""" Cisco_IOS_XR_l2vpn_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR l2vpn package operational data.

This module contains definitions
for the following management objects\:
  l2vpn\-forwarding\: Show L2VPN forwarding
  l2vpnv2\: l2vpnv2
  l2vpn\: l2vpn
  generic\-interface\-list\-v2\: generic interface list v2

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class EvpnMainInterface(Enum):
    """
    EvpnMainInterface

    Evpn main interface

    .. data:: evpn_main_interface_ac = 1

    	EVPN main interface type AC

    .. data:: evpn_main_interface_nve = 2

    	EVPN main interface type NVE

    .. data:: evpn_main_interface_ac_vfi = 3

    	EVPN main interface type AC VFI

    .. data:: evpn_main_interface_ac_pw = 4

    	EVPN main interface type AC PW

    """

    evpn_main_interface_ac = Enum.YLeaf(1, "evpn-main-interface-ac")

    evpn_main_interface_nve = Enum.YLeaf(2, "evpn-main-interface-nve")

    evpn_main_interface_ac_vfi = Enum.YLeaf(3, "evpn-main-interface-ac-vfi")

    evpn_main_interface_ac_pw = Enum.YLeaf(4, "evpn-main-interface-ac-pw")


class IccpSmPortState(Enum):
    """
    IccpSmPortState

    ICCP\-based service multi\-homing port state

    .. data:: unknown = 0

    	Unknown

    .. data:: unconfigured = 1

    	Unconfigured

    .. data:: unsynchronized = 2

    	Unsynchronized

    .. data:: operational = 3

    	Operational

    .. data:: failed = 4

    	Failed

    .. data:: reverting = 5

    	Reverting

    """

    unknown = Enum.YLeaf(0, "unknown")

    unconfigured = Enum.YLeaf(1, "unconfigured")

    unsynchronized = Enum.YLeaf(2, "unsynchronized")

    operational = Enum.YLeaf(3, "operational")

    failed = Enum.YLeaf(4, "failed")

    reverting = Enum.YLeaf(5, "reverting")


class IccpSmState(Enum):
    """
    IccpSmState

    ICCP\-based service multi\-homing group state

    .. data:: unresolved = 0

    	Unresolved

    .. data:: provisioned = 1

    	Provisioned

    .. data:: connecting = 2

    	Connecting

    .. data:: connected = 3

    	Connected

    .. data:: synchronizing = 4

    	Synchronizing

    .. data:: synchronized = 5

    	Synchronized

    """

    unresolved = Enum.YLeaf(0, "unresolved")

    provisioned = Enum.YLeaf(1, "provisioned")

    connecting = Enum.YLeaf(2, "connecting")

    connected = Enum.YLeaf(3, "connected")

    synchronizing = Enum.YLeaf(4, "synchronizing")

    synchronized = Enum.YLeaf(5, "synchronized")


class IflistRepStatus(Enum):
    """
    IflistRepStatus

    Interface list replication status

    .. data:: invalid = 0

    	Invalid

    .. data:: pending = 1

    	Pending

    .. data:: done = 2

    	Done

    .. data:: not_supported = 3

    	Not supported

    .. data:: failed = 4

    	Failed

    """

    invalid = Enum.YLeaf(0, "invalid")

    pending = Enum.YLeaf(1, "pending")

    done = Enum.YLeaf(2, "done")

    not_supported = Enum.YLeaf(3, "not-supported")

    failed = Enum.YLeaf(4, "failed")


class L2FibFeature(Enum):
    """
    L2FibFeature

    L2fib feature

    .. data:: l2fib_feature_dhcp_snooping = 0

    	l2fib feature dhcp snooping

    .. data:: l2fib_feature_igmp_snooping = 1

    	l2fib feature igmp snooping

    .. data:: l2fib_feature_mld_snooping = 2

    	l2fib feature mld snooping

    .. data:: l2fib_feature_max = 3

    	l2fib feature max

    """

    l2fib_feature_dhcp_snooping = Enum.YLeaf(0, "l2fib-feature-dhcp-snooping")

    l2fib_feature_igmp_snooping = Enum.YLeaf(1, "l2fib-feature-igmp-snooping")

    l2fib_feature_mld_snooping = Enum.YLeaf(2, "l2fib-feature-mld-snooping")

    l2fib_feature_max = Enum.YLeaf(3, "l2fib-feature-max")


class L2FibG8032ApsPortStatus(Enum):
    """
    L2FibG8032ApsPortStatus

    APS port status

    .. data:: l2fib_aps_port_state_unknown = 0

    	APS port state unknown

    .. data:: l2fib_aps_port_state_unbound = 1

    	APS port state unbound

    .. data:: l2fib_aps_port_state_bound = 2

    	APS port state bound

    """

    l2fib_aps_port_state_unknown = Enum.YLeaf(0, "l2fib-aps-port-state-unknown")

    l2fib_aps_port_state_unbound = Enum.YLeaf(1, "l2fib-aps-port-state-unbound")

    l2fib_aps_port_state_bound = Enum.YLeaf(2, "l2fib-aps-port-state-bound")


class L2FibG8032Rpl(Enum):
    """
    L2FibG8032Rpl

    RPL types in g8032 ring

    .. data:: rpl_unknown = 0

    	No RPL info

    .. data:: port0_owner = 1

    	Port 0 owner

    .. data:: port0_neighbor = 2

    	Port 0 neighbor

    .. data:: port0_next_neighbor = 3

    	Port 0 next neighbor

    .. data:: port1_owner = 4

    	Port 1 owner

    .. data:: port1_neighbor = 5

    	Port 1 neighbor

    .. data:: port1_next_neighbor = 6

    	Port 1 next neighbor

    """

    rpl_unknown = Enum.YLeaf(0, "rpl-unknown")

    port0_owner = Enum.YLeaf(1, "port0-owner")

    port0_neighbor = Enum.YLeaf(2, "port0-neighbor")

    port0_next_neighbor = Enum.YLeaf(3, "port0-next-neighbor")

    port1_owner = Enum.YLeaf(4, "port1-owner")

    port1_neighbor = Enum.YLeaf(5, "port1-neighbor")

    port1_next_neighbor = Enum.YLeaf(6, "port1-next-neighbor")


class L2FibGroupState(Enum):
    """
    L2FibGroupState

    group state

    .. data:: up = 0

    	Group State Up

    .. data:: down = 1

    	Group State Down

    """

    up = Enum.YLeaf(0, "up")

    down = Enum.YLeaf(1, "down")


class L2FibIpAddr(Enum):
    """
    L2FibIpAddr

    L2fib ip addr

    .. data:: ip_none = 0

    	ip none

    .. data:: v4 = 4

    	v4

    .. data:: v6 = 6

    	v6

    """

    ip_none = Enum.YLeaf(0, "ip-none")

    v4 = Enum.YLeaf(4, "v4")

    v6 = Enum.YLeaf(6, "v6")


class L2FibL2TpSession(Enum):
    """
    L2FibL2TpSession

    L2TPv2 and L2TPv3 session type

    .. data:: l2tpv3 = 0

    	L2TPv3 session

    .. data:: l2tpv2 = 1

    	L2TPv2 session

    """

    l2tpv3 = Enum.YLeaf(0, "l2tpv3")

    l2tpv2 = Enum.YLeaf(1, "l2tpv2")


class L2FibLoadBal(Enum):
    """
    L2FibLoadBal

    L2fib load bal

    .. data:: flow_undef = 0

    	Load Balance Flow Undefined

    .. data:: src_dst_mac = 1

    	Load Balance Flow src-dst-mac

    .. data:: src_dst_ip = 2

    	Load Balance Flow src-dst-ip

    .. data:: vc = 3

    	Load Balance VC based

    """

    flow_undef = Enum.YLeaf(0, "flow-undef")

    src_dst_mac = Enum.YLeaf(1, "src-dst-mac")

    src_dst_ip = Enum.YLeaf(2, "src-dst-ip")

    vc = Enum.YLeaf(3, "vc")


class L2FibMainIfInstanceState(Enum):
    """
    L2FibMainIfInstanceState

    State of a main port instance

    .. data:: forwarding = 0

    	Forwarding state

    .. data:: blocked = 1

    	Blocked state

    .. data:: mac_learning = 2

    	Mac learning state

    .. data:: nack = 3

    	Nack state

    .. data:: forwarning_not_useful = 4

    	Forwarding not useful state

    .. data:: blocked_not_useful = 5

    	Blocked not useful state

    .. data:: mac_learning_not_useful = 6

    	Mac Learning not useful state

    .. data:: blocked_data_only = 7

    	Blocked data only state

    .. data:: multicast_pe2ce_blocked = 8

    	Multicast PE to CE blocked state

    .. data:: multicast_blocked = 9

    	Multicast blocked state

    .. data:: port_state_unknown = 10

    	Port state unknown

    """

    forwarding = Enum.YLeaf(0, "forwarding")

    blocked = Enum.YLeaf(1, "blocked")

    mac_learning = Enum.YLeaf(2, "mac-learning")

    nack = Enum.YLeaf(3, "nack")

    forwarning_not_useful = Enum.YLeaf(4, "forwarning-not-useful")

    blocked_not_useful = Enum.YLeaf(5, "blocked-not-useful")

    mac_learning_not_useful = Enum.YLeaf(6, "mac-learning-not-useful")

    blocked_data_only = Enum.YLeaf(7, "blocked-data-only")

    multicast_pe2ce_blocked = Enum.YLeaf(8, "multicast-pe2ce-blocked")

    multicast_blocked = Enum.YLeaf(9, "multicast-blocked")

    port_state_unknown = Enum.YLeaf(10, "port-state-unknown")


class L2FibPwId(Enum):
    """
    L2FibPwId

    Pseudowire ID type

    .. data:: default = 0

    	Default value - not set

    .. data:: manual = 1

    	Manual pseudowire ID

    .. data:: vpls = 2

    	VPLS pseudowire ID

    .. data:: vpws = 3

    	VPWS pseudowire ID

    .. data:: vpls_ldp = 4

    	VPLS with LDP signaling pseudowire ID

    .. data:: l2fib_pw_id_type_pwr = 5

    	PW-routing ID

    .. data:: l2fib_pw_id_type_evpn = 6

    	EVPN pseudowire ID

    """

    default = Enum.YLeaf(0, "default")

    manual = Enum.YLeaf(1, "manual")

    vpls = Enum.YLeaf(2, "vpls")

    vpws = Enum.YLeaf(3, "vpws")

    vpls_ldp = Enum.YLeaf(4, "vpls-ldp")

    l2fib_pw_id_type_pwr = Enum.YLeaf(5, "l2fib-pw-id-type-pwr")

    l2fib_pw_id_type_evpn = Enum.YLeaf(6, "l2fib-pw-id-type-evpn")


class L2FibPwRedundancyRole(Enum):
    """
    L2FibPwRedundancyRole

    Pseudowire redundancy role

    .. data:: primary = 0

    	Primary pseudowire

    .. data:: backup = 1

    	Backup pseudowire

    """

    primary = Enum.YLeaf(0, "primary")

    backup = Enum.YLeaf(1, "backup")


class L2FibStormControlRateUnit(Enum):
    """
    L2FibStormControlRateUnit

    Storm Control Rate Unit Type

    .. data:: pps = 0

    	Packets Per Second

    .. data:: kb_ps = 1

    	Kilobits Per Second

    """

    pps = Enum.YLeaf(0, "pps")

    kb_ps = Enum.YLeaf(1, "kb-ps")


class L2VpnAcEncap(Enum):
    """
    L2VpnAcEncap

    L2vpn ac encap

    .. data:: unknown_encap = 0

    	unknown encap

    .. data:: vlan = 1

    	vlan

    .. data:: qinq = 2

    	qinq

    .. data:: qin_any = 3

    	qin any

    .. data:: ethernet = 4

    	ethernet

    .. data:: atm_aal0 = 5

    	atm aal0

    .. data:: atm_aal5 = 6

    	atm aal5

    .. data:: atm_vp = 7

    	atm vp

    .. data:: atm_port = 8

    	atm port

    .. data:: hdlc = 9

    	hdlc

    .. data:: fr_dlci = 10

    	fr dlci

    .. data:: fr_dlci_local = 11

    	fr dlci local

    .. data:: ppp = 12

    	ppp

    .. data:: tdm_sa_to_p_e1 = 13

    	tdm sa to p e1

    .. data:: tdm_sa_to_p_t1 = 14

    	tdm sa to p t1

    .. data:: tdm_sa_to_p_e3 = 15

    	tdm sa to p e3

    .. data:: tdm_sa_to_p_t3 = 16

    	tdm sa to p t3

    .. data:: tdm_ce_so_psn = 17

    	tdm ce so psn

    .. data:: ip = 18

    	ip

    .. data:: vlan_encap = 19

    	vlan encap

    .. data:: dot1ad = 20

    	dot1ad

    .. data:: efp = 21

    	efp

    .. data:: bvi = 22

    	bvi

    .. data:: monitor_session = 23

    	monitor session

    .. data:: pseudowire_ether = 24

    	pseudowire ether

    .. data:: pseudowire_iw = 25

    	pseudowire iw

    .. data:: multi_segment_pseudowire = 26

    	multi segment pseudowire

    .. data:: pseudowire_l2_subinterface = 27

    	pseudowire l2 subinterface

    .. data:: virtual_network_interface = 28

    	virtual network interface

    .. data:: encap_types_max = 29

    	encap types max

    """

    unknown_encap = Enum.YLeaf(0, "unknown-encap")

    vlan = Enum.YLeaf(1, "vlan")

    qinq = Enum.YLeaf(2, "qinq")

    qin_any = Enum.YLeaf(3, "qin-any")

    ethernet = Enum.YLeaf(4, "ethernet")

    atm_aal0 = Enum.YLeaf(5, "atm-aal0")

    atm_aal5 = Enum.YLeaf(6, "atm-aal5")

    atm_vp = Enum.YLeaf(7, "atm-vp")

    atm_port = Enum.YLeaf(8, "atm-port")

    hdlc = Enum.YLeaf(9, "hdlc")

    fr_dlci = Enum.YLeaf(10, "fr-dlci")

    fr_dlci_local = Enum.YLeaf(11, "fr-dlci-local")

    ppp = Enum.YLeaf(12, "ppp")

    tdm_sa_to_p_e1 = Enum.YLeaf(13, "tdm-sa-to-p-e1")

    tdm_sa_to_p_t1 = Enum.YLeaf(14, "tdm-sa-to-p-t1")

    tdm_sa_to_p_e3 = Enum.YLeaf(15, "tdm-sa-to-p-e3")

    tdm_sa_to_p_t3 = Enum.YLeaf(16, "tdm-sa-to-p-t3")

    tdm_ce_so_psn = Enum.YLeaf(17, "tdm-ce-so-psn")

    ip = Enum.YLeaf(18, "ip")

    vlan_encap = Enum.YLeaf(19, "vlan-encap")

    dot1ad = Enum.YLeaf(20, "dot1ad")

    efp = Enum.YLeaf(21, "efp")

    bvi = Enum.YLeaf(22, "bvi")

    monitor_session = Enum.YLeaf(23, "monitor-session")

    pseudowire_ether = Enum.YLeaf(24, "pseudowire-ether")

    pseudowire_iw = Enum.YLeaf(25, "pseudowire-iw")

    multi_segment_pseudowire = Enum.YLeaf(26, "multi-segment-pseudowire")

    pseudowire_l2_subinterface = Enum.YLeaf(27, "pseudowire-l2-subinterface")

    virtual_network_interface = Enum.YLeaf(28, "virtual-network-interface")

    encap_types_max = Enum.YLeaf(29, "encap-types-max")


class L2VpnAdLsdErr(Enum):
    """
    L2VpnAdLsdErr

    L2vpn ad lsd err

    .. data:: l2vpn_ad_lsd_err_type_none = 0

    	No Error

    .. data:: l2vpn_ad_lsd_err_type_rw_create_abort_lbl_alloc = 1

    	RW Creation aborted due to related Lbl Alloc

    	failure

    .. data:: l2vpn_ad_lsd_err_type_lbl_alloc_abort_rw_create = 2

    	Lbl Alloc disallowed due to related RW Creation

    	failure

    .. data:: l2vpn_ad_lsd_err_type_lbl_alloc_abort_lbl_alloc = 3

    	Lbl Alloc disallowed due to related Lbl Alloc

    	failure

    .. data:: l2vpn_ad_lsd_err_type_lbl_alloc_lbl_ctx_mismatch = 4

    	Lbl Ctx mismatch

    .. data:: l2vpn_ad_lsd_err_type_rw_create_fpi_size_mismatch = 5

    	FPI Size mismatch

    .. data:: l2vpn_ad_lsd_err_type_rw_create_fpi_version_mismatch = 6

    	FPI Version mismatch

    .. data:: l2vpn_ad_lsd_err_type_enospc = 7

    	Out of Label

    .. data:: l2vpn_ad_lsd_err_type_enomem = 8

    	No Memory

    .. data:: l2vpn_ad_lsd_err_type_undefined = 9

    	LABEL ERR

    """

    l2vpn_ad_lsd_err_type_none = Enum.YLeaf(0, "l2vpn-ad-lsd-err-type-none")

    l2vpn_ad_lsd_err_type_rw_create_abort_lbl_alloc = Enum.YLeaf(1, "l2vpn-ad-lsd-err-type-rw-create-abort-lbl-alloc")

    l2vpn_ad_lsd_err_type_lbl_alloc_abort_rw_create = Enum.YLeaf(2, "l2vpn-ad-lsd-err-type-lbl-alloc-abort-rw-create")

    l2vpn_ad_lsd_err_type_lbl_alloc_abort_lbl_alloc = Enum.YLeaf(3, "l2vpn-ad-lsd-err-type-lbl-alloc-abort-lbl-alloc")

    l2vpn_ad_lsd_err_type_lbl_alloc_lbl_ctx_mismatch = Enum.YLeaf(4, "l2vpn-ad-lsd-err-type-lbl-alloc-lbl-ctx-mismatch")

    l2vpn_ad_lsd_err_type_rw_create_fpi_size_mismatch = Enum.YLeaf(5, "l2vpn-ad-lsd-err-type-rw-create-fpi-size-mismatch")

    l2vpn_ad_lsd_err_type_rw_create_fpi_version_mismatch = Enum.YLeaf(6, "l2vpn-ad-lsd-err-type-rw-create-fpi-version-mismatch")

    l2vpn_ad_lsd_err_type_enospc = Enum.YLeaf(7, "l2vpn-ad-lsd-err-type-enospc")

    l2vpn_ad_lsd_err_type_enomem = Enum.YLeaf(8, "l2vpn-ad-lsd-err-type-enomem")

    l2vpn_ad_lsd_err_type_undefined = Enum.YLeaf(9, "l2vpn-ad-lsd-err-type-undefined")


class L2VpnAdRd(Enum):
    """
    L2VpnAdRd

    L2vpn ad rd

    .. data:: l2vpn_ad_rd_none = 0

    	Route Distinguisher not set

    .. data:: l2vpn_ad_rd_auto = 1

    	Route Distinguisher auto-generated

    .. data:: l2vpn_ad_rd_as = 2

    	Route Distinguisher with 2 Byte AS number

    .. data:: l2vpn_ad_rd_4byte_as = 3

    	Route Distinguisher with 4 Byte AS number

    .. data:: l2vpn_ad_rd_v4_addr = 4

    	Route Distinguisher with IPv4 Address

    """

    l2vpn_ad_rd_none = Enum.YLeaf(0, "l2vpn-ad-rd-none")

    l2vpn_ad_rd_auto = Enum.YLeaf(1, "l2vpn-ad-rd-auto")

    l2vpn_ad_rd_as = Enum.YLeaf(2, "l2vpn-ad-rd-as")

    l2vpn_ad_rd_4byte_as = Enum.YLeaf(3, "l2vpn-ad-rd-4byte-as")

    l2vpn_ad_rd_v4_addr = Enum.YLeaf(4, "l2vpn-ad-rd-v4-addr")


class L2VpnAdRt(Enum):
    """
    L2VpnAdRt

    L2vpn ad rt

    .. data:: l2vpn_ad_rt_none = 0

    	Route target not set

    .. data:: l2vpn_ad_rt_as = 1

    	Route Target with 2 Byte AS number

    .. data:: l2vpn_ad_rt_4byte_as = 2

    	Route Target with 4 Byte AS number

    .. data:: l2vpn_ad_rt_v4_addr = 3

    	Route Target with IPv4 Address

    .. data:: es_import = 1538

    	Ethernet Segment Route Target from BGP

    """

    l2vpn_ad_rt_none = Enum.YLeaf(0, "l2vpn-ad-rt-none")

    l2vpn_ad_rt_as = Enum.YLeaf(1, "l2vpn-ad-rt-as")

    l2vpn_ad_rt_4byte_as = Enum.YLeaf(2, "l2vpn-ad-rt-4byte-as")

    l2vpn_ad_rt_v4_addr = Enum.YLeaf(3, "l2vpn-ad-rt-v4-addr")

    es_import = Enum.YLeaf(1538, "es-import")


class L2VpnAdSigMethod(Enum):
    """
    L2VpnAdSigMethod

    L2vpn ad sig method

    .. data:: l2vpn_ad_sig_method_none = 0

    	None

    .. data:: l2vpn_ad_sig_method_bgp = 1

    	BGP

    .. data:: l2vpn_ad_sig_method_ldp = 2

    	LDP

    """

    l2vpn_ad_sig_method_none = Enum.YLeaf(0, "l2vpn-ad-sig-method-none")

    l2vpn_ad_sig_method_bgp = Enum.YLeaf(1, "l2vpn-ad-sig-method-bgp")

    l2vpn_ad_sig_method_ldp = Enum.YLeaf(2, "l2vpn-ad-sig-method-ldp")


class L2VpnAdVplsId(Enum):
    """
    L2VpnAdVplsId

    L2vpn ad vpls id

    .. data:: l2vpn_ad_vpls_id_none = 0

    	VPLS-ID not set

    .. data:: l2vpn_ad_vpls_id_auto = 1

    	Auto generated VPLS-ID

    .. data:: l2vpn_ad_vpls_id_as = 10

    	VPLS-ID with 2 Byte AS number

    .. data:: l2vpn_ad_vpls_id_v4_addr = 266

    	VPLS-ID with IPv4 Address

    """

    l2vpn_ad_vpls_id_none = Enum.YLeaf(0, "l2vpn-ad-vpls-id-none")

    l2vpn_ad_vpls_id_auto = Enum.YLeaf(1, "l2vpn-ad-vpls-id-auto")

    l2vpn_ad_vpls_id_as = Enum.YLeaf(10, "l2vpn-ad-vpls-id-as")

    l2vpn_ad_vpls_id_v4_addr = Enum.YLeaf(266, "l2vpn-ad-vpls-id-v4-addr")


class L2VpnAtmMode(Enum):
    """
    L2VpnAtmMode

    L2vpn atm mode

    .. data:: l2vpn_atm_port_mode = 0

    	ATM port mode

    .. data:: l2vpn_atm_vp_mode = 1

    	ATM Virtual Path mode

    .. data:: l2vpn_atm_vc_mode = 2

    	ATM Virtual Channel mode

    """

    l2vpn_atm_port_mode = Enum.YLeaf(0, "l2vpn-atm-port-mode")

    l2vpn_atm_vp_mode = Enum.YLeaf(1, "l2vpn-atm-vp-mode")

    l2vpn_atm_vc_mode = Enum.YLeaf(2, "l2vpn-atm-vc-mode")


class L2VpnBagAdEncap(Enum):
    """
    L2VpnBagAdEncap

    L2VPN AD Encapsulation

    .. data:: l2vpn_bag_ad_encap_not_specified = 0

    	Not Specified

    .. data:: l2vpn_bag_ad_encap_ether_vlan = 1

    	Ether VLAN

    .. data:: l2vpn_bag_ad_encap_ether = 2

    	Ethernet

    """

    l2vpn_bag_ad_encap_not_specified = Enum.YLeaf(0, "l2vpn-bag-ad-encap-not-specified")

    l2vpn_bag_ad_encap_ether_vlan = Enum.YLeaf(1, "l2vpn-bag-ad-encap-ether-vlan")

    l2vpn_bag_ad_encap_ether = Enum.YLeaf(2, "l2vpn-bag-ad-encap-ether")


class L2VpnBagMacAgingMode(Enum):
    """
    L2VpnBagMacAgingMode

    L2vpn bag mac aging mode

    .. data:: aging_none = 0

    	MAC Aging None

    .. data:: aging_absolute = 1

    	Mac Aging Absolute

    .. data:: aging_inactivity = 2

    	Mac Aging Inactivity

    """

    aging_none = Enum.YLeaf(0, "aging-none")

    aging_absolute = Enum.YLeaf(1, "aging-absolute")

    aging_inactivity = Enum.YLeaf(2, "aging-inactivity")


class L2VpnBagMacLimitAction(Enum):
    """
    L2VpnBagMacLimitAction

    L2vpn bag mac limit action

    .. data:: limit_none = 0

    	MAC Limit Action None

    .. data:: limit_flood = 1

    	MAC Limit Action Flood

    .. data:: limit_no_flood = 2

    	MAC Limit Action No Flood

    .. data:: limit_shutdown = 3

    	MAC Limit Action Shut

    .. data:: limit_no_config = 4

    	Mac Limit Action No Config

    """

    limit_none = Enum.YLeaf(0, "limit-none")

    limit_flood = Enum.YLeaf(1, "limit-flood")

    limit_no_flood = Enum.YLeaf(2, "limit-no-flood")

    limit_shutdown = Enum.YLeaf(3, "limit-shutdown")

    limit_no_config = Enum.YLeaf(4, "limit-no-config")


class L2VpnBagMacLimitNotify(Enum):
    """
    L2VpnBagMacLimitNotify

    L2vpn bag mac limit notify

    .. data:: mac_limit_notify_none = 0

    	MAC Limit Notify None

    .. data:: mac_limit_notify_syslog = 1

    	MAC Limit Notify Syslog

    .. data:: mac_limit_notify_trap = 2

    	MAC Limit Notify Trap

    .. data:: mac_limit_notify_syslog_trap = 3

    	MAC Limit Notify Syslog and Trap

    .. data:: mac_limit_notify_no_config = 4

    	MAC Limit Notify No Config

    """

    mac_limit_notify_none = Enum.YLeaf(0, "mac-limit-notify-none")

    mac_limit_notify_syslog = Enum.YLeaf(1, "mac-limit-notify-syslog")

    mac_limit_notify_trap = Enum.YLeaf(2, "mac-limit-notify-trap")

    mac_limit_notify_syslog_trap = Enum.YLeaf(3, "mac-limit-notify-syslog-trap")

    mac_limit_notify_no_config = Enum.YLeaf(4, "mac-limit-notify-no-config")


class L2VpnBagMacSecureAction(Enum):
    """
    L2VpnBagMacSecureAction

    L2vpn bag mac secure action

    .. data:: not_set = 0

    	MAC Secure Action Not Set

    .. data:: restrict = 1

    	MAC Secure Action Restrict

    .. data:: none = 2

    	MAC Secure Action None

    .. data:: shutdown = 3

    	MAC Secure Action Shutdown

    """

    not_set = Enum.YLeaf(0, "not-set")

    restrict = Enum.YLeaf(1, "restrict")

    none = Enum.YLeaf(2, "none")

    shutdown = Enum.YLeaf(3, "shutdown")


class L2VpnBagMacWithdrawOption(Enum):
    """
    L2VpnBagMacWithdrawOption

    L2vpn bag mac withdraw option

    .. data:: mac_withdraw_option_state_up = 0

    	Mac withdraw on state up

    .. data:: mac_withdraw_option_state_down = 1

    	Mac withdraw on state down

    .. data:: mac_withdraw_option_optimize = 2

    	Optimized Mac withdraw

    """

    mac_withdraw_option_state_up = Enum.YLeaf(0, "mac-withdraw-option-state-up")

    mac_withdraw_option_state_down = Enum.YLeaf(1, "mac-withdraw-option-state-down")

    mac_withdraw_option_optimize = Enum.YLeaf(2, "mac-withdraw-option-optimize")


class L2VpnBagStormControlRateUnit(Enum):
    """
    L2VpnBagStormControlRateUnit

    Storm Control Rate Unit Type

    .. data:: pps = 0

    	Packets Per Second

    .. data:: kb_ps = 1

    	Kilobits Per Second

    """

    pps = Enum.YLeaf(0, "pps")

    kb_ps = Enum.YLeaf(1, "kb-ps")


class L2VpnBridge(Enum):
    """
    L2VpnBridge

    L2vpn bridge

    .. data:: l2vpn_bridge_type_default = 0

    	Regular none PBB bridge

    .. data:: l2vpn_bridge_type_pbb_edge = 1

    	PBB edge bridge

    .. data:: l2vpn_bridge_type_pbb_core = 2

    	PBB core bridge

    """

    l2vpn_bridge_type_default = Enum.YLeaf(0, "l2vpn-bridge-type-default")

    l2vpn_bridge_type_pbb_edge = Enum.YLeaf(1, "l2vpn-bridge-type-pbb-edge")

    l2vpn_bridge_type_pbb_core = Enum.YLeaf(2, "l2vpn-bridge-type-pbb-core")


class L2VpnBridgeCoupledState(Enum):
    """
    L2VpnBridgeCoupledState

    L2vpn bridge coupled state

    .. data:: disabled = 0

    	Coupled mode disabled

    .. data:: down = 2

    	Coupled state down

    .. data:: up = 3

    	Coupled state up

    """

    disabled = Enum.YLeaf(0, "disabled")

    down = Enum.YLeaf(2, "down")

    up = Enum.YLeaf(3, "up")


class L2VpnBridgeState(Enum):
    """
    L2VpnBridgeState

    L2vpn bridge state

    .. data:: bridge_init = 0

    	Bridge Init State

    .. data:: bridge_up = 1

    	Bridge Up

    .. data:: bridge_down = 2

    	Bridge Down

    .. data:: bridge_admin_down = 3

    	Bridge Admin Down

    """

    bridge_init = Enum.YLeaf(0, "bridge-init")

    bridge_up = Enum.YLeaf(1, "bridge-up")

    bridge_down = Enum.YLeaf(2, "bridge-down")

    bridge_admin_down = Enum.YLeaf(3, "bridge-admin-down")


class L2VpnBriefPsn(Enum):
    """
    L2VpnBriefPsn

    L2vpn brief psn

    .. data:: ls = 0

    	ls

    .. data:: atom = 1

    	atom

    .. data:: l2tpv3 = 2

    	l2tpv3

    .. data:: unknown_psn = 3

    	unknown psn

    """

    ls = Enum.YLeaf(0, "ls")

    atom = Enum.YLeaf(1, "atom")

    l2tpv3 = Enum.YLeaf(2, "l2tpv3")

    unknown_psn = Enum.YLeaf(3, "unknown-psn")


class L2VpnEncapMethod(Enum):
    """
    L2VpnEncapMethod

    Encapsulation Method

    .. data:: l2vpn_pw_encaps_not_specified = 0

    	Not Specified

    .. data:: l2vpn_pw_encaps_l2tpv3 = 1

    	L2TPv3 encapsulation

    .. data:: l2vpn_pw_encaps_l2tpv2 = 2

    	L2TPv2 encapsulation

    .. data:: l2vpn_pw_encaps_mpls = 3

    	MPLS encapsulation

    .. data:: l2vpn_pw_encaps_unknown = 4

    	Unknown

    """

    l2vpn_pw_encaps_not_specified = Enum.YLeaf(0, "l2vpn-pw-encaps-not-specified")

    l2vpn_pw_encaps_l2tpv3 = Enum.YLeaf(1, "l2vpn-pw-encaps-l2tpv3")

    l2vpn_pw_encaps_l2tpv2 = Enum.YLeaf(2, "l2vpn-pw-encaps-l2tpv2")

    l2vpn_pw_encaps_mpls = Enum.YLeaf(3, "l2vpn-pw-encaps-mpls")

    l2vpn_pw_encaps_unknown = Enum.YLeaf(4, "l2vpn-pw-encaps-unknown")


class L2VpnFrMode(Enum):
    """
    L2VpnFrMode

    L2vpn fr mode

    .. data:: l2vpn_fr_port_mode = 0

    	Frame Relay port mode

    .. data:: l2vpn_fr_dlci_mode = 1

    	Frame Relay DLCI mode

    """

    l2vpn_fr_port_mode = Enum.YLeaf(0, "l2vpn-fr-port-mode")

    l2vpn_fr_dlci_mode = Enum.YLeaf(1, "l2vpn-fr-dlci-mode")


class L2VpnG8032Rpl(Enum):
    """
    L2VpnG8032Rpl

    RPL types in g8032 ring

    .. data:: rpl_unknown = 0

    	No RPL info

    .. data:: port0_owner = 1

    	Port 0 owner

    .. data:: port0_neighbor = 2

    	Port 0 neighbor

    .. data:: port0_next_neighbor = 3

    	Port 0 next neighbor

    .. data:: port1_owner = 4

    	Port 1 owner

    .. data:: port1_neighbor = 5

    	Port 1 neighbor

    .. data:: port1_next_neighbor = 6

    	Port 1 next neighbor

    """

    rpl_unknown = Enum.YLeaf(0, "rpl-unknown")

    port0_owner = Enum.YLeaf(1, "port0-owner")

    port0_neighbor = Enum.YLeaf(2, "port0-neighbor")

    port0_next_neighbor = Enum.YLeaf(3, "port0-next-neighbor")

    port1_owner = Enum.YLeaf(4, "port1-owner")

    port1_neighbor = Enum.YLeaf(5, "port1-neighbor")

    port1_next_neighbor = Enum.YLeaf(6, "port1-next-neighbor")


class L2VpnG8032UncfgReason(Enum):
    """
    L2VpnG8032UncfgReason

    Unresolved reason for G8032 ring instance

    .. data:: reason_none = 0

    	No reason

    .. data:: ring_mp0_missing = 1

    	Main port0 missing

    .. data:: ring_mp1_missing = 2

    	Main port1 missing

    .. data:: inclusion_list_empty = 3

    	Inclusion list empty

    .. data:: aps0_missing = 4

    	APS port0 missing

    .. data:: aps0bp_notfound = 5

    	APS port0 not found as valid BP

    .. data:: aps0_no_ac_ctx = 6

    	APS port0 has no valid AC context

    .. data:: aps0_not_in_inclusion_list = 7

    	APS port0 not in inclusion list

    .. data:: aps0_mismatched = 8

    	APS port0 mismatched with main port

    .. data:: aps1_missing = 9

    	APS port1 missing

    .. data:: aps1bp_notfound = 10

    	APS port1 not found as valid BP

    .. data:: aps1_no_ac_ctx = 11

    	APS port1 has no valid AC context

    .. data:: aps1_not_in_inclusion_list = 12

    	APS port1 not in inclusion list

    .. data:: aps1_mismatched = 13

    	APS port1 mismatched with main port

    .. data:: aps_unprovisioned = 14

    	APS AC unrpvosioned

    """

    reason_none = Enum.YLeaf(0, "reason-none")

    ring_mp0_missing = Enum.YLeaf(1, "ring-mp0-missing")

    ring_mp1_missing = Enum.YLeaf(2, "ring-mp1-missing")

    inclusion_list_empty = Enum.YLeaf(3, "inclusion-list-empty")

    aps0_missing = Enum.YLeaf(4, "aps0-missing")

    aps0bp_notfound = Enum.YLeaf(5, "aps0bp-notfound")

    aps0_no_ac_ctx = Enum.YLeaf(6, "aps0-no-ac-ctx")

    aps0_not_in_inclusion_list = Enum.YLeaf(7, "aps0-not-in-inclusion-list")

    aps0_mismatched = Enum.YLeaf(8, "aps0-mismatched")

    aps1_missing = Enum.YLeaf(9, "aps1-missing")

    aps1bp_notfound = Enum.YLeaf(10, "aps1bp-notfound")

    aps1_no_ac_ctx = Enum.YLeaf(11, "aps1-no-ac-ctx")

    aps1_not_in_inclusion_list = Enum.YLeaf(12, "aps1-not-in-inclusion-list")

    aps1_mismatched = Enum.YLeaf(13, "aps1-mismatched")

    aps_unprovisioned = Enum.YLeaf(14, "aps-unprovisioned")


class L2VpnIdMgrApp(Enum):
    """
    L2VpnIdMgrApp

    L2VPN ID Manager App Type

    .. data:: l2vpn_id_mgr_app_type_virtual_ac = 0

    	Virtual AC

    .. data:: l2vpn_id_mgr_app_type_ac = 1

    	AC

    .. data:: l2vpn_id_mgr_app_type_pw = 2

    	PW

    .. data:: l2vpn_id_mgr_app_type_bd = 3

    	BD

    .. data:: l2vpn_id_mgr_app_type_mp2mp = 4

    	MP2MP

    .. data:: l2vpn_id_mgr_app_type_rd = 5

    	RD

    .. data:: l2vpn_id_mgr_app_type_pbb = 6

    	PBB

    .. data:: l2vpn_id_mgr_app_type_if_list = 7

    	IFLIST

    .. data:: l2vpn_id_mgr_app_type_atom = 8

    	ATOM

    .. data:: l2vpn_id_mgr_app_type_global = 9

    	GLOBAL

    .. data:: l2vpn_id_mgr_app_type_p_tree = 10

    	PTREE

    .. data:: l2vpn_id_mgr_app_type_pw_group = 11

    	PWGROUP

    .. data:: l2vpn_id_mgr_app_type_evpn = 12

    	EVPN

    .. data:: l2vpn_id_mgr_app_type_evpn_lbl = 13

    	EVPN LBL

    .. data:: l2vpn_id_mgr_app_type_evpn_rd = 14

    	EVPN RD

    .. data:: l2vpn_id_mgr_app_type_count = 15

    	Count/Invalid

    """

    l2vpn_id_mgr_app_type_virtual_ac = Enum.YLeaf(0, "l2vpn-id-mgr-app-type-virtual-ac")

    l2vpn_id_mgr_app_type_ac = Enum.YLeaf(1, "l2vpn-id-mgr-app-type-ac")

    l2vpn_id_mgr_app_type_pw = Enum.YLeaf(2, "l2vpn-id-mgr-app-type-pw")

    l2vpn_id_mgr_app_type_bd = Enum.YLeaf(3, "l2vpn-id-mgr-app-type-bd")

    l2vpn_id_mgr_app_type_mp2mp = Enum.YLeaf(4, "l2vpn-id-mgr-app-type-mp2mp")

    l2vpn_id_mgr_app_type_rd = Enum.YLeaf(5, "l2vpn-id-mgr-app-type-rd")

    l2vpn_id_mgr_app_type_pbb = Enum.YLeaf(6, "l2vpn-id-mgr-app-type-pbb")

    l2vpn_id_mgr_app_type_if_list = Enum.YLeaf(7, "l2vpn-id-mgr-app-type-if-list")

    l2vpn_id_mgr_app_type_atom = Enum.YLeaf(8, "l2vpn-id-mgr-app-type-atom")

    l2vpn_id_mgr_app_type_global = Enum.YLeaf(9, "l2vpn-id-mgr-app-type-global")

    l2vpn_id_mgr_app_type_p_tree = Enum.YLeaf(10, "l2vpn-id-mgr-app-type-p-tree")

    l2vpn_id_mgr_app_type_pw_group = Enum.YLeaf(11, "l2vpn-id-mgr-app-type-pw-group")

    l2vpn_id_mgr_app_type_evpn = Enum.YLeaf(12, "l2vpn-id-mgr-app-type-evpn")

    l2vpn_id_mgr_app_type_evpn_lbl = Enum.YLeaf(13, "l2vpn-id-mgr-app-type-evpn-lbl")

    l2vpn_id_mgr_app_type_evpn_rd = Enum.YLeaf(14, "l2vpn-id-mgr-app-type-evpn-rd")

    l2vpn_id_mgr_app_type_count = Enum.YLeaf(15, "l2vpn-id-mgr-app-type-count")


class L2VpnInterface(Enum):
    """
    L2VpnInterface

    L2vpn interface

    .. data:: l2vpn_intf_type_unknown = 0

    	Unknown

    .. data:: l2vpn_intf_type_ethernet = 1

    	Ethernet

    .. data:: l2vpn_intf_type_vlan = 2

    	Ethernet Vlan

    .. data:: l2vpn_intf_type_atm = 3

    	ATM

    .. data:: l2vpn_intf_type_frame_relay = 4

    	Frame Relay

    .. data:: l2vpn_intf_type_hdlc = 5

    	HDLC

    .. data:: l2vpn_intf_type_ppp = 6

    	PPP

    .. data:: l2vpn_intf_type_span = 7

    	SPAN

    .. data:: l2vpn_intf_type_bvi = 8

    	BVI

    .. data:: l2vpn_intf_type_cem = 9

    	CEM

    .. data:: l2vpn_intf_type_pw_ether = 10

    	PsuedowireEther

    .. data:: l2vpn_intf_type_pw_iw = 11

    	PsuedowireIW

    .. data:: l2vpn_intf_type_vni = 12

    	VXLAN

    """

    l2vpn_intf_type_unknown = Enum.YLeaf(0, "l2vpn-intf-type-unknown")

    l2vpn_intf_type_ethernet = Enum.YLeaf(1, "l2vpn-intf-type-ethernet")

    l2vpn_intf_type_vlan = Enum.YLeaf(2, "l2vpn-intf-type-vlan")

    l2vpn_intf_type_atm = Enum.YLeaf(3, "l2vpn-intf-type-atm")

    l2vpn_intf_type_frame_relay = Enum.YLeaf(4, "l2vpn-intf-type-frame-relay")

    l2vpn_intf_type_hdlc = Enum.YLeaf(5, "l2vpn-intf-type-hdlc")

    l2vpn_intf_type_ppp = Enum.YLeaf(6, "l2vpn-intf-type-ppp")

    l2vpn_intf_type_span = Enum.YLeaf(7, "l2vpn-intf-type-span")

    l2vpn_intf_type_bvi = Enum.YLeaf(8, "l2vpn-intf-type-bvi")

    l2vpn_intf_type_cem = Enum.YLeaf(9, "l2vpn-intf-type-cem")

    l2vpn_intf_type_pw_ether = Enum.YLeaf(10, "l2vpn-intf-type-pw-ether")

    l2vpn_intf_type_pw_iw = Enum.YLeaf(11, "l2vpn-intf-type-pw-iw")

    l2vpn_intf_type_vni = Enum.YLeaf(12, "l2vpn-intf-type-vni")


class L2VpnInterworking(Enum):
    """
    L2VpnInterworking

    L2vpn interworking

    .. data:: l2vpn_iw_type_none = 0

    	None

    .. data:: l2vpn_iw_type_ethernet = 1

    	Ethernet

    .. data:: l2vpn_iw_type_ppp = 2

    	PPP

    .. data:: l2vpn_iw_type_ipv4 = 3

    	IPv4

    .. data:: l2vpn_iw_type_voluntary = 4

    	Voluntary

    .. data:: l2vpn_iw_type_frf8 = 5

    	FRF8

    """

    l2vpn_iw_type_none = Enum.YLeaf(0, "l2vpn-iw-type-none")

    l2vpn_iw_type_ethernet = Enum.YLeaf(1, "l2vpn-iw-type-ethernet")

    l2vpn_iw_type_ppp = Enum.YLeaf(2, "l2vpn-iw-type-ppp")

    l2vpn_iw_type_ipv4 = Enum.YLeaf(3, "l2vpn-iw-type-ipv4")

    l2vpn_iw_type_voluntary = Enum.YLeaf(4, "l2vpn-iw-type-voluntary")

    l2vpn_iw_type_frf8 = Enum.YLeaf(5, "l2vpn-iw-type-frf8")


class L2VpnIpcTransportMode(Enum):
    """
    L2VpnIpcTransportMode

    L2vpn ipc transport mode

    .. data:: unicast = 0

    	L2VPN Unicast IPC transport mode

    .. data:: broadcast = 1

    	L2VPN Broadcast IPC transport mode

    .. data:: unknown = 2

    	L2VPN Unknown IPC transport mode

    """

    unicast = Enum.YLeaf(0, "unicast")

    broadcast = Enum.YLeaf(1, "broadcast")

    unknown = Enum.YLeaf(2, "unknown")


class L2VpnL2TpTunnelState(Enum):
    """
    L2VpnL2TpTunnelState

    L2vpn l2tp tunnel state

    .. data:: l2vpn_l2tp_idle = 0

    	Idle

    .. data:: l2vpn_l2tp_wait_for_connecting = 1

    	Wait for connecting

    .. data:: l2vpn_l2tp_wait_for_connected = 2

    	Wait for connected

    .. data:: l2vpn_l2tp_in_coming_call = 3

    	Incoming call

    .. data:: l2vpn_l2tp_connected = 4

    	Connected

    .. data:: l2vpn_l2tp_disconnected = 5

    	Disconnected

    """

    l2vpn_l2tp_idle = Enum.YLeaf(0, "l2vpn-l2tp-idle")

    l2vpn_l2tp_wait_for_connecting = Enum.YLeaf(1, "l2vpn-l2tp-wait-for-connecting")

    l2vpn_l2tp_wait_for_connected = Enum.YLeaf(2, "l2vpn-l2tp-wait-for-connected")

    l2vpn_l2tp_in_coming_call = Enum.YLeaf(3, "l2vpn-l2tp-in-coming-call")

    l2vpn_l2tp_connected = Enum.YLeaf(4, "l2vpn-l2tp-connected")

    l2vpn_l2tp_disconnected = Enum.YLeaf(5, "l2vpn-l2tp-disconnected")


class L2VpnLoadBal(Enum):
    """
    L2VpnLoadBal

    L2vpn load bal

    .. data:: not_supported = 0

    	Load Balance Flow Not Supported

    .. data:: source_dest_mac = 1

    	Load Balance Flow src-dst-mac

    .. data:: source_dest_ip = 2

    	Load Balance Flow src-dst-ip

    .. data:: undefined = 3

    	Load Balance Flow Undefined

    .. data:: pseudowire_label = 4

    	Load Balance PW Label based

    """

    not_supported = Enum.YLeaf(0, "not-supported")

    source_dest_mac = Enum.YLeaf(1, "source-dest-mac")

    source_dest_ip = Enum.YLeaf(2, "source-dest-ip")

    undefined = Enum.YLeaf(3, "undefined")

    pseudowire_label = Enum.YLeaf(4, "pseudowire-label")


class L2VpnMainIfInstanceState(Enum):
    """
    L2VpnMainIfInstanceState

    State of a main port instance

    .. data:: forwarding = 0

    	Forwarding state

    .. data:: blocked = 1

    	Blocked state

    .. data:: mac_learning = 2

    	Mac learning state

    .. data:: nack = 3

    	Nack state

    .. data:: forwarning_not_useful = 4

    	Forwarding not useful state

    .. data:: blocked_not_useful = 5

    	Blocked not useful state

    .. data:: mac_learning_not_useful = 6

    	Mac Learning not useful state

    .. data:: blocked_data_only = 7

    	Blocked data only state

    .. data:: mcast_pe2_ce_blocked = 8

    	Mcast PE to CE blocked state

    .. data:: port_state_unknown = 9

    	Port state unknown

    """

    forwarding = Enum.YLeaf(0, "forwarding")

    blocked = Enum.YLeaf(1, "blocked")

    mac_learning = Enum.YLeaf(2, "mac-learning")

    nack = Enum.YLeaf(3, "nack")

    forwarning_not_useful = Enum.YLeaf(4, "forwarning-not-useful")

    blocked_not_useful = Enum.YLeaf(5, "blocked-not-useful")

    mac_learning_not_useful = Enum.YLeaf(6, "mac-learning-not-useful")

    blocked_data_only = Enum.YLeaf(7, "blocked-data-only")

    mcast_pe2_ce_blocked = Enum.YLeaf(8, "mcast-pe2-ce-blocked")

    port_state_unknown = Enum.YLeaf(9, "port-state-unknown")


class L2VpnMainIfProtectected(Enum):
    """
    L2VpnMainIfProtectected

    L2vpn main if protectected

    .. data:: erp_protected = 0

    	ERP Protected

    .. data:: mstp_protected = 1

    	MSTP Protected

    .. data:: no_protected = 2

    	No protection

    """

    erp_protected = Enum.YLeaf(0, "erp-protected")

    mstp_protected = Enum.YLeaf(1, "mstp-protected")

    no_protected = Enum.YLeaf(2, "no-protected")


class L2VpnMemoryState(Enum):
    """
    L2VpnMemoryState

    L2vpn memory state

    .. data:: memory_state_unknown = 0

    	Memory state Unknown

    .. data:: memory_state_normal = 1

    	Memory state Normal

    .. data:: memory_state_minor = 2

    	Memory state Minor

    .. data:: memory_state_severe = 3

    	Memory state Severe

    .. data:: memory_state_critical = 4

    	Memory state Critical

    .. data:: memory_state_invalid = 5

    	Memory state Invalid

    """

    memory_state_unknown = Enum.YLeaf(0, "memory-state-unknown")

    memory_state_normal = Enum.YLeaf(1, "memory-state-normal")

    memory_state_minor = Enum.YLeaf(2, "memory-state-minor")

    memory_state_severe = Enum.YLeaf(3, "memory-state-severe")

    memory_state_critical = Enum.YLeaf(4, "memory-state-critical")

    memory_state_invalid = Enum.YLeaf(5, "memory-state-invalid")


class L2VpnMirpLiteProtocolInfo(Enum):
    """
    L2VpnMirpLiteProtocolInfo

    L2vpn mirp lite protocol info

    .. data:: vlan0 = 0

    	MVRP PDU using Vlan0

    .. data:: none = 1

    	none

    """

    vlan0 = Enum.YLeaf(0, "vlan0")

    none = Enum.YLeaf(1, "none")


class L2VpnMirpLiteStatus(Enum):
    """
    L2VpnMirpLiteStatus

    L2vpn mirp lite status

    .. data:: enabled = 0

    	Supported, enabled

    .. data:: not_supported = 1

    	Not supported

    """

    enabled = Enum.YLeaf(0, "enabled")

    not_supported = Enum.YLeaf(1, "not-supported")


class L2VpnMstiState(Enum):
    """
    L2VpnMstiState

    L2VPN MSTI state

    .. data:: msti_bag_stp_port_state_forwarding = 0

    	msti bag stp port state forwarding

    .. data:: msti_bag_stp_port_state_blocked = 1

    	msti bag stp port state blocked

    .. data:: msti_bag_stp_port_state_mac_learning = 2

    	msti bag stp port state mac learning

    .. data:: msti_bag_stp_port_state_nack = 3

    	msti bag stp port state nack

    .. data:: msti_bag_stp_port_state_forwarding_not_useful = 4

    	msti bag stp port state forwarding not useful

    .. data:: msti_bag_stp_port_state_blocked_not_useful = 5

    	msti bag stp port state blocked not useful

    .. data:: msti_bag_stp_port_state_mac_learning_not_useful = 6

    	msti bag stp port state mac learning not useful

    .. data:: msti_bag_erp_port_state_blocked_data_only = 7

    	msti bag erp port state blocked data only

    .. data:: msti_bag_erp_port_state_evpn_mcast_pe2ce_blocked = 8

    	msti bag erp port state evpn mcast pe2ce

    	blocked

    .. data:: msti_bag_erp_port_state_evpn_port_state_mcast_blocked = 9

    	msti bag erp port state evpn port state mcast

    	blocked

    """

    msti_bag_stp_port_state_forwarding = Enum.YLeaf(0, "msti-bag-stp-port-state-forwarding")

    msti_bag_stp_port_state_blocked = Enum.YLeaf(1, "msti-bag-stp-port-state-blocked")

    msti_bag_stp_port_state_mac_learning = Enum.YLeaf(2, "msti-bag-stp-port-state-mac-learning")

    msti_bag_stp_port_state_nack = Enum.YLeaf(3, "msti-bag-stp-port-state-nack")

    msti_bag_stp_port_state_forwarding_not_useful = Enum.YLeaf(4, "msti-bag-stp-port-state-forwarding-not-useful")

    msti_bag_stp_port_state_blocked_not_useful = Enum.YLeaf(5, "msti-bag-stp-port-state-blocked-not-useful")

    msti_bag_stp_port_state_mac_learning_not_useful = Enum.YLeaf(6, "msti-bag-stp-port-state-mac-learning-not-useful")

    msti_bag_erp_port_state_blocked_data_only = Enum.YLeaf(7, "msti-bag-erp-port-state-blocked-data-only")

    msti_bag_erp_port_state_evpn_mcast_pe2ce_blocked = Enum.YLeaf(8, "msti-bag-erp-port-state-evpn-mcast-pe2ce-blocked")

    msti_bag_erp_port_state_evpn_port_state_mcast_blocked = Enum.YLeaf(9, "msti-bag-erp-port-state-evpn-port-state-mcast-blocked")


class L2VpnP2MpPwPtree(Enum):
    """
    L2VpnP2MpPwPtree

    L2vpn p2mp pw ptree

    .. data:: none = 0

    	None

    .. data:: rsvp_te = 1

    	RSVP TE

    .. data:: mldp = 2

    	MLDP

    """

    none = Enum.YLeaf(0, "none")

    rsvp_te = Enum.YLeaf(1, "rsvp-te")

    mldp = Enum.YLeaf(2, "mldp")


class L2VpnPeer(Enum):
    """
    L2VpnPeer

    L2vpn peer

    .. data:: none = 0

    	None

    .. data:: ipv4 = 1

    	IPv4

    .. data:: ipv6 = 2

    	IPv6

    .. data:: internal_label = 3

    	Internal Label

    """

    none = Enum.YLeaf(0, "none")

    ipv4 = Enum.YLeaf(1, "ipv4")

    ipv6 = Enum.YLeaf(2, "ipv6")

    internal_label = Enum.YLeaf(3, "internal-label")


class L2VpnPrefpathOption(Enum):
    """
    L2VpnPrefpathOption

    Preferred Path Option

    .. data:: l2vpn_pw_mpls_pref_path_not_specified = 0

    	Not Secified

    .. data:: l2vpn_pw_mpls_pref_path_next_hop_ip = 1

    	Next Hop IP

    .. data:: l2vpn_pw_mpls_pref_path_te_tunnel = 2

    	TE Tunnel

    .. data:: l2vpn_pw_mpls_pref_path_ip_tunnel = 3

    	IP Tunnel

    .. data:: l2vpn_pw_mpls_pref_path_tp_tunnel = 4

    	TP Tunnel

    """

    l2vpn_pw_mpls_pref_path_not_specified = Enum.YLeaf(0, "l2vpn-pw-mpls-pref-path-not-specified")

    l2vpn_pw_mpls_pref_path_next_hop_ip = Enum.YLeaf(1, "l2vpn-pw-mpls-pref-path-next-hop-ip")

    l2vpn_pw_mpls_pref_path_te_tunnel = Enum.YLeaf(2, "l2vpn-pw-mpls-pref-path-te-tunnel")

    l2vpn_pw_mpls_pref_path_ip_tunnel = Enum.YLeaf(3, "l2vpn-pw-mpls-pref-path-ip-tunnel")

    l2vpn_pw_mpls_pref_path_tp_tunnel = Enum.YLeaf(4, "l2vpn-pw-mpls-pref-path-tp-tunnel")


class L2VpnProcNsrNotReadyReason(Enum):
    """
    L2VpnProcNsrNotReadyReason

    L2vpn proc nsr not ready reason

    .. data:: collab_time_out = 0

    	Collaborator connection time out

    .. data:: collab_conntection_idt = 1

    	Collaborator connection down or IDT not done

    .. data:: nsr_peer_not_connected = 2

    	NSR peer not connected

    .. data:: nsr_peer_not_in_sync = 3

    	NSR peer not in sync

    """

    collab_time_out = Enum.YLeaf(0, "collab-time-out")

    collab_conntection_idt = Enum.YLeaf(1, "collab-conntection-idt")

    nsr_peer_not_connected = Enum.YLeaf(2, "nsr-peer-not-connected")

    nsr_peer_not_in_sync = Enum.YLeaf(3, "nsr-peer-not-in-sync")


class L2VpnProcRole(Enum):
    """
    L2VpnProcRole

    L2VPN Process Role

    .. data:: unknown = 0

    	Unknown

    .. data:: v1_active = 1

    	V1 Active

    .. data:: v1_standby = 2

    	V1 Standby

    .. data:: v2_active = 3

    	V2 Active

    .. data:: v2_standby = 4

    	V2 Standby

    .. data:: v1_active_post_big_bang = 5

    	V1 Active post big-bang

    .. data:: v1_standby_post_big_bang = 6

    	V1 Standbyi post big-bang

    .. data:: count = 7

    	Count

    """

    unknown = Enum.YLeaf(0, "unknown")

    v1_active = Enum.YLeaf(1, "v1-active")

    v1_standby = Enum.YLeaf(2, "v1-standby")

    v2_active = Enum.YLeaf(3, "v2-active")

    v2_standby = Enum.YLeaf(4, "v2-standby")

    v1_active_post_big_bang = Enum.YLeaf(5, "v1-active-post-big-bang")

    v1_standby_post_big_bang = Enum.YLeaf(6, "v1-standby-post-big-bang")

    count = Enum.YLeaf(7, "count")


class L2VpnProtection(Enum):
    """
    L2VpnProtection

    L2VPN Protection types

    .. data:: l2vpn_protection_unknown = 0

    	Unknown type of protection

    .. data:: l2vpn_protection_interface = 1

    	Interface protection type

    .. data:: l2vpn_protection_pseudowire = 2

    	PW protection type

    .. data:: l2vpn_protection_group = 3

    	Group protection type 

    """

    l2vpn_protection_unknown = Enum.YLeaf(0, "l2vpn-protection-unknown")

    l2vpn_protection_interface = Enum.YLeaf(1, "l2vpn-protection-interface")

    l2vpn_protection_pseudowire = Enum.YLeaf(2, "l2vpn-protection-pseudowire")

    l2vpn_protection_group = Enum.YLeaf(3, "l2vpn-protection-group")


class L2VpnProtectionRole(Enum):
    """
    L2VpnProtectionRole

    L2VPN Configurable protection roles

    .. data:: l2vpn_protection_primary = 0

    	Segment configured as primary

    .. data:: l2vpn_protection_backup = 1

    	Segment configured as backup

    """

    l2vpn_protection_primary = Enum.YLeaf(0, "l2vpn-protection-primary")

    l2vpn_protection_backup = Enum.YLeaf(1, "l2vpn-protection-backup")


class L2VpnPtree(Enum):
    """
    L2VpnPtree

    ptree type

    .. data:: none = 0

    	No ptree type

    .. data:: rsvp_te = 1

    	RSVP_TE ptree type

    .. data:: mldp = 2

    	MLDP ptree type

    """

    none = Enum.YLeaf(0, "none")

    rsvp_te = Enum.YLeaf(1, "rsvp-te")

    mldp = Enum.YLeaf(2, "mldp")


class L2VpnPw(Enum):
    """
    L2VpnPw

    L2vpn pw

    .. data:: l2vpn_pw_type_unknown = 0

    	Unknown

    .. data:: l2vpn_pw_type_frame_relay_dlci = 1

    	Frame Relay DLCI

    .. data:: l2vpn_pw_type_atm_aal5_sdu = 2

    	ATM AAL5 SDU VCC transport

    .. data:: l2vpn_pw_type_atm_trans_cell = 3

    	ATM transparent cell transport

    .. data:: l2vpn_pw_type_ether_vlan = 4

    	Ethernet VLAN tagged mode 

    .. data:: l2vpn_pw_type_ether = 5

    	Ethernet

    .. data:: l2vpn_pw_type_hdlc = 6

    	HDLC

    .. data:: l2vpn_pw_type_ppp = 7

    	PPP

    .. data:: l2vpn_pw_type_sonet_over_mpls = 8

    	SONET/SDH Circuit Emulation Service Over MPLS

    	(CEM)

    .. data:: l2vpn_pw_type_atm_n_vcc_cell = 9

    	ATM n-to-one VCC cell transport

    .. data:: l2vpn_pw_type_atm_n_vpc_cell = 10

    	ATM n-to-one VPC cell transport

    .. data:: l2vpn_pw_type_ip = 11

    	IP Layer2 Transport

    .. data:: l2vpn_pw_type_atm_vcc_cell = 12

    	ATM one-to-one VCC cell transport

    .. data:: l2vpn_pw_type_atm_vpc_cell = 13

    	ATM one-to-one VPC cell transport

    .. data:: l2vpn_pw_type_atm_aal5_pdu = 14

    	ATM AAL5 PDU VCC transport

    .. data:: l2vpn_pw_type_frame_relay = 15

    	Frame Relay port mode

    .. data:: l2vpn_pw_type_sonet = 16

    	SONET/SDH Circuit

    .. data:: l2vpn_pw_type_vpls = 17

    	VPLS

    .. data:: l2vpn_pw_type_tdm_sa_to_p_e1 = 18

    	TDM E1

    .. data:: l2vpn_pw_type_tdm_sa_to_p_t1 = 19

    	TDM T1

    .. data:: l2vpn_pw_type_tdm_sa_to_p_e3 = 20

    	TDM E3

    .. data:: l2vpn_pw_type_tdm_sa_to_p_t3 = 21

    	TDM T3

    .. data:: l2vpn_pw_type_tdm_ce_so_psn = 22

    	TDM CES over PSN

    """

    l2vpn_pw_type_unknown = Enum.YLeaf(0, "l2vpn-pw-type-unknown")

    l2vpn_pw_type_frame_relay_dlci = Enum.YLeaf(1, "l2vpn-pw-type-frame-relay-dlci")

    l2vpn_pw_type_atm_aal5_sdu = Enum.YLeaf(2, "l2vpn-pw-type-atm-aal5-sdu")

    l2vpn_pw_type_atm_trans_cell = Enum.YLeaf(3, "l2vpn-pw-type-atm-trans-cell")

    l2vpn_pw_type_ether_vlan = Enum.YLeaf(4, "l2vpn-pw-type-ether-vlan")

    l2vpn_pw_type_ether = Enum.YLeaf(5, "l2vpn-pw-type-ether")

    l2vpn_pw_type_hdlc = Enum.YLeaf(6, "l2vpn-pw-type-hdlc")

    l2vpn_pw_type_ppp = Enum.YLeaf(7, "l2vpn-pw-type-ppp")

    l2vpn_pw_type_sonet_over_mpls = Enum.YLeaf(8, "l2vpn-pw-type-sonet-over-mpls")

    l2vpn_pw_type_atm_n_vcc_cell = Enum.YLeaf(9, "l2vpn-pw-type-atm-n-vcc-cell")

    l2vpn_pw_type_atm_n_vpc_cell = Enum.YLeaf(10, "l2vpn-pw-type-atm-n-vpc-cell")

    l2vpn_pw_type_ip = Enum.YLeaf(11, "l2vpn-pw-type-ip")

    l2vpn_pw_type_atm_vcc_cell = Enum.YLeaf(12, "l2vpn-pw-type-atm-vcc-cell")

    l2vpn_pw_type_atm_vpc_cell = Enum.YLeaf(13, "l2vpn-pw-type-atm-vpc-cell")

    l2vpn_pw_type_atm_aal5_pdu = Enum.YLeaf(14, "l2vpn-pw-type-atm-aal5-pdu")

    l2vpn_pw_type_frame_relay = Enum.YLeaf(15, "l2vpn-pw-type-frame-relay")

    l2vpn_pw_type_sonet = Enum.YLeaf(16, "l2vpn-pw-type-sonet")

    l2vpn_pw_type_vpls = Enum.YLeaf(17, "l2vpn-pw-type-vpls")

    l2vpn_pw_type_tdm_sa_to_p_e1 = Enum.YLeaf(18, "l2vpn-pw-type-tdm-sa-to-p-e1")

    l2vpn_pw_type_tdm_sa_to_p_t1 = Enum.YLeaf(19, "l2vpn-pw-type-tdm-sa-to-p-t1")

    l2vpn_pw_type_tdm_sa_to_p_e3 = Enum.YLeaf(20, "l2vpn-pw-type-tdm-sa-to-p-e3")

    l2vpn_pw_type_tdm_sa_to_p_t3 = Enum.YLeaf(21, "l2vpn-pw-type-tdm-sa-to-p-t3")

    l2vpn_pw_type_tdm_ce_so_psn = Enum.YLeaf(22, "l2vpn-pw-type-tdm-ce-so-psn")


class L2VpnPwClassControlWord(Enum):
    """
    L2VpnPwClassControlWord

    L2vpn pw class control word

    .. data:: unset = 0

    	Unset

    .. data:: enable = 1

    	Enable

    .. data:: disable = 2

    	Disable

    """

    unset = Enum.YLeaf(0, "unset")

    enable = Enum.YLeaf(1, "enable")

    disable = Enum.YLeaf(2, "disable")


class L2VpnPwControlWord(Enum):
    """
    L2VpnPwControlWord

    L2vpn pw control word

    .. data:: l2vpn_pw_control_word_unknown = 0

    	Unknown

    .. data:: l2vpn_pw_control_word_clear = 1

    	Clear

    .. data:: l2vpn_pw_control_word_set = 2

    	Set

    .. data:: l2vpn_pw_control_word_mandatory = 3

    	Mandatory

    """

    l2vpn_pw_control_word_unknown = Enum.YLeaf(0, "l2vpn-pw-control-word-unknown")

    l2vpn_pw_control_word_clear = Enum.YLeaf(1, "l2vpn-pw-control-word-clear")

    l2vpn_pw_control_word_set = Enum.YLeaf(2, "l2vpn-pw-control-word-set")

    l2vpn_pw_control_word_mandatory = Enum.YLeaf(3, "l2vpn-pw-control-word-mandatory")


class L2VpnPwFec(Enum):
    """
    L2VpnPwFec

    L2vpn pw fec

    .. data:: l2vpn_pw_fec_128 = 0

    	FEC 128 pseudowire type

    .. data:: l2vpn_pw_fec_129 = 1

    	FEC 129 pseudowire type

    .. data:: l2vpn_pw_fec_not_applicable = 268435455

    	FEC Not Applicable

    """

    l2vpn_pw_fec_128 = Enum.YLeaf(0, "l2vpn-pw-fec-128")

    l2vpn_pw_fec_129 = Enum.YLeaf(1, "l2vpn-pw-fec-129")

    l2vpn_pw_fec_not_applicable = Enum.YLeaf(268435455, "l2vpn-pw-fec-not-applicable")


class L2VpnPwFlowLabel(Enum):
    """
    L2VpnPwFlowLabel

    Pseudowire flow label load balance types

    .. data:: off = 0

    	Flow label is off

    .. data:: receive = 1

    	Flow label is enabled on the receive side

    .. data:: transmit = 2

    	Flow label is enabled on the transmit side

    .. data:: both = 3

    	Flow label is enabled on both transmit and

    	receive sides

    """

    off = Enum.YLeaf(0, "off")

    receive = Enum.YLeaf(1, "receive")

    transmit = Enum.YLeaf(2, "transmit")

    both = Enum.YLeaf(3, "both")


class L2VpnPwSequence(Enum):
    """
    L2VpnPwSequence

    L2vpn pw sequence

    .. data:: l2vpn_pw_sequence_off = 0

    	Sequencing is Off

    .. data:: l2vpn_pw_sequence_xmit = 1

    	Sequencing on the transmit side

    .. data:: l2vpn_pw_sequence_recv = 2

    	Sequencing on the receive side

    .. data:: l2vpn_pw_sequence_trans = 3

    	Sequencing is transparent

    .. data:: l2vpn_pw_sequence_both = 4

    	Sequencing on both sides

    """

    l2vpn_pw_sequence_off = Enum.YLeaf(0, "l2vpn-pw-sequence-off")

    l2vpn_pw_sequence_xmit = Enum.YLeaf(1, "l2vpn-pw-sequence-xmit")

    l2vpn_pw_sequence_recv = Enum.YLeaf(2, "l2vpn-pw-sequence-recv")

    l2vpn_pw_sequence_trans = Enum.YLeaf(3, "l2vpn-pw-sequence-trans")

    l2vpn_pw_sequence_both = Enum.YLeaf(4, "l2vpn-pw-sequence-both")


class L2VpnPwState(Enum):
    """
    L2VpnPwState

    L2vpn pw state

    .. data:: l2vpn_pw_state_unresolved = 0

    	Unresolved

    .. data:: l2vpn_pw_state_idle = 1

    	Idle

    .. data:: l2vpn_pw_state_provisioned = 2

    	Provisioned

    .. data:: l2vpn_pw_state_remote_standby = 3

    	Remote standby

    .. data:: l2vpn_pw_state_local_ready = 4

    	Local ready

    .. data:: l2vpn_pw_state_all_ready = 5

    	All ready

    .. data:: l2vpn_pw_state_established = 6

    	Established

    """

    l2vpn_pw_state_unresolved = Enum.YLeaf(0, "l2vpn-pw-state-unresolved")

    l2vpn_pw_state_idle = Enum.YLeaf(1, "l2vpn-pw-state-idle")

    l2vpn_pw_state_provisioned = Enum.YLeaf(2, "l2vpn-pw-state-provisioned")

    l2vpn_pw_state_remote_standby = Enum.YLeaf(3, "l2vpn-pw-state-remote-standby")

    l2vpn_pw_state_local_ready = Enum.YLeaf(4, "l2vpn-pw-state-local-ready")

    l2vpn_pw_state_all_ready = Enum.YLeaf(5, "l2vpn-pw-state-all-ready")

    l2vpn_pw_state_established = Enum.YLeaf(6, "l2vpn-pw-state-established")


class L2VpnPwheIflistRepStatus(Enum):
    """
    L2VpnPwheIflistRepStatus

    Interface list replication status

    .. data:: invalid = 0

    	Invalid

    .. data:: pending = 1

    	Pending

    .. data:: success = 2

    	Success

    .. data:: failed = 3

    	Failed

    .. data:: not_supported = 4

    	Not supported

    """

    invalid = Enum.YLeaf(0, "invalid")

    pending = Enum.YLeaf(1, "pending")

    success = Enum.YLeaf(2, "success")

    failed = Enum.YLeaf(3, "failed")

    not_supported = Enum.YLeaf(4, "not-supported")


class L2VpnPwheIntf(Enum):
    """
    L2VpnPwheIntf

    Interface type

    .. data:: pseudowire_ether = 0

    	PW Ether

    .. data:: pseudowire_iw = 1

    	PW IW

    """

    pseudowire_ether = Enum.YLeaf(0, "pseudowire-ether")

    pseudowire_iw = Enum.YLeaf(1, "pseudowire-iw")


class L2VpnRgState(Enum):
    """
    L2VpnRgState

    L2vpn rg state

    .. data:: unknown = 0

    	Not defined

    .. data:: active = 1

    	Active

    .. data:: standby = 2

    	Standby

    """

    unknown = Enum.YLeaf(0, "unknown")

    active = Enum.YLeaf(1, "active")

    standby = Enum.YLeaf(2, "standby")


class L2VpnSegment(Enum):
    """
    L2VpnSegment

    L2vpn segment

    .. data:: l2vpn_segment_type_unresolved = 0

    	Unresolved segment

    .. data:: l2vpn_segment_type_ac = 1

    	Attachment circuit segment

    .. data:: l2vpn_segment_type_pw = 2

    	Pseudowire segment

    .. data:: l2vpn_segment_type_bd_ac = 3

    	Bridge domain attachment circuit

    .. data:: l2vpn_segment_type_vfi = 4

    	Virtual forwarding instance segment

    .. data:: l2vpn_segment_type_bd_pw = 5

    	Bridge Pseudowire

    .. data:: l2vpn_segment_type_bd_pbb = 6

    	Bridge domain PBB segment

    .. data:: l2vpn_segment_type_bd_evpn = 7

    	Bridge domain EVPN segment

    .. data:: l2vpn_segment_type_vni = 8

    	VxLAN Network Identifier (VNI) segment

    """

    l2vpn_segment_type_unresolved = Enum.YLeaf(0, "l2vpn-segment-type-unresolved")

    l2vpn_segment_type_ac = Enum.YLeaf(1, "l2vpn-segment-type-ac")

    l2vpn_segment_type_pw = Enum.YLeaf(2, "l2vpn-segment-type-pw")

    l2vpn_segment_type_bd_ac = Enum.YLeaf(3, "l2vpn-segment-type-bd-ac")

    l2vpn_segment_type_vfi = Enum.YLeaf(4, "l2vpn-segment-type-vfi")

    l2vpn_segment_type_bd_pw = Enum.YLeaf(5, "l2vpn-segment-type-bd-pw")

    l2vpn_segment_type_bd_pbb = Enum.YLeaf(6, "l2vpn-segment-type-bd-pbb")

    l2vpn_segment_type_bd_evpn = Enum.YLeaf(7, "l2vpn-segment-type-bd-evpn")

    l2vpn_segment_type_vni = Enum.YLeaf(8, "l2vpn-segment-type-vni")


class L2VpnSegmentState(Enum):
    """
    L2VpnSegmentState

    L2vpn segment state

    .. data:: l2vpn_segment_state_unresolved = 0

    	Unresolved

    .. data:: l2vpn_segment_state_up = 1

    	Up

    .. data:: l2vpn_segment_state_down = 2

    	Down

    .. data:: l2vpn_segment_state_admin_down = 3

    	Admin down

    .. data:: l2vpn_segment_state_local_up = 4

    	Local up

    .. data:: l2vpn_segment_state_remote_up = 5

    	Remote up

    .. data:: l2vpn_segment_state_connected = 6

    	Connected

    .. data:: l2vpn_segment_state_standby = 7

    	Standby

    .. data:: l2vpn_segment_state_standby_ready = 8

    	Standby Ready

    """

    l2vpn_segment_state_unresolved = Enum.YLeaf(0, "l2vpn-segment-state-unresolved")

    l2vpn_segment_state_up = Enum.YLeaf(1, "l2vpn-segment-state-up")

    l2vpn_segment_state_down = Enum.YLeaf(2, "l2vpn-segment-state-down")

    l2vpn_segment_state_admin_down = Enum.YLeaf(3, "l2vpn-segment-state-admin-down")

    l2vpn_segment_state_local_up = Enum.YLeaf(4, "l2vpn-segment-state-local-up")

    l2vpn_segment_state_remote_up = Enum.YLeaf(5, "l2vpn-segment-state-remote-up")

    l2vpn_segment_state_connected = Enum.YLeaf(6, "l2vpn-segment-state-connected")

    l2vpn_segment_state_standby = Enum.YLeaf(7, "l2vpn-segment-state-standby")

    l2vpn_segment_state_standby_ready = Enum.YLeaf(8, "l2vpn-segment-state-standby-ready")


class L2VpnService(Enum):
    """
    L2VpnService

    L2vpn service

    .. data:: vpws = 0

    	VPWS service

    .. data:: vpls = 1

    	VPLS service

    """

    vpws = Enum.YLeaf(0, "vpws")

    vpls = Enum.YLeaf(1, "vpls")


class L2VpnSignallingProto(Enum):
    """
    L2VpnSignallingProto

    L2vpn signalling proto

    .. data:: l2vpn_pw_sig_not_specified = 0

    	Not specified

    .. data:: l2vpn_pw_sig_none = 1

    	Static

    .. data:: l2vpn_pw_sig_l2tpv3 = 2

    	L2TPv3 signaling

    .. data:: l2vpn_pw_sig_l2tpv2 = 3

    	L2TPv2 signaling

    .. data:: l2vpn_pw_sig_ldp = 4

    	LDP

    .. data:: l2vpn_pw_sig_bgp = 5

    	BGP

    """

    l2vpn_pw_sig_not_specified = Enum.YLeaf(0, "l2vpn-pw-sig-not-specified")

    l2vpn_pw_sig_none = Enum.YLeaf(1, "l2vpn-pw-sig-none")

    l2vpn_pw_sig_l2tpv3 = Enum.YLeaf(2, "l2vpn-pw-sig-l2tpv3")

    l2vpn_pw_sig_l2tpv2 = Enum.YLeaf(3, "l2vpn-pw-sig-l2tpv2")

    l2vpn_pw_sig_ldp = Enum.YLeaf(4, "l2vpn-pw-sig-ldp")

    l2vpn_pw_sig_bgp = Enum.YLeaf(5, "l2vpn-pw-sig-bgp")


class L2VpnSrcAddressSet(Enum):
    """
    L2VpnSrcAddressSet

    L2vpn src address set

    .. data:: unset = 0

    	Unset

    .. data:: set = 1

    	Set

    """

    unset = Enum.YLeaf(0, "unset")

    set = Enum.YLeaf(1, "set")


class L2VpnSyncStatus(Enum):
    """
    L2VpnSyncStatus

    L2vpn sync status

    .. data:: not_ready = 0

    	Not Ready

    .. data:: ready = 1

    	Ready

    """

    not_ready = Enum.YLeaf(0, "not-ready")

    ready = Enum.YLeaf(1, "ready")


class L2VpnTdmMode(Enum):
    """
    L2VpnTdmMode

    L2VPN TDM modes

    .. data:: unknown = 0

    	Unknown mode

    .. data:: ce_so_psn = 1

    	CESoPSN mode

    .. data:: sa_to_p_e1 = 2

    	SAToP E1 mode

    .. data:: sa_to_p_t1 = 3

    	SAToP T1 mode

    .. data:: sa_to_p_e3 = 4

    	SAToP E3 mode

    .. data:: sa_to_p_t3 = 5

    	SAToP T3 mode

    """

    unknown = Enum.YLeaf(0, "unknown")

    ce_so_psn = Enum.YLeaf(1, "ce-so-psn")

    sa_to_p_e1 = Enum.YLeaf(2, "sa-to-p-e1")

    sa_to_p_t1 = Enum.YLeaf(3, "sa-to-p-t1")

    sa_to_p_e3 = Enum.YLeaf(4, "sa-to-p-e3")

    sa_to_p_t3 = Enum.YLeaf(5, "sa-to-p-t3")


class L2VpnTdmRtpOption(Enum):
    """
    L2VpnTdmRtpOption

    L2VPN TDM RTP option

    .. data:: unknown = 0

    	Unknown RTP option

    .. data:: present = 1

    	RTP option present

    .. data:: absent = 2

    	RTP option absent

    """

    unknown = Enum.YLeaf(0, "unknown")

    present = Enum.YLeaf(1, "present")

    absent = Enum.YLeaf(2, "absent")


class L2VpnTimeStampMode(Enum):
    """
    L2VpnTimeStampMode

    L2VPN TDM Time stamp modes

    .. data:: unknown = 0

    	Unknown time stamp mode

    .. data:: differential = 1

    	Differential time stamp mode

    .. data:: absolute = 2

    	Absolute Time Stamp mode

    .. data:: none = 3

    	time stamp mode none

    """

    unknown = Enum.YLeaf(0, "unknown")

    differential = Enum.YLeaf(1, "differential")

    absolute = Enum.YLeaf(2, "absolute")

    none = Enum.YLeaf(3, "none")


class L2VpnTosMode(Enum):
    """
    L2VpnTosMode

    L2vpn tos mode

    .. data:: l2vpn_pw_ip_tos_none = 0

    	None

    .. data:: l2vpn_pw_ip_tos_reflect = 1

    	Reflect the TOS

    """

    l2vpn_pw_ip_tos_none = Enum.YLeaf(0, "l2vpn-pw-ip-tos-none")

    l2vpn_pw_ip_tos_reflect = Enum.YLeaf(1, "l2vpn-pw-ip-tos-reflect")


class L2VpnTransportMode(Enum):
    """
    L2VpnTransportMode

    L2vpn transport mode

    .. data:: l2vpn_transport_mode_not_specified = 0

    	Not specified

    .. data:: l2vpn_transport_mode_ethernet = 1

    	Ethernet

    .. data:: l2vpn_transport_mode_vlan = 2

    	VLAN

    .. data:: l2vpn_transport_mode_vlan_passthrough = 3

    	VLAN Passthrough

    """

    l2vpn_transport_mode_not_specified = Enum.YLeaf(0, "l2vpn-transport-mode-not-specified")

    l2vpn_transport_mode_ethernet = Enum.YLeaf(1, "l2vpn-transport-mode-ethernet")

    l2vpn_transport_mode_vlan = Enum.YLeaf(2, "l2vpn-transport-mode-vlan")

    l2vpn_transport_mode_vlan_passthrough = Enum.YLeaf(3, "l2vpn-transport-mode-vlan-passthrough")


class L2VpnVfiP2MpSignaling(Enum):
    """
    L2VpnVfiP2MpSignaling

    L2vpn vfi p2mp signaling

    .. data:: none = 0

    	undefined signaling

    .. data:: bgp = 1

    	BGP signaling

    """

    none = Enum.YLeaf(0, "none")

    bgp = Enum.YLeaf(1, "bgp")


class L2VpnVfiP2MpTransport(Enum):
    """
    L2VpnVfiP2MpTransport

    L2vpn vfi p2mp transport

    .. data:: none = 0

    	undefined transport

    .. data:: rsvp_te = 1

    	RSVP-TE transport

    """

    none = Enum.YLeaf(0, "none")

    rsvp_te = Enum.YLeaf(1, "rsvp-te")


class L2VpnVfiState(Enum):
    """
    L2VpnVfiState

    L2vpn vfi state

    .. data:: unknown = 0

    	VFI Unknown

    .. data:: up = 1

    	VFI Up

    .. data:: down = 2

    	VFI Down

    .. data:: admin_down = 3

    	VFI Admin Down

    """

    unknown = Enum.YLeaf(0, "unknown")

    up = Enum.YLeaf(1, "up")

    down = Enum.YLeaf(2, "down")

    admin_down = Enum.YLeaf(3, "admin-down")


class L2VpnVirtualportState(Enum):
    """
    L2VpnVirtualportState

    L2vpn virtualport state

    .. data:: l2vpn_vp_state_undefined = 0

    	Undefined

    .. data:: l2vpn_vp_state_up = 1

    	Up

    .. data:: l2vpn_vp_state_down = 2

    	Down

    """

    l2vpn_vp_state_undefined = Enum.YLeaf(0, "l2vpn-vp-state-undefined")

    l2vpn_vp_state_up = Enum.YLeaf(1, "l2vpn-vp-state-up")

    l2vpn_vp_state_down = Enum.YLeaf(2, "l2vpn-vp-state-down")


class L2VpnVniEncaps(Enum):
    """
    L2VpnVniEncaps

    L2vpn vni encaps

    .. data:: l2vpn_vni_encap_vxlan = 0

    	VXLAN

    .. data:: l2vpn_vni_encap_softgre = 1

    	SOFTGRE

    """

    l2vpn_vni_encap_vxlan = Enum.YLeaf(0, "l2vpn-vni-encap-vxlan")

    l2vpn_vni_encap_softgre = Enum.YLeaf(1, "l2vpn-vni-encap-softgre")


class L2VpnVniMode(Enum):
    """
    L2VpnVniMode

    L2vpn vni mode

    .. data:: l2vpn_vni_mode_l2_dp = 0

    	Data Plane L2 Service

    .. data:: l2vpn_vni_mode_l3_dp = 1

    	Data Plane L3 Service

    .. data:: l2vpn_vni_mode_l2_cp = 2

    	Control Plane L2 Service

    .. data:: l2vpn_vni_mode_l3_cp = 3

    	Control Plane L3 Service

    """

    l2vpn_vni_mode_l2_dp = Enum.YLeaf(0, "l2vpn-vni-mode-l2-dp")

    l2vpn_vni_mode_l3_dp = Enum.YLeaf(1, "l2vpn-vni-mode-l3-dp")

    l2vpn_vni_mode_l2_cp = Enum.YLeaf(2, "l2vpn-vni-mode-l2-cp")

    l2vpn_vni_mode_l3_cp = Enum.YLeaf(3, "l2vpn-vni-mode-l3-cp")


class L2VpnXcState(Enum):
    """
    L2VpnXcState

    L2vpn xc state

    .. data:: l2vpn_xc_state_unresolved = 0

    	Unresolved

    .. data:: l2vpn_xc_state_down = 1

    	Down

    .. data:: l2vpn_xc_state_up = 2

    	Up

    """

    l2vpn_xc_state_unresolved = Enum.YLeaf(0, "l2vpn-xc-state-unresolved")

    l2vpn_xc_state_down = Enum.YLeaf(1, "l2vpn-xc-state-down")

    l2vpn_xc_state_up = Enum.YLeaf(2, "l2vpn-xc-state-up")


class L2Vpnp2MpPtree(Enum):
    """
    L2Vpnp2MpPtree

    L2vpnp2mp ptree

    .. data:: rsvp_te = 1

    	RSVPTE Type

    .. data:: mldp = 2

    	MLDP Type

    """

    rsvp_te = Enum.YLeaf(1, "rsvp-te")

    mldp = Enum.YLeaf(2, "mldp")


class L2Vpnpw(Enum):
    """
    L2Vpnpw

    L2vpnpw

    .. data:: manual = 1

    	Manual pseudowire

    .. data:: vpls_autodiscovered = 2

    	VPLS autodiscovered pseudowire

    .. data:: vpws_autodiscovered = 3

    	VPWS autodiscovered pseudowire

    .. data:: vpls_autodiscovered_ldp = 4

    	VPLS autodiscovered pseudowire with LDP

    	signaling

    """

    manual = Enum.YLeaf(1, "manual")

    vpls_autodiscovered = Enum.YLeaf(2, "vpls-autodiscovered")

    vpws_autodiscovered = Enum.YLeaf(3, "vpws-autodiscovered")

    vpls_autodiscovered_ldp = Enum.YLeaf(4, "vpls-autodiscovered-ldp")


class MgmtL2FibBridge(Enum):
    """
    MgmtL2FibBridge

    Mgmt l2fib bridge

    .. data:: mgmt_l2fib_bridge_type_default = 0

    	mgmt l2fib bridge type default

    .. data:: mgmt_l2fib_bridge_type_pbb_edge = 1

    	mgmt l2fib bridge type pbb edge

    .. data:: mgmt_l2fib_bridge_type_pbb_core = 2

    	mgmt l2fib bridge type pbb core

    """

    mgmt_l2fib_bridge_type_default = Enum.YLeaf(0, "mgmt-l2fib-bridge-type-default")

    mgmt_l2fib_bridge_type_pbb_edge = Enum.YLeaf(1, "mgmt-l2fib-bridge-type-pbb-edge")

    mgmt_l2fib_bridge_type_pbb_core = Enum.YLeaf(2, "mgmt-l2fib-bridge-type-pbb-core")


class MgmtL2FibBridgeMacEvpnCtx(Enum):
    """
    MgmtL2FibBridgeMacEvpnCtx

    Mgmt l2fib bridge mac evpn ctx

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_none = 0

    	mgmt l2fib bridge mac evpn ctx none

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_esi_id = 1

    	mgmt l2fib bridge mac evpn ctx esi id

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_local_label = 2

    	mgmt l2fib bridge mac evpn ctx local label

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_moi = 3

    	mgmt l2fib bridge mac evpn ctx moi

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_bp_ifh = 4

    	mgmt l2fib bridge mac evpn ctx bp ifh

    """

    mgmt_l2fib_bridge_mac_evpn_ctx_none = Enum.YLeaf(0, "mgmt-l2fib-bridge-mac-evpn-ctx-none")

    mgmt_l2fib_bridge_mac_evpn_ctx_esi_id = Enum.YLeaf(1, "mgmt-l2fib-bridge-mac-evpn-ctx-esi-id")

    mgmt_l2fib_bridge_mac_evpn_ctx_local_label = Enum.YLeaf(2, "mgmt-l2fib-bridge-mac-evpn-ctx-local-label")

    mgmt_l2fib_bridge_mac_evpn_ctx_moi = Enum.YLeaf(3, "mgmt-l2fib-bridge-mac-evpn-ctx-moi")

    mgmt_l2fib_bridge_mac_evpn_ctx_bp_ifh = Enum.YLeaf(4, "mgmt-l2fib-bridge-mac-evpn-ctx-bp-ifh")


class MgmtL2FibData(Enum):
    """
    MgmtL2FibData

    Mgmt l2fib data

    .. data:: mgmt_l2fib_data_type_min = 0

    	mgmt l2fib data type min

    .. data:: mgmt_l2fib_data_type_xcon = 1

    	mgmt l2fib data type xcon

    .. data:: mgmt_l2fib_data_type_ac = 2

    	mgmt l2fib data type ac

    .. data:: mgmt_l2fib_data_type_span = 3

    	mgmt l2fib data type span

    .. data:: mgmt_l2fib_data_type_atom = 4

    	mgmt l2fib data type atom

    .. data:: mgmt_l2fib_data_type_pbb = 5

    	mgmt l2fib data type pbb

    .. data:: mgmt_l2fib_data_type_vni = 6

    	mgmt l2fib data type vni

    .. data:: mgmt_l2fib_data_type_n_hop = 7

    	mgmt l2fib data type n hop

    .. data:: mgmt_l2fib_data_type_l2tp = 8

    	mgmt l2fib data type l2tp

    .. data:: mgmt_l2fib_data_type_l2tpv2 = 9

    	mgmt l2fib data type l2tpv2

    .. data:: mgmt_l2fib_data_type_bridge = 10

    	mgmt l2fib data type bridge

    .. data:: mgmt_l2fib_data_type_bridge_shg = 11

    	mgmt l2fib data type bridge shg

    .. data:: mgmt_l2fib_data_type_bridge_port = 12

    	mgmt l2fib data type bridge port

    .. data:: mgmt_l2fib_data_type_bridge_mac = 13

    	mgmt l2fib data type bridge mac

    .. data:: mgmt_l2fib_data_type_mcast_table = 14

    	mgmt l2fib data type mcast table

    .. data:: mgmt_l2fib_data_type_mcast_leaf = 15

    	mgmt l2fib data type mcast leaf

    .. data:: mgmt_l2fib_data_type_mcast_xid = 16

    	mgmt l2fib data type mcast xid

    .. data:: mgmt_l2fib_data_type_dhcp = 17

    	mgmt l2fib data type dhcp

    .. data:: mgmt_l2fib_data_type_l2tp_ipv6_ts = 18

    	mgmt l2fib data type l2tp ipv6 ts

    .. data:: mgmt_l2fib_data_type_pwhe_mp = 19

    	mgmt l2fib data type pwhe mp

    .. data:: mgmt_l2fib_data_type_evpn = 20

    	mgmt l2fib data type evpn

    .. data:: mgmt_l2fib_data_type_fxs = 21

    	mgmt l2fib data type fxs

    .. data:: mgmt_l2fib_data_type_max = 22

    	mgmt l2fib data type max

    """

    mgmt_l2fib_data_type_min = Enum.YLeaf(0, "mgmt-l2fib-data-type-min")

    mgmt_l2fib_data_type_xcon = Enum.YLeaf(1, "mgmt-l2fib-data-type-xcon")

    mgmt_l2fib_data_type_ac = Enum.YLeaf(2, "mgmt-l2fib-data-type-ac")

    mgmt_l2fib_data_type_span = Enum.YLeaf(3, "mgmt-l2fib-data-type-span")

    mgmt_l2fib_data_type_atom = Enum.YLeaf(4, "mgmt-l2fib-data-type-atom")

    mgmt_l2fib_data_type_pbb = Enum.YLeaf(5, "mgmt-l2fib-data-type-pbb")

    mgmt_l2fib_data_type_vni = Enum.YLeaf(6, "mgmt-l2fib-data-type-vni")

    mgmt_l2fib_data_type_n_hop = Enum.YLeaf(7, "mgmt-l2fib-data-type-n-hop")

    mgmt_l2fib_data_type_l2tp = Enum.YLeaf(8, "mgmt-l2fib-data-type-l2tp")

    mgmt_l2fib_data_type_l2tpv2 = Enum.YLeaf(9, "mgmt-l2fib-data-type-l2tpv2")

    mgmt_l2fib_data_type_bridge = Enum.YLeaf(10, "mgmt-l2fib-data-type-bridge")

    mgmt_l2fib_data_type_bridge_shg = Enum.YLeaf(11, "mgmt-l2fib-data-type-bridge-shg")

    mgmt_l2fib_data_type_bridge_port = Enum.YLeaf(12, "mgmt-l2fib-data-type-bridge-port")

    mgmt_l2fib_data_type_bridge_mac = Enum.YLeaf(13, "mgmt-l2fib-data-type-bridge-mac")

    mgmt_l2fib_data_type_mcast_table = Enum.YLeaf(14, "mgmt-l2fib-data-type-mcast-table")

    mgmt_l2fib_data_type_mcast_leaf = Enum.YLeaf(15, "mgmt-l2fib-data-type-mcast-leaf")

    mgmt_l2fib_data_type_mcast_xid = Enum.YLeaf(16, "mgmt-l2fib-data-type-mcast-xid")

    mgmt_l2fib_data_type_dhcp = Enum.YLeaf(17, "mgmt-l2fib-data-type-dhcp")

    mgmt_l2fib_data_type_l2tp_ipv6_ts = Enum.YLeaf(18, "mgmt-l2fib-data-type-l2tp-ipv6-ts")

    mgmt_l2fib_data_type_pwhe_mp = Enum.YLeaf(19, "mgmt-l2fib-data-type-pwhe-mp")

    mgmt_l2fib_data_type_evpn = Enum.YLeaf(20, "mgmt-l2fib-data-type-evpn")

    mgmt_l2fib_data_type_fxs = Enum.YLeaf(21, "mgmt-l2fib-data-type-fxs")

    mgmt_l2fib_data_type_max = Enum.YLeaf(22, "mgmt-l2fib-data-type-max")


class MgmtL2FibMacLimitAction(Enum):
    """
    MgmtL2FibMacLimitAction

    Mgmt l2fib mac limit action

    .. data:: mgmt_l2fib_mac_limit_action_type_none = 0

    	mgmt l2fib mac limit action type none

    .. data:: mgmt_l2fib_mac_limit_action_type_flood = 1

    	mgmt l2fib mac limit action type flood

    .. data:: mgmt_l2fib_mac_limit_action_type_no_flood = 2

    	mgmt l2fib mac limit action type no flood

    .. data:: mgmt_l2fib_mac_limit_action_type_shutdown = 3

    	mgmt l2fib mac limit action type shutdown

    """

    mgmt_l2fib_mac_limit_action_type_none = Enum.YLeaf(0, "mgmt-l2fib-mac-limit-action-type-none")

    mgmt_l2fib_mac_limit_action_type_flood = Enum.YLeaf(1, "mgmt-l2fib-mac-limit-action-type-flood")

    mgmt_l2fib_mac_limit_action_type_no_flood = Enum.YLeaf(2, "mgmt-l2fib-mac-limit-action-type-no-flood")

    mgmt_l2fib_mac_limit_action_type_shutdown = Enum.YLeaf(3, "mgmt-l2fib-mac-limit-action-type-shutdown")


class MgmtL2FibMacLimitNotify(Enum):
    """
    MgmtL2FibMacLimitNotify

    Mgmt l2fib mac limit notify

    .. data:: mgmt_l2fib_mac_limit_notify_none = 0

    	mgmt l2fib mac limit notify none

    .. data:: mgmt_l2fib_mac_limit_notify_syslog = 1

    	mgmt l2fib mac limit notify syslog

    .. data:: mgmt_l2fib_mac_limit_notify_trap = 2

    	mgmt l2fib mac limit notify trap

    .. data:: mgmt_l2fib_mac_limit_notify_both = 3

    	mgmt l2fib mac limit notify both

    """

    mgmt_l2fib_mac_limit_notify_none = Enum.YLeaf(0, "mgmt-l2fib-mac-limit-notify-none")

    mgmt_l2fib_mac_limit_notify_syslog = Enum.YLeaf(1, "mgmt-l2fib-mac-limit-notify-syslog")

    mgmt_l2fib_mac_limit_notify_trap = Enum.YLeaf(2, "mgmt-l2fib-mac-limit-notify-trap")

    mgmt_l2fib_mac_limit_notify_both = Enum.YLeaf(3, "mgmt-l2fib-mac-limit-notify-both")


class MgmtL2FibMacSecAction(Enum):
    """
    MgmtL2FibMacSecAction

    Mgmt l2fib mac sec action

    .. data:: not_set = 0

    	MAC Secure Action Not Set

    .. data:: restrict = 1

    	MAC Secure Action Restrict

    .. data:: none = 2

    	MAC Secure Action None

    .. data:: shutdown = 3

    	MAC Secure Action Shutdown

    """

    not_set = Enum.YLeaf(0, "not-set")

    restrict = Enum.YLeaf(1, "restrict")

    none = Enum.YLeaf(2, "none")

    shutdown = Enum.YLeaf(3, "shutdown")


class MgmtL2FibStatsData(Enum):
    """
    MgmtL2FibStatsData

    Mgmt l2fib stats data

    .. data:: mgmt_l2fib_stats_type_unknown = 0

    	mgmt l2fib stats type unknown

    .. data:: mgmt_l2fib_stats_type_mcast = 1

    	mgmt l2fib stats type mcast

    """

    mgmt_l2fib_stats_type_unknown = Enum.YLeaf(0, "mgmt-l2fib-stats-type-unknown")

    mgmt_l2fib_stats_type_mcast = Enum.YLeaf(1, "mgmt-l2fib-stats-type-mcast")


class MgmtL2FibSwitching(Enum):
    """
    MgmtL2FibSwitching

    Mgmt l2fib switching

    .. data:: mgmt_l2fib_switching_type_unknown = 0

    	mgmt l2fib switching type unknown

    .. data:: mgmt_l2fib_switching_type_ac_ac = 1

    	mgmt l2fib switching type ac ac

    .. data:: mgmt_l2fib_switching_type_ac_atom = 2

    	mgmt l2fib switching type ac atom

    .. data:: mgmt_l2fib_switching_type_ac_vfi = 3

    	mgmt l2fib switching type ac vfi

    .. data:: mgmt_l2fib_switching_type_ac_l2tp = 4

    	mgmt l2fib switching type ac l2tp

    .. data:: mgmt_l2fib_switching_type_atom_atom = 5

    	mgmt l2fib switching type atom atom

    .. data:: mgmt_l2fib_switching_type_vfi_atom = 6

    	mgmt l2fib switching type vfi atom

    .. data:: mgmt_l2fib_switching_type_vfi_l2tp = 7

    	mgmt l2fib switching type vfi l2tp

    .. data:: mgmt_l2fib_switching_type_l2tp_atom = 8

    	mgmt l2fib switching type l2tp atom

    .. data:: mgmt_l2fib_switching_type_l2tp_l2tp = 9

    	mgmt l2fib switching type l2tp l2tp

    .. data:: mgmt_l2fib_switching_type_max = 10

    	mgmt l2fib switching type max

    """

    mgmt_l2fib_switching_type_unknown = Enum.YLeaf(0, "mgmt-l2fib-switching-type-unknown")

    mgmt_l2fib_switching_type_ac_ac = Enum.YLeaf(1, "mgmt-l2fib-switching-type-ac-ac")

    mgmt_l2fib_switching_type_ac_atom = Enum.YLeaf(2, "mgmt-l2fib-switching-type-ac-atom")

    mgmt_l2fib_switching_type_ac_vfi = Enum.YLeaf(3, "mgmt-l2fib-switching-type-ac-vfi")

    mgmt_l2fib_switching_type_ac_l2tp = Enum.YLeaf(4, "mgmt-l2fib-switching-type-ac-l2tp")

    mgmt_l2fib_switching_type_atom_atom = Enum.YLeaf(5, "mgmt-l2fib-switching-type-atom-atom")

    mgmt_l2fib_switching_type_vfi_atom = Enum.YLeaf(6, "mgmt-l2fib-switching-type-vfi-atom")

    mgmt_l2fib_switching_type_vfi_l2tp = Enum.YLeaf(7, "mgmt-l2fib-switching-type-vfi-l2tp")

    mgmt_l2fib_switching_type_l2tp_atom = Enum.YLeaf(8, "mgmt-l2fib-switching-type-l2tp-atom")

    mgmt_l2fib_switching_type_l2tp_l2tp = Enum.YLeaf(9, "mgmt-l2fib-switching-type-l2tp-l2tp")

    mgmt_l2fib_switching_type_max = Enum.YLeaf(10, "mgmt-l2fib-switching-type-max")


class P2MpTransportState(Enum):
    """
    P2MpTransportState

    P2mp transport state

    .. data:: none = 0

    	no information about the transport yet

    .. data:: ok = 1

    	transport up

    .. data:: error = 2

    	transport error

    .. data:: tunnel_down = 3

    	tunnel is down

    .. data:: max_tunnels_reached = 4

    	transport down because the maximum number of

    	tunnels is reached

    """

    none = Enum.YLeaf(0, "none")

    ok = Enum.YLeaf(1, "ok")

    error = Enum.YLeaf(2, "error")

    tunnel_down = Enum.YLeaf(3, "tunnel-down")

    max_tunnels_reached = Enum.YLeaf(4, "max-tunnels-reached")


class PwhePortImState(Enum):
    """
    PwhePortImState

    Pseudowire headend port states

    .. data:: unknown = 0

    	Unknown

    .. data:: down = 1

    	Down

    .. data:: up = 2

    	Up

    """

    unknown = Enum.YLeaf(0, "unknown")

    down = Enum.YLeaf(1, "down")

    up = Enum.YLeaf(2, "up")



class L2VpnForwarding(Entity):
    """
    Show L2VPN forwarding
    
    .. attribute:: nodes
    
    	Per node L2VPN forwarding Operational data
    	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(L2VpnForwarding, self).__init__()
        self._top_entity = None

        self.yang_name = "l2vpn-forwarding"
        self.yang_parent_name = "Cisco-IOS-XR-l2vpn-oper"

        self.nodes = L2VpnForwarding.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._children_yang_names.add("nodes")


    class Nodes(Entity):
        """
        Per node L2VPN forwarding Operational data
        
        .. attribute:: node
        
        	The L2VPN forwarding Operational data for a particular node
        	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2VpnForwarding.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "l2vpn-forwarding"

            self.node = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2VpnForwarding.Nodes, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2VpnForwarding.Nodes, self).__setattr__(name, value)


        class Node(Entity):
            """
            The L2VPN forwarding Operational data for a
            particular node
            
            .. attribute:: node_id  <key>
            
            	The identifier for the node
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: l2fib_bridge_domain_names
            
            	Bridge Domain forwarding detail
            	**type**\:   :py:class:`L2FibBridgeDomainNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames>`
            
            .. attribute:: l2fib_bridge_domains
            
            	Bridge Domain forwarding detail
            	**type**\:   :py:class:`L2FibBridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains>`
            
            .. attribute:: l2fib_bridge_ports
            
            	Bridge Port forwarding detail
            	**type**\:   :py:class:`L2FibBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts>`
            
            .. attribute:: l2fib_dhcp_binding_count
            
            	DHCP binding forwarding total count
            	**type**\:   :py:class:`L2FibDhcpBindingCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingCount>`
            
            .. attribute:: l2fib_dhcp_binding_details
            
            	DHCP binding forwarding detail
            	**type**\:   :py:class:`L2FibDhcpBindingDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails>`
            
            .. attribute:: l2fib_dhcp_binding_summaries
            
            	DHCP binding forwarding summary
            	**type**\:   :py:class:`L2FibDhcpBindingSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries>`
            
            .. attribute:: l2fib_evpn_incl_m_cast_hardware_egresses
            
            	L2VPN forwarding bridge\-domain evpn inclusive multicast hardware egress Table
            	**type**\:   :py:class:`L2FibEvpnInclMCastHardwareEgresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses>`
            
            .. attribute:: l2fib_evpn_incl_m_cast_hardware_ingresses
            
            	L2VPN forwarding bridge\-domain evpn inclusive multicast hardware ingress Table
            	**type**\:   :py:class:`L2FibEvpnInclMCastHardwareIngresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses>`
            
            .. attribute:: l2fib_evpn_incl_m_casts
            
            	L2VPN forwarding bridge\-domain evpn inclusive multicast Table
            	**type**\:   :py:class:`L2FibEvpnInclMCasts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts>`
            
            .. attribute:: l2fib_evpn_ip4macs
            
            	EVPN IPv4\-MAC Table
            	**type**\:   :py:class:`L2FibEvpnIp4Macs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs>`
            
            .. attribute:: l2fib_evpn_ip6macs
            
            	EVPN IPv6\-MAC Table
            	**type**\:   :py:class:`L2FibEvpnIp6Macs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs>`
            
            .. attribute:: l2fib_g8032
            
            	G8032 information
            	**type**\:   :py:class:`L2FibG8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032>`
            
            .. attribute:: l2fib_l2tp
            
            	L2TP
            	**type**\:   :py:class:`L2FibL2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp>`
            
            .. attribute:: l2fib_mac_learning
            
            	The L2VPN forwarding Mac Learning Data
            	**type**\:   :py:class:`L2FibMacLearning <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning>`
            
            .. attribute:: l2fib_main_interfaces
            
            	Main Interface
            	**type**\:   :py:class:`L2FibMainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces>`
            
            .. attribute:: l2fib_message_summary
            
            	L2FIB Message Summary information
            	**type**\:   :py:class:`L2FibMessageSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary>`
            
            .. attribute:: l2fib_mmrp_summaries
            
            	Mmrp Summary Table
            	**type**\:   :py:class:`L2FibMmrpSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries>`
            
            .. attribute:: l2fib_mmrps
            
            	mmmrp information
            	**type**\:   :py:class:`L2FibMmrps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps>`
            
            .. attribute:: l2fib_mon_sess_x_cons
            
            	The L2VPN forwarding Monitor Session XConnect Information
            	**type**\:   :py:class:`L2FibMonSessXCons <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons>`
            
            .. attribute:: l2fib_mroute_ipv6s
            
            	multicast information
            	**type**\:   :py:class:`L2FibMrouteIpv6S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S>`
            
            .. attribute:: l2fib_mroute_ports
            
            	multicast bridge port information 
            	**type**\:   :py:class:`L2FibMroutePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts>`
            
            .. attribute:: l2fib_mroute_summaries
            
            	Mroute Summary Table
            	**type**\:   :py:class:`L2FibMrouteSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries>`
            
            .. attribute:: l2fib_mroutes
            
            	multicast information
            	**type**\:   :py:class:`L2FibMroutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes>`
            
            .. attribute:: l2fib_mstp_details
            
            	MSTP Detail Table
            	**type**\:   :py:class:`L2FibMstpDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpDetails>`
            
            .. attribute:: l2fib_mstp_summaries
            
            	MSTP Summary Table
            	**type**\:   :py:class:`L2FibMstpSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpSummaries>`
            
            .. attribute:: l2fib_nve_peers
            
            	NVE Peer Table
            	**type**\:   :py:class:`L2FibNvePeers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibNvePeers>`
            
            .. attribute:: l2fib_p2mp
            
            	p2mp information
            	**type**\:   :py:class:`L2FibP2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibP2Mp>`
            
            .. attribute:: l2fib_pw_groups
            
            	PW Group Table Information
            	**type**\:   :py:class:`L2FibPwGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibPwGroups>`
            
            .. attribute:: l2fib_pwhe_main_ports
            
            	PWHE Main\-port table
            	**type**\:   :py:class:`L2FibPwheMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts>`
            
            .. attribute:: l2fib_resource_availability
            
            	Resource availability information
            	**type**\:   :py:class:`L2FibResourceAvailability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibResourceAvailability>`
            
            .. attribute:: l2fib_summary
            
            	L2FIB Summary information
            	**type**\:   :py:class:`L2FibSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary>`
            
            .. attribute:: l2fibmac_details
            
            	Bridge MAC detail information
            	**type**\:   :py:class:`L2FibmacDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails>`
            
            .. attribute:: l2fibmac_hardware_egresses
            
            	Bridge Hardware Egress information
            	**type**\:   :py:class:`L2FibmacHardwareEgresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses>`
            
            .. attribute:: l2fibmac_hardware_ingresses
            
            	Bridge Hardware Ingress information
            	**type**\:   :py:class:`L2FibmacHardwareIngresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses>`
            
            .. attribute:: l2fibx_con_l2tpv2s
            
            	The L2VPN forwarding XConnect L2TPv2 Detail Table
            	**type**\:   :py:class:`L2FibxConL2Tpv2S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S>`
            
            .. attribute:: l2fibx_con_locals
            
            	The L2VPN forwarding Local LC XConnect Detail Table
            	**type**\:   :py:class:`L2FibxConLocals <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals>`
            
            .. attribute:: l2fibx_cons
            
            	The L2VPN forwarding XConnect Detail Table
            	**type**\:   :py:class:`L2FibxCons <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons>`
            
            .. attribute:: pbb_bmac_sa
            
            	PBB Backbone Source MAC information
            	**type**\:   :py:class:`PbbBmacSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.PbbBmacSa>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2VpnForwarding.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"

                self.node_id = YLeaf(YType.str, "node-id")

                self.l2fib_bridge_domain_names = L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames()
                self.l2fib_bridge_domain_names.parent = self
                self._children_name_map["l2fib_bridge_domain_names"] = "l2fib-bridge-domain-names"
                self._children_yang_names.add("l2fib-bridge-domain-names")

                self.l2fib_bridge_domains = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains()
                self.l2fib_bridge_domains.parent = self
                self._children_name_map["l2fib_bridge_domains"] = "l2fib-bridge-domains"
                self._children_yang_names.add("l2fib-bridge-domains")

                self.l2fib_bridge_ports = L2VpnForwarding.Nodes.Node.L2FibBridgePorts()
                self.l2fib_bridge_ports.parent = self
                self._children_name_map["l2fib_bridge_ports"] = "l2fib-bridge-ports"
                self._children_yang_names.add("l2fib-bridge-ports")

                self.l2fib_dhcp_binding_count = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingCount()
                self.l2fib_dhcp_binding_count.parent = self
                self._children_name_map["l2fib_dhcp_binding_count"] = "l2fib-dhcp-binding-count"
                self._children_yang_names.add("l2fib-dhcp-binding-count")

                self.l2fib_dhcp_binding_details = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails()
                self.l2fib_dhcp_binding_details.parent = self
                self._children_name_map["l2fib_dhcp_binding_details"] = "l2fib-dhcp-binding-details"
                self._children_yang_names.add("l2fib-dhcp-binding-details")

                self.l2fib_dhcp_binding_summaries = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries()
                self.l2fib_dhcp_binding_summaries.parent = self
                self._children_name_map["l2fib_dhcp_binding_summaries"] = "l2fib-dhcp-binding-summaries"
                self._children_yang_names.add("l2fib-dhcp-binding-summaries")

                self.l2fib_evpn_incl_m_cast_hardware_egresses = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses()
                self.l2fib_evpn_incl_m_cast_hardware_egresses.parent = self
                self._children_name_map["l2fib_evpn_incl_m_cast_hardware_egresses"] = "l2fib-evpn-incl-m-cast-hardware-egresses"
                self._children_yang_names.add("l2fib-evpn-incl-m-cast-hardware-egresses")

                self.l2fib_evpn_incl_m_cast_hardware_ingresses = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses()
                self.l2fib_evpn_incl_m_cast_hardware_ingresses.parent = self
                self._children_name_map["l2fib_evpn_incl_m_cast_hardware_ingresses"] = "l2fib-evpn-incl-m-cast-hardware-ingresses"
                self._children_yang_names.add("l2fib-evpn-incl-m-cast-hardware-ingresses")

                self.l2fib_evpn_incl_m_casts = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts()
                self.l2fib_evpn_incl_m_casts.parent = self
                self._children_name_map["l2fib_evpn_incl_m_casts"] = "l2fib-evpn-incl-m-casts"
                self._children_yang_names.add("l2fib-evpn-incl-m-casts")

                self.l2fib_evpn_ip4macs = L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs()
                self.l2fib_evpn_ip4macs.parent = self
                self._children_name_map["l2fib_evpn_ip4macs"] = "l2fib-evpn-ip4macs"
                self._children_yang_names.add("l2fib-evpn-ip4macs")

                self.l2fib_evpn_ip6macs = L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs()
                self.l2fib_evpn_ip6macs.parent = self
                self._children_name_map["l2fib_evpn_ip6macs"] = "l2fib-evpn-ip6macs"
                self._children_yang_names.add("l2fib-evpn-ip6macs")

                self.l2fib_g8032 = L2VpnForwarding.Nodes.Node.L2FibG8032()
                self.l2fib_g8032.parent = self
                self._children_name_map["l2fib_g8032"] = "l2fib-g8032"
                self._children_yang_names.add("l2fib-g8032")

                self.l2fib_l2tp = L2VpnForwarding.Nodes.Node.L2FibL2Tp()
                self.l2fib_l2tp.parent = self
                self._children_name_map["l2fib_l2tp"] = "l2fib-l2tp"
                self._children_yang_names.add("l2fib-l2tp")

                self.l2fib_mac_learning = L2VpnForwarding.Nodes.Node.L2FibMacLearning()
                self.l2fib_mac_learning.parent = self
                self._children_name_map["l2fib_mac_learning"] = "l2fib-mac-learning"
                self._children_yang_names.add("l2fib-mac-learning")

                self.l2fib_main_interfaces = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces()
                self.l2fib_main_interfaces.parent = self
                self._children_name_map["l2fib_main_interfaces"] = "l2fib-main-interfaces"
                self._children_yang_names.add("l2fib-main-interfaces")

                self.l2fib_message_summary = L2VpnForwarding.Nodes.Node.L2FibMessageSummary()
                self.l2fib_message_summary.parent = self
                self._children_name_map["l2fib_message_summary"] = "l2fib-message-summary"
                self._children_yang_names.add("l2fib-message-summary")

                self.l2fib_mmrp_summaries = L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries()
                self.l2fib_mmrp_summaries.parent = self
                self._children_name_map["l2fib_mmrp_summaries"] = "l2fib-mmrp-summaries"
                self._children_yang_names.add("l2fib-mmrp-summaries")

                self.l2fib_mmrps = L2VpnForwarding.Nodes.Node.L2FibMmrps()
                self.l2fib_mmrps.parent = self
                self._children_name_map["l2fib_mmrps"] = "l2fib-mmrps"
                self._children_yang_names.add("l2fib-mmrps")

                self.l2fib_mon_sess_x_cons = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons()
                self.l2fib_mon_sess_x_cons.parent = self
                self._children_name_map["l2fib_mon_sess_x_cons"] = "l2fib-mon-sess-x-cons"
                self._children_yang_names.add("l2fib-mon-sess-x-cons")

                self.l2fib_mroute_ipv6s = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S()
                self.l2fib_mroute_ipv6s.parent = self
                self._children_name_map["l2fib_mroute_ipv6s"] = "l2fib-mroute-ipv6s"
                self._children_yang_names.add("l2fib-mroute-ipv6s")

                self.l2fib_mroute_ports = L2VpnForwarding.Nodes.Node.L2FibMroutePorts()
                self.l2fib_mroute_ports.parent = self
                self._children_name_map["l2fib_mroute_ports"] = "l2fib-mroute-ports"
                self._children_yang_names.add("l2fib-mroute-ports")

                self.l2fib_mroute_summaries = L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries()
                self.l2fib_mroute_summaries.parent = self
                self._children_name_map["l2fib_mroute_summaries"] = "l2fib-mroute-summaries"
                self._children_yang_names.add("l2fib-mroute-summaries")

                self.l2fib_mroutes = L2VpnForwarding.Nodes.Node.L2FibMroutes()
                self.l2fib_mroutes.parent = self
                self._children_name_map["l2fib_mroutes"] = "l2fib-mroutes"
                self._children_yang_names.add("l2fib-mroutes")

                self.l2fib_mstp_details = L2VpnForwarding.Nodes.Node.L2FibMstpDetails()
                self.l2fib_mstp_details.parent = self
                self._children_name_map["l2fib_mstp_details"] = "l2fib-mstp-details"
                self._children_yang_names.add("l2fib-mstp-details")

                self.l2fib_mstp_summaries = L2VpnForwarding.Nodes.Node.L2FibMstpSummaries()
                self.l2fib_mstp_summaries.parent = self
                self._children_name_map["l2fib_mstp_summaries"] = "l2fib-mstp-summaries"
                self._children_yang_names.add("l2fib-mstp-summaries")

                self.l2fib_nve_peers = L2VpnForwarding.Nodes.Node.L2FibNvePeers()
                self.l2fib_nve_peers.parent = self
                self._children_name_map["l2fib_nve_peers"] = "l2fib-nve-peers"
                self._children_yang_names.add("l2fib-nve-peers")

                self.l2fib_p2mp = L2VpnForwarding.Nodes.Node.L2FibP2Mp()
                self.l2fib_p2mp.parent = self
                self._children_name_map["l2fib_p2mp"] = "l2fib-p2mp"
                self._children_yang_names.add("l2fib-p2mp")

                self.l2fib_pw_groups = L2VpnForwarding.Nodes.Node.L2FibPwGroups()
                self.l2fib_pw_groups.parent = self
                self._children_name_map["l2fib_pw_groups"] = "l2fib-pw-groups"
                self._children_yang_names.add("l2fib-pw-groups")

                self.l2fib_pwhe_main_ports = L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts()
                self.l2fib_pwhe_main_ports.parent = self
                self._children_name_map["l2fib_pwhe_main_ports"] = "l2fib-pwhe-main-ports"
                self._children_yang_names.add("l2fib-pwhe-main-ports")

                self.l2fib_resource_availability = L2VpnForwarding.Nodes.Node.L2FibResourceAvailability()
                self.l2fib_resource_availability.parent = self
                self._children_name_map["l2fib_resource_availability"] = "l2fib-resource-availability"
                self._children_yang_names.add("l2fib-resource-availability")

                self.l2fib_summary = L2VpnForwarding.Nodes.Node.L2FibSummary()
                self.l2fib_summary.parent = self
                self._children_name_map["l2fib_summary"] = "l2fib-summary"
                self._children_yang_names.add("l2fib-summary")

                self.l2fibmac_details = L2VpnForwarding.Nodes.Node.L2FibmacDetails()
                self.l2fibmac_details.parent = self
                self._children_name_map["l2fibmac_details"] = "l2fibmac-details"
                self._children_yang_names.add("l2fibmac-details")

                self.l2fibmac_hardware_egresses = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses()
                self.l2fibmac_hardware_egresses.parent = self
                self._children_name_map["l2fibmac_hardware_egresses"] = "l2fibmac-hardware-egresses"
                self._children_yang_names.add("l2fibmac-hardware-egresses")

                self.l2fibmac_hardware_ingresses = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses()
                self.l2fibmac_hardware_ingresses.parent = self
                self._children_name_map["l2fibmac_hardware_ingresses"] = "l2fibmac-hardware-ingresses"
                self._children_yang_names.add("l2fibmac-hardware-ingresses")

                self.l2fibx_con_l2tpv2s = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S()
                self.l2fibx_con_l2tpv2s.parent = self
                self._children_name_map["l2fibx_con_l2tpv2s"] = "l2fibx-con-l2tpv2s"
                self._children_yang_names.add("l2fibx-con-l2tpv2s")

                self.l2fibx_con_locals = L2VpnForwarding.Nodes.Node.L2FibxConLocals()
                self.l2fibx_con_locals.parent = self
                self._children_name_map["l2fibx_con_locals"] = "l2fibx-con-locals"
                self._children_yang_names.add("l2fibx-con-locals")

                self.l2fibx_cons = L2VpnForwarding.Nodes.Node.L2FibxCons()
                self.l2fibx_cons.parent = self
                self._children_name_map["l2fibx_cons"] = "l2fibx-cons"
                self._children_yang_names.add("l2fibx-cons")

                self.pbb_bmac_sa = L2VpnForwarding.Nodes.Node.PbbBmacSa()
                self.pbb_bmac_sa.parent = self
                self._children_name_map["pbb_bmac_sa"] = "pbb-bmac-sa"
                self._children_yang_names.add("pbb-bmac-sa")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("node_id") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2VpnForwarding.Nodes.Node, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2VpnForwarding.Nodes.Node, self).__setattr__(name, value)


            class L2FibxConLocals(Entity):
                """
                The L2VPN forwarding Local LC XConnect Detail
                Table
                
                .. attribute:: l2fibx_con_local
                
                	Specify Sub Ifh
                	**type**\: list of    :py:class:`L2FibxConLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals, self).__init__()

                    self.yang_name = "l2fibx-con-locals"
                    self.yang_parent_name = "node"

                    self.l2fibx_con_local = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals, self).__setattr__(name, value)


                class L2FibxConLocal(Entity):
                    """
                    Specify Sub Ifh
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Base>`
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\:  bool
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2>`
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:   :py:class:`MgmtL2FibSwitching <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibSwitching>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\:  str
                    
                    	**length:** 0..72
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal, self).__init__()

                        self.yang_name = "l2fibx-con-local"
                        self.yang_parent_name = "l2fibx-con-locals"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.bound = YLeaf(YType.boolean, "bound")

                        self.switching_type = YLeaf(YType.enumeration, "switching-type")

                        self.xcon_name = YLeaf(YType.str, "xcon-name")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                        self.segment1 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"
                        self._children_yang_names.add("segment1")

                        self.segment2 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"
                        self._children_yang_names.add("segment2")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "bound",
                                        "switching_type",
                                        "xcon_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibx-con-local"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Segment1(Entity):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:   :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1, self).__init__()

                            self.yang_name = "segment1"
                            self.yang_parent_name = "l2fibx-con-local"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"
                            self._children_yang_names.add("evpn")

                            self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self._children_name_map["monitor_session"] = "monitor-session"
                            self._children_yang_names.add("monitor-session")

                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"
                            self._children_yang_names.add("pbb")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                            self.vni = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"
                            self._children_yang_names.add("vni")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment1"

                                self.actype = YLeaf(YType.uint8, "actype")

                                self.adjacency_address = YLeaf(YType.str, "adjacency-address")

                                self.adjacency_valid = YLeaf(YType.boolean, "adjacency-valid")

                                self.attachment_circuit_id = YLeaf(YType.uint32, "attachment-circuit-id")

                                self.attachment_circuit_mtu = YLeaf(YType.uint16, "attachment-circuit-mtu")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.fxc_next_hop_valid = YLeaf(YType.boolean, "fxc-next-hop-valid")

                                self.inter_working_mode = YLeaf(YType.uint8, "inter-working-mode")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.ip_inter_working_mac = YLeaf(YType.str, "ip-inter-working-mac")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.sub_interface_handle = YLeaf(YType.str, "sub-interface-handle")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._children_yang_names.add("fxc-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actype",
                                                "adjacency_address",
                                                "adjacency_valid",
                                                "attachment_circuit_id",
                                                "attachment_circuit_mtu",
                                                "bound",
                                                "evpn_internal_label",
                                                "fxc_next_hop_valid",
                                                "inter_working_mode",
                                                "interface_handle",
                                                "ip_inter_working_mac",
                                                "redundancy_group_id",
                                                "redundancy_object_id",
                                                "sub_interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fxc-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.actype.is_set or
                                    self.adjacency_address.is_set or
                                    self.adjacency_valid.is_set or
                                    self.attachment_circuit_id.is_set or
                                    self.attachment_circuit_mtu.is_set or
                                    self.bound.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.fxc_next_hop_valid.is_set or
                                    self.inter_working_mode.is_set or
                                    self.interface_handle.is_set or
                                    self.ip_inter_working_mac.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.sub_interface_handle.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actype.yfilter != YFilter.not_set or
                                    self.adjacency_address.yfilter != YFilter.not_set or
                                    self.adjacency_valid.yfilter != YFilter.not_set or
                                    self.attachment_circuit_id.yfilter != YFilter.not_set or
                                    self.attachment_circuit_mtu.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.fxc_next_hop_valid.yfilter != YFilter.not_set or
                                    self.inter_working_mode.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.ip_inter_working_mac.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.sub_interface_handle.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actype.is_set or self.actype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actype.get_name_leafdata())
                                if (self.adjacency_address.is_set or self.adjacency_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_address.get_name_leafdata())
                                if (self.adjacency_valid.is_set or self.adjacency_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_valid.get_name_leafdata())
                                if (self.attachment_circuit_id.is_set or self.attachment_circuit_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_id.get_name_leafdata())
                                if (self.attachment_circuit_mtu.is_set or self.attachment_circuit_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_mtu.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.fxc_next_hop_valid.is_set or self.fxc_next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxc_next_hop_valid.get_name_leafdata())
                                if (self.inter_working_mode.is_set or self.inter_working_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_working_mode.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.ip_inter_working_mac.is_set or self.ip_inter_working_mac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_inter_working_mac.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.sub_interface_handle.is_set or self.sub_interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "fxc-next-hop"):
                                    if (self.fxc_next_hop is None):
                                        self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop()
                                        self.fxc_next_hop.parent = self
                                        self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                    return self.fxc_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxc-next-hop" or name == "actype" or name == "adjacency-address" or name == "adjacency-valid" or name == "attachment-circuit-id" or name == "attachment-circuit-mtu" or name == "bound" or name == "evpn-internal-label" or name == "fxc-next-hop-valid" or name == "inter-working-mode" or name == "interface-handle" or name == "ip-inter-working-mac" or name == "redundancy-group-id" or name == "redundancy-object-id" or name == "sub-interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actype"):
                                    self.actype = value
                                    self.actype.value_namespace = name_space
                                    self.actype.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-address"):
                                    self.adjacency_address = value
                                    self.adjacency_address.value_namespace = name_space
                                    self.adjacency_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-valid"):
                                    self.adjacency_valid = value
                                    self.adjacency_valid.value_namespace = name_space
                                    self.adjacency_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-id"):
                                    self.attachment_circuit_id = value
                                    self.attachment_circuit_id.value_namespace = name_space
                                    self.attachment_circuit_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-mtu"):
                                    self.attachment_circuit_mtu = value
                                    self.attachment_circuit_mtu.value_namespace = name_space
                                    self.attachment_circuit_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "fxc-next-hop-valid"):
                                    self.fxc_next_hop_valid = value
                                    self.fxc_next_hop_valid.value_namespace = name_space
                                    self.fxc_next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-working-mode"):
                                    self.inter_working_mode = value
                                    self.inter_working_mode.value_namespace = name_space
                                    self.inter_working_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip-inter-working-mac"):
                                    self.ip_inter_working_mac = value
                                    self.ip_inter_working_mac.value_namespace = name_space
                                    self.ip_inter_working_mac.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-interface-handle"):
                                    self.sub_interface_handle = value
                                    self.sub_interface_handle.value_namespace = name_space
                                    self.sub_interface_handle.value_namespace_prefix = name_space_prefix


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:   :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.core_pbb_evpn_enabled = YLeaf(YType.boolean, "core-pbb-evpn-enabled")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self
                                self._children_name_map["pbb_union"] = "pbb-union"
                                self._children_yang_names.add("pbb-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "core_pbb_evpn_enabled",
                                                "forward_class") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pbb"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class PbbUnion(Entity):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:   :py:class:`MgmtL2FibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridge>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion, self).__init__()

                                    self.yang_name = "pbb-union"
                                    self.yang_parent_name = "pbb"

                                    self.pbb_type = YLeaf(YType.enumeration, "pbb-type")

                                    self.core = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                    self._children_yang_names.add("core")

                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"
                                    self._children_yang_names.add("edge")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pbb_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion, self).__setattr__(name, value)


                                class Edge(Entity):
                                    """
                                    edge
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Edge, self).__init__()

                                        self.yang_name = "edge"
                                        self.yang_parent_name = "pbb-union"

                                        self.mac = YLeaf(YType.str, "mac")

                                        self.mac_configured = YLeaf(YType.boolean, "mac-configured")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mac",
                                                        "mac_configured") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Edge, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Edge, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mac.is_set or
                                            self.mac_configured.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mac.yfilter != YFilter.not_set or
                                            self.mac_configured.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "edge" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mac.is_set or self.mac.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac.get_name_leafdata())
                                        if (self.mac_configured.is_set or self.mac_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_configured.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mac" or name == "mac-configured"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mac"):
                                            self.mac = value
                                            self.mac.value_namespace = name_space
                                            self.mac.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-configured"):
                                            self.mac_configured = value
                                            self.mac_configured.value_namespace = name_space
                                            self.mac_configured.value_namespace_prefix = name_space_prefix


                                class Core(Entity):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Core, self).__init__()

                                        self.yang_name = "core"
                                        self.yang_parent_name = "pbb-union"

                                        self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vlan_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Core, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Core, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.vlan_id.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vlan_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "core" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vlan-id"):
                                            self.vlan_id = value
                                            self.vlan_id.value_namespace = name_space
                                            self.vlan_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.pbb_type.is_set or
                                        (self.core is not None and self.core.has_data()) or
                                        (self.edge is not None and self.edge.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pbb_type.yfilter != YFilter.not_set or
                                        (self.core is not None and self.core.has_operation()) or
                                        (self.edge is not None and self.edge.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pbb-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pbb_type.is_set or self.pbb_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pbb_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "core"):
                                        if (self.core is None):
                                            self.core = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Core()
                                            self.core.parent = self
                                            self._children_name_map["core"] = "core"
                                        return self.core

                                    if (child_yang_name == "edge"):
                                        if (self.edge is None):
                                            self.edge = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Edge()
                                            self.edge.parent = self
                                            self._children_name_map["edge"] = "edge"
                                        return self.edge

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "core" or name == "edge" or name == "pbb-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pbb-type"):
                                        self.pbb_type = value
                                        self.pbb_type.value_namespace = name_space
                                        self.pbb_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.core_pbb_evpn_enabled.is_set or
                                    self.forward_class.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.pbb_union is not None and self.pbb_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.core_pbb_evpn_enabled.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.pbb_union is not None and self.pbb_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.core_pbb_evpn_enabled.is_set or self.core_pbb_evpn_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_pbb_evpn_enabled.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "pbb-union"):
                                    if (self.pbb_union is None):
                                        self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion()
                                        self.pbb_union.parent = self
                                        self._children_name_map["pbb_union"] = "pbb-union"
                                    return self.pbb_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "pbb-union" or name == "bound" or name == "core-pbb-evpn-enabled" or name == "forward-class"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "core-pbb-evpn-enabled"):
                                    self.core_pbb_evpn_enabled = value
                                    self.core_pbb_evpn_enabled.value_namespace = name_space
                                    self.core_pbb_evpn_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment1"

                                self.any_cast_ip = YLeaf(YType.str, "any-cast-ip")

                                self.anycast_mcast_ip = YLeaf(YType.str, "anycast-mcast-ip")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.encap = YLeaf(YType.uint32, "encap")

                                self.mcastip = YLeaf(YType.str, "mcastip")

                                self.parent_if = YLeaf(YType.str, "parent-if")

                                self.source_vtep_if = YLeaf(YType.str, "source-vtep-if")

                                self.srcip = YLeaf(YType.str, "srcip")

                                self.udp_port = YLeaf(YType.uint32, "udp-port")

                                self.vx_lan_mode = YLeaf(YType.uint32, "vx-lan-mode")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("any_cast_ip",
                                                "anycast_mcast_ip",
                                                "bound",
                                                "encap",
                                                "mcastip",
                                                "parent_if",
                                                "source_vtep_if",
                                                "srcip",
                                                "udp_port",
                                                "vx_lan_mode") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "vni"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.any_cast_ip.is_set or
                                    self.anycast_mcast_ip.is_set or
                                    self.bound.is_set or
                                    self.encap.is_set or
                                    self.mcastip.is_set or
                                    self.parent_if.is_set or
                                    self.source_vtep_if.is_set or
                                    self.srcip.is_set or
                                    self.udp_port.is_set or
                                    self.vx_lan_mode.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.any_cast_ip.yfilter != YFilter.not_set or
                                    self.anycast_mcast_ip.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.encap.yfilter != YFilter.not_set or
                                    self.mcastip.yfilter != YFilter.not_set or
                                    self.parent_if.yfilter != YFilter.not_set or
                                    self.source_vtep_if.yfilter != YFilter.not_set or
                                    self.srcip.yfilter != YFilter.not_set or
                                    self.udp_port.yfilter != YFilter.not_set or
                                    self.vx_lan_mode.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vni" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.any_cast_ip.is_set or self.any_cast_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.any_cast_ip.get_name_leafdata())
                                if (self.anycast_mcast_ip.is_set or self.anycast_mcast_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.anycast_mcast_ip.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.encap.is_set or self.encap.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encap.get_name_leafdata())
                                if (self.mcastip.is_set or self.mcastip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mcastip.get_name_leafdata())
                                if (self.parent_if.is_set or self.parent_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_if.get_name_leafdata())
                                if (self.source_vtep_if.is_set or self.source_vtep_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_vtep_if.get_name_leafdata())
                                if (self.srcip.is_set or self.srcip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.srcip.get_name_leafdata())
                                if (self.udp_port.is_set or self.udp_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.udp_port.get_name_leafdata())
                                if (self.vx_lan_mode.is_set or self.vx_lan_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vx_lan_mode.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "any-cast-ip" or name == "anycast-mcast-ip" or name == "bound" or name == "encap" or name == "mcastip" or name == "parent-if" or name == "source-vtep-if" or name == "srcip" or name == "udp-port" or name == "vx-lan-mode"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "any-cast-ip"):
                                    self.any_cast_ip = value
                                    self.any_cast_ip.value_namespace = name_space
                                    self.any_cast_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "anycast-mcast-ip"):
                                    self.anycast_mcast_ip = value
                                    self.anycast_mcast_ip.value_namespace = name_space
                                    self.anycast_mcast_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "encap"):
                                    self.encap = value
                                    self.encap.value_namespace = name_space
                                    self.encap.value_namespace_prefix = name_space_prefix
                                if(value_path == "mcastip"):
                                    self.mcastip = value
                                    self.mcastip.value_namespace = name_space
                                    self.mcastip.value_namespace_prefix = name_space_prefix
                                if(value_path == "parent-if"):
                                    self.parent_if = value
                                    self.parent_if.value_namespace = name_space
                                    self.parent_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-vtep-if"):
                                    self.source_vtep_if = value
                                    self.source_vtep_if.value_namespace = name_space
                                    self.source_vtep_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "srcip"):
                                    self.srcip = value
                                    self.srcip.value_namespace = name_space
                                    self.srcip.value_namespace_prefix = name_space_prefix
                                if(value_path == "udp-port"):
                                    self.udp_port = value
                                    self.udp_port.value_namespace = name_space
                                    self.udp_port.value_namespace_prefix = name_space_prefix
                                if(value_path == "vx-lan-mode"):
                                    self.vx_lan_mode = value
                                    self.vx_lan_mode.value_namespace = name_space
                                    self.vx_lan_mode.value_namespace_prefix = name_space_prefix


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evi = YLeaf(YType.uint32, "evi")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "evi",
                                                "forward_class") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "evpn"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.evi.is_set or
                                    self.forward_class.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evi.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evi.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "bound" or name == "evi" or name == "forward-class"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evi"):
                                    self.evi = value
                                    self.evi.value_namespace = name_space
                                    self.evi.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix


                        class MonitorSession(Entity):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\:  str
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession, self).__init__()

                                self.yang_name = "monitor-session"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.hardware_information = YLeaf(YType.str, "hardware-information")

                                self.session_name = YLeaf(YType.str, "session-name")

                                self.xcid = YLeaf(YType.uint32, "xcid")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "hardware_information",
                                                "session_name",
                                                "xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "monitor-session"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.hardware_information.is_set or
                                    self.session_name.is_set or
                                    self.xcid.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.hardware_information.yfilter != YFilter.not_set or
                                    self.session_name.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "monitor-session" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.hardware_information.is_set or self.hardware_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.hardware_information.get_name_leafdata())
                                if (self.session_name.is_set or self.session_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.session_name.get_name_leafdata())
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "bound" or name == "hardware-information" or name == "session-name" or name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "hardware-information"):
                                    self.hardware_information = value
                                    self.hardware_information.value_namespace = name_space
                                    self.hardware_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "session-name"):
                                    self.session_name = value
                                    self.session_name.value_namespace = name_space
                                    self.session_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBal>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment1"

                                self.ac_id = YLeaf(YType.uint32, "ac-id")

                                self.active = YLeaf(YType.boolean, "active")

                                self.backup_configured = YLeaf(YType.boolean, "backup-configured")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.context = YLeaf(YType.uint16, "context")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.global_id = YLeaf(YType.uint32, "global-id")

                                self.group_id = YLeaf(YType.uint32, "group-id")

                                self.group_state = YLeaf(YType.enumeration, "group-state")

                                self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                                self.pw_load_balance_type = YLeaf(YType.enumeration, "pw-load-balance-type")

                                self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                self.sequence_resync_threshold = YLeaf(YType.uint16, "sequence-resync-threshold")

                                self.signal_capability_flags = YLeaf(YType.uint32, "signal-capability-flags")

                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._children_yang_names.add("backup-pseudo-wire")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                self._children_yang_names.add("pseudo-wire-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ac_id",
                                                "active",
                                                "backup_configured",
                                                "bound",
                                                "context",
                                                "forward_class",
                                                "global_id",
                                                "group_id",
                                                "group_state",
                                                "grouping_supported",
                                                "next_hop_valid",
                                                "pseudo_wire_id_type",
                                                "pw_flow_label_tx",
                                                "pw_id",
                                                "pw_load_balance_type",
                                                "redundancy_role",
                                                "sequence_resync_threshold",
                                                "signal_capability_flags") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"
                                    self._children_yang_names.add("l2tp")

                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._children_yang_names.add("l2tp-ipv6-ts")

                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"
                                    self._children_yang_names.add("l2tpv2")

                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"
                                    self._children_yang_names.add("mpls")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion, self).__setattr__(name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix


                                class L2Tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_mtu",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_mtu.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "path-mtu" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix


                                class L2Tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.protocol = YLeaf(YType.uint16, "protocol")

                                        self.pw_flags = YLeaf(YType.uint8, "pw-flags")

                                        self.rem_udp_port = YLeaf(YType.uint16, "rem-udp-port")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop_address",
                                                        "path_mtu",
                                                        "protocol",
                                                        "pw_flags",
                                                        "rem_udp_port",
                                                        "source_address",
                                                        "tos_val",
                                                        "ttl",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.next_hop_address.is_set or
                                            self.path_mtu.is_set or
                                            self.protocol.is_set or
                                            self.pw_flags.is_set or
                                            self.rem_udp_port.is_set or
                                            self.source_address.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            self.xconnect_id.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pw_flags.yfilter != YFilter.not_set or
                                            self.rem_udp_port.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv2" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pw_flags.is_set or self.pw_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flags.get_name_leafdata())
                                        if (self.rem_udp_port.is_set or self.rem_udp_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_udp_port.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "next-hop-address" or name == "path-mtu" or name == "protocol" or name == "pw-flags" or name == "rem-udp-port" or name == "source-address" or name == "tos-val" or name == "ttl" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop-address"):
                                            self.next_hop_address = value
                                            self.next_hop_address.value_namespace = name_space
                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flags"):
                                            self.pw_flags = value
                                            self.pw_flags.value_namespace = name_space
                                            self.pw_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-udp-port"):
                                            self.rem_udp_port = value
                                            self.rem_udp_port.value_namespace = name_space
                                            self.rem_udp_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class L2TpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address",
                                                        "path_mtu",
                                                        "remote_address",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.secondary_cookie_high_value = YLeaf(YType.uint32, "secondary-cookie-high-value")

                                            self.secondary_cookie_low_value = YLeaf(YType.uint32, "secondary-cookie-low-value")

                                            self.secondary_cookie_size = YLeaf(YType.uint8, "secondary-cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "secondary_cookie_high_value",
                                                            "secondary_cookie_low_value",
                                                            "secondary_cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.secondary_cookie_high_value.is_set or
                                                self.secondary_cookie_low_value.is_set or
                                                self.secondary_cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.secondary_cookie_high_value.is_set or self.secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_high_value.get_name_leafdata())
                                            if (self.secondary_cookie_low_value.is_set or self.secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_low_value.get_name_leafdata())
                                            if (self.secondary_cookie_size.is_set or self.secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "secondary-cookie-high-value" or name == "secondary-cookie-low-value" or name == "secondary-cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-high-value"):
                                                self.secondary_cookie_high_value = value
                                                self.secondary_cookie_high_value.value_namespace = name_space
                                                self.secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-low-value"):
                                                self.secondary_cookie_low_value = value
                                                self.secondary_cookie_low_value.value_namespace = name_space
                                                self.secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-size"):
                                                self.secondary_cookie_size = value
                                                self.secondary_cookie_size.value_namespace = name_space
                                                self.secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.local_address.is_set or
                                            self.path_mtu.is_set or
                                            self.remote_address.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp-ipv6-ts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "local-address" or name == "path-mtu" or name == "remote-address" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        (self.l2tp is not None and self.l2tp.has_data()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_data()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_data()) or
                                        (self.mpls is not None and self.mpls.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        (self.l2tp is not None and self.l2tp.has_operation()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_operation()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_operation()) or
                                        (self.mpls is not None and self.mpls.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudo-wire-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2tp"):
                                        if (self.l2tp is None):
                                            self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp()
                                            self.l2tp.parent = self
                                            self._children_name_map["l2tp"] = "l2tp"
                                        return self.l2tp

                                    if (child_yang_name == "l2tp-ipv6-ts"):
                                        if (self.l2tp_ipv6_ts is None):
                                            self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                            self.l2tp_ipv6_ts.parent = self
                                            self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                        return self.l2tp_ipv6_ts

                                    if (child_yang_name == "l2tpv2"):
                                        if (self.l2tpv2 is None):
                                            self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                            self.l2tpv2.parent = self
                                            self._children_name_map["l2tpv2"] = "l2tpv2"
                                        return self.l2tpv2

                                    if (child_yang_name == "mpls"):
                                        if (self.mpls is None):
                                            self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                        return self.mpls

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2tp" or name == "l2tp-ipv6-ts" or name == "l2tpv2" or name == "mpls" or name == "data-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.backup_next_hop = YLeaf(YType.str, "backup-next-hop")

                                    self.backup_pseudo_wire_id = YLeaf(YType.uint32, "backup-pseudo-wire-id")

                                    self.backup_pseudo_wire_id_type = YLeaf(YType.enumeration, "backup-pseudo-wire-id-type")

                                    self.bound = YLeaf(YType.boolean, "bound")

                                    self.group_id = YLeaf(YType.uint32, "group-id")

                                    self.group_state = YLeaf(YType.enumeration, "group-state")

                                    self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                    self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                    self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "backup_next_hop",
                                                    "backup_pseudo_wire_id",
                                                    "backup_pseudo_wire_id_type",
                                                    "bound",
                                                    "group_id",
                                                    "group_state",
                                                    "grouping_supported",
                                                    "pw_flow_label_tx",
                                                    "redundancy_role") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.backup_next_hop.is_set or
                                        self.backup_pseudo_wire_id.is_set or
                                        self.backup_pseudo_wire_id_type.is_set or
                                        self.bound.is_set or
                                        self.group_id.is_set or
                                        self.group_state.is_set or
                                        self.grouping_supported.is_set or
                                        self.pw_flow_label_tx.is_set or
                                        self.redundancy_role.is_set or
                                        (self.atom is not None and self.atom.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.backup_next_hop.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set or
                                        self.bound.yfilter != YFilter.not_set or
                                        self.group_id.yfilter != YFilter.not_set or
                                        self.group_state.yfilter != YFilter.not_set or
                                        self.grouping_supported.yfilter != YFilter.not_set or
                                        self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                        self.redundancy_role.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-pseudo-wire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.backup_next_hop.is_set or self.backup_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_next_hop.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id.is_set or self.backup_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id_type.is_set or self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id_type.get_name_leafdata())
                                    if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bound.get_name_leafdata())
                                    if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_id.get_name_leafdata())
                                    if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_state.get_name_leafdata())
                                    if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                    if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                    if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_role.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "active" or name == "backup-next-hop" or name == "backup-pseudo-wire-id" or name == "backup-pseudo-wire-id-type" or name == "bound" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "pw-flow-label-tx" or name == "redundancy-role"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-next-hop"):
                                        self.backup_next_hop = value
                                        self.backup_next_hop.value_namespace = name_space
                                        self.backup_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id"):
                                        self.backup_pseudo_wire_id = value
                                        self.backup_pseudo_wire_id.value_namespace = name_space
                                        self.backup_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id-type"):
                                        self.backup_pseudo_wire_id_type = value
                                        self.backup_pseudo_wire_id_type.value_namespace = name_space
                                        self.backup_pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bound"):
                                        self.bound = value
                                        self.bound.value_namespace = name_space
                                        self.bound.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-id"):
                                        self.group_id = value
                                        self.group_id.value_namespace = name_space
                                        self.group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-state"):
                                        self.group_state = value
                                        self.group_state.value_namespace = name_space
                                        self.group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "grouping-supported"):
                                        self.grouping_supported = value
                                        self.grouping_supported.value_namespace = name_space
                                        self.grouping_supported.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-tx"):
                                        self.pw_flow_label_tx = value
                                        self.pw_flow_label_tx.value_namespace = name_space
                                        self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-role"):
                                        self.redundancy_role = value
                                        self.redundancy_role.value_namespace = name_space
                                        self.redundancy_role.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ac_id.is_set or
                                    self.active.is_set or
                                    self.backup_configured.is_set or
                                    self.bound.is_set or
                                    self.context.is_set or
                                    self.forward_class.is_set or
                                    self.global_id.is_set or
                                    self.group_id.is_set or
                                    self.group_state.is_set or
                                    self.grouping_supported.is_set or
                                    self.next_hop_valid.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_flow_label_tx.is_set or
                                    self.pw_id.is_set or
                                    self.pw_load_balance_type.is_set or
                                    self.redundancy_role.is_set or
                                    self.sequence_resync_threshold.is_set or
                                    self.signal_capability_flags.is_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_data()) or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ac_id.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.backup_configured.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.context.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.global_id.yfilter != YFilter.not_set or
                                    self.group_id.yfilter != YFilter.not_set or
                                    self.group_state.yfilter != YFilter.not_set or
                                    self.grouping_supported.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.pw_load_balance_type.yfilter != YFilter.not_set or
                                    self.redundancy_role.yfilter != YFilter.not_set or
                                    self.sequence_resync_threshold.yfilter != YFilter.not_set or
                                    self.signal_capability_flags.yfilter != YFilter.not_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_operation()) or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ac_id.is_set or self.ac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac_id.get_name_leafdata())
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.backup_configured.is_set or self.backup_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_configured.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.context.is_set or self.context.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.context.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.global_id.is_set or self.global_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_id.get_name_leafdata())
                                if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_id.get_name_leafdata())
                                if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_state.get_name_leafdata())
                                if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.pw_load_balance_type.is_set or self.pw_load_balance_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_load_balance_type.get_name_leafdata())
                                if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_role.get_name_leafdata())
                                if (self.sequence_resync_threshold.is_set or self.sequence_resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_resync_threshold.get_name_leafdata())
                                if (self.signal_capability_flags.is_set or self.signal_capability_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signal_capability_flags.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-pseudo-wire"):
                                    if (self.backup_pseudo_wire is None):
                                        self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire()
                                        self.backup_pseudo_wire.parent = self
                                        self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                    return self.backup_pseudo_wire

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                if (child_yang_name == "pseudo-wire-union"):
                                    if (self.pseudo_wire_union is None):
                                        self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion()
                                        self.pseudo_wire_union.parent = self
                                        self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                    return self.pseudo_wire_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-pseudo-wire" or name == "base" or name == "next-hop" or name == "pseudo-wire-union" or name == "ac-id" or name == "active" or name == "backup-configured" or name == "bound" or name == "context" or name == "forward-class" or name == "global-id" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "next-hop-valid" or name == "pseudo-wire-id-type" or name == "pw-flow-label-tx" or name == "pw-id" or name == "pw-load-balance-type" or name == "redundancy-role" or name == "sequence-resync-threshold" or name == "signal-capability-flags"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ac-id"):
                                    self.ac_id = value
                                    self.ac_id.value_namespace = name_space
                                    self.ac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-configured"):
                                    self.backup_configured = value
                                    self.backup_configured.value_namespace = name_space
                                    self.backup_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "context"):
                                    self.context = value
                                    self.context.value_namespace = name_space
                                    self.context.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "global-id"):
                                    self.global_id = value
                                    self.global_id.value_namespace = name_space
                                    self.global_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-id"):
                                    self.group_id = value
                                    self.group_id.value_namespace = name_space
                                    self.group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-state"):
                                    self.group_state = value
                                    self.group_state.value_namespace = name_space
                                    self.group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "grouping-supported"):
                                    self.grouping_supported = value
                                    self.grouping_supported.value_namespace = name_space
                                    self.grouping_supported.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-tx"):
                                    self.pw_flow_label_tx = value
                                    self.pw_flow_label_tx.value_namespace = name_space
                                    self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-load-balance-type"):
                                    self.pw_load_balance_type = value
                                    self.pw_load_balance_type.value_namespace = name_space
                                    self.pw_load_balance_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-role"):
                                    self.redundancy_role = value
                                    self.redundancy_role.value_namespace = name_space
                                    self.redundancy_role.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-resync-threshold"):
                                    self.sequence_resync_threshold = value
                                    self.sequence_resync_threshold.value_namespace = name_space
                                    self.sequence_resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "signal-capability-flags"):
                                    self.signal_capability_flags = value
                                    self.signal_capability_flags.value_namespace = name_space
                                    self.signal_capability_flags.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.evpn is not None and self.evpn.has_data()) or
                                (self.monitor_session is not None and self.monitor_session.has_data()) or
                                (self.pbb is not None and self.pbb.has_data()) or
                                (self.pw is not None and self.pw.has_data()) or
                                (self.vni is not None and self.vni.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.evpn is not None and self.evpn.has_operation()) or
                                (self.monitor_session is not None and self.monitor_session.has_operation()) or
                                (self.pbb is not None and self.pbb.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()) or
                                (self.vni is not None and self.vni.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "evpn"):
                                if (self.evpn is None):
                                    self.evpn = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn()
                                    self.evpn.parent = self
                                    self._children_name_map["evpn"] = "evpn"
                                return self.evpn

                            if (child_yang_name == "monitor-session"):
                                if (self.monitor_session is None):
                                    self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession()
                                    self.monitor_session.parent = self
                                    self._children_name_map["monitor_session"] = "monitor-session"
                                return self.monitor_session

                            if (child_yang_name == "pbb"):
                                if (self.pbb is None):
                                    self.pbb = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb()
                                    self.pbb.parent = self
                                    self._children_name_map["pbb"] = "pbb"
                                return self.pbb

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            if (child_yang_name == "vni"):
                                if (self.vni is None):
                                    self.vni = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni()
                                    self.vni.parent = self
                                    self._children_name_map["vni"] = "vni"
                                return self.vni

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "evpn" or name == "monitor-session" or name == "pbb" or name == "pw" or name == "vni" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix


                    class Segment2(Entity):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:   :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:   :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2, self).__init__()

                            self.yang_name = "segment2"
                            self.yang_parent_name = "l2fibx-con-local"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.bp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp()
                            self.bp.parent = self
                            self._children_name_map["bp"] = "bp"
                            self._children_yang_names.add("bp")

                            self.fxs = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs()
                            self.fxs.parent = self
                            self._children_name_map["fxs"] = "fxs"
                            self._children_yang_names.add("fxs")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment2"

                                self.actype = YLeaf(YType.uint8, "actype")

                                self.adjacency_address = YLeaf(YType.str, "adjacency-address")

                                self.adjacency_valid = YLeaf(YType.boolean, "adjacency-valid")

                                self.attachment_circuit_id = YLeaf(YType.uint32, "attachment-circuit-id")

                                self.attachment_circuit_mtu = YLeaf(YType.uint16, "attachment-circuit-mtu")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.fxc_next_hop_valid = YLeaf(YType.boolean, "fxc-next-hop-valid")

                                self.inter_working_mode = YLeaf(YType.uint8, "inter-working-mode")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.ip_inter_working_mac = YLeaf(YType.str, "ip-inter-working-mac")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.sub_interface_handle = YLeaf(YType.str, "sub-interface-handle")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._children_yang_names.add("fxc-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actype",
                                                "adjacency_address",
                                                "adjacency_valid",
                                                "attachment_circuit_id",
                                                "attachment_circuit_mtu",
                                                "bound",
                                                "evpn_internal_label",
                                                "fxc_next_hop_valid",
                                                "inter_working_mode",
                                                "interface_handle",
                                                "ip_inter_working_mac",
                                                "redundancy_group_id",
                                                "redundancy_object_id",
                                                "sub_interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fxc-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.actype.is_set or
                                    self.adjacency_address.is_set or
                                    self.adjacency_valid.is_set or
                                    self.attachment_circuit_id.is_set or
                                    self.attachment_circuit_mtu.is_set or
                                    self.bound.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.fxc_next_hop_valid.is_set or
                                    self.inter_working_mode.is_set or
                                    self.interface_handle.is_set or
                                    self.ip_inter_working_mac.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.sub_interface_handle.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actype.yfilter != YFilter.not_set or
                                    self.adjacency_address.yfilter != YFilter.not_set or
                                    self.adjacency_valid.yfilter != YFilter.not_set or
                                    self.attachment_circuit_id.yfilter != YFilter.not_set or
                                    self.attachment_circuit_mtu.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.fxc_next_hop_valid.yfilter != YFilter.not_set or
                                    self.inter_working_mode.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.ip_inter_working_mac.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.sub_interface_handle.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actype.is_set or self.actype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actype.get_name_leafdata())
                                if (self.adjacency_address.is_set or self.adjacency_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_address.get_name_leafdata())
                                if (self.adjacency_valid.is_set or self.adjacency_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_valid.get_name_leafdata())
                                if (self.attachment_circuit_id.is_set or self.attachment_circuit_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_id.get_name_leafdata())
                                if (self.attachment_circuit_mtu.is_set or self.attachment_circuit_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_mtu.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.fxc_next_hop_valid.is_set or self.fxc_next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxc_next_hop_valid.get_name_leafdata())
                                if (self.inter_working_mode.is_set or self.inter_working_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_working_mode.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.ip_inter_working_mac.is_set or self.ip_inter_working_mac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_inter_working_mac.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.sub_interface_handle.is_set or self.sub_interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "fxc-next-hop"):
                                    if (self.fxc_next_hop is None):
                                        self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop()
                                        self.fxc_next_hop.parent = self
                                        self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                    return self.fxc_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxc-next-hop" or name == "actype" or name == "adjacency-address" or name == "adjacency-valid" or name == "attachment-circuit-id" or name == "attachment-circuit-mtu" or name == "bound" or name == "evpn-internal-label" or name == "fxc-next-hop-valid" or name == "inter-working-mode" or name == "interface-handle" or name == "ip-inter-working-mac" or name == "redundancy-group-id" or name == "redundancy-object-id" or name == "sub-interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actype"):
                                    self.actype = value
                                    self.actype.value_namespace = name_space
                                    self.actype.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-address"):
                                    self.adjacency_address = value
                                    self.adjacency_address.value_namespace = name_space
                                    self.adjacency_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-valid"):
                                    self.adjacency_valid = value
                                    self.adjacency_valid.value_namespace = name_space
                                    self.adjacency_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-id"):
                                    self.attachment_circuit_id = value
                                    self.attachment_circuit_id.value_namespace = name_space
                                    self.attachment_circuit_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-mtu"):
                                    self.attachment_circuit_mtu = value
                                    self.attachment_circuit_mtu.value_namespace = name_space
                                    self.attachment_circuit_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "fxc-next-hop-valid"):
                                    self.fxc_next_hop_valid = value
                                    self.fxc_next_hop_valid.value_namespace = name_space
                                    self.fxc_next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-working-mode"):
                                    self.inter_working_mode = value
                                    self.inter_working_mode.value_namespace = name_space
                                    self.inter_working_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip-inter-working-mac"):
                                    self.ip_inter_working_mac = value
                                    self.ip_inter_working_mac.value_namespace = name_space
                                    self.ip_inter_working_mac.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-interface-handle"):
                                    self.sub_interface_handle = value
                                    self.sub_interface_handle.value_namespace = name_space
                                    self.sub_interface_handle.value_namespace_prefix = name_space_prefix


                        class Bp(Entity):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Base>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:   :py:class:`P2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.P2Mp>`
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp, self).__init__()

                                self.yang_name = "bp"
                                self.yang_parent_name = "segment2"

                                self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                                self.learn_key = YLeaf(YType.uint8, "learn-key")

                                self.msti_pointer = YLeaf(YType.uint32, "msti-pointer")

                                self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                                self.segment_type = YLeaf(YType.uint8, "segment-type")

                                self.shg_id = YLeaf(YType.uint32, "shg-id")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.oper = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self._children_name_map["oper"] = "oper"
                                self._children_yang_names.add("oper")

                                self.p2mp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.P2Mp()
                                self.p2mp.parent = self
                                self._children_name_map["p2mp"] = "p2mp"
                                self._children_yang_names.add("p2mp")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bridge_id",
                                                "learn_key",
                                                "msti_pointer",
                                                "mvrp_sequence_number",
                                                "segment_type",
                                                "shg_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "bp"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Oper(Entity):
                                """
                                Operational information
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper, self).__init__()

                                    self.yang_name = "oper"
                                    self.yang_parent_name = "bp"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self._children_name_map["operational_information"] = "operational-information"
                                    self._children_yang_names.add("operational-information")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper, self).__setattr__(name, value)


                                class OperationalInformation(Entity):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\:  bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: host_routing_enabled
                                    
                                    	Host Routing enabled on this BD
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotify>`
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:   :py:class:`MgmtL2FibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecAction>`
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\:  bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation, self).__init__()

                                        self.yang_name = "operational-information"
                                        self.yang_parent_name = "oper"

                                        self.admin_disabled = YLeaf(YType.boolean, "admin-disabled")

                                        self.bvi_configured = YLeaf(YType.boolean, "bvi-configured")

                                        self.dhcp_enabled = YLeaf(YType.boolean, "dhcp-enabled")

                                        self.dhcp_trusted = YLeaf(YType.boolean, "dhcp-trusted")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flooding_disabled = YLeaf(YType.boolean, "flooding-disabled")

                                        self.host_routing_enabled = YLeaf(YType.boolean, "host-routing-enabled")

                                        self.igmp_flood_forward_enabled = YLeaf(YType.boolean, "igmp-flood-forward-enabled")

                                        self.igmp_mroute_port_enabled = YLeaf(YType.boolean, "igmp-mroute-port-enabled")

                                        self.igmp_route_guard_enabled = YLeaf(YType.boolean, "igmp-route-guard-enabled")

                                        self.igmp_snoop_enabled = YLeaf(YType.boolean, "igmp-snoop-enabled")

                                        self.igmp_snoop_profile_enabled = YLeaf(YType.boolean, "igmp-snoop-profile-enabled")

                                        self.is_bvi_up = YLeaf(YType.boolean, "is-bvi-up")

                                        self.is_dai_addr_validation_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-destination-mac-enabled")

                                        self.is_dai_addr_validation_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-ipv4-enabled")

                                        self.is_dai_addr_validation_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_evpn_cw_disable = YLeaf(YType.boolean, "is-evpn-cw-disable")

                                        self.is_evpn_enabled = YLeaf(YType.boolean, "is-evpn-enabled")

                                        self.is_evpn_flow_label = YLeaf(YType.boolean, "is-evpn-flow-label")

                                        self.is_igmp_snoop_enabled = YLeaf(YType.boolean, "is-igmp-snoop-enabled")

                                        self.is_ipsg_enabled = YLeaf(YType.boolean, "is-ipsg-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.is_p2mp_pw_enabled = YLeaf(YType.boolean, "is-p2mp-pw-enabled")

                                        self.is_pbbevpn_enabled = YLeaf(YType.boolean, "is-pbbevpn-enabled")

                                        self.is_swmac_learning = YLeaf(YType.boolean, "is-swmac-learning")

                                        self.is_vni_enabled = YLeaf(YType.boolean, "is-vni-enabled")

                                        self.is_vpls_flood_optimization_enabled = YLeaf(YType.boolean, "is-vpls-flood-optimization-enabled")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_aging_type = YLeaf(YType.boolean, "mac-aging-type")

                                        self.mac_learning_disabled = YLeaf(YType.boolean, "mac-learning-disabled")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification_type = YLeaf(YType.enumeration, "mac-limit-notification-type")

                                        self.mac_port_down_flush_disabled = YLeaf(YType.boolean, "mac-port-down-flush-disabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_flood_forward_enabled = YLeaf(YType.boolean, "mld-flood-forward-enabled")

                                        self.mld_mroute_port_enabled = YLeaf(YType.boolean, "mld-mroute-port-enabled")

                                        self.mld_route_guard_enabled = YLeaf(YType.boolean, "mld-route-guard-enabled")

                                        self.mld_snoop_enabled = YLeaf(YType.boolean, "mld-snoop-enabled")

                                        self.mld_snoop_profile_enabled = YLeaf(YType.boolean, "mld-snoop-profile-enabled")

                                        self.msti = YLeaf(YType.uint32, "msti")

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.number_of_macs = YLeaf(YType.uint32, "number-of-macs")

                                        self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                                        self.storm_control_broadcast_enabled = YLeaf(YType.boolean, "storm-control-broadcast-enabled")

                                        self.storm_control_broadcast_rate_unit = YLeaf(YType.enumeration, "storm-control-broadcast-rate-unit")

                                        self.storm_control_multicast_enabled = YLeaf(YType.boolean, "storm-control-multicast-enabled")

                                        self.storm_control_multicast_rate_unit = YLeaf(YType.enumeration, "storm-control-multicast-rate-unit")

                                        self.storm_control_unicast_enabled = YLeaf(YType.boolean, "storm-control-unicast-enabled")

                                        self.storm_control_unicast_rate_unit = YLeaf(YType.enumeration, "storm-control-unicast-rate-unit")

                                        self.stp_participating = YLeaf(YType.boolean, "stp-participating")

                                        self.unknown_unicast_flooding_disabled = YLeaf(YType.boolean, "unknown-unicast-flooding-disabled")

                                        self.feature = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("admin_disabled",
                                                        "bvi_configured",
                                                        "dhcp_enabled",
                                                        "dhcp_trusted",
                                                        "flood_unknown_unicast_enabled",
                                                        "flooding_disabled",
                                                        "host_routing_enabled",
                                                        "igmp_flood_forward_enabled",
                                                        "igmp_mroute_port_enabled",
                                                        "igmp_route_guard_enabled",
                                                        "igmp_snoop_enabled",
                                                        "igmp_snoop_profile_enabled",
                                                        "is_bvi_up",
                                                        "is_dai_addr_validation_destination_mac_enabled",
                                                        "is_dai_addr_validation_ipv4_enabled",
                                                        "is_dai_addr_validation_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_evpn_cw_disable",
                                                        "is_evpn_enabled",
                                                        "is_evpn_flow_label",
                                                        "is_igmp_snoop_enabled",
                                                        "is_ipsg_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "is_p2mp_pw_enabled",
                                                        "is_pbbevpn_enabled",
                                                        "is_swmac_learning",
                                                        "is_vni_enabled",
                                                        "is_vpls_flood_optimization_enabled",
                                                        "mac_aging_time",
                                                        "mac_aging_type",
                                                        "mac_learning_disabled",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification_type",
                                                        "mac_port_down_flush_disabled",
                                                        "mac_secure_action",
                                                        "mld_flood_forward_enabled",
                                                        "mld_mroute_port_enabled",
                                                        "mld_route_guard_enabled",
                                                        "mld_snoop_enabled",
                                                        "mld_snoop_profile_enabled",
                                                        "msti",
                                                        "mtu",
                                                        "number_of_macs",
                                                        "nv_satellite_offload_ipv4_multicast_disabled",
                                                        "storm_control_broadcast_enabled",
                                                        "storm_control_broadcast_rate_unit",
                                                        "storm_control_multicast_enabled",
                                                        "storm_control_multicast_rate_unit",
                                                        "storm_control_unicast_enabled",
                                                        "storm_control_unicast_rate_unit",
                                                        "stp_participating",
                                                        "unknown_unicast_flooding_disabled") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation, self).__setattr__(name, value)


                                    class Feature(Entity):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:   :py:class:`L2FibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeature>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature, self).__init__()

                                            self.yang_name = "feature"
                                            self.yang_parent_name = "operational-information"

                                            self.feature_type = YLeaf(YType.enumeration, "feature-type")

                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self._children_name_map["dhcp"] = "dhcp"
                                            self._children_yang_names.add("dhcp")

                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self._children_name_map["igmp"] = "igmp"
                                            self._children_yang_names.add("igmp")

                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self
                                            self._children_name_map["mld"] = "mld"
                                            self._children_yang_names.add("mld")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("feature_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature, self).__setattr__(name, value)


                                        class Dhcp(Entity):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                                self.yang_name = "dhcp"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dhcp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix


                                        class Igmp(Entity):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                                self.yang_name = "igmp"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "igmp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix


                                        class Mld(Entity):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                                self.yang_name = "mld"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mld" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.feature_type.is_set or
                                                (self.dhcp is not None and self.dhcp.has_data()) or
                                                (self.igmp is not None and self.igmp.has_data()) or
                                                (self.mld is not None and self.mld.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.feature_type.yfilter != YFilter.not_set or
                                                (self.dhcp is not None and self.dhcp.has_operation()) or
                                                (self.igmp is not None and self.igmp.has_operation()) or
                                                (self.mld is not None and self.mld.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "feature" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.feature_type.is_set or self.feature_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.feature_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dhcp"):
                                                if (self.dhcp is None):
                                                    self.dhcp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                                    self.dhcp.parent = self
                                                    self._children_name_map["dhcp"] = "dhcp"
                                                return self.dhcp

                                            if (child_yang_name == "igmp"):
                                                if (self.igmp is None):
                                                    self.igmp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                                    self.igmp.parent = self
                                                    self._children_name_map["igmp"] = "igmp"
                                                return self.igmp

                                            if (child_yang_name == "mld"):
                                                if (self.mld is None):
                                                    self.mld = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                                    self.mld.parent = self
                                                    self._children_name_map["mld"] = "mld"
                                                return self.mld

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dhcp" or name == "igmp" or name == "mld" or name == "feature-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "feature-type"):
                                                self.feature_type = value
                                                self.feature_type.value_namespace = name_space
                                                self.feature_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.feature:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.admin_disabled.is_set or
                                            self.bvi_configured.is_set or
                                            self.dhcp_enabled.is_set or
                                            self.dhcp_trusted.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flooding_disabled.is_set or
                                            self.host_routing_enabled.is_set or
                                            self.igmp_flood_forward_enabled.is_set or
                                            self.igmp_mroute_port_enabled.is_set or
                                            self.igmp_route_guard_enabled.is_set or
                                            self.igmp_snoop_enabled.is_set or
                                            self.igmp_snoop_profile_enabled.is_set or
                                            self.is_bvi_up.is_set or
                                            self.is_dai_addr_validation_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validation_ipv4_enabled.is_set or
                                            self.is_dai_addr_validation_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_evpn_cw_disable.is_set or
                                            self.is_evpn_enabled.is_set or
                                            self.is_evpn_flow_label.is_set or
                                            self.is_igmp_snoop_enabled.is_set or
                                            self.is_ipsg_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.is_p2mp_pw_enabled.is_set or
                                            self.is_pbbevpn_enabled.is_set or
                                            self.is_swmac_learning.is_set or
                                            self.is_vni_enabled.is_set or
                                            self.is_vpls_flood_optimization_enabled.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_aging_type.is_set or
                                            self.mac_learning_disabled.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification_type.is_set or
                                            self.mac_port_down_flush_disabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_flood_forward_enabled.is_set or
                                            self.mld_mroute_port_enabled.is_set or
                                            self.mld_route_guard_enabled.is_set or
                                            self.mld_snoop_enabled.is_set or
                                            self.mld_snoop_profile_enabled.is_set or
                                            self.msti.is_set or
                                            self.mtu.is_set or
                                            self.number_of_macs.is_set or
                                            self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                                            self.storm_control_broadcast_enabled.is_set or
                                            self.storm_control_broadcast_rate_unit.is_set or
                                            self.storm_control_multicast_enabled.is_set or
                                            self.storm_control_multicast_rate_unit.is_set or
                                            self.storm_control_unicast_enabled.is_set or
                                            self.storm_control_unicast_rate_unit.is_set or
                                            self.stp_participating.is_set or
                                            self.unknown_unicast_flooding_disabled.is_set)

                                    def has_operation(self):
                                        for c in self.feature:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.admin_disabled.yfilter != YFilter.not_set or
                                            self.bvi_configured.yfilter != YFilter.not_set or
                                            self.dhcp_enabled.yfilter != YFilter.not_set or
                                            self.dhcp_trusted.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flooding_disabled.yfilter != YFilter.not_set or
                                            self.host_routing_enabled.yfilter != YFilter.not_set or
                                            self.igmp_flood_forward_enabled.yfilter != YFilter.not_set or
                                            self.igmp_mroute_port_enabled.yfilter != YFilter.not_set or
                                            self.igmp_route_guard_enabled.yfilter != YFilter.not_set or
                                            self.igmp_snoop_enabled.yfilter != YFilter.not_set or
                                            self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set or
                                            self.is_bvi_up.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_evpn_cw_disable.yfilter != YFilter.not_set or
                                            self.is_evpn_enabled.yfilter != YFilter.not_set or
                                            self.is_evpn_flow_label.yfilter != YFilter.not_set or
                                            self.is_igmp_snoop_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_p2mp_pw_enabled.yfilter != YFilter.not_set or
                                            self.is_pbbevpn_enabled.yfilter != YFilter.not_set or
                                            self.is_swmac_learning.yfilter != YFilter.not_set or
                                            self.is_vni_enabled.yfilter != YFilter.not_set or
                                            self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_aging_type.yfilter != YFilter.not_set or
                                            self.mac_learning_disabled.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification_type.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_disabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_flood_forward_enabled.yfilter != YFilter.not_set or
                                            self.mld_mroute_port_enabled.yfilter != YFilter.not_set or
                                            self.mld_route_guard_enabled.yfilter != YFilter.not_set or
                                            self.mld_snoop_enabled.yfilter != YFilter.not_set or
                                            self.mld_snoop_profile_enabled.yfilter != YFilter.not_set or
                                            self.msti.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.number_of_macs.yfilter != YFilter.not_set or
                                            self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                                            self.storm_control_broadcast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set or
                                            self.storm_control_multicast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set or
                                            self.storm_control_unicast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set or
                                            self.stp_participating.yfilter != YFilter.not_set or
                                            self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "operational-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.admin_disabled.is_set or self.admin_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.admin_disabled.get_name_leafdata())
                                        if (self.bvi_configured.is_set or self.bvi_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bvi_configured.get_name_leafdata())
                                        if (self.dhcp_enabled.is_set or self.dhcp_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcp_enabled.get_name_leafdata())
                                        if (self.dhcp_trusted.is_set or self.dhcp_trusted.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcp_trusted.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flooding_disabled.is_set or self.flooding_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flooding_disabled.get_name_leafdata())
                                        if (self.host_routing_enabled.is_set or self.host_routing_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.host_routing_enabled.get_name_leafdata())
                                        if (self.igmp_flood_forward_enabled.is_set or self.igmp_flood_forward_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_flood_forward_enabled.get_name_leafdata())
                                        if (self.igmp_mroute_port_enabled.is_set or self.igmp_mroute_port_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_mroute_port_enabled.get_name_leafdata())
                                        if (self.igmp_route_guard_enabled.is_set or self.igmp_route_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_route_guard_enabled.get_name_leafdata())
                                        if (self.igmp_snoop_enabled.is_set or self.igmp_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_snoop_enabled.get_name_leafdata())
                                        if (self.igmp_snoop_profile_enabled.is_set or self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_snoop_profile_enabled.get_name_leafdata())
                                        if (self.is_bvi_up.is_set or self.is_bvi_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_bvi_up.get_name_leafdata())
                                        if (self.is_dai_addr_validation_destination_mac_enabled.is_set or self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validation_ipv4_enabled.is_set or self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validation_source_mac_enabled.is_set or self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_evpn_cw_disable.is_set or self.is_evpn_cw_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_cw_disable.get_name_leafdata())
                                        if (self.is_evpn_enabled.is_set or self.is_evpn_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_enabled.get_name_leafdata())
                                        if (self.is_evpn_flow_label.is_set or self.is_evpn_flow_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_flow_label.get_name_leafdata())
                                        if (self.is_igmp_snoop_enabled.is_set or self.is_igmp_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_igmp_snoop_enabled.get_name_leafdata())
                                        if (self.is_ipsg_enabled.is_set or self.is_ipsg_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown.is_set or self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.is_p2mp_pw_enabled.is_set or self.is_p2mp_pw_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_p2mp_pw_enabled.get_name_leafdata())
                                        if (self.is_pbbevpn_enabled.is_set or self.is_pbbevpn_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pbbevpn_enabled.get_name_leafdata())
                                        if (self.is_swmac_learning.is_set or self.is_swmac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_swmac_learning.get_name_leafdata())
                                        if (self.is_vni_enabled.is_set or self.is_vni_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_vni_enabled.get_name_leafdata())
                                        if (self.is_vpls_flood_optimization_enabled.is_set or self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_vpls_flood_optimization_enabled.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_aging_type.is_set or self.mac_aging_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_type.get_name_leafdata())
                                        if (self.mac_learning_disabled.is_set or self.mac_learning_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning_disabled.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification_type.is_set or self.mac_limit_notification_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification_type.get_name_leafdata())
                                        if (self.mac_port_down_flush_disabled.is_set or self.mac_port_down_flush_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_disabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_flood_forward_enabled.is_set or self.mld_flood_forward_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_flood_forward_enabled.get_name_leafdata())
                                        if (self.mld_mroute_port_enabled.is_set or self.mld_mroute_port_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_mroute_port_enabled.get_name_leafdata())
                                        if (self.mld_route_guard_enabled.is_set or self.mld_route_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_route_guard_enabled.get_name_leafdata())
                                        if (self.mld_snoop_enabled.is_set or self.mld_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_snoop_enabled.get_name_leafdata())
                                        if (self.mld_snoop_profile_enabled.is_set or self.mld_snoop_profile_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_snoop_profile_enabled.get_name_leafdata())
                                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msti.get_name_leafdata())
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.number_of_macs.is_set or self.number_of_macs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_macs.get_name_leafdata())
                                        if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                                        if (self.storm_control_broadcast_enabled.is_set or self.storm_control_broadcast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_broadcast_enabled.get_name_leafdata())
                                        if (self.storm_control_broadcast_rate_unit.is_set or self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_broadcast_rate_unit.get_name_leafdata())
                                        if (self.storm_control_multicast_enabled.is_set or self.storm_control_multicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_multicast_enabled.get_name_leafdata())
                                        if (self.storm_control_multicast_rate_unit.is_set or self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_multicast_rate_unit.get_name_leafdata())
                                        if (self.storm_control_unicast_enabled.is_set or self.storm_control_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_unicast_enabled.get_name_leafdata())
                                        if (self.storm_control_unicast_rate_unit.is_set or self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_unicast_rate_unit.get_name_leafdata())
                                        if (self.stp_participating.is_set or self.stp_participating.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.stp_participating.get_name_leafdata())
                                        if (self.unknown_unicast_flooding_disabled.is_set or self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unknown_unicast_flooding_disabled.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "feature"):
                                            for c in self.feature:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.feature.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "feature" or name == "admin-disabled" or name == "bvi-configured" or name == "dhcp-enabled" or name == "dhcp-trusted" or name == "flood-unknown-unicast-enabled" or name == "flooding-disabled" or name == "host-routing-enabled" or name == "igmp-flood-forward-enabled" or name == "igmp-mroute-port-enabled" or name == "igmp-route-guard-enabled" or name == "igmp-snoop-enabled" or name == "igmp-snoop-profile-enabled" or name == "is-bvi-up" or name == "is-dai-addr-validation-destination-mac-enabled" or name == "is-dai-addr-validation-ipv4-enabled" or name == "is-dai-addr-validation-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-evpn-cw-disable" or name == "is-evpn-enabled" or name == "is-evpn-flow-label" or name == "is-igmp-snoop-enabled" or name == "is-ipsg-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "is-p2mp-pw-enabled" or name == "is-pbbevpn-enabled" or name == "is-swmac-learning" or name == "is-vni-enabled" or name == "is-vpls-flood-optimization-enabled" or name == "mac-aging-time" or name == "mac-aging-type" or name == "mac-learning-disabled" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification-type" or name == "mac-port-down-flush-disabled" or name == "mac-secure-action" or name == "mld-flood-forward-enabled" or name == "mld-mroute-port-enabled" or name == "mld-route-guard-enabled" or name == "mld-snoop-enabled" or name == "mld-snoop-profile-enabled" or name == "msti" or name == "mtu" or name == "number-of-macs" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "storm-control-broadcast-enabled" or name == "storm-control-broadcast-rate-unit" or name == "storm-control-multicast-enabled" or name == "storm-control-multicast-rate-unit" or name == "storm-control-unicast-enabled" or name == "storm-control-unicast-rate-unit" or name == "stp-participating" or name == "unknown-unicast-flooding-disabled"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "admin-disabled"):
                                            self.admin_disabled = value
                                            self.admin_disabled.value_namespace = name_space
                                            self.admin_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bvi-configured"):
                                            self.bvi_configured = value
                                            self.bvi_configured.value_namespace = name_space
                                            self.bvi_configured.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcp-enabled"):
                                            self.dhcp_enabled = value
                                            self.dhcp_enabled.value_namespace = name_space
                                            self.dhcp_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcp-trusted"):
                                            self.dhcp_trusted = value
                                            self.dhcp_trusted.value_namespace = name_space
                                            self.dhcp_trusted.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flooding-disabled"):
                                            self.flooding_disabled = value
                                            self.flooding_disabled.value_namespace = name_space
                                            self.flooding_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "host-routing-enabled"):
                                            self.host_routing_enabled = value
                                            self.host_routing_enabled.value_namespace = name_space
                                            self.host_routing_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-flood-forward-enabled"):
                                            self.igmp_flood_forward_enabled = value
                                            self.igmp_flood_forward_enabled.value_namespace = name_space
                                            self.igmp_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-mroute-port-enabled"):
                                            self.igmp_mroute_port_enabled = value
                                            self.igmp_mroute_port_enabled.value_namespace = name_space
                                            self.igmp_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-route-guard-enabled"):
                                            self.igmp_route_guard_enabled = value
                                            self.igmp_route_guard_enabled.value_namespace = name_space
                                            self.igmp_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-snoop-enabled"):
                                            self.igmp_snoop_enabled = value
                                            self.igmp_snoop_enabled.value_namespace = name_space
                                            self.igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-snoop-profile-enabled"):
                                            self.igmp_snoop_profile_enabled = value
                                            self.igmp_snoop_profile_enabled.value_namespace = name_space
                                            self.igmp_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-bvi-up"):
                                            self.is_bvi_up = value
                                            self.is_bvi_up.value_namespace = name_space
                                            self.is_bvi_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-destination-mac-enabled"):
                                            self.is_dai_addr_validation_destination_mac_enabled = value
                                            self.is_dai_addr_validation_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-ipv4-enabled"):
                                            self.is_dai_addr_validation_ipv4_enabled = value
                                            self.is_dai_addr_validation_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-source-mac-enabled"):
                                            self.is_dai_addr_validation_source_mac_enabled = value
                                            self.is_dai_addr_validation_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-cw-disable"):
                                            self.is_evpn_cw_disable = value
                                            self.is_evpn_cw_disable.value_namespace = name_space
                                            self.is_evpn_cw_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-enabled"):
                                            self.is_evpn_enabled = value
                                            self.is_evpn_enabled.value_namespace = name_space
                                            self.is_evpn_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-flow-label"):
                                            self.is_evpn_flow_label = value
                                            self.is_evpn_flow_label.value_namespace = name_space
                                            self.is_evpn_flow_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-igmp-snoop-enabled"):
                                            self.is_igmp_snoop_enabled = value
                                            self.is_igmp_snoop_enabled.value_namespace = name_space
                                            self.is_igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-enabled"):
                                            self.is_ipsg_enabled = value
                                            self.is_ipsg_enabled.value_namespace = name_space
                                            self.is_ipsg_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown"):
                                            self.is_mac_secure_accept_shutdown = value
                                            self.is_mac_secure_accept_shutdown.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-p2mp-pw-enabled"):
                                            self.is_p2mp_pw_enabled = value
                                            self.is_p2mp_pw_enabled.value_namespace = name_space
                                            self.is_p2mp_pw_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-pbbevpn-enabled"):
                                            self.is_pbbevpn_enabled = value
                                            self.is_pbbevpn_enabled.value_namespace = name_space
                                            self.is_pbbevpn_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-swmac-learning"):
                                            self.is_swmac_learning = value
                                            self.is_swmac_learning.value_namespace = name_space
                                            self.is_swmac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-vni-enabled"):
                                            self.is_vni_enabled = value
                                            self.is_vni_enabled.value_namespace = name_space
                                            self.is_vni_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-vpls-flood-optimization-enabled"):
                                            self.is_vpls_flood_optimization_enabled = value
                                            self.is_vpls_flood_optimization_enabled.value_namespace = name_space
                                            self.is_vpls_flood_optimization_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-type"):
                                            self.mac_aging_type = value
                                            self.mac_aging_type.value_namespace = name_space
                                            self.mac_aging_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning-disabled"):
                                            self.mac_learning_disabled = value
                                            self.mac_learning_disabled.value_namespace = name_space
                                            self.mac_learning_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification-type"):
                                            self.mac_limit_notification_type = value
                                            self.mac_limit_notification_type.value_namespace = name_space
                                            self.mac_limit_notification_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-disabled"):
                                            self.mac_port_down_flush_disabled = value
                                            self.mac_port_down_flush_disabled.value_namespace = name_space
                                            self.mac_port_down_flush_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-flood-forward-enabled"):
                                            self.mld_flood_forward_enabled = value
                                            self.mld_flood_forward_enabled.value_namespace = name_space
                                            self.mld_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-mroute-port-enabled"):
                                            self.mld_mroute_port_enabled = value
                                            self.mld_mroute_port_enabled.value_namespace = name_space
                                            self.mld_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-route-guard-enabled"):
                                            self.mld_route_guard_enabled = value
                                            self.mld_route_guard_enabled.value_namespace = name_space
                                            self.mld_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-snoop-enabled"):
                                            self.mld_snoop_enabled = value
                                            self.mld_snoop_enabled.value_namespace = name_space
                                            self.mld_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-snoop-profile-enabled"):
                                            self.mld_snoop_profile_enabled = value
                                            self.mld_snoop_profile_enabled.value_namespace = name_space
                                            self.mld_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msti"):
                                            self.msti = value
                                            self.msti.value_namespace = name_space
                                            self.msti.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-macs"):
                                            self.number_of_macs = value
                                            self.number_of_macs.value_namespace = name_space
                                            self.number_of_macs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                                            self.nv_satellite_offload_ipv4_multicast_disabled = value
                                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-broadcast-enabled"):
                                            self.storm_control_broadcast_enabled = value
                                            self.storm_control_broadcast_enabled.value_namespace = name_space
                                            self.storm_control_broadcast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-broadcast-rate-unit"):
                                            self.storm_control_broadcast_rate_unit = value
                                            self.storm_control_broadcast_rate_unit.value_namespace = name_space
                                            self.storm_control_broadcast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-multicast-enabled"):
                                            self.storm_control_multicast_enabled = value
                                            self.storm_control_multicast_enabled.value_namespace = name_space
                                            self.storm_control_multicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-multicast-rate-unit"):
                                            self.storm_control_multicast_rate_unit = value
                                            self.storm_control_multicast_rate_unit.value_namespace = name_space
                                            self.storm_control_multicast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-unicast-enabled"):
                                            self.storm_control_unicast_enabled = value
                                            self.storm_control_unicast_enabled.value_namespace = name_space
                                            self.storm_control_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-unicast-rate-unit"):
                                            self.storm_control_unicast_rate_unit = value
                                            self.storm_control_unicast_rate_unit.value_namespace = name_space
                                            self.storm_control_unicast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "stp-participating"):
                                            self.stp_participating = value
                                            self.stp_participating.value_namespace = name_space
                                            self.stp_participating.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unknown-unicast-flooding-disabled"):
                                            self.unknown_unicast_flooding_disabled = value
                                            self.unknown_unicast_flooding_disabled.value_namespace = name_space
                                            self.unknown_unicast_flooding_disabled.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        (self.operational_information is not None and self.operational_information.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        (self.operational_information is not None and self.operational_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "oper" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "operational-information"):
                                        if (self.operational_information is None):
                                            self.operational_information = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation()
                                            self.operational_information.parent = self
                                            self._children_name_map["operational_information"] = "operational-information"
                                        return self.operational_information

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "operational-information" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix


                            class P2Mp(Entity):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\:  bool
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:   :py:class:`L2VpnPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPtree>`
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.P2Mp, self).__init__()

                                    self.yang_name = "p2mp"
                                    self.yang_parent_name = "bp"

                                    self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                                    self.lsm_id = YLeaf(YType.uint32, "lsm-id")

                                    self.p2mp_id = YLeaf(YType.uint16, "p2mp-id")

                                    self.ptree_owner_lmrib = YLeaf(YType.boolean, "ptree-owner-lmrib")

                                    self.ptree_type = YLeaf(YType.enumeration, "ptree-type")

                                    self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("extended_tunnel_id",
                                                    "lsm_id",
                                                    "p2mp_id",
                                                    "ptree_owner_lmrib",
                                                    "ptree_type",
                                                    "tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.P2Mp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.P2Mp, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.extended_tunnel_id.is_set or
                                        self.lsm_id.is_set or
                                        self.p2mp_id.is_set or
                                        self.ptree_owner_lmrib.is_set or
                                        self.ptree_type.is_set or
                                        self.tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.lsm_id.yfilter != YFilter.not_set or
                                        self.p2mp_id.yfilter != YFilter.not_set or
                                        self.ptree_owner_lmrib.yfilter != YFilter.not_set or
                                        self.ptree_type.yfilter != YFilter.not_set or
                                        self.tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                                    if (self.lsm_id.is_set or self.lsm_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsm_id.get_name_leafdata())
                                    if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                                    if (self.ptree_owner_lmrib.is_set or self.ptree_owner_lmrib.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ptree_owner_lmrib.get_name_leafdata())
                                    if (self.ptree_type.is_set or self.ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ptree_type.get_name_leafdata())
                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "extended-tunnel-id" or name == "lsm-id" or name == "p2mp-id" or name == "ptree-owner-lmrib" or name == "ptree-type" or name == "tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "extended-tunnel-id"):
                                        self.extended_tunnel_id = value
                                        self.extended_tunnel_id.value_namespace = name_space
                                        self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsm-id"):
                                        self.lsm_id = value
                                        self.lsm_id.value_namespace = name_space
                                        self.lsm_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "p2mp-id"):
                                        self.p2mp_id = value
                                        self.p2mp_id.value_namespace = name_space
                                        self.p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ptree-owner-lmrib"):
                                        self.ptree_owner_lmrib = value
                                        self.ptree_owner_lmrib.value_namespace = name_space
                                        self.ptree_owner_lmrib.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ptree-type"):
                                        self.ptree_type = value
                                        self.ptree_type.value_namespace = name_space
                                        self.ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-id"):
                                        self.tunnel_id = value
                                        self.tunnel_id.value_namespace = name_space
                                        self.tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bridge_id.is_set or
                                    self.learn_key.is_set or
                                    self.msti_pointer.is_set or
                                    self.mvrp_sequence_number.is_set or
                                    self.segment_type.is_set or
                                    self.shg_id.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.oper is not None and self.oper.has_data()) or
                                    (self.p2mp is not None and self.p2mp.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bridge_id.yfilter != YFilter.not_set or
                                    self.learn_key.yfilter != YFilter.not_set or
                                    self.msti_pointer.yfilter != YFilter.not_set or
                                    self.mvrp_sequence_number.yfilter != YFilter.not_set or
                                    self.segment_type.yfilter != YFilter.not_set or
                                    self.shg_id.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.oper is not None and self.oper.has_operation()) or
                                    (self.p2mp is not None and self.p2mp.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bp" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_id.get_name_leafdata())
                                if (self.learn_key.is_set or self.learn_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.learn_key.get_name_leafdata())
                                if (self.msti_pointer.is_set or self.msti_pointer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_pointer.get_name_leafdata())
                                if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())
                                if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_type.get_name_leafdata())
                                if (self.shg_id.is_set or self.shg_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shg_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "oper"):
                                    if (self.oper is None):
                                        self.oper = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper()
                                        self.oper.parent = self
                                        self._children_name_map["oper"] = "oper"
                                    return self.oper

                                if (child_yang_name == "p2mp"):
                                    if (self.p2mp is None):
                                        self.p2mp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.P2Mp()
                                        self.p2mp.parent = self
                                        self._children_name_map["p2mp"] = "p2mp"
                                    return self.p2mp

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "oper" or name == "p2mp" or name == "bridge-id" or name == "learn-key" or name == "msti-pointer" or name == "mvrp-sequence-number" or name == "segment-type" or name == "shg-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bridge-id"):
                                    self.bridge_id = value
                                    self.bridge_id.value_namespace = name_space
                                    self.bridge_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "learn-key"):
                                    self.learn_key = value
                                    self.learn_key.value_namespace = name_space
                                    self.learn_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-pointer"):
                                    self.msti_pointer = value
                                    self.msti_pointer.value_namespace = name_space
                                    self.msti_pointer.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvrp-sequence-number"):
                                    self.mvrp_sequence_number = value
                                    self.mvrp_sequence_number.value_namespace = name_space
                                    self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-type"):
                                    self.segment_type = value
                                    self.segment_type.value_namespace = name_space
                                    self.segment_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shg-id"):
                                    self.shg_id = value
                                    self.shg_id.value_namespace = name_space
                                    self.shg_id.value_namespace_prefix = name_space_prefix


                        class Fxs(Entity):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs, self).__init__()

                                self.yang_name = "fxs"
                                self.yang_parent_name = "segment2"

                                self.fxs_id = YLeaf(YType.uint32, "fxs-id")

                                self.segment_type = YLeaf(YType.uint8, "segment-type")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fxs_id",
                                                "segment_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "fxs"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.fxs_id.is_set or
                                    self.segment_type.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fxs_id.yfilter != YFilter.not_set or
                                    self.segment_type.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "fxs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fxs_id.is_set or self.fxs_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxs_id.get_name_leafdata())
                                if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxs-id" or name == "segment-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fxs-id"):
                                    self.fxs_id = value
                                    self.fxs_id.value_namespace = name_space
                                    self.fxs_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-type"):
                                    self.segment_type = value
                                    self.segment_type.value_namespace = name_space
                                    self.segment_type.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBal>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment2"

                                self.ac_id = YLeaf(YType.uint32, "ac-id")

                                self.active = YLeaf(YType.boolean, "active")

                                self.backup_configured = YLeaf(YType.boolean, "backup-configured")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.context = YLeaf(YType.uint16, "context")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.global_id = YLeaf(YType.uint32, "global-id")

                                self.group_id = YLeaf(YType.uint32, "group-id")

                                self.group_state = YLeaf(YType.enumeration, "group-state")

                                self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                                self.pw_load_balance_type = YLeaf(YType.enumeration, "pw-load-balance-type")

                                self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                self.sequence_resync_threshold = YLeaf(YType.uint16, "sequence-resync-threshold")

                                self.signal_capability_flags = YLeaf(YType.uint32, "signal-capability-flags")

                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._children_yang_names.add("backup-pseudo-wire")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                self._children_yang_names.add("pseudo-wire-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ac_id",
                                                "active",
                                                "backup_configured",
                                                "bound",
                                                "context",
                                                "forward_class",
                                                "global_id",
                                                "group_id",
                                                "group_state",
                                                "grouping_supported",
                                                "next_hop_valid",
                                                "pseudo_wire_id_type",
                                                "pw_flow_label_tx",
                                                "pw_id",
                                                "pw_load_balance_type",
                                                "redundancy_role",
                                                "sequence_resync_threshold",
                                                "signal_capability_flags") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"
                                    self._children_yang_names.add("l2tp")

                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._children_yang_names.add("l2tp-ipv6-ts")

                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"
                                    self._children_yang_names.add("l2tpv2")

                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"
                                    self._children_yang_names.add("mpls")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion, self).__setattr__(name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix


                                class L2Tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_mtu",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_mtu.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "path-mtu" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix


                                class L2Tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.protocol = YLeaf(YType.uint16, "protocol")

                                        self.pw_flags = YLeaf(YType.uint8, "pw-flags")

                                        self.rem_udp_port = YLeaf(YType.uint16, "rem-udp-port")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop_address",
                                                        "path_mtu",
                                                        "protocol",
                                                        "pw_flags",
                                                        "rem_udp_port",
                                                        "source_address",
                                                        "tos_val",
                                                        "ttl",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.next_hop_address.is_set or
                                            self.path_mtu.is_set or
                                            self.protocol.is_set or
                                            self.pw_flags.is_set or
                                            self.rem_udp_port.is_set or
                                            self.source_address.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            self.xconnect_id.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pw_flags.yfilter != YFilter.not_set or
                                            self.rem_udp_port.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv2" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pw_flags.is_set or self.pw_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flags.get_name_leafdata())
                                        if (self.rem_udp_port.is_set or self.rem_udp_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_udp_port.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "next-hop-address" or name == "path-mtu" or name == "protocol" or name == "pw-flags" or name == "rem-udp-port" or name == "source-address" or name == "tos-val" or name == "ttl" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop-address"):
                                            self.next_hop_address = value
                                            self.next_hop_address.value_namespace = name_space
                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flags"):
                                            self.pw_flags = value
                                            self.pw_flags.value_namespace = name_space
                                            self.pw_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-udp-port"):
                                            self.rem_udp_port = value
                                            self.rem_udp_port.value_namespace = name_space
                                            self.rem_udp_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class L2TpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address",
                                                        "path_mtu",
                                                        "remote_address",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.secondary_cookie_high_value = YLeaf(YType.uint32, "secondary-cookie-high-value")

                                            self.secondary_cookie_low_value = YLeaf(YType.uint32, "secondary-cookie-low-value")

                                            self.secondary_cookie_size = YLeaf(YType.uint8, "secondary-cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "secondary_cookie_high_value",
                                                            "secondary_cookie_low_value",
                                                            "secondary_cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.secondary_cookie_high_value.is_set or
                                                self.secondary_cookie_low_value.is_set or
                                                self.secondary_cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.secondary_cookie_high_value.is_set or self.secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_high_value.get_name_leafdata())
                                            if (self.secondary_cookie_low_value.is_set or self.secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_low_value.get_name_leafdata())
                                            if (self.secondary_cookie_size.is_set or self.secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "secondary-cookie-high-value" or name == "secondary-cookie-low-value" or name == "secondary-cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-high-value"):
                                                self.secondary_cookie_high_value = value
                                                self.secondary_cookie_high_value.value_namespace = name_space
                                                self.secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-low-value"):
                                                self.secondary_cookie_low_value = value
                                                self.secondary_cookie_low_value.value_namespace = name_space
                                                self.secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-size"):
                                                self.secondary_cookie_size = value
                                                self.secondary_cookie_size.value_namespace = name_space
                                                self.secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.local_address.is_set or
                                            self.path_mtu.is_set or
                                            self.remote_address.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp-ipv6-ts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "local-address" or name == "path-mtu" or name == "remote-address" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        (self.l2tp is not None and self.l2tp.has_data()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_data()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_data()) or
                                        (self.mpls is not None and self.mpls.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        (self.l2tp is not None and self.l2tp.has_operation()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_operation()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_operation()) or
                                        (self.mpls is not None and self.mpls.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudo-wire-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2tp"):
                                        if (self.l2tp is None):
                                            self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp()
                                            self.l2tp.parent = self
                                            self._children_name_map["l2tp"] = "l2tp"
                                        return self.l2tp

                                    if (child_yang_name == "l2tp-ipv6-ts"):
                                        if (self.l2tp_ipv6_ts is None):
                                            self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                            self.l2tp_ipv6_ts.parent = self
                                            self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                        return self.l2tp_ipv6_ts

                                    if (child_yang_name == "l2tpv2"):
                                        if (self.l2tpv2 is None):
                                            self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                            self.l2tpv2.parent = self
                                            self._children_name_map["l2tpv2"] = "l2tpv2"
                                        return self.l2tpv2

                                    if (child_yang_name == "mpls"):
                                        if (self.mpls is None):
                                            self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                        return self.mpls

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2tp" or name == "l2tp-ipv6-ts" or name == "l2tpv2" or name == "mpls" or name == "data-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.backup_next_hop = YLeaf(YType.str, "backup-next-hop")

                                    self.backup_pseudo_wire_id = YLeaf(YType.uint32, "backup-pseudo-wire-id")

                                    self.backup_pseudo_wire_id_type = YLeaf(YType.enumeration, "backup-pseudo-wire-id-type")

                                    self.bound = YLeaf(YType.boolean, "bound")

                                    self.group_id = YLeaf(YType.uint32, "group-id")

                                    self.group_state = YLeaf(YType.enumeration, "group-state")

                                    self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                    self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                    self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "backup_next_hop",
                                                    "backup_pseudo_wire_id",
                                                    "backup_pseudo_wire_id_type",
                                                    "bound",
                                                    "group_id",
                                                    "group_state",
                                                    "grouping_supported",
                                                    "pw_flow_label_tx",
                                                    "redundancy_role") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.backup_next_hop.is_set or
                                        self.backup_pseudo_wire_id.is_set or
                                        self.backup_pseudo_wire_id_type.is_set or
                                        self.bound.is_set or
                                        self.group_id.is_set or
                                        self.group_state.is_set or
                                        self.grouping_supported.is_set or
                                        self.pw_flow_label_tx.is_set or
                                        self.redundancy_role.is_set or
                                        (self.atom is not None and self.atom.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.backup_next_hop.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set or
                                        self.bound.yfilter != YFilter.not_set or
                                        self.group_id.yfilter != YFilter.not_set or
                                        self.group_state.yfilter != YFilter.not_set or
                                        self.grouping_supported.yfilter != YFilter.not_set or
                                        self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                        self.redundancy_role.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-pseudo-wire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.backup_next_hop.is_set or self.backup_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_next_hop.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id.is_set or self.backup_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id_type.is_set or self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id_type.get_name_leafdata())
                                    if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bound.get_name_leafdata())
                                    if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_id.get_name_leafdata())
                                    if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_state.get_name_leafdata())
                                    if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                    if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                    if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_role.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "active" or name == "backup-next-hop" or name == "backup-pseudo-wire-id" or name == "backup-pseudo-wire-id-type" or name == "bound" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "pw-flow-label-tx" or name == "redundancy-role"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-next-hop"):
                                        self.backup_next_hop = value
                                        self.backup_next_hop.value_namespace = name_space
                                        self.backup_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id"):
                                        self.backup_pseudo_wire_id = value
                                        self.backup_pseudo_wire_id.value_namespace = name_space
                                        self.backup_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id-type"):
                                        self.backup_pseudo_wire_id_type = value
                                        self.backup_pseudo_wire_id_type.value_namespace = name_space
                                        self.backup_pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bound"):
                                        self.bound = value
                                        self.bound.value_namespace = name_space
                                        self.bound.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-id"):
                                        self.group_id = value
                                        self.group_id.value_namespace = name_space
                                        self.group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-state"):
                                        self.group_state = value
                                        self.group_state.value_namespace = name_space
                                        self.group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "grouping-supported"):
                                        self.grouping_supported = value
                                        self.grouping_supported.value_namespace = name_space
                                        self.grouping_supported.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-tx"):
                                        self.pw_flow_label_tx = value
                                        self.pw_flow_label_tx.value_namespace = name_space
                                        self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-role"):
                                        self.redundancy_role = value
                                        self.redundancy_role.value_namespace = name_space
                                        self.redundancy_role.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ac_id.is_set or
                                    self.active.is_set or
                                    self.backup_configured.is_set or
                                    self.bound.is_set or
                                    self.context.is_set or
                                    self.forward_class.is_set or
                                    self.global_id.is_set or
                                    self.group_id.is_set or
                                    self.group_state.is_set or
                                    self.grouping_supported.is_set or
                                    self.next_hop_valid.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_flow_label_tx.is_set or
                                    self.pw_id.is_set or
                                    self.pw_load_balance_type.is_set or
                                    self.redundancy_role.is_set or
                                    self.sequence_resync_threshold.is_set or
                                    self.signal_capability_flags.is_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_data()) or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ac_id.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.backup_configured.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.context.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.global_id.yfilter != YFilter.not_set or
                                    self.group_id.yfilter != YFilter.not_set or
                                    self.group_state.yfilter != YFilter.not_set or
                                    self.grouping_supported.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.pw_load_balance_type.yfilter != YFilter.not_set or
                                    self.redundancy_role.yfilter != YFilter.not_set or
                                    self.sequence_resync_threshold.yfilter != YFilter.not_set or
                                    self.signal_capability_flags.yfilter != YFilter.not_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_operation()) or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ac_id.is_set or self.ac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac_id.get_name_leafdata())
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.backup_configured.is_set or self.backup_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_configured.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.context.is_set or self.context.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.context.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.global_id.is_set or self.global_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_id.get_name_leafdata())
                                if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_id.get_name_leafdata())
                                if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_state.get_name_leafdata())
                                if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.pw_load_balance_type.is_set or self.pw_load_balance_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_load_balance_type.get_name_leafdata())
                                if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_role.get_name_leafdata())
                                if (self.sequence_resync_threshold.is_set or self.sequence_resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_resync_threshold.get_name_leafdata())
                                if (self.signal_capability_flags.is_set or self.signal_capability_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signal_capability_flags.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-pseudo-wire"):
                                    if (self.backup_pseudo_wire is None):
                                        self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire()
                                        self.backup_pseudo_wire.parent = self
                                        self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                    return self.backup_pseudo_wire

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                if (child_yang_name == "pseudo-wire-union"):
                                    if (self.pseudo_wire_union is None):
                                        self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion()
                                        self.pseudo_wire_union.parent = self
                                        self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                    return self.pseudo_wire_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-pseudo-wire" or name == "base" or name == "next-hop" or name == "pseudo-wire-union" or name == "ac-id" or name == "active" or name == "backup-configured" or name == "bound" or name == "context" or name == "forward-class" or name == "global-id" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "next-hop-valid" or name == "pseudo-wire-id-type" or name == "pw-flow-label-tx" or name == "pw-id" or name == "pw-load-balance-type" or name == "redundancy-role" or name == "sequence-resync-threshold" or name == "signal-capability-flags"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ac-id"):
                                    self.ac_id = value
                                    self.ac_id.value_namespace = name_space
                                    self.ac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-configured"):
                                    self.backup_configured = value
                                    self.backup_configured.value_namespace = name_space
                                    self.backup_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "context"):
                                    self.context = value
                                    self.context.value_namespace = name_space
                                    self.context.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "global-id"):
                                    self.global_id = value
                                    self.global_id.value_namespace = name_space
                                    self.global_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-id"):
                                    self.group_id = value
                                    self.group_id.value_namespace = name_space
                                    self.group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-state"):
                                    self.group_state = value
                                    self.group_state.value_namespace = name_space
                                    self.group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "grouping-supported"):
                                    self.grouping_supported = value
                                    self.grouping_supported.value_namespace = name_space
                                    self.grouping_supported.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-tx"):
                                    self.pw_flow_label_tx = value
                                    self.pw_flow_label_tx.value_namespace = name_space
                                    self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-load-balance-type"):
                                    self.pw_load_balance_type = value
                                    self.pw_load_balance_type.value_namespace = name_space
                                    self.pw_load_balance_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-role"):
                                    self.redundancy_role = value
                                    self.redundancy_role.value_namespace = name_space
                                    self.redundancy_role.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-resync-threshold"):
                                    self.sequence_resync_threshold = value
                                    self.sequence_resync_threshold.value_namespace = name_space
                                    self.sequence_resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "signal-capability-flags"):
                                    self.signal_capability_flags = value
                                    self.signal_capability_flags.value_namespace = name_space
                                    self.signal_capability_flags.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.bp is not None and self.bp.has_data()) or
                                (self.fxs is not None and self.fxs.has_data()) or
                                (self.pw is not None and self.pw.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.bp is not None and self.bp.has_operation()) or
                                (self.fxs is not None and self.fxs.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "bp"):
                                if (self.bp is None):
                                    self.bp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp()
                                    self.bp.parent = self
                                    self._children_name_map["bp"] = "bp"
                                return self.bp

                            if (child_yang_name == "fxs"):
                                if (self.fxs is None):
                                    self.fxs = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs()
                                    self.fxs.parent = self
                                    self._children_name_map["fxs"] = "fxs"
                                return self.fxs

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "bp" or name == "fxs" or name == "pw" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.bound.is_set or
                            self.switching_type.is_set or
                            self.xcon_name.is_set or
                            (self.base is not None and self.base.has_data()) or
                            (self.segment1 is not None and self.segment1.has_data()) or
                            (self.segment2 is not None and self.segment2.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.bound.yfilter != YFilter.not_set or
                            self.switching_type.yfilter != YFilter.not_set or
                            self.xcon_name.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()) or
                            (self.segment1 is not None and self.segment1.has_operation()) or
                            (self.segment2 is not None and self.segment2.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fibx-con-local" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bound.get_name_leafdata())
                        if (self.switching_type.is_set or self.switching_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.switching_type.get_name_leafdata())
                        if (self.xcon_name.is_set or self.xcon_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xcon_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        if (child_yang_name == "segment1"):
                            if (self.segment1 is None):
                                self.segment1 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1()
                                self.segment1.parent = self
                                self._children_name_map["segment1"] = "segment1"
                            return self.segment1

                        if (child_yang_name == "segment2"):
                            if (self.segment2 is None):
                                self.segment2 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2()
                                self.segment2.parent = self
                                self._children_name_map["segment2"] = "segment2"
                            return self.segment2

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "segment1" or name == "segment2" or name == "interface-name" or name == "bound" or name == "switching-type" or name == "xcon-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bound"):
                            self.bound = value
                            self.bound.value_namespace = name_space
                            self.bound.value_namespace_prefix = name_space_prefix
                        if(value_path == "switching-type"):
                            self.switching_type = value
                            self.switching_type.value_namespace = name_space
                            self.switching_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "xcon-name"):
                            self.xcon_name = value
                            self.xcon_name.value_namespace = name_space
                            self.xcon_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fibx_con_local:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fibx_con_local:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fibx-con-locals" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fibx-con-local"):
                        for c in self.l2fibx_con_local:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fibx_con_local.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fibx-con-local"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMrouteSummaries(Entity):
                """
                Mroute Summary Table
                
                .. attribute:: l2fib_mroute_summary
                
                	Multicast Summary Information
                	**type**\: list of    :py:class:`L2FibMrouteSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries, self).__init__()

                    self.yang_name = "l2fib-mroute-summaries"
                    self.yang_parent_name = "node"

                    self.l2fib_mroute_summary = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries, self).__setattr__(name, value)


                class L2FibMrouteSummary(Entity):
                    """
                    Multicast Summary Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\:  str
                    
                    	**length:** 0..66
                    
                    .. attribute:: message
                    
                    	Global Message Information
                    	**type**\: list of    :py:class:`Message <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary.Message>`
                    
                    .. attribute:: multicast_update
                    
                    	Multicast Updates
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multicast_update_dropped
                    
                    	Multicast Updates
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_all_delete_drop
                    
                    	Number of Mroutes All Delete droped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_delete_drop
                    
                    	Number of Mroutes Delete droped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_deleted
                    
                    	Number of Mroutes Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroutes_deleted_all
                    
                    	Number of Mroutes All Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_mroute_add
                    
                    	Number of Mroutes Added
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes
                    
                    	Number of Routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes_with_ole_offload
                    
                    	Number of Routes with OleOffload
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_xid
                    
                    	Number of XIDs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_add
                    
                    	Number of XID Added
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_deleted
                    
                    	Number of XID Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_deleted
                    
                    	Stale Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_xid_deleted
                    
                    	Stale XID Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary, self).__init__()

                        self.yang_name = "l2fib-mroute-summary"
                        self.yang_parent_name = "l2fib-mroute-summaries"

                        self.bd_group_name = YLeaf(YType.str, "bd-group-name")

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.bridge_domain_id = YLeaf(YType.uint32, "bridge-domain-id")

                        self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                        self.multicast_update = YLeaf(YType.uint32, "multicast-update")

                        self.multicast_update_dropped = YLeaf(YType.uint32, "multicast-update-dropped")

                        self.number_mroute_all_delete_drop = YLeaf(YType.uint32, "number-mroute-all-delete-drop")

                        self.number_mroute_delete_drop = YLeaf(YType.uint32, "number-mroute-delete-drop")

                        self.number_mroute_deleted = YLeaf(YType.uint32, "number-mroute-deleted")

                        self.number_mroutes_deleted_all = YLeaf(YType.uint32, "number-mroutes-deleted-all")

                        self.number_of_mroute_add = YLeaf(YType.uint32, "number-of-mroute-add")

                        self.number_of_routes = YLeaf(YType.uint32, "number-of-routes")

                        self.number_of_routes_with_ole_offload = YLeaf(YType.uint32, "number-of-routes-with-ole-offload")

                        self.number_of_xid = YLeaf(YType.uint32, "number-of-xid")

                        self.number_xid_add = YLeaf(YType.uint32, "number-xid-add")

                        self.number_xid_deleted = YLeaf(YType.uint32, "number-xid-deleted")

                        self.stale_deleted = YLeaf(YType.uint32, "stale-deleted")

                        self.stale_xid_deleted = YLeaf(YType.uint32, "stale-xid-deleted")

                        self.message = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bd_group_name",
                                        "bd_name",
                                        "bridge_domain_id",
                                        "bridge_domain_name",
                                        "multicast_update",
                                        "multicast_update_dropped",
                                        "number_mroute_all_delete_drop",
                                        "number_mroute_delete_drop",
                                        "number_mroute_deleted",
                                        "number_mroutes_deleted_all",
                                        "number_of_mroute_add",
                                        "number_of_routes",
                                        "number_of_routes_with_ole_offload",
                                        "number_of_xid",
                                        "number_xid_add",
                                        "number_xid_deleted",
                                        "stale_deleted",
                                        "stale_xid_deleted") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary, self).__setattr__(name, value)


                    class Message(Entity):
                        """
                        Global Message Information
                        
                        .. attribute:: information1
                        
                        	Extra info 1
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: information2
                        
                        	Extra info 2
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: messgae_count
                        
                        	number of message
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time
                        
                        	Time string
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary.Message, self).__init__()

                            self.yang_name = "message"
                            self.yang_parent_name = "l2fib-mroute-summary"

                            self.information1 = YLeaf(YType.uint32, "information1")

                            self.information2 = YLeaf(YType.uint32, "information2")

                            self.messgae_count = YLeaf(YType.uint32, "messgae-count")

                            self.time = YLeaf(YType.str, "time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("information1",
                                            "information2",
                                            "messgae_count",
                                            "time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary.Message, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary.Message, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.information1.is_set or
                                self.information2.is_set or
                                self.messgae_count.is_set or
                                self.time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.information1.yfilter != YFilter.not_set or
                                self.information2.yfilter != YFilter.not_set or
                                self.messgae_count.yfilter != YFilter.not_set or
                                self.time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "message" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.information1.is_set or self.information1.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.information1.get_name_leafdata())
                            if (self.information2.is_set or self.information2.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.information2.get_name_leafdata())
                            if (self.messgae_count.is_set or self.messgae_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.messgae_count.get_name_leafdata())
                            if (self.time.is_set or self.time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "information1" or name == "information2" or name == "messgae-count" or name == "time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "information1"):
                                self.information1 = value
                                self.information1.value_namespace = name_space
                                self.information1.value_namespace_prefix = name_space_prefix
                            if(value_path == "information2"):
                                self.information2 = value
                                self.information2.value_namespace = name_space
                                self.information2.value_namespace_prefix = name_space_prefix
                            if(value_path == "messgae-count"):
                                self.messgae_count = value
                                self.messgae_count.value_namespace = name_space
                                self.messgae_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "time"):
                                self.time = value
                                self.time.value_namespace = name_space
                                self.time.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.message:
                            if (c.has_data()):
                                return True
                        return (
                            self.bd_group_name.is_set or
                            self.bd_name.is_set or
                            self.bridge_domain_id.is_set or
                            self.bridge_domain_name.is_set or
                            self.multicast_update.is_set or
                            self.multicast_update_dropped.is_set or
                            self.number_mroute_all_delete_drop.is_set or
                            self.number_mroute_delete_drop.is_set or
                            self.number_mroute_deleted.is_set or
                            self.number_mroutes_deleted_all.is_set or
                            self.number_of_mroute_add.is_set or
                            self.number_of_routes.is_set or
                            self.number_of_routes_with_ole_offload.is_set or
                            self.number_of_xid.is_set or
                            self.number_xid_add.is_set or
                            self.number_xid_deleted.is_set or
                            self.stale_deleted.is_set or
                            self.stale_xid_deleted.is_set)

                    def has_operation(self):
                        for c in self.message:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bd_group_name.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            self.bridge_domain_id.yfilter != YFilter.not_set or
                            self.bridge_domain_name.yfilter != YFilter.not_set or
                            self.multicast_update.yfilter != YFilter.not_set or
                            self.multicast_update_dropped.yfilter != YFilter.not_set or
                            self.number_mroute_all_delete_drop.yfilter != YFilter.not_set or
                            self.number_mroute_delete_drop.yfilter != YFilter.not_set or
                            self.number_mroute_deleted.yfilter != YFilter.not_set or
                            self.number_mroutes_deleted_all.yfilter != YFilter.not_set or
                            self.number_of_mroute_add.yfilter != YFilter.not_set or
                            self.number_of_routes.yfilter != YFilter.not_set or
                            self.number_of_routes_with_ole_offload.yfilter != YFilter.not_set or
                            self.number_of_xid.yfilter != YFilter.not_set or
                            self.number_xid_add.yfilter != YFilter.not_set or
                            self.number_xid_deleted.yfilter != YFilter.not_set or
                            self.stale_deleted.yfilter != YFilter.not_set or
                            self.stale_xid_deleted.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mroute-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bd_group_name.is_set or self.bd_group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_group_name.get_name_leafdata())
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())
                        if (self.bridge_domain_id.is_set or self.bridge_domain_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_id.get_name_leafdata())
                        if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                        if (self.multicast_update.is_set or self.multicast_update.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.multicast_update.get_name_leafdata())
                        if (self.multicast_update_dropped.is_set or self.multicast_update_dropped.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.multicast_update_dropped.get_name_leafdata())
                        if (self.number_mroute_all_delete_drop.is_set or self.number_mroute_all_delete_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_mroute_all_delete_drop.get_name_leafdata())
                        if (self.number_mroute_delete_drop.is_set or self.number_mroute_delete_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_mroute_delete_drop.get_name_leafdata())
                        if (self.number_mroute_deleted.is_set or self.number_mroute_deleted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_mroute_deleted.get_name_leafdata())
                        if (self.number_mroutes_deleted_all.is_set or self.number_mroutes_deleted_all.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_mroutes_deleted_all.get_name_leafdata())
                        if (self.number_of_mroute_add.is_set or self.number_of_mroute_add.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_mroute_add.get_name_leafdata())
                        if (self.number_of_routes.is_set or self.number_of_routes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_routes.get_name_leafdata())
                        if (self.number_of_routes_with_ole_offload.is_set or self.number_of_routes_with_ole_offload.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_routes_with_ole_offload.get_name_leafdata())
                        if (self.number_of_xid.is_set or self.number_of_xid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_xid.get_name_leafdata())
                        if (self.number_xid_add.is_set or self.number_xid_add.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_xid_add.get_name_leafdata())
                        if (self.number_xid_deleted.is_set or self.number_xid_deleted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_xid_deleted.get_name_leafdata())
                        if (self.stale_deleted.is_set or self.stale_deleted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.stale_deleted.get_name_leafdata())
                        if (self.stale_xid_deleted.is_set or self.stale_xid_deleted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.stale_xid_deleted.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "message"):
                            for c in self.message:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary.Message()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.message.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "message" or name == "bd-group-name" or name == "bd-name" or name == "bridge-domain-id" or name == "bridge-domain-name" or name == "multicast-update" or name == "multicast-update-dropped" or name == "number-mroute-all-delete-drop" or name == "number-mroute-delete-drop" or name == "number-mroute-deleted" or name == "number-mroutes-deleted-all" or name == "number-of-mroute-add" or name == "number-of-routes" or name == "number-of-routes-with-ole-offload" or name == "number-of-xid" or name == "number-xid-add" or name == "number-xid-deleted" or name == "stale-deleted" or name == "stale-xid-deleted"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bd-group-name"):
                            self.bd_group_name = value
                            self.bd_group_name.value_namespace = name_space
                            self.bd_group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-id"):
                            self.bridge_domain_id = value
                            self.bridge_domain_id.value_namespace = name_space
                            self.bridge_domain_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-name"):
                            self.bridge_domain_name = value
                            self.bridge_domain_name.value_namespace = name_space
                            self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "multicast-update"):
                            self.multicast_update = value
                            self.multicast_update.value_namespace = name_space
                            self.multicast_update.value_namespace_prefix = name_space_prefix
                        if(value_path == "multicast-update-dropped"):
                            self.multicast_update_dropped = value
                            self.multicast_update_dropped.value_namespace = name_space
                            self.multicast_update_dropped.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-mroute-all-delete-drop"):
                            self.number_mroute_all_delete_drop = value
                            self.number_mroute_all_delete_drop.value_namespace = name_space
                            self.number_mroute_all_delete_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-mroute-delete-drop"):
                            self.number_mroute_delete_drop = value
                            self.number_mroute_delete_drop.value_namespace = name_space
                            self.number_mroute_delete_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-mroute-deleted"):
                            self.number_mroute_deleted = value
                            self.number_mroute_deleted.value_namespace = name_space
                            self.number_mroute_deleted.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-mroutes-deleted-all"):
                            self.number_mroutes_deleted_all = value
                            self.number_mroutes_deleted_all.value_namespace = name_space
                            self.number_mroutes_deleted_all.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-mroute-add"):
                            self.number_of_mroute_add = value
                            self.number_of_mroute_add.value_namespace = name_space
                            self.number_of_mroute_add.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-routes"):
                            self.number_of_routes = value
                            self.number_of_routes.value_namespace = name_space
                            self.number_of_routes.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-routes-with-ole-offload"):
                            self.number_of_routes_with_ole_offload = value
                            self.number_of_routes_with_ole_offload.value_namespace = name_space
                            self.number_of_routes_with_ole_offload.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-xid"):
                            self.number_of_xid = value
                            self.number_of_xid.value_namespace = name_space
                            self.number_of_xid.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-xid-add"):
                            self.number_xid_add = value
                            self.number_xid_add.value_namespace = name_space
                            self.number_xid_add.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-xid-deleted"):
                            self.number_xid_deleted = value
                            self.number_xid_deleted.value_namespace = name_space
                            self.number_xid_deleted.value_namespace_prefix = name_space_prefix
                        if(value_path == "stale-deleted"):
                            self.stale_deleted = value
                            self.stale_deleted.value_namespace = name_space
                            self.stale_deleted.value_namespace_prefix = name_space_prefix
                        if(value_path == "stale-xid-deleted"):
                            self.stale_xid_deleted = value
                            self.stale_xid_deleted.value_namespace = name_space
                            self.stale_xid_deleted.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_mroute_summary:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_mroute_summary:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-mroute-summaries" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-mroute-summary"):
                        for c in self.l2fib_mroute_summary:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_mroute_summary.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-mroute-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMessageSummary(Entity):
                """
                L2FIB Message Summary information
                
                .. attribute:: event_history
                
                	Event history buffer
                	**type**\:   :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory>`
                
                .. attribute:: message
                
                	message
                	**type**\: list of    :py:class:`Message <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.Message>`
                
                .. attribute:: round_trip_delay
                
                	Round\-Trip delay
                	**type**\:   :py:class:`RoundTripDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary, self).__init__()

                    self.yang_name = "l2fib-message-summary"
                    self.yang_parent_name = "node"

                    self.event_history = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory()
                    self.event_history.parent = self
                    self._children_name_map["event_history"] = "event-history"
                    self._children_yang_names.add("event-history")

                    self.round_trip_delay = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay()
                    self.round_trip_delay.parent = self
                    self._children_name_map["round_trip_delay"] = "round-trip-delay"
                    self._children_yang_names.add("round-trip-delay")

                    self.message = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary, self).__setattr__(name, value)


                class EventHistory(Entity):
                    """
                    Event history buffer
                    
                    .. attribute:: event_entry
                    
                    	event entry
                    	**type**\: list of    :py:class:`EventEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory.EventEntry>`
                    
                    .. attribute:: event_neighbor_entry
                    
                    	number of item in the array
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: extra_information1
                    
                    	extra information1
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: extra_information2
                    
                    	extra information2
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory, self).__init__()

                        self.yang_name = "event-history"
                        self.yang_parent_name = "l2fib-message-summary"

                        self.event_neighbor_entry = YLeaf(YType.uint16, "event-neighbor-entry")

                        self.extra_information1 = YLeafList(YType.uint32, "extra-information1")

                        self.extra_information2 = YLeafList(YType.uint32, "extra-information2")

                        self.event_entry = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("event_neighbor_entry",
                                        "extra_information1",
                                        "extra_information2") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory, self).__setattr__(name, value)


                    class EventEntry(Entity):
                        """
                        event entry
                        
                        .. attribute:: event_flags
                        
                        	base flag object
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: event_many
                        
                        	Multiple event instance flag
                        	**type**\:  bool
                        
                        .. attribute:: event_sticky
                        
                        	Unwrittable flag
                        	**type**\:  bool
                        
                        .. attribute:: event_time
                        
                        	The real timestamp of the event
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        .. attribute:: event_type
                        
                        	Event type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory.EventEntry, self).__init__()

                            self.yang_name = "event-entry"
                            self.yang_parent_name = "event-history"

                            self.event_flags = YLeaf(YType.uint32, "event-flags")

                            self.event_many = YLeaf(YType.boolean, "event-many")

                            self.event_sticky = YLeaf(YType.boolean, "event-sticky")

                            self.event_time = YLeaf(YType.str, "event-time")

                            self.event_type = YLeaf(YType.uint8, "event-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_flags",
                                            "event_many",
                                            "event_sticky",
                                            "event_time",
                                            "event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory.EventEntry, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory.EventEntry, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.event_flags.is_set or
                                self.event_many.is_set or
                                self.event_sticky.is_set or
                                self.event_time.is_set or
                                self.event_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_flags.yfilter != YFilter.not_set or
                                self.event_many.yfilter != YFilter.not_set or
                                self.event_sticky.yfilter != YFilter.not_set or
                                self.event_time.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "event-entry" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_flags.is_set or self.event_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_flags.get_name_leafdata())
                            if (self.event_many.is_set or self.event_many.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_many.get_name_leafdata())
                            if (self.event_sticky.is_set or self.event_sticky.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_sticky.get_name_leafdata())
                            if (self.event_time.is_set or self.event_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_time.get_name_leafdata())
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "event-flags" or name == "event-many" or name == "event-sticky" or name == "event-time" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-flags"):
                                self.event_flags = value
                                self.event_flags.value_namespace = name_space
                                self.event_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "event-many"):
                                self.event_many = value
                                self.event_many.value_namespace = name_space
                                self.event_many.value_namespace_prefix = name_space_prefix
                            if(value_path == "event-sticky"):
                                self.event_sticky = value
                                self.event_sticky.value_namespace = name_space
                                self.event_sticky.value_namespace_prefix = name_space_prefix
                            if(value_path == "event-time"):
                                self.event_time = value
                                self.event_time.value_namespace = name_space
                                self.event_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.event_entry:
                            if (c.has_data()):
                                return True
                        for leaf in self.extra_information1.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.extra_information2.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return self.event_neighbor_entry.is_set

                    def has_operation(self):
                        for c in self.event_entry:
                            if (c.has_operation()):
                                return True
                        for leaf in self.extra_information1.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.extra_information2.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.event_neighbor_entry.yfilter != YFilter.not_set or
                            self.extra_information1.yfilter != YFilter.not_set or
                            self.extra_information2.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "event-history" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.event_neighbor_entry.is_set or self.event_neighbor_entry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.event_neighbor_entry.get_name_leafdata())

                        leaf_name_data.extend(self.extra_information1.get_name_leafdata())

                        leaf_name_data.extend(self.extra_information2.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "event-entry"):
                            for c in self.event_entry:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory.EventEntry()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.event_entry.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "event-entry" or name == "event-neighbor-entry" or name == "extra-information1" or name == "extra-information2"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "event-neighbor-entry"):
                            self.event_neighbor_entry = value
                            self.event_neighbor_entry.value_namespace = name_space
                            self.event_neighbor_entry.value_namespace_prefix = name_space_prefix
                        if(value_path == "extra-information1"):
                            self.extra_information1.append(value)
                        if(value_path == "extra-information2"):
                            self.extra_information2.append(value)


                class RoundTripDelay(Entity):
                    """
                    Round\-Trip delay
                    
                    .. attribute:: aging_rtd
                    
                    	aging rtd
                    	**type**\:   :py:class:`AgingRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.AgingRtd>`
                    
                    .. attribute:: bdxc_rtd
                    
                    	bdxc rtd
                    	**type**\:   :py:class:`BdxcRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.BdxcRtd>`
                    
                    .. attribute:: bind
                    
                    	bind
                    	**type**\: list of    :py:class:`Bind <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Bind>`
                    
                    .. attribute:: create
                    
                    	create
                    	**type**\: list of    :py:class:`Create <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Create>`
                    
                    .. attribute:: delete
                    
                    	delete
                    	**type**\: list of    :py:class:`Delete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Delete>`
                    
                    .. attribute:: lock_rtd
                    
                    	lock rtd
                    	**type**\:   :py:class:`LockRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.LockRtd>`
                    
                    .. attribute:: mac_flush
                    
                    	mac flush
                    	**type**\: list of    :py:class:`MacFlush <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.MacFlush>`
                    
                    .. attribute:: modify
                    
                    	modify
                    	**type**\: list of    :py:class:`Modify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Modify>`
                    
                    .. attribute:: pirtd
                    
                    	pirtd
                    	**type**\: list of    :py:class:`Pirtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Pirtd>`
                    
                    .. attribute:: platform_init_rtd
                    
                    	platform init rtd
                    	**type**\:   :py:class:`PlatformInitRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PlatformInitRtd>`
                    
                    .. attribute:: punt_rtd
                    
                    	punt rtd
                    	**type**\:   :py:class:`PuntRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PuntRtd>`
                    
                    .. attribute:: rtd_max_obj_type
                    
                    	RTD MAX OBJTYPE
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unbind
                    
                    	unbind
                    	**type**\: list of    :py:class:`Unbind <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Unbind>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay, self).__init__()

                        self.yang_name = "round-trip-delay"
                        self.yang_parent_name = "l2fib-message-summary"

                        self.rtd_max_obj_type = YLeaf(YType.uint32, "rtd-max-obj-type")

                        self.aging_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.AgingRtd()
                        self.aging_rtd.parent = self
                        self._children_name_map["aging_rtd"] = "aging-rtd"
                        self._children_yang_names.add("aging-rtd")

                        self.bdxc_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.BdxcRtd()
                        self.bdxc_rtd.parent = self
                        self._children_name_map["bdxc_rtd"] = "bdxc-rtd"
                        self._children_yang_names.add("bdxc-rtd")

                        self.lock_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.LockRtd()
                        self.lock_rtd.parent = self
                        self._children_name_map["lock_rtd"] = "lock-rtd"
                        self._children_yang_names.add("lock-rtd")

                        self.platform_init_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PlatformInitRtd()
                        self.platform_init_rtd.parent = self
                        self._children_name_map["platform_init_rtd"] = "platform-init-rtd"
                        self._children_yang_names.add("platform-init-rtd")

                        self.punt_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PuntRtd()
                        self.punt_rtd.parent = self
                        self._children_name_map["punt_rtd"] = "punt-rtd"
                        self._children_yang_names.add("punt-rtd")

                        self.bind = YList(self)
                        self.create = YList(self)
                        self.delete = YList(self)
                        self.mac_flush = YList(self)
                        self.modify = YList(self)
                        self.pirtd = YList(self)
                        self.unbind = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("rtd_max_obj_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay, self).__setattr__(name, value)


                    class BdxcRtd(Entity):
                        """
                        bdxc rtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.BdxcRtd, self).__init__()

                            self.yang_name = "bdxc-rtd"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.BdxcRtd, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.BdxcRtd, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bdxc-rtd" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class AgingRtd(Entity):
                        """
                        aging rtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.AgingRtd, self).__init__()

                            self.yang_name = "aging-rtd"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.AgingRtd, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.AgingRtd, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "aging-rtd" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class PuntRtd(Entity):
                        """
                        punt rtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PuntRtd, self).__init__()

                            self.yang_name = "punt-rtd"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PuntRtd, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PuntRtd, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "punt-rtd" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class LockRtd(Entity):
                        """
                        lock rtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.LockRtd, self).__init__()

                            self.yang_name = "lock-rtd"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.LockRtd, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.LockRtd, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "lock-rtd" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class PlatformInitRtd(Entity):
                        """
                        platform init rtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PlatformInitRtd, self).__init__()

                            self.yang_name = "platform-init-rtd"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PlatformInitRtd, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PlatformInitRtd, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "platform-init-rtd" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class Create(Entity):
                        """
                        create
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Create, self).__init__()

                            self.yang_name = "create"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Create, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Create, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "create" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class Modify(Entity):
                        """
                        modify
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Modify, self).__init__()

                            self.yang_name = "modify"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Modify, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Modify, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "modify" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class Delete(Entity):
                        """
                        delete
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Delete, self).__init__()

                            self.yang_name = "delete"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Delete, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Delete, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "delete" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class Bind(Entity):
                        """
                        bind
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Bind, self).__init__()

                            self.yang_name = "bind"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Bind, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Bind, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bind" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class Unbind(Entity):
                        """
                        unbind
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Unbind, self).__init__()

                            self.yang_name = "unbind"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Unbind, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Unbind, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "unbind" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class MacFlush(Entity):
                        """
                        mac flush
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.MacFlush, self).__init__()

                            self.yang_name = "mac-flush"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.MacFlush, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.MacFlush, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mac-flush" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix


                    class Pirtd(Entity):
                        """
                        pirtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Pirtd, self).__init__()

                            self.yang_name = "pirtd"
                            self.yang_parent_name = "round-trip-delay"

                            self.average_round_trip_delay = YLeaf(YType.uint64, "average-round-trip-delay")

                            self.maximum_round_trip_delay = YLeaf(YType.uint64, "maximum-round-trip-delay")

                            self.minimum_round_trip_delay = YLeaf(YType.uint64, "minimum-round-trip-delay")

                            self.number_pd_update = YLeaf(YType.uint32, "number-pd-update")

                            self.number_pd_update_zero = YLeaf(YType.uint32, "number-pd-update-zero")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("average_round_trip_delay",
                                            "maximum_round_trip_delay",
                                            "minimum_round_trip_delay",
                                            "number_pd_update",
                                            "number_pd_update_zero") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Pirtd, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Pirtd, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.average_round_trip_delay.is_set or
                                self.maximum_round_trip_delay.is_set or
                                self.minimum_round_trip_delay.is_set or
                                self.number_pd_update.is_set or
                                self.number_pd_update_zero.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.average_round_trip_delay.yfilter != YFilter.not_set or
                                self.maximum_round_trip_delay.yfilter != YFilter.not_set or
                                self.minimum_round_trip_delay.yfilter != YFilter.not_set or
                                self.number_pd_update.yfilter != YFilter.not_set or
                                self.number_pd_update_zero.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pirtd" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.average_round_trip_delay.is_set or self.average_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.average_round_trip_delay.get_name_leafdata())
                            if (self.maximum_round_trip_delay.is_set or self.maximum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_round_trip_delay.get_name_leafdata())
                            if (self.minimum_round_trip_delay.is_set or self.minimum_round_trip_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_round_trip_delay.get_name_leafdata())
                            if (self.number_pd_update.is_set or self.number_pd_update.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update.get_name_leafdata())
                            if (self.number_pd_update_zero.is_set or self.number_pd_update_zero.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pd_update_zero.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "average-round-trip-delay" or name == "maximum-round-trip-delay" or name == "minimum-round-trip-delay" or name == "number-pd-update" or name == "number-pd-update-zero"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "average-round-trip-delay"):
                                self.average_round_trip_delay = value
                                self.average_round_trip_delay.value_namespace = name_space
                                self.average_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-round-trip-delay"):
                                self.maximum_round_trip_delay = value
                                self.maximum_round_trip_delay.value_namespace = name_space
                                self.maximum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-round-trip-delay"):
                                self.minimum_round_trip_delay = value
                                self.minimum_round_trip_delay.value_namespace = name_space
                                self.minimum_round_trip_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update"):
                                self.number_pd_update = value
                                self.number_pd_update.value_namespace = name_space
                                self.number_pd_update.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pd-update-zero"):
                                self.number_pd_update_zero = value
                                self.number_pd_update_zero.value_namespace = name_space
                                self.number_pd_update_zero.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bind:
                            if (c.has_data()):
                                return True
                        for c in self.create:
                            if (c.has_data()):
                                return True
                        for c in self.delete:
                            if (c.has_data()):
                                return True
                        for c in self.mac_flush:
                            if (c.has_data()):
                                return True
                        for c in self.modify:
                            if (c.has_data()):
                                return True
                        for c in self.pirtd:
                            if (c.has_data()):
                                return True
                        for c in self.unbind:
                            if (c.has_data()):
                                return True
                        return (
                            self.rtd_max_obj_type.is_set or
                            (self.aging_rtd is not None and self.aging_rtd.has_data()) or
                            (self.bdxc_rtd is not None and self.bdxc_rtd.has_data()) or
                            (self.lock_rtd is not None and self.lock_rtd.has_data()) or
                            (self.platform_init_rtd is not None and self.platform_init_rtd.has_data()) or
                            (self.punt_rtd is not None and self.punt_rtd.has_data()))

                    def has_operation(self):
                        for c in self.bind:
                            if (c.has_operation()):
                                return True
                        for c in self.create:
                            if (c.has_operation()):
                                return True
                        for c in self.delete:
                            if (c.has_operation()):
                                return True
                        for c in self.mac_flush:
                            if (c.has_operation()):
                                return True
                        for c in self.modify:
                            if (c.has_operation()):
                                return True
                        for c in self.pirtd:
                            if (c.has_operation()):
                                return True
                        for c in self.unbind:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.rtd_max_obj_type.yfilter != YFilter.not_set or
                            (self.aging_rtd is not None and self.aging_rtd.has_operation()) or
                            (self.bdxc_rtd is not None and self.bdxc_rtd.has_operation()) or
                            (self.lock_rtd is not None and self.lock_rtd.has_operation()) or
                            (self.platform_init_rtd is not None and self.platform_init_rtd.has_operation()) or
                            (self.punt_rtd is not None and self.punt_rtd.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "round-trip-delay" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.rtd_max_obj_type.is_set or self.rtd_max_obj_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rtd_max_obj_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "aging-rtd"):
                            if (self.aging_rtd is None):
                                self.aging_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.AgingRtd()
                                self.aging_rtd.parent = self
                                self._children_name_map["aging_rtd"] = "aging-rtd"
                            return self.aging_rtd

                        if (child_yang_name == "bdxc-rtd"):
                            if (self.bdxc_rtd is None):
                                self.bdxc_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.BdxcRtd()
                                self.bdxc_rtd.parent = self
                                self._children_name_map["bdxc_rtd"] = "bdxc-rtd"
                            return self.bdxc_rtd

                        if (child_yang_name == "bind"):
                            for c in self.bind:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Bind()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bind.append(c)
                            return c

                        if (child_yang_name == "create"):
                            for c in self.create:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Create()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.create.append(c)
                            return c

                        if (child_yang_name == "delete"):
                            for c in self.delete:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Delete()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.delete.append(c)
                            return c

                        if (child_yang_name == "lock-rtd"):
                            if (self.lock_rtd is None):
                                self.lock_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.LockRtd()
                                self.lock_rtd.parent = self
                                self._children_name_map["lock_rtd"] = "lock-rtd"
                            return self.lock_rtd

                        if (child_yang_name == "mac-flush"):
                            for c in self.mac_flush:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.MacFlush()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mac_flush.append(c)
                            return c

                        if (child_yang_name == "modify"):
                            for c in self.modify:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Modify()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.modify.append(c)
                            return c

                        if (child_yang_name == "pirtd"):
                            for c in self.pirtd:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Pirtd()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.pirtd.append(c)
                            return c

                        if (child_yang_name == "platform-init-rtd"):
                            if (self.platform_init_rtd is None):
                                self.platform_init_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PlatformInitRtd()
                                self.platform_init_rtd.parent = self
                                self._children_name_map["platform_init_rtd"] = "platform-init-rtd"
                            return self.platform_init_rtd

                        if (child_yang_name == "punt-rtd"):
                            if (self.punt_rtd is None):
                                self.punt_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PuntRtd()
                                self.punt_rtd.parent = self
                                self._children_name_map["punt_rtd"] = "punt-rtd"
                            return self.punt_rtd

                        if (child_yang_name == "unbind"):
                            for c in self.unbind:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Unbind()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.unbind.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "aging-rtd" or name == "bdxc-rtd" or name == "bind" or name == "create" or name == "delete" or name == "lock-rtd" or name == "mac-flush" or name == "modify" or name == "pirtd" or name == "platform-init-rtd" or name == "punt-rtd" or name == "unbind" or name == "rtd-max-obj-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "rtd-max-obj-type"):
                            self.rtd_max_obj_type = value
                            self.rtd_max_obj_type.value_namespace = name_space
                            self.rtd_max_obj_type.value_namespace_prefix = name_space_prefix


                class Message(Entity):
                    """
                    message
                    
                    .. attribute:: information1
                    
                    	Extra info 1
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: information2
                    
                    	Extra info 2
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: messgae_count
                    
                    	number of message
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time
                    
                    	Time string
                    	**type**\:  str
                    
                    	**length:** 0..32
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.Message, self).__init__()

                        self.yang_name = "message"
                        self.yang_parent_name = "l2fib-message-summary"

                        self.information1 = YLeaf(YType.uint32, "information1")

                        self.information2 = YLeaf(YType.uint32, "information2")

                        self.messgae_count = YLeaf(YType.uint32, "messgae-count")

                        self.time = YLeaf(YType.str, "time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("information1",
                                        "information2",
                                        "messgae_count",
                                        "time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.Message, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMessageSummary.Message, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.information1.is_set or
                            self.information2.is_set or
                            self.messgae_count.is_set or
                            self.time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.information1.yfilter != YFilter.not_set or
                            self.information2.yfilter != YFilter.not_set or
                            self.messgae_count.yfilter != YFilter.not_set or
                            self.time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "message" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.information1.is_set or self.information1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.information1.get_name_leafdata())
                        if (self.information2.is_set or self.information2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.information2.get_name_leafdata())
                        if (self.messgae_count.is_set or self.messgae_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.messgae_count.get_name_leafdata())
                        if (self.time.is_set or self.time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "information1" or name == "information2" or name == "messgae-count" or name == "time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "information1"):
                            self.information1 = value
                            self.information1.value_namespace = name_space
                            self.information1.value_namespace_prefix = name_space_prefix
                        if(value_path == "information2"):
                            self.information2 = value
                            self.information2.value_namespace = name_space
                            self.information2.value_namespace_prefix = name_space_prefix
                        if(value_path == "messgae-count"):
                            self.messgae_count = value
                            self.messgae_count.value_namespace = name_space
                            self.messgae_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "time"):
                            self.time = value
                            self.time.value_namespace = name_space
                            self.time.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.message:
                        if (c.has_data()):
                            return True
                    return (
                        (self.event_history is not None and self.event_history.has_data()) or
                        (self.round_trip_delay is not None and self.round_trip_delay.has_data()))

                def has_operation(self):
                    for c in self.message:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.event_history is not None and self.event_history.has_operation()) or
                        (self.round_trip_delay is not None and self.round_trip_delay.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-message-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "event-history"):
                        if (self.event_history is None):
                            self.event_history = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory()
                            self.event_history.parent = self
                            self._children_name_map["event_history"] = "event-history"
                        return self.event_history

                    if (child_yang_name == "message"):
                        for c in self.message:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.Message()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.message.append(c)
                        return c

                    if (child_yang_name == "round-trip-delay"):
                        if (self.round_trip_delay is None):
                            self.round_trip_delay = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay()
                            self.round_trip_delay.parent = self
                            self._children_name_map["round_trip_delay"] = "round-trip-delay"
                        return self.round_trip_delay

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "event-history" or name == "message" or name == "round-trip-delay"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMroutes(Entity):
                """
                multicast information
                
                .. attribute:: l2fib_mroute
                
                	Bridge Domain Multicast Information
                	**type**\: list of    :py:class:`L2FibMroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes, self).__init__()

                    self.yang_name = "l2fib-mroutes"
                    self.yang_parent_name = "node"

                    self.l2fib_mroute = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMroutes, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutes, self).__setattr__(name, value)


                class L2FibMroute(Entity):
                    """
                    Bridge Domain Multicast Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\:  str
                    
                    	**length:** 0..66
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:   :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:   :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats>`
                    
                    .. attribute:: group
                    
                    	Group IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: hardware_information
                    
                    	Platform Hardware info
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: irb_info
                    
                    	IRB Information
                    	**type**\:   :py:class:`IrbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.IrbInfo>`
                    
                    .. attribute:: multicast_base_information
                    
                    	Base Information
                    	**type**\:   :py:class:`MulticastBaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.MulticastBaseInformation>`
                    
                    .. attribute:: platform_data
                    
                    	The mcast platform data
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: platform_data_length
                    
                    	The mcast platform data len
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: source
                    
                    	Source IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:   :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.SourcePrefix>`
                    
                    .. attribute:: xid_count
                    
                    	Count of XIDs
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute, self).__init__()

                        self.yang_name = "l2fib-mroute"
                        self.yang_parent_name = "l2fib-mroutes"

                        self.bd_group_name = YLeaf(YType.str, "bd-group-name")

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                        self.group = YLeaf(YType.str, "group")

                        self.hardware_information = YLeaf(YType.str, "hardware-information")

                        self.platform_data = YLeaf(YType.str, "platform-data")

                        self.platform_data_length = YLeaf(YType.uint8, "platform-data-length")

                        self.source = YLeaf(YType.str, "source")

                        self.xid_count = YLeaf(YType.uint16, "xid-count")

                        self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self._children_name_map["destination_prefix"] = "destination-prefix"
                        self._children_yang_names.add("destination-prefix")

                        self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats()
                        self.forward_stats.parent = self
                        self._children_name_map["forward_stats"] = "forward-stats"
                        self._children_yang_names.add("forward-stats")

                        self.irb_info = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.IrbInfo()
                        self.irb_info.parent = self
                        self._children_name_map["irb_info"] = "irb-info"
                        self._children_yang_names.add("irb-info")

                        self.multicast_base_information = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.MulticastBaseInformation()
                        self.multicast_base_information.parent = self
                        self._children_name_map["multicast_base_information"] = "multicast-base-information"
                        self._children_yang_names.add("multicast-base-information")

                        self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.SourcePrefix()
                        self.source_prefix.parent = self
                        self._children_name_map["source_prefix"] = "source-prefix"
                        self._children_yang_names.add("source-prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bd_group_name",
                                        "bd_name",
                                        "bridge_domain_name",
                                        "bridge_id",
                                        "group",
                                        "hardware_information",
                                        "platform_data",
                                        "platform_data_length",
                                        "source",
                                        "xid_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute, self).__setattr__(name, value)


                    class MulticastBaseInformation(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.MulticastBaseInformation, self).__init__()

                            self.yang_name = "multicast-base-information"
                            self.yang_parent_name = "l2fib-mroute"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "multicast-base-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SourcePrefix(Entity):
                        """
                        Source Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.SourcePrefix, self).__init__()

                            self.yang_name = "source-prefix"
                            self.yang_parent_name = "l2fib-mroute"

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                            self.proto = YLeaf(YType.uint8, "proto")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix",
                                            "prefix_length",
                                            "proto") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.SourcePrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.SourcePrefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.proto.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proto.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proto.is_set or self.proto.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proto.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "prefix-length" or name == "proto"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proto"):
                                self.proto = value
                                self.proto.value_namespace = name_space
                                self.proto.value_namespace_prefix = name_space_prefix


                    class DestinationPrefix(Entity):
                        """
                        Destination Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.DestinationPrefix, self).__init__()

                            self.yang_name = "destination-prefix"
                            self.yang_parent_name = "l2fib-mroute"

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                            self.proto = YLeaf(YType.uint8, "proto")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix",
                                            "prefix_length",
                                            "proto") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.DestinationPrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.DestinationPrefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.proto.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proto.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "destination-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proto.is_set or self.proto.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proto.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "prefix-length" or name == "proto"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proto"):
                                self.proto = value
                                self.proto.value_namespace = name_space
                                self.proto.value_namespace_prefix = name_space_prefix


                    class ForwardStats(Entity):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:   :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats, self).__init__()

                            self.yang_name = "forward-stats"
                            self.yang_parent_name = "l2fib-mroute"

                            self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self
                            self._children_name_map["forward_stat"] = "forward-stat"
                            self._children_yang_names.add("forward-stat")


                        class ForwardStat(Entity):
                            """
                            fwd stats
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:   :py:class:`MgmtL2FibStatsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibStatsData>`
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:   :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat, self).__init__()

                                self.yang_name = "forward-stat"
                                self.yang_parent_name = "forward-stats"

                                self.data_type = YLeaf(YType.enumeration, "data-type")

                                self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self
                                self._children_name_map["mulicast"] = "mulicast"
                                self._children_yang_names.add("mulicast")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("data_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat, self).__setattr__(name, value)


                            class Mulicast(Entity):
                                """
                                mulicast
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:   :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:   :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:   :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:   :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:   :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:   :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast, self).__init__()

                                    self.yang_name = "mulicast"
                                    self.yang_parent_name = "forward-stat"

                                    self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self._children_name_map["core_received_stat"] = "core-received-stat"
                                    self._children_yang_names.add("core-received-stat")

                                    self.drop = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self._children_name_map["drop"] = "drop"
                                    self._children_yang_names.add("drop")

                                    self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"
                                    self._children_yang_names.add("multicast-core-forward-stat")

                                    self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"
                                    self._children_yang_names.add("multicast-forward-stat")

                                    self.punt = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self._children_name_map["punt"] = "punt"
                                    self._children_yang_names.add("punt")

                                    self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self
                                    self._children_name_map["received_stat"] = "received-stat"
                                    self._children_yang_names.add("received-stat")


                                class MulticastForwardStat(Entity):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__init__()

                                        self.yang_name = "multicast-forward-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-forward-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class ReceivedStat(Entity):
                                    """
                                    received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__init__()

                                        self.yang_name = "received-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class Punt(Entity):
                                    """
                                    punted stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Punt, self).__init__()

                                        self.yang_name = "punt"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Punt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Punt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "punt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class Drop(Entity):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Drop, self).__init__()

                                        self.yang_name = "drop"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Drop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Drop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class MulticastCoreForwardStat(Entity):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__init__()

                                        self.yang_name = "multicast-core-forward-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-core-forward-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class CoreReceivedStat(Entity):
                                    """
                                    core received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__init__()

                                        self.yang_name = "core-received-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "core-received-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.core_received_stat is not None and self.core_received_stat.has_data()) or
                                        (self.drop is not None and self.drop.has_data()) or
                                        (self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat.has_data()) or
                                        (self.multicast_forward_stat is not None and self.multicast_forward_stat.has_data()) or
                                        (self.punt is not None and self.punt.has_data()) or
                                        (self.received_stat is not None and self.received_stat.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.core_received_stat is not None and self.core_received_stat.has_operation()) or
                                        (self.drop is not None and self.drop.has_operation()) or
                                        (self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat.has_operation()) or
                                        (self.multicast_forward_stat is not None and self.multicast_forward_stat.has_operation()) or
                                        (self.punt is not None and self.punt.has_operation()) or
                                        (self.received_stat is not None and self.received_stat.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mulicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "core-received-stat"):
                                        if (self.core_received_stat is None):
                                            self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                            self.core_received_stat.parent = self
                                            self._children_name_map["core_received_stat"] = "core-received-stat"
                                        return self.core_received_stat

                                    if (child_yang_name == "drop"):
                                        if (self.drop is None):
                                            self.drop = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Drop()
                                            self.drop.parent = self
                                            self._children_name_map["drop"] = "drop"
                                        return self.drop

                                    if (child_yang_name == "multicast-core-forward-stat"):
                                        if (self.multicast_core_forward_stat is None):
                                            self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                            self.multicast_core_forward_stat.parent = self
                                            self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"
                                        return self.multicast_core_forward_stat

                                    if (child_yang_name == "multicast-forward-stat"):
                                        if (self.multicast_forward_stat is None):
                                            self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                            self.multicast_forward_stat.parent = self
                                            self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"
                                        return self.multicast_forward_stat

                                    if (child_yang_name == "punt"):
                                        if (self.punt is None):
                                            self.punt = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Punt()
                                            self.punt.parent = self
                                            self._children_name_map["punt"] = "punt"
                                        return self.punt

                                    if (child_yang_name == "received-stat"):
                                        if (self.received_stat is None):
                                            self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                            self.received_stat.parent = self
                                            self._children_name_map["received_stat"] = "received-stat"
                                        return self.received_stat

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "core-received-stat" or name == "drop" or name == "multicast-core-forward-stat" or name == "multicast-forward-stat" or name == "punt" or name == "received-stat"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.data_type.is_set or
                                    (self.mulicast is not None and self.mulicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.data_type.yfilter != YFilter.not_set or
                                    (self.mulicast is not None and self.mulicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "forward-stat" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.data_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mulicast"):
                                    if (self.mulicast is None):
                                        self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast()
                                        self.mulicast.parent = self
                                        self._children_name_map["mulicast"] = "mulicast"
                                    return self.mulicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mulicast" or name == "data-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "data-type"):
                                    self.data_type = value
                                    self.data_type.value_namespace = name_space
                                    self.data_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.forward_stat is not None and self.forward_stat.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.forward_stat is not None and self.forward_stat.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "forward-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "forward-stat"):
                                if (self.forward_stat is None):
                                    self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat()
                                    self.forward_stat.parent = self
                                    self._children_name_map["forward_stat"] = "forward-stat"
                                return self.forward_stat

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "forward-stat"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class IrbInfo(Entity):
                        """
                        IRB Information
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        .. attribute:: mxid_ac_interface_handle
                        
                        	Master XID AC If handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mxid_next_hop_address
                        
                        	Master XID NHOP IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mxid_pw_id
                        
                        	Master XID PW ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.IrbInfo, self).__init__()

                            self.yang_name = "irb-info"
                            self.yang_parent_name = "l2fib-mroute"

                            self.irb_plat_data = YLeafList(YType.uint32, "irb-plat-data")

                            self.irb_plat_data_len = YLeaf(YType.uint16, "irb-plat-data-len")

                            self.mxid_ac_interface_handle = YLeaf(YType.str, "mxid-ac-interface-handle")

                            self.mxid_next_hop_address = YLeaf(YType.str, "mxid-next-hop-address")

                            self.mxid_pw_id = YLeaf(YType.uint32, "mxid-pw-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("irb_plat_data",
                                            "irb_plat_data_len",
                                            "mxid_ac_interface_handle",
                                            "mxid_next_hop_address",
                                            "mxid_pw_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.IrbInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.IrbInfo, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.irb_plat_data.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.irb_plat_data_len.is_set or
                                self.mxid_ac_interface_handle.is_set or
                                self.mxid_next_hop_address.is_set or
                                self.mxid_pw_id.is_set)

                        def has_operation(self):
                            for leaf in self.irb_plat_data.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.irb_plat_data.yfilter != YFilter.not_set or
                                self.irb_plat_data_len.yfilter != YFilter.not_set or
                                self.mxid_ac_interface_handle.yfilter != YFilter.not_set or
                                self.mxid_next_hop_address.yfilter != YFilter.not_set or
                                self.mxid_pw_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "irb-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.irb_plat_data_len.is_set or self.irb_plat_data_len.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.irb_plat_data_len.get_name_leafdata())
                            if (self.mxid_ac_interface_handle.is_set or self.mxid_ac_interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mxid_ac_interface_handle.get_name_leafdata())
                            if (self.mxid_next_hop_address.is_set or self.mxid_next_hop_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mxid_next_hop_address.get_name_leafdata())
                            if (self.mxid_pw_id.is_set or self.mxid_pw_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mxid_pw_id.get_name_leafdata())

                            leaf_name_data.extend(self.irb_plat_data.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "irb-plat-data" or name == "irb-plat-data-len" or name == "mxid-ac-interface-handle" or name == "mxid-next-hop-address" or name == "mxid-pw-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "irb-plat-data"):
                                self.irb_plat_data.append(value)
                            if(value_path == "irb-plat-data-len"):
                                self.irb_plat_data_len = value
                                self.irb_plat_data_len.value_namespace = name_space
                                self.irb_plat_data_len.value_namespace_prefix = name_space_prefix
                            if(value_path == "mxid-ac-interface-handle"):
                                self.mxid_ac_interface_handle = value
                                self.mxid_ac_interface_handle.value_namespace = name_space
                                self.mxid_ac_interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "mxid-next-hop-address"):
                                self.mxid_next_hop_address = value
                                self.mxid_next_hop_address.value_namespace = name_space
                                self.mxid_next_hop_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mxid-pw-id"):
                                self.mxid_pw_id = value
                                self.mxid_pw_id.value_namespace = name_space
                                self.mxid_pw_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bd_group_name.is_set or
                            self.bd_name.is_set or
                            self.bridge_domain_name.is_set or
                            self.bridge_id.is_set or
                            self.group.is_set or
                            self.hardware_information.is_set or
                            self.platform_data.is_set or
                            self.platform_data_length.is_set or
                            self.source.is_set or
                            self.xid_count.is_set or
                            (self.destination_prefix is not None and self.destination_prefix.has_data()) or
                            (self.forward_stats is not None and self.forward_stats.has_data()) or
                            (self.irb_info is not None and self.irb_info.has_data()) or
                            (self.multicast_base_information is not None and self.multicast_base_information.has_data()) or
                            (self.source_prefix is not None and self.source_prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bd_group_name.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            self.bridge_domain_name.yfilter != YFilter.not_set or
                            self.bridge_id.yfilter != YFilter.not_set or
                            self.group.yfilter != YFilter.not_set or
                            self.hardware_information.yfilter != YFilter.not_set or
                            self.platform_data.yfilter != YFilter.not_set or
                            self.platform_data_length.yfilter != YFilter.not_set or
                            self.source.yfilter != YFilter.not_set or
                            self.xid_count.yfilter != YFilter.not_set or
                            (self.destination_prefix is not None and self.destination_prefix.has_operation()) or
                            (self.forward_stats is not None and self.forward_stats.has_operation()) or
                            (self.irb_info is not None and self.irb_info.has_operation()) or
                            (self.multicast_base_information is not None and self.multicast_base_information.has_operation()) or
                            (self.source_prefix is not None and self.source_prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mroute" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bd_group_name.is_set or self.bd_group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_group_name.get_name_leafdata())
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())
                        if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                        if (self.group.is_set or self.group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group.get_name_leafdata())
                        if (self.hardware_information.is_set or self.hardware_information.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hardware_information.get_name_leafdata())
                        if (self.platform_data.is_set or self.platform_data.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.platform_data.get_name_leafdata())
                        if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.platform_data_length.get_name_leafdata())
                        if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source.get_name_leafdata())
                        if (self.xid_count.is_set or self.xid_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xid_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "destination-prefix"):
                            if (self.destination_prefix is None):
                                self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.DestinationPrefix()
                                self.destination_prefix.parent = self
                                self._children_name_map["destination_prefix"] = "destination-prefix"
                            return self.destination_prefix

                        if (child_yang_name == "forward-stats"):
                            if (self.forward_stats is None):
                                self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats()
                                self.forward_stats.parent = self
                                self._children_name_map["forward_stats"] = "forward-stats"
                            return self.forward_stats

                        if (child_yang_name == "irb-info"):
                            if (self.irb_info is None):
                                self.irb_info = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.IrbInfo()
                                self.irb_info.parent = self
                                self._children_name_map["irb_info"] = "irb-info"
                            return self.irb_info

                        if (child_yang_name == "multicast-base-information"):
                            if (self.multicast_base_information is None):
                                self.multicast_base_information = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.MulticastBaseInformation()
                                self.multicast_base_information.parent = self
                                self._children_name_map["multicast_base_information"] = "multicast-base-information"
                            return self.multicast_base_information

                        if (child_yang_name == "source-prefix"):
                            if (self.source_prefix is None):
                                self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.SourcePrefix()
                                self.source_prefix.parent = self
                                self._children_name_map["source_prefix"] = "source-prefix"
                            return self.source_prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "destination-prefix" or name == "forward-stats" or name == "irb-info" or name == "multicast-base-information" or name == "source-prefix" or name == "bd-group-name" or name == "bd-name" or name == "bridge-domain-name" or name == "bridge-id" or name == "group" or name == "hardware-information" or name == "platform-data" or name == "platform-data-length" or name == "source" or name == "xid-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bd-group-name"):
                            self.bd_group_name = value
                            self.bd_group_name.value_namespace = name_space
                            self.bd_group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-name"):
                            self.bridge_domain_name = value
                            self.bridge_domain_name.value_namespace = name_space
                            self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-id"):
                            self.bridge_id = value
                            self.bridge_id.value_namespace = name_space
                            self.bridge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "group"):
                            self.group = value
                            self.group.value_namespace = name_space
                            self.group.value_namespace_prefix = name_space_prefix
                        if(value_path == "hardware-information"):
                            self.hardware_information = value
                            self.hardware_information.value_namespace = name_space
                            self.hardware_information.value_namespace_prefix = name_space_prefix
                        if(value_path == "platform-data"):
                            self.platform_data = value
                            self.platform_data.value_namespace = name_space
                            self.platform_data.value_namespace_prefix = name_space_prefix
                        if(value_path == "platform-data-length"):
                            self.platform_data_length = value
                            self.platform_data_length.value_namespace = name_space
                            self.platform_data_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "source"):
                            self.source = value
                            self.source.value_namespace = name_space
                            self.source.value_namespace_prefix = name_space_prefix
                        if(value_path == "xid-count"):
                            self.xid_count = value
                            self.xid_count.value_namespace = name_space
                            self.xid_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_mroute:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_mroute:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-mroutes" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-mroute"):
                        for c in self.l2fib_mroute:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_mroute.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-mroute"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class PbbBmacSa(Entity):
                """
                PBB Backbone Source MAC information
                
                .. attribute:: chassis_mac
                
                	Chassis Mac
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: configured
                
                	BMAC SA configured
                	**type**\:  bool
                
                .. attribute:: mac
                
                	Backbone Source Mac
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.PbbBmacSa, self).__init__()

                    self.yang_name = "pbb-bmac-sa"
                    self.yang_parent_name = "node"

                    self.chassis_mac = YLeaf(YType.str, "chassis-mac")

                    self.configured = YLeaf(YType.boolean, "configured")

                    self.mac = YLeaf(YType.str, "mac")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("chassis_mac",
                                    "configured",
                                    "mac") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.PbbBmacSa, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.PbbBmacSa, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.chassis_mac.is_set or
                        self.configured.is_set or
                        self.mac.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.chassis_mac.yfilter != YFilter.not_set or
                        self.configured.yfilter != YFilter.not_set or
                        self.mac.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pbb-bmac-sa" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.chassis_mac.is_set or self.chassis_mac.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.chassis_mac.get_name_leafdata())
                    if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured.get_name_leafdata())
                    if (self.mac.is_set or self.mac.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mac.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "chassis-mac" or name == "configured" or name == "mac"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "chassis-mac"):
                        self.chassis_mac = value
                        self.chassis_mac.value_namespace = name_space
                        self.chassis_mac.value_namespace_prefix = name_space_prefix
                    if(value_path == "configured"):
                        self.configured = value
                        self.configured.value_namespace = name_space
                        self.configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "mac"):
                        self.mac = value
                        self.mac.value_namespace = name_space
                        self.mac.value_namespace_prefix = name_space_prefix


            class L2FibMacLearning(Entity):
                """
                The L2VPN forwarding Mac Learning Data
                
                .. attribute:: l2fib_mac_learning_mac_ipv4s
                
                	The L2VPN forwarding Mac IPV4 Learning Table
                	**type**\:   :py:class:`L2FibMacLearningMacIpv4S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S>`
                
                .. attribute:: l2fib_mac_learning_mac_ipv6s
                
                	The L2VPN forwarding Mac IPV6 Learning Table
                	**type**\:   :py:class:`L2FibMacLearningMacIpv6S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S>`
                
                .. attribute:: l2fib_mac_learning_macs
                
                	The L2VPN forwarding All Mac Learning Table
                	**type**\:   :py:class:`L2FibMacLearningMacs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMacLearning, self).__init__()

                    self.yang_name = "l2fib-mac-learning"
                    self.yang_parent_name = "node"

                    self.l2fib_mac_learning_mac_ipv4s = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S()
                    self.l2fib_mac_learning_mac_ipv4s.parent = self
                    self._children_name_map["l2fib_mac_learning_mac_ipv4s"] = "l2fib-mac-learning-mac-ipv4s"
                    self._children_yang_names.add("l2fib-mac-learning-mac-ipv4s")

                    self.l2fib_mac_learning_mac_ipv6s = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S()
                    self.l2fib_mac_learning_mac_ipv6s.parent = self
                    self._children_name_map["l2fib_mac_learning_mac_ipv6s"] = "l2fib-mac-learning-mac-ipv6s"
                    self._children_yang_names.add("l2fib-mac-learning-mac-ipv6s")

                    self.l2fib_mac_learning_macs = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs()
                    self.l2fib_mac_learning_macs.parent = self
                    self._children_name_map["l2fib_mac_learning_macs"] = "l2fib-mac-learning-macs"
                    self._children_yang_names.add("l2fib-mac-learning-macs")


                class L2FibMacLearningMacs(Entity):
                    """
                    The L2VPN forwarding All Mac Learning Table
                    
                    .. attribute:: l2fib_mac_learning_mac
                    
                    	The attributes for a particular learned Mac Route
                    	**type**\: list of    :py:class:`L2FibMacLearningMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs, self).__init__()

                        self.yang_name = "l2fib-mac-learning-macs"
                        self.yang_parent_name = "l2fib-mac-learning"

                        self.l2fib_mac_learning_mac = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs, self).__setattr__(name, value)


                    class L2FibMacLearningMac(Entity):
                        """
                        The attributes for a particular learned Mac
                        Route
                        
                        .. attribute:: addr
                        
                        	IP Address
                        	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Addr>`
                        
                        .. attribute:: address
                        
                        	IP Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: element_type
                        
                        	Element Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: generation
                        
                        	HW MAC generation
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_handle_xr
                        
                        	Interface Handle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_address
                        
                        	MAC Address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: mac_address_xr
                        
                        	MAC Address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: nhaddr
                        
                        	IP Address
                        	**type**\:   :py:class:`Nhaddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Nhaddr>`
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: topology_id
                        
                        	Topology ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: xcid
                        
                        	Cross\-connect Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac, self).__init__()

                            self.yang_name = "l2fib-mac-learning-mac"
                            self.yang_parent_name = "l2fib-mac-learning-macs"

                            self.address = YLeaf(YType.str, "address")

                            self.bdid = YLeaf(YType.int32, "bdid")

                            self.element_type = YLeaf(YType.uint8, "element-type")

                            self.generation = YLeaf(YType.uint8, "generation")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.interface_handle_xr = YLeaf(YType.uint32, "interface-handle-xr")

                            self.mac_address = YLeaf(YType.str, "mac-address")

                            self.mac_address_xr = YLeaf(YType.str, "mac-address-xr")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.topology_id = YLeaf(YType.uint32, "topology-id")

                            self.xcid = YLeaf(YType.uint32, "xcid")

                            self.addr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Addr()
                            self.addr.parent = self
                            self._children_name_map["addr"] = "addr"
                            self._children_yang_names.add("addr")

                            self.nhaddr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Nhaddr()
                            self.nhaddr.parent = self
                            self._children_name_map["nhaddr"] = "nhaddr"
                            self._children_yang_names.add("nhaddr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "bdid",
                                            "element_type",
                                            "generation",
                                            "interface_handle",
                                            "interface_handle_xr",
                                            "mac_address",
                                            "mac_address_xr",
                                            "node_id",
                                            "topology_id",
                                            "xcid") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac, self).__setattr__(name, value)


                        class Addr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:   :py:class:`L2FibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Addr, self).__init__()

                                self.yang_name = "addr"
                                self.yang_parent_name = "l2fib-mac-learning-mac"

                                self.addr_type = YLeaf(YType.enumeration, "addr-type")

                                self.ip = YLeaf(YType.str, "ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("addr_type",
                                                "ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.addr_type.is_set or
                                    self.ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.addr_type.yfilter != YFilter.not_set or
                                    self.ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.addr_type.is_set or self.addr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.addr_type.get_name_leafdata())
                                if (self.ip.is_set or self.ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "addr-type" or name == "ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "addr-type"):
                                    self.addr_type = value
                                    self.addr_type.value_namespace = name_space
                                    self.addr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip"):
                                    self.ip = value
                                    self.ip.value_namespace = name_space
                                    self.ip.value_namespace_prefix = name_space_prefix


                        class Nhaddr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:   :py:class:`L2FibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Nhaddr, self).__init__()

                                self.yang_name = "nhaddr"
                                self.yang_parent_name = "l2fib-mac-learning-mac"

                                self.addr_type = YLeaf(YType.enumeration, "addr-type")

                                self.ip = YLeaf(YType.str, "ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("addr_type",
                                                "ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Nhaddr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Nhaddr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.addr_type.is_set or
                                    self.ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.addr_type.yfilter != YFilter.not_set or
                                    self.ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nhaddr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.addr_type.is_set or self.addr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.addr_type.get_name_leafdata())
                                if (self.ip.is_set or self.ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "addr-type" or name == "ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "addr-type"):
                                    self.addr_type = value
                                    self.addr_type.value_namespace = name_space
                                    self.addr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip"):
                                    self.ip = value
                                    self.ip.value_namespace = name_space
                                    self.ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.bdid.is_set or
                                self.element_type.is_set or
                                self.generation.is_set or
                                self.interface_handle.is_set or
                                self.interface_handle_xr.is_set or
                                self.mac_address.is_set or
                                self.mac_address_xr.is_set or
                                self.node_id.is_set or
                                self.topology_id.is_set or
                                self.xcid.is_set or
                                (self.addr is not None and self.addr.has_data()) or
                                (self.nhaddr is not None and self.nhaddr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.bdid.yfilter != YFilter.not_set or
                                self.element_type.yfilter != YFilter.not_set or
                                self.generation.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.interface_handle_xr.yfilter != YFilter.not_set or
                                self.mac_address.yfilter != YFilter.not_set or
                                self.mac_address_xr.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.topology_id.yfilter != YFilter.not_set or
                                self.xcid.yfilter != YFilter.not_set or
                                (self.addr is not None and self.addr.has_operation()) or
                                (self.nhaddr is not None and self.nhaddr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-mac-learning-mac" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.bdid.is_set or self.bdid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bdid.get_name_leafdata())
                            if (self.element_type.is_set or self.element_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.element_type.get_name_leafdata())
                            if (self.generation.is_set or self.generation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.interface_handle_xr.is_set or self.interface_handle_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle_xr.get_name_leafdata())
                            if (self.mac_address.is_set or self.mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_address.get_name_leafdata())
                            if (self.mac_address_xr.is_set or self.mac_address_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_address_xr.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.topology_id.is_set or self.topology_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_id.get_name_leafdata())
                            if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xcid.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "addr"):
                                if (self.addr is None):
                                    self.addr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                return self.addr

                            if (child_yang_name == "nhaddr"):
                                if (self.nhaddr is None):
                                    self.nhaddr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac.Nhaddr()
                                    self.nhaddr.parent = self
                                    self._children_name_map["nhaddr"] = "nhaddr"
                                return self.nhaddr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "addr" or name == "nhaddr" or name == "address" or name == "bdid" or name == "element-type" or name == "generation" or name == "interface-handle" or name == "interface-handle-xr" or name == "mac-address" or name == "mac-address-xr" or name == "node-id" or name == "topology-id" or name == "xcid"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "bdid"):
                                self.bdid = value
                                self.bdid.value_namespace = name_space
                                self.bdid.value_namespace_prefix = name_space_prefix
                            if(value_path == "element-type"):
                                self.element_type = value
                                self.element_type.value_namespace = name_space
                                self.element_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation"):
                                self.generation = value
                                self.generation.value_namespace = name_space
                                self.generation.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle-xr"):
                                self.interface_handle_xr = value
                                self.interface_handle_xr.value_namespace = name_space
                                self.interface_handle_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-address"):
                                self.mac_address = value
                                self.mac_address.value_namespace = name_space
                                self.mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-address-xr"):
                                self.mac_address_xr = value
                                self.mac_address_xr.value_namespace = name_space
                                self.mac_address_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-id"):
                                self.topology_id = value
                                self.topology_id.value_namespace = name_space
                                self.topology_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "xcid"):
                                self.xcid = value
                                self.xcid.value_namespace = name_space
                                self.xcid.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.l2fib_mac_learning_mac:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.l2fib_mac_learning_mac:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mac-learning-macs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2fib-mac-learning-mac"):
                            for c in self.l2fib_mac_learning_mac:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs.L2FibMacLearningMac()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.l2fib_mac_learning_mac.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2fib-mac-learning-mac"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class L2FibMacLearningMacIpv4S(Entity):
                    """
                    The L2VPN forwarding Mac IPV4 Learning Table
                    
                    .. attribute:: l2fib_mac_learning_mac_ipv4
                    
                    	The attributes for a particular learned IPV4 Mac Route
                    	**type**\: list of    :py:class:`L2FibMacLearningMacIpv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S, self).__init__()

                        self.yang_name = "l2fib-mac-learning-mac-ipv4s"
                        self.yang_parent_name = "l2fib-mac-learning"

                        self.l2fib_mac_learning_mac_ipv4 = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S, self).__setattr__(name, value)


                    class L2FibMacLearningMacIpv4(Entity):
                        """
                        The attributes for a particular learned IPV4
                        Mac Route
                        
                        .. attribute:: addr
                        
                        	IP Address
                        	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Addr>`
                        
                        .. attribute:: address
                        
                        	IP Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: element_type
                        
                        	Element Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: generation
                        
                        	HW MAC generation
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_handle_xr
                        
                        	Interface Handle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_address
                        
                        	MAC Address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: mac_address_xr
                        
                        	MAC Address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: nhaddr
                        
                        	IP Address
                        	**type**\:   :py:class:`Nhaddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Nhaddr>`
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: topology_id
                        
                        	Topology ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: xcid
                        
                        	Cross\-connect Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4, self).__init__()

                            self.yang_name = "l2fib-mac-learning-mac-ipv4"
                            self.yang_parent_name = "l2fib-mac-learning-mac-ipv4s"

                            self.address = YLeaf(YType.str, "address")

                            self.bdid = YLeaf(YType.int32, "bdid")

                            self.element_type = YLeaf(YType.uint8, "element-type")

                            self.generation = YLeaf(YType.uint8, "generation")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.interface_handle_xr = YLeaf(YType.uint32, "interface-handle-xr")

                            self.mac_address = YLeaf(YType.str, "mac-address")

                            self.mac_address_xr = YLeaf(YType.str, "mac-address-xr")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.topology_id = YLeaf(YType.uint32, "topology-id")

                            self.xcid = YLeaf(YType.uint32, "xcid")

                            self.addr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Addr()
                            self.addr.parent = self
                            self._children_name_map["addr"] = "addr"
                            self._children_yang_names.add("addr")

                            self.nhaddr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Nhaddr()
                            self.nhaddr.parent = self
                            self._children_name_map["nhaddr"] = "nhaddr"
                            self._children_yang_names.add("nhaddr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "bdid",
                                            "element_type",
                                            "generation",
                                            "interface_handle",
                                            "interface_handle_xr",
                                            "mac_address",
                                            "mac_address_xr",
                                            "node_id",
                                            "topology_id",
                                            "xcid") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4, self).__setattr__(name, value)


                        class Addr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:   :py:class:`L2FibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Addr, self).__init__()

                                self.yang_name = "addr"
                                self.yang_parent_name = "l2fib-mac-learning-mac-ipv4"

                                self.addr_type = YLeaf(YType.enumeration, "addr-type")

                                self.ip = YLeaf(YType.str, "ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("addr_type",
                                                "ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.addr_type.is_set or
                                    self.ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.addr_type.yfilter != YFilter.not_set or
                                    self.ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.addr_type.is_set or self.addr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.addr_type.get_name_leafdata())
                                if (self.ip.is_set or self.ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "addr-type" or name == "ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "addr-type"):
                                    self.addr_type = value
                                    self.addr_type.value_namespace = name_space
                                    self.addr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip"):
                                    self.ip = value
                                    self.ip.value_namespace = name_space
                                    self.ip.value_namespace_prefix = name_space_prefix


                        class Nhaddr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:   :py:class:`L2FibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Nhaddr, self).__init__()

                                self.yang_name = "nhaddr"
                                self.yang_parent_name = "l2fib-mac-learning-mac-ipv4"

                                self.addr_type = YLeaf(YType.enumeration, "addr-type")

                                self.ip = YLeaf(YType.str, "ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("addr_type",
                                                "ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Nhaddr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Nhaddr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.addr_type.is_set or
                                    self.ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.addr_type.yfilter != YFilter.not_set or
                                    self.ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nhaddr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.addr_type.is_set or self.addr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.addr_type.get_name_leafdata())
                                if (self.ip.is_set or self.ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "addr-type" or name == "ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "addr-type"):
                                    self.addr_type = value
                                    self.addr_type.value_namespace = name_space
                                    self.addr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip"):
                                    self.ip = value
                                    self.ip.value_namespace = name_space
                                    self.ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.bdid.is_set or
                                self.element_type.is_set or
                                self.generation.is_set or
                                self.interface_handle.is_set or
                                self.interface_handle_xr.is_set or
                                self.mac_address.is_set or
                                self.mac_address_xr.is_set or
                                self.node_id.is_set or
                                self.topology_id.is_set or
                                self.xcid.is_set or
                                (self.addr is not None and self.addr.has_data()) or
                                (self.nhaddr is not None and self.nhaddr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.bdid.yfilter != YFilter.not_set or
                                self.element_type.yfilter != YFilter.not_set or
                                self.generation.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.interface_handle_xr.yfilter != YFilter.not_set or
                                self.mac_address.yfilter != YFilter.not_set or
                                self.mac_address_xr.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.topology_id.yfilter != YFilter.not_set or
                                self.xcid.yfilter != YFilter.not_set or
                                (self.addr is not None and self.addr.has_operation()) or
                                (self.nhaddr is not None and self.nhaddr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-mac-learning-mac-ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.bdid.is_set or self.bdid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bdid.get_name_leafdata())
                            if (self.element_type.is_set or self.element_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.element_type.get_name_leafdata())
                            if (self.generation.is_set or self.generation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.interface_handle_xr.is_set or self.interface_handle_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle_xr.get_name_leafdata())
                            if (self.mac_address.is_set or self.mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_address.get_name_leafdata())
                            if (self.mac_address_xr.is_set or self.mac_address_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_address_xr.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.topology_id.is_set or self.topology_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_id.get_name_leafdata())
                            if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xcid.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "addr"):
                                if (self.addr is None):
                                    self.addr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                return self.addr

                            if (child_yang_name == "nhaddr"):
                                if (self.nhaddr is None):
                                    self.nhaddr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4.Nhaddr()
                                    self.nhaddr.parent = self
                                    self._children_name_map["nhaddr"] = "nhaddr"
                                return self.nhaddr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "addr" or name == "nhaddr" or name == "address" or name == "bdid" or name == "element-type" or name == "generation" or name == "interface-handle" or name == "interface-handle-xr" or name == "mac-address" or name == "mac-address-xr" or name == "node-id" or name == "topology-id" or name == "xcid"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "bdid"):
                                self.bdid = value
                                self.bdid.value_namespace = name_space
                                self.bdid.value_namespace_prefix = name_space_prefix
                            if(value_path == "element-type"):
                                self.element_type = value
                                self.element_type.value_namespace = name_space
                                self.element_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation"):
                                self.generation = value
                                self.generation.value_namespace = name_space
                                self.generation.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle-xr"):
                                self.interface_handle_xr = value
                                self.interface_handle_xr.value_namespace = name_space
                                self.interface_handle_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-address"):
                                self.mac_address = value
                                self.mac_address.value_namespace = name_space
                                self.mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-address-xr"):
                                self.mac_address_xr = value
                                self.mac_address_xr.value_namespace = name_space
                                self.mac_address_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-id"):
                                self.topology_id = value
                                self.topology_id.value_namespace = name_space
                                self.topology_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "xcid"):
                                self.xcid = value
                                self.xcid.value_namespace = name_space
                                self.xcid.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.l2fib_mac_learning_mac_ipv4:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.l2fib_mac_learning_mac_ipv4:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mac-learning-mac-ipv4s" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2fib-mac-learning-mac-ipv4"):
                            for c in self.l2fib_mac_learning_mac_ipv4:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S.L2FibMacLearningMacIpv4()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.l2fib_mac_learning_mac_ipv4.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2fib-mac-learning-mac-ipv4"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class L2FibMacLearningMacIpv6S(Entity):
                    """
                    The L2VPN forwarding Mac IPV6 Learning Table
                    
                    .. attribute:: l2fib_mac_learning_mac_ipv6
                    
                    	The attributes for a particular learned IPV6 Mac Route
                    	**type**\: list of    :py:class:`L2FibMacLearningMacIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S, self).__init__()

                        self.yang_name = "l2fib-mac-learning-mac-ipv6s"
                        self.yang_parent_name = "l2fib-mac-learning"

                        self.l2fib_mac_learning_mac_ipv6 = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S, self).__setattr__(name, value)


                    class L2FibMacLearningMacIpv6(Entity):
                        """
                        The attributes for a particular learned IPV6
                        Mac Route
                        
                        .. attribute:: addr
                        
                        	IP Address
                        	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Addr>`
                        
                        .. attribute:: address
                        
                        	IP Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: element_type
                        
                        	Element Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: generation
                        
                        	HW MAC generation
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_handle_xr
                        
                        	Interface Handle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_address
                        
                        	MAC Address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: mac_address_xr
                        
                        	MAC Address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: nhaddr
                        
                        	IP Address
                        	**type**\:   :py:class:`Nhaddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Nhaddr>`
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: topology_id
                        
                        	Topology ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: xcid
                        
                        	Cross\-connect Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6, self).__init__()

                            self.yang_name = "l2fib-mac-learning-mac-ipv6"
                            self.yang_parent_name = "l2fib-mac-learning-mac-ipv6s"

                            self.address = YLeaf(YType.str, "address")

                            self.bdid = YLeaf(YType.int32, "bdid")

                            self.element_type = YLeaf(YType.uint8, "element-type")

                            self.generation = YLeaf(YType.uint8, "generation")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.interface_handle_xr = YLeaf(YType.uint32, "interface-handle-xr")

                            self.mac_address = YLeaf(YType.str, "mac-address")

                            self.mac_address_xr = YLeaf(YType.str, "mac-address-xr")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.topology_id = YLeaf(YType.uint32, "topology-id")

                            self.xcid = YLeaf(YType.uint32, "xcid")

                            self.addr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Addr()
                            self.addr.parent = self
                            self._children_name_map["addr"] = "addr"
                            self._children_yang_names.add("addr")

                            self.nhaddr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Nhaddr()
                            self.nhaddr.parent = self
                            self._children_name_map["nhaddr"] = "nhaddr"
                            self._children_yang_names.add("nhaddr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "bdid",
                                            "element_type",
                                            "generation",
                                            "interface_handle",
                                            "interface_handle_xr",
                                            "mac_address",
                                            "mac_address_xr",
                                            "node_id",
                                            "topology_id",
                                            "xcid") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6, self).__setattr__(name, value)


                        class Addr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:   :py:class:`L2FibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Addr, self).__init__()

                                self.yang_name = "addr"
                                self.yang_parent_name = "l2fib-mac-learning-mac-ipv6"

                                self.addr_type = YLeaf(YType.enumeration, "addr-type")

                                self.ip = YLeaf(YType.str, "ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("addr_type",
                                                "ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.addr_type.is_set or
                                    self.ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.addr_type.yfilter != YFilter.not_set or
                                    self.ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.addr_type.is_set or self.addr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.addr_type.get_name_leafdata())
                                if (self.ip.is_set or self.ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "addr-type" or name == "ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "addr-type"):
                                    self.addr_type = value
                                    self.addr_type.value_namespace = name_space
                                    self.addr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip"):
                                    self.ip = value
                                    self.ip.value_namespace = name_space
                                    self.ip.value_namespace_prefix = name_space_prefix


                        class Nhaddr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:   :py:class:`L2FibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Nhaddr, self).__init__()

                                self.yang_name = "nhaddr"
                                self.yang_parent_name = "l2fib-mac-learning-mac-ipv6"

                                self.addr_type = YLeaf(YType.enumeration, "addr-type")

                                self.ip = YLeaf(YType.str, "ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("addr_type",
                                                "ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Nhaddr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Nhaddr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.addr_type.is_set or
                                    self.ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.addr_type.yfilter != YFilter.not_set or
                                    self.ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nhaddr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.addr_type.is_set or self.addr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.addr_type.get_name_leafdata())
                                if (self.ip.is_set or self.ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "addr-type" or name == "ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "addr-type"):
                                    self.addr_type = value
                                    self.addr_type.value_namespace = name_space
                                    self.addr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip"):
                                    self.ip = value
                                    self.ip.value_namespace = name_space
                                    self.ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.bdid.is_set or
                                self.element_type.is_set or
                                self.generation.is_set or
                                self.interface_handle.is_set or
                                self.interface_handle_xr.is_set or
                                self.mac_address.is_set or
                                self.mac_address_xr.is_set or
                                self.node_id.is_set or
                                self.topology_id.is_set or
                                self.xcid.is_set or
                                (self.addr is not None and self.addr.has_data()) or
                                (self.nhaddr is not None and self.nhaddr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.bdid.yfilter != YFilter.not_set or
                                self.element_type.yfilter != YFilter.not_set or
                                self.generation.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.interface_handle_xr.yfilter != YFilter.not_set or
                                self.mac_address.yfilter != YFilter.not_set or
                                self.mac_address_xr.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.topology_id.yfilter != YFilter.not_set or
                                self.xcid.yfilter != YFilter.not_set or
                                (self.addr is not None and self.addr.has_operation()) or
                                (self.nhaddr is not None and self.nhaddr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-mac-learning-mac-ipv6" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.bdid.is_set or self.bdid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bdid.get_name_leafdata())
                            if (self.element_type.is_set or self.element_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.element_type.get_name_leafdata())
                            if (self.generation.is_set or self.generation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.interface_handle_xr.is_set or self.interface_handle_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle_xr.get_name_leafdata())
                            if (self.mac_address.is_set or self.mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_address.get_name_leafdata())
                            if (self.mac_address_xr.is_set or self.mac_address_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_address_xr.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.topology_id.is_set or self.topology_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_id.get_name_leafdata())
                            if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xcid.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "addr"):
                                if (self.addr is None):
                                    self.addr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                return self.addr

                            if (child_yang_name == "nhaddr"):
                                if (self.nhaddr is None):
                                    self.nhaddr = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6.Nhaddr()
                                    self.nhaddr.parent = self
                                    self._children_name_map["nhaddr"] = "nhaddr"
                                return self.nhaddr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "addr" or name == "nhaddr" or name == "address" or name == "bdid" or name == "element-type" or name == "generation" or name == "interface-handle" or name == "interface-handle-xr" or name == "mac-address" or name == "mac-address-xr" or name == "node-id" or name == "topology-id" or name == "xcid"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "bdid"):
                                self.bdid = value
                                self.bdid.value_namespace = name_space
                                self.bdid.value_namespace_prefix = name_space_prefix
                            if(value_path == "element-type"):
                                self.element_type = value
                                self.element_type.value_namespace = name_space
                                self.element_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation"):
                                self.generation = value
                                self.generation.value_namespace = name_space
                                self.generation.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle-xr"):
                                self.interface_handle_xr = value
                                self.interface_handle_xr.value_namespace = name_space
                                self.interface_handle_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-address"):
                                self.mac_address = value
                                self.mac_address.value_namespace = name_space
                                self.mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-address-xr"):
                                self.mac_address_xr = value
                                self.mac_address_xr.value_namespace = name_space
                                self.mac_address_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-id"):
                                self.topology_id = value
                                self.topology_id.value_namespace = name_space
                                self.topology_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "xcid"):
                                self.xcid = value
                                self.xcid.value_namespace = name_space
                                self.xcid.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.l2fib_mac_learning_mac_ipv6:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.l2fib_mac_learning_mac_ipv6:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mac-learning-mac-ipv6s" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2fib-mac-learning-mac-ipv6"):
                            for c in self.l2fib_mac_learning_mac_ipv6:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S.L2FibMacLearningMacIpv6()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.l2fib_mac_learning_mac_ipv6.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2fib-mac-learning-mac-ipv6"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.l2fib_mac_learning_mac_ipv4s is not None and self.l2fib_mac_learning_mac_ipv4s.has_data()) or
                        (self.l2fib_mac_learning_mac_ipv6s is not None and self.l2fib_mac_learning_mac_ipv6s.has_data()) or
                        (self.l2fib_mac_learning_macs is not None and self.l2fib_mac_learning_macs.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.l2fib_mac_learning_mac_ipv4s is not None and self.l2fib_mac_learning_mac_ipv4s.has_operation()) or
                        (self.l2fib_mac_learning_mac_ipv6s is not None and self.l2fib_mac_learning_mac_ipv6s.has_operation()) or
                        (self.l2fib_mac_learning_macs is not None and self.l2fib_mac_learning_macs.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-mac-learning" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-mac-learning-mac-ipv4s"):
                        if (self.l2fib_mac_learning_mac_ipv4s is None):
                            self.l2fib_mac_learning_mac_ipv4s = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv4S()
                            self.l2fib_mac_learning_mac_ipv4s.parent = self
                            self._children_name_map["l2fib_mac_learning_mac_ipv4s"] = "l2fib-mac-learning-mac-ipv4s"
                        return self.l2fib_mac_learning_mac_ipv4s

                    if (child_yang_name == "l2fib-mac-learning-mac-ipv6s"):
                        if (self.l2fib_mac_learning_mac_ipv6s is None):
                            self.l2fib_mac_learning_mac_ipv6s = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacIpv6S()
                            self.l2fib_mac_learning_mac_ipv6s.parent = self
                            self._children_name_map["l2fib_mac_learning_mac_ipv6s"] = "l2fib-mac-learning-mac-ipv6s"
                        return self.l2fib_mac_learning_mac_ipv6s

                    if (child_yang_name == "l2fib-mac-learning-macs"):
                        if (self.l2fib_mac_learning_macs is None):
                            self.l2fib_mac_learning_macs = L2VpnForwarding.Nodes.Node.L2FibMacLearning.L2FibMacLearningMacs()
                            self.l2fib_mac_learning_macs.parent = self
                            self._children_name_map["l2fib_mac_learning_macs"] = "l2fib-mac-learning-macs"
                        return self.l2fib_mac_learning_macs

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-mac-learning-mac-ipv4s" or name == "l2fib-mac-learning-mac-ipv6s" or name == "l2fib-mac-learning-macs"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibP2Mp(Entity):
                """
                p2mp information
                
                .. attribute:: ptrees
                
                	ptree information
                	**type**\:   :py:class:`Ptrees <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibP2Mp, self).__init__()

                    self.yang_name = "l2fib-p2mp"
                    self.yang_parent_name = "node"

                    self.ptrees = L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees()
                    self.ptrees.parent = self
                    self._children_name_map["ptrees"] = "ptrees"
                    self._children_yang_names.add("ptrees")


                class Ptrees(Entity):
                    """
                    ptree information
                    
                    .. attribute:: ptree
                    
                    	P2MP PTree Information
                    	**type**\: list of    :py:class:`Ptree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees.Ptree>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees, self).__init__()

                        self.yang_name = "ptrees"
                        self.yang_parent_name = "l2fib-p2mp"

                        self.ptree = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees, self).__setattr__(name, value)


                    class Ptree(Entity):
                        """
                        P2MP PTree Information
                        
                        .. attribute:: extended_tunnel_id
                        
                        	Extended Tunnel Id
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: extended_tunnel_id_xr
                        
                        	RSVPTE Ext Tunnel Id
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: lsm_id
                        
                        	LSM Id
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: lsm_id_xr
                        
                        	MLDP Lsm Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_id
                        
                        	P2MP Id
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: p2mp_id_xr
                        
                        	RSVPTE P2MP Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ptree_type
                        
                        	PTree Type
                        	**type**\:   :py:class:`L2Vpnp2MpPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnp2MpPtree>`
                        
                        .. attribute:: tunnel_id
                        
                        	Tunnel Id
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: tunnel_id_xr
                        
                        	RSVPTE Tunnel Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees.Ptree, self).__init__()

                            self.yang_name = "ptree"
                            self.yang_parent_name = "ptrees"

                            self.extended_tunnel_id = YLeaf(YType.int32, "extended-tunnel-id")

                            self.extended_tunnel_id_xr = YLeaf(YType.str, "extended-tunnel-id-xr")

                            self.lsm_id = YLeaf(YType.int32, "lsm-id")

                            self.lsm_id_xr = YLeaf(YType.uint32, "lsm-id-xr")

                            self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                            self.p2mp_id_xr = YLeaf(YType.uint32, "p2mp-id-xr")

                            self.ptree_type = YLeaf(YType.enumeration, "ptree-type")

                            self.tunnel_id = YLeaf(YType.int32, "tunnel-id")

                            self.tunnel_id_xr = YLeaf(YType.uint32, "tunnel-id-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "extended_tunnel_id_xr",
                                            "lsm_id",
                                            "lsm_id_xr",
                                            "p2mp_id",
                                            "p2mp_id_xr",
                                            "ptree_type",
                                            "tunnel_id",
                                            "tunnel_id_xr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees.Ptree, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees.Ptree, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.extended_tunnel_id_xr.is_set or
                                self.lsm_id.is_set or
                                self.lsm_id_xr.is_set or
                                self.p2mp_id.is_set or
                                self.p2mp_id_xr.is_set or
                                self.ptree_type.is_set or
                                self.tunnel_id.is_set or
                                self.tunnel_id_xr.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.extended_tunnel_id_xr.yfilter != YFilter.not_set or
                                self.lsm_id.yfilter != YFilter.not_set or
                                self.lsm_id_xr.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.p2mp_id_xr.yfilter != YFilter.not_set or
                                self.ptree_type.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id_xr.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ptree" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.extended_tunnel_id_xr.is_set or self.extended_tunnel_id_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id_xr.get_name_leafdata())
                            if (self.lsm_id.is_set or self.lsm_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsm_id.get_name_leafdata())
                            if (self.lsm_id_xr.is_set or self.lsm_id_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsm_id_xr.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.p2mp_id_xr.is_set or self.p2mp_id_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id_xr.get_name_leafdata())
                            if (self.ptree_type.is_set or self.ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ptree_type.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                            if (self.tunnel_id_xr.is_set or self.tunnel_id_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id_xr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "extended-tunnel-id-xr" or name == "lsm-id" or name == "lsm-id-xr" or name == "p2mp-id" or name == "p2mp-id-xr" or name == "ptree-type" or name == "tunnel-id" or name == "tunnel-id-xr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id-xr"):
                                self.extended_tunnel_id_xr = value
                                self.extended_tunnel_id_xr.value_namespace = name_space
                                self.extended_tunnel_id_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsm-id"):
                                self.lsm_id = value
                                self.lsm_id.value_namespace = name_space
                                self.lsm_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsm-id-xr"):
                                self.lsm_id_xr = value
                                self.lsm_id_xr.value_namespace = name_space
                                self.lsm_id_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id-xr"):
                                self.p2mp_id_xr = value
                                self.p2mp_id_xr.value_namespace = name_space
                                self.p2mp_id_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "ptree-type"):
                                self.ptree_type = value
                                self.ptree_type.value_namespace = name_space
                                self.ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id-xr"):
                                self.tunnel_id_xr = value
                                self.tunnel_id_xr.value_namespace = name_space
                                self.tunnel_id_xr.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ptree:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ptree:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ptrees" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ptree"):
                            for c in self.ptree:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees.Ptree()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ptree.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ptree"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.ptrees is not None and self.ptrees.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.ptrees is not None and self.ptrees.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-p2mp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ptrees"):
                        if (self.ptrees is None):
                            self.ptrees = L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees()
                            self.ptrees.parent = self
                            self._children_name_map["ptrees"] = "ptrees"
                        return self.ptrees

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ptrees"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibEvpnInclMCastHardwareEgresses(Entity):
                """
                L2VPN forwarding bridge\-domain evpn inclusive
                multicast hardware egress Table
                
                .. attribute:: l2fib_evpn_incl_m_cast_hardware_egress
                
                	Specify bridge domain name
                	**type**\: list of    :py:class:`L2FibEvpnInclMCastHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses, self).__init__()

                    self.yang_name = "l2fib-evpn-incl-m-cast-hardware-egresses"
                    self.yang_parent_name = "node"

                    self.l2fib_evpn_incl_m_cast_hardware_egress = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses, self).__setattr__(name, value)


                class L2FibEvpnInclMCastHardwareEgress(Entity):
                    """
                    Specify bridge domain name
                    
                    .. attribute:: bd_name  <key>
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: l2fib_evpn_incl_m_cast_oles
                    
                    	EVPN ingress mcast ole Information
                    	**type**\:   :py:class:`L2FibEvpnInclMCastOles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles>`
                    
                    .. attribute:: mcast_replication_list
                    
                    	Information of pbb\-evpn/evpn ingress mcast replication list for a particular bridge domain
                    	**type**\:   :py:class:`McastReplicationList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.McastReplicationList>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress, self).__init__()

                        self.yang_name = "l2fib-evpn-incl-m-cast-hardware-egress"
                        self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-egresses"

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.l2fib_evpn_incl_m_cast_oles = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles()
                        self.l2fib_evpn_incl_m_cast_oles.parent = self
                        self._children_name_map["l2fib_evpn_incl_m_cast_oles"] = "l2fib-evpn-incl-m-cast-oles"
                        self._children_yang_names.add("l2fib-evpn-incl-m-cast-oles")

                        self.mcast_replication_list = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.McastReplicationList()
                        self.mcast_replication_list.parent = self
                        self._children_name_map["mcast_replication_list"] = "mcast-replication-list"
                        self._children_yang_names.add("mcast-replication-list")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bd_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress, self).__setattr__(name, value)


                    class McastReplicationList(Entity):
                        """
                        Information of pbb\-evpn/evpn ingress mcast
                        replication list for a particular bridge domain
                        
                        .. attribute:: bridge_domain_id
                        
                        	bdid value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_domain_name
                        
                        	Bridge\-domain name
                        	**type**\:  str
                        
                        .. attribute:: is_bound
                        
                        	Is bound
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.McastReplicationList, self).__init__()

                            self.yang_name = "mcast-replication-list"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-egress"

                            self.bridge_domain_id = YLeaf(YType.uint32, "bridge-domain-id")

                            self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                            self.is_bound = YLeaf(YType.boolean, "is-bound")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bridge_domain_id",
                                            "bridge_domain_name",
                                            "is_bound") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.McastReplicationList, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.McastReplicationList, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bridge_domain_id.is_set or
                                self.bridge_domain_name.is_set or
                                self.is_bound.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bridge_domain_id.yfilter != YFilter.not_set or
                                self.bridge_domain_name.yfilter != YFilter.not_set or
                                self.is_bound.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mcast-replication-list" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bridge_domain_id.is_set or self.bridge_domain_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_domain_id.get_name_leafdata())
                            if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                            if (self.is_bound.is_set or self.is_bound.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bound.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-domain-id" or name == "bridge-domain-name" or name == "is-bound"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bridge-domain-id"):
                                self.bridge_domain_id = value
                                self.bridge_domain_id.value_namespace = name_space
                                self.bridge_domain_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-domain-name"):
                                self.bridge_domain_name = value
                                self.bridge_domain_name.value_namespace = name_space
                                self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bound"):
                                self.is_bound = value
                                self.is_bound.value_namespace = name_space
                                self.is_bound.value_namespace_prefix = name_space_prefix


                    class L2FibEvpnInclMCastOles(Entity):
                        """
                        EVPN ingress mcast ole Information
                        
                        .. attribute:: l2fib_evpn_incl_m_cast_ole
                        
                        	Information on a particular output path of the pbb\-evpn/evpn ingress replication list
                        	**type**\: list of    :py:class:`L2FibEvpnInclMCastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles, self).__init__()

                            self.yang_name = "l2fib-evpn-incl-m-cast-oles"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-egress"

                            self.l2fib_evpn_incl_m_cast_ole = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles, self).__setattr__(name, value)


                        class L2FibEvpnInclMCastOle(Entity):
                            """
                            Information on a particular output path of the
                            pbb\-evpn/evpn ingress replication list
                            
                            .. attribute:: next_hop_address  <key>
                            
                            	Next Hop Address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_bound
                            
                            	Is bound
                            	**type**\:  bool
                            
                            .. attribute:: mcast_ole
                            
                            	Mcast Ole Info
                            	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle, self).__init__()

                                self.yang_name = "l2fib-evpn-incl-m-cast-ole"
                                self.yang_parent_name = "l2fib-evpn-incl-m-cast-oles"

                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                self.is_bound = YLeaf(YType.boolean, "is-bound")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle()
                                self.mcast_ole.parent = self
                                self._children_name_map["mcast_ole"] = "mcast-ole"
                                self._children_yang_names.add("mcast-ole")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("next_hop_address",
                                                "is_bound",
                                                "next_hop_valid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle, self).__setattr__(name, value)


                            class McastOle(Entity):
                                """
                                Mcast Ole Info
                                
                                .. attribute:: mcast_label
                                
                                	Inclusive mcast label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ipv6_addr
                                
                                	Next Hop IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle, self).__init__()

                                    self.yang_name = "mcast-ole"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"

                                    self.mcast_label = YLeaf(YType.uint32, "mcast-label")

                                    self.next_hop_ipv6_addr = YLeaf(YType.str, "next-hop-ipv6-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mcast_label",
                                                    "next_hop_ipv6_addr") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.mcast_label.is_set or
                                        self.next_hop_ipv6_addr.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mcast_label.yfilter != YFilter.not_set or
                                        self.next_hop_ipv6_addr.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mcast-ole" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mcast_label.is_set or self.mcast_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mcast_label.get_name_leafdata())
                                    if (self.next_hop_ipv6_addr.is_set or self.next_hop_ipv6_addr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ipv6_addr.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mcast-label" or name == "next-hop-ipv6-addr"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mcast-label"):
                                        self.mcast_label = value
                                        self.mcast_label.value_namespace = name_space
                                        self.mcast_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ipv6-addr"):
                                        self.next_hop_ipv6_addr = value
                                        self.next_hop_ipv6_addr.value_namespace = name_space
                                        self.next_hop_ipv6_addr.value_namespace_prefix = name_space_prefix


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.next_hop_address.is_set or
                                    self.is_bound.is_set or
                                    self.next_hop_valid.is_set or
                                    (self.mcast_ole is not None and self.mcast_ole.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.next_hop_address.yfilter != YFilter.not_set or
                                    self.is_bound.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    (self.mcast_ole is not None and self.mcast_ole.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2fib-evpn-incl-m-cast-ole" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                if (self.is_bound.is_set or self.is_bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_bound.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mcast-ole"):
                                    if (self.mcast_ole is None):
                                        self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle()
                                        self.mcast_ole.parent = self
                                        self._children_name_map["mcast_ole"] = "mcast-ole"
                                    return self.mcast_ole

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mcast-ole" or name == "next-hop" or name == "next-hop-address" or name == "is-bound" or name == "next-hop-valid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "next-hop-address"):
                                    self.next_hop_address = value
                                    self.next_hop_address.value_namespace = name_space
                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-bound"):
                                    self.is_bound = value
                                    self.is_bound.value_namespace = name_space
                                    self.is_bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.l2fib_evpn_incl_m_cast_ole:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.l2fib_evpn_incl_m_cast_ole:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-evpn-incl-m-cast-oles" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "l2fib-evpn-incl-m-cast-ole"):
                                for c in self.l2fib_evpn_incl_m_cast_ole:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.l2fib_evpn_incl_m_cast_ole.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "l2fib-evpn-incl-m-cast-ole"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.bd_name.is_set or
                            (self.l2fib_evpn_incl_m_cast_oles is not None and self.l2fib_evpn_incl_m_cast_oles.has_data()) or
                            (self.mcast_replication_list is not None and self.mcast_replication_list.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            (self.l2fib_evpn_incl_m_cast_oles is not None and self.l2fib_evpn_incl_m_cast_oles.has_operation()) or
                            (self.mcast_replication_list is not None and self.mcast_replication_list.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-evpn-incl-m-cast-hardware-egress" + "[bd-name='" + self.bd_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2fib-evpn-incl-m-cast-oles"):
                            if (self.l2fib_evpn_incl_m_cast_oles is None):
                                self.l2fib_evpn_incl_m_cast_oles = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles()
                                self.l2fib_evpn_incl_m_cast_oles.parent = self
                                self._children_name_map["l2fib_evpn_incl_m_cast_oles"] = "l2fib-evpn-incl-m-cast-oles"
                            return self.l2fib_evpn_incl_m_cast_oles

                        if (child_yang_name == "mcast-replication-list"):
                            if (self.mcast_replication_list is None):
                                self.mcast_replication_list = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.McastReplicationList()
                                self.mcast_replication_list.parent = self
                                self._children_name_map["mcast_replication_list"] = "mcast-replication-list"
                            return self.mcast_replication_list

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2fib-evpn-incl-m-cast-oles" or name == "mcast-replication-list" or name == "bd-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_evpn_incl_m_cast_hardware_egress:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_evpn_incl_m_cast_hardware_egress:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-evpn-incl-m-cast-hardware-egresses" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-evpn-incl-m-cast-hardware-egress"):
                        for c in self.l2fib_evpn_incl_m_cast_hardware_egress:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_evpn_incl_m_cast_hardware_egress.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-evpn-incl-m-cast-hardware-egress"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibmacHardwareIngresses(Entity):
                """
                Bridge Hardware Ingress information
                
                .. attribute:: l2fibmac_hardware_ingress
                
                	MAC Hardware Ingress information
                	**type**\: list of    :py:class:`L2FibmacHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses, self).__init__()

                    self.yang_name = "l2fibmac-hardware-ingresses"
                    self.yang_parent_name = "node"

                    self.l2fibmac_hardware_ingress = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses, self).__setattr__(name, value)


                class L2FibmacHardwareIngress(Entity):
                    """
                    MAC Hardware Ingress information
                    
                    .. attribute:: address
                    
                    	Static MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Base>`
                    
                    .. attribute:: bmac_configured
                    
                    	Flag\: Configured BMAC
                    	**type**\:  bool
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge name
                    	**type**\:  str
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_ctx
                    
                    	Evpn Context
                    	**type**\:   :py:class:`EvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx>`
                    
                    .. attribute:: flag_extension
                    
                    	MAC Flag Extension
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: l3_encapsulationvlan_id
                    
                    	L3 encapsulation Vlan ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..27
                    
                    .. attribute:: next_hop
                    
                    	Next Hop
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop>`
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Nodeid list
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: pbb_bmac
                    
                    	Backbone MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: peer_vtep_ip
                    
                    	Peer VTEP IP for this MAC Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: platform_is_hw_learn
                    
                    	Platform is HW Learn
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:   :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment>`
                    
                    .. attribute:: vni
                    
                    	VNI Information
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_l3_flag
                    
                    	Flag\: L3 Vxlan
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress, self).__init__()

                        self.yang_name = "l2fibmac-hardware-ingress"
                        self.yang_parent_name = "l2fibmac-hardware-ingresses"

                        self.address = YLeaf(YType.str, "address")

                        self.bmac_configured = YLeaf(YType.boolean, "bmac-configured")

                        self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                        self.flag_extension = YLeaf(YType.uint16, "flag-extension")

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.l3_encapsulationvlan_id = YLeaf(YType.uint16, "l3-encapsulationvlan-id")

                        self.name = YLeaf(YType.str, "name")

                        self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                        self.node_id = YLeaf(YType.str, "node-id")

                        self.pbb_bmac = YLeaf(YType.str, "pbb-bmac")

                        self.peer_vtep_ip = YLeaf(YType.str, "peer-vtep-ip")

                        self.platform_is_hw_learn = YLeaf(YType.uint8, "platform-is-hw-learn")

                        self.vni = YLeaf(YType.uint32, "vni")

                        self.vni_l3_flag = YLeaf(YType.boolean, "vni-l3-flag")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                        self.evpn_ctx = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx()
                        self.evpn_ctx.parent = self
                        self._children_name_map["evpn_ctx"] = "evpn-ctx"
                        self._children_yang_names.add("evpn-ctx")

                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.segment = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment()
                        self.segment.parent = self
                        self._children_name_map["segment"] = "segment"
                        self._children_yang_names.add("segment")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "bmac_configured",
                                        "bridge_domain_name",
                                        "bridge_id",
                                        "flag_extension",
                                        "group_name",
                                        "l3_encapsulationvlan_id",
                                        "name",
                                        "next_hop_valid",
                                        "node_id",
                                        "pbb_bmac",
                                        "peer_vtep_ip",
                                        "platform_is_hw_learn",
                                        "vni",
                                        "vni_l3_flag") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibmac-hardware-ingress"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Segment(Entity):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Evpn>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment, self).__init__()

                            self.yang_name = "segment"
                            self.yang_parent_name = "l2fibmac-hardware-ingress"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"
                            self._children_yang_names.add("evpn")

                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"
                            self._children_yang_names.add("pbb")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                            self.vni = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"
                            self._children_yang_names.add("vni")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment"

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Ac, self).__setattr__(name, value)

                            def has_data(self):
                                return self.interface_handle.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment"

                                self.xcid = YLeaf(YType.uint32, "xcid")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pbb, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pbb, self).__setattr__(name, value)

                            def has_data(self):
                                return self.xcid.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment"

                                self.parent_if = YLeaf(YType.str, "parent-if")

                                self.xcid = YLeaf(YType.uint32, "xcid")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("parent_if",
                                                "xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Vni, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Vni, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.parent_if.is_set or
                                    self.xcid.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.parent_if.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vni" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.parent_if.is_set or self.parent_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_if.get_name_leafdata())
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parent-if" or name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "parent-if"):
                                    self.parent_if = value
                                    self.parent_if.value_namespace = name_space
                                    self.parent_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment"

                                self.xcid = YLeaf(YType.uint32, "xcid")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Evpn, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Evpn, self).__setattr__(name, value)

                            def has_data(self):
                                return self.xcid.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment"

                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("next_hop_address",
                                                "pseudo_wire_id_type",
                                                "pw_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.next_hop_address.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.next_hop_address.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "pseudo-wire-id-type" or name == "pw-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "next-hop-address"):
                                    self.next_hop_address = value
                                    self.next_hop_address.value_namespace = name_space
                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.evpn is not None and self.evpn.has_data()) or
                                (self.pbb is not None and self.pbb.has_data()) or
                                (self.pw is not None and self.pw.has_data()) or
                                (self.vni is not None and self.vni.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.evpn is not None and self.evpn.has_operation()) or
                                (self.pbb is not None and self.pbb.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()) or
                                (self.vni is not None and self.vni.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "evpn"):
                                if (self.evpn is None):
                                    self.evpn = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Evpn()
                                    self.evpn.parent = self
                                    self._children_name_map["evpn"] = "evpn"
                                return self.evpn

                            if (child_yang_name == "pbb"):
                                if (self.pbb is None):
                                    self.pbb = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pbb()
                                    self.pbb.parent = self
                                    self._children_name_map["pbb"] = "pbb"
                                return self.pbb

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            if (child_yang_name == "vni"):
                                if (self.vni is None):
                                    self.vni = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Vni()
                                    self.vni.parent = self
                                    self._children_name_map["vni"] = "vni"
                                return self.vni

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "evpn" or name == "pbb" or name == "pw" or name == "vni" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix


                    class EvpnCtx(Entity):
                        """
                        Evpn Context
                        
                        .. attribute:: bp_ifh
                        
                        	BP IFH
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibBridgeMacEvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeMacEvpnCtx>`
                        
                        .. attribute:: esi_id
                        
                        	EsiID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: local_label
                        
                        	LocalLabel
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mcast_ole
                        
                        	mcast ole
                        	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx.McastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx, self).__init__()

                            self.yang_name = "evpn-ctx"
                            self.yang_parent_name = "l2fibmac-hardware-ingress"

                            self.bp_ifh = YLeaf(YType.str, "bp-ifh")

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.esi_id = YLeaf(YType.uint16, "esi-id")

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx.McastOle()
                            self.mcast_ole.parent = self
                            self._children_name_map["mcast_ole"] = "mcast-ole"
                            self._children_yang_names.add("mcast-ole")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bp_ifh",
                                            "data_type",
                                            "esi_id",
                                            "local_label") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx, self).__setattr__(name, value)


                        class McastOle(Entity):
                            """
                            mcast ole
                            
                            .. attribute:: mcast_label
                            
                            	Inclusive mcast label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ipv6_addr
                            
                            	Next Hop IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx.McastOle, self).__init__()

                                self.yang_name = "mcast-ole"
                                self.yang_parent_name = "evpn-ctx"

                                self.mcast_label = YLeaf(YType.uint32, "mcast-label")

                                self.next_hop_ipv6_addr = YLeaf(YType.str, "next-hop-ipv6-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mcast_label",
                                                "next_hop_ipv6_addr") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx.McastOle, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx.McastOle, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.mcast_label.is_set or
                                    self.next_hop_ipv6_addr.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mcast_label.yfilter != YFilter.not_set or
                                    self.next_hop_ipv6_addr.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mcast-ole" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mcast_label.is_set or self.mcast_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mcast_label.get_name_leafdata())
                                if (self.next_hop_ipv6_addr.is_set or self.next_hop_ipv6_addr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ipv6_addr.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mcast-label" or name == "next-hop-ipv6-addr"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mcast-label"):
                                    self.mcast_label = value
                                    self.mcast_label.value_namespace = name_space
                                    self.mcast_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ipv6-addr"):
                                    self.next_hop_ipv6_addr = value
                                    self.next_hop_ipv6_addr.value_namespace = name_space
                                    self.next_hop_ipv6_addr.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bp_ifh.is_set or
                                self.data_type.is_set or
                                self.esi_id.is_set or
                                self.local_label.is_set or
                                (self.mcast_ole is not None and self.mcast_ole.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bp_ifh.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                self.esi_id.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                (self.mcast_ole is not None and self.mcast_ole.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "evpn-ctx" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bp_ifh.is_set or self.bp_ifh.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bp_ifh.get_name_leafdata())
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())
                            if (self.esi_id.is_set or self.esi_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.esi_id.get_name_leafdata())
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mcast-ole"):
                                if (self.mcast_ole is None):
                                    self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx.McastOle()
                                    self.mcast_ole.parent = self
                                    self._children_name_map["mcast_ole"] = "mcast-ole"
                                return self.mcast_ole

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mcast-ole" or name == "bp-ifh" or name == "data-type" or name == "esi-id" or name == "local-label"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bp-ifh"):
                                self.bp_ifh = value
                                self.bp_ifh.value_namespace = name_space
                                self.bp_ifh.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "esi-id"):
                                self.esi_id = value
                                self.esi_id.value_namespace = name_space
                                self.esi_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix


                    class NextHop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: base
                        
                        	Base Information
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop.Base>`
                        
                        .. attribute:: children_count
                        
                        	Children Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_address
                        
                        	NHOP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_internal_label
                        
                        	NHOP Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: plaformt_data_valid
                        
                        	Is Platform Data Valid
                        	**type**\:  bool
                        
                        .. attribute:: platform_data_length
                        
                        	Platform Data Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "l2fibmac-hardware-ingress"

                            self.children_count = YLeaf(YType.uint32, "children-count")

                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                            self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                            self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                            self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                            self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._children_yang_names.add("base")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("children_count",
                                            "next_hop_address",
                                            "next_hop_internal_label",
                                            "plaformt_data_valid",
                                            "platform_data_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop, self).__setattr__(name, value)


                        class Base(Entity):
                            """
                            Base Information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "next-hop"

                            def has_data(self):
                                return False

                            def has_operation(self):
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "base" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.children_count.is_set or
                                self.next_hop_address.is_set or
                                self.next_hop_internal_label.is_set or
                                self.plaformt_data_valid.is_set or
                                self.platform_data_length.is_set or
                                (self.base is not None and self.base.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.children_count.yfilter != YFilter.not_set or
                                self.next_hop_address.yfilter != YFilter.not_set or
                                self.next_hop_internal_label.yfilter != YFilter.not_set or
                                self.plaformt_data_valid.yfilter != YFilter.not_set or
                                self.platform_data_length.yfilter != YFilter.not_set or
                                (self.base is not None and self.base.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "next-hop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.children_count.get_name_leafdata())
                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                            if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                            if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                            if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "base"):
                                if (self.base is None):
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                return self.base

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "children-count"):
                                self.children_count = value
                                self.children_count.value_namespace = name_space
                                self.children_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-address"):
                                self.next_hop_address = value
                                self.next_hop_address.value_namespace = name_space
                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-internal-label"):
                                self.next_hop_internal_label = value
                                self.next_hop_internal_label.value_namespace = name_space
                                self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "plaformt-data-valid"):
                                self.plaformt_data_valid = value
                                self.plaformt_data_valid.value_namespace = name_space
                                self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                            if(value_path == "platform-data-length"):
                                self.platform_data_length = value
                                self.platform_data_length.value_namespace = name_space
                                self.platform_data_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.bmac_configured.is_set or
                            self.bridge_domain_name.is_set or
                            self.bridge_id.is_set or
                            self.flag_extension.is_set or
                            self.group_name.is_set or
                            self.l3_encapsulationvlan_id.is_set or
                            self.name.is_set or
                            self.next_hop_valid.is_set or
                            self.node_id.is_set or
                            self.pbb_bmac.is_set or
                            self.peer_vtep_ip.is_set or
                            self.platform_is_hw_learn.is_set or
                            self.vni.is_set or
                            self.vni_l3_flag.is_set or
                            (self.base is not None and self.base.has_data()) or
                            (self.evpn_ctx is not None and self.evpn_ctx.has_data()) or
                            (self.next_hop is not None and self.next_hop.has_data()) or
                            (self.segment is not None and self.segment.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.bmac_configured.yfilter != YFilter.not_set or
                            self.bridge_domain_name.yfilter != YFilter.not_set or
                            self.bridge_id.yfilter != YFilter.not_set or
                            self.flag_extension.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.l3_encapsulationvlan_id.yfilter != YFilter.not_set or
                            self.name.yfilter != YFilter.not_set or
                            self.next_hop_valid.yfilter != YFilter.not_set or
                            self.node_id.yfilter != YFilter.not_set or
                            self.pbb_bmac.yfilter != YFilter.not_set or
                            self.peer_vtep_ip.yfilter != YFilter.not_set or
                            self.platform_is_hw_learn.yfilter != YFilter.not_set or
                            self.vni.yfilter != YFilter.not_set or
                            self.vni_l3_flag.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()) or
                            (self.evpn_ctx is not None and self.evpn_ctx.has_operation()) or
                            (self.next_hop is not None and self.next_hop.has_operation()) or
                            (self.segment is not None and self.segment.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fibmac-hardware-ingress" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.bmac_configured.is_set or self.bmac_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bmac_configured.get_name_leafdata())
                        if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                        if (self.flag_extension.is_set or self.flag_extension.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flag_extension.get_name_leafdata())
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.l3_encapsulationvlan_id.is_set or self.l3_encapsulationvlan_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.l3_encapsulationvlan_id.get_name_leafdata())
                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.name.get_name_leafdata())
                        if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                        if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_id.get_name_leafdata())
                        if (self.pbb_bmac.is_set or self.pbb_bmac.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pbb_bmac.get_name_leafdata())
                        if (self.peer_vtep_ip.is_set or self.peer_vtep_ip.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.peer_vtep_ip.get_name_leafdata())
                        if (self.platform_is_hw_learn.is_set or self.platform_is_hw_learn.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.platform_is_hw_learn.get_name_leafdata())
                        if (self.vni.is_set or self.vni.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni.get_name_leafdata())
                        if (self.vni_l3_flag.is_set or self.vni_l3_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_l3_flag.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        if (child_yang_name == "evpn-ctx"):
                            if (self.evpn_ctx is None):
                                self.evpn_ctx = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx()
                                self.evpn_ctx.parent = self
                                self._children_name_map["evpn_ctx"] = "evpn-ctx"
                            return self.evpn_ctx

                        if (child_yang_name == "next-hop"):
                            if (self.next_hop is None):
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                            return self.next_hop

                        if (child_yang_name == "segment"):
                            if (self.segment is None):
                                self.segment = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment()
                                self.segment.parent = self
                                self._children_name_map["segment"] = "segment"
                            return self.segment

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "evpn-ctx" or name == "next-hop" or name == "segment" or name == "address" or name == "bmac-configured" or name == "bridge-domain-name" or name == "bridge-id" or name == "flag-extension" or name == "group-name" or name == "l3-encapsulationvlan-id" or name == "name" or name == "next-hop-valid" or name == "node-id" or name == "pbb-bmac" or name == "peer-vtep-ip" or name == "platform-is-hw-learn" or name == "vni" or name == "vni-l3-flag"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "bmac-configured"):
                            self.bmac_configured = value
                            self.bmac_configured.value_namespace = name_space
                            self.bmac_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-name"):
                            self.bridge_domain_name = value
                            self.bridge_domain_name.value_namespace = name_space
                            self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-id"):
                            self.bridge_id = value
                            self.bridge_id.value_namespace = name_space
                            self.bridge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "flag-extension"):
                            self.flag_extension = value
                            self.flag_extension.value_namespace = name_space
                            self.flag_extension.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "l3-encapsulationvlan-id"):
                            self.l3_encapsulationvlan_id = value
                            self.l3_encapsulationvlan_id.value_namespace = name_space
                            self.l3_encapsulationvlan_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "name"):
                            self.name = value
                            self.name.value_namespace = name_space
                            self.name.value_namespace_prefix = name_space_prefix
                        if(value_path == "next-hop-valid"):
                            self.next_hop_valid = value
                            self.next_hop_valid.value_namespace = name_space
                            self.next_hop_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-id"):
                            self.node_id = value
                            self.node_id.value_namespace = name_space
                            self.node_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "pbb-bmac"):
                            self.pbb_bmac = value
                            self.pbb_bmac.value_namespace = name_space
                            self.pbb_bmac.value_namespace_prefix = name_space_prefix
                        if(value_path == "peer-vtep-ip"):
                            self.peer_vtep_ip = value
                            self.peer_vtep_ip.value_namespace = name_space
                            self.peer_vtep_ip.value_namespace_prefix = name_space_prefix
                        if(value_path == "platform-is-hw-learn"):
                            self.platform_is_hw_learn = value
                            self.platform_is_hw_learn.value_namespace = name_space
                            self.platform_is_hw_learn.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni"):
                            self.vni = value
                            self.vni.value_namespace = name_space
                            self.vni.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni-l3-flag"):
                            self.vni_l3_flag = value
                            self.vni_l3_flag.value_namespace = name_space
                            self.vni_l3_flag.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fibmac_hardware_ingress:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fibmac_hardware_ingress:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fibmac-hardware-ingresses" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fibmac-hardware-ingress"):
                        for c in self.l2fibmac_hardware_ingress:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fibmac_hardware_ingress.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fibmac-hardware-ingress"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibEvpnIp4Macs(Entity):
                """
                EVPN IPv4\-MAC Table
                
                .. attribute:: l2fib_evpn_ip4mac
                
                	The attributes for a particular EVPN IPv4\-MAC Entry
                	**type**\: list of    :py:class:`L2FibEvpnIp4Mac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs, self).__init__()

                    self.yang_name = "l2fib-evpn-ip4macs"
                    self.yang_parent_name = "node"

                    self.l2fib_evpn_ip4mac = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs, self).__setattr__(name, value)


                class L2FibEvpnIp4Mac(Entity):
                    """
                    The attributes for a particular EVPN IPv4\-MAC
                    Entry
                    
                    .. attribute:: arp_nd_delete_pending
                    
                    	Delete to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: arp_nd_probe_pending
                    
                    	Probe to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: arp_nd_sync_pending
                    
                    	Sync to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: bdid
                    
                    	BD ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: bdid_xr
                    
                    	BD ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ip_address
                    
                    	IP Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: ip_address_xr
                    
                    	IP Address
                    	**type**\:   :py:class:`IpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac.IpAddressXr>`
                    
                    .. attribute:: is_local
                    
                    	Entry is locally learned
                    	**type**\:  bool
                    
                    .. attribute:: is_local_xr
                    
                    	IP\-MAC Route is locally learned
                    	**type**\:  bool
                    
                    .. attribute:: mac_address
                    
                    	MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: mac_address_xr
                    
                    	MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac, self).__init__()

                        self.yang_name = "l2fib-evpn-ip4mac"
                        self.yang_parent_name = "l2fib-evpn-ip4macs"

                        self.arp_nd_delete_pending = YLeaf(YType.boolean, "arp-nd-delete-pending")

                        self.arp_nd_probe_pending = YLeaf(YType.boolean, "arp-nd-probe-pending")

                        self.arp_nd_sync_pending = YLeaf(YType.boolean, "arp-nd-sync-pending")

                        self.bdid = YLeaf(YType.int32, "bdid")

                        self.bdid_xr = YLeaf(YType.uint32, "bdid-xr")

                        self.ip_address = YLeaf(YType.str, "ip-address")

                        self.is_local = YLeaf(YType.boolean, "is-local")

                        self.is_local_xr = YLeaf(YType.boolean, "is-local-xr")

                        self.mac_address = YLeaf(YType.str, "mac-address")

                        self.mac_address_xr = YLeaf(YType.str, "mac-address-xr")

                        self.ip_address_xr = L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac.IpAddressXr()
                        self.ip_address_xr.parent = self
                        self._children_name_map["ip_address_xr"] = "ip-address-xr"
                        self._children_yang_names.add("ip-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("arp_nd_delete_pending",
                                        "arp_nd_probe_pending",
                                        "arp_nd_sync_pending",
                                        "bdid",
                                        "bdid_xr",
                                        "ip_address",
                                        "is_local",
                                        "is_local_xr",
                                        "mac_address",
                                        "mac_address_xr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac, self).__setattr__(name, value)


                    class IpAddressXr(Entity):
                        """
                        IP Address
                        
                        .. attribute:: addr_type
                        
                        	addr type
                        	**type**\:   :py:class:`L2FibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibIpAddr>`
                        
                        .. attribute:: ip
                        
                        	ip
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac.IpAddressXr, self).__init__()

                            self.yang_name = "ip-address-xr"
                            self.yang_parent_name = "l2fib-evpn-ip4mac"

                            self.addr_type = YLeaf(YType.enumeration, "addr-type")

                            self.ip = YLeaf(YType.str, "ip")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("addr_type",
                                            "ip") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac.IpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac.IpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.addr_type.is_set or
                                self.ip.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.addr_type.yfilter != YFilter.not_set or
                                self.ip.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ip-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.addr_type.is_set or self.addr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.addr_type.get_name_leafdata())
                            if (self.ip.is_set or self.ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ip.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "addr-type" or name == "ip"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "addr-type"):
                                self.addr_type = value
                                self.addr_type.value_namespace = name_space
                                self.addr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "ip"):
                                self.ip = value
                                self.ip.value_namespace = name_space
                                self.ip.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.arp_nd_delete_pending.is_set or
                            self.arp_nd_probe_pending.is_set or
                            self.arp_nd_sync_pending.is_set or
                            self.bdid.is_set or
                            self.bdid_xr.is_set or
                            self.ip_address.is_set or
                            self.is_local.is_set or
                            self.is_local_xr.is_set or
                            self.mac_address.is_set or
                            self.mac_address_xr.is_set or
                            (self.ip_address_xr is not None and self.ip_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.arp_nd_delete_pending.yfilter != YFilter.not_set or
                            self.arp_nd_probe_pending.yfilter != YFilter.not_set or
                            self.arp_nd_sync_pending.yfilter != YFilter.not_set or
                            self.bdid.yfilter != YFilter.not_set or
                            self.bdid_xr.yfilter != YFilter.not_set or
                            self.ip_address.yfilter != YFilter.not_set or
                            self.is_local.yfilter != YFilter.not_set or
                            self.is_local_xr.yfilter != YFilter.not_set or
                            self.mac_address.yfilter != YFilter.not_set or
                            self.mac_address_xr.yfilter != YFilter.not_set or
                            (self.ip_address_xr is not None and self.ip_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-evpn-ip4mac" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.arp_nd_delete_pending.is_set or self.arp_nd_delete_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.arp_nd_delete_pending.get_name_leafdata())
                        if (self.arp_nd_probe_pending.is_set or self.arp_nd_probe_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.arp_nd_probe_pending.get_name_leafdata())
                        if (self.arp_nd_sync_pending.is_set or self.arp_nd_sync_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.arp_nd_sync_pending.get_name_leafdata())
                        if (self.bdid.is_set or self.bdid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bdid.get_name_leafdata())
                        if (self.bdid_xr.is_set or self.bdid_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bdid_xr.get_name_leafdata())
                        if (self.ip_address.is_set or self.ip_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ip_address.get_name_leafdata())
                        if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_local.get_name_leafdata())
                        if (self.is_local_xr.is_set or self.is_local_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_local_xr.get_name_leafdata())
                        if (self.mac_address.is_set or self.mac_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_address.get_name_leafdata())
                        if (self.mac_address_xr.is_set or self.mac_address_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_address_xr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ip-address-xr"):
                            if (self.ip_address_xr is None):
                                self.ip_address_xr = L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac.IpAddressXr()
                                self.ip_address_xr.parent = self
                                self._children_name_map["ip_address_xr"] = "ip-address-xr"
                            return self.ip_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ip-address-xr" or name == "arp-nd-delete-pending" or name == "arp-nd-probe-pending" or name == "arp-nd-sync-pending" or name == "bdid" or name == "bdid-xr" or name == "ip-address" or name == "is-local" or name == "is-local-xr" or name == "mac-address" or name == "mac-address-xr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "arp-nd-delete-pending"):
                            self.arp_nd_delete_pending = value
                            self.arp_nd_delete_pending.value_namespace = name_space
                            self.arp_nd_delete_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "arp-nd-probe-pending"):
                            self.arp_nd_probe_pending = value
                            self.arp_nd_probe_pending.value_namespace = name_space
                            self.arp_nd_probe_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "arp-nd-sync-pending"):
                            self.arp_nd_sync_pending = value
                            self.arp_nd_sync_pending.value_namespace = name_space
                            self.arp_nd_sync_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "bdid"):
                            self.bdid = value
                            self.bdid.value_namespace = name_space
                            self.bdid.value_namespace_prefix = name_space_prefix
                        if(value_path == "bdid-xr"):
                            self.bdid_xr = value
                            self.bdid_xr.value_namespace = name_space
                            self.bdid_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "ip-address"):
                            self.ip_address = value
                            self.ip_address.value_namespace = name_space
                            self.ip_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-local"):
                            self.is_local = value
                            self.is_local.value_namespace = name_space
                            self.is_local.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-local-xr"):
                            self.is_local_xr = value
                            self.is_local_xr.value_namespace = name_space
                            self.is_local_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-address"):
                            self.mac_address = value
                            self.mac_address.value_namespace = name_space
                            self.mac_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-address-xr"):
                            self.mac_address_xr = value
                            self.mac_address_xr.value_namespace = name_space
                            self.mac_address_xr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_evpn_ip4mac:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_evpn_ip4mac:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-evpn-ip4macs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-evpn-ip4mac"):
                        for c in self.l2fib_evpn_ip4mac:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_evpn_ip4mac.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-evpn-ip4mac"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibPwheMainPorts(Entity):
                """
                PWHE Main\-port table
                
                .. attribute:: l2fib_pwhe_main_port
                
                	PWHE Main\-port
                	**type**\: list of    :py:class:`L2FibPwheMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts.L2FibPwheMainPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts, self).__init__()

                    self.yang_name = "l2fib-pwhe-main-ports"
                    self.yang_parent_name = "node"

                    self.l2fib_pwhe_main_port = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts, self).__setattr__(name, value)


                class L2FibPwheMainPort(Entity):
                    """
                    PWHE Main\-port
                    
                    .. attribute:: interface_name  <key>
                    
                    	PWHE Main\-port
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: control_word_enabled
                    
                    	Control Word Enabled
                    	**type**\:  bool
                    
                    .. attribute:: generic_interface_list_id
                    
                    	Generic Interface List ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: internal_label
                    
                    	Internal label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: next_hop_address
                    
                    	Next Hop Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\:  bool
                    
                    .. attribute:: pseudo_wire_type
                    
                    	Pseudowire type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_label
                    
                    	Remote label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts.L2FibPwheMainPort, self).__init__()

                        self.yang_name = "l2fib-pwhe-main-port"
                        self.yang_parent_name = "l2fib-pwhe-main-ports"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.control_word_enabled = YLeaf(YType.boolean, "control-word-enabled")

                        self.generic_interface_list_id = YLeaf(YType.uint32, "generic-interface-list-id")

                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                        self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                        self.pseudo_wire_type = YLeaf(YType.uint32, "pseudo-wire-type")

                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "control_word_enabled",
                                        "generic_interface_list_id",
                                        "internal_label",
                                        "next_hop_address",
                                        "next_hop_valid",
                                        "pseudo_wire_type",
                                        "remote_label") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts.L2FibPwheMainPort, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts.L2FibPwheMainPort, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.control_word_enabled.is_set or
                            self.generic_interface_list_id.is_set or
                            self.internal_label.is_set or
                            self.next_hop_address.is_set or
                            self.next_hop_valid.is_set or
                            self.pseudo_wire_type.is_set or
                            self.remote_label.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.control_word_enabled.yfilter != YFilter.not_set or
                            self.generic_interface_list_id.yfilter != YFilter.not_set or
                            self.internal_label.yfilter != YFilter.not_set or
                            self.next_hop_address.yfilter != YFilter.not_set or
                            self.next_hop_valid.yfilter != YFilter.not_set or
                            self.pseudo_wire_type.yfilter != YFilter.not_set or
                            self.remote_label.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-pwhe-main-port" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.control_word_enabled.is_set or self.control_word_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.control_word_enabled.get_name_leafdata())
                        if (self.generic_interface_list_id.is_set or self.generic_interface_list_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_interface_list_id.get_name_leafdata())
                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                        if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                        if (self.pseudo_wire_type.is_set or self.pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_type.get_name_leafdata())
                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_label.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "control-word-enabled" or name == "generic-interface-list-id" or name == "internal-label" or name == "next-hop-address" or name == "next-hop-valid" or name == "pseudo-wire-type" or name == "remote-label"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "control-word-enabled"):
                            self.control_word_enabled = value
                            self.control_word_enabled.value_namespace = name_space
                            self.control_word_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "generic-interface-list-id"):
                            self.generic_interface_list_id = value
                            self.generic_interface_list_id.value_namespace = name_space
                            self.generic_interface_list_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "internal-label"):
                            self.internal_label = value
                            self.internal_label.value_namespace = name_space
                            self.internal_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "next-hop-address"):
                            self.next_hop_address = value
                            self.next_hop_address.value_namespace = name_space
                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "next-hop-valid"):
                            self.next_hop_valid = value
                            self.next_hop_valid.value_namespace = name_space
                            self.next_hop_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-type"):
                            self.pseudo_wire_type = value
                            self.pseudo_wire_type.value_namespace = name_space
                            self.pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-label"):
                            self.remote_label = value
                            self.remote_label.value_namespace = name_space
                            self.remote_label.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_pwhe_main_port:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_pwhe_main_port:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-pwhe-main-ports" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-pwhe-main-port"):
                        for c in self.l2fib_pwhe_main_port:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts.L2FibPwheMainPort()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_pwhe_main_port.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-pwhe-main-port"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibDhcpBindingCount(Entity):
                """
                DHCP binding forwarding total count
                
                .. attribute:: bindings
                
                	DHCP binding count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingCount, self).__init__()

                    self.yang_name = "l2fib-dhcp-binding-count"
                    self.yang_parent_name = "node"

                    self.bindings = YLeaf(YType.uint32, "bindings")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bindings") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingCount, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingCount, self).__setattr__(name, value)

                def has_data(self):
                    return self.bindings.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bindings.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-dhcp-binding-count" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bindings.is_set or self.bindings.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bindings.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bindings"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bindings"):
                        self.bindings = value
                        self.bindings.value_namespace = name_space
                        self.bindings.value_namespace_prefix = name_space_prefix


            class L2FibBridgeDomains(Entity):
                """
                Bridge Domain forwarding detail
                
                .. attribute:: l2fib_bridge_domain
                
                	Specify Bridge Domain Name
                	**type**\: list of    :py:class:`L2FibBridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains, self).__init__()

                    self.yang_name = "l2fib-bridge-domains"
                    self.yang_parent_name = "node"

                    self.l2fib_bridge_domain = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains, self).__setattr__(name, value)


                class L2FibBridgeDomain(Entity):
                    """
                    Specify Bridge Domain Name
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Base>`
                    
                    .. attribute:: bd_group_name
                    
                    	Name of the Bridge group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bd_pbb_union
                    
                    	Union of bridge Edge and Core info
                    	**type**\:   :py:class:`BdPbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion>`
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_name
                    
                    	Bridge name
                    	**type**\:  str
                    
                    .. attribute:: bridge_port_count
                    
                    	Number of bridge ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_type
                    
                    	Bridge Type
                    	**type**\:   :py:class:`MgmtL2FibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridge>`
                    
                    .. attribute:: bvi_info
                    
                    	BVI Information
                    	**type**\:   :py:class:`BviInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BviInfo>`
                    
                    .. attribute:: learn_key
                    
                    	Learn Key
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_of_hwmac
                    
                    	Number of HW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_swmac
                    
                    	Number of SW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: oper
                    
                    	Operational information
                    	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper>`
                    
                    .. attribute:: p2mppw_info
                    
                    	P2MP PW Information
                    	**type**\:   :py:class:`P2MppwInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo>`
                    
                    .. attribute:: shg_count
                    
                    	Number of split horizon groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain, self).__init__()

                        self.yang_name = "l2fib-bridge-domain"
                        self.yang_parent_name = "l2fib-bridge-domains"

                        self.bd_group_name = YLeaf(YType.str, "bd-group-name")

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                        self.bridge_name = YLeaf(YType.str, "bridge-name")

                        self.bridge_port_count = YLeaf(YType.uint32, "bridge-port-count")

                        self.bridge_type = YLeaf(YType.enumeration, "bridge-type")

                        self.learn_key = YLeaf(YType.uint8, "learn-key")

                        self.number_of_hwmac = YLeaf(YType.uint32, "number-of-hwmac")

                        self.number_of_swmac = YLeaf(YType.uint32, "number-of-swmac")

                        self.shg_count = YLeaf(YType.uint32, "shg-count")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                        self.bd_pbb_union = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion()
                        self.bd_pbb_union.parent = self
                        self._children_name_map["bd_pbb_union"] = "bd-pbb-union"
                        self._children_yang_names.add("bd-pbb-union")

                        self.bvi_info = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BviInfo()
                        self.bvi_info.parent = self
                        self._children_name_map["bvi_info"] = "bvi-info"
                        self._children_yang_names.add("bvi-info")

                        self.oper = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper()
                        self.oper.parent = self
                        self._children_name_map["oper"] = "oper"
                        self._children_yang_names.add("oper")

                        self.p2mppw_info = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo()
                        self.p2mppw_info.parent = self
                        self._children_name_map["p2mppw_info"] = "p2mppw-info"
                        self._children_yang_names.add("p2mppw-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bd_group_name",
                                        "bd_name",
                                        "bridge_id",
                                        "bridge_name",
                                        "bridge_port_count",
                                        "bridge_type",
                                        "learn_key",
                                        "number_of_hwmac",
                                        "number_of_swmac",
                                        "shg_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fib-bridge-domain"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Oper(Entity):
                        """
                        Operational information
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: operational_information
                        
                        	L2 operational information
                        	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper, self).__init__()

                            self.yang_name = "oper"
                            self.yang_parent_name = "l2fib-bridge-domain"

                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                            self.operational_information = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation()
                            self.operational_information.parent = self
                            self._children_name_map["operational_information"] = "operational-information"
                            self._children_yang_names.add("operational-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("broadcast_storm_control_kb_ps",
                                            "broadcast_storm_control_pps",
                                            "multicast_storm_control_kb_ps",
                                            "multicast_storm_control_pps",
                                            "unicast_storm_control_kb_ps",
                                            "unicast_storm_control_pps") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper, self).__setattr__(name, value)


                        class OperationalInformation(Entity):
                            """
                            L2 operational information
                            
                            .. attribute:: admin_disabled
                            
                            	Is administratively disabled
                            	**type**\:  bool
                            
                            .. attribute:: bvi_configured
                            
                            	Is BVI Interface configured
                            	**type**\:  bool
                            
                            .. attribute:: dhcp_enabled
                            
                            	Is DHCP snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: dhcp_trusted
                            
                            	Is DHCP trusted
                            	**type**\:  bool
                            
                            .. attribute:: feature
                            
                            	Feature information
                            	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature>`
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Is flooding unknown unicast disabled
                            	**type**\:  bool
                            
                            .. attribute:: flooding_disabled
                            
                            	Is flooding disabled
                            	**type**\:  bool
                            
                            .. attribute:: host_routing_enabled
                            
                            	Host Routing enabled on this BD
                            	**type**\:  bool
                            
                            .. attribute:: igmp_flood_forward_enabled
                            
                            	Is IGMP flood forwarding enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\:  bool
                            
                            .. attribute:: igmp_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_snoop_enabled
                            
                            	Is IGMP snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_snoop_profile_enabled
                            
                            	Is IGMP snooping profile enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_bvi_up
                            
                            	Is BVI state UP
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_destination_mac_enabled
                            
                            	Is DAI Destination MAC Validation enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_ipv4_enabled
                            
                            	Is DAI IPv4 Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_cw_disable
                            
                            	Is EVPN CW disabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_enabled
                            
                            	Is EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_flow_label
                            
                            	Is EVPN Flow Label enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_igmp_snoop_enabled
                            
                            	Is IGMP Snooping admin enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown
                            
                            	Is MAC secure accept shutdown (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_p2mp_pw_enabled
                            
                            	Is P2MP PW enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_pbbevpn_enabled
                            
                            	Is PBBEVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_swmac_learning
                            
                            	Is SW MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_vni_enabled
                            
                            	Is VNI enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_vpls_flood_optimization_enabled
                            
                            	Is MMRP  Flood Optimization Enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in minutes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: minute
                            
                            .. attribute:: mac_aging_type
                            
                            	MAC aging type
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning_disabled
                            
                            	Is MAC learning disabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`MgmtL2FibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitAction>`
                            
                            .. attribute:: mac_limit_notification_type
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`MgmtL2FibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotify>`
                            
                            .. attribute:: mac_port_down_flush_disabled
                            
                            	Is MAC port down flush disabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC secure action
                            	**type**\:   :py:class:`MgmtL2FibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecAction>`
                            
                            .. attribute:: mld_flood_forward_enabled
                            
                            	Is MLD flood forwarding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\:  bool
                            
                            .. attribute:: mld_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_snoop_enabled
                            
                            	Is MLD snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_snoop_profile_enabled
                            
                            	Is MLD snooping profile enabled
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	Multi\-spanning tree instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_macs
                            
                            	numberOfMacs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                            
                            	nV Satellite Offload IPv4 Multicast Disabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_broadcast_enabled
                            
                            	Is broadcast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_broadcast_rate_unit
                            
                            	Storm control broadcast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                            
                            .. attribute:: storm_control_multicast_enabled
                            
                            	Is multicast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_multicast_rate_unit
                            
                            	Storm control multicast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                            
                            .. attribute:: storm_control_unicast_enabled
                            
                            	Is unicast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_unicast_rate_unit
                            
                            	Storm control unicast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                            
                            .. attribute:: stp_participating
                            
                            	Is Spanning Tree Protocol participating
                            	**type**\:  bool
                            
                            .. attribute:: unknown_unicast_flooding_disabled
                            
                            	Unknown Unicast Flooding is disabled
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation, self).__init__()

                                self.yang_name = "operational-information"
                                self.yang_parent_name = "oper"

                                self.admin_disabled = YLeaf(YType.boolean, "admin-disabled")

                                self.bvi_configured = YLeaf(YType.boolean, "bvi-configured")

                                self.dhcp_enabled = YLeaf(YType.boolean, "dhcp-enabled")

                                self.dhcp_trusted = YLeaf(YType.boolean, "dhcp-trusted")

                                self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                self.flooding_disabled = YLeaf(YType.boolean, "flooding-disabled")

                                self.host_routing_enabled = YLeaf(YType.boolean, "host-routing-enabled")

                                self.igmp_flood_forward_enabled = YLeaf(YType.boolean, "igmp-flood-forward-enabled")

                                self.igmp_mroute_port_enabled = YLeaf(YType.boolean, "igmp-mroute-port-enabled")

                                self.igmp_route_guard_enabled = YLeaf(YType.boolean, "igmp-route-guard-enabled")

                                self.igmp_snoop_enabled = YLeaf(YType.boolean, "igmp-snoop-enabled")

                                self.igmp_snoop_profile_enabled = YLeaf(YType.boolean, "igmp-snoop-profile-enabled")

                                self.is_bvi_up = YLeaf(YType.boolean, "is-bvi-up")

                                self.is_dai_addr_validation_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-destination-mac-enabled")

                                self.is_dai_addr_validation_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-ipv4-enabled")

                                self.is_dai_addr_validation_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-source-mac-enabled")

                                self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                self.is_evpn_cw_disable = YLeaf(YType.boolean, "is-evpn-cw-disable")

                                self.is_evpn_enabled = YLeaf(YType.boolean, "is-evpn-enabled")

                                self.is_evpn_flow_label = YLeaf(YType.boolean, "is-evpn-flow-label")

                                self.is_igmp_snoop_enabled = YLeaf(YType.boolean, "is-igmp-snoop-enabled")

                                self.is_ipsg_enabled = YLeaf(YType.boolean, "is-ipsg-enabled")

                                self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                self.is_mac_secure_accept_shutdown = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown")

                                self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                self.is_p2mp_pw_enabled = YLeaf(YType.boolean, "is-p2mp-pw-enabled")

                                self.is_pbbevpn_enabled = YLeaf(YType.boolean, "is-pbbevpn-enabled")

                                self.is_swmac_learning = YLeaf(YType.boolean, "is-swmac-learning")

                                self.is_vni_enabled = YLeaf(YType.boolean, "is-vni-enabled")

                                self.is_vpls_flood_optimization_enabled = YLeaf(YType.boolean, "is-vpls-flood-optimization-enabled")

                                self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                self.mac_aging_type = YLeaf(YType.boolean, "mac-aging-type")

                                self.mac_learning_disabled = YLeaf(YType.boolean, "mac-learning-disabled")

                                self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                self.mac_limit_notification_type = YLeaf(YType.enumeration, "mac-limit-notification-type")

                                self.mac_port_down_flush_disabled = YLeaf(YType.boolean, "mac-port-down-flush-disabled")

                                self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                self.mld_flood_forward_enabled = YLeaf(YType.boolean, "mld-flood-forward-enabled")

                                self.mld_mroute_port_enabled = YLeaf(YType.boolean, "mld-mroute-port-enabled")

                                self.mld_route_guard_enabled = YLeaf(YType.boolean, "mld-route-guard-enabled")

                                self.mld_snoop_enabled = YLeaf(YType.boolean, "mld-snoop-enabled")

                                self.mld_snoop_profile_enabled = YLeaf(YType.boolean, "mld-snoop-profile-enabled")

                                self.msti = YLeaf(YType.uint32, "msti")

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.number_of_macs = YLeaf(YType.uint32, "number-of-macs")

                                self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                                self.storm_control_broadcast_enabled = YLeaf(YType.boolean, "storm-control-broadcast-enabled")

                                self.storm_control_broadcast_rate_unit = YLeaf(YType.enumeration, "storm-control-broadcast-rate-unit")

                                self.storm_control_multicast_enabled = YLeaf(YType.boolean, "storm-control-multicast-enabled")

                                self.storm_control_multicast_rate_unit = YLeaf(YType.enumeration, "storm-control-multicast-rate-unit")

                                self.storm_control_unicast_enabled = YLeaf(YType.boolean, "storm-control-unicast-enabled")

                                self.storm_control_unicast_rate_unit = YLeaf(YType.enumeration, "storm-control-unicast-rate-unit")

                                self.stp_participating = YLeaf(YType.boolean, "stp-participating")

                                self.unknown_unicast_flooding_disabled = YLeaf(YType.boolean, "unknown-unicast-flooding-disabled")

                                self.feature = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("admin_disabled",
                                                "bvi_configured",
                                                "dhcp_enabled",
                                                "dhcp_trusted",
                                                "flood_unknown_unicast_enabled",
                                                "flooding_disabled",
                                                "host_routing_enabled",
                                                "igmp_flood_forward_enabled",
                                                "igmp_mroute_port_enabled",
                                                "igmp_route_guard_enabled",
                                                "igmp_snoop_enabled",
                                                "igmp_snoop_profile_enabled",
                                                "is_bvi_up",
                                                "is_dai_addr_validation_destination_mac_enabled",
                                                "is_dai_addr_validation_ipv4_enabled",
                                                "is_dai_addr_validation_source_mac_enabled",
                                                "is_dai_enabled",
                                                "is_dai_logging_enabled",
                                                "is_evpn_cw_disable",
                                                "is_evpn_enabled",
                                                "is_evpn_flow_label",
                                                "is_igmp_snoop_enabled",
                                                "is_ipsg_enabled",
                                                "is_ipsg_logging_enabled",
                                                "is_mac_secure_accept_shutdown",
                                                "is_mac_secure_enabled",
                                                "is_mac_secure_logging_enabled",
                                                "is_p2mp_pw_enabled",
                                                "is_pbbevpn_enabled",
                                                "is_swmac_learning",
                                                "is_vni_enabled",
                                                "is_vpls_flood_optimization_enabled",
                                                "mac_aging_time",
                                                "mac_aging_type",
                                                "mac_learning_disabled",
                                                "mac_limit",
                                                "mac_limit_action",
                                                "mac_limit_notification_type",
                                                "mac_port_down_flush_disabled",
                                                "mac_secure_action",
                                                "mld_flood_forward_enabled",
                                                "mld_mroute_port_enabled",
                                                "mld_route_guard_enabled",
                                                "mld_snoop_enabled",
                                                "mld_snoop_profile_enabled",
                                                "msti",
                                                "mtu",
                                                "number_of_macs",
                                                "nv_satellite_offload_ipv4_multicast_disabled",
                                                "storm_control_broadcast_enabled",
                                                "storm_control_broadcast_rate_unit",
                                                "storm_control_multicast_enabled",
                                                "storm_control_multicast_rate_unit",
                                                "storm_control_unicast_enabled",
                                                "storm_control_unicast_rate_unit",
                                                "stp_participating",
                                                "unknown_unicast_flooding_disabled") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation, self).__setattr__(name, value)


                            class Feature(Entity):
                                """
                                Feature information
                                
                                .. attribute:: dhcp
                                
                                	dhcp
                                	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp>`
                                
                                .. attribute:: feature_type
                                
                                	feature type
                                	**type**\:   :py:class:`L2FibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeature>`
                                
                                .. attribute:: igmp
                                
                                	igmp
                                	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Igmp>`
                                
                                .. attribute:: mld
                                
                                	mld
                                	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Mld>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature, self).__init__()

                                    self.yang_name = "feature"
                                    self.yang_parent_name = "operational-information"

                                    self.feature_type = YLeaf(YType.enumeration, "feature-type")

                                    self.dhcp = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp()
                                    self.dhcp.parent = self
                                    self._children_name_map["dhcp"] = "dhcp"
                                    self._children_yang_names.add("dhcp")

                                    self.igmp = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Igmp()
                                    self.igmp.parent = self
                                    self._children_name_map["igmp"] = "igmp"
                                    self._children_yang_names.add("igmp")

                                    self.mld = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Mld()
                                    self.mld.parent = self
                                    self._children_name_map["mld"] = "mld"
                                    self._children_yang_names.add("mld")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("feature_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature, self).__setattr__(name, value)


                                class Dhcp(Entity):
                                    """
                                    dhcp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                        self.yang_name = "dhcp"
                                        self.yang_parent_name = "feature"

                                        self.profile_name = YLeaf(YType.str, "profile-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("profile_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.profile_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.profile_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dhcp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.profile_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "profile-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "profile-name"):
                                            self.profile_name = value
                                            self.profile_name.value_namespace = name_space
                                            self.profile_name.value_namespace_prefix = name_space_prefix


                                class Igmp(Entity):
                                    """
                                    igmp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                        self.yang_name = "igmp"
                                        self.yang_parent_name = "feature"

                                        self.profile_name = YLeaf(YType.str, "profile-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("profile_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.profile_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.profile_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "igmp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.profile_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "profile-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "profile-name"):
                                            self.profile_name = value
                                            self.profile_name.value_namespace = name_space
                                            self.profile_name.value_namespace_prefix = name_space_prefix


                                class Mld(Entity):
                                    """
                                    mld
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                        self.yang_name = "mld"
                                        self.yang_parent_name = "feature"

                                        self.profile_name = YLeaf(YType.str, "profile-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("profile_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.profile_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.profile_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mld" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.profile_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "profile-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "profile-name"):
                                            self.profile_name = value
                                            self.profile_name.value_namespace = name_space
                                            self.profile_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.feature_type.is_set or
                                        (self.dhcp is not None and self.dhcp.has_data()) or
                                        (self.igmp is not None and self.igmp.has_data()) or
                                        (self.mld is not None and self.mld.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.feature_type.yfilter != YFilter.not_set or
                                        (self.dhcp is not None and self.dhcp.has_operation()) or
                                        (self.igmp is not None and self.igmp.has_operation()) or
                                        (self.mld is not None and self.mld.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "feature" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.feature_type.is_set or self.feature_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.feature_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dhcp"):
                                        if (self.dhcp is None):
                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self._children_name_map["dhcp"] = "dhcp"
                                        return self.dhcp

                                    if (child_yang_name == "igmp"):
                                        if (self.igmp is None):
                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self._children_name_map["igmp"] = "igmp"
                                        return self.igmp

                                    if (child_yang_name == "mld"):
                                        if (self.mld is None):
                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self
                                            self._children_name_map["mld"] = "mld"
                                        return self.mld

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dhcp" or name == "igmp" or name == "mld" or name == "feature-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "feature-type"):
                                        self.feature_type = value
                                        self.feature_type.value_namespace = name_space
                                        self.feature_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.feature:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.admin_disabled.is_set or
                                    self.bvi_configured.is_set or
                                    self.dhcp_enabled.is_set or
                                    self.dhcp_trusted.is_set or
                                    self.flood_unknown_unicast_enabled.is_set or
                                    self.flooding_disabled.is_set or
                                    self.host_routing_enabled.is_set or
                                    self.igmp_flood_forward_enabled.is_set or
                                    self.igmp_mroute_port_enabled.is_set or
                                    self.igmp_route_guard_enabled.is_set or
                                    self.igmp_snoop_enabled.is_set or
                                    self.igmp_snoop_profile_enabled.is_set or
                                    self.is_bvi_up.is_set or
                                    self.is_dai_addr_validation_destination_mac_enabled.is_set or
                                    self.is_dai_addr_validation_ipv4_enabled.is_set or
                                    self.is_dai_addr_validation_source_mac_enabled.is_set or
                                    self.is_dai_enabled.is_set or
                                    self.is_dai_logging_enabled.is_set or
                                    self.is_evpn_cw_disable.is_set or
                                    self.is_evpn_enabled.is_set or
                                    self.is_evpn_flow_label.is_set or
                                    self.is_igmp_snoop_enabled.is_set or
                                    self.is_ipsg_enabled.is_set or
                                    self.is_ipsg_logging_enabled.is_set or
                                    self.is_mac_secure_accept_shutdown.is_set or
                                    self.is_mac_secure_enabled.is_set or
                                    self.is_mac_secure_logging_enabled.is_set or
                                    self.is_p2mp_pw_enabled.is_set or
                                    self.is_pbbevpn_enabled.is_set or
                                    self.is_swmac_learning.is_set or
                                    self.is_vni_enabled.is_set or
                                    self.is_vpls_flood_optimization_enabled.is_set or
                                    self.mac_aging_time.is_set or
                                    self.mac_aging_type.is_set or
                                    self.mac_learning_disabled.is_set or
                                    self.mac_limit.is_set or
                                    self.mac_limit_action.is_set or
                                    self.mac_limit_notification_type.is_set or
                                    self.mac_port_down_flush_disabled.is_set or
                                    self.mac_secure_action.is_set or
                                    self.mld_flood_forward_enabled.is_set or
                                    self.mld_mroute_port_enabled.is_set or
                                    self.mld_route_guard_enabled.is_set or
                                    self.mld_snoop_enabled.is_set or
                                    self.mld_snoop_profile_enabled.is_set or
                                    self.msti.is_set or
                                    self.mtu.is_set or
                                    self.number_of_macs.is_set or
                                    self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                                    self.storm_control_broadcast_enabled.is_set or
                                    self.storm_control_broadcast_rate_unit.is_set or
                                    self.storm_control_multicast_enabled.is_set or
                                    self.storm_control_multicast_rate_unit.is_set or
                                    self.storm_control_unicast_enabled.is_set or
                                    self.storm_control_unicast_rate_unit.is_set or
                                    self.stp_participating.is_set or
                                    self.unknown_unicast_flooding_disabled.is_set)

                            def has_operation(self):
                                for c in self.feature:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.admin_disabled.yfilter != YFilter.not_set or
                                    self.bvi_configured.yfilter != YFilter.not_set or
                                    self.dhcp_enabled.yfilter != YFilter.not_set or
                                    self.dhcp_trusted.yfilter != YFilter.not_set or
                                    self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                    self.flooding_disabled.yfilter != YFilter.not_set or
                                    self.host_routing_enabled.yfilter != YFilter.not_set or
                                    self.igmp_flood_forward_enabled.yfilter != YFilter.not_set or
                                    self.igmp_mroute_port_enabled.yfilter != YFilter.not_set or
                                    self.igmp_route_guard_enabled.yfilter != YFilter.not_set or
                                    self.igmp_snoop_enabled.yfilter != YFilter.not_set or
                                    self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set or
                                    self.is_bvi_up.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_evpn_cw_disable.yfilter != YFilter.not_set or
                                    self.is_evpn_enabled.yfilter != YFilter.not_set or
                                    self.is_evpn_flow_label.yfilter != YFilter.not_set or
                                    self.is_igmp_snoop_enabled.yfilter != YFilter.not_set or
                                    self.is_ipsg_enabled.yfilter != YFilter.not_set or
                                    self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set or
                                    self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_p2mp_pw_enabled.yfilter != YFilter.not_set or
                                    self.is_pbbevpn_enabled.yfilter != YFilter.not_set or
                                    self.is_swmac_learning.yfilter != YFilter.not_set or
                                    self.is_vni_enabled.yfilter != YFilter.not_set or
                                    self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set or
                                    self.mac_aging_time.yfilter != YFilter.not_set or
                                    self.mac_aging_type.yfilter != YFilter.not_set or
                                    self.mac_learning_disabled.yfilter != YFilter.not_set or
                                    self.mac_limit.yfilter != YFilter.not_set or
                                    self.mac_limit_action.yfilter != YFilter.not_set or
                                    self.mac_limit_notification_type.yfilter != YFilter.not_set or
                                    self.mac_port_down_flush_disabled.yfilter != YFilter.not_set or
                                    self.mac_secure_action.yfilter != YFilter.not_set or
                                    self.mld_flood_forward_enabled.yfilter != YFilter.not_set or
                                    self.mld_mroute_port_enabled.yfilter != YFilter.not_set or
                                    self.mld_route_guard_enabled.yfilter != YFilter.not_set or
                                    self.mld_snoop_enabled.yfilter != YFilter.not_set or
                                    self.mld_snoop_profile_enabled.yfilter != YFilter.not_set or
                                    self.msti.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.number_of_macs.yfilter != YFilter.not_set or
                                    self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                                    self.storm_control_broadcast_enabled.yfilter != YFilter.not_set or
                                    self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set or
                                    self.storm_control_multicast_enabled.yfilter != YFilter.not_set or
                                    self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set or
                                    self.storm_control_unicast_enabled.yfilter != YFilter.not_set or
                                    self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set or
                                    self.stp_participating.yfilter != YFilter.not_set or
                                    self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "operational-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.admin_disabled.is_set or self.admin_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admin_disabled.get_name_leafdata())
                                if (self.bvi_configured.is_set or self.bvi_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_configured.get_name_leafdata())
                                if (self.dhcp_enabled.is_set or self.dhcp_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcp_enabled.get_name_leafdata())
                                if (self.dhcp_trusted.is_set or self.dhcp_trusted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcp_trusted.get_name_leafdata())
                                if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                if (self.flooding_disabled.is_set or self.flooding_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flooding_disabled.get_name_leafdata())
                                if (self.host_routing_enabled.is_set or self.host_routing_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.host_routing_enabled.get_name_leafdata())
                                if (self.igmp_flood_forward_enabled.is_set or self.igmp_flood_forward_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_flood_forward_enabled.get_name_leafdata())
                                if (self.igmp_mroute_port_enabled.is_set or self.igmp_mroute_port_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_mroute_port_enabled.get_name_leafdata())
                                if (self.igmp_route_guard_enabled.is_set or self.igmp_route_guard_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_route_guard_enabled.get_name_leafdata())
                                if (self.igmp_snoop_enabled.is_set or self.igmp_snoop_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_snoop_enabled.get_name_leafdata())
                                if (self.igmp_snoop_profile_enabled.is_set or self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_snoop_profile_enabled.get_name_leafdata())
                                if (self.is_bvi_up.is_set or self.is_bvi_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_bvi_up.get_name_leafdata())
                                if (self.is_dai_addr_validation_destination_mac_enabled.is_set or self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validation_destination_mac_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validation_ipv4_enabled.is_set or self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validation_ipv4_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validation_source_mac_enabled.is_set or self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validation_source_mac_enabled.get_name_leafdata())
                                if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                if (self.is_evpn_cw_disable.is_set or self.is_evpn_cw_disable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpn_cw_disable.get_name_leafdata())
                                if (self.is_evpn_enabled.is_set or self.is_evpn_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpn_enabled.get_name_leafdata())
                                if (self.is_evpn_flow_label.is_set or self.is_evpn_flow_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpn_flow_label.get_name_leafdata())
                                if (self.is_igmp_snoop_enabled.is_set or self.is_igmp_snoop_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_igmp_snoop_enabled.get_name_leafdata())
                                if (self.is_ipsg_enabled.is_set or self.is_ipsg_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ipsg_enabled.get_name_leafdata())
                                if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                if (self.is_mac_secure_accept_shutdown.is_set or self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_accept_shutdown.get_name_leafdata())
                                if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                if (self.is_p2mp_pw_enabled.is_set or self.is_p2mp_pw_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_p2mp_pw_enabled.get_name_leafdata())
                                if (self.is_pbbevpn_enabled.is_set or self.is_pbbevpn_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pbbevpn_enabled.get_name_leafdata())
                                if (self.is_swmac_learning.is_set or self.is_swmac_learning.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_swmac_learning.get_name_leafdata())
                                if (self.is_vni_enabled.is_set or self.is_vni_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vni_enabled.get_name_leafdata())
                                if (self.is_vpls_flood_optimization_enabled.is_set or self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vpls_flood_optimization_enabled.get_name_leafdata())
                                if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                if (self.mac_aging_type.is_set or self.mac_aging_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_type.get_name_leafdata())
                                if (self.mac_learning_disabled.is_set or self.mac_learning_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_learning_disabled.get_name_leafdata())
                                if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                if (self.mac_limit_notification_type.is_set or self.mac_limit_notification_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_notification_type.get_name_leafdata())
                                if (self.mac_port_down_flush_disabled.is_set or self.mac_port_down_flush_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_port_down_flush_disabled.get_name_leafdata())
                                if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                if (self.mld_flood_forward_enabled.is_set or self.mld_flood_forward_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_flood_forward_enabled.get_name_leafdata())
                                if (self.mld_mroute_port_enabled.is_set or self.mld_mroute_port_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_mroute_port_enabled.get_name_leafdata())
                                if (self.mld_route_guard_enabled.is_set or self.mld_route_guard_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_route_guard_enabled.get_name_leafdata())
                                if (self.mld_snoop_enabled.is_set or self.mld_snoop_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_snoop_enabled.get_name_leafdata())
                                if (self.mld_snoop_profile_enabled.is_set or self.mld_snoop_profile_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_snoop_profile_enabled.get_name_leafdata())
                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.number_of_macs.is_set or self.number_of_macs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_of_macs.get_name_leafdata())
                                if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                                if (self.storm_control_broadcast_enabled.is_set or self.storm_control_broadcast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_broadcast_enabled.get_name_leafdata())
                                if (self.storm_control_broadcast_rate_unit.is_set or self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_broadcast_rate_unit.get_name_leafdata())
                                if (self.storm_control_multicast_enabled.is_set or self.storm_control_multicast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_multicast_enabled.get_name_leafdata())
                                if (self.storm_control_multicast_rate_unit.is_set or self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_multicast_rate_unit.get_name_leafdata())
                                if (self.storm_control_unicast_enabled.is_set or self.storm_control_unicast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_unicast_enabled.get_name_leafdata())
                                if (self.storm_control_unicast_rate_unit.is_set or self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_unicast_rate_unit.get_name_leafdata())
                                if (self.stp_participating.is_set or self.stp_participating.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stp_participating.get_name_leafdata())
                                if (self.unknown_unicast_flooding_disabled.is_set or self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_unicast_flooding_disabled.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "feature"):
                                    for c in self.feature:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.feature.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "feature" or name == "admin-disabled" or name == "bvi-configured" or name == "dhcp-enabled" or name == "dhcp-trusted" or name == "flood-unknown-unicast-enabled" or name == "flooding-disabled" or name == "host-routing-enabled" or name == "igmp-flood-forward-enabled" or name == "igmp-mroute-port-enabled" or name == "igmp-route-guard-enabled" or name == "igmp-snoop-enabled" or name == "igmp-snoop-profile-enabled" or name == "is-bvi-up" or name == "is-dai-addr-validation-destination-mac-enabled" or name == "is-dai-addr-validation-ipv4-enabled" or name == "is-dai-addr-validation-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-evpn-cw-disable" or name == "is-evpn-enabled" or name == "is-evpn-flow-label" or name == "is-igmp-snoop-enabled" or name == "is-ipsg-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "is-p2mp-pw-enabled" or name == "is-pbbevpn-enabled" or name == "is-swmac-learning" or name == "is-vni-enabled" or name == "is-vpls-flood-optimization-enabled" or name == "mac-aging-time" or name == "mac-aging-type" or name == "mac-learning-disabled" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification-type" or name == "mac-port-down-flush-disabled" or name == "mac-secure-action" or name == "mld-flood-forward-enabled" or name == "mld-mroute-port-enabled" or name == "mld-route-guard-enabled" or name == "mld-snoop-enabled" or name == "mld-snoop-profile-enabled" or name == "msti" or name == "mtu" or name == "number-of-macs" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "storm-control-broadcast-enabled" or name == "storm-control-broadcast-rate-unit" or name == "storm-control-multicast-enabled" or name == "storm-control-multicast-rate-unit" or name == "storm-control-unicast-enabled" or name == "storm-control-unicast-rate-unit" or name == "stp-participating" or name == "unknown-unicast-flooding-disabled"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "admin-disabled"):
                                    self.admin_disabled = value
                                    self.admin_disabled.value_namespace = name_space
                                    self.admin_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-configured"):
                                    self.bvi_configured = value
                                    self.bvi_configured.value_namespace = name_space
                                    self.bvi_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcp-enabled"):
                                    self.dhcp_enabled = value
                                    self.dhcp_enabled.value_namespace = name_space
                                    self.dhcp_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcp-trusted"):
                                    self.dhcp_trusted = value
                                    self.dhcp_trusted.value_namespace = name_space
                                    self.dhcp_trusted.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-unknown-unicast-enabled"):
                                    self.flood_unknown_unicast_enabled = value
                                    self.flood_unknown_unicast_enabled.value_namespace = name_space
                                    self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "flooding-disabled"):
                                    self.flooding_disabled = value
                                    self.flooding_disabled.value_namespace = name_space
                                    self.flooding_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "host-routing-enabled"):
                                    self.host_routing_enabled = value
                                    self.host_routing_enabled.value_namespace = name_space
                                    self.host_routing_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-flood-forward-enabled"):
                                    self.igmp_flood_forward_enabled = value
                                    self.igmp_flood_forward_enabled.value_namespace = name_space
                                    self.igmp_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-mroute-port-enabled"):
                                    self.igmp_mroute_port_enabled = value
                                    self.igmp_mroute_port_enabled.value_namespace = name_space
                                    self.igmp_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-route-guard-enabled"):
                                    self.igmp_route_guard_enabled = value
                                    self.igmp_route_guard_enabled.value_namespace = name_space
                                    self.igmp_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-snoop-enabled"):
                                    self.igmp_snoop_enabled = value
                                    self.igmp_snoop_enabled.value_namespace = name_space
                                    self.igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-snoop-profile-enabled"):
                                    self.igmp_snoop_profile_enabled = value
                                    self.igmp_snoop_profile_enabled.value_namespace = name_space
                                    self.igmp_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-bvi-up"):
                                    self.is_bvi_up = value
                                    self.is_bvi_up.value_namespace = name_space
                                    self.is_bvi_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validation-destination-mac-enabled"):
                                    self.is_dai_addr_validation_destination_mac_enabled = value
                                    self.is_dai_addr_validation_destination_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validation_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validation-ipv4-enabled"):
                                    self.is_dai_addr_validation_ipv4_enabled = value
                                    self.is_dai_addr_validation_ipv4_enabled.value_namespace = name_space
                                    self.is_dai_addr_validation_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validation-source-mac-enabled"):
                                    self.is_dai_addr_validation_source_mac_enabled = value
                                    self.is_dai_addr_validation_source_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validation_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-enabled"):
                                    self.is_dai_enabled = value
                                    self.is_dai_enabled.value_namespace = name_space
                                    self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-logging-enabled"):
                                    self.is_dai_logging_enabled = value
                                    self.is_dai_logging_enabled.value_namespace = name_space
                                    self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpn-cw-disable"):
                                    self.is_evpn_cw_disable = value
                                    self.is_evpn_cw_disable.value_namespace = name_space
                                    self.is_evpn_cw_disable.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpn-enabled"):
                                    self.is_evpn_enabled = value
                                    self.is_evpn_enabled.value_namespace = name_space
                                    self.is_evpn_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpn-flow-label"):
                                    self.is_evpn_flow_label = value
                                    self.is_evpn_flow_label.value_namespace = name_space
                                    self.is_evpn_flow_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-igmp-snoop-enabled"):
                                    self.is_igmp_snoop_enabled = value
                                    self.is_igmp_snoop_enabled.value_namespace = name_space
                                    self.is_igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ipsg-enabled"):
                                    self.is_ipsg_enabled = value
                                    self.is_ipsg_enabled.value_namespace = name_space
                                    self.is_ipsg_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ipsg-logging-enabled"):
                                    self.is_ipsg_logging_enabled = value
                                    self.is_ipsg_logging_enabled.value_namespace = name_space
                                    self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-accept-shutdown"):
                                    self.is_mac_secure_accept_shutdown = value
                                    self.is_mac_secure_accept_shutdown.value_namespace = name_space
                                    self.is_mac_secure_accept_shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-enabled"):
                                    self.is_mac_secure_enabled = value
                                    self.is_mac_secure_enabled.value_namespace = name_space
                                    self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-logging-enabled"):
                                    self.is_mac_secure_logging_enabled = value
                                    self.is_mac_secure_logging_enabled.value_namespace = name_space
                                    self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-p2mp-pw-enabled"):
                                    self.is_p2mp_pw_enabled = value
                                    self.is_p2mp_pw_enabled.value_namespace = name_space
                                    self.is_p2mp_pw_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pbbevpn-enabled"):
                                    self.is_pbbevpn_enabled = value
                                    self.is_pbbevpn_enabled.value_namespace = name_space
                                    self.is_pbbevpn_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-swmac-learning"):
                                    self.is_swmac_learning = value
                                    self.is_swmac_learning.value_namespace = name_space
                                    self.is_swmac_learning.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vni-enabled"):
                                    self.is_vni_enabled = value
                                    self.is_vni_enabled.value_namespace = name_space
                                    self.is_vni_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vpls-flood-optimization-enabled"):
                                    self.is_vpls_flood_optimization_enabled = value
                                    self.is_vpls_flood_optimization_enabled.value_namespace = name_space
                                    self.is_vpls_flood_optimization_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-time"):
                                    self.mac_aging_time = value
                                    self.mac_aging_time.value_namespace = name_space
                                    self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-type"):
                                    self.mac_aging_type = value
                                    self.mac_aging_type.value_namespace = name_space
                                    self.mac_aging_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-learning-disabled"):
                                    self.mac_learning_disabled = value
                                    self.mac_learning_disabled.value_namespace = name_space
                                    self.mac_learning_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit"):
                                    self.mac_limit = value
                                    self.mac_limit.value_namespace = name_space
                                    self.mac_limit.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-action"):
                                    self.mac_limit_action = value
                                    self.mac_limit_action.value_namespace = name_space
                                    self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-notification-type"):
                                    self.mac_limit_notification_type = value
                                    self.mac_limit_notification_type.value_namespace = name_space
                                    self.mac_limit_notification_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-port-down-flush-disabled"):
                                    self.mac_port_down_flush_disabled = value
                                    self.mac_port_down_flush_disabled.value_namespace = name_space
                                    self.mac_port_down_flush_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-secure-action"):
                                    self.mac_secure_action = value
                                    self.mac_secure_action.value_namespace = name_space
                                    self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-flood-forward-enabled"):
                                    self.mld_flood_forward_enabled = value
                                    self.mld_flood_forward_enabled.value_namespace = name_space
                                    self.mld_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-mroute-port-enabled"):
                                    self.mld_mroute_port_enabled = value
                                    self.mld_mroute_port_enabled.value_namespace = name_space
                                    self.mld_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-route-guard-enabled"):
                                    self.mld_route_guard_enabled = value
                                    self.mld_route_guard_enabled.value_namespace = name_space
                                    self.mld_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-snoop-enabled"):
                                    self.mld_snoop_enabled = value
                                    self.mld_snoop_enabled.value_namespace = name_space
                                    self.mld_snoop_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-snoop-profile-enabled"):
                                    self.mld_snoop_profile_enabled = value
                                    self.mld_snoop_profile_enabled.value_namespace = name_space
                                    self.mld_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti"):
                                    self.msti = value
                                    self.msti.value_namespace = name_space
                                    self.msti.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-of-macs"):
                                    self.number_of_macs = value
                                    self.number_of_macs.value_namespace = name_space
                                    self.number_of_macs.value_namespace_prefix = name_space_prefix
                                if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                                    self.nv_satellite_offload_ipv4_multicast_disabled = value
                                    self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                                    self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-broadcast-enabled"):
                                    self.storm_control_broadcast_enabled = value
                                    self.storm_control_broadcast_enabled.value_namespace = name_space
                                    self.storm_control_broadcast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-broadcast-rate-unit"):
                                    self.storm_control_broadcast_rate_unit = value
                                    self.storm_control_broadcast_rate_unit.value_namespace = name_space
                                    self.storm_control_broadcast_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-multicast-enabled"):
                                    self.storm_control_multicast_enabled = value
                                    self.storm_control_multicast_enabled.value_namespace = name_space
                                    self.storm_control_multicast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-multicast-rate-unit"):
                                    self.storm_control_multicast_rate_unit = value
                                    self.storm_control_multicast_rate_unit.value_namespace = name_space
                                    self.storm_control_multicast_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-unicast-enabled"):
                                    self.storm_control_unicast_enabled = value
                                    self.storm_control_unicast_enabled.value_namespace = name_space
                                    self.storm_control_unicast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-unicast-rate-unit"):
                                    self.storm_control_unicast_rate_unit = value
                                    self.storm_control_unicast_rate_unit.value_namespace = name_space
                                    self.storm_control_unicast_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "stp-participating"):
                                    self.stp_participating = value
                                    self.stp_participating.value_namespace = name_space
                                    self.stp_participating.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-unicast-flooding-disabled"):
                                    self.unknown_unicast_flooding_disabled = value
                                    self.unknown_unicast_flooding_disabled.value_namespace = name_space
                                    self.unknown_unicast_flooding_disabled.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.broadcast_storm_control_kb_ps.is_set or
                                self.broadcast_storm_control_pps.is_set or
                                self.multicast_storm_control_kb_ps.is_set or
                                self.multicast_storm_control_pps.is_set or
                                self.unicast_storm_control_kb_ps.is_set or
                                self.unicast_storm_control_pps.is_set or
                                (self.operational_information is not None and self.operational_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                (self.operational_information is not None and self.operational_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "oper" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "operational-information"):
                                if (self.operational_information is None):
                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self._children_name_map["operational_information"] = "operational-information"
                                return self.operational_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "operational-information" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "broadcast-storm-control-kb-ps"):
                                self.broadcast_storm_control_kb_ps = value
                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-pps"):
                                self.broadcast_storm_control_pps = value
                                self.broadcast_storm_control_pps.value_namespace = name_space
                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-kb-ps"):
                                self.multicast_storm_control_kb_ps = value
                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-pps"):
                                self.multicast_storm_control_pps = value
                                self.multicast_storm_control_pps.value_namespace = name_space
                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-kb-ps"):
                                self.unicast_storm_control_kb_ps = value
                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-pps"):
                                self.unicast_storm_control_pps = value
                                self.unicast_storm_control_pps.value_namespace = name_space
                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix


                    class BdPbbUnion(Entity):
                        """
                        Union of bridge Edge and Core info
                        
                        .. attribute:: core
                        
                        	core
                        	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Core>`
                        
                        .. attribute:: edge
                        
                        	edge
                        	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Edge>`
                        
                        .. attribute:: pbb_type
                        
                        	PbbType
                        	**type**\:   :py:class:`MgmtL2FibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion, self).__init__()

                            self.yang_name = "bd-pbb-union"
                            self.yang_parent_name = "l2fib-bridge-domain"

                            self.pbb_type = YLeaf(YType.enumeration, "pbb-type")

                            self.core = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Core()
                            self.core.parent = self
                            self._children_name_map["core"] = "core"
                            self._children_yang_names.add("core")

                            self.edge = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Edge()
                            self.edge.parent = self
                            self._children_name_map["edge"] = "edge"
                            self._children_yang_names.add("edge")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pbb_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion, self).__setattr__(name, value)


                        class Edge(Entity):
                            """
                            edge
                            
                            .. attribute:: core_bd_name
                            
                            	Core Bridge Domain name
                            	**type**\:  str
                            
                            .. attribute:: i_sid
                            
                            	I SID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mirp_lite_rx
                            
                            	MIRP\-lite Rx packet counter
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: mirp_lite_tx
                            
                            	MIRP\-lite Tx packet counter
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Edge, self).__init__()

                                self.yang_name = "edge"
                                self.yang_parent_name = "bd-pbb-union"

                                self.core_bd_name = YLeaf(YType.str, "core-bd-name")

                                self.i_sid = YLeaf(YType.uint32, "i-sid")

                                self.mirp_lite_rx = YLeaf(YType.uint64, "mirp-lite-rx")

                                self.mirp_lite_tx = YLeaf(YType.uint64, "mirp-lite-tx")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("core_bd_name",
                                                "i_sid",
                                                "mirp_lite_rx",
                                                "mirp_lite_tx") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Edge, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Edge, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.core_bd_name.is_set or
                                    self.i_sid.is_set or
                                    self.mirp_lite_rx.is_set or
                                    self.mirp_lite_tx.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.core_bd_name.yfilter != YFilter.not_set or
                                    self.i_sid.yfilter != YFilter.not_set or
                                    self.mirp_lite_rx.yfilter != YFilter.not_set or
                                    self.mirp_lite_tx.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "edge" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.core_bd_name.is_set or self.core_bd_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_bd_name.get_name_leafdata())
                                if (self.i_sid.is_set or self.i_sid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.i_sid.get_name_leafdata())
                                if (self.mirp_lite_rx.is_set or self.mirp_lite_rx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mirp_lite_rx.get_name_leafdata())
                                if (self.mirp_lite_tx.is_set or self.mirp_lite_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mirp_lite_tx.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "core-bd-name" or name == "i-sid" or name == "mirp-lite-rx" or name == "mirp-lite-tx"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "core-bd-name"):
                                    self.core_bd_name = value
                                    self.core_bd_name.value_namespace = name_space
                                    self.core_bd_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "i-sid"):
                                    self.i_sid = value
                                    self.i_sid.value_namespace = name_space
                                    self.i_sid.value_namespace_prefix = name_space_prefix
                                if(value_path == "mirp-lite-rx"):
                                    self.mirp_lite_rx = value
                                    self.mirp_lite_rx.value_namespace = name_space
                                    self.mirp_lite_rx.value_namespace_prefix = name_space_prefix
                                if(value_path == "mirp-lite-tx"):
                                    self.mirp_lite_tx = value
                                    self.mirp_lite_tx.value_namespace = name_space
                                    self.mirp_lite_tx.value_namespace_prefix = name_space_prefix


                        class Core(Entity):
                            """
                            core
                            
                            .. attribute:: nber_edge_bd
                            
                            	Number of associated pbb\-edge Bds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Core, self).__init__()

                                self.yang_name = "core"
                                self.yang_parent_name = "bd-pbb-union"

                                self.nber_edge_bd = YLeaf(YType.uint32, "nber-edge-bd")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nber_edge_bd") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Core, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Core, self).__setattr__(name, value)

                            def has_data(self):
                                return self.nber_edge_bd.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nber_edge_bd.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "core" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nber_edge_bd.is_set or self.nber_edge_bd.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nber_edge_bd.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nber-edge-bd"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nber-edge-bd"):
                                    self.nber_edge_bd = value
                                    self.nber_edge_bd.value_namespace = name_space
                                    self.nber_edge_bd.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.pbb_type.is_set or
                                (self.core is not None and self.core.has_data()) or
                                (self.edge is not None and self.edge.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pbb_type.yfilter != YFilter.not_set or
                                (self.core is not None and self.core.has_operation()) or
                                (self.edge is not None and self.edge.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bd-pbb-union" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pbb_type.is_set or self.pbb_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pbb_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "core"):
                                if (self.core is None):
                                    self.core = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                return self.core

                            if (child_yang_name == "edge"):
                                if (self.edge is None):
                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"
                                return self.edge

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "core" or name == "edge" or name == "pbb-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pbb-type"):
                                self.pbb_type = value
                                self.pbb_type.value_namespace = name_space
                                self.pbb_type.value_namespace_prefix = name_space_prefix


                    class BviInfo(Entity):
                        """
                        BVI Information
                        
                        .. attribute:: bvi_ifh
                        
                        	BVI interface handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: bvi_name
                        
                        	BVI name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: bvi_shg_id
                        
                        	BVI Split Horizon Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bvi_xid
                        
                        	BVI xconnect id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BviInfo, self).__init__()

                            self.yang_name = "bvi-info"
                            self.yang_parent_name = "l2fib-bridge-domain"

                            self.bvi_ifh = YLeaf(YType.str, "bvi-ifh")

                            self.bvi_name = YLeaf(YType.str, "bvi-name")

                            self.bvi_shg_id = YLeaf(YType.uint32, "bvi-shg-id")

                            self.bvi_xid = YLeaf(YType.uint32, "bvi-xid")

                            self.irb_plat_data = YLeaf(YType.str, "irb-plat-data")

                            self.irb_plat_data_len = YLeaf(YType.uint32, "irb-plat-data-len")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_ifh",
                                            "bvi_name",
                                            "bvi_shg_id",
                                            "bvi_xid",
                                            "irb_plat_data",
                                            "irb_plat_data_len") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BviInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BviInfo, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bvi_ifh.is_set or
                                self.bvi_name.is_set or
                                self.bvi_shg_id.is_set or
                                self.bvi_xid.is_set or
                                self.irb_plat_data.is_set or
                                self.irb_plat_data_len.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_ifh.yfilter != YFilter.not_set or
                                self.bvi_name.yfilter != YFilter.not_set or
                                self.bvi_shg_id.yfilter != YFilter.not_set or
                                self.bvi_xid.yfilter != YFilter.not_set or
                                self.irb_plat_data.yfilter != YFilter.not_set or
                                self.irb_plat_data_len.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bvi-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_ifh.is_set or self.bvi_ifh.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_ifh.get_name_leafdata())
                            if (self.bvi_name.is_set or self.bvi_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_name.get_name_leafdata())
                            if (self.bvi_shg_id.is_set or self.bvi_shg_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_shg_id.get_name_leafdata())
                            if (self.bvi_xid.is_set or self.bvi_xid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_xid.get_name_leafdata())
                            if (self.irb_plat_data.is_set or self.irb_plat_data.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.irb_plat_data.get_name_leafdata())
                            if (self.irb_plat_data_len.is_set or self.irb_plat_data_len.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.irb_plat_data_len.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bvi-ifh" or name == "bvi-name" or name == "bvi-shg-id" or name == "bvi-xid" or name == "irb-plat-data" or name == "irb-plat-data-len"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-ifh"):
                                self.bvi_ifh = value
                                self.bvi_ifh.value_namespace = name_space
                                self.bvi_ifh.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-name"):
                                self.bvi_name = value
                                self.bvi_name.value_namespace = name_space
                                self.bvi_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-shg-id"):
                                self.bvi_shg_id = value
                                self.bvi_shg_id.value_namespace = name_space
                                self.bvi_shg_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-xid"):
                                self.bvi_xid = value
                                self.bvi_xid.value_namespace = name_space
                                self.bvi_xid.value_namespace_prefix = name_space_prefix
                            if(value_path == "irb-plat-data"):
                                self.irb_plat_data = value
                                self.irb_plat_data.value_namespace = name_space
                                self.irb_plat_data.value_namespace_prefix = name_space_prefix
                            if(value_path == "irb-plat-data-len"):
                                self.irb_plat_data_len = value
                                self.irb_plat_data_len.value_namespace = name_space
                                self.irb_plat_data_len.value_namespace_prefix = name_space_prefix


                    class P2MppwInfo(Entity):
                        """
                        P2MP PW Information
                        
                        .. attribute:: local_label
                        
                        	Local label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsm_id
                        
                        	LSM id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_te_interface
                        
                        	P2MP TE ifh
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: parent_next_hop
                        
                        	Parent Next Hop for P2MP PW
                        	**type**\:   :py:class:`ParentNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop>`
                        
                        .. attribute:: parent_nh_bound
                        
                        	Is Parent NH Bound
                        	**type**\:  bool
                        
                        .. attribute:: parent_nh_valid
                        
                        	Is Parent NH Valid
                        	**type**\:  bool
                        
                        .. attribute:: ptree_type
                        
                        	P2MP ptree type
                        	**type**\:   :py:class:`L2VpnPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPtree>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo, self).__init__()

                            self.yang_name = "p2mppw-info"
                            self.yang_parent_name = "l2fib-bridge-domain"

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.lsm_id = YLeaf(YType.uint32, "lsm-id")

                            self.p2mp_te_interface = YLeaf(YType.str, "p2mp-te-interface")

                            self.parent_nh_bound = YLeaf(YType.boolean, "parent-nh-bound")

                            self.parent_nh_valid = YLeaf(YType.boolean, "parent-nh-valid")

                            self.ptree_type = YLeaf(YType.enumeration, "ptree-type")

                            self.parent_next_hop = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop()
                            self.parent_next_hop.parent = self
                            self._children_name_map["parent_next_hop"] = "parent-next-hop"
                            self._children_yang_names.add("parent-next-hop")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("local_label",
                                            "lsm_id",
                                            "p2mp_te_interface",
                                            "parent_nh_bound",
                                            "parent_nh_valid",
                                            "ptree_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo, self).__setattr__(name, value)


                        class ParentNextHop(Entity):
                            """
                            Parent Next Hop for P2MP PW
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop.Base>`
                            
                            .. attribute:: children_count
                            
                            	Children Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_address
                            
                            	NHOP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: next_hop_internal_label
                            
                            	NHOP Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: plaformt_data_valid
                            
                            	Is Platform Data Valid
                            	**type**\:  bool
                            
                            .. attribute:: platform_data_length
                            
                            	Platform Data Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop, self).__init__()

                                self.yang_name = "parent-next-hop"
                                self.yang_parent_name = "p2mppw-info"

                                self.children_count = YLeaf(YType.uint32, "children-count")

                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("children_count",
                                                "next_hop_address",
                                                "next_hop_internal_label",
                                                "plaformt_data_valid",
                                                "platform_data_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "parent-next-hop"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.children_count.is_set or
                                    self.next_hop_address.is_set or
                                    self.next_hop_internal_label.is_set or
                                    self.plaformt_data_valid.is_set or
                                    self.platform_data_length.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.children_count.yfilter != YFilter.not_set or
                                    self.next_hop_address.yfilter != YFilter.not_set or
                                    self.next_hop_internal_label.yfilter != YFilter.not_set or
                                    self.plaformt_data_valid.yfilter != YFilter.not_set or
                                    self.platform_data_length.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parent-next-hop" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.children_count.get_name_leafdata())
                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "children-count"):
                                    self.children_count = value
                                    self.children_count.value_namespace = name_space
                                    self.children_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-address"):
                                    self.next_hop_address = value
                                    self.next_hop_address.value_namespace = name_space
                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-internal-label"):
                                    self.next_hop_internal_label = value
                                    self.next_hop_internal_label.value_namespace = name_space
                                    self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "plaformt-data-valid"):
                                    self.plaformt_data_valid = value
                                    self.plaformt_data_valid.value_namespace = name_space
                                    self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "platform-data-length"):
                                    self.platform_data_length = value
                                    self.platform_data_length.value_namespace = name_space
                                    self.platform_data_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.local_label.is_set or
                                self.lsm_id.is_set or
                                self.p2mp_te_interface.is_set or
                                self.parent_nh_bound.is_set or
                                self.parent_nh_valid.is_set or
                                self.ptree_type.is_set or
                                (self.parent_next_hop is not None and self.parent_next_hop.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                self.lsm_id.yfilter != YFilter.not_set or
                                self.p2mp_te_interface.yfilter != YFilter.not_set or
                                self.parent_nh_bound.yfilter != YFilter.not_set or
                                self.parent_nh_valid.yfilter != YFilter.not_set or
                                self.ptree_type.yfilter != YFilter.not_set or
                                (self.parent_next_hop is not None and self.parent_next_hop.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mppw-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())
                            if (self.lsm_id.is_set or self.lsm_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsm_id.get_name_leafdata())
                            if (self.p2mp_te_interface.is_set or self.p2mp_te_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_te_interface.get_name_leafdata())
                            if (self.parent_nh_bound.is_set or self.parent_nh_bound.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_nh_bound.get_name_leafdata())
                            if (self.parent_nh_valid.is_set or self.parent_nh_valid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_nh_valid.get_name_leafdata())
                            if (self.ptree_type.is_set or self.ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ptree_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parent-next-hop"):
                                if (self.parent_next_hop is None):
                                    self.parent_next_hop = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop()
                                    self.parent_next_hop.parent = self
                                    self._children_name_map["parent_next_hop"] = "parent-next-hop"
                                return self.parent_next_hop

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parent-next-hop" or name == "local-label" or name == "lsm-id" or name == "p2mp-te-interface" or name == "parent-nh-bound" or name == "parent-nh-valid" or name == "ptree-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsm-id"):
                                self.lsm_id = value
                                self.lsm_id.value_namespace = name_space
                                self.lsm_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-te-interface"):
                                self.p2mp_te_interface = value
                                self.p2mp_te_interface.value_namespace = name_space
                                self.p2mp_te_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-nh-bound"):
                                self.parent_nh_bound = value
                                self.parent_nh_bound.value_namespace = name_space
                                self.parent_nh_bound.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-nh-valid"):
                                self.parent_nh_valid = value
                                self.parent_nh_valid.value_namespace = name_space
                                self.parent_nh_valid.value_namespace_prefix = name_space_prefix
                            if(value_path == "ptree-type"):
                                self.ptree_type = value
                                self.ptree_type.value_namespace = name_space
                                self.ptree_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bd_group_name.is_set or
                            self.bd_name.is_set or
                            self.bridge_id.is_set or
                            self.bridge_name.is_set or
                            self.bridge_port_count.is_set or
                            self.bridge_type.is_set or
                            self.learn_key.is_set or
                            self.number_of_hwmac.is_set or
                            self.number_of_swmac.is_set or
                            self.shg_count.is_set or
                            (self.base is not None and self.base.has_data()) or
                            (self.bd_pbb_union is not None and self.bd_pbb_union.has_data()) or
                            (self.bvi_info is not None and self.bvi_info.has_data()) or
                            (self.oper is not None and self.oper.has_data()) or
                            (self.p2mppw_info is not None and self.p2mppw_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bd_group_name.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            self.bridge_id.yfilter != YFilter.not_set or
                            self.bridge_name.yfilter != YFilter.not_set or
                            self.bridge_port_count.yfilter != YFilter.not_set or
                            self.bridge_type.yfilter != YFilter.not_set or
                            self.learn_key.yfilter != YFilter.not_set or
                            self.number_of_hwmac.yfilter != YFilter.not_set or
                            self.number_of_swmac.yfilter != YFilter.not_set or
                            self.shg_count.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()) or
                            (self.bd_pbb_union is not None and self.bd_pbb_union.has_operation()) or
                            (self.bvi_info is not None and self.bvi_info.has_operation()) or
                            (self.oper is not None and self.oper.has_operation()) or
                            (self.p2mppw_info is not None and self.p2mppw_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-bridge-domain" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bd_group_name.is_set or self.bd_group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_group_name.get_name_leafdata())
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())
                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                        if (self.bridge_name.is_set or self.bridge_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_name.get_name_leafdata())
                        if (self.bridge_port_count.is_set or self.bridge_port_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_port_count.get_name_leafdata())
                        if (self.bridge_type.is_set or self.bridge_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_type.get_name_leafdata())
                        if (self.learn_key.is_set or self.learn_key.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.learn_key.get_name_leafdata())
                        if (self.number_of_hwmac.is_set or self.number_of_hwmac.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_hwmac.get_name_leafdata())
                        if (self.number_of_swmac.is_set or self.number_of_swmac.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_swmac.get_name_leafdata())
                        if (self.shg_count.is_set or self.shg_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shg_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        if (child_yang_name == "bd-pbb-union"):
                            if (self.bd_pbb_union is None):
                                self.bd_pbb_union = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion()
                                self.bd_pbb_union.parent = self
                                self._children_name_map["bd_pbb_union"] = "bd-pbb-union"
                            return self.bd_pbb_union

                        if (child_yang_name == "bvi-info"):
                            if (self.bvi_info is None):
                                self.bvi_info = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BviInfo()
                                self.bvi_info.parent = self
                                self._children_name_map["bvi_info"] = "bvi-info"
                            return self.bvi_info

                        if (child_yang_name == "oper"):
                            if (self.oper is None):
                                self.oper = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper()
                                self.oper.parent = self
                                self._children_name_map["oper"] = "oper"
                            return self.oper

                        if (child_yang_name == "p2mppw-info"):
                            if (self.p2mppw_info is None):
                                self.p2mppw_info = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo()
                                self.p2mppw_info.parent = self
                                self._children_name_map["p2mppw_info"] = "p2mppw-info"
                            return self.p2mppw_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "bd-pbb-union" or name == "bvi-info" or name == "oper" or name == "p2mppw-info" or name == "bd-group-name" or name == "bd-name" or name == "bridge-id" or name == "bridge-name" or name == "bridge-port-count" or name == "bridge-type" or name == "learn-key" or name == "number-of-hwmac" or name == "number-of-swmac" or name == "shg-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bd-group-name"):
                            self.bd_group_name = value
                            self.bd_group_name.value_namespace = name_space
                            self.bd_group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-id"):
                            self.bridge_id = value
                            self.bridge_id.value_namespace = name_space
                            self.bridge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-name"):
                            self.bridge_name = value
                            self.bridge_name.value_namespace = name_space
                            self.bridge_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-port-count"):
                            self.bridge_port_count = value
                            self.bridge_port_count.value_namespace = name_space
                            self.bridge_port_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-type"):
                            self.bridge_type = value
                            self.bridge_type.value_namespace = name_space
                            self.bridge_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "learn-key"):
                            self.learn_key = value
                            self.learn_key.value_namespace = name_space
                            self.learn_key.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-hwmac"):
                            self.number_of_hwmac = value
                            self.number_of_hwmac.value_namespace = name_space
                            self.number_of_hwmac.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-swmac"):
                            self.number_of_swmac = value
                            self.number_of_swmac.value_namespace = name_space
                            self.number_of_swmac.value_namespace_prefix = name_space_prefix
                        if(value_path == "shg-count"):
                            self.shg_count = value
                            self.shg_count.value_namespace = name_space
                            self.shg_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_bridge_domain:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_bridge_domain:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-bridge-domains" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-bridge-domain"):
                        for c in self.l2fib_bridge_domain:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_bridge_domain.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-bridge-domain"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMstpSummaries(Entity):
                """
                MSTP Summary Table
                
                .. attribute:: l2fib_mstp_summary
                
                	MSTP Summary information
                	**type**\: list of    :py:class:`L2FibMstpSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMstpSummaries, self).__init__()

                    self.yang_name = "l2fib-mstp-summaries"
                    self.yang_parent_name = "node"

                    self.l2fib_mstp_summary = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMstpSummaries, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMstpSummaries, self).__setattr__(name, value)


                class L2FibMstpSummary(Entity):
                    """
                    MSTP Summary information
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary.Base>`
                    
                    .. attribute:: bridge_port_count
                    
                    	Number of bridge ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti
                    
                    	MSTI context
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: msti_xr
                    
                    	multi\-spanning tree instance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_interface
                    
                    	Parent interface context
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: parent_interface_xr
                    
                    	main port ID
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: state
                    
                    	MSTI state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary, self).__init__()

                        self.yang_name = "l2fib-mstp-summary"
                        self.yang_parent_name = "l2fib-mstp-summaries"

                        self.bridge_port_count = YLeaf(YType.uint32, "bridge-port-count")

                        self.msti = YLeaf(YType.int32, "msti")

                        self.msti_xr = YLeaf(YType.uint32, "msti-xr")

                        self.parent_interface = YLeaf(YType.str, "parent-interface")

                        self.parent_interface_xr = YLeaf(YType.str, "parent-interface-xr")

                        self.state = YLeaf(YType.uint32, "state")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bridge_port_count",
                                        "msti",
                                        "msti_xr",
                                        "parent_interface",
                                        "parent_interface_xr",
                                        "state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fib-mstp-summary"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.bridge_port_count.is_set or
                            self.msti.is_set or
                            self.msti_xr.is_set or
                            self.parent_interface.is_set or
                            self.parent_interface_xr.is_set or
                            self.state.is_set or
                            (self.base is not None and self.base.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bridge_port_count.yfilter != YFilter.not_set or
                            self.msti.yfilter != YFilter.not_set or
                            self.msti_xr.yfilter != YFilter.not_set or
                            self.parent_interface.yfilter != YFilter.not_set or
                            self.parent_interface_xr.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mstp-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bridge_port_count.is_set or self.bridge_port_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_port_count.get_name_leafdata())
                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti.get_name_leafdata())
                        if (self.msti_xr.is_set or self.msti_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_xr.get_name_leafdata())
                        if (self.parent_interface.is_set or self.parent_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_interface.get_name_leafdata())
                        if (self.parent_interface_xr.is_set or self.parent_interface_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_interface_xr.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "bridge-port-count" or name == "msti" or name == "msti-xr" or name == "parent-interface" or name == "parent-interface-xr" or name == "state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bridge-port-count"):
                            self.bridge_port_count = value
                            self.bridge_port_count.value_namespace = name_space
                            self.bridge_port_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti"):
                            self.msti = value
                            self.msti.value_namespace = name_space
                            self.msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-xr"):
                            self.msti_xr = value
                            self.msti_xr.value_namespace = name_space
                            self.msti_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-interface"):
                            self.parent_interface = value
                            self.parent_interface.value_namespace = name_space
                            self.parent_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-interface-xr"):
                            self.parent_interface_xr = value
                            self.parent_interface_xr.value_namespace = name_space
                            self.parent_interface_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_mstp_summary:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_mstp_summary:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-mstp-summaries" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-mstp-summary"):
                        for c in self.l2fib_mstp_summary:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_mstp_summary.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-mstp-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibResourceAvailability(Entity):
                """
                Resource availability information
                
                .. attribute:: hardware_resource_mode
                
                	Hardware resource mode
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: hardware_resource_mode_information
                
                	Opaque hardware resource info
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: overall_out_of_resource_mode
                
                	Overall OOR mode
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: shm_resource
                
                	Shared memory resource info
                	**type**\:   :py:class:`ShmResource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibResourceAvailability.ShmResource>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibResourceAvailability, self).__init__()

                    self.yang_name = "l2fib-resource-availability"
                    self.yang_parent_name = "node"

                    self.hardware_resource_mode = YLeafList(YType.uint32, "hardware-resource-mode")

                    self.hardware_resource_mode_information = YLeaf(YType.str, "hardware-resource-mode-information")

                    self.overall_out_of_resource_mode = YLeaf(YType.uint32, "overall-out-of-resource-mode")

                    self.shm_resource = L2VpnForwarding.Nodes.Node.L2FibResourceAvailability.ShmResource()
                    self.shm_resource.parent = self
                    self._children_name_map["shm_resource"] = "shm-resource"
                    self._children_yang_names.add("shm-resource")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("hardware_resource_mode",
                                    "hardware_resource_mode_information",
                                    "overall_out_of_resource_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibResourceAvailability, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibResourceAvailability, self).__setattr__(name, value)


                class ShmResource(Entity):
                    """
                    Shared memory resource info
                    
                    .. attribute:: average_available
                    
                    	Average number of bytes available
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: average_utility
                    
                    	Average utilization
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: maximum_available
                    
                    	Maximum bytes available
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: oout_of_resource_mode
                    
                    	OOR mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibResourceAvailability.ShmResource, self).__init__()

                        self.yang_name = "shm-resource"
                        self.yang_parent_name = "l2fib-resource-availability"

                        self.average_available = YLeaf(YType.uint64, "average-available")

                        self.average_utility = YLeaf(YType.uint64, "average-utility")

                        self.maximum_available = YLeaf(YType.uint64, "maximum-available")

                        self.oout_of_resource_mode = YLeaf(YType.uint32, "oout-of-resource-mode")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("average_available",
                                        "average_utility",
                                        "maximum_available",
                                        "oout_of_resource_mode") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibResourceAvailability.ShmResource, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibResourceAvailability.ShmResource, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.average_available.is_set or
                            self.average_utility.is_set or
                            self.maximum_available.is_set or
                            self.oout_of_resource_mode.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.average_available.yfilter != YFilter.not_set or
                            self.average_utility.yfilter != YFilter.not_set or
                            self.maximum_available.yfilter != YFilter.not_set or
                            self.oout_of_resource_mode.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "shm-resource" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.average_available.is_set or self.average_available.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.average_available.get_name_leafdata())
                        if (self.average_utility.is_set or self.average_utility.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.average_utility.get_name_leafdata())
                        if (self.maximum_available.is_set or self.maximum_available.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_available.get_name_leafdata())
                        if (self.oout_of_resource_mode.is_set or self.oout_of_resource_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.oout_of_resource_mode.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "average-available" or name == "average-utility" or name == "maximum-available" or name == "oout-of-resource-mode"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "average-available"):
                            self.average_available = value
                            self.average_available.value_namespace = name_space
                            self.average_available.value_namespace_prefix = name_space_prefix
                        if(value_path == "average-utility"):
                            self.average_utility = value
                            self.average_utility.value_namespace = name_space
                            self.average_utility.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-available"):
                            self.maximum_available = value
                            self.maximum_available.value_namespace = name_space
                            self.maximum_available.value_namespace_prefix = name_space_prefix
                        if(value_path == "oout-of-resource-mode"):
                            self.oout_of_resource_mode = value
                            self.oout_of_resource_mode.value_namespace = name_space
                            self.oout_of_resource_mode.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for leaf in self.hardware_resource_mode.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.hardware_resource_mode_information.is_set or
                        self.overall_out_of_resource_mode.is_set or
                        (self.shm_resource is not None and self.shm_resource.has_data()))

                def has_operation(self):
                    for leaf in self.hardware_resource_mode.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.hardware_resource_mode.yfilter != YFilter.not_set or
                        self.hardware_resource_mode_information.yfilter != YFilter.not_set or
                        self.overall_out_of_resource_mode.yfilter != YFilter.not_set or
                        (self.shm_resource is not None and self.shm_resource.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-resource-availability" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.hardware_resource_mode_information.is_set or self.hardware_resource_mode_information.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hardware_resource_mode_information.get_name_leafdata())
                    if (self.overall_out_of_resource_mode.is_set or self.overall_out_of_resource_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.overall_out_of_resource_mode.get_name_leafdata())

                    leaf_name_data.extend(self.hardware_resource_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "shm-resource"):
                        if (self.shm_resource is None):
                            self.shm_resource = L2VpnForwarding.Nodes.Node.L2FibResourceAvailability.ShmResource()
                            self.shm_resource.parent = self
                            self._children_name_map["shm_resource"] = "shm-resource"
                        return self.shm_resource

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "shm-resource" or name == "hardware-resource-mode" or name == "hardware-resource-mode-information" or name == "overall-out-of-resource-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "hardware-resource-mode"):
                        self.hardware_resource_mode.append(value)
                    if(value_path == "hardware-resource-mode-information"):
                        self.hardware_resource_mode_information = value
                        self.hardware_resource_mode_information.value_namespace = name_space
                        self.hardware_resource_mode_information.value_namespace_prefix = name_space_prefix
                    if(value_path == "overall-out-of-resource-mode"):
                        self.overall_out_of_resource_mode = value
                        self.overall_out_of_resource_mode.value_namespace = name_space
                        self.overall_out_of_resource_mode.value_namespace_prefix = name_space_prefix


            class L2FibmacHardwareEgresses(Entity):
                """
                Bridge Hardware Egress information
                
                .. attribute:: l2fibmac_hardware_egress
                
                	MAC Hardware Egress information
                	**type**\: list of    :py:class:`L2FibmacHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses, self).__init__()

                    self.yang_name = "l2fibmac-hardware-egresses"
                    self.yang_parent_name = "node"

                    self.l2fibmac_hardware_egress = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses, self).__setattr__(name, value)


                class L2FibmacHardwareEgress(Entity):
                    """
                    MAC Hardware Egress information
                    
                    .. attribute:: address
                    
                    	Static MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Base>`
                    
                    .. attribute:: bmac_configured
                    
                    	Flag\: Configured BMAC
                    	**type**\:  bool
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge name
                    	**type**\:  str
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_ctx
                    
                    	Evpn Context
                    	**type**\:   :py:class:`EvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx>`
                    
                    .. attribute:: flag_extension
                    
                    	MAC Flag Extension
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: l3_encapsulationvlan_id
                    
                    	L3 encapsulation Vlan ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..27
                    
                    .. attribute:: next_hop
                    
                    	Next Hop
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop>`
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Nodeid list
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: pbb_bmac
                    
                    	Backbone MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: peer_vtep_ip
                    
                    	Peer VTEP IP for this MAC Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: platform_is_hw_learn
                    
                    	Platform is HW Learn
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:   :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment>`
                    
                    .. attribute:: vni
                    
                    	VNI Information
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_l3_flag
                    
                    	Flag\: L3 Vxlan
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress, self).__init__()

                        self.yang_name = "l2fibmac-hardware-egress"
                        self.yang_parent_name = "l2fibmac-hardware-egresses"

                        self.address = YLeaf(YType.str, "address")

                        self.bmac_configured = YLeaf(YType.boolean, "bmac-configured")

                        self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                        self.flag_extension = YLeaf(YType.uint16, "flag-extension")

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.l3_encapsulationvlan_id = YLeaf(YType.uint16, "l3-encapsulationvlan-id")

                        self.name = YLeaf(YType.str, "name")

                        self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                        self.node_id = YLeaf(YType.str, "node-id")

                        self.pbb_bmac = YLeaf(YType.str, "pbb-bmac")

                        self.peer_vtep_ip = YLeaf(YType.str, "peer-vtep-ip")

                        self.platform_is_hw_learn = YLeaf(YType.uint8, "platform-is-hw-learn")

                        self.vni = YLeaf(YType.uint32, "vni")

                        self.vni_l3_flag = YLeaf(YType.boolean, "vni-l3-flag")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                        self.evpn_ctx = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx()
                        self.evpn_ctx.parent = self
                        self._children_name_map["evpn_ctx"] = "evpn-ctx"
                        self._children_yang_names.add("evpn-ctx")

                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.segment = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment()
                        self.segment.parent = self
                        self._children_name_map["segment"] = "segment"
                        self._children_yang_names.add("segment")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "bmac_configured",
                                        "bridge_domain_name",
                                        "bridge_id",
                                        "flag_extension",
                                        "group_name",
                                        "l3_encapsulationvlan_id",
                                        "name",
                                        "next_hop_valid",
                                        "node_id",
                                        "pbb_bmac",
                                        "peer_vtep_ip",
                                        "platform_is_hw_learn",
                                        "vni",
                                        "vni_l3_flag") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibmac-hardware-egress"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Segment(Entity):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Evpn>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment, self).__init__()

                            self.yang_name = "segment"
                            self.yang_parent_name = "l2fibmac-hardware-egress"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"
                            self._children_yang_names.add("evpn")

                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"
                            self._children_yang_names.add("pbb")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                            self.vni = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"
                            self._children_yang_names.add("vni")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment"

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Ac, self).__setattr__(name, value)

                            def has_data(self):
                                return self.interface_handle.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment"

                                self.xcid = YLeaf(YType.uint32, "xcid")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pbb, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pbb, self).__setattr__(name, value)

                            def has_data(self):
                                return self.xcid.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment"

                                self.parent_if = YLeaf(YType.str, "parent-if")

                                self.xcid = YLeaf(YType.uint32, "xcid")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("parent_if",
                                                "xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Vni, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Vni, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.parent_if.is_set or
                                    self.xcid.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.parent_if.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vni" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.parent_if.is_set or self.parent_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_if.get_name_leafdata())
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parent-if" or name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "parent-if"):
                                    self.parent_if = value
                                    self.parent_if.value_namespace = name_space
                                    self.parent_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment"

                                self.xcid = YLeaf(YType.uint32, "xcid")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Evpn, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Evpn, self).__setattr__(name, value)

                            def has_data(self):
                                return self.xcid.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment"

                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("next_hop_address",
                                                "pseudo_wire_id_type",
                                                "pw_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.next_hop_address.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.next_hop_address.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "pseudo-wire-id-type" or name == "pw-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "next-hop-address"):
                                    self.next_hop_address = value
                                    self.next_hop_address.value_namespace = name_space
                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.evpn is not None and self.evpn.has_data()) or
                                (self.pbb is not None and self.pbb.has_data()) or
                                (self.pw is not None and self.pw.has_data()) or
                                (self.vni is not None and self.vni.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.evpn is not None and self.evpn.has_operation()) or
                                (self.pbb is not None and self.pbb.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()) or
                                (self.vni is not None and self.vni.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "evpn"):
                                if (self.evpn is None):
                                    self.evpn = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Evpn()
                                    self.evpn.parent = self
                                    self._children_name_map["evpn"] = "evpn"
                                return self.evpn

                            if (child_yang_name == "pbb"):
                                if (self.pbb is None):
                                    self.pbb = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pbb()
                                    self.pbb.parent = self
                                    self._children_name_map["pbb"] = "pbb"
                                return self.pbb

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            if (child_yang_name == "vni"):
                                if (self.vni is None):
                                    self.vni = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Vni()
                                    self.vni.parent = self
                                    self._children_name_map["vni"] = "vni"
                                return self.vni

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "evpn" or name == "pbb" or name == "pw" or name == "vni" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix


                    class EvpnCtx(Entity):
                        """
                        Evpn Context
                        
                        .. attribute:: bp_ifh
                        
                        	BP IFH
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibBridgeMacEvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeMacEvpnCtx>`
                        
                        .. attribute:: esi_id
                        
                        	EsiID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: local_label
                        
                        	LocalLabel
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mcast_ole
                        
                        	mcast ole
                        	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx.McastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx, self).__init__()

                            self.yang_name = "evpn-ctx"
                            self.yang_parent_name = "l2fibmac-hardware-egress"

                            self.bp_ifh = YLeaf(YType.str, "bp-ifh")

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.esi_id = YLeaf(YType.uint16, "esi-id")

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx.McastOle()
                            self.mcast_ole.parent = self
                            self._children_name_map["mcast_ole"] = "mcast-ole"
                            self._children_yang_names.add("mcast-ole")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bp_ifh",
                                            "data_type",
                                            "esi_id",
                                            "local_label") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx, self).__setattr__(name, value)


                        class McastOle(Entity):
                            """
                            mcast ole
                            
                            .. attribute:: mcast_label
                            
                            	Inclusive mcast label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ipv6_addr
                            
                            	Next Hop IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx.McastOle, self).__init__()

                                self.yang_name = "mcast-ole"
                                self.yang_parent_name = "evpn-ctx"

                                self.mcast_label = YLeaf(YType.uint32, "mcast-label")

                                self.next_hop_ipv6_addr = YLeaf(YType.str, "next-hop-ipv6-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mcast_label",
                                                "next_hop_ipv6_addr") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx.McastOle, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx.McastOle, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.mcast_label.is_set or
                                    self.next_hop_ipv6_addr.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mcast_label.yfilter != YFilter.not_set or
                                    self.next_hop_ipv6_addr.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mcast-ole" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mcast_label.is_set or self.mcast_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mcast_label.get_name_leafdata())
                                if (self.next_hop_ipv6_addr.is_set or self.next_hop_ipv6_addr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ipv6_addr.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mcast-label" or name == "next-hop-ipv6-addr"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mcast-label"):
                                    self.mcast_label = value
                                    self.mcast_label.value_namespace = name_space
                                    self.mcast_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ipv6-addr"):
                                    self.next_hop_ipv6_addr = value
                                    self.next_hop_ipv6_addr.value_namespace = name_space
                                    self.next_hop_ipv6_addr.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bp_ifh.is_set or
                                self.data_type.is_set or
                                self.esi_id.is_set or
                                self.local_label.is_set or
                                (self.mcast_ole is not None and self.mcast_ole.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bp_ifh.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                self.esi_id.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                (self.mcast_ole is not None and self.mcast_ole.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "evpn-ctx" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bp_ifh.is_set or self.bp_ifh.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bp_ifh.get_name_leafdata())
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())
                            if (self.esi_id.is_set or self.esi_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.esi_id.get_name_leafdata())
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mcast-ole"):
                                if (self.mcast_ole is None):
                                    self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx.McastOle()
                                    self.mcast_ole.parent = self
                                    self._children_name_map["mcast_ole"] = "mcast-ole"
                                return self.mcast_ole

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mcast-ole" or name == "bp-ifh" or name == "data-type" or name == "esi-id" or name == "local-label"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bp-ifh"):
                                self.bp_ifh = value
                                self.bp_ifh.value_namespace = name_space
                                self.bp_ifh.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "esi-id"):
                                self.esi_id = value
                                self.esi_id.value_namespace = name_space
                                self.esi_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix


                    class NextHop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: base
                        
                        	Base Information
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop.Base>`
                        
                        .. attribute:: children_count
                        
                        	Children Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_address
                        
                        	NHOP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_internal_label
                        
                        	NHOP Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: plaformt_data_valid
                        
                        	Is Platform Data Valid
                        	**type**\:  bool
                        
                        .. attribute:: platform_data_length
                        
                        	Platform Data Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "l2fibmac-hardware-egress"

                            self.children_count = YLeaf(YType.uint32, "children-count")

                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                            self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                            self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                            self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                            self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._children_yang_names.add("base")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("children_count",
                                            "next_hop_address",
                                            "next_hop_internal_label",
                                            "plaformt_data_valid",
                                            "platform_data_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop, self).__setattr__(name, value)


                        class Base(Entity):
                            """
                            Base Information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "next-hop"

                            def has_data(self):
                                return False

                            def has_operation(self):
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "base" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.children_count.is_set or
                                self.next_hop_address.is_set or
                                self.next_hop_internal_label.is_set or
                                self.plaformt_data_valid.is_set or
                                self.platform_data_length.is_set or
                                (self.base is not None and self.base.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.children_count.yfilter != YFilter.not_set or
                                self.next_hop_address.yfilter != YFilter.not_set or
                                self.next_hop_internal_label.yfilter != YFilter.not_set or
                                self.plaformt_data_valid.yfilter != YFilter.not_set or
                                self.platform_data_length.yfilter != YFilter.not_set or
                                (self.base is not None and self.base.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "next-hop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.children_count.get_name_leafdata())
                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                            if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                            if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                            if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "base"):
                                if (self.base is None):
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                return self.base

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "children-count"):
                                self.children_count = value
                                self.children_count.value_namespace = name_space
                                self.children_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-address"):
                                self.next_hop_address = value
                                self.next_hop_address.value_namespace = name_space
                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-internal-label"):
                                self.next_hop_internal_label = value
                                self.next_hop_internal_label.value_namespace = name_space
                                self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "plaformt-data-valid"):
                                self.plaformt_data_valid = value
                                self.plaformt_data_valid.value_namespace = name_space
                                self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                            if(value_path == "platform-data-length"):
                                self.platform_data_length = value
                                self.platform_data_length.value_namespace = name_space
                                self.platform_data_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.bmac_configured.is_set or
                            self.bridge_domain_name.is_set or
                            self.bridge_id.is_set or
                            self.flag_extension.is_set or
                            self.group_name.is_set or
                            self.l3_encapsulationvlan_id.is_set or
                            self.name.is_set or
                            self.next_hop_valid.is_set or
                            self.node_id.is_set or
                            self.pbb_bmac.is_set or
                            self.peer_vtep_ip.is_set or
                            self.platform_is_hw_learn.is_set or
                            self.vni.is_set or
                            self.vni_l3_flag.is_set or
                            (self.base is not None and self.base.has_data()) or
                            (self.evpn_ctx is not None and self.evpn_ctx.has_data()) or
                            (self.next_hop is not None and self.next_hop.has_data()) or
                            (self.segment is not None and self.segment.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.bmac_configured.yfilter != YFilter.not_set or
                            self.bridge_domain_name.yfilter != YFilter.not_set or
                            self.bridge_id.yfilter != YFilter.not_set or
                            self.flag_extension.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.l3_encapsulationvlan_id.yfilter != YFilter.not_set or
                            self.name.yfilter != YFilter.not_set or
                            self.next_hop_valid.yfilter != YFilter.not_set or
                            self.node_id.yfilter != YFilter.not_set or
                            self.pbb_bmac.yfilter != YFilter.not_set or
                            self.peer_vtep_ip.yfilter != YFilter.not_set or
                            self.platform_is_hw_learn.yfilter != YFilter.not_set or
                            self.vni.yfilter != YFilter.not_set or
                            self.vni_l3_flag.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()) or
                            (self.evpn_ctx is not None and self.evpn_ctx.has_operation()) or
                            (self.next_hop is not None and self.next_hop.has_operation()) or
                            (self.segment is not None and self.segment.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fibmac-hardware-egress" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.bmac_configured.is_set or self.bmac_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bmac_configured.get_name_leafdata())
                        if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                        if (self.flag_extension.is_set or self.flag_extension.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flag_extension.get_name_leafdata())
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.l3_encapsulationvlan_id.is_set or self.l3_encapsulationvlan_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.l3_encapsulationvlan_id.get_name_leafdata())
                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.name.get_name_leafdata())
                        if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                        if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_id.get_name_leafdata())
                        if (self.pbb_bmac.is_set or self.pbb_bmac.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pbb_bmac.get_name_leafdata())
                        if (self.peer_vtep_ip.is_set or self.peer_vtep_ip.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.peer_vtep_ip.get_name_leafdata())
                        if (self.platform_is_hw_learn.is_set or self.platform_is_hw_learn.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.platform_is_hw_learn.get_name_leafdata())
                        if (self.vni.is_set or self.vni.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni.get_name_leafdata())
                        if (self.vni_l3_flag.is_set or self.vni_l3_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_l3_flag.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        if (child_yang_name == "evpn-ctx"):
                            if (self.evpn_ctx is None):
                                self.evpn_ctx = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx()
                                self.evpn_ctx.parent = self
                                self._children_name_map["evpn_ctx"] = "evpn-ctx"
                            return self.evpn_ctx

                        if (child_yang_name == "next-hop"):
                            if (self.next_hop is None):
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                            return self.next_hop

                        if (child_yang_name == "segment"):
                            if (self.segment is None):
                                self.segment = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment()
                                self.segment.parent = self
                                self._children_name_map["segment"] = "segment"
                            return self.segment

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "evpn-ctx" or name == "next-hop" or name == "segment" or name == "address" or name == "bmac-configured" or name == "bridge-domain-name" or name == "bridge-id" or name == "flag-extension" or name == "group-name" or name == "l3-encapsulationvlan-id" or name == "name" or name == "next-hop-valid" or name == "node-id" or name == "pbb-bmac" or name == "peer-vtep-ip" or name == "platform-is-hw-learn" or name == "vni" or name == "vni-l3-flag"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "bmac-configured"):
                            self.bmac_configured = value
                            self.bmac_configured.value_namespace = name_space
                            self.bmac_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-name"):
                            self.bridge_domain_name = value
                            self.bridge_domain_name.value_namespace = name_space
                            self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-id"):
                            self.bridge_id = value
                            self.bridge_id.value_namespace = name_space
                            self.bridge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "flag-extension"):
                            self.flag_extension = value
                            self.flag_extension.value_namespace = name_space
                            self.flag_extension.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "l3-encapsulationvlan-id"):
                            self.l3_encapsulationvlan_id = value
                            self.l3_encapsulationvlan_id.value_namespace = name_space
                            self.l3_encapsulationvlan_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "name"):
                            self.name = value
                            self.name.value_namespace = name_space
                            self.name.value_namespace_prefix = name_space_prefix
                        if(value_path == "next-hop-valid"):
                            self.next_hop_valid = value
                            self.next_hop_valid.value_namespace = name_space
                            self.next_hop_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-id"):
                            self.node_id = value
                            self.node_id.value_namespace = name_space
                            self.node_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "pbb-bmac"):
                            self.pbb_bmac = value
                            self.pbb_bmac.value_namespace = name_space
                            self.pbb_bmac.value_namespace_prefix = name_space_prefix
                        if(value_path == "peer-vtep-ip"):
                            self.peer_vtep_ip = value
                            self.peer_vtep_ip.value_namespace = name_space
                            self.peer_vtep_ip.value_namespace_prefix = name_space_prefix
                        if(value_path == "platform-is-hw-learn"):
                            self.platform_is_hw_learn = value
                            self.platform_is_hw_learn.value_namespace = name_space
                            self.platform_is_hw_learn.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni"):
                            self.vni = value
                            self.vni.value_namespace = name_space
                            self.vni.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni-l3-flag"):
                            self.vni_l3_flag = value
                            self.vni_l3_flag.value_namespace = name_space
                            self.vni_l3_flag.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fibmac_hardware_egress:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fibmac_hardware_egress:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fibmac-hardware-egresses" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fibmac-hardware-egress"):
                        for c in self.l2fibmac_hardware_egress:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fibmac_hardware_egress.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fibmac-hardware-egress"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibxConL2Tpv2S(Entity):
                """
                The L2VPN forwarding XConnect L2TPv2 Detail
                Table
                
                .. attribute:: l2fibx_con_l2tpv2
                
                	Specify Sub Ifh
                	**type**\: list of    :py:class:`L2FibxConL2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S, self).__init__()

                    self.yang_name = "l2fibx-con-l2tpv2s"
                    self.yang_parent_name = "node"

                    self.l2fibx_con_l2tpv2 = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S, self).__setattr__(name, value)


                class L2FibxConL2Tpv2(Entity):
                    """
                    Specify Sub Ifh
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Base>`
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\:  bool
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2>`
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:   :py:class:`MgmtL2FibSwitching <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibSwitching>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\:  str
                    
                    	**length:** 0..72
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2, self).__init__()

                        self.yang_name = "l2fibx-con-l2tpv2"
                        self.yang_parent_name = "l2fibx-con-l2tpv2s"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.bound = YLeaf(YType.boolean, "bound")

                        self.switching_type = YLeaf(YType.enumeration, "switching-type")

                        self.xcon_name = YLeaf(YType.str, "xcon-name")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                        self.segment1 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"
                        self._children_yang_names.add("segment1")

                        self.segment2 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"
                        self._children_yang_names.add("segment2")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "bound",
                                        "switching_type",
                                        "xcon_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibx-con-l2tpv2"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Segment1(Entity):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:   :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1, self).__init__()

                            self.yang_name = "segment1"
                            self.yang_parent_name = "l2fibx-con-l2tpv2"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"
                            self._children_yang_names.add("evpn")

                            self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self._children_name_map["monitor_session"] = "monitor-session"
                            self._children_yang_names.add("monitor-session")

                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"
                            self._children_yang_names.add("pbb")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                            self.vni = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"
                            self._children_yang_names.add("vni")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment1"

                                self.actype = YLeaf(YType.uint8, "actype")

                                self.adjacency_address = YLeaf(YType.str, "adjacency-address")

                                self.adjacency_valid = YLeaf(YType.boolean, "adjacency-valid")

                                self.attachment_circuit_id = YLeaf(YType.uint32, "attachment-circuit-id")

                                self.attachment_circuit_mtu = YLeaf(YType.uint16, "attachment-circuit-mtu")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.fxc_next_hop_valid = YLeaf(YType.boolean, "fxc-next-hop-valid")

                                self.inter_working_mode = YLeaf(YType.uint8, "inter-working-mode")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.ip_inter_working_mac = YLeaf(YType.str, "ip-inter-working-mac")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.sub_interface_handle = YLeaf(YType.str, "sub-interface-handle")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._children_yang_names.add("fxc-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actype",
                                                "adjacency_address",
                                                "adjacency_valid",
                                                "attachment_circuit_id",
                                                "attachment_circuit_mtu",
                                                "bound",
                                                "evpn_internal_label",
                                                "fxc_next_hop_valid",
                                                "inter_working_mode",
                                                "interface_handle",
                                                "ip_inter_working_mac",
                                                "redundancy_group_id",
                                                "redundancy_object_id",
                                                "sub_interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fxc-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.actype.is_set or
                                    self.adjacency_address.is_set or
                                    self.adjacency_valid.is_set or
                                    self.attachment_circuit_id.is_set or
                                    self.attachment_circuit_mtu.is_set or
                                    self.bound.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.fxc_next_hop_valid.is_set or
                                    self.inter_working_mode.is_set or
                                    self.interface_handle.is_set or
                                    self.ip_inter_working_mac.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.sub_interface_handle.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actype.yfilter != YFilter.not_set or
                                    self.adjacency_address.yfilter != YFilter.not_set or
                                    self.adjacency_valid.yfilter != YFilter.not_set or
                                    self.attachment_circuit_id.yfilter != YFilter.not_set or
                                    self.attachment_circuit_mtu.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.fxc_next_hop_valid.yfilter != YFilter.not_set or
                                    self.inter_working_mode.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.ip_inter_working_mac.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.sub_interface_handle.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actype.is_set or self.actype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actype.get_name_leafdata())
                                if (self.adjacency_address.is_set or self.adjacency_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_address.get_name_leafdata())
                                if (self.adjacency_valid.is_set or self.adjacency_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_valid.get_name_leafdata())
                                if (self.attachment_circuit_id.is_set or self.attachment_circuit_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_id.get_name_leafdata())
                                if (self.attachment_circuit_mtu.is_set or self.attachment_circuit_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_mtu.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.fxc_next_hop_valid.is_set or self.fxc_next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxc_next_hop_valid.get_name_leafdata())
                                if (self.inter_working_mode.is_set or self.inter_working_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_working_mode.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.ip_inter_working_mac.is_set or self.ip_inter_working_mac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_inter_working_mac.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.sub_interface_handle.is_set or self.sub_interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "fxc-next-hop"):
                                    if (self.fxc_next_hop is None):
                                        self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop()
                                        self.fxc_next_hop.parent = self
                                        self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                    return self.fxc_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxc-next-hop" or name == "actype" or name == "adjacency-address" or name == "adjacency-valid" or name == "attachment-circuit-id" or name == "attachment-circuit-mtu" or name == "bound" or name == "evpn-internal-label" or name == "fxc-next-hop-valid" or name == "inter-working-mode" or name == "interface-handle" or name == "ip-inter-working-mac" or name == "redundancy-group-id" or name == "redundancy-object-id" or name == "sub-interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actype"):
                                    self.actype = value
                                    self.actype.value_namespace = name_space
                                    self.actype.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-address"):
                                    self.adjacency_address = value
                                    self.adjacency_address.value_namespace = name_space
                                    self.adjacency_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-valid"):
                                    self.adjacency_valid = value
                                    self.adjacency_valid.value_namespace = name_space
                                    self.adjacency_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-id"):
                                    self.attachment_circuit_id = value
                                    self.attachment_circuit_id.value_namespace = name_space
                                    self.attachment_circuit_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-mtu"):
                                    self.attachment_circuit_mtu = value
                                    self.attachment_circuit_mtu.value_namespace = name_space
                                    self.attachment_circuit_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "fxc-next-hop-valid"):
                                    self.fxc_next_hop_valid = value
                                    self.fxc_next_hop_valid.value_namespace = name_space
                                    self.fxc_next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-working-mode"):
                                    self.inter_working_mode = value
                                    self.inter_working_mode.value_namespace = name_space
                                    self.inter_working_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip-inter-working-mac"):
                                    self.ip_inter_working_mac = value
                                    self.ip_inter_working_mac.value_namespace = name_space
                                    self.ip_inter_working_mac.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-interface-handle"):
                                    self.sub_interface_handle = value
                                    self.sub_interface_handle.value_namespace = name_space
                                    self.sub_interface_handle.value_namespace_prefix = name_space_prefix


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:   :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.core_pbb_evpn_enabled = YLeaf(YType.boolean, "core-pbb-evpn-enabled")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self
                                self._children_name_map["pbb_union"] = "pbb-union"
                                self._children_yang_names.add("pbb-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "core_pbb_evpn_enabled",
                                                "forward_class") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pbb"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class PbbUnion(Entity):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:   :py:class:`MgmtL2FibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridge>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion, self).__init__()

                                    self.yang_name = "pbb-union"
                                    self.yang_parent_name = "pbb"

                                    self.pbb_type = YLeaf(YType.enumeration, "pbb-type")

                                    self.core = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                    self._children_yang_names.add("core")

                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"
                                    self._children_yang_names.add("edge")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pbb_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion, self).__setattr__(name, value)


                                class Edge(Entity):
                                    """
                                    edge
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Edge, self).__init__()

                                        self.yang_name = "edge"
                                        self.yang_parent_name = "pbb-union"

                                        self.mac = YLeaf(YType.str, "mac")

                                        self.mac_configured = YLeaf(YType.boolean, "mac-configured")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mac",
                                                        "mac_configured") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Edge, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Edge, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mac.is_set or
                                            self.mac_configured.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mac.yfilter != YFilter.not_set or
                                            self.mac_configured.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "edge" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mac.is_set or self.mac.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac.get_name_leafdata())
                                        if (self.mac_configured.is_set or self.mac_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_configured.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mac" or name == "mac-configured"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mac"):
                                            self.mac = value
                                            self.mac.value_namespace = name_space
                                            self.mac.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-configured"):
                                            self.mac_configured = value
                                            self.mac_configured.value_namespace = name_space
                                            self.mac_configured.value_namespace_prefix = name_space_prefix


                                class Core(Entity):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Core, self).__init__()

                                        self.yang_name = "core"
                                        self.yang_parent_name = "pbb-union"

                                        self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vlan_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Core, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Core, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.vlan_id.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vlan_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "core" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vlan-id"):
                                            self.vlan_id = value
                                            self.vlan_id.value_namespace = name_space
                                            self.vlan_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.pbb_type.is_set or
                                        (self.core is not None and self.core.has_data()) or
                                        (self.edge is not None and self.edge.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pbb_type.yfilter != YFilter.not_set or
                                        (self.core is not None and self.core.has_operation()) or
                                        (self.edge is not None and self.edge.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pbb-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pbb_type.is_set or self.pbb_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pbb_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "core"):
                                        if (self.core is None):
                                            self.core = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Core()
                                            self.core.parent = self
                                            self._children_name_map["core"] = "core"
                                        return self.core

                                    if (child_yang_name == "edge"):
                                        if (self.edge is None):
                                            self.edge = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Edge()
                                            self.edge.parent = self
                                            self._children_name_map["edge"] = "edge"
                                        return self.edge

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "core" or name == "edge" or name == "pbb-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pbb-type"):
                                        self.pbb_type = value
                                        self.pbb_type.value_namespace = name_space
                                        self.pbb_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.core_pbb_evpn_enabled.is_set or
                                    self.forward_class.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.pbb_union is not None and self.pbb_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.core_pbb_evpn_enabled.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.pbb_union is not None and self.pbb_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.core_pbb_evpn_enabled.is_set or self.core_pbb_evpn_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_pbb_evpn_enabled.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "pbb-union"):
                                    if (self.pbb_union is None):
                                        self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion()
                                        self.pbb_union.parent = self
                                        self._children_name_map["pbb_union"] = "pbb-union"
                                    return self.pbb_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "pbb-union" or name == "bound" or name == "core-pbb-evpn-enabled" or name == "forward-class"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "core-pbb-evpn-enabled"):
                                    self.core_pbb_evpn_enabled = value
                                    self.core_pbb_evpn_enabled.value_namespace = name_space
                                    self.core_pbb_evpn_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment1"

                                self.any_cast_ip = YLeaf(YType.str, "any-cast-ip")

                                self.anycast_mcast_ip = YLeaf(YType.str, "anycast-mcast-ip")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.encap = YLeaf(YType.uint32, "encap")

                                self.mcastip = YLeaf(YType.str, "mcastip")

                                self.parent_if = YLeaf(YType.str, "parent-if")

                                self.source_vtep_if = YLeaf(YType.str, "source-vtep-if")

                                self.srcip = YLeaf(YType.str, "srcip")

                                self.udp_port = YLeaf(YType.uint32, "udp-port")

                                self.vx_lan_mode = YLeaf(YType.uint32, "vx-lan-mode")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("any_cast_ip",
                                                "anycast_mcast_ip",
                                                "bound",
                                                "encap",
                                                "mcastip",
                                                "parent_if",
                                                "source_vtep_if",
                                                "srcip",
                                                "udp_port",
                                                "vx_lan_mode") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "vni"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.any_cast_ip.is_set or
                                    self.anycast_mcast_ip.is_set or
                                    self.bound.is_set or
                                    self.encap.is_set or
                                    self.mcastip.is_set or
                                    self.parent_if.is_set or
                                    self.source_vtep_if.is_set or
                                    self.srcip.is_set or
                                    self.udp_port.is_set or
                                    self.vx_lan_mode.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.any_cast_ip.yfilter != YFilter.not_set or
                                    self.anycast_mcast_ip.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.encap.yfilter != YFilter.not_set or
                                    self.mcastip.yfilter != YFilter.not_set or
                                    self.parent_if.yfilter != YFilter.not_set or
                                    self.source_vtep_if.yfilter != YFilter.not_set or
                                    self.srcip.yfilter != YFilter.not_set or
                                    self.udp_port.yfilter != YFilter.not_set or
                                    self.vx_lan_mode.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vni" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.any_cast_ip.is_set or self.any_cast_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.any_cast_ip.get_name_leafdata())
                                if (self.anycast_mcast_ip.is_set or self.anycast_mcast_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.anycast_mcast_ip.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.encap.is_set or self.encap.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encap.get_name_leafdata())
                                if (self.mcastip.is_set or self.mcastip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mcastip.get_name_leafdata())
                                if (self.parent_if.is_set or self.parent_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_if.get_name_leafdata())
                                if (self.source_vtep_if.is_set or self.source_vtep_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_vtep_if.get_name_leafdata())
                                if (self.srcip.is_set or self.srcip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.srcip.get_name_leafdata())
                                if (self.udp_port.is_set or self.udp_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.udp_port.get_name_leafdata())
                                if (self.vx_lan_mode.is_set or self.vx_lan_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vx_lan_mode.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "any-cast-ip" or name == "anycast-mcast-ip" or name == "bound" or name == "encap" or name == "mcastip" or name == "parent-if" or name == "source-vtep-if" or name == "srcip" or name == "udp-port" or name == "vx-lan-mode"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "any-cast-ip"):
                                    self.any_cast_ip = value
                                    self.any_cast_ip.value_namespace = name_space
                                    self.any_cast_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "anycast-mcast-ip"):
                                    self.anycast_mcast_ip = value
                                    self.anycast_mcast_ip.value_namespace = name_space
                                    self.anycast_mcast_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "encap"):
                                    self.encap = value
                                    self.encap.value_namespace = name_space
                                    self.encap.value_namespace_prefix = name_space_prefix
                                if(value_path == "mcastip"):
                                    self.mcastip = value
                                    self.mcastip.value_namespace = name_space
                                    self.mcastip.value_namespace_prefix = name_space_prefix
                                if(value_path == "parent-if"):
                                    self.parent_if = value
                                    self.parent_if.value_namespace = name_space
                                    self.parent_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-vtep-if"):
                                    self.source_vtep_if = value
                                    self.source_vtep_if.value_namespace = name_space
                                    self.source_vtep_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "srcip"):
                                    self.srcip = value
                                    self.srcip.value_namespace = name_space
                                    self.srcip.value_namespace_prefix = name_space_prefix
                                if(value_path == "udp-port"):
                                    self.udp_port = value
                                    self.udp_port.value_namespace = name_space
                                    self.udp_port.value_namespace_prefix = name_space_prefix
                                if(value_path == "vx-lan-mode"):
                                    self.vx_lan_mode = value
                                    self.vx_lan_mode.value_namespace = name_space
                                    self.vx_lan_mode.value_namespace_prefix = name_space_prefix


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evi = YLeaf(YType.uint32, "evi")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "evi",
                                                "forward_class") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "evpn"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.evi.is_set or
                                    self.forward_class.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evi.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evi.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "bound" or name == "evi" or name == "forward-class"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evi"):
                                    self.evi = value
                                    self.evi.value_namespace = name_space
                                    self.evi.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix


                        class MonitorSession(Entity):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\:  str
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession, self).__init__()

                                self.yang_name = "monitor-session"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.hardware_information = YLeaf(YType.str, "hardware-information")

                                self.session_name = YLeaf(YType.str, "session-name")

                                self.xcid = YLeaf(YType.uint32, "xcid")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "hardware_information",
                                                "session_name",
                                                "xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "monitor-session"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.hardware_information.is_set or
                                    self.session_name.is_set or
                                    self.xcid.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.hardware_information.yfilter != YFilter.not_set or
                                    self.session_name.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "monitor-session" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.hardware_information.is_set or self.hardware_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.hardware_information.get_name_leafdata())
                                if (self.session_name.is_set or self.session_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.session_name.get_name_leafdata())
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "bound" or name == "hardware-information" or name == "session-name" or name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "hardware-information"):
                                    self.hardware_information = value
                                    self.hardware_information.value_namespace = name_space
                                    self.hardware_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "session-name"):
                                    self.session_name = value
                                    self.session_name.value_namespace = name_space
                                    self.session_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBal>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment1"

                                self.ac_id = YLeaf(YType.uint32, "ac-id")

                                self.active = YLeaf(YType.boolean, "active")

                                self.backup_configured = YLeaf(YType.boolean, "backup-configured")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.context = YLeaf(YType.uint16, "context")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.global_id = YLeaf(YType.uint32, "global-id")

                                self.group_id = YLeaf(YType.uint32, "group-id")

                                self.group_state = YLeaf(YType.enumeration, "group-state")

                                self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                                self.pw_load_balance_type = YLeaf(YType.enumeration, "pw-load-balance-type")

                                self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                self.sequence_resync_threshold = YLeaf(YType.uint16, "sequence-resync-threshold")

                                self.signal_capability_flags = YLeaf(YType.uint32, "signal-capability-flags")

                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._children_yang_names.add("backup-pseudo-wire")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                self._children_yang_names.add("pseudo-wire-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ac_id",
                                                "active",
                                                "backup_configured",
                                                "bound",
                                                "context",
                                                "forward_class",
                                                "global_id",
                                                "group_id",
                                                "group_state",
                                                "grouping_supported",
                                                "next_hop_valid",
                                                "pseudo_wire_id_type",
                                                "pw_flow_label_tx",
                                                "pw_id",
                                                "pw_load_balance_type",
                                                "redundancy_role",
                                                "sequence_resync_threshold",
                                                "signal_capability_flags") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"
                                    self._children_yang_names.add("l2tp")

                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._children_yang_names.add("l2tp-ipv6-ts")

                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"
                                    self._children_yang_names.add("l2tpv2")

                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"
                                    self._children_yang_names.add("mpls")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion, self).__setattr__(name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix


                                class L2Tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_mtu",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_mtu.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "path-mtu" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix


                                class L2Tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.protocol = YLeaf(YType.uint16, "protocol")

                                        self.pw_flags = YLeaf(YType.uint8, "pw-flags")

                                        self.rem_udp_port = YLeaf(YType.uint16, "rem-udp-port")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop_address",
                                                        "path_mtu",
                                                        "protocol",
                                                        "pw_flags",
                                                        "rem_udp_port",
                                                        "source_address",
                                                        "tos_val",
                                                        "ttl",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.next_hop_address.is_set or
                                            self.path_mtu.is_set or
                                            self.protocol.is_set or
                                            self.pw_flags.is_set or
                                            self.rem_udp_port.is_set or
                                            self.source_address.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            self.xconnect_id.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pw_flags.yfilter != YFilter.not_set or
                                            self.rem_udp_port.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv2" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pw_flags.is_set or self.pw_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flags.get_name_leafdata())
                                        if (self.rem_udp_port.is_set or self.rem_udp_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_udp_port.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "next-hop-address" or name == "path-mtu" or name == "protocol" or name == "pw-flags" or name == "rem-udp-port" or name == "source-address" or name == "tos-val" or name == "ttl" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop-address"):
                                            self.next_hop_address = value
                                            self.next_hop_address.value_namespace = name_space
                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flags"):
                                            self.pw_flags = value
                                            self.pw_flags.value_namespace = name_space
                                            self.pw_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-udp-port"):
                                            self.rem_udp_port = value
                                            self.rem_udp_port.value_namespace = name_space
                                            self.rem_udp_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class L2TpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address",
                                                        "path_mtu",
                                                        "remote_address",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.secondary_cookie_high_value = YLeaf(YType.uint32, "secondary-cookie-high-value")

                                            self.secondary_cookie_low_value = YLeaf(YType.uint32, "secondary-cookie-low-value")

                                            self.secondary_cookie_size = YLeaf(YType.uint8, "secondary-cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "secondary_cookie_high_value",
                                                            "secondary_cookie_low_value",
                                                            "secondary_cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.secondary_cookie_high_value.is_set or
                                                self.secondary_cookie_low_value.is_set or
                                                self.secondary_cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.secondary_cookie_high_value.is_set or self.secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_high_value.get_name_leafdata())
                                            if (self.secondary_cookie_low_value.is_set or self.secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_low_value.get_name_leafdata())
                                            if (self.secondary_cookie_size.is_set or self.secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "secondary-cookie-high-value" or name == "secondary-cookie-low-value" or name == "secondary-cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-high-value"):
                                                self.secondary_cookie_high_value = value
                                                self.secondary_cookie_high_value.value_namespace = name_space
                                                self.secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-low-value"):
                                                self.secondary_cookie_low_value = value
                                                self.secondary_cookie_low_value.value_namespace = name_space
                                                self.secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-size"):
                                                self.secondary_cookie_size = value
                                                self.secondary_cookie_size.value_namespace = name_space
                                                self.secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.local_address.is_set or
                                            self.path_mtu.is_set or
                                            self.remote_address.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp-ipv6-ts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "local-address" or name == "path-mtu" or name == "remote-address" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        (self.l2tp is not None and self.l2tp.has_data()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_data()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_data()) or
                                        (self.mpls is not None and self.mpls.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        (self.l2tp is not None and self.l2tp.has_operation()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_operation()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_operation()) or
                                        (self.mpls is not None and self.mpls.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudo-wire-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2tp"):
                                        if (self.l2tp is None):
                                            self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp()
                                            self.l2tp.parent = self
                                            self._children_name_map["l2tp"] = "l2tp"
                                        return self.l2tp

                                    if (child_yang_name == "l2tp-ipv6-ts"):
                                        if (self.l2tp_ipv6_ts is None):
                                            self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                            self.l2tp_ipv6_ts.parent = self
                                            self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                        return self.l2tp_ipv6_ts

                                    if (child_yang_name == "l2tpv2"):
                                        if (self.l2tpv2 is None):
                                            self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                            self.l2tpv2.parent = self
                                            self._children_name_map["l2tpv2"] = "l2tpv2"
                                        return self.l2tpv2

                                    if (child_yang_name == "mpls"):
                                        if (self.mpls is None):
                                            self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                        return self.mpls

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2tp" or name == "l2tp-ipv6-ts" or name == "l2tpv2" or name == "mpls" or name == "data-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.backup_next_hop = YLeaf(YType.str, "backup-next-hop")

                                    self.backup_pseudo_wire_id = YLeaf(YType.uint32, "backup-pseudo-wire-id")

                                    self.backup_pseudo_wire_id_type = YLeaf(YType.enumeration, "backup-pseudo-wire-id-type")

                                    self.bound = YLeaf(YType.boolean, "bound")

                                    self.group_id = YLeaf(YType.uint32, "group-id")

                                    self.group_state = YLeaf(YType.enumeration, "group-state")

                                    self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                    self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                    self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "backup_next_hop",
                                                    "backup_pseudo_wire_id",
                                                    "backup_pseudo_wire_id_type",
                                                    "bound",
                                                    "group_id",
                                                    "group_state",
                                                    "grouping_supported",
                                                    "pw_flow_label_tx",
                                                    "redundancy_role") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.backup_next_hop.is_set or
                                        self.backup_pseudo_wire_id.is_set or
                                        self.backup_pseudo_wire_id_type.is_set or
                                        self.bound.is_set or
                                        self.group_id.is_set or
                                        self.group_state.is_set or
                                        self.grouping_supported.is_set or
                                        self.pw_flow_label_tx.is_set or
                                        self.redundancy_role.is_set or
                                        (self.atom is not None and self.atom.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.backup_next_hop.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set or
                                        self.bound.yfilter != YFilter.not_set or
                                        self.group_id.yfilter != YFilter.not_set or
                                        self.group_state.yfilter != YFilter.not_set or
                                        self.grouping_supported.yfilter != YFilter.not_set or
                                        self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                        self.redundancy_role.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-pseudo-wire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.backup_next_hop.is_set or self.backup_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_next_hop.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id.is_set or self.backup_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id_type.is_set or self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id_type.get_name_leafdata())
                                    if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bound.get_name_leafdata())
                                    if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_id.get_name_leafdata())
                                    if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_state.get_name_leafdata())
                                    if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                    if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                    if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_role.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "active" or name == "backup-next-hop" or name == "backup-pseudo-wire-id" or name == "backup-pseudo-wire-id-type" or name == "bound" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "pw-flow-label-tx" or name == "redundancy-role"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-next-hop"):
                                        self.backup_next_hop = value
                                        self.backup_next_hop.value_namespace = name_space
                                        self.backup_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id"):
                                        self.backup_pseudo_wire_id = value
                                        self.backup_pseudo_wire_id.value_namespace = name_space
                                        self.backup_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id-type"):
                                        self.backup_pseudo_wire_id_type = value
                                        self.backup_pseudo_wire_id_type.value_namespace = name_space
                                        self.backup_pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bound"):
                                        self.bound = value
                                        self.bound.value_namespace = name_space
                                        self.bound.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-id"):
                                        self.group_id = value
                                        self.group_id.value_namespace = name_space
                                        self.group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-state"):
                                        self.group_state = value
                                        self.group_state.value_namespace = name_space
                                        self.group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "grouping-supported"):
                                        self.grouping_supported = value
                                        self.grouping_supported.value_namespace = name_space
                                        self.grouping_supported.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-tx"):
                                        self.pw_flow_label_tx = value
                                        self.pw_flow_label_tx.value_namespace = name_space
                                        self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-role"):
                                        self.redundancy_role = value
                                        self.redundancy_role.value_namespace = name_space
                                        self.redundancy_role.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ac_id.is_set or
                                    self.active.is_set or
                                    self.backup_configured.is_set or
                                    self.bound.is_set or
                                    self.context.is_set or
                                    self.forward_class.is_set or
                                    self.global_id.is_set or
                                    self.group_id.is_set or
                                    self.group_state.is_set or
                                    self.grouping_supported.is_set or
                                    self.next_hop_valid.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_flow_label_tx.is_set or
                                    self.pw_id.is_set or
                                    self.pw_load_balance_type.is_set or
                                    self.redundancy_role.is_set or
                                    self.sequence_resync_threshold.is_set or
                                    self.signal_capability_flags.is_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_data()) or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ac_id.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.backup_configured.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.context.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.global_id.yfilter != YFilter.not_set or
                                    self.group_id.yfilter != YFilter.not_set or
                                    self.group_state.yfilter != YFilter.not_set or
                                    self.grouping_supported.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.pw_load_balance_type.yfilter != YFilter.not_set or
                                    self.redundancy_role.yfilter != YFilter.not_set or
                                    self.sequence_resync_threshold.yfilter != YFilter.not_set or
                                    self.signal_capability_flags.yfilter != YFilter.not_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_operation()) or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ac_id.is_set or self.ac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac_id.get_name_leafdata())
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.backup_configured.is_set or self.backup_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_configured.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.context.is_set or self.context.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.context.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.global_id.is_set or self.global_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_id.get_name_leafdata())
                                if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_id.get_name_leafdata())
                                if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_state.get_name_leafdata())
                                if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.pw_load_balance_type.is_set or self.pw_load_balance_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_load_balance_type.get_name_leafdata())
                                if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_role.get_name_leafdata())
                                if (self.sequence_resync_threshold.is_set or self.sequence_resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_resync_threshold.get_name_leafdata())
                                if (self.signal_capability_flags.is_set or self.signal_capability_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signal_capability_flags.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-pseudo-wire"):
                                    if (self.backup_pseudo_wire is None):
                                        self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire()
                                        self.backup_pseudo_wire.parent = self
                                        self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                    return self.backup_pseudo_wire

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                if (child_yang_name == "pseudo-wire-union"):
                                    if (self.pseudo_wire_union is None):
                                        self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion()
                                        self.pseudo_wire_union.parent = self
                                        self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                    return self.pseudo_wire_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-pseudo-wire" or name == "base" or name == "next-hop" or name == "pseudo-wire-union" or name == "ac-id" or name == "active" or name == "backup-configured" or name == "bound" or name == "context" or name == "forward-class" or name == "global-id" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "next-hop-valid" or name == "pseudo-wire-id-type" or name == "pw-flow-label-tx" or name == "pw-id" or name == "pw-load-balance-type" or name == "redundancy-role" or name == "sequence-resync-threshold" or name == "signal-capability-flags"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ac-id"):
                                    self.ac_id = value
                                    self.ac_id.value_namespace = name_space
                                    self.ac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-configured"):
                                    self.backup_configured = value
                                    self.backup_configured.value_namespace = name_space
                                    self.backup_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "context"):
                                    self.context = value
                                    self.context.value_namespace = name_space
                                    self.context.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "global-id"):
                                    self.global_id = value
                                    self.global_id.value_namespace = name_space
                                    self.global_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-id"):
                                    self.group_id = value
                                    self.group_id.value_namespace = name_space
                                    self.group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-state"):
                                    self.group_state = value
                                    self.group_state.value_namespace = name_space
                                    self.group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "grouping-supported"):
                                    self.grouping_supported = value
                                    self.grouping_supported.value_namespace = name_space
                                    self.grouping_supported.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-tx"):
                                    self.pw_flow_label_tx = value
                                    self.pw_flow_label_tx.value_namespace = name_space
                                    self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-load-balance-type"):
                                    self.pw_load_balance_type = value
                                    self.pw_load_balance_type.value_namespace = name_space
                                    self.pw_load_balance_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-role"):
                                    self.redundancy_role = value
                                    self.redundancy_role.value_namespace = name_space
                                    self.redundancy_role.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-resync-threshold"):
                                    self.sequence_resync_threshold = value
                                    self.sequence_resync_threshold.value_namespace = name_space
                                    self.sequence_resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "signal-capability-flags"):
                                    self.signal_capability_flags = value
                                    self.signal_capability_flags.value_namespace = name_space
                                    self.signal_capability_flags.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.evpn is not None and self.evpn.has_data()) or
                                (self.monitor_session is not None and self.monitor_session.has_data()) or
                                (self.pbb is not None and self.pbb.has_data()) or
                                (self.pw is not None and self.pw.has_data()) or
                                (self.vni is not None and self.vni.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.evpn is not None and self.evpn.has_operation()) or
                                (self.monitor_session is not None and self.monitor_session.has_operation()) or
                                (self.pbb is not None and self.pbb.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()) or
                                (self.vni is not None and self.vni.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "evpn"):
                                if (self.evpn is None):
                                    self.evpn = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn()
                                    self.evpn.parent = self
                                    self._children_name_map["evpn"] = "evpn"
                                return self.evpn

                            if (child_yang_name == "monitor-session"):
                                if (self.monitor_session is None):
                                    self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession()
                                    self.monitor_session.parent = self
                                    self._children_name_map["monitor_session"] = "monitor-session"
                                return self.monitor_session

                            if (child_yang_name == "pbb"):
                                if (self.pbb is None):
                                    self.pbb = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb()
                                    self.pbb.parent = self
                                    self._children_name_map["pbb"] = "pbb"
                                return self.pbb

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            if (child_yang_name == "vni"):
                                if (self.vni is None):
                                    self.vni = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni()
                                    self.vni.parent = self
                                    self._children_name_map["vni"] = "vni"
                                return self.vni

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "evpn" or name == "monitor-session" or name == "pbb" or name == "pw" or name == "vni" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix


                    class Segment2(Entity):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:   :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:   :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2, self).__init__()

                            self.yang_name = "segment2"
                            self.yang_parent_name = "l2fibx-con-l2tpv2"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.bp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp()
                            self.bp.parent = self
                            self._children_name_map["bp"] = "bp"
                            self._children_yang_names.add("bp")

                            self.fxs = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs()
                            self.fxs.parent = self
                            self._children_name_map["fxs"] = "fxs"
                            self._children_yang_names.add("fxs")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment2"

                                self.actype = YLeaf(YType.uint8, "actype")

                                self.adjacency_address = YLeaf(YType.str, "adjacency-address")

                                self.adjacency_valid = YLeaf(YType.boolean, "adjacency-valid")

                                self.attachment_circuit_id = YLeaf(YType.uint32, "attachment-circuit-id")

                                self.attachment_circuit_mtu = YLeaf(YType.uint16, "attachment-circuit-mtu")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.fxc_next_hop_valid = YLeaf(YType.boolean, "fxc-next-hop-valid")

                                self.inter_working_mode = YLeaf(YType.uint8, "inter-working-mode")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.ip_inter_working_mac = YLeaf(YType.str, "ip-inter-working-mac")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.sub_interface_handle = YLeaf(YType.str, "sub-interface-handle")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._children_yang_names.add("fxc-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actype",
                                                "adjacency_address",
                                                "adjacency_valid",
                                                "attachment_circuit_id",
                                                "attachment_circuit_mtu",
                                                "bound",
                                                "evpn_internal_label",
                                                "fxc_next_hop_valid",
                                                "inter_working_mode",
                                                "interface_handle",
                                                "ip_inter_working_mac",
                                                "redundancy_group_id",
                                                "redundancy_object_id",
                                                "sub_interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fxc-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.actype.is_set or
                                    self.adjacency_address.is_set or
                                    self.adjacency_valid.is_set or
                                    self.attachment_circuit_id.is_set or
                                    self.attachment_circuit_mtu.is_set or
                                    self.bound.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.fxc_next_hop_valid.is_set or
                                    self.inter_working_mode.is_set or
                                    self.interface_handle.is_set or
                                    self.ip_inter_working_mac.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.sub_interface_handle.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actype.yfilter != YFilter.not_set or
                                    self.adjacency_address.yfilter != YFilter.not_set or
                                    self.adjacency_valid.yfilter != YFilter.not_set or
                                    self.attachment_circuit_id.yfilter != YFilter.not_set or
                                    self.attachment_circuit_mtu.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.fxc_next_hop_valid.yfilter != YFilter.not_set or
                                    self.inter_working_mode.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.ip_inter_working_mac.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.sub_interface_handle.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actype.is_set or self.actype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actype.get_name_leafdata())
                                if (self.adjacency_address.is_set or self.adjacency_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_address.get_name_leafdata())
                                if (self.adjacency_valid.is_set or self.adjacency_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_valid.get_name_leafdata())
                                if (self.attachment_circuit_id.is_set or self.attachment_circuit_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_id.get_name_leafdata())
                                if (self.attachment_circuit_mtu.is_set or self.attachment_circuit_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_mtu.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.fxc_next_hop_valid.is_set or self.fxc_next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxc_next_hop_valid.get_name_leafdata())
                                if (self.inter_working_mode.is_set or self.inter_working_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_working_mode.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.ip_inter_working_mac.is_set or self.ip_inter_working_mac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_inter_working_mac.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.sub_interface_handle.is_set or self.sub_interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "fxc-next-hop"):
                                    if (self.fxc_next_hop is None):
                                        self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop()
                                        self.fxc_next_hop.parent = self
                                        self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                    return self.fxc_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxc-next-hop" or name == "actype" or name == "adjacency-address" or name == "adjacency-valid" or name == "attachment-circuit-id" or name == "attachment-circuit-mtu" or name == "bound" or name == "evpn-internal-label" or name == "fxc-next-hop-valid" or name == "inter-working-mode" or name == "interface-handle" or name == "ip-inter-working-mac" or name == "redundancy-group-id" or name == "redundancy-object-id" or name == "sub-interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actype"):
                                    self.actype = value
                                    self.actype.value_namespace = name_space
                                    self.actype.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-address"):
                                    self.adjacency_address = value
                                    self.adjacency_address.value_namespace = name_space
                                    self.adjacency_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-valid"):
                                    self.adjacency_valid = value
                                    self.adjacency_valid.value_namespace = name_space
                                    self.adjacency_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-id"):
                                    self.attachment_circuit_id = value
                                    self.attachment_circuit_id.value_namespace = name_space
                                    self.attachment_circuit_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-mtu"):
                                    self.attachment_circuit_mtu = value
                                    self.attachment_circuit_mtu.value_namespace = name_space
                                    self.attachment_circuit_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "fxc-next-hop-valid"):
                                    self.fxc_next_hop_valid = value
                                    self.fxc_next_hop_valid.value_namespace = name_space
                                    self.fxc_next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-working-mode"):
                                    self.inter_working_mode = value
                                    self.inter_working_mode.value_namespace = name_space
                                    self.inter_working_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip-inter-working-mac"):
                                    self.ip_inter_working_mac = value
                                    self.ip_inter_working_mac.value_namespace = name_space
                                    self.ip_inter_working_mac.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-interface-handle"):
                                    self.sub_interface_handle = value
                                    self.sub_interface_handle.value_namespace = name_space
                                    self.sub_interface_handle.value_namespace_prefix = name_space_prefix


                        class Bp(Entity):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Base>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:   :py:class:`P2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.P2Mp>`
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp, self).__init__()

                                self.yang_name = "bp"
                                self.yang_parent_name = "segment2"

                                self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                                self.learn_key = YLeaf(YType.uint8, "learn-key")

                                self.msti_pointer = YLeaf(YType.uint32, "msti-pointer")

                                self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                                self.segment_type = YLeaf(YType.uint8, "segment-type")

                                self.shg_id = YLeaf(YType.uint32, "shg-id")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.oper = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self._children_name_map["oper"] = "oper"
                                self._children_yang_names.add("oper")

                                self.p2mp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.P2Mp()
                                self.p2mp.parent = self
                                self._children_name_map["p2mp"] = "p2mp"
                                self._children_yang_names.add("p2mp")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bridge_id",
                                                "learn_key",
                                                "msti_pointer",
                                                "mvrp_sequence_number",
                                                "segment_type",
                                                "shg_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "bp"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Oper(Entity):
                                """
                                Operational information
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper, self).__init__()

                                    self.yang_name = "oper"
                                    self.yang_parent_name = "bp"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self._children_name_map["operational_information"] = "operational-information"
                                    self._children_yang_names.add("operational-information")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper, self).__setattr__(name, value)


                                class OperationalInformation(Entity):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\:  bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: host_routing_enabled
                                    
                                    	Host Routing enabled on this BD
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotify>`
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:   :py:class:`MgmtL2FibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecAction>`
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\:  bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation, self).__init__()

                                        self.yang_name = "operational-information"
                                        self.yang_parent_name = "oper"

                                        self.admin_disabled = YLeaf(YType.boolean, "admin-disabled")

                                        self.bvi_configured = YLeaf(YType.boolean, "bvi-configured")

                                        self.dhcp_enabled = YLeaf(YType.boolean, "dhcp-enabled")

                                        self.dhcp_trusted = YLeaf(YType.boolean, "dhcp-trusted")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flooding_disabled = YLeaf(YType.boolean, "flooding-disabled")

                                        self.host_routing_enabled = YLeaf(YType.boolean, "host-routing-enabled")

                                        self.igmp_flood_forward_enabled = YLeaf(YType.boolean, "igmp-flood-forward-enabled")

                                        self.igmp_mroute_port_enabled = YLeaf(YType.boolean, "igmp-mroute-port-enabled")

                                        self.igmp_route_guard_enabled = YLeaf(YType.boolean, "igmp-route-guard-enabled")

                                        self.igmp_snoop_enabled = YLeaf(YType.boolean, "igmp-snoop-enabled")

                                        self.igmp_snoop_profile_enabled = YLeaf(YType.boolean, "igmp-snoop-profile-enabled")

                                        self.is_bvi_up = YLeaf(YType.boolean, "is-bvi-up")

                                        self.is_dai_addr_validation_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-destination-mac-enabled")

                                        self.is_dai_addr_validation_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-ipv4-enabled")

                                        self.is_dai_addr_validation_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_evpn_cw_disable = YLeaf(YType.boolean, "is-evpn-cw-disable")

                                        self.is_evpn_enabled = YLeaf(YType.boolean, "is-evpn-enabled")

                                        self.is_evpn_flow_label = YLeaf(YType.boolean, "is-evpn-flow-label")

                                        self.is_igmp_snoop_enabled = YLeaf(YType.boolean, "is-igmp-snoop-enabled")

                                        self.is_ipsg_enabled = YLeaf(YType.boolean, "is-ipsg-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.is_p2mp_pw_enabled = YLeaf(YType.boolean, "is-p2mp-pw-enabled")

                                        self.is_pbbevpn_enabled = YLeaf(YType.boolean, "is-pbbevpn-enabled")

                                        self.is_swmac_learning = YLeaf(YType.boolean, "is-swmac-learning")

                                        self.is_vni_enabled = YLeaf(YType.boolean, "is-vni-enabled")

                                        self.is_vpls_flood_optimization_enabled = YLeaf(YType.boolean, "is-vpls-flood-optimization-enabled")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_aging_type = YLeaf(YType.boolean, "mac-aging-type")

                                        self.mac_learning_disabled = YLeaf(YType.boolean, "mac-learning-disabled")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification_type = YLeaf(YType.enumeration, "mac-limit-notification-type")

                                        self.mac_port_down_flush_disabled = YLeaf(YType.boolean, "mac-port-down-flush-disabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_flood_forward_enabled = YLeaf(YType.boolean, "mld-flood-forward-enabled")

                                        self.mld_mroute_port_enabled = YLeaf(YType.boolean, "mld-mroute-port-enabled")

                                        self.mld_route_guard_enabled = YLeaf(YType.boolean, "mld-route-guard-enabled")

                                        self.mld_snoop_enabled = YLeaf(YType.boolean, "mld-snoop-enabled")

                                        self.mld_snoop_profile_enabled = YLeaf(YType.boolean, "mld-snoop-profile-enabled")

                                        self.msti = YLeaf(YType.uint32, "msti")

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.number_of_macs = YLeaf(YType.uint32, "number-of-macs")

                                        self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                                        self.storm_control_broadcast_enabled = YLeaf(YType.boolean, "storm-control-broadcast-enabled")

                                        self.storm_control_broadcast_rate_unit = YLeaf(YType.enumeration, "storm-control-broadcast-rate-unit")

                                        self.storm_control_multicast_enabled = YLeaf(YType.boolean, "storm-control-multicast-enabled")

                                        self.storm_control_multicast_rate_unit = YLeaf(YType.enumeration, "storm-control-multicast-rate-unit")

                                        self.storm_control_unicast_enabled = YLeaf(YType.boolean, "storm-control-unicast-enabled")

                                        self.storm_control_unicast_rate_unit = YLeaf(YType.enumeration, "storm-control-unicast-rate-unit")

                                        self.stp_participating = YLeaf(YType.boolean, "stp-participating")

                                        self.unknown_unicast_flooding_disabled = YLeaf(YType.boolean, "unknown-unicast-flooding-disabled")

                                        self.feature = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("admin_disabled",
                                                        "bvi_configured",
                                                        "dhcp_enabled",
                                                        "dhcp_trusted",
                                                        "flood_unknown_unicast_enabled",
                                                        "flooding_disabled",
                                                        "host_routing_enabled",
                                                        "igmp_flood_forward_enabled",
                                                        "igmp_mroute_port_enabled",
                                                        "igmp_route_guard_enabled",
                                                        "igmp_snoop_enabled",
                                                        "igmp_snoop_profile_enabled",
                                                        "is_bvi_up",
                                                        "is_dai_addr_validation_destination_mac_enabled",
                                                        "is_dai_addr_validation_ipv4_enabled",
                                                        "is_dai_addr_validation_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_evpn_cw_disable",
                                                        "is_evpn_enabled",
                                                        "is_evpn_flow_label",
                                                        "is_igmp_snoop_enabled",
                                                        "is_ipsg_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "is_p2mp_pw_enabled",
                                                        "is_pbbevpn_enabled",
                                                        "is_swmac_learning",
                                                        "is_vni_enabled",
                                                        "is_vpls_flood_optimization_enabled",
                                                        "mac_aging_time",
                                                        "mac_aging_type",
                                                        "mac_learning_disabled",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification_type",
                                                        "mac_port_down_flush_disabled",
                                                        "mac_secure_action",
                                                        "mld_flood_forward_enabled",
                                                        "mld_mroute_port_enabled",
                                                        "mld_route_guard_enabled",
                                                        "mld_snoop_enabled",
                                                        "mld_snoop_profile_enabled",
                                                        "msti",
                                                        "mtu",
                                                        "number_of_macs",
                                                        "nv_satellite_offload_ipv4_multicast_disabled",
                                                        "storm_control_broadcast_enabled",
                                                        "storm_control_broadcast_rate_unit",
                                                        "storm_control_multicast_enabled",
                                                        "storm_control_multicast_rate_unit",
                                                        "storm_control_unicast_enabled",
                                                        "storm_control_unicast_rate_unit",
                                                        "stp_participating",
                                                        "unknown_unicast_flooding_disabled") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation, self).__setattr__(name, value)


                                    class Feature(Entity):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:   :py:class:`L2FibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeature>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature, self).__init__()

                                            self.yang_name = "feature"
                                            self.yang_parent_name = "operational-information"

                                            self.feature_type = YLeaf(YType.enumeration, "feature-type")

                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self._children_name_map["dhcp"] = "dhcp"
                                            self._children_yang_names.add("dhcp")

                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self._children_name_map["igmp"] = "igmp"
                                            self._children_yang_names.add("igmp")

                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self
                                            self._children_name_map["mld"] = "mld"
                                            self._children_yang_names.add("mld")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("feature_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature, self).__setattr__(name, value)


                                        class Dhcp(Entity):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                                self.yang_name = "dhcp"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dhcp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix


                                        class Igmp(Entity):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                                self.yang_name = "igmp"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "igmp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix


                                        class Mld(Entity):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                                self.yang_name = "mld"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mld" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.feature_type.is_set or
                                                (self.dhcp is not None and self.dhcp.has_data()) or
                                                (self.igmp is not None and self.igmp.has_data()) or
                                                (self.mld is not None and self.mld.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.feature_type.yfilter != YFilter.not_set or
                                                (self.dhcp is not None and self.dhcp.has_operation()) or
                                                (self.igmp is not None and self.igmp.has_operation()) or
                                                (self.mld is not None and self.mld.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "feature" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.feature_type.is_set or self.feature_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.feature_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dhcp"):
                                                if (self.dhcp is None):
                                                    self.dhcp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                                    self.dhcp.parent = self
                                                    self._children_name_map["dhcp"] = "dhcp"
                                                return self.dhcp

                                            if (child_yang_name == "igmp"):
                                                if (self.igmp is None):
                                                    self.igmp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                                    self.igmp.parent = self
                                                    self._children_name_map["igmp"] = "igmp"
                                                return self.igmp

                                            if (child_yang_name == "mld"):
                                                if (self.mld is None):
                                                    self.mld = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                                    self.mld.parent = self
                                                    self._children_name_map["mld"] = "mld"
                                                return self.mld

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dhcp" or name == "igmp" or name == "mld" or name == "feature-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "feature-type"):
                                                self.feature_type = value
                                                self.feature_type.value_namespace = name_space
                                                self.feature_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.feature:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.admin_disabled.is_set or
                                            self.bvi_configured.is_set or
                                            self.dhcp_enabled.is_set or
                                            self.dhcp_trusted.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flooding_disabled.is_set or
                                            self.host_routing_enabled.is_set or
                                            self.igmp_flood_forward_enabled.is_set or
                                            self.igmp_mroute_port_enabled.is_set or
                                            self.igmp_route_guard_enabled.is_set or
                                            self.igmp_snoop_enabled.is_set or
                                            self.igmp_snoop_profile_enabled.is_set or
                                            self.is_bvi_up.is_set or
                                            self.is_dai_addr_validation_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validation_ipv4_enabled.is_set or
                                            self.is_dai_addr_validation_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_evpn_cw_disable.is_set or
                                            self.is_evpn_enabled.is_set or
                                            self.is_evpn_flow_label.is_set or
                                            self.is_igmp_snoop_enabled.is_set or
                                            self.is_ipsg_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.is_p2mp_pw_enabled.is_set or
                                            self.is_pbbevpn_enabled.is_set or
                                            self.is_swmac_learning.is_set or
                                            self.is_vni_enabled.is_set or
                                            self.is_vpls_flood_optimization_enabled.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_aging_type.is_set or
                                            self.mac_learning_disabled.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification_type.is_set or
                                            self.mac_port_down_flush_disabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_flood_forward_enabled.is_set or
                                            self.mld_mroute_port_enabled.is_set or
                                            self.mld_route_guard_enabled.is_set or
                                            self.mld_snoop_enabled.is_set or
                                            self.mld_snoop_profile_enabled.is_set or
                                            self.msti.is_set or
                                            self.mtu.is_set or
                                            self.number_of_macs.is_set or
                                            self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                                            self.storm_control_broadcast_enabled.is_set or
                                            self.storm_control_broadcast_rate_unit.is_set or
                                            self.storm_control_multicast_enabled.is_set or
                                            self.storm_control_multicast_rate_unit.is_set or
                                            self.storm_control_unicast_enabled.is_set or
                                            self.storm_control_unicast_rate_unit.is_set or
                                            self.stp_participating.is_set or
                                            self.unknown_unicast_flooding_disabled.is_set)

                                    def has_operation(self):
                                        for c in self.feature:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.admin_disabled.yfilter != YFilter.not_set or
                                            self.bvi_configured.yfilter != YFilter.not_set or
                                            self.dhcp_enabled.yfilter != YFilter.not_set or
                                            self.dhcp_trusted.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flooding_disabled.yfilter != YFilter.not_set or
                                            self.host_routing_enabled.yfilter != YFilter.not_set or
                                            self.igmp_flood_forward_enabled.yfilter != YFilter.not_set or
                                            self.igmp_mroute_port_enabled.yfilter != YFilter.not_set or
                                            self.igmp_route_guard_enabled.yfilter != YFilter.not_set or
                                            self.igmp_snoop_enabled.yfilter != YFilter.not_set or
                                            self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set or
                                            self.is_bvi_up.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_evpn_cw_disable.yfilter != YFilter.not_set or
                                            self.is_evpn_enabled.yfilter != YFilter.not_set or
                                            self.is_evpn_flow_label.yfilter != YFilter.not_set or
                                            self.is_igmp_snoop_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_p2mp_pw_enabled.yfilter != YFilter.not_set or
                                            self.is_pbbevpn_enabled.yfilter != YFilter.not_set or
                                            self.is_swmac_learning.yfilter != YFilter.not_set or
                                            self.is_vni_enabled.yfilter != YFilter.not_set or
                                            self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_aging_type.yfilter != YFilter.not_set or
                                            self.mac_learning_disabled.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification_type.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_disabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_flood_forward_enabled.yfilter != YFilter.not_set or
                                            self.mld_mroute_port_enabled.yfilter != YFilter.not_set or
                                            self.mld_route_guard_enabled.yfilter != YFilter.not_set or
                                            self.mld_snoop_enabled.yfilter != YFilter.not_set or
                                            self.mld_snoop_profile_enabled.yfilter != YFilter.not_set or
                                            self.msti.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.number_of_macs.yfilter != YFilter.not_set or
                                            self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                                            self.storm_control_broadcast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set or
                                            self.storm_control_multicast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set or
                                            self.storm_control_unicast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set or
                                            self.stp_participating.yfilter != YFilter.not_set or
                                            self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "operational-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.admin_disabled.is_set or self.admin_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.admin_disabled.get_name_leafdata())
                                        if (self.bvi_configured.is_set or self.bvi_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bvi_configured.get_name_leafdata())
                                        if (self.dhcp_enabled.is_set or self.dhcp_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcp_enabled.get_name_leafdata())
                                        if (self.dhcp_trusted.is_set or self.dhcp_trusted.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcp_trusted.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flooding_disabled.is_set or self.flooding_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flooding_disabled.get_name_leafdata())
                                        if (self.host_routing_enabled.is_set or self.host_routing_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.host_routing_enabled.get_name_leafdata())
                                        if (self.igmp_flood_forward_enabled.is_set or self.igmp_flood_forward_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_flood_forward_enabled.get_name_leafdata())
                                        if (self.igmp_mroute_port_enabled.is_set or self.igmp_mroute_port_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_mroute_port_enabled.get_name_leafdata())
                                        if (self.igmp_route_guard_enabled.is_set or self.igmp_route_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_route_guard_enabled.get_name_leafdata())
                                        if (self.igmp_snoop_enabled.is_set or self.igmp_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_snoop_enabled.get_name_leafdata())
                                        if (self.igmp_snoop_profile_enabled.is_set or self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_snoop_profile_enabled.get_name_leafdata())
                                        if (self.is_bvi_up.is_set or self.is_bvi_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_bvi_up.get_name_leafdata())
                                        if (self.is_dai_addr_validation_destination_mac_enabled.is_set or self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validation_ipv4_enabled.is_set or self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validation_source_mac_enabled.is_set or self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_evpn_cw_disable.is_set or self.is_evpn_cw_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_cw_disable.get_name_leafdata())
                                        if (self.is_evpn_enabled.is_set or self.is_evpn_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_enabled.get_name_leafdata())
                                        if (self.is_evpn_flow_label.is_set or self.is_evpn_flow_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_flow_label.get_name_leafdata())
                                        if (self.is_igmp_snoop_enabled.is_set or self.is_igmp_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_igmp_snoop_enabled.get_name_leafdata())
                                        if (self.is_ipsg_enabled.is_set or self.is_ipsg_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown.is_set or self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.is_p2mp_pw_enabled.is_set or self.is_p2mp_pw_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_p2mp_pw_enabled.get_name_leafdata())
                                        if (self.is_pbbevpn_enabled.is_set or self.is_pbbevpn_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pbbevpn_enabled.get_name_leafdata())
                                        if (self.is_swmac_learning.is_set or self.is_swmac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_swmac_learning.get_name_leafdata())
                                        if (self.is_vni_enabled.is_set or self.is_vni_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_vni_enabled.get_name_leafdata())
                                        if (self.is_vpls_flood_optimization_enabled.is_set or self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_vpls_flood_optimization_enabled.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_aging_type.is_set or self.mac_aging_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_type.get_name_leafdata())
                                        if (self.mac_learning_disabled.is_set or self.mac_learning_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning_disabled.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification_type.is_set or self.mac_limit_notification_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification_type.get_name_leafdata())
                                        if (self.mac_port_down_flush_disabled.is_set or self.mac_port_down_flush_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_disabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_flood_forward_enabled.is_set or self.mld_flood_forward_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_flood_forward_enabled.get_name_leafdata())
                                        if (self.mld_mroute_port_enabled.is_set or self.mld_mroute_port_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_mroute_port_enabled.get_name_leafdata())
                                        if (self.mld_route_guard_enabled.is_set or self.mld_route_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_route_guard_enabled.get_name_leafdata())
                                        if (self.mld_snoop_enabled.is_set or self.mld_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_snoop_enabled.get_name_leafdata())
                                        if (self.mld_snoop_profile_enabled.is_set or self.mld_snoop_profile_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_snoop_profile_enabled.get_name_leafdata())
                                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msti.get_name_leafdata())
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.number_of_macs.is_set or self.number_of_macs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_macs.get_name_leafdata())
                                        if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                                        if (self.storm_control_broadcast_enabled.is_set or self.storm_control_broadcast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_broadcast_enabled.get_name_leafdata())
                                        if (self.storm_control_broadcast_rate_unit.is_set or self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_broadcast_rate_unit.get_name_leafdata())
                                        if (self.storm_control_multicast_enabled.is_set or self.storm_control_multicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_multicast_enabled.get_name_leafdata())
                                        if (self.storm_control_multicast_rate_unit.is_set or self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_multicast_rate_unit.get_name_leafdata())
                                        if (self.storm_control_unicast_enabled.is_set or self.storm_control_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_unicast_enabled.get_name_leafdata())
                                        if (self.storm_control_unicast_rate_unit.is_set or self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_unicast_rate_unit.get_name_leafdata())
                                        if (self.stp_participating.is_set or self.stp_participating.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.stp_participating.get_name_leafdata())
                                        if (self.unknown_unicast_flooding_disabled.is_set or self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unknown_unicast_flooding_disabled.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "feature"):
                                            for c in self.feature:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.feature.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "feature" or name == "admin-disabled" or name == "bvi-configured" or name == "dhcp-enabled" or name == "dhcp-trusted" or name == "flood-unknown-unicast-enabled" or name == "flooding-disabled" or name == "host-routing-enabled" or name == "igmp-flood-forward-enabled" or name == "igmp-mroute-port-enabled" or name == "igmp-route-guard-enabled" or name == "igmp-snoop-enabled" or name == "igmp-snoop-profile-enabled" or name == "is-bvi-up" or name == "is-dai-addr-validation-destination-mac-enabled" or name == "is-dai-addr-validation-ipv4-enabled" or name == "is-dai-addr-validation-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-evpn-cw-disable" or name == "is-evpn-enabled" or name == "is-evpn-flow-label" or name == "is-igmp-snoop-enabled" or name == "is-ipsg-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "is-p2mp-pw-enabled" or name == "is-pbbevpn-enabled" or name == "is-swmac-learning" or name == "is-vni-enabled" or name == "is-vpls-flood-optimization-enabled" or name == "mac-aging-time" or name == "mac-aging-type" or name == "mac-learning-disabled" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification-type" or name == "mac-port-down-flush-disabled" or name == "mac-secure-action" or name == "mld-flood-forward-enabled" or name == "mld-mroute-port-enabled" or name == "mld-route-guard-enabled" or name == "mld-snoop-enabled" or name == "mld-snoop-profile-enabled" or name == "msti" or name == "mtu" or name == "number-of-macs" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "storm-control-broadcast-enabled" or name == "storm-control-broadcast-rate-unit" or name == "storm-control-multicast-enabled" or name == "storm-control-multicast-rate-unit" or name == "storm-control-unicast-enabled" or name == "storm-control-unicast-rate-unit" or name == "stp-participating" or name == "unknown-unicast-flooding-disabled"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "admin-disabled"):
                                            self.admin_disabled = value
                                            self.admin_disabled.value_namespace = name_space
                                            self.admin_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bvi-configured"):
                                            self.bvi_configured = value
                                            self.bvi_configured.value_namespace = name_space
                                            self.bvi_configured.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcp-enabled"):
                                            self.dhcp_enabled = value
                                            self.dhcp_enabled.value_namespace = name_space
                                            self.dhcp_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcp-trusted"):
                                            self.dhcp_trusted = value
                                            self.dhcp_trusted.value_namespace = name_space
                                            self.dhcp_trusted.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flooding-disabled"):
                                            self.flooding_disabled = value
                                            self.flooding_disabled.value_namespace = name_space
                                            self.flooding_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "host-routing-enabled"):
                                            self.host_routing_enabled = value
                                            self.host_routing_enabled.value_namespace = name_space
                                            self.host_routing_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-flood-forward-enabled"):
                                            self.igmp_flood_forward_enabled = value
                                            self.igmp_flood_forward_enabled.value_namespace = name_space
                                            self.igmp_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-mroute-port-enabled"):
                                            self.igmp_mroute_port_enabled = value
                                            self.igmp_mroute_port_enabled.value_namespace = name_space
                                            self.igmp_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-route-guard-enabled"):
                                            self.igmp_route_guard_enabled = value
                                            self.igmp_route_guard_enabled.value_namespace = name_space
                                            self.igmp_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-snoop-enabled"):
                                            self.igmp_snoop_enabled = value
                                            self.igmp_snoop_enabled.value_namespace = name_space
                                            self.igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-snoop-profile-enabled"):
                                            self.igmp_snoop_profile_enabled = value
                                            self.igmp_snoop_profile_enabled.value_namespace = name_space
                                            self.igmp_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-bvi-up"):
                                            self.is_bvi_up = value
                                            self.is_bvi_up.value_namespace = name_space
                                            self.is_bvi_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-destination-mac-enabled"):
                                            self.is_dai_addr_validation_destination_mac_enabled = value
                                            self.is_dai_addr_validation_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-ipv4-enabled"):
                                            self.is_dai_addr_validation_ipv4_enabled = value
                                            self.is_dai_addr_validation_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-source-mac-enabled"):
                                            self.is_dai_addr_validation_source_mac_enabled = value
                                            self.is_dai_addr_validation_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-cw-disable"):
                                            self.is_evpn_cw_disable = value
                                            self.is_evpn_cw_disable.value_namespace = name_space
                                            self.is_evpn_cw_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-enabled"):
                                            self.is_evpn_enabled = value
                                            self.is_evpn_enabled.value_namespace = name_space
                                            self.is_evpn_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-flow-label"):
                                            self.is_evpn_flow_label = value
                                            self.is_evpn_flow_label.value_namespace = name_space
                                            self.is_evpn_flow_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-igmp-snoop-enabled"):
                                            self.is_igmp_snoop_enabled = value
                                            self.is_igmp_snoop_enabled.value_namespace = name_space
                                            self.is_igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-enabled"):
                                            self.is_ipsg_enabled = value
                                            self.is_ipsg_enabled.value_namespace = name_space
                                            self.is_ipsg_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown"):
                                            self.is_mac_secure_accept_shutdown = value
                                            self.is_mac_secure_accept_shutdown.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-p2mp-pw-enabled"):
                                            self.is_p2mp_pw_enabled = value
                                            self.is_p2mp_pw_enabled.value_namespace = name_space
                                            self.is_p2mp_pw_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-pbbevpn-enabled"):
                                            self.is_pbbevpn_enabled = value
                                            self.is_pbbevpn_enabled.value_namespace = name_space
                                            self.is_pbbevpn_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-swmac-learning"):
                                            self.is_swmac_learning = value
                                            self.is_swmac_learning.value_namespace = name_space
                                            self.is_swmac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-vni-enabled"):
                                            self.is_vni_enabled = value
                                            self.is_vni_enabled.value_namespace = name_space
                                            self.is_vni_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-vpls-flood-optimization-enabled"):
                                            self.is_vpls_flood_optimization_enabled = value
                                            self.is_vpls_flood_optimization_enabled.value_namespace = name_space
                                            self.is_vpls_flood_optimization_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-type"):
                                            self.mac_aging_type = value
                                            self.mac_aging_type.value_namespace = name_space
                                            self.mac_aging_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning-disabled"):
                                            self.mac_learning_disabled = value
                                            self.mac_learning_disabled.value_namespace = name_space
                                            self.mac_learning_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification-type"):
                                            self.mac_limit_notification_type = value
                                            self.mac_limit_notification_type.value_namespace = name_space
                                            self.mac_limit_notification_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-disabled"):
                                            self.mac_port_down_flush_disabled = value
                                            self.mac_port_down_flush_disabled.value_namespace = name_space
                                            self.mac_port_down_flush_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-flood-forward-enabled"):
                                            self.mld_flood_forward_enabled = value
                                            self.mld_flood_forward_enabled.value_namespace = name_space
                                            self.mld_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-mroute-port-enabled"):
                                            self.mld_mroute_port_enabled = value
                                            self.mld_mroute_port_enabled.value_namespace = name_space
                                            self.mld_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-route-guard-enabled"):
                                            self.mld_route_guard_enabled = value
                                            self.mld_route_guard_enabled.value_namespace = name_space
                                            self.mld_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-snoop-enabled"):
                                            self.mld_snoop_enabled = value
                                            self.mld_snoop_enabled.value_namespace = name_space
                                            self.mld_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-snoop-profile-enabled"):
                                            self.mld_snoop_profile_enabled = value
                                            self.mld_snoop_profile_enabled.value_namespace = name_space
                                            self.mld_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msti"):
                                            self.msti = value
                                            self.msti.value_namespace = name_space
                                            self.msti.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-macs"):
                                            self.number_of_macs = value
                                            self.number_of_macs.value_namespace = name_space
                                            self.number_of_macs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                                            self.nv_satellite_offload_ipv4_multicast_disabled = value
                                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-broadcast-enabled"):
                                            self.storm_control_broadcast_enabled = value
                                            self.storm_control_broadcast_enabled.value_namespace = name_space
                                            self.storm_control_broadcast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-broadcast-rate-unit"):
                                            self.storm_control_broadcast_rate_unit = value
                                            self.storm_control_broadcast_rate_unit.value_namespace = name_space
                                            self.storm_control_broadcast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-multicast-enabled"):
                                            self.storm_control_multicast_enabled = value
                                            self.storm_control_multicast_enabled.value_namespace = name_space
                                            self.storm_control_multicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-multicast-rate-unit"):
                                            self.storm_control_multicast_rate_unit = value
                                            self.storm_control_multicast_rate_unit.value_namespace = name_space
                                            self.storm_control_multicast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-unicast-enabled"):
                                            self.storm_control_unicast_enabled = value
                                            self.storm_control_unicast_enabled.value_namespace = name_space
                                            self.storm_control_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-unicast-rate-unit"):
                                            self.storm_control_unicast_rate_unit = value
                                            self.storm_control_unicast_rate_unit.value_namespace = name_space
                                            self.storm_control_unicast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "stp-participating"):
                                            self.stp_participating = value
                                            self.stp_participating.value_namespace = name_space
                                            self.stp_participating.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unknown-unicast-flooding-disabled"):
                                            self.unknown_unicast_flooding_disabled = value
                                            self.unknown_unicast_flooding_disabled.value_namespace = name_space
                                            self.unknown_unicast_flooding_disabled.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        (self.operational_information is not None and self.operational_information.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        (self.operational_information is not None and self.operational_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "oper" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "operational-information"):
                                        if (self.operational_information is None):
                                            self.operational_information = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation()
                                            self.operational_information.parent = self
                                            self._children_name_map["operational_information"] = "operational-information"
                                        return self.operational_information

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "operational-information" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix


                            class P2Mp(Entity):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\:  bool
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:   :py:class:`L2VpnPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPtree>`
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.P2Mp, self).__init__()

                                    self.yang_name = "p2mp"
                                    self.yang_parent_name = "bp"

                                    self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                                    self.lsm_id = YLeaf(YType.uint32, "lsm-id")

                                    self.p2mp_id = YLeaf(YType.uint16, "p2mp-id")

                                    self.ptree_owner_lmrib = YLeaf(YType.boolean, "ptree-owner-lmrib")

                                    self.ptree_type = YLeaf(YType.enumeration, "ptree-type")

                                    self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("extended_tunnel_id",
                                                    "lsm_id",
                                                    "p2mp_id",
                                                    "ptree_owner_lmrib",
                                                    "ptree_type",
                                                    "tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.P2Mp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.P2Mp, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.extended_tunnel_id.is_set or
                                        self.lsm_id.is_set or
                                        self.p2mp_id.is_set or
                                        self.ptree_owner_lmrib.is_set or
                                        self.ptree_type.is_set or
                                        self.tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.lsm_id.yfilter != YFilter.not_set or
                                        self.p2mp_id.yfilter != YFilter.not_set or
                                        self.ptree_owner_lmrib.yfilter != YFilter.not_set or
                                        self.ptree_type.yfilter != YFilter.not_set or
                                        self.tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                                    if (self.lsm_id.is_set or self.lsm_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsm_id.get_name_leafdata())
                                    if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                                    if (self.ptree_owner_lmrib.is_set or self.ptree_owner_lmrib.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ptree_owner_lmrib.get_name_leafdata())
                                    if (self.ptree_type.is_set or self.ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ptree_type.get_name_leafdata())
                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "extended-tunnel-id" or name == "lsm-id" or name == "p2mp-id" or name == "ptree-owner-lmrib" or name == "ptree-type" or name == "tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "extended-tunnel-id"):
                                        self.extended_tunnel_id = value
                                        self.extended_tunnel_id.value_namespace = name_space
                                        self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsm-id"):
                                        self.lsm_id = value
                                        self.lsm_id.value_namespace = name_space
                                        self.lsm_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "p2mp-id"):
                                        self.p2mp_id = value
                                        self.p2mp_id.value_namespace = name_space
                                        self.p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ptree-owner-lmrib"):
                                        self.ptree_owner_lmrib = value
                                        self.ptree_owner_lmrib.value_namespace = name_space
                                        self.ptree_owner_lmrib.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ptree-type"):
                                        self.ptree_type = value
                                        self.ptree_type.value_namespace = name_space
                                        self.ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-id"):
                                        self.tunnel_id = value
                                        self.tunnel_id.value_namespace = name_space
                                        self.tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bridge_id.is_set or
                                    self.learn_key.is_set or
                                    self.msti_pointer.is_set or
                                    self.mvrp_sequence_number.is_set or
                                    self.segment_type.is_set or
                                    self.shg_id.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.oper is not None and self.oper.has_data()) or
                                    (self.p2mp is not None and self.p2mp.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bridge_id.yfilter != YFilter.not_set or
                                    self.learn_key.yfilter != YFilter.not_set or
                                    self.msti_pointer.yfilter != YFilter.not_set or
                                    self.mvrp_sequence_number.yfilter != YFilter.not_set or
                                    self.segment_type.yfilter != YFilter.not_set or
                                    self.shg_id.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.oper is not None and self.oper.has_operation()) or
                                    (self.p2mp is not None and self.p2mp.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bp" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_id.get_name_leafdata())
                                if (self.learn_key.is_set or self.learn_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.learn_key.get_name_leafdata())
                                if (self.msti_pointer.is_set or self.msti_pointer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_pointer.get_name_leafdata())
                                if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())
                                if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_type.get_name_leafdata())
                                if (self.shg_id.is_set or self.shg_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shg_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "oper"):
                                    if (self.oper is None):
                                        self.oper = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper()
                                        self.oper.parent = self
                                        self._children_name_map["oper"] = "oper"
                                    return self.oper

                                if (child_yang_name == "p2mp"):
                                    if (self.p2mp is None):
                                        self.p2mp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.P2Mp()
                                        self.p2mp.parent = self
                                        self._children_name_map["p2mp"] = "p2mp"
                                    return self.p2mp

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "oper" or name == "p2mp" or name == "bridge-id" or name == "learn-key" or name == "msti-pointer" or name == "mvrp-sequence-number" or name == "segment-type" or name == "shg-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bridge-id"):
                                    self.bridge_id = value
                                    self.bridge_id.value_namespace = name_space
                                    self.bridge_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "learn-key"):
                                    self.learn_key = value
                                    self.learn_key.value_namespace = name_space
                                    self.learn_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-pointer"):
                                    self.msti_pointer = value
                                    self.msti_pointer.value_namespace = name_space
                                    self.msti_pointer.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvrp-sequence-number"):
                                    self.mvrp_sequence_number = value
                                    self.mvrp_sequence_number.value_namespace = name_space
                                    self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-type"):
                                    self.segment_type = value
                                    self.segment_type.value_namespace = name_space
                                    self.segment_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shg-id"):
                                    self.shg_id = value
                                    self.shg_id.value_namespace = name_space
                                    self.shg_id.value_namespace_prefix = name_space_prefix


                        class Fxs(Entity):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs, self).__init__()

                                self.yang_name = "fxs"
                                self.yang_parent_name = "segment2"

                                self.fxs_id = YLeaf(YType.uint32, "fxs-id")

                                self.segment_type = YLeaf(YType.uint8, "segment-type")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fxs_id",
                                                "segment_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "fxs"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.fxs_id.is_set or
                                    self.segment_type.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fxs_id.yfilter != YFilter.not_set or
                                    self.segment_type.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "fxs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fxs_id.is_set or self.fxs_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxs_id.get_name_leafdata())
                                if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxs-id" or name == "segment-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fxs-id"):
                                    self.fxs_id = value
                                    self.fxs_id.value_namespace = name_space
                                    self.fxs_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-type"):
                                    self.segment_type = value
                                    self.segment_type.value_namespace = name_space
                                    self.segment_type.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBal>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment2"

                                self.ac_id = YLeaf(YType.uint32, "ac-id")

                                self.active = YLeaf(YType.boolean, "active")

                                self.backup_configured = YLeaf(YType.boolean, "backup-configured")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.context = YLeaf(YType.uint16, "context")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.global_id = YLeaf(YType.uint32, "global-id")

                                self.group_id = YLeaf(YType.uint32, "group-id")

                                self.group_state = YLeaf(YType.enumeration, "group-state")

                                self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                                self.pw_load_balance_type = YLeaf(YType.enumeration, "pw-load-balance-type")

                                self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                self.sequence_resync_threshold = YLeaf(YType.uint16, "sequence-resync-threshold")

                                self.signal_capability_flags = YLeaf(YType.uint32, "signal-capability-flags")

                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._children_yang_names.add("backup-pseudo-wire")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                self._children_yang_names.add("pseudo-wire-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ac_id",
                                                "active",
                                                "backup_configured",
                                                "bound",
                                                "context",
                                                "forward_class",
                                                "global_id",
                                                "group_id",
                                                "group_state",
                                                "grouping_supported",
                                                "next_hop_valid",
                                                "pseudo_wire_id_type",
                                                "pw_flow_label_tx",
                                                "pw_id",
                                                "pw_load_balance_type",
                                                "redundancy_role",
                                                "sequence_resync_threshold",
                                                "signal_capability_flags") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"
                                    self._children_yang_names.add("l2tp")

                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._children_yang_names.add("l2tp-ipv6-ts")

                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"
                                    self._children_yang_names.add("l2tpv2")

                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"
                                    self._children_yang_names.add("mpls")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion, self).__setattr__(name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix


                                class L2Tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_mtu",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_mtu.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "path-mtu" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix


                                class L2Tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.protocol = YLeaf(YType.uint16, "protocol")

                                        self.pw_flags = YLeaf(YType.uint8, "pw-flags")

                                        self.rem_udp_port = YLeaf(YType.uint16, "rem-udp-port")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop_address",
                                                        "path_mtu",
                                                        "protocol",
                                                        "pw_flags",
                                                        "rem_udp_port",
                                                        "source_address",
                                                        "tos_val",
                                                        "ttl",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.next_hop_address.is_set or
                                            self.path_mtu.is_set or
                                            self.protocol.is_set or
                                            self.pw_flags.is_set or
                                            self.rem_udp_port.is_set or
                                            self.source_address.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            self.xconnect_id.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pw_flags.yfilter != YFilter.not_set or
                                            self.rem_udp_port.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv2" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pw_flags.is_set or self.pw_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flags.get_name_leafdata())
                                        if (self.rem_udp_port.is_set or self.rem_udp_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_udp_port.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "next-hop-address" or name == "path-mtu" or name == "protocol" or name == "pw-flags" or name == "rem-udp-port" or name == "source-address" or name == "tos-val" or name == "ttl" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop-address"):
                                            self.next_hop_address = value
                                            self.next_hop_address.value_namespace = name_space
                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flags"):
                                            self.pw_flags = value
                                            self.pw_flags.value_namespace = name_space
                                            self.pw_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-udp-port"):
                                            self.rem_udp_port = value
                                            self.rem_udp_port.value_namespace = name_space
                                            self.rem_udp_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class L2TpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address",
                                                        "path_mtu",
                                                        "remote_address",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.secondary_cookie_high_value = YLeaf(YType.uint32, "secondary-cookie-high-value")

                                            self.secondary_cookie_low_value = YLeaf(YType.uint32, "secondary-cookie-low-value")

                                            self.secondary_cookie_size = YLeaf(YType.uint8, "secondary-cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "secondary_cookie_high_value",
                                                            "secondary_cookie_low_value",
                                                            "secondary_cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.secondary_cookie_high_value.is_set or
                                                self.secondary_cookie_low_value.is_set or
                                                self.secondary_cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.secondary_cookie_high_value.is_set or self.secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_high_value.get_name_leafdata())
                                            if (self.secondary_cookie_low_value.is_set or self.secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_low_value.get_name_leafdata())
                                            if (self.secondary_cookie_size.is_set or self.secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "secondary-cookie-high-value" or name == "secondary-cookie-low-value" or name == "secondary-cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-high-value"):
                                                self.secondary_cookie_high_value = value
                                                self.secondary_cookie_high_value.value_namespace = name_space
                                                self.secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-low-value"):
                                                self.secondary_cookie_low_value = value
                                                self.secondary_cookie_low_value.value_namespace = name_space
                                                self.secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-size"):
                                                self.secondary_cookie_size = value
                                                self.secondary_cookie_size.value_namespace = name_space
                                                self.secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.local_address.is_set or
                                            self.path_mtu.is_set or
                                            self.remote_address.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp-ipv6-ts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "local-address" or name == "path-mtu" or name == "remote-address" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        (self.l2tp is not None and self.l2tp.has_data()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_data()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_data()) or
                                        (self.mpls is not None and self.mpls.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        (self.l2tp is not None and self.l2tp.has_operation()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_operation()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_operation()) or
                                        (self.mpls is not None and self.mpls.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudo-wire-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2tp"):
                                        if (self.l2tp is None):
                                            self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp()
                                            self.l2tp.parent = self
                                            self._children_name_map["l2tp"] = "l2tp"
                                        return self.l2tp

                                    if (child_yang_name == "l2tp-ipv6-ts"):
                                        if (self.l2tp_ipv6_ts is None):
                                            self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                            self.l2tp_ipv6_ts.parent = self
                                            self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                        return self.l2tp_ipv6_ts

                                    if (child_yang_name == "l2tpv2"):
                                        if (self.l2tpv2 is None):
                                            self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                            self.l2tpv2.parent = self
                                            self._children_name_map["l2tpv2"] = "l2tpv2"
                                        return self.l2tpv2

                                    if (child_yang_name == "mpls"):
                                        if (self.mpls is None):
                                            self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                        return self.mpls

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2tp" or name == "l2tp-ipv6-ts" or name == "l2tpv2" or name == "mpls" or name == "data-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.backup_next_hop = YLeaf(YType.str, "backup-next-hop")

                                    self.backup_pseudo_wire_id = YLeaf(YType.uint32, "backup-pseudo-wire-id")

                                    self.backup_pseudo_wire_id_type = YLeaf(YType.enumeration, "backup-pseudo-wire-id-type")

                                    self.bound = YLeaf(YType.boolean, "bound")

                                    self.group_id = YLeaf(YType.uint32, "group-id")

                                    self.group_state = YLeaf(YType.enumeration, "group-state")

                                    self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                    self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                    self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "backup_next_hop",
                                                    "backup_pseudo_wire_id",
                                                    "backup_pseudo_wire_id_type",
                                                    "bound",
                                                    "group_id",
                                                    "group_state",
                                                    "grouping_supported",
                                                    "pw_flow_label_tx",
                                                    "redundancy_role") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.backup_next_hop.is_set or
                                        self.backup_pseudo_wire_id.is_set or
                                        self.backup_pseudo_wire_id_type.is_set or
                                        self.bound.is_set or
                                        self.group_id.is_set or
                                        self.group_state.is_set or
                                        self.grouping_supported.is_set or
                                        self.pw_flow_label_tx.is_set or
                                        self.redundancy_role.is_set or
                                        (self.atom is not None and self.atom.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.backup_next_hop.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set or
                                        self.bound.yfilter != YFilter.not_set or
                                        self.group_id.yfilter != YFilter.not_set or
                                        self.group_state.yfilter != YFilter.not_set or
                                        self.grouping_supported.yfilter != YFilter.not_set or
                                        self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                        self.redundancy_role.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-pseudo-wire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.backup_next_hop.is_set or self.backup_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_next_hop.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id.is_set or self.backup_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id_type.is_set or self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id_type.get_name_leafdata())
                                    if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bound.get_name_leafdata())
                                    if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_id.get_name_leafdata())
                                    if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_state.get_name_leafdata())
                                    if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                    if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                    if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_role.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "active" or name == "backup-next-hop" or name == "backup-pseudo-wire-id" or name == "backup-pseudo-wire-id-type" or name == "bound" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "pw-flow-label-tx" or name == "redundancy-role"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-next-hop"):
                                        self.backup_next_hop = value
                                        self.backup_next_hop.value_namespace = name_space
                                        self.backup_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id"):
                                        self.backup_pseudo_wire_id = value
                                        self.backup_pseudo_wire_id.value_namespace = name_space
                                        self.backup_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id-type"):
                                        self.backup_pseudo_wire_id_type = value
                                        self.backup_pseudo_wire_id_type.value_namespace = name_space
                                        self.backup_pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bound"):
                                        self.bound = value
                                        self.bound.value_namespace = name_space
                                        self.bound.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-id"):
                                        self.group_id = value
                                        self.group_id.value_namespace = name_space
                                        self.group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-state"):
                                        self.group_state = value
                                        self.group_state.value_namespace = name_space
                                        self.group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "grouping-supported"):
                                        self.grouping_supported = value
                                        self.grouping_supported.value_namespace = name_space
                                        self.grouping_supported.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-tx"):
                                        self.pw_flow_label_tx = value
                                        self.pw_flow_label_tx.value_namespace = name_space
                                        self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-role"):
                                        self.redundancy_role = value
                                        self.redundancy_role.value_namespace = name_space
                                        self.redundancy_role.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ac_id.is_set or
                                    self.active.is_set or
                                    self.backup_configured.is_set or
                                    self.bound.is_set or
                                    self.context.is_set or
                                    self.forward_class.is_set or
                                    self.global_id.is_set or
                                    self.group_id.is_set or
                                    self.group_state.is_set or
                                    self.grouping_supported.is_set or
                                    self.next_hop_valid.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_flow_label_tx.is_set or
                                    self.pw_id.is_set or
                                    self.pw_load_balance_type.is_set or
                                    self.redundancy_role.is_set or
                                    self.sequence_resync_threshold.is_set or
                                    self.signal_capability_flags.is_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_data()) or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ac_id.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.backup_configured.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.context.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.global_id.yfilter != YFilter.not_set or
                                    self.group_id.yfilter != YFilter.not_set or
                                    self.group_state.yfilter != YFilter.not_set or
                                    self.grouping_supported.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.pw_load_balance_type.yfilter != YFilter.not_set or
                                    self.redundancy_role.yfilter != YFilter.not_set or
                                    self.sequence_resync_threshold.yfilter != YFilter.not_set or
                                    self.signal_capability_flags.yfilter != YFilter.not_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_operation()) or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ac_id.is_set or self.ac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac_id.get_name_leafdata())
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.backup_configured.is_set or self.backup_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_configured.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.context.is_set or self.context.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.context.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.global_id.is_set or self.global_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_id.get_name_leafdata())
                                if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_id.get_name_leafdata())
                                if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_state.get_name_leafdata())
                                if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.pw_load_balance_type.is_set or self.pw_load_balance_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_load_balance_type.get_name_leafdata())
                                if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_role.get_name_leafdata())
                                if (self.sequence_resync_threshold.is_set or self.sequence_resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_resync_threshold.get_name_leafdata())
                                if (self.signal_capability_flags.is_set or self.signal_capability_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signal_capability_flags.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-pseudo-wire"):
                                    if (self.backup_pseudo_wire is None):
                                        self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire()
                                        self.backup_pseudo_wire.parent = self
                                        self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                    return self.backup_pseudo_wire

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                if (child_yang_name == "pseudo-wire-union"):
                                    if (self.pseudo_wire_union is None):
                                        self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion()
                                        self.pseudo_wire_union.parent = self
                                        self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                    return self.pseudo_wire_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-pseudo-wire" or name == "base" or name == "next-hop" or name == "pseudo-wire-union" or name == "ac-id" or name == "active" or name == "backup-configured" or name == "bound" or name == "context" or name == "forward-class" or name == "global-id" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "next-hop-valid" or name == "pseudo-wire-id-type" or name == "pw-flow-label-tx" or name == "pw-id" or name == "pw-load-balance-type" or name == "redundancy-role" or name == "sequence-resync-threshold" or name == "signal-capability-flags"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ac-id"):
                                    self.ac_id = value
                                    self.ac_id.value_namespace = name_space
                                    self.ac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-configured"):
                                    self.backup_configured = value
                                    self.backup_configured.value_namespace = name_space
                                    self.backup_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "context"):
                                    self.context = value
                                    self.context.value_namespace = name_space
                                    self.context.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "global-id"):
                                    self.global_id = value
                                    self.global_id.value_namespace = name_space
                                    self.global_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-id"):
                                    self.group_id = value
                                    self.group_id.value_namespace = name_space
                                    self.group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-state"):
                                    self.group_state = value
                                    self.group_state.value_namespace = name_space
                                    self.group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "grouping-supported"):
                                    self.grouping_supported = value
                                    self.grouping_supported.value_namespace = name_space
                                    self.grouping_supported.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-tx"):
                                    self.pw_flow_label_tx = value
                                    self.pw_flow_label_tx.value_namespace = name_space
                                    self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-load-balance-type"):
                                    self.pw_load_balance_type = value
                                    self.pw_load_balance_type.value_namespace = name_space
                                    self.pw_load_balance_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-role"):
                                    self.redundancy_role = value
                                    self.redundancy_role.value_namespace = name_space
                                    self.redundancy_role.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-resync-threshold"):
                                    self.sequence_resync_threshold = value
                                    self.sequence_resync_threshold.value_namespace = name_space
                                    self.sequence_resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "signal-capability-flags"):
                                    self.signal_capability_flags = value
                                    self.signal_capability_flags.value_namespace = name_space
                                    self.signal_capability_flags.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.bp is not None and self.bp.has_data()) or
                                (self.fxs is not None and self.fxs.has_data()) or
                                (self.pw is not None and self.pw.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.bp is not None and self.bp.has_operation()) or
                                (self.fxs is not None and self.fxs.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "bp"):
                                if (self.bp is None):
                                    self.bp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp()
                                    self.bp.parent = self
                                    self._children_name_map["bp"] = "bp"
                                return self.bp

                            if (child_yang_name == "fxs"):
                                if (self.fxs is None):
                                    self.fxs = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs()
                                    self.fxs.parent = self
                                    self._children_name_map["fxs"] = "fxs"
                                return self.fxs

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "bp" or name == "fxs" or name == "pw" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.bound.is_set or
                            self.switching_type.is_set or
                            self.xcon_name.is_set or
                            (self.base is not None and self.base.has_data()) or
                            (self.segment1 is not None and self.segment1.has_data()) or
                            (self.segment2 is not None and self.segment2.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.bound.yfilter != YFilter.not_set or
                            self.switching_type.yfilter != YFilter.not_set or
                            self.xcon_name.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()) or
                            (self.segment1 is not None and self.segment1.has_operation()) or
                            (self.segment2 is not None and self.segment2.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fibx-con-l2tpv2" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bound.get_name_leafdata())
                        if (self.switching_type.is_set or self.switching_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.switching_type.get_name_leafdata())
                        if (self.xcon_name.is_set or self.xcon_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xcon_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        if (child_yang_name == "segment1"):
                            if (self.segment1 is None):
                                self.segment1 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1()
                                self.segment1.parent = self
                                self._children_name_map["segment1"] = "segment1"
                            return self.segment1

                        if (child_yang_name == "segment2"):
                            if (self.segment2 is None):
                                self.segment2 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2()
                                self.segment2.parent = self
                                self._children_name_map["segment2"] = "segment2"
                            return self.segment2

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "segment1" or name == "segment2" or name == "interface-name" or name == "bound" or name == "switching-type" or name == "xcon-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bound"):
                            self.bound = value
                            self.bound.value_namespace = name_space
                            self.bound.value_namespace_prefix = name_space_prefix
                        if(value_path == "switching-type"):
                            self.switching_type = value
                            self.switching_type.value_namespace = name_space
                            self.switching_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "xcon-name"):
                            self.xcon_name = value
                            self.xcon_name.value_namespace = name_space
                            self.xcon_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fibx_con_l2tpv2:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fibx_con_l2tpv2:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fibx-con-l2tpv2s" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fibx-con-l2tpv2"):
                        for c in self.l2fibx_con_l2tpv2:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fibx_con_l2tpv2.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fibx-con-l2tpv2"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMrouteIpv6S(Entity):
                """
                multicast information
                
                .. attribute:: l2fib_mroute_ipv6
                
                	Bridge Domain Multicast Information
                	**type**\: list of    :py:class:`L2FibMrouteIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S, self).__init__()

                    self.yang_name = "l2fib-mroute-ipv6s"
                    self.yang_parent_name = "node"

                    self.l2fib_mroute_ipv6 = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S, self).__setattr__(name, value)


                class L2FibMrouteIpv6(Entity):
                    """
                    Bridge Domain Multicast Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\:  str
                    
                    	**length:** 0..66
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:   :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:   :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats>`
                    
                    .. attribute:: group
                    
                    	Group IPv6 Address
                    	**type**\:  str
                    
                    	**length:** 1..128
                    
                    .. attribute:: hardware_information
                    
                    	Platform Hardware info
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: irb_info
                    
                    	IRB Information
                    	**type**\:   :py:class:`IrbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.IrbInfo>`
                    
                    .. attribute:: multicast_base_information
                    
                    	Base Information
                    	**type**\:   :py:class:`MulticastBaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.MulticastBaseInformation>`
                    
                    .. attribute:: platform_data
                    
                    	The mcast platform data
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: platform_data_length
                    
                    	The mcast platform data len
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: source
                    
                    	Source IPv6 Address
                    	**type**\:  str
                    
                    	**length:** 1..128
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:   :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.SourcePrefix>`
                    
                    .. attribute:: xid_count
                    
                    	Count of XIDs
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6, self).__init__()

                        self.yang_name = "l2fib-mroute-ipv6"
                        self.yang_parent_name = "l2fib-mroute-ipv6s"

                        self.bd_group_name = YLeaf(YType.str, "bd-group-name")

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                        self.group = YLeaf(YType.str, "group")

                        self.hardware_information = YLeaf(YType.str, "hardware-information")

                        self.platform_data = YLeaf(YType.str, "platform-data")

                        self.platform_data_length = YLeaf(YType.uint8, "platform-data-length")

                        self.source = YLeaf(YType.str, "source")

                        self.xid_count = YLeaf(YType.uint16, "xid-count")

                        self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self._children_name_map["destination_prefix"] = "destination-prefix"
                        self._children_yang_names.add("destination-prefix")

                        self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats()
                        self.forward_stats.parent = self
                        self._children_name_map["forward_stats"] = "forward-stats"
                        self._children_yang_names.add("forward-stats")

                        self.irb_info = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.IrbInfo()
                        self.irb_info.parent = self
                        self._children_name_map["irb_info"] = "irb-info"
                        self._children_yang_names.add("irb-info")

                        self.multicast_base_information = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.MulticastBaseInformation()
                        self.multicast_base_information.parent = self
                        self._children_name_map["multicast_base_information"] = "multicast-base-information"
                        self._children_yang_names.add("multicast-base-information")

                        self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.SourcePrefix()
                        self.source_prefix.parent = self
                        self._children_name_map["source_prefix"] = "source-prefix"
                        self._children_yang_names.add("source-prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bd_group_name",
                                        "bd_name",
                                        "bridge_domain_name",
                                        "bridge_id",
                                        "group",
                                        "hardware_information",
                                        "platform_data",
                                        "platform_data_length",
                                        "source",
                                        "xid_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6, self).__setattr__(name, value)


                    class MulticastBaseInformation(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.MulticastBaseInformation, self).__init__()

                            self.yang_name = "multicast-base-information"
                            self.yang_parent_name = "l2fib-mroute-ipv6"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "multicast-base-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SourcePrefix(Entity):
                        """
                        Source Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.SourcePrefix, self).__init__()

                            self.yang_name = "source-prefix"
                            self.yang_parent_name = "l2fib-mroute-ipv6"

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                            self.proto = YLeaf(YType.uint8, "proto")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix",
                                            "prefix_length",
                                            "proto") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.SourcePrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.SourcePrefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.proto.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proto.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proto.is_set or self.proto.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proto.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "prefix-length" or name == "proto"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proto"):
                                self.proto = value
                                self.proto.value_namespace = name_space
                                self.proto.value_namespace_prefix = name_space_prefix


                    class DestinationPrefix(Entity):
                        """
                        Destination Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.DestinationPrefix, self).__init__()

                            self.yang_name = "destination-prefix"
                            self.yang_parent_name = "l2fib-mroute-ipv6"

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                            self.proto = YLeaf(YType.uint8, "proto")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix",
                                            "prefix_length",
                                            "proto") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.DestinationPrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.DestinationPrefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.proto.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proto.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "destination-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proto.is_set or self.proto.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proto.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "prefix-length" or name == "proto"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proto"):
                                self.proto = value
                                self.proto.value_namespace = name_space
                                self.proto.value_namespace_prefix = name_space_prefix


                    class ForwardStats(Entity):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:   :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats, self).__init__()

                            self.yang_name = "forward-stats"
                            self.yang_parent_name = "l2fib-mroute-ipv6"

                            self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self
                            self._children_name_map["forward_stat"] = "forward-stat"
                            self._children_yang_names.add("forward-stat")


                        class ForwardStat(Entity):
                            """
                            fwd stats
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:   :py:class:`MgmtL2FibStatsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibStatsData>`
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:   :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat, self).__init__()

                                self.yang_name = "forward-stat"
                                self.yang_parent_name = "forward-stats"

                                self.data_type = YLeaf(YType.enumeration, "data-type")

                                self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self
                                self._children_name_map["mulicast"] = "mulicast"
                                self._children_yang_names.add("mulicast")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("data_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat, self).__setattr__(name, value)


                            class Mulicast(Entity):
                                """
                                mulicast
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:   :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:   :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:   :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:   :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:   :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:   :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast, self).__init__()

                                    self.yang_name = "mulicast"
                                    self.yang_parent_name = "forward-stat"

                                    self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self._children_name_map["core_received_stat"] = "core-received-stat"
                                    self._children_yang_names.add("core-received-stat")

                                    self.drop = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self._children_name_map["drop"] = "drop"
                                    self._children_yang_names.add("drop")

                                    self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"
                                    self._children_yang_names.add("multicast-core-forward-stat")

                                    self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"
                                    self._children_yang_names.add("multicast-forward-stat")

                                    self.punt = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self._children_name_map["punt"] = "punt"
                                    self._children_yang_names.add("punt")

                                    self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self
                                    self._children_name_map["received_stat"] = "received-stat"
                                    self._children_yang_names.add("received-stat")


                                class MulticastForwardStat(Entity):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__init__()

                                        self.yang_name = "multicast-forward-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-forward-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class ReceivedStat(Entity):
                                    """
                                    received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__init__()

                                        self.yang_name = "received-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class Punt(Entity):
                                    """
                                    punted stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt, self).__init__()

                                        self.yang_name = "punt"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "punt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class Drop(Entity):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop, self).__init__()

                                        self.yang_name = "drop"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class MulticastCoreForwardStat(Entity):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__init__()

                                        self.yang_name = "multicast-core-forward-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-core-forward-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class CoreReceivedStat(Entity):
                                    """
                                    core received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__init__()

                                        self.yang_name = "core-received-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "core-received-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.core_received_stat is not None and self.core_received_stat.has_data()) or
                                        (self.drop is not None and self.drop.has_data()) or
                                        (self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat.has_data()) or
                                        (self.multicast_forward_stat is not None and self.multicast_forward_stat.has_data()) or
                                        (self.punt is not None and self.punt.has_data()) or
                                        (self.received_stat is not None and self.received_stat.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.core_received_stat is not None and self.core_received_stat.has_operation()) or
                                        (self.drop is not None and self.drop.has_operation()) or
                                        (self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat.has_operation()) or
                                        (self.multicast_forward_stat is not None and self.multicast_forward_stat.has_operation()) or
                                        (self.punt is not None and self.punt.has_operation()) or
                                        (self.received_stat is not None and self.received_stat.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mulicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "core-received-stat"):
                                        if (self.core_received_stat is None):
                                            self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                            self.core_received_stat.parent = self
                                            self._children_name_map["core_received_stat"] = "core-received-stat"
                                        return self.core_received_stat

                                    if (child_yang_name == "drop"):
                                        if (self.drop is None):
                                            self.drop = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop()
                                            self.drop.parent = self
                                            self._children_name_map["drop"] = "drop"
                                        return self.drop

                                    if (child_yang_name == "multicast-core-forward-stat"):
                                        if (self.multicast_core_forward_stat is None):
                                            self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                            self.multicast_core_forward_stat.parent = self
                                            self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"
                                        return self.multicast_core_forward_stat

                                    if (child_yang_name == "multicast-forward-stat"):
                                        if (self.multicast_forward_stat is None):
                                            self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                            self.multicast_forward_stat.parent = self
                                            self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"
                                        return self.multicast_forward_stat

                                    if (child_yang_name == "punt"):
                                        if (self.punt is None):
                                            self.punt = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt()
                                            self.punt.parent = self
                                            self._children_name_map["punt"] = "punt"
                                        return self.punt

                                    if (child_yang_name == "received-stat"):
                                        if (self.received_stat is None):
                                            self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                            self.received_stat.parent = self
                                            self._children_name_map["received_stat"] = "received-stat"
                                        return self.received_stat

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "core-received-stat" or name == "drop" or name == "multicast-core-forward-stat" or name == "multicast-forward-stat" or name == "punt" or name == "received-stat"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.data_type.is_set or
                                    (self.mulicast is not None and self.mulicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.data_type.yfilter != YFilter.not_set or
                                    (self.mulicast is not None and self.mulicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "forward-stat" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.data_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mulicast"):
                                    if (self.mulicast is None):
                                        self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast()
                                        self.mulicast.parent = self
                                        self._children_name_map["mulicast"] = "mulicast"
                                    return self.mulicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mulicast" or name == "data-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "data-type"):
                                    self.data_type = value
                                    self.data_type.value_namespace = name_space
                                    self.data_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.forward_stat is not None and self.forward_stat.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.forward_stat is not None and self.forward_stat.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "forward-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "forward-stat"):
                                if (self.forward_stat is None):
                                    self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat()
                                    self.forward_stat.parent = self
                                    self._children_name_map["forward_stat"] = "forward-stat"
                                return self.forward_stat

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "forward-stat"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class IrbInfo(Entity):
                        """
                        IRB Information
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        .. attribute:: mxid_ac_interface_handle
                        
                        	Master XID AC If handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mxid_next_hop_address
                        
                        	Master XID NHOP IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mxid_pw_id
                        
                        	Master XID PW ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.IrbInfo, self).__init__()

                            self.yang_name = "irb-info"
                            self.yang_parent_name = "l2fib-mroute-ipv6"

                            self.irb_plat_data = YLeafList(YType.uint32, "irb-plat-data")

                            self.irb_plat_data_len = YLeaf(YType.uint16, "irb-plat-data-len")

                            self.mxid_ac_interface_handle = YLeaf(YType.str, "mxid-ac-interface-handle")

                            self.mxid_next_hop_address = YLeaf(YType.str, "mxid-next-hop-address")

                            self.mxid_pw_id = YLeaf(YType.uint32, "mxid-pw-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("irb_plat_data",
                                            "irb_plat_data_len",
                                            "mxid_ac_interface_handle",
                                            "mxid_next_hop_address",
                                            "mxid_pw_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.IrbInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.IrbInfo, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.irb_plat_data.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.irb_plat_data_len.is_set or
                                self.mxid_ac_interface_handle.is_set or
                                self.mxid_next_hop_address.is_set or
                                self.mxid_pw_id.is_set)

                        def has_operation(self):
                            for leaf in self.irb_plat_data.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.irb_plat_data.yfilter != YFilter.not_set or
                                self.irb_plat_data_len.yfilter != YFilter.not_set or
                                self.mxid_ac_interface_handle.yfilter != YFilter.not_set or
                                self.mxid_next_hop_address.yfilter != YFilter.not_set or
                                self.mxid_pw_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "irb-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.irb_plat_data_len.is_set or self.irb_plat_data_len.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.irb_plat_data_len.get_name_leafdata())
                            if (self.mxid_ac_interface_handle.is_set or self.mxid_ac_interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mxid_ac_interface_handle.get_name_leafdata())
                            if (self.mxid_next_hop_address.is_set or self.mxid_next_hop_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mxid_next_hop_address.get_name_leafdata())
                            if (self.mxid_pw_id.is_set or self.mxid_pw_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mxid_pw_id.get_name_leafdata())

                            leaf_name_data.extend(self.irb_plat_data.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "irb-plat-data" or name == "irb-plat-data-len" or name == "mxid-ac-interface-handle" or name == "mxid-next-hop-address" or name == "mxid-pw-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "irb-plat-data"):
                                self.irb_plat_data.append(value)
                            if(value_path == "irb-plat-data-len"):
                                self.irb_plat_data_len = value
                                self.irb_plat_data_len.value_namespace = name_space
                                self.irb_plat_data_len.value_namespace_prefix = name_space_prefix
                            if(value_path == "mxid-ac-interface-handle"):
                                self.mxid_ac_interface_handle = value
                                self.mxid_ac_interface_handle.value_namespace = name_space
                                self.mxid_ac_interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "mxid-next-hop-address"):
                                self.mxid_next_hop_address = value
                                self.mxid_next_hop_address.value_namespace = name_space
                                self.mxid_next_hop_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mxid-pw-id"):
                                self.mxid_pw_id = value
                                self.mxid_pw_id.value_namespace = name_space
                                self.mxid_pw_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bd_group_name.is_set or
                            self.bd_name.is_set or
                            self.bridge_domain_name.is_set or
                            self.bridge_id.is_set or
                            self.group.is_set or
                            self.hardware_information.is_set or
                            self.platform_data.is_set or
                            self.platform_data_length.is_set or
                            self.source.is_set or
                            self.xid_count.is_set or
                            (self.destination_prefix is not None and self.destination_prefix.has_data()) or
                            (self.forward_stats is not None and self.forward_stats.has_data()) or
                            (self.irb_info is not None and self.irb_info.has_data()) or
                            (self.multicast_base_information is not None and self.multicast_base_information.has_data()) or
                            (self.source_prefix is not None and self.source_prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bd_group_name.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            self.bridge_domain_name.yfilter != YFilter.not_set or
                            self.bridge_id.yfilter != YFilter.not_set or
                            self.group.yfilter != YFilter.not_set or
                            self.hardware_information.yfilter != YFilter.not_set or
                            self.platform_data.yfilter != YFilter.not_set or
                            self.platform_data_length.yfilter != YFilter.not_set or
                            self.source.yfilter != YFilter.not_set or
                            self.xid_count.yfilter != YFilter.not_set or
                            (self.destination_prefix is not None and self.destination_prefix.has_operation()) or
                            (self.forward_stats is not None and self.forward_stats.has_operation()) or
                            (self.irb_info is not None and self.irb_info.has_operation()) or
                            (self.multicast_base_information is not None and self.multicast_base_information.has_operation()) or
                            (self.source_prefix is not None and self.source_prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mroute-ipv6" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bd_group_name.is_set or self.bd_group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_group_name.get_name_leafdata())
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())
                        if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                        if (self.group.is_set or self.group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group.get_name_leafdata())
                        if (self.hardware_information.is_set or self.hardware_information.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hardware_information.get_name_leafdata())
                        if (self.platform_data.is_set or self.platform_data.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.platform_data.get_name_leafdata())
                        if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.platform_data_length.get_name_leafdata())
                        if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source.get_name_leafdata())
                        if (self.xid_count.is_set or self.xid_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xid_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "destination-prefix"):
                            if (self.destination_prefix is None):
                                self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.DestinationPrefix()
                                self.destination_prefix.parent = self
                                self._children_name_map["destination_prefix"] = "destination-prefix"
                            return self.destination_prefix

                        if (child_yang_name == "forward-stats"):
                            if (self.forward_stats is None):
                                self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats()
                                self.forward_stats.parent = self
                                self._children_name_map["forward_stats"] = "forward-stats"
                            return self.forward_stats

                        if (child_yang_name == "irb-info"):
                            if (self.irb_info is None):
                                self.irb_info = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.IrbInfo()
                                self.irb_info.parent = self
                                self._children_name_map["irb_info"] = "irb-info"
                            return self.irb_info

                        if (child_yang_name == "multicast-base-information"):
                            if (self.multicast_base_information is None):
                                self.multicast_base_information = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.MulticastBaseInformation()
                                self.multicast_base_information.parent = self
                                self._children_name_map["multicast_base_information"] = "multicast-base-information"
                            return self.multicast_base_information

                        if (child_yang_name == "source-prefix"):
                            if (self.source_prefix is None):
                                self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.SourcePrefix()
                                self.source_prefix.parent = self
                                self._children_name_map["source_prefix"] = "source-prefix"
                            return self.source_prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "destination-prefix" or name == "forward-stats" or name == "irb-info" or name == "multicast-base-information" or name == "source-prefix" or name == "bd-group-name" or name == "bd-name" or name == "bridge-domain-name" or name == "bridge-id" or name == "group" or name == "hardware-information" or name == "platform-data" or name == "platform-data-length" or name == "source" or name == "xid-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bd-group-name"):
                            self.bd_group_name = value
                            self.bd_group_name.value_namespace = name_space
                            self.bd_group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-name"):
                            self.bridge_domain_name = value
                            self.bridge_domain_name.value_namespace = name_space
                            self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-id"):
                            self.bridge_id = value
                            self.bridge_id.value_namespace = name_space
                            self.bridge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "group"):
                            self.group = value
                            self.group.value_namespace = name_space
                            self.group.value_namespace_prefix = name_space_prefix
                        if(value_path == "hardware-information"):
                            self.hardware_information = value
                            self.hardware_information.value_namespace = name_space
                            self.hardware_information.value_namespace_prefix = name_space_prefix
                        if(value_path == "platform-data"):
                            self.platform_data = value
                            self.platform_data.value_namespace = name_space
                            self.platform_data.value_namespace_prefix = name_space_prefix
                        if(value_path == "platform-data-length"):
                            self.platform_data_length = value
                            self.platform_data_length.value_namespace = name_space
                            self.platform_data_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "source"):
                            self.source = value
                            self.source.value_namespace = name_space
                            self.source.value_namespace_prefix = name_space_prefix
                        if(value_path == "xid-count"):
                            self.xid_count = value
                            self.xid_count.value_namespace = name_space
                            self.xid_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_mroute_ipv6:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_mroute_ipv6:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-mroute-ipv6s" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-mroute-ipv6"):
                        for c in self.l2fib_mroute_ipv6:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_mroute_ipv6.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-mroute-ipv6"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMonSessXCons(Entity):
                """
                The L2VPN forwarding Monitor Session XConnect
                Information
                
                .. attribute:: l2fib_mon_sess_x_con
                
                	Specify Monitor Session Name
                	**type**\: list of    :py:class:`L2FibMonSessXCon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons, self).__init__()

                    self.yang_name = "l2fib-mon-sess-x-cons"
                    self.yang_parent_name = "node"

                    self.l2fib_mon_sess_x_con = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons, self).__setattr__(name, value)


                class L2FibMonSessXCon(Entity):
                    """
                    Specify Monitor Session Name
                    
                    .. attribute:: monitor_session_name  <key>
                    
                    	Monitor Session Name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Base>`
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\:  bool
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2>`
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:   :py:class:`MgmtL2FibSwitching <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibSwitching>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\:  str
                    
                    	**length:** 0..72
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon, self).__init__()

                        self.yang_name = "l2fib-mon-sess-x-con"
                        self.yang_parent_name = "l2fib-mon-sess-x-cons"

                        self.monitor_session_name = YLeaf(YType.str, "monitor-session-name")

                        self.bound = YLeaf(YType.boolean, "bound")

                        self.switching_type = YLeaf(YType.enumeration, "switching-type")

                        self.xcon_name = YLeaf(YType.str, "xcon-name")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                        self.segment1 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"
                        self._children_yang_names.add("segment1")

                        self.segment2 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"
                        self._children_yang_names.add("segment2")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("monitor_session_name",
                                        "bound",
                                        "switching_type",
                                        "xcon_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fib-mon-sess-x-con"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Segment1(Entity):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:   :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1, self).__init__()

                            self.yang_name = "segment1"
                            self.yang_parent_name = "l2fib-mon-sess-x-con"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"
                            self._children_yang_names.add("evpn")

                            self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self._children_name_map["monitor_session"] = "monitor-session"
                            self._children_yang_names.add("monitor-session")

                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"
                            self._children_yang_names.add("pbb")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                            self.vni = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"
                            self._children_yang_names.add("vni")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment1"

                                self.actype = YLeaf(YType.uint8, "actype")

                                self.adjacency_address = YLeaf(YType.str, "adjacency-address")

                                self.adjacency_valid = YLeaf(YType.boolean, "adjacency-valid")

                                self.attachment_circuit_id = YLeaf(YType.uint32, "attachment-circuit-id")

                                self.attachment_circuit_mtu = YLeaf(YType.uint16, "attachment-circuit-mtu")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.fxc_next_hop_valid = YLeaf(YType.boolean, "fxc-next-hop-valid")

                                self.inter_working_mode = YLeaf(YType.uint8, "inter-working-mode")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.ip_inter_working_mac = YLeaf(YType.str, "ip-inter-working-mac")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.sub_interface_handle = YLeaf(YType.str, "sub-interface-handle")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._children_yang_names.add("fxc-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actype",
                                                "adjacency_address",
                                                "adjacency_valid",
                                                "attachment_circuit_id",
                                                "attachment_circuit_mtu",
                                                "bound",
                                                "evpn_internal_label",
                                                "fxc_next_hop_valid",
                                                "inter_working_mode",
                                                "interface_handle",
                                                "ip_inter_working_mac",
                                                "redundancy_group_id",
                                                "redundancy_object_id",
                                                "sub_interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fxc-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.actype.is_set or
                                    self.adjacency_address.is_set or
                                    self.adjacency_valid.is_set or
                                    self.attachment_circuit_id.is_set or
                                    self.attachment_circuit_mtu.is_set or
                                    self.bound.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.fxc_next_hop_valid.is_set or
                                    self.inter_working_mode.is_set or
                                    self.interface_handle.is_set or
                                    self.ip_inter_working_mac.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.sub_interface_handle.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actype.yfilter != YFilter.not_set or
                                    self.adjacency_address.yfilter != YFilter.not_set or
                                    self.adjacency_valid.yfilter != YFilter.not_set or
                                    self.attachment_circuit_id.yfilter != YFilter.not_set or
                                    self.attachment_circuit_mtu.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.fxc_next_hop_valid.yfilter != YFilter.not_set or
                                    self.inter_working_mode.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.ip_inter_working_mac.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.sub_interface_handle.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actype.is_set or self.actype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actype.get_name_leafdata())
                                if (self.adjacency_address.is_set or self.adjacency_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_address.get_name_leafdata())
                                if (self.adjacency_valid.is_set or self.adjacency_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_valid.get_name_leafdata())
                                if (self.attachment_circuit_id.is_set or self.attachment_circuit_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_id.get_name_leafdata())
                                if (self.attachment_circuit_mtu.is_set or self.attachment_circuit_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_mtu.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.fxc_next_hop_valid.is_set or self.fxc_next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxc_next_hop_valid.get_name_leafdata())
                                if (self.inter_working_mode.is_set or self.inter_working_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_working_mode.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.ip_inter_working_mac.is_set or self.ip_inter_working_mac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_inter_working_mac.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.sub_interface_handle.is_set or self.sub_interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "fxc-next-hop"):
                                    if (self.fxc_next_hop is None):
                                        self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop()
                                        self.fxc_next_hop.parent = self
                                        self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                    return self.fxc_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxc-next-hop" or name == "actype" or name == "adjacency-address" or name == "adjacency-valid" or name == "attachment-circuit-id" or name == "attachment-circuit-mtu" or name == "bound" or name == "evpn-internal-label" or name == "fxc-next-hop-valid" or name == "inter-working-mode" or name == "interface-handle" or name == "ip-inter-working-mac" or name == "redundancy-group-id" or name == "redundancy-object-id" or name == "sub-interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actype"):
                                    self.actype = value
                                    self.actype.value_namespace = name_space
                                    self.actype.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-address"):
                                    self.adjacency_address = value
                                    self.adjacency_address.value_namespace = name_space
                                    self.adjacency_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-valid"):
                                    self.adjacency_valid = value
                                    self.adjacency_valid.value_namespace = name_space
                                    self.adjacency_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-id"):
                                    self.attachment_circuit_id = value
                                    self.attachment_circuit_id.value_namespace = name_space
                                    self.attachment_circuit_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-mtu"):
                                    self.attachment_circuit_mtu = value
                                    self.attachment_circuit_mtu.value_namespace = name_space
                                    self.attachment_circuit_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "fxc-next-hop-valid"):
                                    self.fxc_next_hop_valid = value
                                    self.fxc_next_hop_valid.value_namespace = name_space
                                    self.fxc_next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-working-mode"):
                                    self.inter_working_mode = value
                                    self.inter_working_mode.value_namespace = name_space
                                    self.inter_working_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip-inter-working-mac"):
                                    self.ip_inter_working_mac = value
                                    self.ip_inter_working_mac.value_namespace = name_space
                                    self.ip_inter_working_mac.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-interface-handle"):
                                    self.sub_interface_handle = value
                                    self.sub_interface_handle.value_namespace = name_space
                                    self.sub_interface_handle.value_namespace_prefix = name_space_prefix


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:   :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.core_pbb_evpn_enabled = YLeaf(YType.boolean, "core-pbb-evpn-enabled")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self
                                self._children_name_map["pbb_union"] = "pbb-union"
                                self._children_yang_names.add("pbb-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "core_pbb_evpn_enabled",
                                                "forward_class") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pbb"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class PbbUnion(Entity):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:   :py:class:`MgmtL2FibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridge>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion, self).__init__()

                                    self.yang_name = "pbb-union"
                                    self.yang_parent_name = "pbb"

                                    self.pbb_type = YLeaf(YType.enumeration, "pbb-type")

                                    self.core = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                    self._children_yang_names.add("core")

                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"
                                    self._children_yang_names.add("edge")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pbb_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion, self).__setattr__(name, value)


                                class Edge(Entity):
                                    """
                                    edge
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Edge, self).__init__()

                                        self.yang_name = "edge"
                                        self.yang_parent_name = "pbb-union"

                                        self.mac = YLeaf(YType.str, "mac")

                                        self.mac_configured = YLeaf(YType.boolean, "mac-configured")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mac",
                                                        "mac_configured") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Edge, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Edge, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mac.is_set or
                                            self.mac_configured.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mac.yfilter != YFilter.not_set or
                                            self.mac_configured.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "edge" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mac.is_set or self.mac.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac.get_name_leafdata())
                                        if (self.mac_configured.is_set or self.mac_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_configured.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mac" or name == "mac-configured"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mac"):
                                            self.mac = value
                                            self.mac.value_namespace = name_space
                                            self.mac.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-configured"):
                                            self.mac_configured = value
                                            self.mac_configured.value_namespace = name_space
                                            self.mac_configured.value_namespace_prefix = name_space_prefix


                                class Core(Entity):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Core, self).__init__()

                                        self.yang_name = "core"
                                        self.yang_parent_name = "pbb-union"

                                        self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vlan_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Core, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Core, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.vlan_id.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vlan_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "core" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vlan-id"):
                                            self.vlan_id = value
                                            self.vlan_id.value_namespace = name_space
                                            self.vlan_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.pbb_type.is_set or
                                        (self.core is not None and self.core.has_data()) or
                                        (self.edge is not None and self.edge.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pbb_type.yfilter != YFilter.not_set or
                                        (self.core is not None and self.core.has_operation()) or
                                        (self.edge is not None and self.edge.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pbb-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pbb_type.is_set or self.pbb_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pbb_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "core"):
                                        if (self.core is None):
                                            self.core = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Core()
                                            self.core.parent = self
                                            self._children_name_map["core"] = "core"
                                        return self.core

                                    if (child_yang_name == "edge"):
                                        if (self.edge is None):
                                            self.edge = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Edge()
                                            self.edge.parent = self
                                            self._children_name_map["edge"] = "edge"
                                        return self.edge

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "core" or name == "edge" or name == "pbb-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pbb-type"):
                                        self.pbb_type = value
                                        self.pbb_type.value_namespace = name_space
                                        self.pbb_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.core_pbb_evpn_enabled.is_set or
                                    self.forward_class.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.pbb_union is not None and self.pbb_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.core_pbb_evpn_enabled.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.pbb_union is not None and self.pbb_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.core_pbb_evpn_enabled.is_set or self.core_pbb_evpn_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_pbb_evpn_enabled.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "pbb-union"):
                                    if (self.pbb_union is None):
                                        self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion()
                                        self.pbb_union.parent = self
                                        self._children_name_map["pbb_union"] = "pbb-union"
                                    return self.pbb_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "pbb-union" or name == "bound" or name == "core-pbb-evpn-enabled" or name == "forward-class"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "core-pbb-evpn-enabled"):
                                    self.core_pbb_evpn_enabled = value
                                    self.core_pbb_evpn_enabled.value_namespace = name_space
                                    self.core_pbb_evpn_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment1"

                                self.any_cast_ip = YLeaf(YType.str, "any-cast-ip")

                                self.anycast_mcast_ip = YLeaf(YType.str, "anycast-mcast-ip")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.encap = YLeaf(YType.uint32, "encap")

                                self.mcastip = YLeaf(YType.str, "mcastip")

                                self.parent_if = YLeaf(YType.str, "parent-if")

                                self.source_vtep_if = YLeaf(YType.str, "source-vtep-if")

                                self.srcip = YLeaf(YType.str, "srcip")

                                self.udp_port = YLeaf(YType.uint32, "udp-port")

                                self.vx_lan_mode = YLeaf(YType.uint32, "vx-lan-mode")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("any_cast_ip",
                                                "anycast_mcast_ip",
                                                "bound",
                                                "encap",
                                                "mcastip",
                                                "parent_if",
                                                "source_vtep_if",
                                                "srcip",
                                                "udp_port",
                                                "vx_lan_mode") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "vni"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.any_cast_ip.is_set or
                                    self.anycast_mcast_ip.is_set or
                                    self.bound.is_set or
                                    self.encap.is_set or
                                    self.mcastip.is_set or
                                    self.parent_if.is_set or
                                    self.source_vtep_if.is_set or
                                    self.srcip.is_set or
                                    self.udp_port.is_set or
                                    self.vx_lan_mode.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.any_cast_ip.yfilter != YFilter.not_set or
                                    self.anycast_mcast_ip.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.encap.yfilter != YFilter.not_set or
                                    self.mcastip.yfilter != YFilter.not_set or
                                    self.parent_if.yfilter != YFilter.not_set or
                                    self.source_vtep_if.yfilter != YFilter.not_set or
                                    self.srcip.yfilter != YFilter.not_set or
                                    self.udp_port.yfilter != YFilter.not_set or
                                    self.vx_lan_mode.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vni" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.any_cast_ip.is_set or self.any_cast_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.any_cast_ip.get_name_leafdata())
                                if (self.anycast_mcast_ip.is_set or self.anycast_mcast_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.anycast_mcast_ip.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.encap.is_set or self.encap.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encap.get_name_leafdata())
                                if (self.mcastip.is_set or self.mcastip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mcastip.get_name_leafdata())
                                if (self.parent_if.is_set or self.parent_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_if.get_name_leafdata())
                                if (self.source_vtep_if.is_set or self.source_vtep_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_vtep_if.get_name_leafdata())
                                if (self.srcip.is_set or self.srcip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.srcip.get_name_leafdata())
                                if (self.udp_port.is_set or self.udp_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.udp_port.get_name_leafdata())
                                if (self.vx_lan_mode.is_set or self.vx_lan_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vx_lan_mode.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "any-cast-ip" or name == "anycast-mcast-ip" or name == "bound" or name == "encap" or name == "mcastip" or name == "parent-if" or name == "source-vtep-if" or name == "srcip" or name == "udp-port" or name == "vx-lan-mode"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "any-cast-ip"):
                                    self.any_cast_ip = value
                                    self.any_cast_ip.value_namespace = name_space
                                    self.any_cast_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "anycast-mcast-ip"):
                                    self.anycast_mcast_ip = value
                                    self.anycast_mcast_ip.value_namespace = name_space
                                    self.anycast_mcast_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "encap"):
                                    self.encap = value
                                    self.encap.value_namespace = name_space
                                    self.encap.value_namespace_prefix = name_space_prefix
                                if(value_path == "mcastip"):
                                    self.mcastip = value
                                    self.mcastip.value_namespace = name_space
                                    self.mcastip.value_namespace_prefix = name_space_prefix
                                if(value_path == "parent-if"):
                                    self.parent_if = value
                                    self.parent_if.value_namespace = name_space
                                    self.parent_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-vtep-if"):
                                    self.source_vtep_if = value
                                    self.source_vtep_if.value_namespace = name_space
                                    self.source_vtep_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "srcip"):
                                    self.srcip = value
                                    self.srcip.value_namespace = name_space
                                    self.srcip.value_namespace_prefix = name_space_prefix
                                if(value_path == "udp-port"):
                                    self.udp_port = value
                                    self.udp_port.value_namespace = name_space
                                    self.udp_port.value_namespace_prefix = name_space_prefix
                                if(value_path == "vx-lan-mode"):
                                    self.vx_lan_mode = value
                                    self.vx_lan_mode.value_namespace = name_space
                                    self.vx_lan_mode.value_namespace_prefix = name_space_prefix


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evi = YLeaf(YType.uint32, "evi")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "evi",
                                                "forward_class") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "evpn"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.evi.is_set or
                                    self.forward_class.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evi.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evi.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "bound" or name == "evi" or name == "forward-class"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evi"):
                                    self.evi = value
                                    self.evi.value_namespace = name_space
                                    self.evi.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix


                        class MonitorSession(Entity):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\:  str
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession, self).__init__()

                                self.yang_name = "monitor-session"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.hardware_information = YLeaf(YType.str, "hardware-information")

                                self.session_name = YLeaf(YType.str, "session-name")

                                self.xcid = YLeaf(YType.uint32, "xcid")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "hardware_information",
                                                "session_name",
                                                "xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "monitor-session"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.hardware_information.is_set or
                                    self.session_name.is_set or
                                    self.xcid.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.hardware_information.yfilter != YFilter.not_set or
                                    self.session_name.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "monitor-session" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.hardware_information.is_set or self.hardware_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.hardware_information.get_name_leafdata())
                                if (self.session_name.is_set or self.session_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.session_name.get_name_leafdata())
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "bound" or name == "hardware-information" or name == "session-name" or name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "hardware-information"):
                                    self.hardware_information = value
                                    self.hardware_information.value_namespace = name_space
                                    self.hardware_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "session-name"):
                                    self.session_name = value
                                    self.session_name.value_namespace = name_space
                                    self.session_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBal>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment1"

                                self.ac_id = YLeaf(YType.uint32, "ac-id")

                                self.active = YLeaf(YType.boolean, "active")

                                self.backup_configured = YLeaf(YType.boolean, "backup-configured")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.context = YLeaf(YType.uint16, "context")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.global_id = YLeaf(YType.uint32, "global-id")

                                self.group_id = YLeaf(YType.uint32, "group-id")

                                self.group_state = YLeaf(YType.enumeration, "group-state")

                                self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                                self.pw_load_balance_type = YLeaf(YType.enumeration, "pw-load-balance-type")

                                self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                self.sequence_resync_threshold = YLeaf(YType.uint16, "sequence-resync-threshold")

                                self.signal_capability_flags = YLeaf(YType.uint32, "signal-capability-flags")

                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._children_yang_names.add("backup-pseudo-wire")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                self._children_yang_names.add("pseudo-wire-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ac_id",
                                                "active",
                                                "backup_configured",
                                                "bound",
                                                "context",
                                                "forward_class",
                                                "global_id",
                                                "group_id",
                                                "group_state",
                                                "grouping_supported",
                                                "next_hop_valid",
                                                "pseudo_wire_id_type",
                                                "pw_flow_label_tx",
                                                "pw_id",
                                                "pw_load_balance_type",
                                                "redundancy_role",
                                                "sequence_resync_threshold",
                                                "signal_capability_flags") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"
                                    self._children_yang_names.add("l2tp")

                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._children_yang_names.add("l2tp-ipv6-ts")

                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"
                                    self._children_yang_names.add("l2tpv2")

                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"
                                    self._children_yang_names.add("mpls")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion, self).__setattr__(name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix


                                class L2Tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_mtu",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_mtu.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "path-mtu" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix


                                class L2Tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.protocol = YLeaf(YType.uint16, "protocol")

                                        self.pw_flags = YLeaf(YType.uint8, "pw-flags")

                                        self.rem_udp_port = YLeaf(YType.uint16, "rem-udp-port")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop_address",
                                                        "path_mtu",
                                                        "protocol",
                                                        "pw_flags",
                                                        "rem_udp_port",
                                                        "source_address",
                                                        "tos_val",
                                                        "ttl",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.next_hop_address.is_set or
                                            self.path_mtu.is_set or
                                            self.protocol.is_set or
                                            self.pw_flags.is_set or
                                            self.rem_udp_port.is_set or
                                            self.source_address.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            self.xconnect_id.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pw_flags.yfilter != YFilter.not_set or
                                            self.rem_udp_port.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv2" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pw_flags.is_set or self.pw_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flags.get_name_leafdata())
                                        if (self.rem_udp_port.is_set or self.rem_udp_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_udp_port.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "next-hop-address" or name == "path-mtu" or name == "protocol" or name == "pw-flags" or name == "rem-udp-port" or name == "source-address" or name == "tos-val" or name == "ttl" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop-address"):
                                            self.next_hop_address = value
                                            self.next_hop_address.value_namespace = name_space
                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flags"):
                                            self.pw_flags = value
                                            self.pw_flags.value_namespace = name_space
                                            self.pw_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-udp-port"):
                                            self.rem_udp_port = value
                                            self.rem_udp_port.value_namespace = name_space
                                            self.rem_udp_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class L2TpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address",
                                                        "path_mtu",
                                                        "remote_address",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.secondary_cookie_high_value = YLeaf(YType.uint32, "secondary-cookie-high-value")

                                            self.secondary_cookie_low_value = YLeaf(YType.uint32, "secondary-cookie-low-value")

                                            self.secondary_cookie_size = YLeaf(YType.uint8, "secondary-cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "secondary_cookie_high_value",
                                                            "secondary_cookie_low_value",
                                                            "secondary_cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.secondary_cookie_high_value.is_set or
                                                self.secondary_cookie_low_value.is_set or
                                                self.secondary_cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.secondary_cookie_high_value.is_set or self.secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_high_value.get_name_leafdata())
                                            if (self.secondary_cookie_low_value.is_set or self.secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_low_value.get_name_leafdata())
                                            if (self.secondary_cookie_size.is_set or self.secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "secondary-cookie-high-value" or name == "secondary-cookie-low-value" or name == "secondary-cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-high-value"):
                                                self.secondary_cookie_high_value = value
                                                self.secondary_cookie_high_value.value_namespace = name_space
                                                self.secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-low-value"):
                                                self.secondary_cookie_low_value = value
                                                self.secondary_cookie_low_value.value_namespace = name_space
                                                self.secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-size"):
                                                self.secondary_cookie_size = value
                                                self.secondary_cookie_size.value_namespace = name_space
                                                self.secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.local_address.is_set or
                                            self.path_mtu.is_set or
                                            self.remote_address.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp-ipv6-ts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "local-address" or name == "path-mtu" or name == "remote-address" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        (self.l2tp is not None and self.l2tp.has_data()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_data()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_data()) or
                                        (self.mpls is not None and self.mpls.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        (self.l2tp is not None and self.l2tp.has_operation()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_operation()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_operation()) or
                                        (self.mpls is not None and self.mpls.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudo-wire-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2tp"):
                                        if (self.l2tp is None):
                                            self.l2tp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp()
                                            self.l2tp.parent = self
                                            self._children_name_map["l2tp"] = "l2tp"
                                        return self.l2tp

                                    if (child_yang_name == "l2tp-ipv6-ts"):
                                        if (self.l2tp_ipv6_ts is None):
                                            self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                            self.l2tp_ipv6_ts.parent = self
                                            self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                        return self.l2tp_ipv6_ts

                                    if (child_yang_name == "l2tpv2"):
                                        if (self.l2tpv2 is None):
                                            self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                            self.l2tpv2.parent = self
                                            self._children_name_map["l2tpv2"] = "l2tpv2"
                                        return self.l2tpv2

                                    if (child_yang_name == "mpls"):
                                        if (self.mpls is None):
                                            self.mpls = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                        return self.mpls

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2tp" or name == "l2tp-ipv6-ts" or name == "l2tpv2" or name == "mpls" or name == "data-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.backup_next_hop = YLeaf(YType.str, "backup-next-hop")

                                    self.backup_pseudo_wire_id = YLeaf(YType.uint32, "backup-pseudo-wire-id")

                                    self.backup_pseudo_wire_id_type = YLeaf(YType.enumeration, "backup-pseudo-wire-id-type")

                                    self.bound = YLeaf(YType.boolean, "bound")

                                    self.group_id = YLeaf(YType.uint32, "group-id")

                                    self.group_state = YLeaf(YType.enumeration, "group-state")

                                    self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                    self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                    self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "backup_next_hop",
                                                    "backup_pseudo_wire_id",
                                                    "backup_pseudo_wire_id_type",
                                                    "bound",
                                                    "group_id",
                                                    "group_state",
                                                    "grouping_supported",
                                                    "pw_flow_label_tx",
                                                    "redundancy_role") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.backup_next_hop.is_set or
                                        self.backup_pseudo_wire_id.is_set or
                                        self.backup_pseudo_wire_id_type.is_set or
                                        self.bound.is_set or
                                        self.group_id.is_set or
                                        self.group_state.is_set or
                                        self.grouping_supported.is_set or
                                        self.pw_flow_label_tx.is_set or
                                        self.redundancy_role.is_set or
                                        (self.atom is not None and self.atom.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.backup_next_hop.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set or
                                        self.bound.yfilter != YFilter.not_set or
                                        self.group_id.yfilter != YFilter.not_set or
                                        self.group_state.yfilter != YFilter.not_set or
                                        self.grouping_supported.yfilter != YFilter.not_set or
                                        self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                        self.redundancy_role.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-pseudo-wire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.backup_next_hop.is_set or self.backup_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_next_hop.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id.is_set or self.backup_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id_type.is_set or self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id_type.get_name_leafdata())
                                    if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bound.get_name_leafdata())
                                    if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_id.get_name_leafdata())
                                    if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_state.get_name_leafdata())
                                    if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                    if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                    if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_role.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "active" or name == "backup-next-hop" or name == "backup-pseudo-wire-id" or name == "backup-pseudo-wire-id-type" or name == "bound" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "pw-flow-label-tx" or name == "redundancy-role"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-next-hop"):
                                        self.backup_next_hop = value
                                        self.backup_next_hop.value_namespace = name_space
                                        self.backup_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id"):
                                        self.backup_pseudo_wire_id = value
                                        self.backup_pseudo_wire_id.value_namespace = name_space
                                        self.backup_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id-type"):
                                        self.backup_pseudo_wire_id_type = value
                                        self.backup_pseudo_wire_id_type.value_namespace = name_space
                                        self.backup_pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bound"):
                                        self.bound = value
                                        self.bound.value_namespace = name_space
                                        self.bound.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-id"):
                                        self.group_id = value
                                        self.group_id.value_namespace = name_space
                                        self.group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-state"):
                                        self.group_state = value
                                        self.group_state.value_namespace = name_space
                                        self.group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "grouping-supported"):
                                        self.grouping_supported = value
                                        self.grouping_supported.value_namespace = name_space
                                        self.grouping_supported.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-tx"):
                                        self.pw_flow_label_tx = value
                                        self.pw_flow_label_tx.value_namespace = name_space
                                        self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-role"):
                                        self.redundancy_role = value
                                        self.redundancy_role.value_namespace = name_space
                                        self.redundancy_role.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ac_id.is_set or
                                    self.active.is_set or
                                    self.backup_configured.is_set or
                                    self.bound.is_set or
                                    self.context.is_set or
                                    self.forward_class.is_set or
                                    self.global_id.is_set or
                                    self.group_id.is_set or
                                    self.group_state.is_set or
                                    self.grouping_supported.is_set or
                                    self.next_hop_valid.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_flow_label_tx.is_set or
                                    self.pw_id.is_set or
                                    self.pw_load_balance_type.is_set or
                                    self.redundancy_role.is_set or
                                    self.sequence_resync_threshold.is_set or
                                    self.signal_capability_flags.is_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_data()) or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ac_id.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.backup_configured.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.context.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.global_id.yfilter != YFilter.not_set or
                                    self.group_id.yfilter != YFilter.not_set or
                                    self.group_state.yfilter != YFilter.not_set or
                                    self.grouping_supported.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.pw_load_balance_type.yfilter != YFilter.not_set or
                                    self.redundancy_role.yfilter != YFilter.not_set or
                                    self.sequence_resync_threshold.yfilter != YFilter.not_set or
                                    self.signal_capability_flags.yfilter != YFilter.not_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_operation()) or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ac_id.is_set or self.ac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac_id.get_name_leafdata())
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.backup_configured.is_set or self.backup_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_configured.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.context.is_set or self.context.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.context.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.global_id.is_set or self.global_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_id.get_name_leafdata())
                                if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_id.get_name_leafdata())
                                if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_state.get_name_leafdata())
                                if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.pw_load_balance_type.is_set or self.pw_load_balance_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_load_balance_type.get_name_leafdata())
                                if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_role.get_name_leafdata())
                                if (self.sequence_resync_threshold.is_set or self.sequence_resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_resync_threshold.get_name_leafdata())
                                if (self.signal_capability_flags.is_set or self.signal_capability_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signal_capability_flags.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-pseudo-wire"):
                                    if (self.backup_pseudo_wire is None):
                                        self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire()
                                        self.backup_pseudo_wire.parent = self
                                        self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                    return self.backup_pseudo_wire

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                if (child_yang_name == "pseudo-wire-union"):
                                    if (self.pseudo_wire_union is None):
                                        self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion()
                                        self.pseudo_wire_union.parent = self
                                        self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                    return self.pseudo_wire_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-pseudo-wire" or name == "base" or name == "next-hop" or name == "pseudo-wire-union" or name == "ac-id" or name == "active" or name == "backup-configured" or name == "bound" or name == "context" or name == "forward-class" or name == "global-id" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "next-hop-valid" or name == "pseudo-wire-id-type" or name == "pw-flow-label-tx" or name == "pw-id" or name == "pw-load-balance-type" or name == "redundancy-role" or name == "sequence-resync-threshold" or name == "signal-capability-flags"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ac-id"):
                                    self.ac_id = value
                                    self.ac_id.value_namespace = name_space
                                    self.ac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-configured"):
                                    self.backup_configured = value
                                    self.backup_configured.value_namespace = name_space
                                    self.backup_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "context"):
                                    self.context = value
                                    self.context.value_namespace = name_space
                                    self.context.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "global-id"):
                                    self.global_id = value
                                    self.global_id.value_namespace = name_space
                                    self.global_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-id"):
                                    self.group_id = value
                                    self.group_id.value_namespace = name_space
                                    self.group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-state"):
                                    self.group_state = value
                                    self.group_state.value_namespace = name_space
                                    self.group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "grouping-supported"):
                                    self.grouping_supported = value
                                    self.grouping_supported.value_namespace = name_space
                                    self.grouping_supported.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-tx"):
                                    self.pw_flow_label_tx = value
                                    self.pw_flow_label_tx.value_namespace = name_space
                                    self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-load-balance-type"):
                                    self.pw_load_balance_type = value
                                    self.pw_load_balance_type.value_namespace = name_space
                                    self.pw_load_balance_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-role"):
                                    self.redundancy_role = value
                                    self.redundancy_role.value_namespace = name_space
                                    self.redundancy_role.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-resync-threshold"):
                                    self.sequence_resync_threshold = value
                                    self.sequence_resync_threshold.value_namespace = name_space
                                    self.sequence_resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "signal-capability-flags"):
                                    self.signal_capability_flags = value
                                    self.signal_capability_flags.value_namespace = name_space
                                    self.signal_capability_flags.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.evpn is not None and self.evpn.has_data()) or
                                (self.monitor_session is not None and self.monitor_session.has_data()) or
                                (self.pbb is not None and self.pbb.has_data()) or
                                (self.pw is not None and self.pw.has_data()) or
                                (self.vni is not None and self.vni.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.evpn is not None and self.evpn.has_operation()) or
                                (self.monitor_session is not None and self.monitor_session.has_operation()) or
                                (self.pbb is not None and self.pbb.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()) or
                                (self.vni is not None and self.vni.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "evpn"):
                                if (self.evpn is None):
                                    self.evpn = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn()
                                    self.evpn.parent = self
                                    self._children_name_map["evpn"] = "evpn"
                                return self.evpn

                            if (child_yang_name == "monitor-session"):
                                if (self.monitor_session is None):
                                    self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession()
                                    self.monitor_session.parent = self
                                    self._children_name_map["monitor_session"] = "monitor-session"
                                return self.monitor_session

                            if (child_yang_name == "pbb"):
                                if (self.pbb is None):
                                    self.pbb = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb()
                                    self.pbb.parent = self
                                    self._children_name_map["pbb"] = "pbb"
                                return self.pbb

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            if (child_yang_name == "vni"):
                                if (self.vni is None):
                                    self.vni = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni()
                                    self.vni.parent = self
                                    self._children_name_map["vni"] = "vni"
                                return self.vni

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "evpn" or name == "monitor-session" or name == "pbb" or name == "pw" or name == "vni" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix


                    class Segment2(Entity):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:   :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:   :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2, self).__init__()

                            self.yang_name = "segment2"
                            self.yang_parent_name = "l2fib-mon-sess-x-con"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.bp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp()
                            self.bp.parent = self
                            self._children_name_map["bp"] = "bp"
                            self._children_yang_names.add("bp")

                            self.fxs = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs()
                            self.fxs.parent = self
                            self._children_name_map["fxs"] = "fxs"
                            self._children_yang_names.add("fxs")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment2"

                                self.actype = YLeaf(YType.uint8, "actype")

                                self.adjacency_address = YLeaf(YType.str, "adjacency-address")

                                self.adjacency_valid = YLeaf(YType.boolean, "adjacency-valid")

                                self.attachment_circuit_id = YLeaf(YType.uint32, "attachment-circuit-id")

                                self.attachment_circuit_mtu = YLeaf(YType.uint16, "attachment-circuit-mtu")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.fxc_next_hop_valid = YLeaf(YType.boolean, "fxc-next-hop-valid")

                                self.inter_working_mode = YLeaf(YType.uint8, "inter-working-mode")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.ip_inter_working_mac = YLeaf(YType.str, "ip-inter-working-mac")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.sub_interface_handle = YLeaf(YType.str, "sub-interface-handle")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._children_yang_names.add("fxc-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actype",
                                                "adjacency_address",
                                                "adjacency_valid",
                                                "attachment_circuit_id",
                                                "attachment_circuit_mtu",
                                                "bound",
                                                "evpn_internal_label",
                                                "fxc_next_hop_valid",
                                                "inter_working_mode",
                                                "interface_handle",
                                                "ip_inter_working_mac",
                                                "redundancy_group_id",
                                                "redundancy_object_id",
                                                "sub_interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fxc-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.actype.is_set or
                                    self.adjacency_address.is_set or
                                    self.adjacency_valid.is_set or
                                    self.attachment_circuit_id.is_set or
                                    self.attachment_circuit_mtu.is_set or
                                    self.bound.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.fxc_next_hop_valid.is_set or
                                    self.inter_working_mode.is_set or
                                    self.interface_handle.is_set or
                                    self.ip_inter_working_mac.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.sub_interface_handle.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actype.yfilter != YFilter.not_set or
                                    self.adjacency_address.yfilter != YFilter.not_set or
                                    self.adjacency_valid.yfilter != YFilter.not_set or
                                    self.attachment_circuit_id.yfilter != YFilter.not_set or
                                    self.attachment_circuit_mtu.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.fxc_next_hop_valid.yfilter != YFilter.not_set or
                                    self.inter_working_mode.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.ip_inter_working_mac.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.sub_interface_handle.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actype.is_set or self.actype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actype.get_name_leafdata())
                                if (self.adjacency_address.is_set or self.adjacency_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_address.get_name_leafdata())
                                if (self.adjacency_valid.is_set or self.adjacency_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_valid.get_name_leafdata())
                                if (self.attachment_circuit_id.is_set or self.attachment_circuit_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_id.get_name_leafdata())
                                if (self.attachment_circuit_mtu.is_set or self.attachment_circuit_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_mtu.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.fxc_next_hop_valid.is_set or self.fxc_next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxc_next_hop_valid.get_name_leafdata())
                                if (self.inter_working_mode.is_set or self.inter_working_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_working_mode.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.ip_inter_working_mac.is_set or self.ip_inter_working_mac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_inter_working_mac.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.sub_interface_handle.is_set or self.sub_interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "fxc-next-hop"):
                                    if (self.fxc_next_hop is None):
                                        self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop()
                                        self.fxc_next_hop.parent = self
                                        self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                    return self.fxc_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxc-next-hop" or name == "actype" or name == "adjacency-address" or name == "adjacency-valid" or name == "attachment-circuit-id" or name == "attachment-circuit-mtu" or name == "bound" or name == "evpn-internal-label" or name == "fxc-next-hop-valid" or name == "inter-working-mode" or name == "interface-handle" or name == "ip-inter-working-mac" or name == "redundancy-group-id" or name == "redundancy-object-id" or name == "sub-interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actype"):
                                    self.actype = value
                                    self.actype.value_namespace = name_space
                                    self.actype.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-address"):
                                    self.adjacency_address = value
                                    self.adjacency_address.value_namespace = name_space
                                    self.adjacency_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-valid"):
                                    self.adjacency_valid = value
                                    self.adjacency_valid.value_namespace = name_space
                                    self.adjacency_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-id"):
                                    self.attachment_circuit_id = value
                                    self.attachment_circuit_id.value_namespace = name_space
                                    self.attachment_circuit_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-mtu"):
                                    self.attachment_circuit_mtu = value
                                    self.attachment_circuit_mtu.value_namespace = name_space
                                    self.attachment_circuit_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "fxc-next-hop-valid"):
                                    self.fxc_next_hop_valid = value
                                    self.fxc_next_hop_valid.value_namespace = name_space
                                    self.fxc_next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-working-mode"):
                                    self.inter_working_mode = value
                                    self.inter_working_mode.value_namespace = name_space
                                    self.inter_working_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip-inter-working-mac"):
                                    self.ip_inter_working_mac = value
                                    self.ip_inter_working_mac.value_namespace = name_space
                                    self.ip_inter_working_mac.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-interface-handle"):
                                    self.sub_interface_handle = value
                                    self.sub_interface_handle.value_namespace = name_space
                                    self.sub_interface_handle.value_namespace_prefix = name_space_prefix


                        class Bp(Entity):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Base>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:   :py:class:`P2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.P2Mp>`
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp, self).__init__()

                                self.yang_name = "bp"
                                self.yang_parent_name = "segment2"

                                self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                                self.learn_key = YLeaf(YType.uint8, "learn-key")

                                self.msti_pointer = YLeaf(YType.uint32, "msti-pointer")

                                self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                                self.segment_type = YLeaf(YType.uint8, "segment-type")

                                self.shg_id = YLeaf(YType.uint32, "shg-id")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.oper = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self._children_name_map["oper"] = "oper"
                                self._children_yang_names.add("oper")

                                self.p2mp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.P2Mp()
                                self.p2mp.parent = self
                                self._children_name_map["p2mp"] = "p2mp"
                                self._children_yang_names.add("p2mp")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bridge_id",
                                                "learn_key",
                                                "msti_pointer",
                                                "mvrp_sequence_number",
                                                "segment_type",
                                                "shg_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "bp"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Oper(Entity):
                                """
                                Operational information
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper, self).__init__()

                                    self.yang_name = "oper"
                                    self.yang_parent_name = "bp"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self._children_name_map["operational_information"] = "operational-information"
                                    self._children_yang_names.add("operational-information")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper, self).__setattr__(name, value)


                                class OperationalInformation(Entity):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\:  bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: host_routing_enabled
                                    
                                    	Host Routing enabled on this BD
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotify>`
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:   :py:class:`MgmtL2FibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecAction>`
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\:  bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation, self).__init__()

                                        self.yang_name = "operational-information"
                                        self.yang_parent_name = "oper"

                                        self.admin_disabled = YLeaf(YType.boolean, "admin-disabled")

                                        self.bvi_configured = YLeaf(YType.boolean, "bvi-configured")

                                        self.dhcp_enabled = YLeaf(YType.boolean, "dhcp-enabled")

                                        self.dhcp_trusted = YLeaf(YType.boolean, "dhcp-trusted")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flooding_disabled = YLeaf(YType.boolean, "flooding-disabled")

                                        self.host_routing_enabled = YLeaf(YType.boolean, "host-routing-enabled")

                                        self.igmp_flood_forward_enabled = YLeaf(YType.boolean, "igmp-flood-forward-enabled")

                                        self.igmp_mroute_port_enabled = YLeaf(YType.boolean, "igmp-mroute-port-enabled")

                                        self.igmp_route_guard_enabled = YLeaf(YType.boolean, "igmp-route-guard-enabled")

                                        self.igmp_snoop_enabled = YLeaf(YType.boolean, "igmp-snoop-enabled")

                                        self.igmp_snoop_profile_enabled = YLeaf(YType.boolean, "igmp-snoop-profile-enabled")

                                        self.is_bvi_up = YLeaf(YType.boolean, "is-bvi-up")

                                        self.is_dai_addr_validation_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-destination-mac-enabled")

                                        self.is_dai_addr_validation_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-ipv4-enabled")

                                        self.is_dai_addr_validation_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_evpn_cw_disable = YLeaf(YType.boolean, "is-evpn-cw-disable")

                                        self.is_evpn_enabled = YLeaf(YType.boolean, "is-evpn-enabled")

                                        self.is_evpn_flow_label = YLeaf(YType.boolean, "is-evpn-flow-label")

                                        self.is_igmp_snoop_enabled = YLeaf(YType.boolean, "is-igmp-snoop-enabled")

                                        self.is_ipsg_enabled = YLeaf(YType.boolean, "is-ipsg-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.is_p2mp_pw_enabled = YLeaf(YType.boolean, "is-p2mp-pw-enabled")

                                        self.is_pbbevpn_enabled = YLeaf(YType.boolean, "is-pbbevpn-enabled")

                                        self.is_swmac_learning = YLeaf(YType.boolean, "is-swmac-learning")

                                        self.is_vni_enabled = YLeaf(YType.boolean, "is-vni-enabled")

                                        self.is_vpls_flood_optimization_enabled = YLeaf(YType.boolean, "is-vpls-flood-optimization-enabled")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_aging_type = YLeaf(YType.boolean, "mac-aging-type")

                                        self.mac_learning_disabled = YLeaf(YType.boolean, "mac-learning-disabled")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification_type = YLeaf(YType.enumeration, "mac-limit-notification-type")

                                        self.mac_port_down_flush_disabled = YLeaf(YType.boolean, "mac-port-down-flush-disabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_flood_forward_enabled = YLeaf(YType.boolean, "mld-flood-forward-enabled")

                                        self.mld_mroute_port_enabled = YLeaf(YType.boolean, "mld-mroute-port-enabled")

                                        self.mld_route_guard_enabled = YLeaf(YType.boolean, "mld-route-guard-enabled")

                                        self.mld_snoop_enabled = YLeaf(YType.boolean, "mld-snoop-enabled")

                                        self.mld_snoop_profile_enabled = YLeaf(YType.boolean, "mld-snoop-profile-enabled")

                                        self.msti = YLeaf(YType.uint32, "msti")

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.number_of_macs = YLeaf(YType.uint32, "number-of-macs")

                                        self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                                        self.storm_control_broadcast_enabled = YLeaf(YType.boolean, "storm-control-broadcast-enabled")

                                        self.storm_control_broadcast_rate_unit = YLeaf(YType.enumeration, "storm-control-broadcast-rate-unit")

                                        self.storm_control_multicast_enabled = YLeaf(YType.boolean, "storm-control-multicast-enabled")

                                        self.storm_control_multicast_rate_unit = YLeaf(YType.enumeration, "storm-control-multicast-rate-unit")

                                        self.storm_control_unicast_enabled = YLeaf(YType.boolean, "storm-control-unicast-enabled")

                                        self.storm_control_unicast_rate_unit = YLeaf(YType.enumeration, "storm-control-unicast-rate-unit")

                                        self.stp_participating = YLeaf(YType.boolean, "stp-participating")

                                        self.unknown_unicast_flooding_disabled = YLeaf(YType.boolean, "unknown-unicast-flooding-disabled")

                                        self.feature = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("admin_disabled",
                                                        "bvi_configured",
                                                        "dhcp_enabled",
                                                        "dhcp_trusted",
                                                        "flood_unknown_unicast_enabled",
                                                        "flooding_disabled",
                                                        "host_routing_enabled",
                                                        "igmp_flood_forward_enabled",
                                                        "igmp_mroute_port_enabled",
                                                        "igmp_route_guard_enabled",
                                                        "igmp_snoop_enabled",
                                                        "igmp_snoop_profile_enabled",
                                                        "is_bvi_up",
                                                        "is_dai_addr_validation_destination_mac_enabled",
                                                        "is_dai_addr_validation_ipv4_enabled",
                                                        "is_dai_addr_validation_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_evpn_cw_disable",
                                                        "is_evpn_enabled",
                                                        "is_evpn_flow_label",
                                                        "is_igmp_snoop_enabled",
                                                        "is_ipsg_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "is_p2mp_pw_enabled",
                                                        "is_pbbevpn_enabled",
                                                        "is_swmac_learning",
                                                        "is_vni_enabled",
                                                        "is_vpls_flood_optimization_enabled",
                                                        "mac_aging_time",
                                                        "mac_aging_type",
                                                        "mac_learning_disabled",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification_type",
                                                        "mac_port_down_flush_disabled",
                                                        "mac_secure_action",
                                                        "mld_flood_forward_enabled",
                                                        "mld_mroute_port_enabled",
                                                        "mld_route_guard_enabled",
                                                        "mld_snoop_enabled",
                                                        "mld_snoop_profile_enabled",
                                                        "msti",
                                                        "mtu",
                                                        "number_of_macs",
                                                        "nv_satellite_offload_ipv4_multicast_disabled",
                                                        "storm_control_broadcast_enabled",
                                                        "storm_control_broadcast_rate_unit",
                                                        "storm_control_multicast_enabled",
                                                        "storm_control_multicast_rate_unit",
                                                        "storm_control_unicast_enabled",
                                                        "storm_control_unicast_rate_unit",
                                                        "stp_participating",
                                                        "unknown_unicast_flooding_disabled") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation, self).__setattr__(name, value)


                                    class Feature(Entity):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:   :py:class:`L2FibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeature>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature, self).__init__()

                                            self.yang_name = "feature"
                                            self.yang_parent_name = "operational-information"

                                            self.feature_type = YLeaf(YType.enumeration, "feature-type")

                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self._children_name_map["dhcp"] = "dhcp"
                                            self._children_yang_names.add("dhcp")

                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self._children_name_map["igmp"] = "igmp"
                                            self._children_yang_names.add("igmp")

                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self
                                            self._children_name_map["mld"] = "mld"
                                            self._children_yang_names.add("mld")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("feature_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature, self).__setattr__(name, value)


                                        class Dhcp(Entity):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                                self.yang_name = "dhcp"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dhcp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix


                                        class Igmp(Entity):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                                self.yang_name = "igmp"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "igmp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix


                                        class Mld(Entity):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                                self.yang_name = "mld"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mld" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.feature_type.is_set or
                                                (self.dhcp is not None and self.dhcp.has_data()) or
                                                (self.igmp is not None and self.igmp.has_data()) or
                                                (self.mld is not None and self.mld.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.feature_type.yfilter != YFilter.not_set or
                                                (self.dhcp is not None and self.dhcp.has_operation()) or
                                                (self.igmp is not None and self.igmp.has_operation()) or
                                                (self.mld is not None and self.mld.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "feature" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.feature_type.is_set or self.feature_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.feature_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dhcp"):
                                                if (self.dhcp is None):
                                                    self.dhcp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                                    self.dhcp.parent = self
                                                    self._children_name_map["dhcp"] = "dhcp"
                                                return self.dhcp

                                            if (child_yang_name == "igmp"):
                                                if (self.igmp is None):
                                                    self.igmp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                                    self.igmp.parent = self
                                                    self._children_name_map["igmp"] = "igmp"
                                                return self.igmp

                                            if (child_yang_name == "mld"):
                                                if (self.mld is None):
                                                    self.mld = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                                    self.mld.parent = self
                                                    self._children_name_map["mld"] = "mld"
                                                return self.mld

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dhcp" or name == "igmp" or name == "mld" or name == "feature-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "feature-type"):
                                                self.feature_type = value
                                                self.feature_type.value_namespace = name_space
                                                self.feature_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.feature:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.admin_disabled.is_set or
                                            self.bvi_configured.is_set or
                                            self.dhcp_enabled.is_set or
                                            self.dhcp_trusted.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flooding_disabled.is_set or
                                            self.host_routing_enabled.is_set or
                                            self.igmp_flood_forward_enabled.is_set or
                                            self.igmp_mroute_port_enabled.is_set or
                                            self.igmp_route_guard_enabled.is_set or
                                            self.igmp_snoop_enabled.is_set or
                                            self.igmp_snoop_profile_enabled.is_set or
                                            self.is_bvi_up.is_set or
                                            self.is_dai_addr_validation_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validation_ipv4_enabled.is_set or
                                            self.is_dai_addr_validation_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_evpn_cw_disable.is_set or
                                            self.is_evpn_enabled.is_set or
                                            self.is_evpn_flow_label.is_set or
                                            self.is_igmp_snoop_enabled.is_set or
                                            self.is_ipsg_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.is_p2mp_pw_enabled.is_set or
                                            self.is_pbbevpn_enabled.is_set or
                                            self.is_swmac_learning.is_set or
                                            self.is_vni_enabled.is_set or
                                            self.is_vpls_flood_optimization_enabled.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_aging_type.is_set or
                                            self.mac_learning_disabled.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification_type.is_set or
                                            self.mac_port_down_flush_disabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_flood_forward_enabled.is_set or
                                            self.mld_mroute_port_enabled.is_set or
                                            self.mld_route_guard_enabled.is_set or
                                            self.mld_snoop_enabled.is_set or
                                            self.mld_snoop_profile_enabled.is_set or
                                            self.msti.is_set or
                                            self.mtu.is_set or
                                            self.number_of_macs.is_set or
                                            self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                                            self.storm_control_broadcast_enabled.is_set or
                                            self.storm_control_broadcast_rate_unit.is_set or
                                            self.storm_control_multicast_enabled.is_set or
                                            self.storm_control_multicast_rate_unit.is_set or
                                            self.storm_control_unicast_enabled.is_set or
                                            self.storm_control_unicast_rate_unit.is_set or
                                            self.stp_participating.is_set or
                                            self.unknown_unicast_flooding_disabled.is_set)

                                    def has_operation(self):
                                        for c in self.feature:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.admin_disabled.yfilter != YFilter.not_set or
                                            self.bvi_configured.yfilter != YFilter.not_set or
                                            self.dhcp_enabled.yfilter != YFilter.not_set or
                                            self.dhcp_trusted.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flooding_disabled.yfilter != YFilter.not_set or
                                            self.host_routing_enabled.yfilter != YFilter.not_set or
                                            self.igmp_flood_forward_enabled.yfilter != YFilter.not_set or
                                            self.igmp_mroute_port_enabled.yfilter != YFilter.not_set or
                                            self.igmp_route_guard_enabled.yfilter != YFilter.not_set or
                                            self.igmp_snoop_enabled.yfilter != YFilter.not_set or
                                            self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set or
                                            self.is_bvi_up.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_evpn_cw_disable.yfilter != YFilter.not_set or
                                            self.is_evpn_enabled.yfilter != YFilter.not_set or
                                            self.is_evpn_flow_label.yfilter != YFilter.not_set or
                                            self.is_igmp_snoop_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_p2mp_pw_enabled.yfilter != YFilter.not_set or
                                            self.is_pbbevpn_enabled.yfilter != YFilter.not_set or
                                            self.is_swmac_learning.yfilter != YFilter.not_set or
                                            self.is_vni_enabled.yfilter != YFilter.not_set or
                                            self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_aging_type.yfilter != YFilter.not_set or
                                            self.mac_learning_disabled.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification_type.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_disabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_flood_forward_enabled.yfilter != YFilter.not_set or
                                            self.mld_mroute_port_enabled.yfilter != YFilter.not_set or
                                            self.mld_route_guard_enabled.yfilter != YFilter.not_set or
                                            self.mld_snoop_enabled.yfilter != YFilter.not_set or
                                            self.mld_snoop_profile_enabled.yfilter != YFilter.not_set or
                                            self.msti.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.number_of_macs.yfilter != YFilter.not_set or
                                            self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                                            self.storm_control_broadcast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set or
                                            self.storm_control_multicast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set or
                                            self.storm_control_unicast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set or
                                            self.stp_participating.yfilter != YFilter.not_set or
                                            self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "operational-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.admin_disabled.is_set or self.admin_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.admin_disabled.get_name_leafdata())
                                        if (self.bvi_configured.is_set or self.bvi_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bvi_configured.get_name_leafdata())
                                        if (self.dhcp_enabled.is_set or self.dhcp_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcp_enabled.get_name_leafdata())
                                        if (self.dhcp_trusted.is_set or self.dhcp_trusted.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcp_trusted.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flooding_disabled.is_set or self.flooding_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flooding_disabled.get_name_leafdata())
                                        if (self.host_routing_enabled.is_set or self.host_routing_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.host_routing_enabled.get_name_leafdata())
                                        if (self.igmp_flood_forward_enabled.is_set or self.igmp_flood_forward_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_flood_forward_enabled.get_name_leafdata())
                                        if (self.igmp_mroute_port_enabled.is_set or self.igmp_mroute_port_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_mroute_port_enabled.get_name_leafdata())
                                        if (self.igmp_route_guard_enabled.is_set or self.igmp_route_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_route_guard_enabled.get_name_leafdata())
                                        if (self.igmp_snoop_enabled.is_set or self.igmp_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_snoop_enabled.get_name_leafdata())
                                        if (self.igmp_snoop_profile_enabled.is_set or self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_snoop_profile_enabled.get_name_leafdata())
                                        if (self.is_bvi_up.is_set or self.is_bvi_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_bvi_up.get_name_leafdata())
                                        if (self.is_dai_addr_validation_destination_mac_enabled.is_set or self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validation_ipv4_enabled.is_set or self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validation_source_mac_enabled.is_set or self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_evpn_cw_disable.is_set or self.is_evpn_cw_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_cw_disable.get_name_leafdata())
                                        if (self.is_evpn_enabled.is_set or self.is_evpn_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_enabled.get_name_leafdata())
                                        if (self.is_evpn_flow_label.is_set or self.is_evpn_flow_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_flow_label.get_name_leafdata())
                                        if (self.is_igmp_snoop_enabled.is_set or self.is_igmp_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_igmp_snoop_enabled.get_name_leafdata())
                                        if (self.is_ipsg_enabled.is_set or self.is_ipsg_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown.is_set or self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.is_p2mp_pw_enabled.is_set or self.is_p2mp_pw_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_p2mp_pw_enabled.get_name_leafdata())
                                        if (self.is_pbbevpn_enabled.is_set or self.is_pbbevpn_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pbbevpn_enabled.get_name_leafdata())
                                        if (self.is_swmac_learning.is_set or self.is_swmac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_swmac_learning.get_name_leafdata())
                                        if (self.is_vni_enabled.is_set or self.is_vni_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_vni_enabled.get_name_leafdata())
                                        if (self.is_vpls_flood_optimization_enabled.is_set or self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_vpls_flood_optimization_enabled.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_aging_type.is_set or self.mac_aging_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_type.get_name_leafdata())
                                        if (self.mac_learning_disabled.is_set or self.mac_learning_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning_disabled.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification_type.is_set or self.mac_limit_notification_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification_type.get_name_leafdata())
                                        if (self.mac_port_down_flush_disabled.is_set or self.mac_port_down_flush_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_disabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_flood_forward_enabled.is_set or self.mld_flood_forward_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_flood_forward_enabled.get_name_leafdata())
                                        if (self.mld_mroute_port_enabled.is_set or self.mld_mroute_port_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_mroute_port_enabled.get_name_leafdata())
                                        if (self.mld_route_guard_enabled.is_set or self.mld_route_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_route_guard_enabled.get_name_leafdata())
                                        if (self.mld_snoop_enabled.is_set or self.mld_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_snoop_enabled.get_name_leafdata())
                                        if (self.mld_snoop_profile_enabled.is_set or self.mld_snoop_profile_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_snoop_profile_enabled.get_name_leafdata())
                                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msti.get_name_leafdata())
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.number_of_macs.is_set or self.number_of_macs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_macs.get_name_leafdata())
                                        if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                                        if (self.storm_control_broadcast_enabled.is_set or self.storm_control_broadcast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_broadcast_enabled.get_name_leafdata())
                                        if (self.storm_control_broadcast_rate_unit.is_set or self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_broadcast_rate_unit.get_name_leafdata())
                                        if (self.storm_control_multicast_enabled.is_set or self.storm_control_multicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_multicast_enabled.get_name_leafdata())
                                        if (self.storm_control_multicast_rate_unit.is_set or self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_multicast_rate_unit.get_name_leafdata())
                                        if (self.storm_control_unicast_enabled.is_set or self.storm_control_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_unicast_enabled.get_name_leafdata())
                                        if (self.storm_control_unicast_rate_unit.is_set or self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_unicast_rate_unit.get_name_leafdata())
                                        if (self.stp_participating.is_set or self.stp_participating.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.stp_participating.get_name_leafdata())
                                        if (self.unknown_unicast_flooding_disabled.is_set or self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unknown_unicast_flooding_disabled.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "feature"):
                                            for c in self.feature:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.feature.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "feature" or name == "admin-disabled" or name == "bvi-configured" or name == "dhcp-enabled" or name == "dhcp-trusted" or name == "flood-unknown-unicast-enabled" or name == "flooding-disabled" or name == "host-routing-enabled" or name == "igmp-flood-forward-enabled" or name == "igmp-mroute-port-enabled" or name == "igmp-route-guard-enabled" or name == "igmp-snoop-enabled" or name == "igmp-snoop-profile-enabled" or name == "is-bvi-up" or name == "is-dai-addr-validation-destination-mac-enabled" or name == "is-dai-addr-validation-ipv4-enabled" or name == "is-dai-addr-validation-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-evpn-cw-disable" or name == "is-evpn-enabled" or name == "is-evpn-flow-label" or name == "is-igmp-snoop-enabled" or name == "is-ipsg-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "is-p2mp-pw-enabled" or name == "is-pbbevpn-enabled" or name == "is-swmac-learning" or name == "is-vni-enabled" or name == "is-vpls-flood-optimization-enabled" or name == "mac-aging-time" or name == "mac-aging-type" or name == "mac-learning-disabled" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification-type" or name == "mac-port-down-flush-disabled" or name == "mac-secure-action" or name == "mld-flood-forward-enabled" or name == "mld-mroute-port-enabled" or name == "mld-route-guard-enabled" or name == "mld-snoop-enabled" or name == "mld-snoop-profile-enabled" or name == "msti" or name == "mtu" or name == "number-of-macs" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "storm-control-broadcast-enabled" or name == "storm-control-broadcast-rate-unit" or name == "storm-control-multicast-enabled" or name == "storm-control-multicast-rate-unit" or name == "storm-control-unicast-enabled" or name == "storm-control-unicast-rate-unit" or name == "stp-participating" or name == "unknown-unicast-flooding-disabled"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "admin-disabled"):
                                            self.admin_disabled = value
                                            self.admin_disabled.value_namespace = name_space
                                            self.admin_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bvi-configured"):
                                            self.bvi_configured = value
                                            self.bvi_configured.value_namespace = name_space
                                            self.bvi_configured.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcp-enabled"):
                                            self.dhcp_enabled = value
                                            self.dhcp_enabled.value_namespace = name_space
                                            self.dhcp_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcp-trusted"):
                                            self.dhcp_trusted = value
                                            self.dhcp_trusted.value_namespace = name_space
                                            self.dhcp_trusted.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flooding-disabled"):
                                            self.flooding_disabled = value
                                            self.flooding_disabled.value_namespace = name_space
                                            self.flooding_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "host-routing-enabled"):
                                            self.host_routing_enabled = value
                                            self.host_routing_enabled.value_namespace = name_space
                                            self.host_routing_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-flood-forward-enabled"):
                                            self.igmp_flood_forward_enabled = value
                                            self.igmp_flood_forward_enabled.value_namespace = name_space
                                            self.igmp_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-mroute-port-enabled"):
                                            self.igmp_mroute_port_enabled = value
                                            self.igmp_mroute_port_enabled.value_namespace = name_space
                                            self.igmp_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-route-guard-enabled"):
                                            self.igmp_route_guard_enabled = value
                                            self.igmp_route_guard_enabled.value_namespace = name_space
                                            self.igmp_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-snoop-enabled"):
                                            self.igmp_snoop_enabled = value
                                            self.igmp_snoop_enabled.value_namespace = name_space
                                            self.igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-snoop-profile-enabled"):
                                            self.igmp_snoop_profile_enabled = value
                                            self.igmp_snoop_profile_enabled.value_namespace = name_space
                                            self.igmp_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-bvi-up"):
                                            self.is_bvi_up = value
                                            self.is_bvi_up.value_namespace = name_space
                                            self.is_bvi_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-destination-mac-enabled"):
                                            self.is_dai_addr_validation_destination_mac_enabled = value
                                            self.is_dai_addr_validation_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-ipv4-enabled"):
                                            self.is_dai_addr_validation_ipv4_enabled = value
                                            self.is_dai_addr_validation_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-source-mac-enabled"):
                                            self.is_dai_addr_validation_source_mac_enabled = value
                                            self.is_dai_addr_validation_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-cw-disable"):
                                            self.is_evpn_cw_disable = value
                                            self.is_evpn_cw_disable.value_namespace = name_space
                                            self.is_evpn_cw_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-enabled"):
                                            self.is_evpn_enabled = value
                                            self.is_evpn_enabled.value_namespace = name_space
                                            self.is_evpn_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-flow-label"):
                                            self.is_evpn_flow_label = value
                                            self.is_evpn_flow_label.value_namespace = name_space
                                            self.is_evpn_flow_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-igmp-snoop-enabled"):
                                            self.is_igmp_snoop_enabled = value
                                            self.is_igmp_snoop_enabled.value_namespace = name_space
                                            self.is_igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-enabled"):
                                            self.is_ipsg_enabled = value
                                            self.is_ipsg_enabled.value_namespace = name_space
                                            self.is_ipsg_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown"):
                                            self.is_mac_secure_accept_shutdown = value
                                            self.is_mac_secure_accept_shutdown.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-p2mp-pw-enabled"):
                                            self.is_p2mp_pw_enabled = value
                                            self.is_p2mp_pw_enabled.value_namespace = name_space
                                            self.is_p2mp_pw_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-pbbevpn-enabled"):
                                            self.is_pbbevpn_enabled = value
                                            self.is_pbbevpn_enabled.value_namespace = name_space
                                            self.is_pbbevpn_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-swmac-learning"):
                                            self.is_swmac_learning = value
                                            self.is_swmac_learning.value_namespace = name_space
                                            self.is_swmac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-vni-enabled"):
                                            self.is_vni_enabled = value
                                            self.is_vni_enabled.value_namespace = name_space
                                            self.is_vni_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-vpls-flood-optimization-enabled"):
                                            self.is_vpls_flood_optimization_enabled = value
                                            self.is_vpls_flood_optimization_enabled.value_namespace = name_space
                                            self.is_vpls_flood_optimization_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-type"):
                                            self.mac_aging_type = value
                                            self.mac_aging_type.value_namespace = name_space
                                            self.mac_aging_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning-disabled"):
                                            self.mac_learning_disabled = value
                                            self.mac_learning_disabled.value_namespace = name_space
                                            self.mac_learning_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification-type"):
                                            self.mac_limit_notification_type = value
                                            self.mac_limit_notification_type.value_namespace = name_space
                                            self.mac_limit_notification_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-disabled"):
                                            self.mac_port_down_flush_disabled = value
                                            self.mac_port_down_flush_disabled.value_namespace = name_space
                                            self.mac_port_down_flush_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-flood-forward-enabled"):
                                            self.mld_flood_forward_enabled = value
                                            self.mld_flood_forward_enabled.value_namespace = name_space
                                            self.mld_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-mroute-port-enabled"):
                                            self.mld_mroute_port_enabled = value
                                            self.mld_mroute_port_enabled.value_namespace = name_space
                                            self.mld_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-route-guard-enabled"):
                                            self.mld_route_guard_enabled = value
                                            self.mld_route_guard_enabled.value_namespace = name_space
                                            self.mld_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-snoop-enabled"):
                                            self.mld_snoop_enabled = value
                                            self.mld_snoop_enabled.value_namespace = name_space
                                            self.mld_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-snoop-profile-enabled"):
                                            self.mld_snoop_profile_enabled = value
                                            self.mld_snoop_profile_enabled.value_namespace = name_space
                                            self.mld_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msti"):
                                            self.msti = value
                                            self.msti.value_namespace = name_space
                                            self.msti.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-macs"):
                                            self.number_of_macs = value
                                            self.number_of_macs.value_namespace = name_space
                                            self.number_of_macs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                                            self.nv_satellite_offload_ipv4_multicast_disabled = value
                                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-broadcast-enabled"):
                                            self.storm_control_broadcast_enabled = value
                                            self.storm_control_broadcast_enabled.value_namespace = name_space
                                            self.storm_control_broadcast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-broadcast-rate-unit"):
                                            self.storm_control_broadcast_rate_unit = value
                                            self.storm_control_broadcast_rate_unit.value_namespace = name_space
                                            self.storm_control_broadcast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-multicast-enabled"):
                                            self.storm_control_multicast_enabled = value
                                            self.storm_control_multicast_enabled.value_namespace = name_space
                                            self.storm_control_multicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-multicast-rate-unit"):
                                            self.storm_control_multicast_rate_unit = value
                                            self.storm_control_multicast_rate_unit.value_namespace = name_space
                                            self.storm_control_multicast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-unicast-enabled"):
                                            self.storm_control_unicast_enabled = value
                                            self.storm_control_unicast_enabled.value_namespace = name_space
                                            self.storm_control_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-unicast-rate-unit"):
                                            self.storm_control_unicast_rate_unit = value
                                            self.storm_control_unicast_rate_unit.value_namespace = name_space
                                            self.storm_control_unicast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "stp-participating"):
                                            self.stp_participating = value
                                            self.stp_participating.value_namespace = name_space
                                            self.stp_participating.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unknown-unicast-flooding-disabled"):
                                            self.unknown_unicast_flooding_disabled = value
                                            self.unknown_unicast_flooding_disabled.value_namespace = name_space
                                            self.unknown_unicast_flooding_disabled.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        (self.operational_information is not None and self.operational_information.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        (self.operational_information is not None and self.operational_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "oper" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "operational-information"):
                                        if (self.operational_information is None):
                                            self.operational_information = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation()
                                            self.operational_information.parent = self
                                            self._children_name_map["operational_information"] = "operational-information"
                                        return self.operational_information

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "operational-information" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix


                            class P2Mp(Entity):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\:  bool
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:   :py:class:`L2VpnPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPtree>`
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.P2Mp, self).__init__()

                                    self.yang_name = "p2mp"
                                    self.yang_parent_name = "bp"

                                    self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                                    self.lsm_id = YLeaf(YType.uint32, "lsm-id")

                                    self.p2mp_id = YLeaf(YType.uint16, "p2mp-id")

                                    self.ptree_owner_lmrib = YLeaf(YType.boolean, "ptree-owner-lmrib")

                                    self.ptree_type = YLeaf(YType.enumeration, "ptree-type")

                                    self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("extended_tunnel_id",
                                                    "lsm_id",
                                                    "p2mp_id",
                                                    "ptree_owner_lmrib",
                                                    "ptree_type",
                                                    "tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.P2Mp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.P2Mp, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.extended_tunnel_id.is_set or
                                        self.lsm_id.is_set or
                                        self.p2mp_id.is_set or
                                        self.ptree_owner_lmrib.is_set or
                                        self.ptree_type.is_set or
                                        self.tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.lsm_id.yfilter != YFilter.not_set or
                                        self.p2mp_id.yfilter != YFilter.not_set or
                                        self.ptree_owner_lmrib.yfilter != YFilter.not_set or
                                        self.ptree_type.yfilter != YFilter.not_set or
                                        self.tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                                    if (self.lsm_id.is_set or self.lsm_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsm_id.get_name_leafdata())
                                    if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                                    if (self.ptree_owner_lmrib.is_set or self.ptree_owner_lmrib.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ptree_owner_lmrib.get_name_leafdata())
                                    if (self.ptree_type.is_set or self.ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ptree_type.get_name_leafdata())
                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "extended-tunnel-id" or name == "lsm-id" or name == "p2mp-id" or name == "ptree-owner-lmrib" or name == "ptree-type" or name == "tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "extended-tunnel-id"):
                                        self.extended_tunnel_id = value
                                        self.extended_tunnel_id.value_namespace = name_space
                                        self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsm-id"):
                                        self.lsm_id = value
                                        self.lsm_id.value_namespace = name_space
                                        self.lsm_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "p2mp-id"):
                                        self.p2mp_id = value
                                        self.p2mp_id.value_namespace = name_space
                                        self.p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ptree-owner-lmrib"):
                                        self.ptree_owner_lmrib = value
                                        self.ptree_owner_lmrib.value_namespace = name_space
                                        self.ptree_owner_lmrib.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ptree-type"):
                                        self.ptree_type = value
                                        self.ptree_type.value_namespace = name_space
                                        self.ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-id"):
                                        self.tunnel_id = value
                                        self.tunnel_id.value_namespace = name_space
                                        self.tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bridge_id.is_set or
                                    self.learn_key.is_set or
                                    self.msti_pointer.is_set or
                                    self.mvrp_sequence_number.is_set or
                                    self.segment_type.is_set or
                                    self.shg_id.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.oper is not None and self.oper.has_data()) or
                                    (self.p2mp is not None and self.p2mp.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bridge_id.yfilter != YFilter.not_set or
                                    self.learn_key.yfilter != YFilter.not_set or
                                    self.msti_pointer.yfilter != YFilter.not_set or
                                    self.mvrp_sequence_number.yfilter != YFilter.not_set or
                                    self.segment_type.yfilter != YFilter.not_set or
                                    self.shg_id.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.oper is not None and self.oper.has_operation()) or
                                    (self.p2mp is not None and self.p2mp.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bp" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_id.get_name_leafdata())
                                if (self.learn_key.is_set or self.learn_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.learn_key.get_name_leafdata())
                                if (self.msti_pointer.is_set or self.msti_pointer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_pointer.get_name_leafdata())
                                if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())
                                if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_type.get_name_leafdata())
                                if (self.shg_id.is_set or self.shg_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shg_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "oper"):
                                    if (self.oper is None):
                                        self.oper = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper()
                                        self.oper.parent = self
                                        self._children_name_map["oper"] = "oper"
                                    return self.oper

                                if (child_yang_name == "p2mp"):
                                    if (self.p2mp is None):
                                        self.p2mp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.P2Mp()
                                        self.p2mp.parent = self
                                        self._children_name_map["p2mp"] = "p2mp"
                                    return self.p2mp

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "oper" or name == "p2mp" or name == "bridge-id" or name == "learn-key" or name == "msti-pointer" or name == "mvrp-sequence-number" or name == "segment-type" or name == "shg-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bridge-id"):
                                    self.bridge_id = value
                                    self.bridge_id.value_namespace = name_space
                                    self.bridge_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "learn-key"):
                                    self.learn_key = value
                                    self.learn_key.value_namespace = name_space
                                    self.learn_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-pointer"):
                                    self.msti_pointer = value
                                    self.msti_pointer.value_namespace = name_space
                                    self.msti_pointer.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvrp-sequence-number"):
                                    self.mvrp_sequence_number = value
                                    self.mvrp_sequence_number.value_namespace = name_space
                                    self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-type"):
                                    self.segment_type = value
                                    self.segment_type.value_namespace = name_space
                                    self.segment_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shg-id"):
                                    self.shg_id = value
                                    self.shg_id.value_namespace = name_space
                                    self.shg_id.value_namespace_prefix = name_space_prefix


                        class Fxs(Entity):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs, self).__init__()

                                self.yang_name = "fxs"
                                self.yang_parent_name = "segment2"

                                self.fxs_id = YLeaf(YType.uint32, "fxs-id")

                                self.segment_type = YLeaf(YType.uint8, "segment-type")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fxs_id",
                                                "segment_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "fxs"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.fxs_id.is_set or
                                    self.segment_type.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fxs_id.yfilter != YFilter.not_set or
                                    self.segment_type.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "fxs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fxs_id.is_set or self.fxs_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxs_id.get_name_leafdata())
                                if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxs-id" or name == "segment-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fxs-id"):
                                    self.fxs_id = value
                                    self.fxs_id.value_namespace = name_space
                                    self.fxs_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-type"):
                                    self.segment_type = value
                                    self.segment_type.value_namespace = name_space
                                    self.segment_type.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBal>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment2"

                                self.ac_id = YLeaf(YType.uint32, "ac-id")

                                self.active = YLeaf(YType.boolean, "active")

                                self.backup_configured = YLeaf(YType.boolean, "backup-configured")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.context = YLeaf(YType.uint16, "context")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.global_id = YLeaf(YType.uint32, "global-id")

                                self.group_id = YLeaf(YType.uint32, "group-id")

                                self.group_state = YLeaf(YType.enumeration, "group-state")

                                self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                                self.pw_load_balance_type = YLeaf(YType.enumeration, "pw-load-balance-type")

                                self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                self.sequence_resync_threshold = YLeaf(YType.uint16, "sequence-resync-threshold")

                                self.signal_capability_flags = YLeaf(YType.uint32, "signal-capability-flags")

                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._children_yang_names.add("backup-pseudo-wire")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                self._children_yang_names.add("pseudo-wire-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ac_id",
                                                "active",
                                                "backup_configured",
                                                "bound",
                                                "context",
                                                "forward_class",
                                                "global_id",
                                                "group_id",
                                                "group_state",
                                                "grouping_supported",
                                                "next_hop_valid",
                                                "pseudo_wire_id_type",
                                                "pw_flow_label_tx",
                                                "pw_id",
                                                "pw_load_balance_type",
                                                "redundancy_role",
                                                "sequence_resync_threshold",
                                                "signal_capability_flags") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"
                                    self._children_yang_names.add("l2tp")

                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._children_yang_names.add("l2tp-ipv6-ts")

                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"
                                    self._children_yang_names.add("l2tpv2")

                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"
                                    self._children_yang_names.add("mpls")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion, self).__setattr__(name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix


                                class L2Tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_mtu",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_mtu.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "path-mtu" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix


                                class L2Tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.protocol = YLeaf(YType.uint16, "protocol")

                                        self.pw_flags = YLeaf(YType.uint8, "pw-flags")

                                        self.rem_udp_port = YLeaf(YType.uint16, "rem-udp-port")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop_address",
                                                        "path_mtu",
                                                        "protocol",
                                                        "pw_flags",
                                                        "rem_udp_port",
                                                        "source_address",
                                                        "tos_val",
                                                        "ttl",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.next_hop_address.is_set or
                                            self.path_mtu.is_set or
                                            self.protocol.is_set or
                                            self.pw_flags.is_set or
                                            self.rem_udp_port.is_set or
                                            self.source_address.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            self.xconnect_id.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pw_flags.yfilter != YFilter.not_set or
                                            self.rem_udp_port.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv2" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pw_flags.is_set or self.pw_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flags.get_name_leafdata())
                                        if (self.rem_udp_port.is_set or self.rem_udp_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_udp_port.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "next-hop-address" or name == "path-mtu" or name == "protocol" or name == "pw-flags" or name == "rem-udp-port" or name == "source-address" or name == "tos-val" or name == "ttl" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop-address"):
                                            self.next_hop_address = value
                                            self.next_hop_address.value_namespace = name_space
                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flags"):
                                            self.pw_flags = value
                                            self.pw_flags.value_namespace = name_space
                                            self.pw_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-udp-port"):
                                            self.rem_udp_port = value
                                            self.rem_udp_port.value_namespace = name_space
                                            self.rem_udp_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class L2TpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address",
                                                        "path_mtu",
                                                        "remote_address",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.secondary_cookie_high_value = YLeaf(YType.uint32, "secondary-cookie-high-value")

                                            self.secondary_cookie_low_value = YLeaf(YType.uint32, "secondary-cookie-low-value")

                                            self.secondary_cookie_size = YLeaf(YType.uint8, "secondary-cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "secondary_cookie_high_value",
                                                            "secondary_cookie_low_value",
                                                            "secondary_cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.secondary_cookie_high_value.is_set or
                                                self.secondary_cookie_low_value.is_set or
                                                self.secondary_cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.secondary_cookie_high_value.is_set or self.secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_high_value.get_name_leafdata())
                                            if (self.secondary_cookie_low_value.is_set or self.secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_low_value.get_name_leafdata())
                                            if (self.secondary_cookie_size.is_set or self.secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "secondary-cookie-high-value" or name == "secondary-cookie-low-value" or name == "secondary-cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-high-value"):
                                                self.secondary_cookie_high_value = value
                                                self.secondary_cookie_high_value.value_namespace = name_space
                                                self.secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-low-value"):
                                                self.secondary_cookie_low_value = value
                                                self.secondary_cookie_low_value.value_namespace = name_space
                                                self.secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-size"):
                                                self.secondary_cookie_size = value
                                                self.secondary_cookie_size.value_namespace = name_space
                                                self.secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.local_address.is_set or
                                            self.path_mtu.is_set or
                                            self.remote_address.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp-ipv6-ts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "local-address" or name == "path-mtu" or name == "remote-address" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        (self.l2tp is not None and self.l2tp.has_data()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_data()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_data()) or
                                        (self.mpls is not None and self.mpls.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        (self.l2tp is not None and self.l2tp.has_operation()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_operation()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_operation()) or
                                        (self.mpls is not None and self.mpls.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudo-wire-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2tp"):
                                        if (self.l2tp is None):
                                            self.l2tp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp()
                                            self.l2tp.parent = self
                                            self._children_name_map["l2tp"] = "l2tp"
                                        return self.l2tp

                                    if (child_yang_name == "l2tp-ipv6-ts"):
                                        if (self.l2tp_ipv6_ts is None):
                                            self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                            self.l2tp_ipv6_ts.parent = self
                                            self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                        return self.l2tp_ipv6_ts

                                    if (child_yang_name == "l2tpv2"):
                                        if (self.l2tpv2 is None):
                                            self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                            self.l2tpv2.parent = self
                                            self._children_name_map["l2tpv2"] = "l2tpv2"
                                        return self.l2tpv2

                                    if (child_yang_name == "mpls"):
                                        if (self.mpls is None):
                                            self.mpls = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                        return self.mpls

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2tp" or name == "l2tp-ipv6-ts" or name == "l2tpv2" or name == "mpls" or name == "data-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.backup_next_hop = YLeaf(YType.str, "backup-next-hop")

                                    self.backup_pseudo_wire_id = YLeaf(YType.uint32, "backup-pseudo-wire-id")

                                    self.backup_pseudo_wire_id_type = YLeaf(YType.enumeration, "backup-pseudo-wire-id-type")

                                    self.bound = YLeaf(YType.boolean, "bound")

                                    self.group_id = YLeaf(YType.uint32, "group-id")

                                    self.group_state = YLeaf(YType.enumeration, "group-state")

                                    self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                    self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                    self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "backup_next_hop",
                                                    "backup_pseudo_wire_id",
                                                    "backup_pseudo_wire_id_type",
                                                    "bound",
                                                    "group_id",
                                                    "group_state",
                                                    "grouping_supported",
                                                    "pw_flow_label_tx",
                                                    "redundancy_role") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.backup_next_hop.is_set or
                                        self.backup_pseudo_wire_id.is_set or
                                        self.backup_pseudo_wire_id_type.is_set or
                                        self.bound.is_set or
                                        self.group_id.is_set or
                                        self.group_state.is_set or
                                        self.grouping_supported.is_set or
                                        self.pw_flow_label_tx.is_set or
                                        self.redundancy_role.is_set or
                                        (self.atom is not None and self.atom.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.backup_next_hop.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set or
                                        self.bound.yfilter != YFilter.not_set or
                                        self.group_id.yfilter != YFilter.not_set or
                                        self.group_state.yfilter != YFilter.not_set or
                                        self.grouping_supported.yfilter != YFilter.not_set or
                                        self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                        self.redundancy_role.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-pseudo-wire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.backup_next_hop.is_set or self.backup_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_next_hop.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id.is_set or self.backup_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id_type.is_set or self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id_type.get_name_leafdata())
                                    if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bound.get_name_leafdata())
                                    if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_id.get_name_leafdata())
                                    if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_state.get_name_leafdata())
                                    if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                    if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                    if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_role.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "active" or name == "backup-next-hop" or name == "backup-pseudo-wire-id" or name == "backup-pseudo-wire-id-type" or name == "bound" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "pw-flow-label-tx" or name == "redundancy-role"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-next-hop"):
                                        self.backup_next_hop = value
                                        self.backup_next_hop.value_namespace = name_space
                                        self.backup_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id"):
                                        self.backup_pseudo_wire_id = value
                                        self.backup_pseudo_wire_id.value_namespace = name_space
                                        self.backup_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id-type"):
                                        self.backup_pseudo_wire_id_type = value
                                        self.backup_pseudo_wire_id_type.value_namespace = name_space
                                        self.backup_pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bound"):
                                        self.bound = value
                                        self.bound.value_namespace = name_space
                                        self.bound.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-id"):
                                        self.group_id = value
                                        self.group_id.value_namespace = name_space
                                        self.group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-state"):
                                        self.group_state = value
                                        self.group_state.value_namespace = name_space
                                        self.group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "grouping-supported"):
                                        self.grouping_supported = value
                                        self.grouping_supported.value_namespace = name_space
                                        self.grouping_supported.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-tx"):
                                        self.pw_flow_label_tx = value
                                        self.pw_flow_label_tx.value_namespace = name_space
                                        self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-role"):
                                        self.redundancy_role = value
                                        self.redundancy_role.value_namespace = name_space
                                        self.redundancy_role.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ac_id.is_set or
                                    self.active.is_set or
                                    self.backup_configured.is_set or
                                    self.bound.is_set or
                                    self.context.is_set or
                                    self.forward_class.is_set or
                                    self.global_id.is_set or
                                    self.group_id.is_set or
                                    self.group_state.is_set or
                                    self.grouping_supported.is_set or
                                    self.next_hop_valid.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_flow_label_tx.is_set or
                                    self.pw_id.is_set or
                                    self.pw_load_balance_type.is_set or
                                    self.redundancy_role.is_set or
                                    self.sequence_resync_threshold.is_set or
                                    self.signal_capability_flags.is_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_data()) or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ac_id.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.backup_configured.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.context.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.global_id.yfilter != YFilter.not_set or
                                    self.group_id.yfilter != YFilter.not_set or
                                    self.group_state.yfilter != YFilter.not_set or
                                    self.grouping_supported.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.pw_load_balance_type.yfilter != YFilter.not_set or
                                    self.redundancy_role.yfilter != YFilter.not_set or
                                    self.sequence_resync_threshold.yfilter != YFilter.not_set or
                                    self.signal_capability_flags.yfilter != YFilter.not_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_operation()) or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ac_id.is_set or self.ac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac_id.get_name_leafdata())
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.backup_configured.is_set or self.backup_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_configured.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.context.is_set or self.context.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.context.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.global_id.is_set or self.global_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_id.get_name_leafdata())
                                if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_id.get_name_leafdata())
                                if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_state.get_name_leafdata())
                                if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.pw_load_balance_type.is_set or self.pw_load_balance_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_load_balance_type.get_name_leafdata())
                                if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_role.get_name_leafdata())
                                if (self.sequence_resync_threshold.is_set or self.sequence_resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_resync_threshold.get_name_leafdata())
                                if (self.signal_capability_flags.is_set or self.signal_capability_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signal_capability_flags.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-pseudo-wire"):
                                    if (self.backup_pseudo_wire is None):
                                        self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire()
                                        self.backup_pseudo_wire.parent = self
                                        self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                    return self.backup_pseudo_wire

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                if (child_yang_name == "pseudo-wire-union"):
                                    if (self.pseudo_wire_union is None):
                                        self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion()
                                        self.pseudo_wire_union.parent = self
                                        self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                    return self.pseudo_wire_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-pseudo-wire" or name == "base" or name == "next-hop" or name == "pseudo-wire-union" or name == "ac-id" or name == "active" or name == "backup-configured" or name == "bound" or name == "context" or name == "forward-class" or name == "global-id" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "next-hop-valid" or name == "pseudo-wire-id-type" or name == "pw-flow-label-tx" or name == "pw-id" or name == "pw-load-balance-type" or name == "redundancy-role" or name == "sequence-resync-threshold" or name == "signal-capability-flags"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ac-id"):
                                    self.ac_id = value
                                    self.ac_id.value_namespace = name_space
                                    self.ac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-configured"):
                                    self.backup_configured = value
                                    self.backup_configured.value_namespace = name_space
                                    self.backup_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "context"):
                                    self.context = value
                                    self.context.value_namespace = name_space
                                    self.context.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "global-id"):
                                    self.global_id = value
                                    self.global_id.value_namespace = name_space
                                    self.global_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-id"):
                                    self.group_id = value
                                    self.group_id.value_namespace = name_space
                                    self.group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-state"):
                                    self.group_state = value
                                    self.group_state.value_namespace = name_space
                                    self.group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "grouping-supported"):
                                    self.grouping_supported = value
                                    self.grouping_supported.value_namespace = name_space
                                    self.grouping_supported.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-tx"):
                                    self.pw_flow_label_tx = value
                                    self.pw_flow_label_tx.value_namespace = name_space
                                    self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-load-balance-type"):
                                    self.pw_load_balance_type = value
                                    self.pw_load_balance_type.value_namespace = name_space
                                    self.pw_load_balance_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-role"):
                                    self.redundancy_role = value
                                    self.redundancy_role.value_namespace = name_space
                                    self.redundancy_role.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-resync-threshold"):
                                    self.sequence_resync_threshold = value
                                    self.sequence_resync_threshold.value_namespace = name_space
                                    self.sequence_resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "signal-capability-flags"):
                                    self.signal_capability_flags = value
                                    self.signal_capability_flags.value_namespace = name_space
                                    self.signal_capability_flags.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.bp is not None and self.bp.has_data()) or
                                (self.fxs is not None and self.fxs.has_data()) or
                                (self.pw is not None and self.pw.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.bp is not None and self.bp.has_operation()) or
                                (self.fxs is not None and self.fxs.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "bp"):
                                if (self.bp is None):
                                    self.bp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp()
                                    self.bp.parent = self
                                    self._children_name_map["bp"] = "bp"
                                return self.bp

                            if (child_yang_name == "fxs"):
                                if (self.fxs is None):
                                    self.fxs = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs()
                                    self.fxs.parent = self
                                    self._children_name_map["fxs"] = "fxs"
                                return self.fxs

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "bp" or name == "fxs" or name == "pw" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.monitor_session_name.is_set or
                            self.bound.is_set or
                            self.switching_type.is_set or
                            self.xcon_name.is_set or
                            (self.base is not None and self.base.has_data()) or
                            (self.segment1 is not None and self.segment1.has_data()) or
                            (self.segment2 is not None and self.segment2.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.monitor_session_name.yfilter != YFilter.not_set or
                            self.bound.yfilter != YFilter.not_set or
                            self.switching_type.yfilter != YFilter.not_set or
                            self.xcon_name.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()) or
                            (self.segment1 is not None and self.segment1.has_operation()) or
                            (self.segment2 is not None and self.segment2.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mon-sess-x-con" + "[monitor-session-name='" + self.monitor_session_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.monitor_session_name.is_set or self.monitor_session_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.monitor_session_name.get_name_leafdata())
                        if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bound.get_name_leafdata())
                        if (self.switching_type.is_set or self.switching_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.switching_type.get_name_leafdata())
                        if (self.xcon_name.is_set or self.xcon_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xcon_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        if (child_yang_name == "segment1"):
                            if (self.segment1 is None):
                                self.segment1 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1()
                                self.segment1.parent = self
                                self._children_name_map["segment1"] = "segment1"
                            return self.segment1

                        if (child_yang_name == "segment2"):
                            if (self.segment2 is None):
                                self.segment2 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2()
                                self.segment2.parent = self
                                self._children_name_map["segment2"] = "segment2"
                            return self.segment2

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "segment1" or name == "segment2" or name == "monitor-session-name" or name == "bound" or name == "switching-type" or name == "xcon-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "monitor-session-name"):
                            self.monitor_session_name = value
                            self.monitor_session_name.value_namespace = name_space
                            self.monitor_session_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bound"):
                            self.bound = value
                            self.bound.value_namespace = name_space
                            self.bound.value_namespace_prefix = name_space_prefix
                        if(value_path == "switching-type"):
                            self.switching_type = value
                            self.switching_type.value_namespace = name_space
                            self.switching_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "xcon-name"):
                            self.xcon_name = value
                            self.xcon_name.value_namespace = name_space
                            self.xcon_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_mon_sess_x_con:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_mon_sess_x_con:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-mon-sess-x-cons" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-mon-sess-x-con"):
                        for c in self.l2fib_mon_sess_x_con:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_mon_sess_x_con.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-mon-sess-x-con"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMmrpSummaries(Entity):
                """
                Mmrp Summary Table
                
                .. attribute:: l2fib_mmrp_summary
                
                	Mmrp Summary Information
                	**type**\: list of    :py:class:`L2FibMmrpSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries, self).__init__()

                    self.yang_name = "l2fib-mmrp-summaries"
                    self.yang_parent_name = "node"

                    self.l2fib_mmrp_summary = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries, self).__setattr__(name, value)


                class L2FibMmrpSummary(Entity):
                    """
                    Mmrp Summary Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\:  str
                    
                    	**length:** 0..66
                    
                    .. attribute:: message
                    
                    	Global Message Information
                    	**type**\: list of    :py:class:`Message <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary.Message>`
                    
                    .. attribute:: multicast_update
                    
                    	Multicast Updates
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multicast_update_dropped
                    
                    	Multicast Updates
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_all_delete_drop
                    
                    	Number of Mroutes All Delete droped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_delete_drop
                    
                    	Number of Mroutes Delete droped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_deleted
                    
                    	Number of Mroutes Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroutes_deleted_all
                    
                    	Number of Mroutes All Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_mroute_add
                    
                    	Number of Mroutes Added
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes
                    
                    	Number of Routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes_with_ole_offload
                    
                    	Number of Routes with OleOffload
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_xid
                    
                    	Number of XIDs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_add
                    
                    	Number of XID Added
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_deleted
                    
                    	Number of XID Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_deleted
                    
                    	Stale Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_xid_deleted
                    
                    	Stale XID Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary, self).__init__()

                        self.yang_name = "l2fib-mmrp-summary"
                        self.yang_parent_name = "l2fib-mmrp-summaries"

                        self.bd_group_name = YLeaf(YType.str, "bd-group-name")

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.bridge_domain_id = YLeaf(YType.uint32, "bridge-domain-id")

                        self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                        self.multicast_update = YLeaf(YType.uint32, "multicast-update")

                        self.multicast_update_dropped = YLeaf(YType.uint32, "multicast-update-dropped")

                        self.number_mroute_all_delete_drop = YLeaf(YType.uint32, "number-mroute-all-delete-drop")

                        self.number_mroute_delete_drop = YLeaf(YType.uint32, "number-mroute-delete-drop")

                        self.number_mroute_deleted = YLeaf(YType.uint32, "number-mroute-deleted")

                        self.number_mroutes_deleted_all = YLeaf(YType.uint32, "number-mroutes-deleted-all")

                        self.number_of_mroute_add = YLeaf(YType.uint32, "number-of-mroute-add")

                        self.number_of_routes = YLeaf(YType.uint32, "number-of-routes")

                        self.number_of_routes_with_ole_offload = YLeaf(YType.uint32, "number-of-routes-with-ole-offload")

                        self.number_of_xid = YLeaf(YType.uint32, "number-of-xid")

                        self.number_xid_add = YLeaf(YType.uint32, "number-xid-add")

                        self.number_xid_deleted = YLeaf(YType.uint32, "number-xid-deleted")

                        self.stale_deleted = YLeaf(YType.uint32, "stale-deleted")

                        self.stale_xid_deleted = YLeaf(YType.uint32, "stale-xid-deleted")

                        self.message = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bd_group_name",
                                        "bd_name",
                                        "bridge_domain_id",
                                        "bridge_domain_name",
                                        "multicast_update",
                                        "multicast_update_dropped",
                                        "number_mroute_all_delete_drop",
                                        "number_mroute_delete_drop",
                                        "number_mroute_deleted",
                                        "number_mroutes_deleted_all",
                                        "number_of_mroute_add",
                                        "number_of_routes",
                                        "number_of_routes_with_ole_offload",
                                        "number_of_xid",
                                        "number_xid_add",
                                        "number_xid_deleted",
                                        "stale_deleted",
                                        "stale_xid_deleted") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary, self).__setattr__(name, value)


                    class Message(Entity):
                        """
                        Global Message Information
                        
                        .. attribute:: information1
                        
                        	Extra info 1
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: information2
                        
                        	Extra info 2
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: messgae_count
                        
                        	number of message
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time
                        
                        	Time string
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary.Message, self).__init__()

                            self.yang_name = "message"
                            self.yang_parent_name = "l2fib-mmrp-summary"

                            self.information1 = YLeaf(YType.uint32, "information1")

                            self.information2 = YLeaf(YType.uint32, "information2")

                            self.messgae_count = YLeaf(YType.uint32, "messgae-count")

                            self.time = YLeaf(YType.str, "time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("information1",
                                            "information2",
                                            "messgae_count",
                                            "time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary.Message, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary.Message, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.information1.is_set or
                                self.information2.is_set or
                                self.messgae_count.is_set or
                                self.time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.information1.yfilter != YFilter.not_set or
                                self.information2.yfilter != YFilter.not_set or
                                self.messgae_count.yfilter != YFilter.not_set or
                                self.time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "message" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.information1.is_set or self.information1.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.information1.get_name_leafdata())
                            if (self.information2.is_set or self.information2.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.information2.get_name_leafdata())
                            if (self.messgae_count.is_set or self.messgae_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.messgae_count.get_name_leafdata())
                            if (self.time.is_set or self.time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "information1" or name == "information2" or name == "messgae-count" or name == "time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "information1"):
                                self.information1 = value
                                self.information1.value_namespace = name_space
                                self.information1.value_namespace_prefix = name_space_prefix
                            if(value_path == "information2"):
                                self.information2 = value
                                self.information2.value_namespace = name_space
                                self.information2.value_namespace_prefix = name_space_prefix
                            if(value_path == "messgae-count"):
                                self.messgae_count = value
                                self.messgae_count.value_namespace = name_space
                                self.messgae_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "time"):
                                self.time = value
                                self.time.value_namespace = name_space
                                self.time.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.message:
                            if (c.has_data()):
                                return True
                        return (
                            self.bd_group_name.is_set or
                            self.bd_name.is_set or
                            self.bridge_domain_id.is_set or
                            self.bridge_domain_name.is_set or
                            self.multicast_update.is_set or
                            self.multicast_update_dropped.is_set or
                            self.number_mroute_all_delete_drop.is_set or
                            self.number_mroute_delete_drop.is_set or
                            self.number_mroute_deleted.is_set or
                            self.number_mroutes_deleted_all.is_set or
                            self.number_of_mroute_add.is_set or
                            self.number_of_routes.is_set or
                            self.number_of_routes_with_ole_offload.is_set or
                            self.number_of_xid.is_set or
                            self.number_xid_add.is_set or
                            self.number_xid_deleted.is_set or
                            self.stale_deleted.is_set or
                            self.stale_xid_deleted.is_set)

                    def has_operation(self):
                        for c in self.message:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bd_group_name.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            self.bridge_domain_id.yfilter != YFilter.not_set or
                            self.bridge_domain_name.yfilter != YFilter.not_set or
                            self.multicast_update.yfilter != YFilter.not_set or
                            self.multicast_update_dropped.yfilter != YFilter.not_set or
                            self.number_mroute_all_delete_drop.yfilter != YFilter.not_set or
                            self.number_mroute_delete_drop.yfilter != YFilter.not_set or
                            self.number_mroute_deleted.yfilter != YFilter.not_set or
                            self.number_mroutes_deleted_all.yfilter != YFilter.not_set or
                            self.number_of_mroute_add.yfilter != YFilter.not_set or
                            self.number_of_routes.yfilter != YFilter.not_set or
                            self.number_of_routes_with_ole_offload.yfilter != YFilter.not_set or
                            self.number_of_xid.yfilter != YFilter.not_set or
                            self.number_xid_add.yfilter != YFilter.not_set or
                            self.number_xid_deleted.yfilter != YFilter.not_set or
                            self.stale_deleted.yfilter != YFilter.not_set or
                            self.stale_xid_deleted.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mmrp-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bd_group_name.is_set or self.bd_group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_group_name.get_name_leafdata())
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())
                        if (self.bridge_domain_id.is_set or self.bridge_domain_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_id.get_name_leafdata())
                        if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                        if (self.multicast_update.is_set or self.multicast_update.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.multicast_update.get_name_leafdata())
                        if (self.multicast_update_dropped.is_set or self.multicast_update_dropped.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.multicast_update_dropped.get_name_leafdata())
                        if (self.number_mroute_all_delete_drop.is_set or self.number_mroute_all_delete_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_mroute_all_delete_drop.get_name_leafdata())
                        if (self.number_mroute_delete_drop.is_set or self.number_mroute_delete_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_mroute_delete_drop.get_name_leafdata())
                        if (self.number_mroute_deleted.is_set or self.number_mroute_deleted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_mroute_deleted.get_name_leafdata())
                        if (self.number_mroutes_deleted_all.is_set or self.number_mroutes_deleted_all.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_mroutes_deleted_all.get_name_leafdata())
                        if (self.number_of_mroute_add.is_set or self.number_of_mroute_add.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_mroute_add.get_name_leafdata())
                        if (self.number_of_routes.is_set or self.number_of_routes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_routes.get_name_leafdata())
                        if (self.number_of_routes_with_ole_offload.is_set or self.number_of_routes_with_ole_offload.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_routes_with_ole_offload.get_name_leafdata())
                        if (self.number_of_xid.is_set or self.number_of_xid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_xid.get_name_leafdata())
                        if (self.number_xid_add.is_set or self.number_xid_add.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_xid_add.get_name_leafdata())
                        if (self.number_xid_deleted.is_set or self.number_xid_deleted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_xid_deleted.get_name_leafdata())
                        if (self.stale_deleted.is_set or self.stale_deleted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.stale_deleted.get_name_leafdata())
                        if (self.stale_xid_deleted.is_set or self.stale_xid_deleted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.stale_xid_deleted.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "message"):
                            for c in self.message:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary.Message()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.message.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "message" or name == "bd-group-name" or name == "bd-name" or name == "bridge-domain-id" or name == "bridge-domain-name" or name == "multicast-update" or name == "multicast-update-dropped" or name == "number-mroute-all-delete-drop" or name == "number-mroute-delete-drop" or name == "number-mroute-deleted" or name == "number-mroutes-deleted-all" or name == "number-of-mroute-add" or name == "number-of-routes" or name == "number-of-routes-with-ole-offload" or name == "number-of-xid" or name == "number-xid-add" or name == "number-xid-deleted" or name == "stale-deleted" or name == "stale-xid-deleted"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bd-group-name"):
                            self.bd_group_name = value
                            self.bd_group_name.value_namespace = name_space
                            self.bd_group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-id"):
                            self.bridge_domain_id = value
                            self.bridge_domain_id.value_namespace = name_space
                            self.bridge_domain_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-name"):
                            self.bridge_domain_name = value
                            self.bridge_domain_name.value_namespace = name_space
                            self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "multicast-update"):
                            self.multicast_update = value
                            self.multicast_update.value_namespace = name_space
                            self.multicast_update.value_namespace_prefix = name_space_prefix
                        if(value_path == "multicast-update-dropped"):
                            self.multicast_update_dropped = value
                            self.multicast_update_dropped.value_namespace = name_space
                            self.multicast_update_dropped.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-mroute-all-delete-drop"):
                            self.number_mroute_all_delete_drop = value
                            self.number_mroute_all_delete_drop.value_namespace = name_space
                            self.number_mroute_all_delete_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-mroute-delete-drop"):
                            self.number_mroute_delete_drop = value
                            self.number_mroute_delete_drop.value_namespace = name_space
                            self.number_mroute_delete_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-mroute-deleted"):
                            self.number_mroute_deleted = value
                            self.number_mroute_deleted.value_namespace = name_space
                            self.number_mroute_deleted.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-mroutes-deleted-all"):
                            self.number_mroutes_deleted_all = value
                            self.number_mroutes_deleted_all.value_namespace = name_space
                            self.number_mroutes_deleted_all.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-mroute-add"):
                            self.number_of_mroute_add = value
                            self.number_of_mroute_add.value_namespace = name_space
                            self.number_of_mroute_add.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-routes"):
                            self.number_of_routes = value
                            self.number_of_routes.value_namespace = name_space
                            self.number_of_routes.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-routes-with-ole-offload"):
                            self.number_of_routes_with_ole_offload = value
                            self.number_of_routes_with_ole_offload.value_namespace = name_space
                            self.number_of_routes_with_ole_offload.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-xid"):
                            self.number_of_xid = value
                            self.number_of_xid.value_namespace = name_space
                            self.number_of_xid.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-xid-add"):
                            self.number_xid_add = value
                            self.number_xid_add.value_namespace = name_space
                            self.number_xid_add.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-xid-deleted"):
                            self.number_xid_deleted = value
                            self.number_xid_deleted.value_namespace = name_space
                            self.number_xid_deleted.value_namespace_prefix = name_space_prefix
                        if(value_path == "stale-deleted"):
                            self.stale_deleted = value
                            self.stale_deleted.value_namespace = name_space
                            self.stale_deleted.value_namespace_prefix = name_space_prefix
                        if(value_path == "stale-xid-deleted"):
                            self.stale_xid_deleted = value
                            self.stale_xid_deleted.value_namespace = name_space
                            self.stale_xid_deleted.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_mmrp_summary:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_mmrp_summary:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-mmrp-summaries" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-mmrp-summary"):
                        for c in self.l2fib_mmrp_summary:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_mmrp_summary.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-mmrp-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibPwGroups(Entity):
                """
                PW Group Table Information
                
                .. attribute:: l2fib_pw_group
                
                	PW Group Information
                	**type**\: list of    :py:class:`L2FibPwGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibPwGroups.L2FibPwGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibPwGroups, self).__init__()

                    self.yang_name = "l2fib-pw-groups"
                    self.yang_parent_name = "node"

                    self.l2fib_pw_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibPwGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibPwGroups, self).__setattr__(name, value)


                class L2FibPwGroup(Entity):
                    """
                    PW Group Information
                    
                    .. attribute:: group_id
                    
                    	Group Id
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: group_state
                    
                    	Group State
                    	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                    
                    .. attribute:: peer_address
                    
                    	Peer IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pw_list_count
                    
                    	Dependent PW List Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_if_handle
                    
                    	Tunnel Interface Handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibPwGroups.L2FibPwGroup, self).__init__()

                        self.yang_name = "l2fib-pw-group"
                        self.yang_parent_name = "l2fib-pw-groups"

                        self.group_id = YLeaf(YType.int32, "group-id")

                        self.group_state = YLeaf(YType.enumeration, "group-state")

                        self.peer_address = YLeaf(YType.str, "peer-address")

                        self.pw_list_count = YLeaf(YType.uint32, "pw-list-count")

                        self.tunnel_if_handle = YLeaf(YType.int32, "tunnel-if-handle")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_id",
                                        "group_state",
                                        "peer_address",
                                        "pw_list_count",
                                        "tunnel_if_handle") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibPwGroups.L2FibPwGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibPwGroups.L2FibPwGroup, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.group_id.is_set or
                            self.group_state.is_set or
                            self.peer_address.is_set or
                            self.pw_list_count.is_set or
                            self.tunnel_if_handle.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_id.yfilter != YFilter.not_set or
                            self.group_state.yfilter != YFilter.not_set or
                            self.peer_address.yfilter != YFilter.not_set or
                            self.pw_list_count.yfilter != YFilter.not_set or
                            self.tunnel_if_handle.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-pw-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_id.get_name_leafdata())
                        if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_state.get_name_leafdata())
                        if (self.peer_address.is_set or self.peer_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.peer_address.get_name_leafdata())
                        if (self.pw_list_count.is_set or self.pw_list_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_list_count.get_name_leafdata())
                        if (self.tunnel_if_handle.is_set or self.tunnel_if_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_if_handle.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-id" or name == "group-state" or name == "peer-address" or name == "pw-list-count" or name == "tunnel-if-handle"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-id"):
                            self.group_id = value
                            self.group_id.value_namespace = name_space
                            self.group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-state"):
                            self.group_state = value
                            self.group_state.value_namespace = name_space
                            self.group_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "peer-address"):
                            self.peer_address = value
                            self.peer_address.value_namespace = name_space
                            self.peer_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-list-count"):
                            self.pw_list_count = value
                            self.pw_list_count.value_namespace = name_space
                            self.pw_list_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "tunnel-if-handle"):
                            self.tunnel_if_handle = value
                            self.tunnel_if_handle.value_namespace = name_space
                            self.tunnel_if_handle.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_pw_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_pw_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-pw-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-pw-group"):
                        for c in self.l2fib_pw_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibPwGroups.L2FibPwGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_pw_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-pw-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibEvpnInclMCastHardwareIngresses(Entity):
                """
                L2VPN forwarding bridge\-domain evpn inclusive
                multicast hardware ingress Table
                
                .. attribute:: l2fib_evpn_incl_m_cast_hardware_ingress
                
                	Specify bridge domain name
                	**type**\: list of    :py:class:`L2FibEvpnInclMCastHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses, self).__init__()

                    self.yang_name = "l2fib-evpn-incl-m-cast-hardware-ingresses"
                    self.yang_parent_name = "node"

                    self.l2fib_evpn_incl_m_cast_hardware_ingress = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses, self).__setattr__(name, value)


                class L2FibEvpnInclMCastHardwareIngress(Entity):
                    """
                    Specify bridge domain name
                    
                    .. attribute:: bd_name  <key>
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: l2fib_evpn_incl_m_cast_oles
                    
                    	EVPN ingress mcast ole Information
                    	**type**\:   :py:class:`L2FibEvpnInclMCastOles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles>`
                    
                    .. attribute:: mcast_replication_list
                    
                    	Information of pbb\-evpn/evpn ingress mcast replication list for a particular bridge domain
                    	**type**\:   :py:class:`McastReplicationList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.McastReplicationList>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress, self).__init__()

                        self.yang_name = "l2fib-evpn-incl-m-cast-hardware-ingress"
                        self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-ingresses"

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.l2fib_evpn_incl_m_cast_oles = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles()
                        self.l2fib_evpn_incl_m_cast_oles.parent = self
                        self._children_name_map["l2fib_evpn_incl_m_cast_oles"] = "l2fib-evpn-incl-m-cast-oles"
                        self._children_yang_names.add("l2fib-evpn-incl-m-cast-oles")

                        self.mcast_replication_list = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.McastReplicationList()
                        self.mcast_replication_list.parent = self
                        self._children_name_map["mcast_replication_list"] = "mcast-replication-list"
                        self._children_yang_names.add("mcast-replication-list")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bd_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress, self).__setattr__(name, value)


                    class McastReplicationList(Entity):
                        """
                        Information of pbb\-evpn/evpn ingress mcast
                        replication list for a particular bridge domain
                        
                        .. attribute:: bridge_domain_id
                        
                        	bdid value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_domain_name
                        
                        	Bridge\-domain name
                        	**type**\:  str
                        
                        .. attribute:: is_bound
                        
                        	Is bound
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.McastReplicationList, self).__init__()

                            self.yang_name = "mcast-replication-list"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-ingress"

                            self.bridge_domain_id = YLeaf(YType.uint32, "bridge-domain-id")

                            self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                            self.is_bound = YLeaf(YType.boolean, "is-bound")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bridge_domain_id",
                                            "bridge_domain_name",
                                            "is_bound") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.McastReplicationList, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.McastReplicationList, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bridge_domain_id.is_set or
                                self.bridge_domain_name.is_set or
                                self.is_bound.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bridge_domain_id.yfilter != YFilter.not_set or
                                self.bridge_domain_name.yfilter != YFilter.not_set or
                                self.is_bound.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mcast-replication-list" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bridge_domain_id.is_set or self.bridge_domain_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_domain_id.get_name_leafdata())
                            if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                            if (self.is_bound.is_set or self.is_bound.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bound.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-domain-id" or name == "bridge-domain-name" or name == "is-bound"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bridge-domain-id"):
                                self.bridge_domain_id = value
                                self.bridge_domain_id.value_namespace = name_space
                                self.bridge_domain_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-domain-name"):
                                self.bridge_domain_name = value
                                self.bridge_domain_name.value_namespace = name_space
                                self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bound"):
                                self.is_bound = value
                                self.is_bound.value_namespace = name_space
                                self.is_bound.value_namespace_prefix = name_space_prefix


                    class L2FibEvpnInclMCastOles(Entity):
                        """
                        EVPN ingress mcast ole Information
                        
                        .. attribute:: l2fib_evpn_incl_m_cast_ole
                        
                        	Information on a particular output path of the pbb\-evpn/evpn ingress replication list
                        	**type**\: list of    :py:class:`L2FibEvpnInclMCastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles, self).__init__()

                            self.yang_name = "l2fib-evpn-incl-m-cast-oles"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-ingress"

                            self.l2fib_evpn_incl_m_cast_ole = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles, self).__setattr__(name, value)


                        class L2FibEvpnInclMCastOle(Entity):
                            """
                            Information on a particular output path of the
                            pbb\-evpn/evpn ingress replication list
                            
                            .. attribute:: next_hop_address  <key>
                            
                            	Next Hop Address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_bound
                            
                            	Is bound
                            	**type**\:  bool
                            
                            .. attribute:: mcast_ole
                            
                            	Mcast Ole Info
                            	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle, self).__init__()

                                self.yang_name = "l2fib-evpn-incl-m-cast-ole"
                                self.yang_parent_name = "l2fib-evpn-incl-m-cast-oles"

                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                self.is_bound = YLeaf(YType.boolean, "is-bound")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle()
                                self.mcast_ole.parent = self
                                self._children_name_map["mcast_ole"] = "mcast-ole"
                                self._children_yang_names.add("mcast-ole")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("next_hop_address",
                                                "is_bound",
                                                "next_hop_valid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle, self).__setattr__(name, value)


                            class McastOle(Entity):
                                """
                                Mcast Ole Info
                                
                                .. attribute:: mcast_label
                                
                                	Inclusive mcast label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ipv6_addr
                                
                                	Next Hop IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle, self).__init__()

                                    self.yang_name = "mcast-ole"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"

                                    self.mcast_label = YLeaf(YType.uint32, "mcast-label")

                                    self.next_hop_ipv6_addr = YLeaf(YType.str, "next-hop-ipv6-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mcast_label",
                                                    "next_hop_ipv6_addr") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.mcast_label.is_set or
                                        self.next_hop_ipv6_addr.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mcast_label.yfilter != YFilter.not_set or
                                        self.next_hop_ipv6_addr.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mcast-ole" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mcast_label.is_set or self.mcast_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mcast_label.get_name_leafdata())
                                    if (self.next_hop_ipv6_addr.is_set or self.next_hop_ipv6_addr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ipv6_addr.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mcast-label" or name == "next-hop-ipv6-addr"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mcast-label"):
                                        self.mcast_label = value
                                        self.mcast_label.value_namespace = name_space
                                        self.mcast_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ipv6-addr"):
                                        self.next_hop_ipv6_addr = value
                                        self.next_hop_ipv6_addr.value_namespace = name_space
                                        self.next_hop_ipv6_addr.value_namespace_prefix = name_space_prefix


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.next_hop_address.is_set or
                                    self.is_bound.is_set or
                                    self.next_hop_valid.is_set or
                                    (self.mcast_ole is not None and self.mcast_ole.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.next_hop_address.yfilter != YFilter.not_set or
                                    self.is_bound.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    (self.mcast_ole is not None and self.mcast_ole.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2fib-evpn-incl-m-cast-ole" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                if (self.is_bound.is_set or self.is_bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_bound.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mcast-ole"):
                                    if (self.mcast_ole is None):
                                        self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle()
                                        self.mcast_ole.parent = self
                                        self._children_name_map["mcast_ole"] = "mcast-ole"
                                    return self.mcast_ole

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mcast-ole" or name == "next-hop" or name == "next-hop-address" or name == "is-bound" or name == "next-hop-valid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "next-hop-address"):
                                    self.next_hop_address = value
                                    self.next_hop_address.value_namespace = name_space
                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-bound"):
                                    self.is_bound = value
                                    self.is_bound.value_namespace = name_space
                                    self.is_bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.l2fib_evpn_incl_m_cast_ole:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.l2fib_evpn_incl_m_cast_ole:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-evpn-incl-m-cast-oles" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "l2fib-evpn-incl-m-cast-ole"):
                                for c in self.l2fib_evpn_incl_m_cast_ole:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.l2fib_evpn_incl_m_cast_ole.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "l2fib-evpn-incl-m-cast-ole"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.bd_name.is_set or
                            (self.l2fib_evpn_incl_m_cast_oles is not None and self.l2fib_evpn_incl_m_cast_oles.has_data()) or
                            (self.mcast_replication_list is not None and self.mcast_replication_list.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            (self.l2fib_evpn_incl_m_cast_oles is not None and self.l2fib_evpn_incl_m_cast_oles.has_operation()) or
                            (self.mcast_replication_list is not None and self.mcast_replication_list.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-evpn-incl-m-cast-hardware-ingress" + "[bd-name='" + self.bd_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2fib-evpn-incl-m-cast-oles"):
                            if (self.l2fib_evpn_incl_m_cast_oles is None):
                                self.l2fib_evpn_incl_m_cast_oles = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles()
                                self.l2fib_evpn_incl_m_cast_oles.parent = self
                                self._children_name_map["l2fib_evpn_incl_m_cast_oles"] = "l2fib-evpn-incl-m-cast-oles"
                            return self.l2fib_evpn_incl_m_cast_oles

                        if (child_yang_name == "mcast-replication-list"):
                            if (self.mcast_replication_list is None):
                                self.mcast_replication_list = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.McastReplicationList()
                                self.mcast_replication_list.parent = self
                                self._children_name_map["mcast_replication_list"] = "mcast-replication-list"
                            return self.mcast_replication_list

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2fib-evpn-incl-m-cast-oles" or name == "mcast-replication-list" or name == "bd-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_evpn_incl_m_cast_hardware_ingress:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_evpn_incl_m_cast_hardware_ingress:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-evpn-incl-m-cast-hardware-ingresses" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-evpn-incl-m-cast-hardware-ingress"):
                        for c in self.l2fib_evpn_incl_m_cast_hardware_ingress:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_evpn_incl_m_cast_hardware_ingress.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-evpn-incl-m-cast-hardware-ingress"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibDhcpBindingDetails(Entity):
                """
                DHCP binding forwarding detail
                
                .. attribute:: l2fib_dhcp_binding_detail
                
                	Specify DHCP binding detail
                	**type**\: list of    :py:class:`L2FibDhcpBindingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails, self).__init__()

                    self.yang_name = "l2fib-dhcp-binding-details"
                    self.yang_parent_name = "node"

                    self.l2fib_dhcp_binding_detail = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails, self).__setattr__(name, value)


                class L2FibDhcpBindingDetail(Entity):
                    """
                    Specify DHCP binding detail
                    
                    .. attribute:: address
                    
                    	MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Base>`
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor IPv4 address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: port
                    
                    	Union of Port information
                    	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port>`
                    
                    .. attribute:: xcid
                    
                    	XConnect ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail, self).__init__()

                        self.yang_name = "l2fib-dhcp-binding-detail"
                        self.yang_parent_name = "l2fib-dhcp-binding-details"

                        self.address = YLeaf(YType.str, "address")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.xcid = YLeaf(YType.str, "xcid")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                        self.port = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"
                        self._children_yang_names.add("port")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "neighbor_address",
                                        "xcid") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fib-dhcp-binding-detail"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Port(Entity):
                        """
                        Union of Port information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "l2fib-dhcp-binding-detail"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "port"

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Ac, self).__setattr__(name, value)

                            def has_data(self):
                                return self.interface_handle.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "port"

                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("next_hop_address",
                                                "pseudo_wire_id_type",
                                                "pw_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Pw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.next_hop_address.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.next_hop_address.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "pseudo-wire-id-type" or name == "pw-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "next-hop-address"):
                                    self.next_hop_address = value
                                    self.next_hop_address.value_namespace = name_space
                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.pw is not None and self.pw.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "port" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "pw" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.neighbor_address.is_set or
                            self.xcid.is_set or
                            (self.base is not None and self.base.has_data()) or
                            (self.port is not None and self.port.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.neighbor_address.yfilter != YFilter.not_set or
                            self.xcid.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()) or
                            (self.port is not None and self.port.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-dhcp-binding-detail" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                        if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xcid.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        if (child_yang_name == "port"):
                            if (self.port is None):
                                self.port = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                            return self.port

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "port" or name == "address" or name == "neighbor-address" or name == "xcid"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-address"):
                            self.neighbor_address = value
                            self.neighbor_address.value_namespace = name_space
                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "xcid"):
                            self.xcid = value
                            self.xcid.value_namespace = name_space
                            self.xcid.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_dhcp_binding_detail:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_dhcp_binding_detail:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-dhcp-binding-details" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-dhcp-binding-detail"):
                        for c in self.l2fib_dhcp_binding_detail:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_dhcp_binding_detail.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-dhcp-binding-detail"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibxCons(Entity):
                """
                The L2VPN forwarding XConnect Detail Table
                
                .. attribute:: l2fibx_con
                
                	Specify XConnect ID
                	**type**\: list of    :py:class:`L2FibxCon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibxCons, self).__init__()

                    self.yang_name = "l2fibx-cons"
                    self.yang_parent_name = "node"

                    self.l2fibx_con = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibxCons, self).__setattr__(name, value)


                class L2FibxCon(Entity):
                    """
                    Specify XConnect ID
                    
                    .. attribute:: xcid  <key>
                    
                    	XC ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Base>`
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\:  bool
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2>`
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:   :py:class:`MgmtL2FibSwitching <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibSwitching>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\:  str
                    
                    	**length:** 0..72
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon, self).__init__()

                        self.yang_name = "l2fibx-con"
                        self.yang_parent_name = "l2fibx-cons"

                        self.xcid = YLeaf(YType.str, "xcid")

                        self.bound = YLeaf(YType.boolean, "bound")

                        self.switching_type = YLeaf(YType.enumeration, "switching-type")

                        self.xcon_name = YLeaf(YType.str, "xcon-name")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                        self.segment1 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"
                        self._children_yang_names.add("segment1")

                        self.segment2 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"
                        self._children_yang_names.add("segment2")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("xcid",
                                        "bound",
                                        "switching_type",
                                        "xcon_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibx-con"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Segment1(Entity):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:   :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1, self).__init__()

                            self.yang_name = "segment1"
                            self.yang_parent_name = "l2fibx-con"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"
                            self._children_yang_names.add("evpn")

                            self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self._children_name_map["monitor_session"] = "monitor-session"
                            self._children_yang_names.add("monitor-session")

                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"
                            self._children_yang_names.add("pbb")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                            self.vni = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"
                            self._children_yang_names.add("vni")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment1"

                                self.actype = YLeaf(YType.uint8, "actype")

                                self.adjacency_address = YLeaf(YType.str, "adjacency-address")

                                self.adjacency_valid = YLeaf(YType.boolean, "adjacency-valid")

                                self.attachment_circuit_id = YLeaf(YType.uint32, "attachment-circuit-id")

                                self.attachment_circuit_mtu = YLeaf(YType.uint16, "attachment-circuit-mtu")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.fxc_next_hop_valid = YLeaf(YType.boolean, "fxc-next-hop-valid")

                                self.inter_working_mode = YLeaf(YType.uint8, "inter-working-mode")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.ip_inter_working_mac = YLeaf(YType.str, "ip-inter-working-mac")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.sub_interface_handle = YLeaf(YType.str, "sub-interface-handle")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._children_yang_names.add("fxc-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actype",
                                                "adjacency_address",
                                                "adjacency_valid",
                                                "attachment_circuit_id",
                                                "attachment_circuit_mtu",
                                                "bound",
                                                "evpn_internal_label",
                                                "fxc_next_hop_valid",
                                                "inter_working_mode",
                                                "interface_handle",
                                                "ip_inter_working_mac",
                                                "redundancy_group_id",
                                                "redundancy_object_id",
                                                "sub_interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fxc-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.actype.is_set or
                                    self.adjacency_address.is_set or
                                    self.adjacency_valid.is_set or
                                    self.attachment_circuit_id.is_set or
                                    self.attachment_circuit_mtu.is_set or
                                    self.bound.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.fxc_next_hop_valid.is_set or
                                    self.inter_working_mode.is_set or
                                    self.interface_handle.is_set or
                                    self.ip_inter_working_mac.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.sub_interface_handle.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actype.yfilter != YFilter.not_set or
                                    self.adjacency_address.yfilter != YFilter.not_set or
                                    self.adjacency_valid.yfilter != YFilter.not_set or
                                    self.attachment_circuit_id.yfilter != YFilter.not_set or
                                    self.attachment_circuit_mtu.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.fxc_next_hop_valid.yfilter != YFilter.not_set or
                                    self.inter_working_mode.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.ip_inter_working_mac.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.sub_interface_handle.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actype.is_set or self.actype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actype.get_name_leafdata())
                                if (self.adjacency_address.is_set or self.adjacency_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_address.get_name_leafdata())
                                if (self.adjacency_valid.is_set or self.adjacency_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_valid.get_name_leafdata())
                                if (self.attachment_circuit_id.is_set or self.attachment_circuit_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_id.get_name_leafdata())
                                if (self.attachment_circuit_mtu.is_set or self.attachment_circuit_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_mtu.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.fxc_next_hop_valid.is_set or self.fxc_next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxc_next_hop_valid.get_name_leafdata())
                                if (self.inter_working_mode.is_set or self.inter_working_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_working_mode.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.ip_inter_working_mac.is_set or self.ip_inter_working_mac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_inter_working_mac.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.sub_interface_handle.is_set or self.sub_interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "fxc-next-hop"):
                                    if (self.fxc_next_hop is None):
                                        self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop()
                                        self.fxc_next_hop.parent = self
                                        self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                    return self.fxc_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxc-next-hop" or name == "actype" or name == "adjacency-address" or name == "adjacency-valid" or name == "attachment-circuit-id" or name == "attachment-circuit-mtu" or name == "bound" or name == "evpn-internal-label" or name == "fxc-next-hop-valid" or name == "inter-working-mode" or name == "interface-handle" or name == "ip-inter-working-mac" or name == "redundancy-group-id" or name == "redundancy-object-id" or name == "sub-interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actype"):
                                    self.actype = value
                                    self.actype.value_namespace = name_space
                                    self.actype.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-address"):
                                    self.adjacency_address = value
                                    self.adjacency_address.value_namespace = name_space
                                    self.adjacency_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-valid"):
                                    self.adjacency_valid = value
                                    self.adjacency_valid.value_namespace = name_space
                                    self.adjacency_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-id"):
                                    self.attachment_circuit_id = value
                                    self.attachment_circuit_id.value_namespace = name_space
                                    self.attachment_circuit_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-mtu"):
                                    self.attachment_circuit_mtu = value
                                    self.attachment_circuit_mtu.value_namespace = name_space
                                    self.attachment_circuit_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "fxc-next-hop-valid"):
                                    self.fxc_next_hop_valid = value
                                    self.fxc_next_hop_valid.value_namespace = name_space
                                    self.fxc_next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-working-mode"):
                                    self.inter_working_mode = value
                                    self.inter_working_mode.value_namespace = name_space
                                    self.inter_working_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip-inter-working-mac"):
                                    self.ip_inter_working_mac = value
                                    self.ip_inter_working_mac.value_namespace = name_space
                                    self.ip_inter_working_mac.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-interface-handle"):
                                    self.sub_interface_handle = value
                                    self.sub_interface_handle.value_namespace = name_space
                                    self.sub_interface_handle.value_namespace_prefix = name_space_prefix


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:   :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.core_pbb_evpn_enabled = YLeaf(YType.boolean, "core-pbb-evpn-enabled")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self
                                self._children_name_map["pbb_union"] = "pbb-union"
                                self._children_yang_names.add("pbb-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "core_pbb_evpn_enabled",
                                                "forward_class") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pbb"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class PbbUnion(Entity):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:   :py:class:`MgmtL2FibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridge>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion, self).__init__()

                                    self.yang_name = "pbb-union"
                                    self.yang_parent_name = "pbb"

                                    self.pbb_type = YLeaf(YType.enumeration, "pbb-type")

                                    self.core = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                    self._children_yang_names.add("core")

                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"
                                    self._children_yang_names.add("edge")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pbb_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion, self).__setattr__(name, value)


                                class Edge(Entity):
                                    """
                                    edge
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Edge, self).__init__()

                                        self.yang_name = "edge"
                                        self.yang_parent_name = "pbb-union"

                                        self.mac = YLeaf(YType.str, "mac")

                                        self.mac_configured = YLeaf(YType.boolean, "mac-configured")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mac",
                                                        "mac_configured") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Edge, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Edge, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mac.is_set or
                                            self.mac_configured.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mac.yfilter != YFilter.not_set or
                                            self.mac_configured.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "edge" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mac.is_set or self.mac.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac.get_name_leafdata())
                                        if (self.mac_configured.is_set or self.mac_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_configured.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mac" or name == "mac-configured"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mac"):
                                            self.mac = value
                                            self.mac.value_namespace = name_space
                                            self.mac.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-configured"):
                                            self.mac_configured = value
                                            self.mac_configured.value_namespace = name_space
                                            self.mac_configured.value_namespace_prefix = name_space_prefix


                                class Core(Entity):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Core, self).__init__()

                                        self.yang_name = "core"
                                        self.yang_parent_name = "pbb-union"

                                        self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vlan_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Core, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Core, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.vlan_id.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vlan_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "core" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vlan-id"):
                                            self.vlan_id = value
                                            self.vlan_id.value_namespace = name_space
                                            self.vlan_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.pbb_type.is_set or
                                        (self.core is not None and self.core.has_data()) or
                                        (self.edge is not None and self.edge.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pbb_type.yfilter != YFilter.not_set or
                                        (self.core is not None and self.core.has_operation()) or
                                        (self.edge is not None and self.edge.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pbb-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pbb_type.is_set or self.pbb_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pbb_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "core"):
                                        if (self.core is None):
                                            self.core = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Core()
                                            self.core.parent = self
                                            self._children_name_map["core"] = "core"
                                        return self.core

                                    if (child_yang_name == "edge"):
                                        if (self.edge is None):
                                            self.edge = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Edge()
                                            self.edge.parent = self
                                            self._children_name_map["edge"] = "edge"
                                        return self.edge

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "core" or name == "edge" or name == "pbb-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pbb-type"):
                                        self.pbb_type = value
                                        self.pbb_type.value_namespace = name_space
                                        self.pbb_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.core_pbb_evpn_enabled.is_set or
                                    self.forward_class.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.pbb_union is not None and self.pbb_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.core_pbb_evpn_enabled.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.pbb_union is not None and self.pbb_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.core_pbb_evpn_enabled.is_set or self.core_pbb_evpn_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_pbb_evpn_enabled.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "pbb-union"):
                                    if (self.pbb_union is None):
                                        self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion()
                                        self.pbb_union.parent = self
                                        self._children_name_map["pbb_union"] = "pbb-union"
                                    return self.pbb_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "pbb-union" or name == "bound" or name == "core-pbb-evpn-enabled" or name == "forward-class"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "core-pbb-evpn-enabled"):
                                    self.core_pbb_evpn_enabled = value
                                    self.core_pbb_evpn_enabled.value_namespace = name_space
                                    self.core_pbb_evpn_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment1"

                                self.any_cast_ip = YLeaf(YType.str, "any-cast-ip")

                                self.anycast_mcast_ip = YLeaf(YType.str, "anycast-mcast-ip")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.encap = YLeaf(YType.uint32, "encap")

                                self.mcastip = YLeaf(YType.str, "mcastip")

                                self.parent_if = YLeaf(YType.str, "parent-if")

                                self.source_vtep_if = YLeaf(YType.str, "source-vtep-if")

                                self.srcip = YLeaf(YType.str, "srcip")

                                self.udp_port = YLeaf(YType.uint32, "udp-port")

                                self.vx_lan_mode = YLeaf(YType.uint32, "vx-lan-mode")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("any_cast_ip",
                                                "anycast_mcast_ip",
                                                "bound",
                                                "encap",
                                                "mcastip",
                                                "parent_if",
                                                "source_vtep_if",
                                                "srcip",
                                                "udp_port",
                                                "vx_lan_mode") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "vni"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.any_cast_ip.is_set or
                                    self.anycast_mcast_ip.is_set or
                                    self.bound.is_set or
                                    self.encap.is_set or
                                    self.mcastip.is_set or
                                    self.parent_if.is_set or
                                    self.source_vtep_if.is_set or
                                    self.srcip.is_set or
                                    self.udp_port.is_set or
                                    self.vx_lan_mode.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.any_cast_ip.yfilter != YFilter.not_set or
                                    self.anycast_mcast_ip.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.encap.yfilter != YFilter.not_set or
                                    self.mcastip.yfilter != YFilter.not_set or
                                    self.parent_if.yfilter != YFilter.not_set or
                                    self.source_vtep_if.yfilter != YFilter.not_set or
                                    self.srcip.yfilter != YFilter.not_set or
                                    self.udp_port.yfilter != YFilter.not_set or
                                    self.vx_lan_mode.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vni" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.any_cast_ip.is_set or self.any_cast_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.any_cast_ip.get_name_leafdata())
                                if (self.anycast_mcast_ip.is_set or self.anycast_mcast_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.anycast_mcast_ip.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.encap.is_set or self.encap.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encap.get_name_leafdata())
                                if (self.mcastip.is_set or self.mcastip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mcastip.get_name_leafdata())
                                if (self.parent_if.is_set or self.parent_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_if.get_name_leafdata())
                                if (self.source_vtep_if.is_set or self.source_vtep_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_vtep_if.get_name_leafdata())
                                if (self.srcip.is_set or self.srcip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.srcip.get_name_leafdata())
                                if (self.udp_port.is_set or self.udp_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.udp_port.get_name_leafdata())
                                if (self.vx_lan_mode.is_set or self.vx_lan_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vx_lan_mode.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "any-cast-ip" or name == "anycast-mcast-ip" or name == "bound" or name == "encap" or name == "mcastip" or name == "parent-if" or name == "source-vtep-if" or name == "srcip" or name == "udp-port" or name == "vx-lan-mode"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "any-cast-ip"):
                                    self.any_cast_ip = value
                                    self.any_cast_ip.value_namespace = name_space
                                    self.any_cast_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "anycast-mcast-ip"):
                                    self.anycast_mcast_ip = value
                                    self.anycast_mcast_ip.value_namespace = name_space
                                    self.anycast_mcast_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "encap"):
                                    self.encap = value
                                    self.encap.value_namespace = name_space
                                    self.encap.value_namespace_prefix = name_space_prefix
                                if(value_path == "mcastip"):
                                    self.mcastip = value
                                    self.mcastip.value_namespace = name_space
                                    self.mcastip.value_namespace_prefix = name_space_prefix
                                if(value_path == "parent-if"):
                                    self.parent_if = value
                                    self.parent_if.value_namespace = name_space
                                    self.parent_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-vtep-if"):
                                    self.source_vtep_if = value
                                    self.source_vtep_if.value_namespace = name_space
                                    self.source_vtep_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "srcip"):
                                    self.srcip = value
                                    self.srcip.value_namespace = name_space
                                    self.srcip.value_namespace_prefix = name_space_prefix
                                if(value_path == "udp-port"):
                                    self.udp_port = value
                                    self.udp_port.value_namespace = name_space
                                    self.udp_port.value_namespace_prefix = name_space_prefix
                                if(value_path == "vx-lan-mode"):
                                    self.vx_lan_mode = value
                                    self.vx_lan_mode.value_namespace = name_space
                                    self.vx_lan_mode.value_namespace_prefix = name_space_prefix


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evi = YLeaf(YType.uint32, "evi")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "evi",
                                                "forward_class") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "evpn"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.evi.is_set or
                                    self.forward_class.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evi.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evi.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "bound" or name == "evi" or name == "forward-class"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evi"):
                                    self.evi = value
                                    self.evi.value_namespace = name_space
                                    self.evi.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix


                        class MonitorSession(Entity):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\:  str
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession, self).__init__()

                                self.yang_name = "monitor-session"
                                self.yang_parent_name = "segment1"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.hardware_information = YLeaf(YType.str, "hardware-information")

                                self.session_name = YLeaf(YType.str, "session-name")

                                self.xcid = YLeaf(YType.uint32, "xcid")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "hardware_information",
                                                "session_name",
                                                "xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "monitor-session"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.hardware_information.is_set or
                                    self.session_name.is_set or
                                    self.xcid.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.hardware_information.yfilter != YFilter.not_set or
                                    self.session_name.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "monitor-session" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.hardware_information.is_set or self.hardware_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.hardware_information.get_name_leafdata())
                                if (self.session_name.is_set or self.session_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.session_name.get_name_leafdata())
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "bound" or name == "hardware-information" or name == "session-name" or name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "hardware-information"):
                                    self.hardware_information = value
                                    self.hardware_information.value_namespace = name_space
                                    self.hardware_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "session-name"):
                                    self.session_name = value
                                    self.session_name.value_namespace = name_space
                                    self.session_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBal>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment1"

                                self.ac_id = YLeaf(YType.uint32, "ac-id")

                                self.active = YLeaf(YType.boolean, "active")

                                self.backup_configured = YLeaf(YType.boolean, "backup-configured")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.context = YLeaf(YType.uint16, "context")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.global_id = YLeaf(YType.uint32, "global-id")

                                self.group_id = YLeaf(YType.uint32, "group-id")

                                self.group_state = YLeaf(YType.enumeration, "group-state")

                                self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                                self.pw_load_balance_type = YLeaf(YType.enumeration, "pw-load-balance-type")

                                self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                self.sequence_resync_threshold = YLeaf(YType.uint16, "sequence-resync-threshold")

                                self.signal_capability_flags = YLeaf(YType.uint32, "signal-capability-flags")

                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._children_yang_names.add("backup-pseudo-wire")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                self._children_yang_names.add("pseudo-wire-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ac_id",
                                                "active",
                                                "backup_configured",
                                                "bound",
                                                "context",
                                                "forward_class",
                                                "global_id",
                                                "group_id",
                                                "group_state",
                                                "grouping_supported",
                                                "next_hop_valid",
                                                "pseudo_wire_id_type",
                                                "pw_flow_label_tx",
                                                "pw_id",
                                                "pw_load_balance_type",
                                                "redundancy_role",
                                                "sequence_resync_threshold",
                                                "signal_capability_flags") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"
                                    self._children_yang_names.add("l2tp")

                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._children_yang_names.add("l2tp-ipv6-ts")

                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"
                                    self._children_yang_names.add("l2tpv2")

                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"
                                    self._children_yang_names.add("mpls")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion, self).__setattr__(name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix


                                class L2Tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_mtu",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_mtu.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "path-mtu" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix


                                class L2Tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.protocol = YLeaf(YType.uint16, "protocol")

                                        self.pw_flags = YLeaf(YType.uint8, "pw-flags")

                                        self.rem_udp_port = YLeaf(YType.uint16, "rem-udp-port")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop_address",
                                                        "path_mtu",
                                                        "protocol",
                                                        "pw_flags",
                                                        "rem_udp_port",
                                                        "source_address",
                                                        "tos_val",
                                                        "ttl",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.next_hop_address.is_set or
                                            self.path_mtu.is_set or
                                            self.protocol.is_set or
                                            self.pw_flags.is_set or
                                            self.rem_udp_port.is_set or
                                            self.source_address.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            self.xconnect_id.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pw_flags.yfilter != YFilter.not_set or
                                            self.rem_udp_port.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv2" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pw_flags.is_set or self.pw_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flags.get_name_leafdata())
                                        if (self.rem_udp_port.is_set or self.rem_udp_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_udp_port.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "next-hop-address" or name == "path-mtu" or name == "protocol" or name == "pw-flags" or name == "rem-udp-port" or name == "source-address" or name == "tos-val" or name == "ttl" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop-address"):
                                            self.next_hop_address = value
                                            self.next_hop_address.value_namespace = name_space
                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flags"):
                                            self.pw_flags = value
                                            self.pw_flags.value_namespace = name_space
                                            self.pw_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-udp-port"):
                                            self.rem_udp_port = value
                                            self.rem_udp_port.value_namespace = name_space
                                            self.rem_udp_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class L2TpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address",
                                                        "path_mtu",
                                                        "remote_address",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.secondary_cookie_high_value = YLeaf(YType.uint32, "secondary-cookie-high-value")

                                            self.secondary_cookie_low_value = YLeaf(YType.uint32, "secondary-cookie-low-value")

                                            self.secondary_cookie_size = YLeaf(YType.uint8, "secondary-cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "secondary_cookie_high_value",
                                                            "secondary_cookie_low_value",
                                                            "secondary_cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.secondary_cookie_high_value.is_set or
                                                self.secondary_cookie_low_value.is_set or
                                                self.secondary_cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.secondary_cookie_high_value.is_set or self.secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_high_value.get_name_leafdata())
                                            if (self.secondary_cookie_low_value.is_set or self.secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_low_value.get_name_leafdata())
                                            if (self.secondary_cookie_size.is_set or self.secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "secondary-cookie-high-value" or name == "secondary-cookie-low-value" or name == "secondary-cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-high-value"):
                                                self.secondary_cookie_high_value = value
                                                self.secondary_cookie_high_value.value_namespace = name_space
                                                self.secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-low-value"):
                                                self.secondary_cookie_low_value = value
                                                self.secondary_cookie_low_value.value_namespace = name_space
                                                self.secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-size"):
                                                self.secondary_cookie_size = value
                                                self.secondary_cookie_size.value_namespace = name_space
                                                self.secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.local_address.is_set or
                                            self.path_mtu.is_set or
                                            self.remote_address.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp-ipv6-ts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "local-address" or name == "path-mtu" or name == "remote-address" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        (self.l2tp is not None and self.l2tp.has_data()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_data()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_data()) or
                                        (self.mpls is not None and self.mpls.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        (self.l2tp is not None and self.l2tp.has_operation()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_operation()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_operation()) or
                                        (self.mpls is not None and self.mpls.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudo-wire-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2tp"):
                                        if (self.l2tp is None):
                                            self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp()
                                            self.l2tp.parent = self
                                            self._children_name_map["l2tp"] = "l2tp"
                                        return self.l2tp

                                    if (child_yang_name == "l2tp-ipv6-ts"):
                                        if (self.l2tp_ipv6_ts is None):
                                            self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                            self.l2tp_ipv6_ts.parent = self
                                            self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                        return self.l2tp_ipv6_ts

                                    if (child_yang_name == "l2tpv2"):
                                        if (self.l2tpv2 is None):
                                            self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                            self.l2tpv2.parent = self
                                            self._children_name_map["l2tpv2"] = "l2tpv2"
                                        return self.l2tpv2

                                    if (child_yang_name == "mpls"):
                                        if (self.mpls is None):
                                            self.mpls = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                        return self.mpls

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2tp" or name == "l2tp-ipv6-ts" or name == "l2tpv2" or name == "mpls" or name == "data-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.backup_next_hop = YLeaf(YType.str, "backup-next-hop")

                                    self.backup_pseudo_wire_id = YLeaf(YType.uint32, "backup-pseudo-wire-id")

                                    self.backup_pseudo_wire_id_type = YLeaf(YType.enumeration, "backup-pseudo-wire-id-type")

                                    self.bound = YLeaf(YType.boolean, "bound")

                                    self.group_id = YLeaf(YType.uint32, "group-id")

                                    self.group_state = YLeaf(YType.enumeration, "group-state")

                                    self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                    self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                    self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "backup_next_hop",
                                                    "backup_pseudo_wire_id",
                                                    "backup_pseudo_wire_id_type",
                                                    "bound",
                                                    "group_id",
                                                    "group_state",
                                                    "grouping_supported",
                                                    "pw_flow_label_tx",
                                                    "redundancy_role") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.backup_next_hop.is_set or
                                        self.backup_pseudo_wire_id.is_set or
                                        self.backup_pseudo_wire_id_type.is_set or
                                        self.bound.is_set or
                                        self.group_id.is_set or
                                        self.group_state.is_set or
                                        self.grouping_supported.is_set or
                                        self.pw_flow_label_tx.is_set or
                                        self.redundancy_role.is_set or
                                        (self.atom is not None and self.atom.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.backup_next_hop.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set or
                                        self.bound.yfilter != YFilter.not_set or
                                        self.group_id.yfilter != YFilter.not_set or
                                        self.group_state.yfilter != YFilter.not_set or
                                        self.grouping_supported.yfilter != YFilter.not_set or
                                        self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                        self.redundancy_role.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-pseudo-wire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.backup_next_hop.is_set or self.backup_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_next_hop.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id.is_set or self.backup_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id_type.is_set or self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id_type.get_name_leafdata())
                                    if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bound.get_name_leafdata())
                                    if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_id.get_name_leafdata())
                                    if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_state.get_name_leafdata())
                                    if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                    if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                    if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_role.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "active" or name == "backup-next-hop" or name == "backup-pseudo-wire-id" or name == "backup-pseudo-wire-id-type" or name == "bound" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "pw-flow-label-tx" or name == "redundancy-role"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-next-hop"):
                                        self.backup_next_hop = value
                                        self.backup_next_hop.value_namespace = name_space
                                        self.backup_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id"):
                                        self.backup_pseudo_wire_id = value
                                        self.backup_pseudo_wire_id.value_namespace = name_space
                                        self.backup_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id-type"):
                                        self.backup_pseudo_wire_id_type = value
                                        self.backup_pseudo_wire_id_type.value_namespace = name_space
                                        self.backup_pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bound"):
                                        self.bound = value
                                        self.bound.value_namespace = name_space
                                        self.bound.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-id"):
                                        self.group_id = value
                                        self.group_id.value_namespace = name_space
                                        self.group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-state"):
                                        self.group_state = value
                                        self.group_state.value_namespace = name_space
                                        self.group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "grouping-supported"):
                                        self.grouping_supported = value
                                        self.grouping_supported.value_namespace = name_space
                                        self.grouping_supported.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-tx"):
                                        self.pw_flow_label_tx = value
                                        self.pw_flow_label_tx.value_namespace = name_space
                                        self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-role"):
                                        self.redundancy_role = value
                                        self.redundancy_role.value_namespace = name_space
                                        self.redundancy_role.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ac_id.is_set or
                                    self.active.is_set or
                                    self.backup_configured.is_set or
                                    self.bound.is_set or
                                    self.context.is_set or
                                    self.forward_class.is_set or
                                    self.global_id.is_set or
                                    self.group_id.is_set or
                                    self.group_state.is_set or
                                    self.grouping_supported.is_set or
                                    self.next_hop_valid.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_flow_label_tx.is_set or
                                    self.pw_id.is_set or
                                    self.pw_load_balance_type.is_set or
                                    self.redundancy_role.is_set or
                                    self.sequence_resync_threshold.is_set or
                                    self.signal_capability_flags.is_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_data()) or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ac_id.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.backup_configured.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.context.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.global_id.yfilter != YFilter.not_set or
                                    self.group_id.yfilter != YFilter.not_set or
                                    self.group_state.yfilter != YFilter.not_set or
                                    self.grouping_supported.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.pw_load_balance_type.yfilter != YFilter.not_set or
                                    self.redundancy_role.yfilter != YFilter.not_set or
                                    self.sequence_resync_threshold.yfilter != YFilter.not_set or
                                    self.signal_capability_flags.yfilter != YFilter.not_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_operation()) or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ac_id.is_set or self.ac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac_id.get_name_leafdata())
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.backup_configured.is_set or self.backup_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_configured.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.context.is_set or self.context.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.context.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.global_id.is_set or self.global_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_id.get_name_leafdata())
                                if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_id.get_name_leafdata())
                                if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_state.get_name_leafdata())
                                if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.pw_load_balance_type.is_set or self.pw_load_balance_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_load_balance_type.get_name_leafdata())
                                if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_role.get_name_leafdata())
                                if (self.sequence_resync_threshold.is_set or self.sequence_resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_resync_threshold.get_name_leafdata())
                                if (self.signal_capability_flags.is_set or self.signal_capability_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signal_capability_flags.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-pseudo-wire"):
                                    if (self.backup_pseudo_wire is None):
                                        self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire()
                                        self.backup_pseudo_wire.parent = self
                                        self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                    return self.backup_pseudo_wire

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                if (child_yang_name == "pseudo-wire-union"):
                                    if (self.pseudo_wire_union is None):
                                        self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion()
                                        self.pseudo_wire_union.parent = self
                                        self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                    return self.pseudo_wire_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-pseudo-wire" or name == "base" or name == "next-hop" or name == "pseudo-wire-union" or name == "ac-id" or name == "active" or name == "backup-configured" or name == "bound" or name == "context" or name == "forward-class" or name == "global-id" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "next-hop-valid" or name == "pseudo-wire-id-type" or name == "pw-flow-label-tx" or name == "pw-id" or name == "pw-load-balance-type" or name == "redundancy-role" or name == "sequence-resync-threshold" or name == "signal-capability-flags"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ac-id"):
                                    self.ac_id = value
                                    self.ac_id.value_namespace = name_space
                                    self.ac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-configured"):
                                    self.backup_configured = value
                                    self.backup_configured.value_namespace = name_space
                                    self.backup_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "context"):
                                    self.context = value
                                    self.context.value_namespace = name_space
                                    self.context.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "global-id"):
                                    self.global_id = value
                                    self.global_id.value_namespace = name_space
                                    self.global_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-id"):
                                    self.group_id = value
                                    self.group_id.value_namespace = name_space
                                    self.group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-state"):
                                    self.group_state = value
                                    self.group_state.value_namespace = name_space
                                    self.group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "grouping-supported"):
                                    self.grouping_supported = value
                                    self.grouping_supported.value_namespace = name_space
                                    self.grouping_supported.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-tx"):
                                    self.pw_flow_label_tx = value
                                    self.pw_flow_label_tx.value_namespace = name_space
                                    self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-load-balance-type"):
                                    self.pw_load_balance_type = value
                                    self.pw_load_balance_type.value_namespace = name_space
                                    self.pw_load_balance_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-role"):
                                    self.redundancy_role = value
                                    self.redundancy_role.value_namespace = name_space
                                    self.redundancy_role.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-resync-threshold"):
                                    self.sequence_resync_threshold = value
                                    self.sequence_resync_threshold.value_namespace = name_space
                                    self.sequence_resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "signal-capability-flags"):
                                    self.signal_capability_flags = value
                                    self.signal_capability_flags.value_namespace = name_space
                                    self.signal_capability_flags.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.evpn is not None and self.evpn.has_data()) or
                                (self.monitor_session is not None and self.monitor_session.has_data()) or
                                (self.pbb is not None and self.pbb.has_data()) or
                                (self.pw is not None and self.pw.has_data()) or
                                (self.vni is not None and self.vni.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.evpn is not None and self.evpn.has_operation()) or
                                (self.monitor_session is not None and self.monitor_session.has_operation()) or
                                (self.pbb is not None and self.pbb.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()) or
                                (self.vni is not None and self.vni.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "evpn"):
                                if (self.evpn is None):
                                    self.evpn = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn()
                                    self.evpn.parent = self
                                    self._children_name_map["evpn"] = "evpn"
                                return self.evpn

                            if (child_yang_name == "monitor-session"):
                                if (self.monitor_session is None):
                                    self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession()
                                    self.monitor_session.parent = self
                                    self._children_name_map["monitor_session"] = "monitor-session"
                                return self.monitor_session

                            if (child_yang_name == "pbb"):
                                if (self.pbb is None):
                                    self.pbb = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb()
                                    self.pbb.parent = self
                                    self._children_name_map["pbb"] = "pbb"
                                return self.pbb

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            if (child_yang_name == "vni"):
                                if (self.vni is None):
                                    self.vni = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni()
                                    self.vni.parent = self
                                    self._children_name_map["vni"] = "vni"
                                return self.vni

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "evpn" or name == "monitor-session" or name == "pbb" or name == "pw" or name == "vni" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix


                    class Segment2(Entity):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:   :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:   :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2, self).__init__()

                            self.yang_name = "segment2"
                            self.yang_parent_name = "l2fibx-con"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.bp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp()
                            self.bp.parent = self
                            self._children_name_map["bp"] = "bp"
                            self._children_yang_names.add("bp")

                            self.fxs = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs()
                            self.fxs.parent = self
                            self._children_name_map["fxs"] = "fxs"
                            self._children_yang_names.add("fxs")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment2"

                                self.actype = YLeaf(YType.uint8, "actype")

                                self.adjacency_address = YLeaf(YType.str, "adjacency-address")

                                self.adjacency_valid = YLeaf(YType.boolean, "adjacency-valid")

                                self.attachment_circuit_id = YLeaf(YType.uint32, "attachment-circuit-id")

                                self.attachment_circuit_mtu = YLeaf(YType.uint16, "attachment-circuit-mtu")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.fxc_next_hop_valid = YLeaf(YType.boolean, "fxc-next-hop-valid")

                                self.inter_working_mode = YLeaf(YType.uint8, "inter-working-mode")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.ip_inter_working_mac = YLeaf(YType.str, "ip-inter-working-mac")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.sub_interface_handle = YLeaf(YType.str, "sub-interface-handle")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._children_yang_names.add("fxc-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actype",
                                                "adjacency_address",
                                                "adjacency_valid",
                                                "attachment_circuit_id",
                                                "attachment_circuit_mtu",
                                                "bound",
                                                "evpn_internal_label",
                                                "fxc_next_hop_valid",
                                                "inter_working_mode",
                                                "interface_handle",
                                                "ip_inter_working_mac",
                                                "redundancy_group_id",
                                                "redundancy_object_id",
                                                "sub_interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fxc-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.actype.is_set or
                                    self.adjacency_address.is_set or
                                    self.adjacency_valid.is_set or
                                    self.attachment_circuit_id.is_set or
                                    self.attachment_circuit_mtu.is_set or
                                    self.bound.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.fxc_next_hop_valid.is_set or
                                    self.inter_working_mode.is_set or
                                    self.interface_handle.is_set or
                                    self.ip_inter_working_mac.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.sub_interface_handle.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actype.yfilter != YFilter.not_set or
                                    self.adjacency_address.yfilter != YFilter.not_set or
                                    self.adjacency_valid.yfilter != YFilter.not_set or
                                    self.attachment_circuit_id.yfilter != YFilter.not_set or
                                    self.attachment_circuit_mtu.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.fxc_next_hop_valid.yfilter != YFilter.not_set or
                                    self.inter_working_mode.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.ip_inter_working_mac.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.sub_interface_handle.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actype.is_set or self.actype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actype.get_name_leafdata())
                                if (self.adjacency_address.is_set or self.adjacency_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_address.get_name_leafdata())
                                if (self.adjacency_valid.is_set or self.adjacency_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_valid.get_name_leafdata())
                                if (self.attachment_circuit_id.is_set or self.attachment_circuit_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_id.get_name_leafdata())
                                if (self.attachment_circuit_mtu.is_set or self.attachment_circuit_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_mtu.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.fxc_next_hop_valid.is_set or self.fxc_next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxc_next_hop_valid.get_name_leafdata())
                                if (self.inter_working_mode.is_set or self.inter_working_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_working_mode.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.ip_inter_working_mac.is_set or self.ip_inter_working_mac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_inter_working_mac.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.sub_interface_handle.is_set or self.sub_interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "fxc-next-hop"):
                                    if (self.fxc_next_hop is None):
                                        self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop()
                                        self.fxc_next_hop.parent = self
                                        self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                    return self.fxc_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxc-next-hop" or name == "actype" or name == "adjacency-address" or name == "adjacency-valid" or name == "attachment-circuit-id" or name == "attachment-circuit-mtu" or name == "bound" or name == "evpn-internal-label" or name == "fxc-next-hop-valid" or name == "inter-working-mode" or name == "interface-handle" or name == "ip-inter-working-mac" or name == "redundancy-group-id" or name == "redundancy-object-id" or name == "sub-interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actype"):
                                    self.actype = value
                                    self.actype.value_namespace = name_space
                                    self.actype.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-address"):
                                    self.adjacency_address = value
                                    self.adjacency_address.value_namespace = name_space
                                    self.adjacency_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-valid"):
                                    self.adjacency_valid = value
                                    self.adjacency_valid.value_namespace = name_space
                                    self.adjacency_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-id"):
                                    self.attachment_circuit_id = value
                                    self.attachment_circuit_id.value_namespace = name_space
                                    self.attachment_circuit_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-mtu"):
                                    self.attachment_circuit_mtu = value
                                    self.attachment_circuit_mtu.value_namespace = name_space
                                    self.attachment_circuit_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "fxc-next-hop-valid"):
                                    self.fxc_next_hop_valid = value
                                    self.fxc_next_hop_valid.value_namespace = name_space
                                    self.fxc_next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-working-mode"):
                                    self.inter_working_mode = value
                                    self.inter_working_mode.value_namespace = name_space
                                    self.inter_working_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip-inter-working-mac"):
                                    self.ip_inter_working_mac = value
                                    self.ip_inter_working_mac.value_namespace = name_space
                                    self.ip_inter_working_mac.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-interface-handle"):
                                    self.sub_interface_handle = value
                                    self.sub_interface_handle.value_namespace = name_space
                                    self.sub_interface_handle.value_namespace_prefix = name_space_prefix


                        class Bp(Entity):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Base>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:   :py:class:`P2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.P2Mp>`
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp, self).__init__()

                                self.yang_name = "bp"
                                self.yang_parent_name = "segment2"

                                self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                                self.learn_key = YLeaf(YType.uint8, "learn-key")

                                self.msti_pointer = YLeaf(YType.uint32, "msti-pointer")

                                self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                                self.segment_type = YLeaf(YType.uint8, "segment-type")

                                self.shg_id = YLeaf(YType.uint32, "shg-id")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.oper = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self._children_name_map["oper"] = "oper"
                                self._children_yang_names.add("oper")

                                self.p2mp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.P2Mp()
                                self.p2mp.parent = self
                                self._children_name_map["p2mp"] = "p2mp"
                                self._children_yang_names.add("p2mp")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bridge_id",
                                                "learn_key",
                                                "msti_pointer",
                                                "mvrp_sequence_number",
                                                "segment_type",
                                                "shg_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "bp"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Oper(Entity):
                                """
                                Operational information
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper, self).__init__()

                                    self.yang_name = "oper"
                                    self.yang_parent_name = "bp"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self._children_name_map["operational_information"] = "operational-information"
                                    self._children_yang_names.add("operational-information")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper, self).__setattr__(name, value)


                                class OperationalInformation(Entity):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\:  bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: host_routing_enabled
                                    
                                    	Host Routing enabled on this BD
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotify>`
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:   :py:class:`MgmtL2FibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecAction>`
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\:  bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation, self).__init__()

                                        self.yang_name = "operational-information"
                                        self.yang_parent_name = "oper"

                                        self.admin_disabled = YLeaf(YType.boolean, "admin-disabled")

                                        self.bvi_configured = YLeaf(YType.boolean, "bvi-configured")

                                        self.dhcp_enabled = YLeaf(YType.boolean, "dhcp-enabled")

                                        self.dhcp_trusted = YLeaf(YType.boolean, "dhcp-trusted")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flooding_disabled = YLeaf(YType.boolean, "flooding-disabled")

                                        self.host_routing_enabled = YLeaf(YType.boolean, "host-routing-enabled")

                                        self.igmp_flood_forward_enabled = YLeaf(YType.boolean, "igmp-flood-forward-enabled")

                                        self.igmp_mroute_port_enabled = YLeaf(YType.boolean, "igmp-mroute-port-enabled")

                                        self.igmp_route_guard_enabled = YLeaf(YType.boolean, "igmp-route-guard-enabled")

                                        self.igmp_snoop_enabled = YLeaf(YType.boolean, "igmp-snoop-enabled")

                                        self.igmp_snoop_profile_enabled = YLeaf(YType.boolean, "igmp-snoop-profile-enabled")

                                        self.is_bvi_up = YLeaf(YType.boolean, "is-bvi-up")

                                        self.is_dai_addr_validation_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-destination-mac-enabled")

                                        self.is_dai_addr_validation_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-ipv4-enabled")

                                        self.is_dai_addr_validation_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_evpn_cw_disable = YLeaf(YType.boolean, "is-evpn-cw-disable")

                                        self.is_evpn_enabled = YLeaf(YType.boolean, "is-evpn-enabled")

                                        self.is_evpn_flow_label = YLeaf(YType.boolean, "is-evpn-flow-label")

                                        self.is_igmp_snoop_enabled = YLeaf(YType.boolean, "is-igmp-snoop-enabled")

                                        self.is_ipsg_enabled = YLeaf(YType.boolean, "is-ipsg-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.is_p2mp_pw_enabled = YLeaf(YType.boolean, "is-p2mp-pw-enabled")

                                        self.is_pbbevpn_enabled = YLeaf(YType.boolean, "is-pbbevpn-enabled")

                                        self.is_swmac_learning = YLeaf(YType.boolean, "is-swmac-learning")

                                        self.is_vni_enabled = YLeaf(YType.boolean, "is-vni-enabled")

                                        self.is_vpls_flood_optimization_enabled = YLeaf(YType.boolean, "is-vpls-flood-optimization-enabled")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_aging_type = YLeaf(YType.boolean, "mac-aging-type")

                                        self.mac_learning_disabled = YLeaf(YType.boolean, "mac-learning-disabled")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification_type = YLeaf(YType.enumeration, "mac-limit-notification-type")

                                        self.mac_port_down_flush_disabled = YLeaf(YType.boolean, "mac-port-down-flush-disabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_flood_forward_enabled = YLeaf(YType.boolean, "mld-flood-forward-enabled")

                                        self.mld_mroute_port_enabled = YLeaf(YType.boolean, "mld-mroute-port-enabled")

                                        self.mld_route_guard_enabled = YLeaf(YType.boolean, "mld-route-guard-enabled")

                                        self.mld_snoop_enabled = YLeaf(YType.boolean, "mld-snoop-enabled")

                                        self.mld_snoop_profile_enabled = YLeaf(YType.boolean, "mld-snoop-profile-enabled")

                                        self.msti = YLeaf(YType.uint32, "msti")

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.number_of_macs = YLeaf(YType.uint32, "number-of-macs")

                                        self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                                        self.storm_control_broadcast_enabled = YLeaf(YType.boolean, "storm-control-broadcast-enabled")

                                        self.storm_control_broadcast_rate_unit = YLeaf(YType.enumeration, "storm-control-broadcast-rate-unit")

                                        self.storm_control_multicast_enabled = YLeaf(YType.boolean, "storm-control-multicast-enabled")

                                        self.storm_control_multicast_rate_unit = YLeaf(YType.enumeration, "storm-control-multicast-rate-unit")

                                        self.storm_control_unicast_enabled = YLeaf(YType.boolean, "storm-control-unicast-enabled")

                                        self.storm_control_unicast_rate_unit = YLeaf(YType.enumeration, "storm-control-unicast-rate-unit")

                                        self.stp_participating = YLeaf(YType.boolean, "stp-participating")

                                        self.unknown_unicast_flooding_disabled = YLeaf(YType.boolean, "unknown-unicast-flooding-disabled")

                                        self.feature = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("admin_disabled",
                                                        "bvi_configured",
                                                        "dhcp_enabled",
                                                        "dhcp_trusted",
                                                        "flood_unknown_unicast_enabled",
                                                        "flooding_disabled",
                                                        "host_routing_enabled",
                                                        "igmp_flood_forward_enabled",
                                                        "igmp_mroute_port_enabled",
                                                        "igmp_route_guard_enabled",
                                                        "igmp_snoop_enabled",
                                                        "igmp_snoop_profile_enabled",
                                                        "is_bvi_up",
                                                        "is_dai_addr_validation_destination_mac_enabled",
                                                        "is_dai_addr_validation_ipv4_enabled",
                                                        "is_dai_addr_validation_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_evpn_cw_disable",
                                                        "is_evpn_enabled",
                                                        "is_evpn_flow_label",
                                                        "is_igmp_snoop_enabled",
                                                        "is_ipsg_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "is_p2mp_pw_enabled",
                                                        "is_pbbevpn_enabled",
                                                        "is_swmac_learning",
                                                        "is_vni_enabled",
                                                        "is_vpls_flood_optimization_enabled",
                                                        "mac_aging_time",
                                                        "mac_aging_type",
                                                        "mac_learning_disabled",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification_type",
                                                        "mac_port_down_flush_disabled",
                                                        "mac_secure_action",
                                                        "mld_flood_forward_enabled",
                                                        "mld_mroute_port_enabled",
                                                        "mld_route_guard_enabled",
                                                        "mld_snoop_enabled",
                                                        "mld_snoop_profile_enabled",
                                                        "msti",
                                                        "mtu",
                                                        "number_of_macs",
                                                        "nv_satellite_offload_ipv4_multicast_disabled",
                                                        "storm_control_broadcast_enabled",
                                                        "storm_control_broadcast_rate_unit",
                                                        "storm_control_multicast_enabled",
                                                        "storm_control_multicast_rate_unit",
                                                        "storm_control_unicast_enabled",
                                                        "storm_control_unicast_rate_unit",
                                                        "stp_participating",
                                                        "unknown_unicast_flooding_disabled") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation, self).__setattr__(name, value)


                                    class Feature(Entity):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:   :py:class:`L2FibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeature>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature, self).__init__()

                                            self.yang_name = "feature"
                                            self.yang_parent_name = "operational-information"

                                            self.feature_type = YLeaf(YType.enumeration, "feature-type")

                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self._children_name_map["dhcp"] = "dhcp"
                                            self._children_yang_names.add("dhcp")

                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self._children_name_map["igmp"] = "igmp"
                                            self._children_yang_names.add("igmp")

                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self
                                            self._children_name_map["mld"] = "mld"
                                            self._children_yang_names.add("mld")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("feature_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature, self).__setattr__(name, value)


                                        class Dhcp(Entity):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                                self.yang_name = "dhcp"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dhcp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix


                                        class Igmp(Entity):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                                self.yang_name = "igmp"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "igmp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix


                                        class Mld(Entity):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                                self.yang_name = "mld"
                                                self.yang_parent_name = "feature"

                                                self.profile_name = YLeaf(YType.str, "profile-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("profile_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.profile_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.profile_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mld" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "profile-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "profile-name"):
                                                    self.profile_name = value
                                                    self.profile_name.value_namespace = name_space
                                                    self.profile_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.feature_type.is_set or
                                                (self.dhcp is not None and self.dhcp.has_data()) or
                                                (self.igmp is not None and self.igmp.has_data()) or
                                                (self.mld is not None and self.mld.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.feature_type.yfilter != YFilter.not_set or
                                                (self.dhcp is not None and self.dhcp.has_operation()) or
                                                (self.igmp is not None and self.igmp.has_operation()) or
                                                (self.mld is not None and self.mld.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "feature" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.feature_type.is_set or self.feature_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.feature_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dhcp"):
                                                if (self.dhcp is None):
                                                    self.dhcp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                                    self.dhcp.parent = self
                                                    self._children_name_map["dhcp"] = "dhcp"
                                                return self.dhcp

                                            if (child_yang_name == "igmp"):
                                                if (self.igmp is None):
                                                    self.igmp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                                    self.igmp.parent = self
                                                    self._children_name_map["igmp"] = "igmp"
                                                return self.igmp

                                            if (child_yang_name == "mld"):
                                                if (self.mld is None):
                                                    self.mld = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                                    self.mld.parent = self
                                                    self._children_name_map["mld"] = "mld"
                                                return self.mld

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dhcp" or name == "igmp" or name == "mld" or name == "feature-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "feature-type"):
                                                self.feature_type = value
                                                self.feature_type.value_namespace = name_space
                                                self.feature_type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.feature:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.admin_disabled.is_set or
                                            self.bvi_configured.is_set or
                                            self.dhcp_enabled.is_set or
                                            self.dhcp_trusted.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flooding_disabled.is_set or
                                            self.host_routing_enabled.is_set or
                                            self.igmp_flood_forward_enabled.is_set or
                                            self.igmp_mroute_port_enabled.is_set or
                                            self.igmp_route_guard_enabled.is_set or
                                            self.igmp_snoop_enabled.is_set or
                                            self.igmp_snoop_profile_enabled.is_set or
                                            self.is_bvi_up.is_set or
                                            self.is_dai_addr_validation_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validation_ipv4_enabled.is_set or
                                            self.is_dai_addr_validation_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_evpn_cw_disable.is_set or
                                            self.is_evpn_enabled.is_set or
                                            self.is_evpn_flow_label.is_set or
                                            self.is_igmp_snoop_enabled.is_set or
                                            self.is_ipsg_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.is_p2mp_pw_enabled.is_set or
                                            self.is_pbbevpn_enabled.is_set or
                                            self.is_swmac_learning.is_set or
                                            self.is_vni_enabled.is_set or
                                            self.is_vpls_flood_optimization_enabled.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_aging_type.is_set or
                                            self.mac_learning_disabled.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification_type.is_set or
                                            self.mac_port_down_flush_disabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_flood_forward_enabled.is_set or
                                            self.mld_mroute_port_enabled.is_set or
                                            self.mld_route_guard_enabled.is_set or
                                            self.mld_snoop_enabled.is_set or
                                            self.mld_snoop_profile_enabled.is_set or
                                            self.msti.is_set or
                                            self.mtu.is_set or
                                            self.number_of_macs.is_set or
                                            self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                                            self.storm_control_broadcast_enabled.is_set or
                                            self.storm_control_broadcast_rate_unit.is_set or
                                            self.storm_control_multicast_enabled.is_set or
                                            self.storm_control_multicast_rate_unit.is_set or
                                            self.storm_control_unicast_enabled.is_set or
                                            self.storm_control_unicast_rate_unit.is_set or
                                            self.stp_participating.is_set or
                                            self.unknown_unicast_flooding_disabled.is_set)

                                    def has_operation(self):
                                        for c in self.feature:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.admin_disabled.yfilter != YFilter.not_set or
                                            self.bvi_configured.yfilter != YFilter.not_set or
                                            self.dhcp_enabled.yfilter != YFilter.not_set or
                                            self.dhcp_trusted.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flooding_disabled.yfilter != YFilter.not_set or
                                            self.host_routing_enabled.yfilter != YFilter.not_set or
                                            self.igmp_flood_forward_enabled.yfilter != YFilter.not_set or
                                            self.igmp_mroute_port_enabled.yfilter != YFilter.not_set or
                                            self.igmp_route_guard_enabled.yfilter != YFilter.not_set or
                                            self.igmp_snoop_enabled.yfilter != YFilter.not_set or
                                            self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set or
                                            self.is_bvi_up.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_evpn_cw_disable.yfilter != YFilter.not_set or
                                            self.is_evpn_enabled.yfilter != YFilter.not_set or
                                            self.is_evpn_flow_label.yfilter != YFilter.not_set or
                                            self.is_igmp_snoop_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_p2mp_pw_enabled.yfilter != YFilter.not_set or
                                            self.is_pbbevpn_enabled.yfilter != YFilter.not_set or
                                            self.is_swmac_learning.yfilter != YFilter.not_set or
                                            self.is_vni_enabled.yfilter != YFilter.not_set or
                                            self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_aging_type.yfilter != YFilter.not_set or
                                            self.mac_learning_disabled.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification_type.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_disabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_flood_forward_enabled.yfilter != YFilter.not_set or
                                            self.mld_mroute_port_enabled.yfilter != YFilter.not_set or
                                            self.mld_route_guard_enabled.yfilter != YFilter.not_set or
                                            self.mld_snoop_enabled.yfilter != YFilter.not_set or
                                            self.mld_snoop_profile_enabled.yfilter != YFilter.not_set or
                                            self.msti.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.number_of_macs.yfilter != YFilter.not_set or
                                            self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                                            self.storm_control_broadcast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set or
                                            self.storm_control_multicast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set or
                                            self.storm_control_unicast_enabled.yfilter != YFilter.not_set or
                                            self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set or
                                            self.stp_participating.yfilter != YFilter.not_set or
                                            self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "operational-information" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.admin_disabled.is_set or self.admin_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.admin_disabled.get_name_leafdata())
                                        if (self.bvi_configured.is_set or self.bvi_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bvi_configured.get_name_leafdata())
                                        if (self.dhcp_enabled.is_set or self.dhcp_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcp_enabled.get_name_leafdata())
                                        if (self.dhcp_trusted.is_set or self.dhcp_trusted.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcp_trusted.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flooding_disabled.is_set or self.flooding_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flooding_disabled.get_name_leafdata())
                                        if (self.host_routing_enabled.is_set or self.host_routing_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.host_routing_enabled.get_name_leafdata())
                                        if (self.igmp_flood_forward_enabled.is_set or self.igmp_flood_forward_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_flood_forward_enabled.get_name_leafdata())
                                        if (self.igmp_mroute_port_enabled.is_set or self.igmp_mroute_port_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_mroute_port_enabled.get_name_leafdata())
                                        if (self.igmp_route_guard_enabled.is_set or self.igmp_route_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_route_guard_enabled.get_name_leafdata())
                                        if (self.igmp_snoop_enabled.is_set or self.igmp_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_snoop_enabled.get_name_leafdata())
                                        if (self.igmp_snoop_profile_enabled.is_set or self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igmp_snoop_profile_enabled.get_name_leafdata())
                                        if (self.is_bvi_up.is_set or self.is_bvi_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_bvi_up.get_name_leafdata())
                                        if (self.is_dai_addr_validation_destination_mac_enabled.is_set or self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validation_ipv4_enabled.is_set or self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validation_source_mac_enabled.is_set or self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validation_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_evpn_cw_disable.is_set or self.is_evpn_cw_disable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_cw_disable.get_name_leafdata())
                                        if (self.is_evpn_enabled.is_set or self.is_evpn_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_enabled.get_name_leafdata())
                                        if (self.is_evpn_flow_label.is_set or self.is_evpn_flow_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpn_flow_label.get_name_leafdata())
                                        if (self.is_igmp_snoop_enabled.is_set or self.is_igmp_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_igmp_snoop_enabled.get_name_leafdata())
                                        if (self.is_ipsg_enabled.is_set or self.is_ipsg_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown.is_set or self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.is_p2mp_pw_enabled.is_set or self.is_p2mp_pw_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_p2mp_pw_enabled.get_name_leafdata())
                                        if (self.is_pbbevpn_enabled.is_set or self.is_pbbevpn_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pbbevpn_enabled.get_name_leafdata())
                                        if (self.is_swmac_learning.is_set or self.is_swmac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_swmac_learning.get_name_leafdata())
                                        if (self.is_vni_enabled.is_set or self.is_vni_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_vni_enabled.get_name_leafdata())
                                        if (self.is_vpls_flood_optimization_enabled.is_set or self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_vpls_flood_optimization_enabled.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_aging_type.is_set or self.mac_aging_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_type.get_name_leafdata())
                                        if (self.mac_learning_disabled.is_set or self.mac_learning_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning_disabled.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification_type.is_set or self.mac_limit_notification_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification_type.get_name_leafdata())
                                        if (self.mac_port_down_flush_disabled.is_set or self.mac_port_down_flush_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_disabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_flood_forward_enabled.is_set or self.mld_flood_forward_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_flood_forward_enabled.get_name_leafdata())
                                        if (self.mld_mroute_port_enabled.is_set or self.mld_mroute_port_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_mroute_port_enabled.get_name_leafdata())
                                        if (self.mld_route_guard_enabled.is_set or self.mld_route_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_route_guard_enabled.get_name_leafdata())
                                        if (self.mld_snoop_enabled.is_set or self.mld_snoop_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_snoop_enabled.get_name_leafdata())
                                        if (self.mld_snoop_profile_enabled.is_set or self.mld_snoop_profile_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_snoop_profile_enabled.get_name_leafdata())
                                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.msti.get_name_leafdata())
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.number_of_macs.is_set or self.number_of_macs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_of_macs.get_name_leafdata())
                                        if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                                        if (self.storm_control_broadcast_enabled.is_set or self.storm_control_broadcast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_broadcast_enabled.get_name_leafdata())
                                        if (self.storm_control_broadcast_rate_unit.is_set or self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_broadcast_rate_unit.get_name_leafdata())
                                        if (self.storm_control_multicast_enabled.is_set or self.storm_control_multicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_multicast_enabled.get_name_leafdata())
                                        if (self.storm_control_multicast_rate_unit.is_set or self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_multicast_rate_unit.get_name_leafdata())
                                        if (self.storm_control_unicast_enabled.is_set or self.storm_control_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_unicast_enabled.get_name_leafdata())
                                        if (self.storm_control_unicast_rate_unit.is_set or self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.storm_control_unicast_rate_unit.get_name_leafdata())
                                        if (self.stp_participating.is_set or self.stp_participating.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.stp_participating.get_name_leafdata())
                                        if (self.unknown_unicast_flooding_disabled.is_set or self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unknown_unicast_flooding_disabled.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "feature"):
                                            for c in self.feature:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.feature.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "feature" or name == "admin-disabled" or name == "bvi-configured" or name == "dhcp-enabled" or name == "dhcp-trusted" or name == "flood-unknown-unicast-enabled" or name == "flooding-disabled" or name == "host-routing-enabled" or name == "igmp-flood-forward-enabled" or name == "igmp-mroute-port-enabled" or name == "igmp-route-guard-enabled" or name == "igmp-snoop-enabled" or name == "igmp-snoop-profile-enabled" or name == "is-bvi-up" or name == "is-dai-addr-validation-destination-mac-enabled" or name == "is-dai-addr-validation-ipv4-enabled" or name == "is-dai-addr-validation-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-evpn-cw-disable" or name == "is-evpn-enabled" or name == "is-evpn-flow-label" or name == "is-igmp-snoop-enabled" or name == "is-ipsg-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "is-p2mp-pw-enabled" or name == "is-pbbevpn-enabled" or name == "is-swmac-learning" or name == "is-vni-enabled" or name == "is-vpls-flood-optimization-enabled" or name == "mac-aging-time" or name == "mac-aging-type" or name == "mac-learning-disabled" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification-type" or name == "mac-port-down-flush-disabled" or name == "mac-secure-action" or name == "mld-flood-forward-enabled" or name == "mld-mroute-port-enabled" or name == "mld-route-guard-enabled" or name == "mld-snoop-enabled" or name == "mld-snoop-profile-enabled" or name == "msti" or name == "mtu" or name == "number-of-macs" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "storm-control-broadcast-enabled" or name == "storm-control-broadcast-rate-unit" or name == "storm-control-multicast-enabled" or name == "storm-control-multicast-rate-unit" or name == "storm-control-unicast-enabled" or name == "storm-control-unicast-rate-unit" or name == "stp-participating" or name == "unknown-unicast-flooding-disabled"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "admin-disabled"):
                                            self.admin_disabled = value
                                            self.admin_disabled.value_namespace = name_space
                                            self.admin_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bvi-configured"):
                                            self.bvi_configured = value
                                            self.bvi_configured.value_namespace = name_space
                                            self.bvi_configured.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcp-enabled"):
                                            self.dhcp_enabled = value
                                            self.dhcp_enabled.value_namespace = name_space
                                            self.dhcp_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcp-trusted"):
                                            self.dhcp_trusted = value
                                            self.dhcp_trusted.value_namespace = name_space
                                            self.dhcp_trusted.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flooding-disabled"):
                                            self.flooding_disabled = value
                                            self.flooding_disabled.value_namespace = name_space
                                            self.flooding_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "host-routing-enabled"):
                                            self.host_routing_enabled = value
                                            self.host_routing_enabled.value_namespace = name_space
                                            self.host_routing_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-flood-forward-enabled"):
                                            self.igmp_flood_forward_enabled = value
                                            self.igmp_flood_forward_enabled.value_namespace = name_space
                                            self.igmp_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-mroute-port-enabled"):
                                            self.igmp_mroute_port_enabled = value
                                            self.igmp_mroute_port_enabled.value_namespace = name_space
                                            self.igmp_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-route-guard-enabled"):
                                            self.igmp_route_guard_enabled = value
                                            self.igmp_route_guard_enabled.value_namespace = name_space
                                            self.igmp_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-snoop-enabled"):
                                            self.igmp_snoop_enabled = value
                                            self.igmp_snoop_enabled.value_namespace = name_space
                                            self.igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igmp-snoop-profile-enabled"):
                                            self.igmp_snoop_profile_enabled = value
                                            self.igmp_snoop_profile_enabled.value_namespace = name_space
                                            self.igmp_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-bvi-up"):
                                            self.is_bvi_up = value
                                            self.is_bvi_up.value_namespace = name_space
                                            self.is_bvi_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-destination-mac-enabled"):
                                            self.is_dai_addr_validation_destination_mac_enabled = value
                                            self.is_dai_addr_validation_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-ipv4-enabled"):
                                            self.is_dai_addr_validation_ipv4_enabled = value
                                            self.is_dai_addr_validation_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validation-source-mac-enabled"):
                                            self.is_dai_addr_validation_source_mac_enabled = value
                                            self.is_dai_addr_validation_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validation_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-cw-disable"):
                                            self.is_evpn_cw_disable = value
                                            self.is_evpn_cw_disable.value_namespace = name_space
                                            self.is_evpn_cw_disable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-enabled"):
                                            self.is_evpn_enabled = value
                                            self.is_evpn_enabled.value_namespace = name_space
                                            self.is_evpn_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpn-flow-label"):
                                            self.is_evpn_flow_label = value
                                            self.is_evpn_flow_label.value_namespace = name_space
                                            self.is_evpn_flow_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-igmp-snoop-enabled"):
                                            self.is_igmp_snoop_enabled = value
                                            self.is_igmp_snoop_enabled.value_namespace = name_space
                                            self.is_igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-enabled"):
                                            self.is_ipsg_enabled = value
                                            self.is_ipsg_enabled.value_namespace = name_space
                                            self.is_ipsg_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown"):
                                            self.is_mac_secure_accept_shutdown = value
                                            self.is_mac_secure_accept_shutdown.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-p2mp-pw-enabled"):
                                            self.is_p2mp_pw_enabled = value
                                            self.is_p2mp_pw_enabled.value_namespace = name_space
                                            self.is_p2mp_pw_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-pbbevpn-enabled"):
                                            self.is_pbbevpn_enabled = value
                                            self.is_pbbevpn_enabled.value_namespace = name_space
                                            self.is_pbbevpn_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-swmac-learning"):
                                            self.is_swmac_learning = value
                                            self.is_swmac_learning.value_namespace = name_space
                                            self.is_swmac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-vni-enabled"):
                                            self.is_vni_enabled = value
                                            self.is_vni_enabled.value_namespace = name_space
                                            self.is_vni_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-vpls-flood-optimization-enabled"):
                                            self.is_vpls_flood_optimization_enabled = value
                                            self.is_vpls_flood_optimization_enabled.value_namespace = name_space
                                            self.is_vpls_flood_optimization_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-type"):
                                            self.mac_aging_type = value
                                            self.mac_aging_type.value_namespace = name_space
                                            self.mac_aging_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning-disabled"):
                                            self.mac_learning_disabled = value
                                            self.mac_learning_disabled.value_namespace = name_space
                                            self.mac_learning_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification-type"):
                                            self.mac_limit_notification_type = value
                                            self.mac_limit_notification_type.value_namespace = name_space
                                            self.mac_limit_notification_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-disabled"):
                                            self.mac_port_down_flush_disabled = value
                                            self.mac_port_down_flush_disabled.value_namespace = name_space
                                            self.mac_port_down_flush_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-flood-forward-enabled"):
                                            self.mld_flood_forward_enabled = value
                                            self.mld_flood_forward_enabled.value_namespace = name_space
                                            self.mld_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-mroute-port-enabled"):
                                            self.mld_mroute_port_enabled = value
                                            self.mld_mroute_port_enabled.value_namespace = name_space
                                            self.mld_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-route-guard-enabled"):
                                            self.mld_route_guard_enabled = value
                                            self.mld_route_guard_enabled.value_namespace = name_space
                                            self.mld_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-snoop-enabled"):
                                            self.mld_snoop_enabled = value
                                            self.mld_snoop_enabled.value_namespace = name_space
                                            self.mld_snoop_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-snoop-profile-enabled"):
                                            self.mld_snoop_profile_enabled = value
                                            self.mld_snoop_profile_enabled.value_namespace = name_space
                                            self.mld_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "msti"):
                                            self.msti = value
                                            self.msti.value_namespace = name_space
                                            self.msti.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-of-macs"):
                                            self.number_of_macs = value
                                            self.number_of_macs.value_namespace = name_space
                                            self.number_of_macs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                                            self.nv_satellite_offload_ipv4_multicast_disabled = value
                                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-broadcast-enabled"):
                                            self.storm_control_broadcast_enabled = value
                                            self.storm_control_broadcast_enabled.value_namespace = name_space
                                            self.storm_control_broadcast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-broadcast-rate-unit"):
                                            self.storm_control_broadcast_rate_unit = value
                                            self.storm_control_broadcast_rate_unit.value_namespace = name_space
                                            self.storm_control_broadcast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-multicast-enabled"):
                                            self.storm_control_multicast_enabled = value
                                            self.storm_control_multicast_enabled.value_namespace = name_space
                                            self.storm_control_multicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-multicast-rate-unit"):
                                            self.storm_control_multicast_rate_unit = value
                                            self.storm_control_multicast_rate_unit.value_namespace = name_space
                                            self.storm_control_multicast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-unicast-enabled"):
                                            self.storm_control_unicast_enabled = value
                                            self.storm_control_unicast_enabled.value_namespace = name_space
                                            self.storm_control_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "storm-control-unicast-rate-unit"):
                                            self.storm_control_unicast_rate_unit = value
                                            self.storm_control_unicast_rate_unit.value_namespace = name_space
                                            self.storm_control_unicast_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "stp-participating"):
                                            self.stp_participating = value
                                            self.stp_participating.value_namespace = name_space
                                            self.stp_participating.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unknown-unicast-flooding-disabled"):
                                            self.unknown_unicast_flooding_disabled = value
                                            self.unknown_unicast_flooding_disabled.value_namespace = name_space
                                            self.unknown_unicast_flooding_disabled.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        (self.operational_information is not None and self.operational_information.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        (self.operational_information is not None and self.operational_information.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "oper" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "operational-information"):
                                        if (self.operational_information is None):
                                            self.operational_information = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation()
                                            self.operational_information.parent = self
                                            self._children_name_map["operational_information"] = "operational-information"
                                        return self.operational_information

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "operational-information" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix


                            class P2Mp(Entity):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\:  bool
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:   :py:class:`L2VpnPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPtree>`
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.P2Mp, self).__init__()

                                    self.yang_name = "p2mp"
                                    self.yang_parent_name = "bp"

                                    self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                                    self.lsm_id = YLeaf(YType.uint32, "lsm-id")

                                    self.p2mp_id = YLeaf(YType.uint16, "p2mp-id")

                                    self.ptree_owner_lmrib = YLeaf(YType.boolean, "ptree-owner-lmrib")

                                    self.ptree_type = YLeaf(YType.enumeration, "ptree-type")

                                    self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("extended_tunnel_id",
                                                    "lsm_id",
                                                    "p2mp_id",
                                                    "ptree_owner_lmrib",
                                                    "ptree_type",
                                                    "tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.P2Mp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.P2Mp, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.extended_tunnel_id.is_set or
                                        self.lsm_id.is_set or
                                        self.p2mp_id.is_set or
                                        self.ptree_owner_lmrib.is_set or
                                        self.ptree_type.is_set or
                                        self.tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.lsm_id.yfilter != YFilter.not_set or
                                        self.p2mp_id.yfilter != YFilter.not_set or
                                        self.ptree_owner_lmrib.yfilter != YFilter.not_set or
                                        self.ptree_type.yfilter != YFilter.not_set or
                                        self.tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                                    if (self.lsm_id.is_set or self.lsm_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsm_id.get_name_leafdata())
                                    if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                                    if (self.ptree_owner_lmrib.is_set or self.ptree_owner_lmrib.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ptree_owner_lmrib.get_name_leafdata())
                                    if (self.ptree_type.is_set or self.ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ptree_type.get_name_leafdata())
                                    if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "extended-tunnel-id" or name == "lsm-id" or name == "p2mp-id" or name == "ptree-owner-lmrib" or name == "ptree-type" or name == "tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "extended-tunnel-id"):
                                        self.extended_tunnel_id = value
                                        self.extended_tunnel_id.value_namespace = name_space
                                        self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsm-id"):
                                        self.lsm_id = value
                                        self.lsm_id.value_namespace = name_space
                                        self.lsm_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "p2mp-id"):
                                        self.p2mp_id = value
                                        self.p2mp_id.value_namespace = name_space
                                        self.p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ptree-owner-lmrib"):
                                        self.ptree_owner_lmrib = value
                                        self.ptree_owner_lmrib.value_namespace = name_space
                                        self.ptree_owner_lmrib.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ptree-type"):
                                        self.ptree_type = value
                                        self.ptree_type.value_namespace = name_space
                                        self.ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-id"):
                                        self.tunnel_id = value
                                        self.tunnel_id.value_namespace = name_space
                                        self.tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bridge_id.is_set or
                                    self.learn_key.is_set or
                                    self.msti_pointer.is_set or
                                    self.mvrp_sequence_number.is_set or
                                    self.segment_type.is_set or
                                    self.shg_id.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.oper is not None and self.oper.has_data()) or
                                    (self.p2mp is not None and self.p2mp.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bridge_id.yfilter != YFilter.not_set or
                                    self.learn_key.yfilter != YFilter.not_set or
                                    self.msti_pointer.yfilter != YFilter.not_set or
                                    self.mvrp_sequence_number.yfilter != YFilter.not_set or
                                    self.segment_type.yfilter != YFilter.not_set or
                                    self.shg_id.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.oper is not None and self.oper.has_operation()) or
                                    (self.p2mp is not None and self.p2mp.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bp" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_id.get_name_leafdata())
                                if (self.learn_key.is_set or self.learn_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.learn_key.get_name_leafdata())
                                if (self.msti_pointer.is_set or self.msti_pointer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_pointer.get_name_leafdata())
                                if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())
                                if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_type.get_name_leafdata())
                                if (self.shg_id.is_set or self.shg_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shg_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "oper"):
                                    if (self.oper is None):
                                        self.oper = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper()
                                        self.oper.parent = self
                                        self._children_name_map["oper"] = "oper"
                                    return self.oper

                                if (child_yang_name == "p2mp"):
                                    if (self.p2mp is None):
                                        self.p2mp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.P2Mp()
                                        self.p2mp.parent = self
                                        self._children_name_map["p2mp"] = "p2mp"
                                    return self.p2mp

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "oper" or name == "p2mp" or name == "bridge-id" or name == "learn-key" or name == "msti-pointer" or name == "mvrp-sequence-number" or name == "segment-type" or name == "shg-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bridge-id"):
                                    self.bridge_id = value
                                    self.bridge_id.value_namespace = name_space
                                    self.bridge_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "learn-key"):
                                    self.learn_key = value
                                    self.learn_key.value_namespace = name_space
                                    self.learn_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-pointer"):
                                    self.msti_pointer = value
                                    self.msti_pointer.value_namespace = name_space
                                    self.msti_pointer.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvrp-sequence-number"):
                                    self.mvrp_sequence_number = value
                                    self.mvrp_sequence_number.value_namespace = name_space
                                    self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-type"):
                                    self.segment_type = value
                                    self.segment_type.value_namespace = name_space
                                    self.segment_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shg-id"):
                                    self.shg_id = value
                                    self.shg_id.value_namespace = name_space
                                    self.shg_id.value_namespace_prefix = name_space_prefix


                        class Fxs(Entity):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs, self).__init__()

                                self.yang_name = "fxs"
                                self.yang_parent_name = "segment2"

                                self.fxs_id = YLeaf(YType.uint32, "fxs-id")

                                self.segment_type = YLeaf(YType.uint8, "segment-type")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fxs_id",
                                                "segment_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "fxs"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.fxs_id.is_set or
                                    self.segment_type.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fxs_id.yfilter != YFilter.not_set or
                                    self.segment_type.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "fxs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fxs_id.is_set or self.fxs_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxs_id.get_name_leafdata())
                                if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxs-id" or name == "segment-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fxs-id"):
                                    self.fxs_id = value
                                    self.fxs_id.value_namespace = name_space
                                    self.fxs_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-type"):
                                    self.segment_type = value
                                    self.segment_type.value_namespace = name_space
                                    self.segment_type.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBal>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment2"

                                self.ac_id = YLeaf(YType.uint32, "ac-id")

                                self.active = YLeaf(YType.boolean, "active")

                                self.backup_configured = YLeaf(YType.boolean, "backup-configured")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.context = YLeaf(YType.uint16, "context")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.global_id = YLeaf(YType.uint32, "global-id")

                                self.group_id = YLeaf(YType.uint32, "group-id")

                                self.group_state = YLeaf(YType.enumeration, "group-state")

                                self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                                self.pw_load_balance_type = YLeaf(YType.enumeration, "pw-load-balance-type")

                                self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                self.sequence_resync_threshold = YLeaf(YType.uint16, "sequence-resync-threshold")

                                self.signal_capability_flags = YLeaf(YType.uint32, "signal-capability-flags")

                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._children_yang_names.add("backup-pseudo-wire")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                self._children_yang_names.add("pseudo-wire-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ac_id",
                                                "active",
                                                "backup_configured",
                                                "bound",
                                                "context",
                                                "forward_class",
                                                "global_id",
                                                "group_id",
                                                "group_state",
                                                "grouping_supported",
                                                "next_hop_valid",
                                                "pseudo_wire_id_type",
                                                "pw_flow_label_tx",
                                                "pw_id",
                                                "pw_load_balance_type",
                                                "redundancy_role",
                                                "sequence_resync_threshold",
                                                "signal_capability_flags") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"
                                    self._children_yang_names.add("l2tp")

                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._children_yang_names.add("l2tp-ipv6-ts")

                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"
                                    self._children_yang_names.add("l2tpv2")

                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"
                                    self._children_yang_names.add("mpls")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion, self).__setattr__(name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix


                                class L2Tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_mtu",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_mtu.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "path-mtu" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix


                                class L2Tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.protocol = YLeaf(YType.uint16, "protocol")

                                        self.pw_flags = YLeaf(YType.uint8, "pw-flags")

                                        self.rem_udp_port = YLeaf(YType.uint16, "rem-udp-port")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop_address",
                                                        "path_mtu",
                                                        "protocol",
                                                        "pw_flags",
                                                        "rem_udp_port",
                                                        "source_address",
                                                        "tos_val",
                                                        "ttl",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.next_hop_address.is_set or
                                            self.path_mtu.is_set or
                                            self.protocol.is_set or
                                            self.pw_flags.is_set or
                                            self.rem_udp_port.is_set or
                                            self.source_address.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            self.xconnect_id.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pw_flags.yfilter != YFilter.not_set or
                                            self.rem_udp_port.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv2" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pw_flags.is_set or self.pw_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flags.get_name_leafdata())
                                        if (self.rem_udp_port.is_set or self.rem_udp_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_udp_port.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "next-hop-address" or name == "path-mtu" or name == "protocol" or name == "pw-flags" or name == "rem-udp-port" or name == "source-address" or name == "tos-val" or name == "ttl" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop-address"):
                                            self.next_hop_address = value
                                            self.next_hop_address.value_namespace = name_space
                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flags"):
                                            self.pw_flags = value
                                            self.pw_flags.value_namespace = name_space
                                            self.pw_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-udp-port"):
                                            self.rem_udp_port = value
                                            self.rem_udp_port.value_namespace = name_space
                                            self.rem_udp_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class L2TpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address",
                                                        "path_mtu",
                                                        "remote_address",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.secondary_cookie_high_value = YLeaf(YType.uint32, "secondary-cookie-high-value")

                                            self.secondary_cookie_low_value = YLeaf(YType.uint32, "secondary-cookie-low-value")

                                            self.secondary_cookie_size = YLeaf(YType.uint8, "secondary-cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "secondary_cookie_high_value",
                                                            "secondary_cookie_low_value",
                                                            "secondary_cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.secondary_cookie_high_value.is_set or
                                                self.secondary_cookie_low_value.is_set or
                                                self.secondary_cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.secondary_cookie_high_value.is_set or self.secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_high_value.get_name_leafdata())
                                            if (self.secondary_cookie_low_value.is_set or self.secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_low_value.get_name_leafdata())
                                            if (self.secondary_cookie_size.is_set or self.secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "secondary-cookie-high-value" or name == "secondary-cookie-low-value" or name == "secondary-cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-high-value"):
                                                self.secondary_cookie_high_value = value
                                                self.secondary_cookie_high_value.value_namespace = name_space
                                                self.secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-low-value"):
                                                self.secondary_cookie_low_value = value
                                                self.secondary_cookie_low_value.value_namespace = name_space
                                                self.secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-size"):
                                                self.secondary_cookie_size = value
                                                self.secondary_cookie_size.value_namespace = name_space
                                                self.secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.local_address.is_set or
                                            self.path_mtu.is_set or
                                            self.remote_address.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp-ipv6-ts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "local-address" or name == "path-mtu" or name == "remote-address" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        (self.l2tp is not None and self.l2tp.has_data()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_data()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_data()) or
                                        (self.mpls is not None and self.mpls.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        (self.l2tp is not None and self.l2tp.has_operation()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_operation()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_operation()) or
                                        (self.mpls is not None and self.mpls.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudo-wire-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2tp"):
                                        if (self.l2tp is None):
                                            self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp()
                                            self.l2tp.parent = self
                                            self._children_name_map["l2tp"] = "l2tp"
                                        return self.l2tp

                                    if (child_yang_name == "l2tp-ipv6-ts"):
                                        if (self.l2tp_ipv6_ts is None):
                                            self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                            self.l2tp_ipv6_ts.parent = self
                                            self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                        return self.l2tp_ipv6_ts

                                    if (child_yang_name == "l2tpv2"):
                                        if (self.l2tpv2 is None):
                                            self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                            self.l2tpv2.parent = self
                                            self._children_name_map["l2tpv2"] = "l2tpv2"
                                        return self.l2tpv2

                                    if (child_yang_name == "mpls"):
                                        if (self.mpls is None):
                                            self.mpls = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                        return self.mpls

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2tp" or name == "l2tp-ipv6-ts" or name == "l2tpv2" or name == "mpls" or name == "data-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.backup_next_hop = YLeaf(YType.str, "backup-next-hop")

                                    self.backup_pseudo_wire_id = YLeaf(YType.uint32, "backup-pseudo-wire-id")

                                    self.backup_pseudo_wire_id_type = YLeaf(YType.enumeration, "backup-pseudo-wire-id-type")

                                    self.bound = YLeaf(YType.boolean, "bound")

                                    self.group_id = YLeaf(YType.uint32, "group-id")

                                    self.group_state = YLeaf(YType.enumeration, "group-state")

                                    self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                    self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                    self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "backup_next_hop",
                                                    "backup_pseudo_wire_id",
                                                    "backup_pseudo_wire_id_type",
                                                    "bound",
                                                    "group_id",
                                                    "group_state",
                                                    "grouping_supported",
                                                    "pw_flow_label_tx",
                                                    "redundancy_role") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.backup_next_hop.is_set or
                                        self.backup_pseudo_wire_id.is_set or
                                        self.backup_pseudo_wire_id_type.is_set or
                                        self.bound.is_set or
                                        self.group_id.is_set or
                                        self.group_state.is_set or
                                        self.grouping_supported.is_set or
                                        self.pw_flow_label_tx.is_set or
                                        self.redundancy_role.is_set or
                                        (self.atom is not None and self.atom.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.backup_next_hop.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set or
                                        self.bound.yfilter != YFilter.not_set or
                                        self.group_id.yfilter != YFilter.not_set or
                                        self.group_state.yfilter != YFilter.not_set or
                                        self.grouping_supported.yfilter != YFilter.not_set or
                                        self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                        self.redundancy_role.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-pseudo-wire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.backup_next_hop.is_set or self.backup_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_next_hop.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id.is_set or self.backup_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id_type.is_set or self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id_type.get_name_leafdata())
                                    if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bound.get_name_leafdata())
                                    if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_id.get_name_leafdata())
                                    if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_state.get_name_leafdata())
                                    if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                    if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                    if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_role.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "active" or name == "backup-next-hop" or name == "backup-pseudo-wire-id" or name == "backup-pseudo-wire-id-type" or name == "bound" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "pw-flow-label-tx" or name == "redundancy-role"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-next-hop"):
                                        self.backup_next_hop = value
                                        self.backup_next_hop.value_namespace = name_space
                                        self.backup_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id"):
                                        self.backup_pseudo_wire_id = value
                                        self.backup_pseudo_wire_id.value_namespace = name_space
                                        self.backup_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id-type"):
                                        self.backup_pseudo_wire_id_type = value
                                        self.backup_pseudo_wire_id_type.value_namespace = name_space
                                        self.backup_pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bound"):
                                        self.bound = value
                                        self.bound.value_namespace = name_space
                                        self.bound.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-id"):
                                        self.group_id = value
                                        self.group_id.value_namespace = name_space
                                        self.group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-state"):
                                        self.group_state = value
                                        self.group_state.value_namespace = name_space
                                        self.group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "grouping-supported"):
                                        self.grouping_supported = value
                                        self.grouping_supported.value_namespace = name_space
                                        self.grouping_supported.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-tx"):
                                        self.pw_flow_label_tx = value
                                        self.pw_flow_label_tx.value_namespace = name_space
                                        self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-role"):
                                        self.redundancy_role = value
                                        self.redundancy_role.value_namespace = name_space
                                        self.redundancy_role.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ac_id.is_set or
                                    self.active.is_set or
                                    self.backup_configured.is_set or
                                    self.bound.is_set or
                                    self.context.is_set or
                                    self.forward_class.is_set or
                                    self.global_id.is_set or
                                    self.group_id.is_set or
                                    self.group_state.is_set or
                                    self.grouping_supported.is_set or
                                    self.next_hop_valid.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_flow_label_tx.is_set or
                                    self.pw_id.is_set or
                                    self.pw_load_balance_type.is_set or
                                    self.redundancy_role.is_set or
                                    self.sequence_resync_threshold.is_set or
                                    self.signal_capability_flags.is_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_data()) or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ac_id.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.backup_configured.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.context.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.global_id.yfilter != YFilter.not_set or
                                    self.group_id.yfilter != YFilter.not_set or
                                    self.group_state.yfilter != YFilter.not_set or
                                    self.grouping_supported.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.pw_load_balance_type.yfilter != YFilter.not_set or
                                    self.redundancy_role.yfilter != YFilter.not_set or
                                    self.sequence_resync_threshold.yfilter != YFilter.not_set or
                                    self.signal_capability_flags.yfilter != YFilter.not_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_operation()) or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ac_id.is_set or self.ac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac_id.get_name_leafdata())
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.backup_configured.is_set or self.backup_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_configured.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.context.is_set or self.context.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.context.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.global_id.is_set or self.global_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_id.get_name_leafdata())
                                if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_id.get_name_leafdata())
                                if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_state.get_name_leafdata())
                                if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.pw_load_balance_type.is_set or self.pw_load_balance_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_load_balance_type.get_name_leafdata())
                                if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_role.get_name_leafdata())
                                if (self.sequence_resync_threshold.is_set or self.sequence_resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_resync_threshold.get_name_leafdata())
                                if (self.signal_capability_flags.is_set or self.signal_capability_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signal_capability_flags.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-pseudo-wire"):
                                    if (self.backup_pseudo_wire is None):
                                        self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire()
                                        self.backup_pseudo_wire.parent = self
                                        self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                    return self.backup_pseudo_wire

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                if (child_yang_name == "pseudo-wire-union"):
                                    if (self.pseudo_wire_union is None):
                                        self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion()
                                        self.pseudo_wire_union.parent = self
                                        self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                    return self.pseudo_wire_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-pseudo-wire" or name == "base" or name == "next-hop" or name == "pseudo-wire-union" or name == "ac-id" or name == "active" or name == "backup-configured" or name == "bound" or name == "context" or name == "forward-class" or name == "global-id" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "next-hop-valid" or name == "pseudo-wire-id-type" or name == "pw-flow-label-tx" or name == "pw-id" or name == "pw-load-balance-type" or name == "redundancy-role" or name == "sequence-resync-threshold" or name == "signal-capability-flags"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ac-id"):
                                    self.ac_id = value
                                    self.ac_id.value_namespace = name_space
                                    self.ac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-configured"):
                                    self.backup_configured = value
                                    self.backup_configured.value_namespace = name_space
                                    self.backup_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "context"):
                                    self.context = value
                                    self.context.value_namespace = name_space
                                    self.context.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "global-id"):
                                    self.global_id = value
                                    self.global_id.value_namespace = name_space
                                    self.global_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-id"):
                                    self.group_id = value
                                    self.group_id.value_namespace = name_space
                                    self.group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-state"):
                                    self.group_state = value
                                    self.group_state.value_namespace = name_space
                                    self.group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "grouping-supported"):
                                    self.grouping_supported = value
                                    self.grouping_supported.value_namespace = name_space
                                    self.grouping_supported.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-tx"):
                                    self.pw_flow_label_tx = value
                                    self.pw_flow_label_tx.value_namespace = name_space
                                    self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-load-balance-type"):
                                    self.pw_load_balance_type = value
                                    self.pw_load_balance_type.value_namespace = name_space
                                    self.pw_load_balance_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-role"):
                                    self.redundancy_role = value
                                    self.redundancy_role.value_namespace = name_space
                                    self.redundancy_role.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-resync-threshold"):
                                    self.sequence_resync_threshold = value
                                    self.sequence_resync_threshold.value_namespace = name_space
                                    self.sequence_resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "signal-capability-flags"):
                                    self.signal_capability_flags = value
                                    self.signal_capability_flags.value_namespace = name_space
                                    self.signal_capability_flags.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.bp is not None and self.bp.has_data()) or
                                (self.fxs is not None and self.fxs.has_data()) or
                                (self.pw is not None and self.pw.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.bp is not None and self.bp.has_operation()) or
                                (self.fxs is not None and self.fxs.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "bp"):
                                if (self.bp is None):
                                    self.bp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp()
                                    self.bp.parent = self
                                    self._children_name_map["bp"] = "bp"
                                return self.bp

                            if (child_yang_name == "fxs"):
                                if (self.fxs is None):
                                    self.fxs = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs()
                                    self.fxs.parent = self
                                    self._children_name_map["fxs"] = "fxs"
                                return self.fxs

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "bp" or name == "fxs" or name == "pw" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.xcid.is_set or
                            self.bound.is_set or
                            self.switching_type.is_set or
                            self.xcon_name.is_set or
                            (self.base is not None and self.base.has_data()) or
                            (self.segment1 is not None and self.segment1.has_data()) or
                            (self.segment2 is not None and self.segment2.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.xcid.yfilter != YFilter.not_set or
                            self.bound.yfilter != YFilter.not_set or
                            self.switching_type.yfilter != YFilter.not_set or
                            self.xcon_name.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()) or
                            (self.segment1 is not None and self.segment1.has_operation()) or
                            (self.segment2 is not None and self.segment2.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fibx-con" + "[xcid='" + self.xcid.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xcid.get_name_leafdata())
                        if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bound.get_name_leafdata())
                        if (self.switching_type.is_set or self.switching_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.switching_type.get_name_leafdata())
                        if (self.xcon_name.is_set or self.xcon_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xcon_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        if (child_yang_name == "segment1"):
                            if (self.segment1 is None):
                                self.segment1 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1()
                                self.segment1.parent = self
                                self._children_name_map["segment1"] = "segment1"
                            return self.segment1

                        if (child_yang_name == "segment2"):
                            if (self.segment2 is None):
                                self.segment2 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2()
                                self.segment2.parent = self
                                self._children_name_map["segment2"] = "segment2"
                            return self.segment2

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "segment1" or name == "segment2" or name == "xcid" or name == "bound" or name == "switching-type" or name == "xcon-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "xcid"):
                            self.xcid = value
                            self.xcid.value_namespace = name_space
                            self.xcid.value_namespace_prefix = name_space_prefix
                        if(value_path == "bound"):
                            self.bound = value
                            self.bound.value_namespace = name_space
                            self.bound.value_namespace_prefix = name_space_prefix
                        if(value_path == "switching-type"):
                            self.switching_type = value
                            self.switching_type.value_namespace = name_space
                            self.switching_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "xcon-name"):
                            self.xcon_name = value
                            self.xcon_name.value_namespace = name_space
                            self.xcon_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fibx_con:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fibx_con:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fibx-cons" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fibx-con"):
                        for c in self.l2fibx_con:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fibx_con.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fibx-con"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMainInterfaces(Entity):
                """
                Main Interface
                
                .. attribute:: l2fib_main_interface
                
                	Main Interface Table
                	**type**\: list of    :py:class:`L2FibMainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces, self).__init__()

                    self.yang_name = "l2fib-main-interfaces"
                    self.yang_parent_name = "node"

                    self.l2fib_main_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces, self).__setattr__(name, value)


                class L2FibMainInterface(Entity):
                    """
                    Main Interface Table
                    
                    .. attribute:: l2fib_main_interface_detail_info
                    
                    	Main Interface detail info
                    	**type**\:   :py:class:`L2FibMainInterfaceDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_egress_detail_info
                    
                    	Main Interface hardware egress detail info
                    	**type**\:   :py:class:`L2FibMainInterfaceHardwareEgressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_egress_info
                    
                    	Main Interface hardware egress info
                    	**type**\:   :py:class:`L2FibMainInterfaceHardwareEgressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_ingress_detail_info
                    
                    	Main Interface hardware ingress detail info
                    	**type**\:   :py:class:`L2FibMainInterfaceHardwareIngressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_ingress_info
                    
                    	Main Interface hardware ingress info
                    	**type**\:   :py:class:`L2FibMainInterfaceHardwareIngressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressInfo>`
                    
                    .. attribute:: l2fib_main_interface_info
                    
                    	Main Interface info
                    	**type**\:   :py:class:`L2FibMainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInfo>`
                    
                    .. attribute:: l2fib_main_interface_instances
                    
                    	Main Interface Instance table
                    	**type**\:   :py:class:`L2FibMainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances>`
                    
                    .. attribute:: main_interface_id
                    
                    	Main interface id
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: main_interface_type
                    
                    	Main interface type
                    	**type**\:   :py:class:`EvpnMainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.EvpnMainInterface>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface, self).__init__()

                        self.yang_name = "l2fib-main-interface"
                        self.yang_parent_name = "l2fib-main-interfaces"

                        self.main_interface_id = YLeaf(YType.int32, "main-interface-id")

                        self.main_interface_type = YLeaf(YType.enumeration, "main-interface-type")

                        self.l2fib_main_interface_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo()
                        self.l2fib_main_interface_detail_info.parent = self
                        self._children_name_map["l2fib_main_interface_detail_info"] = "l2fib-main-interface-detail-info"
                        self._children_yang_names.add("l2fib-main-interface-detail-info")

                        self.l2fib_main_interface_hardware_egress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo()
                        self.l2fib_main_interface_hardware_egress_detail_info.parent = self
                        self._children_name_map["l2fib_main_interface_hardware_egress_detail_info"] = "l2fib-main-interface-hardware-egress-detail-info"
                        self._children_yang_names.add("l2fib-main-interface-hardware-egress-detail-info")

                        self.l2fib_main_interface_hardware_egress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressInfo()
                        self.l2fib_main_interface_hardware_egress_info.parent = self
                        self._children_name_map["l2fib_main_interface_hardware_egress_info"] = "l2fib-main-interface-hardware-egress-info"
                        self._children_yang_names.add("l2fib-main-interface-hardware-egress-info")

                        self.l2fib_main_interface_hardware_ingress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo()
                        self.l2fib_main_interface_hardware_ingress_detail_info.parent = self
                        self._children_name_map["l2fib_main_interface_hardware_ingress_detail_info"] = "l2fib-main-interface-hardware-ingress-detail-info"
                        self._children_yang_names.add("l2fib-main-interface-hardware-ingress-detail-info")

                        self.l2fib_main_interface_hardware_ingress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressInfo()
                        self.l2fib_main_interface_hardware_ingress_info.parent = self
                        self._children_name_map["l2fib_main_interface_hardware_ingress_info"] = "l2fib-main-interface-hardware-ingress-info"
                        self._children_yang_names.add("l2fib-main-interface-hardware-ingress-info")

                        self.l2fib_main_interface_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInfo()
                        self.l2fib_main_interface_info.parent = self
                        self._children_name_map["l2fib_main_interface_info"] = "l2fib-main-interface-info"
                        self._children_yang_names.add("l2fib-main-interface-info")

                        self.l2fib_main_interface_instances = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances()
                        self.l2fib_main_interface_instances.parent = self
                        self._children_name_map["l2fib_main_interface_instances"] = "l2fib-main-interface-instances"
                        self._children_yang_names.add("l2fib-main-interface-instances")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("main_interface_id",
                                        "main_interface_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface, self).__setattr__(name, value)


                    class L2FibMainInterfaceHardwareEgressDetailInfo(Entity):
                        """
                        Main Interface hardware egress detail info
                        
                        .. attribute:: bridge_port_count_instance
                        
                        	Number of bridge ports per instance
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: esi_id
                        
                        	Ethernet segment ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ethernet_segment_identifier
                        
                        	Ethernet Segment Identifier
                        	**type**\:  list of int
                        
                        	**range:** 0..255
                        
                        .. attribute:: evpn_shg_local_label
                        
                        	EVPN split horizon group local label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_shg_remote_info
                        
                        	EVPN split horizon group remote info
                        	**type**\: list of    :py:class:`EvpnShgRemoteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo>`
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                        
                        .. attribute:: mac
                        
                        	MAC Address
                        	**type**\:  str
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-hardware-egress-detail-info"
                            self.yang_parent_name = "l2fib-main-interface"

                            self.bridge_port_count_instance = YLeafList(YType.uint32, "bridge-port-count-instance")

                            self.esi_id = YLeaf(YType.uint16, "esi-id")

                            self.ethernet_segment_identifier = YLeafList(YType.uint8, "ethernet-segment-identifier")

                            self.evpn_shg_local_label = YLeaf(YType.uint32, "evpn-shg-local-label")

                            self.instance_id = YLeafList(YType.uint32, "instance-id")

                            self.instances_provisioned = YLeafList(YType.boolean, "instances-provisioned")

                            self.instances_state = YLeafList(YType.enumeration, "instances-state")

                            self.mac = YLeaf(YType.str, "mac")

                            self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                            self.main_interface = YLeaf(YType.str, "main-interface")

                            self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                            self.evpn_shg_remote_info = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bridge_port_count_instance",
                                            "esi_id",
                                            "ethernet_segment_identifier",
                                            "evpn_shg_local_label",
                                            "instance_id",
                                            "instances_provisioned",
                                            "instances_state",
                                            "mac",
                                            "main_if_type",
                                            "main_interface",
                                            "virtual_if_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo, self).__setattr__(name, value)


                        class EvpnShgRemoteInfo(Entity):
                            """
                            EVPN split horizon group remote info
                            
                            .. attribute:: remote_split_horizon_group_label
                            
                            	Remote split horizon group label
                            	**type**\:   :py:class:`RemoteSplitHorizonGroupLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo, self).__init__()

                                self.yang_name = "evpn-shg-remote-info"
                                self.yang_parent_name = "l2fib-main-interface-hardware-egress-detail-info"

                                self.remote_split_horizon_group_label = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                self.remote_split_horizon_group_label.parent = self
                                self._children_name_map["remote_split_horizon_group_label"] = "remote-split-horizon-group-label"
                                self._children_yang_names.add("remote-split-horizon-group-label")


                            class RemoteSplitHorizonGroupLabel(Entity):
                                """
                                Remote split horizon group label
                                
                                .. attribute:: label
                                
                                	Split horizon label associated with next\-hop address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	Next\-hop IP address (v6 format)
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__init__()

                                    self.yang_name = "remote-split-horizon-group-label"
                                    self.yang_parent_name = "evpn-shg-remote-info"

                                    self.label = YLeaf(YType.uint32, "label")

                                    self.next_hop = YLeaf(YType.str, "next-hop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("label",
                                                    "next_hop") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.label.is_set or
                                        self.next_hop.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.label.yfilter != YFilter.not_set or
                                        self.next_hop.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-split-horizon-group-label" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.label.is_set or self.label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label.get_name_leafdata())
                                    if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "label" or name == "next-hop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "label"):
                                        self.label = value
                                        self.label.value_namespace = name_space
                                        self.label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop"):
                                        self.next_hop = value
                                        self.next_hop.value_namespace = name_space
                                        self.next_hop.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (self.remote_split_horizon_group_label is not None and self.remote_split_horizon_group_label.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.remote_split_horizon_group_label is not None and self.remote_split_horizon_group_label.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn-shg-remote-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "remote-split-horizon-group-label"):
                                    if (self.remote_split_horizon_group_label is None):
                                        self.remote_split_horizon_group_label = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                        self.remote_split_horizon_group_label.parent = self
                                        self._children_name_map["remote_split_horizon_group_label"] = "remote-split-horizon-group-label"
                                    return self.remote_split_horizon_group_label

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "remote-split-horizon-group-label"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            for c in self.evpn_shg_remote_info:
                                if (c.has_data()):
                                    return True
                            for leaf in self.bridge_port_count_instance.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.ethernet_segment_identifier.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.esi_id.is_set or
                                self.evpn_shg_local_label.is_set or
                                self.mac.is_set or
                                self.main_if_type.is_set or
                                self.main_interface.is_set or
                                self.virtual_if_name.is_set)

                        def has_operation(self):
                            for c in self.evpn_shg_remote_info:
                                if (c.has_operation()):
                                    return True
                            for leaf in self.bridge_port_count_instance.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.ethernet_segment_identifier.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bridge_port_count_instance.yfilter != YFilter.not_set or
                                self.esi_id.yfilter != YFilter.not_set or
                                self.ethernet_segment_identifier.yfilter != YFilter.not_set or
                                self.evpn_shg_local_label.yfilter != YFilter.not_set or
                                self.instance_id.yfilter != YFilter.not_set or
                                self.instances_provisioned.yfilter != YFilter.not_set or
                                self.instances_state.yfilter != YFilter.not_set or
                                self.mac.yfilter != YFilter.not_set or
                                self.main_if_type.yfilter != YFilter.not_set or
                                self.main_interface.yfilter != YFilter.not_set or
                                self.virtual_if_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-main-interface-hardware-egress-detail-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.esi_id.is_set or self.esi_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.esi_id.get_name_leafdata())
                            if (self.evpn_shg_local_label.is_set or self.evpn_shg_local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_shg_local_label.get_name_leafdata())
                            if (self.mac.is_set or self.mac.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac.get_name_leafdata())
                            if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_if_type.get_name_leafdata())
                            if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_interface.get_name_leafdata())
                            if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                            leaf_name_data.extend(self.bridge_port_count_instance.get_name_leafdata())

                            leaf_name_data.extend(self.ethernet_segment_identifier.get_name_leafdata())

                            leaf_name_data.extend(self.instance_id.get_name_leafdata())

                            leaf_name_data.extend(self.instances_provisioned.get_name_leafdata())

                            leaf_name_data.extend(self.instances_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "evpn-shg-remote-info"):
                                for c in self.evpn_shg_remote_info:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.evpn_shg_remote_info.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "evpn-shg-remote-info" or name == "bridge-port-count-instance" or name == "esi-id" or name == "ethernet-segment-identifier" or name == "evpn-shg-local-label" or name == "instance-id" or name == "instances-provisioned" or name == "instances-state" or name == "mac" or name == "main-if-type" or name == "main-interface" or name == "virtual-if-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bridge-port-count-instance"):
                                self.bridge_port_count_instance.append(value)
                            if(value_path == "esi-id"):
                                self.esi_id = value
                                self.esi_id.value_namespace = name_space
                                self.esi_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ethernet-segment-identifier"):
                                self.ethernet_segment_identifier.append(value)
                            if(value_path == "evpn-shg-local-label"):
                                self.evpn_shg_local_label = value
                                self.evpn_shg_local_label.value_namespace = name_space
                                self.evpn_shg_local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "instance-id"):
                                self.instance_id.append(value)
                            if(value_path == "instances-provisioned"):
                                self.instances_provisioned.append(value)
                            if(value_path == "instances-state"):
                                self.instances_state.append(value)
                            if(value_path == "mac"):
                                self.mac = value
                                self.mac.value_namespace = name_space
                                self.mac.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-if-type"):
                                self.main_if_type = value
                                self.main_if_type.value_namespace = name_space
                                self.main_if_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-interface"):
                                self.main_interface = value
                                self.main_interface.value_namespace = name_space
                                self.main_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-if-name"):
                                self.virtual_if_name = value
                                self.virtual_if_name.value_namespace = name_space
                                self.virtual_if_name.value_namespace_prefix = name_space_prefix


                    class L2FibMainInterfaceHardwareEgressInfo(Entity):
                        """
                        Main Interface hardware egress info
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-hardware-egress-info"
                            self.yang_parent_name = "l2fib-main-interface"

                            self.instance_id = YLeafList(YType.uint32, "instance-id")

                            self.instances_provisioned = YLeafList(YType.boolean, "instances-provisioned")

                            self.instances_state = YLeafList(YType.enumeration, "instances-state")

                            self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                            self.main_interface = YLeaf(YType.str, "main-interface")

                            self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("instance_id",
                                            "instances_provisioned",
                                            "instances_state",
                                            "main_if_type",
                                            "main_interface",
                                            "virtual_if_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressInfo, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.main_if_type.is_set or
                                self.main_interface.is_set or
                                self.virtual_if_name.is_set)

                        def has_operation(self):
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.instance_id.yfilter != YFilter.not_set or
                                self.instances_provisioned.yfilter != YFilter.not_set or
                                self.instances_state.yfilter != YFilter.not_set or
                                self.main_if_type.yfilter != YFilter.not_set or
                                self.main_interface.yfilter != YFilter.not_set or
                                self.virtual_if_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-main-interface-hardware-egress-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_if_type.get_name_leafdata())
                            if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_interface.get_name_leafdata())
                            if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                            leaf_name_data.extend(self.instance_id.get_name_leafdata())

                            leaf_name_data.extend(self.instances_provisioned.get_name_leafdata())

                            leaf_name_data.extend(self.instances_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "instance-id" or name == "instances-provisioned" or name == "instances-state" or name == "main-if-type" or name == "main-interface" or name == "virtual-if-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "instance-id"):
                                self.instance_id.append(value)
                            if(value_path == "instances-provisioned"):
                                self.instances_provisioned.append(value)
                            if(value_path == "instances-state"):
                                self.instances_state.append(value)
                            if(value_path == "main-if-type"):
                                self.main_if_type = value
                                self.main_if_type.value_namespace = name_space
                                self.main_if_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-interface"):
                                self.main_interface = value
                                self.main_interface.value_namespace = name_space
                                self.main_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-if-name"):
                                self.virtual_if_name = value
                                self.virtual_if_name.value_namespace = name_space
                                self.virtual_if_name.value_namespace_prefix = name_space_prefix


                    class L2FibMainInterfaceInstances(Entity):
                        """
                        Main Interface Instance table
                        
                        .. attribute:: l2fib_main_interface_instance
                        
                        	Main Interface Instance
                        	**type**\: list of    :py:class:`L2FibMainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances, self).__init__()

                            self.yang_name = "l2fib-main-interface-instances"
                            self.yang_parent_name = "l2fib-main-interface"

                            self.l2fib_main_interface_instance = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances, self).__setattr__(name, value)


                        class L2FibMainInterfaceInstance(Entity):
                            """
                            Main Interface Instance
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: l2fib_main_interface_instance_bridge_port_details
                            
                            	Main Interface Instance Bridge Port detail table
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceBridgePortDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails>`
                            
                            .. attribute:: l2fib_main_interface_instance_bridge_ports
                            
                            	Main Interface Instance Bridge Port table
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts>`
                            
                            .. attribute:: l2fib_main_interface_instance_detail_info
                            
                            	Main Interface Instance detail info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceDetailInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_egress_detail_info
                            
                            	Main Interface Instance hardware egress detail info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceHardwareEgressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressDetailInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_egress_info
                            
                            	Main Interface Instance hardware egress info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceHardwareEgressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_ingress_detail_info
                            
                            	Main Interface Instance hardware ingress detail info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceHardwareIngressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressDetailInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_ingress_info
                            
                            	Main Interface Instance hardware ingress info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceHardwareIngressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_info
                            
                            	Main Interface Instance info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceInfo>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance, self).__init__()

                                self.yang_name = "l2fib-main-interface-instance"
                                self.yang_parent_name = "l2fib-main-interface-instances"

                                self.instance = YLeaf(YType.int32, "instance")

                                self.l2fib_main_interface_instance_bridge_port_details = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails()
                                self.l2fib_main_interface_instance_bridge_port_details.parent = self
                                self._children_name_map["l2fib_main_interface_instance_bridge_port_details"] = "l2fib-main-interface-instance-bridge-port-details"
                                self._children_yang_names.add("l2fib-main-interface-instance-bridge-port-details")

                                self.l2fib_main_interface_instance_bridge_ports = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts()
                                self.l2fib_main_interface_instance_bridge_ports.parent = self
                                self._children_name_map["l2fib_main_interface_instance_bridge_ports"] = "l2fib-main-interface-instance-bridge-ports"
                                self._children_yang_names.add("l2fib-main-interface-instance-bridge-ports")

                                self.l2fib_main_interface_instance_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceDetailInfo()
                                self.l2fib_main_interface_instance_detail_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_detail_info"] = "l2fib-main-interface-instance-detail-info"
                                self._children_yang_names.add("l2fib-main-interface-instance-detail-info")

                                self.l2fib_main_interface_instance_hardware_egress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressDetailInfo()
                                self.l2fib_main_interface_instance_hardware_egress_detail_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_hardware_egress_detail_info"] = "l2fib-main-interface-instance-hardware-egress-detail-info"
                                self._children_yang_names.add("l2fib-main-interface-instance-hardware-egress-detail-info")

                                self.l2fib_main_interface_instance_hardware_egress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressInfo()
                                self.l2fib_main_interface_instance_hardware_egress_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_hardware_egress_info"] = "l2fib-main-interface-instance-hardware-egress-info"
                                self._children_yang_names.add("l2fib-main-interface-instance-hardware-egress-info")

                                self.l2fib_main_interface_instance_hardware_ingress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressDetailInfo()
                                self.l2fib_main_interface_instance_hardware_ingress_detail_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_hardware_ingress_detail_info"] = "l2fib-main-interface-instance-hardware-ingress-detail-info"
                                self._children_yang_names.add("l2fib-main-interface-instance-hardware-ingress-detail-info")

                                self.l2fib_main_interface_instance_hardware_ingress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressInfo()
                                self.l2fib_main_interface_instance_hardware_ingress_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_hardware_ingress_info"] = "l2fib-main-interface-instance-hardware-ingress-info"
                                self._children_yang_names.add("l2fib-main-interface-instance-hardware-ingress-info")

                                self.l2fib_main_interface_instance_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceInfo()
                                self.l2fib_main_interface_instance_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_info"] = "l2fib-main-interface-instance-info"
                                self._children_yang_names.add("l2fib-main-interface-instance-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("instance") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance, self).__setattr__(name, value)


                            class L2FibMainInterfaceInstanceDetailInfo(Entity):
                                """
                                Main Interface Instance detail info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceDetailInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-detail-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"

                                    self.bridge_port_count = YLeaf(YType.uint32, "bridge-port-count")

                                    self.instance = YLeaf(YType.uint32, "instance")

                                    self.instance_provisioned = YLeaf(YType.boolean, "instance-provisioned")

                                    self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                                    self.main_interface = YLeaf(YType.str, "main-interface")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bridge_port_count",
                                                    "instance",
                                                    "instance_provisioned",
                                                    "main_if_type",
                                                    "main_interface",
                                                    "state",
                                                    "virtual_if_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceDetailInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceDetailInfo, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bridge_port_count.is_set or
                                        self.instance.is_set or
                                        self.instance_provisioned.is_set or
                                        self.main_if_type.is_set or
                                        self.main_interface.is_set or
                                        self.state.is_set or
                                        self.virtual_if_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bridge_port_count.yfilter != YFilter.not_set or
                                        self.instance.yfilter != YFilter.not_set or
                                        self.instance_provisioned.yfilter != YFilter.not_set or
                                        self.main_if_type.yfilter != YFilter.not_set or
                                        self.main_interface.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.virtual_if_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fib-main-interface-instance-detail-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bridge_port_count.is_set or self.bridge_port_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_count.get_name_leafdata())
                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                    if (self.instance_provisioned.is_set or self.instance_provisioned.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_provisioned.get_name_leafdata())
                                    if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_if_type.get_name_leafdata())
                                    if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_interface.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bridge-port-count" or name == "instance" or name == "instance-provisioned" or name == "main-if-type" or name == "main-interface" or name == "state" or name == "virtual-if-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bridge-port-count"):
                                        self.bridge_port_count = value
                                        self.bridge_port_count.value_namespace = name_space
                                        self.bridge_port_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance"):
                                        self.instance = value
                                        self.instance.value_namespace = name_space
                                        self.instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-provisioned"):
                                        self.instance_provisioned = value
                                        self.instance_provisioned.value_namespace = name_space
                                        self.instance_provisioned.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-if-type"):
                                        self.main_if_type = value
                                        self.main_if_type.value_namespace = name_space
                                        self.main_if_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-interface"):
                                        self.main_interface = value
                                        self.main_interface.value_namespace = name_space
                                        self.main_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-if-name"):
                                        self.virtual_if_name = value
                                        self.virtual_if_name.value_namespace = name_space
                                        self.virtual_if_name.value_namespace_prefix = name_space_prefix


                            class L2FibMainInterfaceInstanceBridgePortDetails(Entity):
                                """
                                Main Interface Instance Bridge Port detail
                                table
                                
                                .. attribute:: l2fib_main_interface_instance_bridge_port_detail
                                
                                	Main Interface Bridge Port detail info
                                	**type**\: list of    :py:class:`L2FibMainInterfaceInstanceBridgePortDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-bridge-port-details"
                                    self.yang_parent_name = "l2fib-main-interface-instance"

                                    self.l2fib_main_interface_instance_bridge_port_detail = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails, self).__setattr__(name, value)


                                class L2FibMainInterfaceInstanceBridgePortDetail(Entity):
                                    """
                                    Main Interface Bridge Port detail info
                                    
                                    .. attribute:: bridge_port  <key>
                                    
                                    	Bridge Port
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: bp_type
                                    
                                    	Bridge Port Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: bridge_id
                                    
                                    	Bridge ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bridge_port_id
                                    
                                    	Bridge Port ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: main_if_type
                                    
                                    	Main Interface Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: main_interface
                                    
                                    	Main interface ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: oper
                                    
                                    	Operational information
                                    	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper>`
                                    
                                    .. attribute:: state
                                    
                                    	Instance state
                                    	**type**\:   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                                    
                                    .. attribute:: virtual_if_name
                                    
                                    	Virtual Main IfName
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail, self).__init__()

                                        self.yang_name = "l2fib-main-interface-instance-bridge-port-detail"
                                        self.yang_parent_name = "l2fib-main-interface-instance-bridge-port-details"

                                        self.bridge_port = YLeaf(YType.str, "bridge-port")

                                        self.bp_type = YLeaf(YType.uint8, "bp-type")

                                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                                        self.bridge_port_id = YLeaf(YType.str, "bridge-port-id")

                                        self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                                        self.main_interface = YLeaf(YType.str, "main-interface")

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                                        self.oper = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper()
                                        self.oper.parent = self
                                        self._children_name_map["oper"] = "oper"
                                        self._children_yang_names.add("oper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bridge_port",
                                                        "bp_type",
                                                        "bridge_id",
                                                        "bridge_port_id",
                                                        "main_if_type",
                                                        "main_interface",
                                                        "state",
                                                        "virtual_if_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail, self).__setattr__(name, value)


                                    class Oper(Entity):
                                        """
                                        Operational information
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast storm control kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast storm control pps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast storm control kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast storm control pps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: operational_information
                                        
                                        	L2 operational information
                                        	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast storm control kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast storm control pps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper, self).__init__()

                                            self.yang_name = "oper"
                                            self.yang_parent_name = "l2fib-main-interface-instance-bridge-port-detail"

                                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                            self.operational_information = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation()
                                            self.operational_information.parent = self
                                            self._children_name_map["operational_information"] = "operational-information"
                                            self._children_yang_names.add("operational-information")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("broadcast_storm_control_kb_ps",
                                                            "broadcast_storm_control_pps",
                                                            "multicast_storm_control_kb_ps",
                                                            "multicast_storm_control_pps",
                                                            "unicast_storm_control_kb_ps",
                                                            "unicast_storm_control_pps") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper, self).__setattr__(name, value)


                                        class OperationalInformation(Entity):
                                            """
                                            L2 operational information
                                            
                                            .. attribute:: admin_disabled
                                            
                                            	Is administratively disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: bvi_configured
                                            
                                            	Is BVI Interface configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: dhcp_enabled
                                            
                                            	Is DHCP snooping enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: dhcp_trusted
                                            
                                            	Is DHCP trusted
                                            	**type**\:  bool
                                            
                                            .. attribute:: feature
                                            
                                            	Feature information
                                            	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature>`
                                            
                                            .. attribute:: flood_unknown_unicast_enabled
                                            
                                            	Is flooding unknown unicast disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: flooding_disabled
                                            
                                            	Is flooding disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: host_routing_enabled
                                            
                                            	Host Routing enabled on this BD
                                            	**type**\:  bool
                                            
                                            .. attribute:: igmp_flood_forward_enabled
                                            
                                            	Is IGMP flood forwarding enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: igmp_mroute_port_enabled
                                            
                                            	Is mrouter port
                                            	**type**\:  bool
                                            
                                            .. attribute:: igmp_route_guard_enabled
                                            
                                            	Is router gurad enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: igmp_snoop_enabled
                                            
                                            	Is IGMP snooping enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: igmp_snoop_profile_enabled
                                            
                                            	Is IGMP snooping profile enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_bvi_up
                                            
                                            	Is BVI state UP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                            
                                            	Is DAI Destination MAC Validation enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validation_ipv4_enabled
                                            
                                            	Is DAI IPv4 Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validation_source_mac_enabled
                                            
                                            	Is DAI Source MAC Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_enabled
                                            
                                            	Is Dynamic ARP Inspection Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_logging_enabled
                                            
                                            	Is DAI Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_evpn_cw_disable
                                            
                                            	Is EVPN CW disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_evpn_enabled
                                            
                                            	Is EVPN enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_evpn_flow_label
                                            
                                            	Is EVPN Flow Label enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_igmp_snoop_enabled
                                            
                                            	Is IGMP Snooping admin enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ipsg_enabled
                                            
                                            	Is IP Source Guard Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ipsg_logging_enabled
                                            
                                            	Is IP Source Guard Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_accept_shutdown
                                            
                                            	Is MAC secure accept shutdown (BP only)
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_enabled
                                            
                                            	Is MAC Secure Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_logging_enabled
                                            
                                            	Is MAC Secure Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_p2mp_pw_enabled
                                            
                                            	Is P2MP PW enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pbbevpn_enabled
                                            
                                            	Is PBBEVPN enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_swmac_learning
                                            
                                            	Is SW MAC learning enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_vni_enabled
                                            
                                            	Is VNI enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_vpls_flood_optimization_enabled
                                            
                                            	Is MMRP  Flood Optimization Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_aging_time
                                            
                                            	MAC aging time in minutes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: minute
                                            
                                            .. attribute:: mac_aging_type
                                            
                                            	MAC aging type
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_learning_disabled
                                            
                                            	Is MAC learning disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_limit
                                            
                                            	MAC limit
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mac_limit_action
                                            
                                            	MAC limit action
                                            	**type**\:   :py:class:`MgmtL2FibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitAction>`
                                            
                                            .. attribute:: mac_limit_notification_type
                                            
                                            	MAC limit notification
                                            	**type**\:   :py:class:`MgmtL2FibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotify>`
                                            
                                            .. attribute:: mac_port_down_flush_disabled
                                            
                                            	Is MAC port down flush disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_secure_action
                                            
                                            	MAC secure action
                                            	**type**\:   :py:class:`MgmtL2FibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecAction>`
                                            
                                            .. attribute:: mld_flood_forward_enabled
                                            
                                            	Is MLD flood forwarding enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mld_mroute_port_enabled
                                            
                                            	Is mrouter port
                                            	**type**\:  bool
                                            
                                            .. attribute:: mld_route_guard_enabled
                                            
                                            	Is router gurad enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mld_snoop_enabled
                                            
                                            	Is MLD snooping enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mld_snoop_profile_enabled
                                            
                                            	Is MLD snooping profile enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: msti
                                            
                                            	Multi\-spanning tree instance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mtu
                                            
                                            	MTU
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_macs
                                            
                                            	numberOfMacs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                            
                                            	nV Satellite Offload IPv4 Multicast Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: storm_control_broadcast_enabled
                                            
                                            	Is broadcast storm control enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: storm_control_broadcast_rate_unit
                                            
                                            	Storm control broadcast rate unit
                                            	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                            
                                            .. attribute:: storm_control_multicast_enabled
                                            
                                            	Is multicast storm control enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: storm_control_multicast_rate_unit
                                            
                                            	Storm control multicast rate unit
                                            	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                            
                                            .. attribute:: storm_control_unicast_enabled
                                            
                                            	Is unicast storm control enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: storm_control_unicast_rate_unit
                                            
                                            	Storm control unicast rate unit
                                            	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                                            
                                            .. attribute:: stp_participating
                                            
                                            	Is Spanning Tree Protocol participating
                                            	**type**\:  bool
                                            
                                            .. attribute:: unknown_unicast_flooding_disabled
                                            
                                            	Unknown Unicast Flooding is disabled
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation, self).__init__()

                                                self.yang_name = "operational-information"
                                                self.yang_parent_name = "oper"

                                                self.admin_disabled = YLeaf(YType.boolean, "admin-disabled")

                                                self.bvi_configured = YLeaf(YType.boolean, "bvi-configured")

                                                self.dhcp_enabled = YLeaf(YType.boolean, "dhcp-enabled")

                                                self.dhcp_trusted = YLeaf(YType.boolean, "dhcp-trusted")

                                                self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                                self.flooding_disabled = YLeaf(YType.boolean, "flooding-disabled")

                                                self.host_routing_enabled = YLeaf(YType.boolean, "host-routing-enabled")

                                                self.igmp_flood_forward_enabled = YLeaf(YType.boolean, "igmp-flood-forward-enabled")

                                                self.igmp_mroute_port_enabled = YLeaf(YType.boolean, "igmp-mroute-port-enabled")

                                                self.igmp_route_guard_enabled = YLeaf(YType.boolean, "igmp-route-guard-enabled")

                                                self.igmp_snoop_enabled = YLeaf(YType.boolean, "igmp-snoop-enabled")

                                                self.igmp_snoop_profile_enabled = YLeaf(YType.boolean, "igmp-snoop-profile-enabled")

                                                self.is_bvi_up = YLeaf(YType.boolean, "is-bvi-up")

                                                self.is_dai_addr_validation_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-destination-mac-enabled")

                                                self.is_dai_addr_validation_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-ipv4-enabled")

                                                self.is_dai_addr_validation_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-source-mac-enabled")

                                                self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                                self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                                self.is_evpn_cw_disable = YLeaf(YType.boolean, "is-evpn-cw-disable")

                                                self.is_evpn_enabled = YLeaf(YType.boolean, "is-evpn-enabled")

                                                self.is_evpn_flow_label = YLeaf(YType.boolean, "is-evpn-flow-label")

                                                self.is_igmp_snoop_enabled = YLeaf(YType.boolean, "is-igmp-snoop-enabled")

                                                self.is_ipsg_enabled = YLeaf(YType.boolean, "is-ipsg-enabled")

                                                self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                                self.is_mac_secure_accept_shutdown = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown")

                                                self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                                self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                                self.is_p2mp_pw_enabled = YLeaf(YType.boolean, "is-p2mp-pw-enabled")

                                                self.is_pbbevpn_enabled = YLeaf(YType.boolean, "is-pbbevpn-enabled")

                                                self.is_swmac_learning = YLeaf(YType.boolean, "is-swmac-learning")

                                                self.is_vni_enabled = YLeaf(YType.boolean, "is-vni-enabled")

                                                self.is_vpls_flood_optimization_enabled = YLeaf(YType.boolean, "is-vpls-flood-optimization-enabled")

                                                self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                                self.mac_aging_type = YLeaf(YType.boolean, "mac-aging-type")

                                                self.mac_learning_disabled = YLeaf(YType.boolean, "mac-learning-disabled")

                                                self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                                self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                                self.mac_limit_notification_type = YLeaf(YType.enumeration, "mac-limit-notification-type")

                                                self.mac_port_down_flush_disabled = YLeaf(YType.boolean, "mac-port-down-flush-disabled")

                                                self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                                self.mld_flood_forward_enabled = YLeaf(YType.boolean, "mld-flood-forward-enabled")

                                                self.mld_mroute_port_enabled = YLeaf(YType.boolean, "mld-mroute-port-enabled")

                                                self.mld_route_guard_enabled = YLeaf(YType.boolean, "mld-route-guard-enabled")

                                                self.mld_snoop_enabled = YLeaf(YType.boolean, "mld-snoop-enabled")

                                                self.mld_snoop_profile_enabled = YLeaf(YType.boolean, "mld-snoop-profile-enabled")

                                                self.msti = YLeaf(YType.uint32, "msti")

                                                self.mtu = YLeaf(YType.uint32, "mtu")

                                                self.number_of_macs = YLeaf(YType.uint32, "number-of-macs")

                                                self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                                                self.storm_control_broadcast_enabled = YLeaf(YType.boolean, "storm-control-broadcast-enabled")

                                                self.storm_control_broadcast_rate_unit = YLeaf(YType.enumeration, "storm-control-broadcast-rate-unit")

                                                self.storm_control_multicast_enabled = YLeaf(YType.boolean, "storm-control-multicast-enabled")

                                                self.storm_control_multicast_rate_unit = YLeaf(YType.enumeration, "storm-control-multicast-rate-unit")

                                                self.storm_control_unicast_enabled = YLeaf(YType.boolean, "storm-control-unicast-enabled")

                                                self.storm_control_unicast_rate_unit = YLeaf(YType.enumeration, "storm-control-unicast-rate-unit")

                                                self.stp_participating = YLeaf(YType.boolean, "stp-participating")

                                                self.unknown_unicast_flooding_disabled = YLeaf(YType.boolean, "unknown-unicast-flooding-disabled")

                                                self.feature = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("admin_disabled",
                                                                "bvi_configured",
                                                                "dhcp_enabled",
                                                                "dhcp_trusted",
                                                                "flood_unknown_unicast_enabled",
                                                                "flooding_disabled",
                                                                "host_routing_enabled",
                                                                "igmp_flood_forward_enabled",
                                                                "igmp_mroute_port_enabled",
                                                                "igmp_route_guard_enabled",
                                                                "igmp_snoop_enabled",
                                                                "igmp_snoop_profile_enabled",
                                                                "is_bvi_up",
                                                                "is_dai_addr_validation_destination_mac_enabled",
                                                                "is_dai_addr_validation_ipv4_enabled",
                                                                "is_dai_addr_validation_source_mac_enabled",
                                                                "is_dai_enabled",
                                                                "is_dai_logging_enabled",
                                                                "is_evpn_cw_disable",
                                                                "is_evpn_enabled",
                                                                "is_evpn_flow_label",
                                                                "is_igmp_snoop_enabled",
                                                                "is_ipsg_enabled",
                                                                "is_ipsg_logging_enabled",
                                                                "is_mac_secure_accept_shutdown",
                                                                "is_mac_secure_enabled",
                                                                "is_mac_secure_logging_enabled",
                                                                "is_p2mp_pw_enabled",
                                                                "is_pbbevpn_enabled",
                                                                "is_swmac_learning",
                                                                "is_vni_enabled",
                                                                "is_vpls_flood_optimization_enabled",
                                                                "mac_aging_time",
                                                                "mac_aging_type",
                                                                "mac_learning_disabled",
                                                                "mac_limit",
                                                                "mac_limit_action",
                                                                "mac_limit_notification_type",
                                                                "mac_port_down_flush_disabled",
                                                                "mac_secure_action",
                                                                "mld_flood_forward_enabled",
                                                                "mld_mroute_port_enabled",
                                                                "mld_route_guard_enabled",
                                                                "mld_snoop_enabled",
                                                                "mld_snoop_profile_enabled",
                                                                "msti",
                                                                "mtu",
                                                                "number_of_macs",
                                                                "nv_satellite_offload_ipv4_multicast_disabled",
                                                                "storm_control_broadcast_enabled",
                                                                "storm_control_broadcast_rate_unit",
                                                                "storm_control_multicast_enabled",
                                                                "storm_control_multicast_rate_unit",
                                                                "storm_control_unicast_enabled",
                                                                "storm_control_unicast_rate_unit",
                                                                "stp_participating",
                                                                "unknown_unicast_flooding_disabled") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation, self).__setattr__(name, value)


                                            class Feature(Entity):
                                                """
                                                Feature information
                                                
                                                .. attribute:: dhcp
                                                
                                                	dhcp
                                                	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp>`
                                                
                                                .. attribute:: feature_type
                                                
                                                	feature type
                                                	**type**\:   :py:class:`L2FibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeature>`
                                                
                                                .. attribute:: igmp
                                                
                                                	igmp
                                                	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp>`
                                                
                                                .. attribute:: mld
                                                
                                                	mld
                                                	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature, self).__init__()

                                                    self.yang_name = "feature"
                                                    self.yang_parent_name = "operational-information"

                                                    self.feature_type = YLeaf(YType.enumeration, "feature-type")

                                                    self.dhcp = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp()
                                                    self.dhcp.parent = self
                                                    self._children_name_map["dhcp"] = "dhcp"
                                                    self._children_yang_names.add("dhcp")

                                                    self.igmp = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp()
                                                    self.igmp.parent = self
                                                    self._children_name_map["igmp"] = "igmp"
                                                    self._children_yang_names.add("igmp")

                                                    self.mld = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld()
                                                    self.mld.parent = self
                                                    self._children_name_map["mld"] = "mld"
                                                    self._children_yang_names.add("mld")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("feature_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature, self).__setattr__(name, value)


                                                class Dhcp(Entity):
                                                    """
                                                    dhcp
                                                    
                                                    .. attribute:: profile_name
                                                    
                                                    	Feature profile name
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                                        self.yang_name = "dhcp"
                                                        self.yang_parent_name = "feature"

                                                        self.profile_name = YLeaf(YType.str, "profile-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("profile_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.profile_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.profile_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "dhcp" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "profile-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "profile-name"):
                                                            self.profile_name = value
                                                            self.profile_name.value_namespace = name_space
                                                            self.profile_name.value_namespace_prefix = name_space_prefix


                                                class Igmp(Entity):
                                                    """
                                                    igmp
                                                    
                                                    .. attribute:: profile_name
                                                    
                                                    	Feature profile name
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                                        self.yang_name = "igmp"
                                                        self.yang_parent_name = "feature"

                                                        self.profile_name = YLeaf(YType.str, "profile-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("profile_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.profile_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.profile_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "igmp" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "profile-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "profile-name"):
                                                            self.profile_name = value
                                                            self.profile_name.value_namespace = name_space
                                                            self.profile_name.value_namespace_prefix = name_space_prefix


                                                class Mld(Entity):
                                                    """
                                                    mld
                                                    
                                                    .. attribute:: profile_name
                                                    
                                                    	Feature profile name
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                                        self.yang_name = "mld"
                                                        self.yang_parent_name = "feature"

                                                        self.profile_name = YLeaf(YType.str, "profile-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("profile_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.profile_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.profile_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "mld" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.profile_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "profile-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "profile-name"):
                                                            self.profile_name = value
                                                            self.profile_name.value_namespace = name_space
                                                            self.profile_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.feature_type.is_set or
                                                        (self.dhcp is not None and self.dhcp.has_data()) or
                                                        (self.igmp is not None and self.igmp.has_data()) or
                                                        (self.mld is not None and self.mld.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.feature_type.yfilter != YFilter.not_set or
                                                        (self.dhcp is not None and self.dhcp.has_operation()) or
                                                        (self.igmp is not None and self.igmp.has_operation()) or
                                                        (self.mld is not None and self.mld.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "feature" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.feature_type.is_set or self.feature_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.feature_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "dhcp"):
                                                        if (self.dhcp is None):
                                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp()
                                                            self.dhcp.parent = self
                                                            self._children_name_map["dhcp"] = "dhcp"
                                                        return self.dhcp

                                                    if (child_yang_name == "igmp"):
                                                        if (self.igmp is None):
                                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp()
                                                            self.igmp.parent = self
                                                            self._children_name_map["igmp"] = "igmp"
                                                        return self.igmp

                                                    if (child_yang_name == "mld"):
                                                        if (self.mld is None):
                                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld()
                                                            self.mld.parent = self
                                                            self._children_name_map["mld"] = "mld"
                                                        return self.mld

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "dhcp" or name == "igmp" or name == "mld" or name == "feature-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "feature-type"):
                                                        self.feature_type = value
                                                        self.feature_type.value_namespace = name_space
                                                        self.feature_type.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.feature:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.admin_disabled.is_set or
                                                    self.bvi_configured.is_set or
                                                    self.dhcp_enabled.is_set or
                                                    self.dhcp_trusted.is_set or
                                                    self.flood_unknown_unicast_enabled.is_set or
                                                    self.flooding_disabled.is_set or
                                                    self.host_routing_enabled.is_set or
                                                    self.igmp_flood_forward_enabled.is_set or
                                                    self.igmp_mroute_port_enabled.is_set or
                                                    self.igmp_route_guard_enabled.is_set or
                                                    self.igmp_snoop_enabled.is_set or
                                                    self.igmp_snoop_profile_enabled.is_set or
                                                    self.is_bvi_up.is_set or
                                                    self.is_dai_addr_validation_destination_mac_enabled.is_set or
                                                    self.is_dai_addr_validation_ipv4_enabled.is_set or
                                                    self.is_dai_addr_validation_source_mac_enabled.is_set or
                                                    self.is_dai_enabled.is_set or
                                                    self.is_dai_logging_enabled.is_set or
                                                    self.is_evpn_cw_disable.is_set or
                                                    self.is_evpn_enabled.is_set or
                                                    self.is_evpn_flow_label.is_set or
                                                    self.is_igmp_snoop_enabled.is_set or
                                                    self.is_ipsg_enabled.is_set or
                                                    self.is_ipsg_logging_enabled.is_set or
                                                    self.is_mac_secure_accept_shutdown.is_set or
                                                    self.is_mac_secure_enabled.is_set or
                                                    self.is_mac_secure_logging_enabled.is_set or
                                                    self.is_p2mp_pw_enabled.is_set or
                                                    self.is_pbbevpn_enabled.is_set or
                                                    self.is_swmac_learning.is_set or
                                                    self.is_vni_enabled.is_set or
                                                    self.is_vpls_flood_optimization_enabled.is_set or
                                                    self.mac_aging_time.is_set or
                                                    self.mac_aging_type.is_set or
                                                    self.mac_learning_disabled.is_set or
                                                    self.mac_limit.is_set or
                                                    self.mac_limit_action.is_set or
                                                    self.mac_limit_notification_type.is_set or
                                                    self.mac_port_down_flush_disabled.is_set or
                                                    self.mac_secure_action.is_set or
                                                    self.mld_flood_forward_enabled.is_set or
                                                    self.mld_mroute_port_enabled.is_set or
                                                    self.mld_route_guard_enabled.is_set or
                                                    self.mld_snoop_enabled.is_set or
                                                    self.mld_snoop_profile_enabled.is_set or
                                                    self.msti.is_set or
                                                    self.mtu.is_set or
                                                    self.number_of_macs.is_set or
                                                    self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                                                    self.storm_control_broadcast_enabled.is_set or
                                                    self.storm_control_broadcast_rate_unit.is_set or
                                                    self.storm_control_multicast_enabled.is_set or
                                                    self.storm_control_multicast_rate_unit.is_set or
                                                    self.storm_control_unicast_enabled.is_set or
                                                    self.storm_control_unicast_rate_unit.is_set or
                                                    self.stp_participating.is_set or
                                                    self.unknown_unicast_flooding_disabled.is_set)

                                            def has_operation(self):
                                                for c in self.feature:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.admin_disabled.yfilter != YFilter.not_set or
                                                    self.bvi_configured.yfilter != YFilter.not_set or
                                                    self.dhcp_enabled.yfilter != YFilter.not_set or
                                                    self.dhcp_trusted.yfilter != YFilter.not_set or
                                                    self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                                    self.flooding_disabled.yfilter != YFilter.not_set or
                                                    self.host_routing_enabled.yfilter != YFilter.not_set or
                                                    self.igmp_flood_forward_enabled.yfilter != YFilter.not_set or
                                                    self.igmp_mroute_port_enabled.yfilter != YFilter.not_set or
                                                    self.igmp_route_guard_enabled.yfilter != YFilter.not_set or
                                                    self.igmp_snoop_enabled.yfilter != YFilter.not_set or
                                                    self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set or
                                                    self.is_bvi_up.yfilter != YFilter.not_set or
                                                    self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                                    self.is_evpn_cw_disable.yfilter != YFilter.not_set or
                                                    self.is_evpn_enabled.yfilter != YFilter.not_set or
                                                    self.is_evpn_flow_label.yfilter != YFilter.not_set or
                                                    self.is_igmp_snoop_enabled.yfilter != YFilter.not_set or
                                                    self.is_ipsg_enabled.yfilter != YFilter.not_set or
                                                    self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                                    self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set or
                                                    self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                                    self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                                    self.is_p2mp_pw_enabled.yfilter != YFilter.not_set or
                                                    self.is_pbbevpn_enabled.yfilter != YFilter.not_set or
                                                    self.is_swmac_learning.yfilter != YFilter.not_set or
                                                    self.is_vni_enabled.yfilter != YFilter.not_set or
                                                    self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set or
                                                    self.mac_aging_time.yfilter != YFilter.not_set or
                                                    self.mac_aging_type.yfilter != YFilter.not_set or
                                                    self.mac_learning_disabled.yfilter != YFilter.not_set or
                                                    self.mac_limit.yfilter != YFilter.not_set or
                                                    self.mac_limit_action.yfilter != YFilter.not_set or
                                                    self.mac_limit_notification_type.yfilter != YFilter.not_set or
                                                    self.mac_port_down_flush_disabled.yfilter != YFilter.not_set or
                                                    self.mac_secure_action.yfilter != YFilter.not_set or
                                                    self.mld_flood_forward_enabled.yfilter != YFilter.not_set or
                                                    self.mld_mroute_port_enabled.yfilter != YFilter.not_set or
                                                    self.mld_route_guard_enabled.yfilter != YFilter.not_set or
                                                    self.mld_snoop_enabled.yfilter != YFilter.not_set or
                                                    self.mld_snoop_profile_enabled.yfilter != YFilter.not_set or
                                                    self.msti.yfilter != YFilter.not_set or
                                                    self.mtu.yfilter != YFilter.not_set or
                                                    self.number_of_macs.yfilter != YFilter.not_set or
                                                    self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                                                    self.storm_control_broadcast_enabled.yfilter != YFilter.not_set or
                                                    self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set or
                                                    self.storm_control_multicast_enabled.yfilter != YFilter.not_set or
                                                    self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set or
                                                    self.storm_control_unicast_enabled.yfilter != YFilter.not_set or
                                                    self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set or
                                                    self.stp_participating.yfilter != YFilter.not_set or
                                                    self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "operational-information" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.admin_disabled.is_set or self.admin_disabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.admin_disabled.get_name_leafdata())
                                                if (self.bvi_configured.is_set or self.bvi_configured.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bvi_configured.get_name_leafdata())
                                                if (self.dhcp_enabled.is_set or self.dhcp_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dhcp_enabled.get_name_leafdata())
                                                if (self.dhcp_trusted.is_set or self.dhcp_trusted.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dhcp_trusted.get_name_leafdata())
                                                if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                                if (self.flooding_disabled.is_set or self.flooding_disabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flooding_disabled.get_name_leafdata())
                                                if (self.host_routing_enabled.is_set or self.host_routing_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.host_routing_enabled.get_name_leafdata())
                                                if (self.igmp_flood_forward_enabled.is_set or self.igmp_flood_forward_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.igmp_flood_forward_enabled.get_name_leafdata())
                                                if (self.igmp_mroute_port_enabled.is_set or self.igmp_mroute_port_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.igmp_mroute_port_enabled.get_name_leafdata())
                                                if (self.igmp_route_guard_enabled.is_set or self.igmp_route_guard_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.igmp_route_guard_enabled.get_name_leafdata())
                                                if (self.igmp_snoop_enabled.is_set or self.igmp_snoop_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.igmp_snoop_enabled.get_name_leafdata())
                                                if (self.igmp_snoop_profile_enabled.is_set or self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.igmp_snoop_profile_enabled.get_name_leafdata())
                                                if (self.is_bvi_up.is_set or self.is_bvi_up.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_bvi_up.get_name_leafdata())
                                                if (self.is_dai_addr_validation_destination_mac_enabled.is_set or self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_addr_validation_destination_mac_enabled.get_name_leafdata())
                                                if (self.is_dai_addr_validation_ipv4_enabled.is_set or self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_addr_validation_ipv4_enabled.get_name_leafdata())
                                                if (self.is_dai_addr_validation_source_mac_enabled.is_set or self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_addr_validation_source_mac_enabled.get_name_leafdata())
                                                if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                                if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                                if (self.is_evpn_cw_disable.is_set or self.is_evpn_cw_disable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_evpn_cw_disable.get_name_leafdata())
                                                if (self.is_evpn_enabled.is_set or self.is_evpn_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_evpn_enabled.get_name_leafdata())
                                                if (self.is_evpn_flow_label.is_set or self.is_evpn_flow_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_evpn_flow_label.get_name_leafdata())
                                                if (self.is_igmp_snoop_enabled.is_set or self.is_igmp_snoop_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_igmp_snoop_enabled.get_name_leafdata())
                                                if (self.is_ipsg_enabled.is_set or self.is_ipsg_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_ipsg_enabled.get_name_leafdata())
                                                if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                                if (self.is_mac_secure_accept_shutdown.is_set or self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_mac_secure_accept_shutdown.get_name_leafdata())
                                                if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                                if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                                if (self.is_p2mp_pw_enabled.is_set or self.is_p2mp_pw_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_p2mp_pw_enabled.get_name_leafdata())
                                                if (self.is_pbbevpn_enabled.is_set or self.is_pbbevpn_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_pbbevpn_enabled.get_name_leafdata())
                                                if (self.is_swmac_learning.is_set or self.is_swmac_learning.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_swmac_learning.get_name_leafdata())
                                                if (self.is_vni_enabled.is_set or self.is_vni_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_vni_enabled.get_name_leafdata())
                                                if (self.is_vpls_flood_optimization_enabled.is_set or self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_vpls_flood_optimization_enabled.get_name_leafdata())
                                                if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                                if (self.mac_aging_type.is_set or self.mac_aging_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_aging_type.get_name_leafdata())
                                                if (self.mac_learning_disabled.is_set or self.mac_learning_disabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_learning_disabled.get_name_leafdata())
                                                if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                                if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                                if (self.mac_limit_notification_type.is_set or self.mac_limit_notification_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit_notification_type.get_name_leafdata())
                                                if (self.mac_port_down_flush_disabled.is_set or self.mac_port_down_flush_disabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_port_down_flush_disabled.get_name_leafdata())
                                                if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                                if (self.mld_flood_forward_enabled.is_set or self.mld_flood_forward_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mld_flood_forward_enabled.get_name_leafdata())
                                                if (self.mld_mroute_port_enabled.is_set or self.mld_mroute_port_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mld_mroute_port_enabled.get_name_leafdata())
                                                if (self.mld_route_guard_enabled.is_set or self.mld_route_guard_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mld_route_guard_enabled.get_name_leafdata())
                                                if (self.mld_snoop_enabled.is_set or self.mld_snoop_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mld_snoop_enabled.get_name_leafdata())
                                                if (self.mld_snoop_profile_enabled.is_set or self.mld_snoop_profile_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mld_snoop_profile_enabled.get_name_leafdata())
                                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                                if (self.number_of_macs.is_set or self.number_of_macs.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number_of_macs.get_name_leafdata())
                                                if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                                                if (self.storm_control_broadcast_enabled.is_set or self.storm_control_broadcast_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.storm_control_broadcast_enabled.get_name_leafdata())
                                                if (self.storm_control_broadcast_rate_unit.is_set or self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.storm_control_broadcast_rate_unit.get_name_leafdata())
                                                if (self.storm_control_multicast_enabled.is_set or self.storm_control_multicast_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.storm_control_multicast_enabled.get_name_leafdata())
                                                if (self.storm_control_multicast_rate_unit.is_set or self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.storm_control_multicast_rate_unit.get_name_leafdata())
                                                if (self.storm_control_unicast_enabled.is_set or self.storm_control_unicast_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.storm_control_unicast_enabled.get_name_leafdata())
                                                if (self.storm_control_unicast_rate_unit.is_set or self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.storm_control_unicast_rate_unit.get_name_leafdata())
                                                if (self.stp_participating.is_set or self.stp_participating.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.stp_participating.get_name_leafdata())
                                                if (self.unknown_unicast_flooding_disabled.is_set or self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unknown_unicast_flooding_disabled.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "feature"):
                                                    for c in self.feature:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.feature.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "feature" or name == "admin-disabled" or name == "bvi-configured" or name == "dhcp-enabled" or name == "dhcp-trusted" or name == "flood-unknown-unicast-enabled" or name == "flooding-disabled" or name == "host-routing-enabled" or name == "igmp-flood-forward-enabled" or name == "igmp-mroute-port-enabled" or name == "igmp-route-guard-enabled" or name == "igmp-snoop-enabled" or name == "igmp-snoop-profile-enabled" or name == "is-bvi-up" or name == "is-dai-addr-validation-destination-mac-enabled" or name == "is-dai-addr-validation-ipv4-enabled" or name == "is-dai-addr-validation-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-evpn-cw-disable" or name == "is-evpn-enabled" or name == "is-evpn-flow-label" or name == "is-igmp-snoop-enabled" or name == "is-ipsg-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "is-p2mp-pw-enabled" or name == "is-pbbevpn-enabled" or name == "is-swmac-learning" or name == "is-vni-enabled" or name == "is-vpls-flood-optimization-enabled" or name == "mac-aging-time" or name == "mac-aging-type" or name == "mac-learning-disabled" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification-type" or name == "mac-port-down-flush-disabled" or name == "mac-secure-action" or name == "mld-flood-forward-enabled" or name == "mld-mroute-port-enabled" or name == "mld-route-guard-enabled" or name == "mld-snoop-enabled" or name == "mld-snoop-profile-enabled" or name == "msti" or name == "mtu" or name == "number-of-macs" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "storm-control-broadcast-enabled" or name == "storm-control-broadcast-rate-unit" or name == "storm-control-multicast-enabled" or name == "storm-control-multicast-rate-unit" or name == "storm-control-unicast-enabled" or name == "storm-control-unicast-rate-unit" or name == "stp-participating" or name == "unknown-unicast-flooding-disabled"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "admin-disabled"):
                                                    self.admin_disabled = value
                                                    self.admin_disabled.value_namespace = name_space
                                                    self.admin_disabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bvi-configured"):
                                                    self.bvi_configured = value
                                                    self.bvi_configured.value_namespace = name_space
                                                    self.bvi_configured.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dhcp-enabled"):
                                                    self.dhcp_enabled = value
                                                    self.dhcp_enabled.value_namespace = name_space
                                                    self.dhcp_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dhcp-trusted"):
                                                    self.dhcp_trusted = value
                                                    self.dhcp_trusted.value_namespace = name_space
                                                    self.dhcp_trusted.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flood-unknown-unicast-enabled"):
                                                    self.flood_unknown_unicast_enabled = value
                                                    self.flood_unknown_unicast_enabled.value_namespace = name_space
                                                    self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flooding-disabled"):
                                                    self.flooding_disabled = value
                                                    self.flooding_disabled.value_namespace = name_space
                                                    self.flooding_disabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "host-routing-enabled"):
                                                    self.host_routing_enabled = value
                                                    self.host_routing_enabled.value_namespace = name_space
                                                    self.host_routing_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "igmp-flood-forward-enabled"):
                                                    self.igmp_flood_forward_enabled = value
                                                    self.igmp_flood_forward_enabled.value_namespace = name_space
                                                    self.igmp_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "igmp-mroute-port-enabled"):
                                                    self.igmp_mroute_port_enabled = value
                                                    self.igmp_mroute_port_enabled.value_namespace = name_space
                                                    self.igmp_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "igmp-route-guard-enabled"):
                                                    self.igmp_route_guard_enabled = value
                                                    self.igmp_route_guard_enabled.value_namespace = name_space
                                                    self.igmp_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "igmp-snoop-enabled"):
                                                    self.igmp_snoop_enabled = value
                                                    self.igmp_snoop_enabled.value_namespace = name_space
                                                    self.igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "igmp-snoop-profile-enabled"):
                                                    self.igmp_snoop_profile_enabled = value
                                                    self.igmp_snoop_profile_enabled.value_namespace = name_space
                                                    self.igmp_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-bvi-up"):
                                                    self.is_bvi_up = value
                                                    self.is_bvi_up.value_namespace = name_space
                                                    self.is_bvi_up.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-addr-validation-destination-mac-enabled"):
                                                    self.is_dai_addr_validation_destination_mac_enabled = value
                                                    self.is_dai_addr_validation_destination_mac_enabled.value_namespace = name_space
                                                    self.is_dai_addr_validation_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-addr-validation-ipv4-enabled"):
                                                    self.is_dai_addr_validation_ipv4_enabled = value
                                                    self.is_dai_addr_validation_ipv4_enabled.value_namespace = name_space
                                                    self.is_dai_addr_validation_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-addr-validation-source-mac-enabled"):
                                                    self.is_dai_addr_validation_source_mac_enabled = value
                                                    self.is_dai_addr_validation_source_mac_enabled.value_namespace = name_space
                                                    self.is_dai_addr_validation_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-enabled"):
                                                    self.is_dai_enabled = value
                                                    self.is_dai_enabled.value_namespace = name_space
                                                    self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-logging-enabled"):
                                                    self.is_dai_logging_enabled = value
                                                    self.is_dai_logging_enabled.value_namespace = name_space
                                                    self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-evpn-cw-disable"):
                                                    self.is_evpn_cw_disable = value
                                                    self.is_evpn_cw_disable.value_namespace = name_space
                                                    self.is_evpn_cw_disable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-evpn-enabled"):
                                                    self.is_evpn_enabled = value
                                                    self.is_evpn_enabled.value_namespace = name_space
                                                    self.is_evpn_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-evpn-flow-label"):
                                                    self.is_evpn_flow_label = value
                                                    self.is_evpn_flow_label.value_namespace = name_space
                                                    self.is_evpn_flow_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-igmp-snoop-enabled"):
                                                    self.is_igmp_snoop_enabled = value
                                                    self.is_igmp_snoop_enabled.value_namespace = name_space
                                                    self.is_igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-ipsg-enabled"):
                                                    self.is_ipsg_enabled = value
                                                    self.is_ipsg_enabled.value_namespace = name_space
                                                    self.is_ipsg_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-ipsg-logging-enabled"):
                                                    self.is_ipsg_logging_enabled = value
                                                    self.is_ipsg_logging_enabled.value_namespace = name_space
                                                    self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-mac-secure-accept-shutdown"):
                                                    self.is_mac_secure_accept_shutdown = value
                                                    self.is_mac_secure_accept_shutdown.value_namespace = name_space
                                                    self.is_mac_secure_accept_shutdown.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-mac-secure-enabled"):
                                                    self.is_mac_secure_enabled = value
                                                    self.is_mac_secure_enabled.value_namespace = name_space
                                                    self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-mac-secure-logging-enabled"):
                                                    self.is_mac_secure_logging_enabled = value
                                                    self.is_mac_secure_logging_enabled.value_namespace = name_space
                                                    self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-p2mp-pw-enabled"):
                                                    self.is_p2mp_pw_enabled = value
                                                    self.is_p2mp_pw_enabled.value_namespace = name_space
                                                    self.is_p2mp_pw_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-pbbevpn-enabled"):
                                                    self.is_pbbevpn_enabled = value
                                                    self.is_pbbevpn_enabled.value_namespace = name_space
                                                    self.is_pbbevpn_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-swmac-learning"):
                                                    self.is_swmac_learning = value
                                                    self.is_swmac_learning.value_namespace = name_space
                                                    self.is_swmac_learning.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-vni-enabled"):
                                                    self.is_vni_enabled = value
                                                    self.is_vni_enabled.value_namespace = name_space
                                                    self.is_vni_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-vpls-flood-optimization-enabled"):
                                                    self.is_vpls_flood_optimization_enabled = value
                                                    self.is_vpls_flood_optimization_enabled.value_namespace = name_space
                                                    self.is_vpls_flood_optimization_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-aging-time"):
                                                    self.mac_aging_time = value
                                                    self.mac_aging_time.value_namespace = name_space
                                                    self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-aging-type"):
                                                    self.mac_aging_type = value
                                                    self.mac_aging_type.value_namespace = name_space
                                                    self.mac_aging_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-learning-disabled"):
                                                    self.mac_learning_disabled = value
                                                    self.mac_learning_disabled.value_namespace = name_space
                                                    self.mac_learning_disabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit"):
                                                    self.mac_limit = value
                                                    self.mac_limit.value_namespace = name_space
                                                    self.mac_limit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit-action"):
                                                    self.mac_limit_action = value
                                                    self.mac_limit_action.value_namespace = name_space
                                                    self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit-notification-type"):
                                                    self.mac_limit_notification_type = value
                                                    self.mac_limit_notification_type.value_namespace = name_space
                                                    self.mac_limit_notification_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-port-down-flush-disabled"):
                                                    self.mac_port_down_flush_disabled = value
                                                    self.mac_port_down_flush_disabled.value_namespace = name_space
                                                    self.mac_port_down_flush_disabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-secure-action"):
                                                    self.mac_secure_action = value
                                                    self.mac_secure_action.value_namespace = name_space
                                                    self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mld-flood-forward-enabled"):
                                                    self.mld_flood_forward_enabled = value
                                                    self.mld_flood_forward_enabled.value_namespace = name_space
                                                    self.mld_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mld-mroute-port-enabled"):
                                                    self.mld_mroute_port_enabled = value
                                                    self.mld_mroute_port_enabled.value_namespace = name_space
                                                    self.mld_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mld-route-guard-enabled"):
                                                    self.mld_route_guard_enabled = value
                                                    self.mld_route_guard_enabled.value_namespace = name_space
                                                    self.mld_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mld-snoop-enabled"):
                                                    self.mld_snoop_enabled = value
                                                    self.mld_snoop_enabled.value_namespace = name_space
                                                    self.mld_snoop_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mld-snoop-profile-enabled"):
                                                    self.mld_snoop_profile_enabled = value
                                                    self.mld_snoop_profile_enabled.value_namespace = name_space
                                                    self.mld_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "msti"):
                                                    self.msti = value
                                                    self.msti.value_namespace = name_space
                                                    self.msti.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mtu"):
                                                    self.mtu = value
                                                    self.mtu.value_namespace = name_space
                                                    self.mtu.value_namespace_prefix = name_space_prefix
                                                if(value_path == "number-of-macs"):
                                                    self.number_of_macs = value
                                                    self.number_of_macs.value_namespace = name_space
                                                    self.number_of_macs.value_namespace_prefix = name_space_prefix
                                                if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                                                    self.nv_satellite_offload_ipv4_multicast_disabled = value
                                                    self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                                                    self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "storm-control-broadcast-enabled"):
                                                    self.storm_control_broadcast_enabled = value
                                                    self.storm_control_broadcast_enabled.value_namespace = name_space
                                                    self.storm_control_broadcast_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "storm-control-broadcast-rate-unit"):
                                                    self.storm_control_broadcast_rate_unit = value
                                                    self.storm_control_broadcast_rate_unit.value_namespace = name_space
                                                    self.storm_control_broadcast_rate_unit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "storm-control-multicast-enabled"):
                                                    self.storm_control_multicast_enabled = value
                                                    self.storm_control_multicast_enabled.value_namespace = name_space
                                                    self.storm_control_multicast_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "storm-control-multicast-rate-unit"):
                                                    self.storm_control_multicast_rate_unit = value
                                                    self.storm_control_multicast_rate_unit.value_namespace = name_space
                                                    self.storm_control_multicast_rate_unit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "storm-control-unicast-enabled"):
                                                    self.storm_control_unicast_enabled = value
                                                    self.storm_control_unicast_enabled.value_namespace = name_space
                                                    self.storm_control_unicast_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "storm-control-unicast-rate-unit"):
                                                    self.storm_control_unicast_rate_unit = value
                                                    self.storm_control_unicast_rate_unit.value_namespace = name_space
                                                    self.storm_control_unicast_rate_unit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "stp-participating"):
                                                    self.stp_participating = value
                                                    self.stp_participating.value_namespace = name_space
                                                    self.stp_participating.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unknown-unicast-flooding-disabled"):
                                                    self.unknown_unicast_flooding_disabled = value
                                                    self.unknown_unicast_flooding_disabled.value_namespace = name_space
                                                    self.unknown_unicast_flooding_disabled.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.broadcast_storm_control_kb_ps.is_set or
                                                self.broadcast_storm_control_pps.is_set or
                                                self.multicast_storm_control_kb_ps.is_set or
                                                self.multicast_storm_control_pps.is_set or
                                                self.unicast_storm_control_kb_ps.is_set or
                                                self.unicast_storm_control_pps.is_set or
                                                (self.operational_information is not None and self.operational_information.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                (self.operational_information is not None and self.operational_information.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "oper" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "operational-information"):
                                                if (self.operational_information is None):
                                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation()
                                                    self.operational_information.parent = self
                                                    self._children_name_map["operational_information"] = "operational-information"
                                                return self.operational_information

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "operational-information" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "broadcast-storm-control-kb-ps"):
                                                self.broadcast_storm_control_kb_ps = value
                                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-pps"):
                                                self.broadcast_storm_control_pps = value
                                                self.broadcast_storm_control_pps.value_namespace = name_space
                                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-kb-ps"):
                                                self.multicast_storm_control_kb_ps = value
                                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-pps"):
                                                self.multicast_storm_control_pps = value
                                                self.multicast_storm_control_pps.value_namespace = name_space
                                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-kb-ps"):
                                                self.unicast_storm_control_kb_ps = value
                                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-pps"):
                                                self.unicast_storm_control_pps = value
                                                self.unicast_storm_control_pps.value_namespace = name_space
                                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.bridge_port.is_set or
                                            self.bp_type.is_set or
                                            self.bridge_id.is_set or
                                            self.bridge_port_id.is_set or
                                            self.main_if_type.is_set or
                                            self.main_interface.is_set or
                                            self.state.is_set or
                                            self.virtual_if_name.is_set or
                                            (self.oper is not None and self.oper.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bridge_port.yfilter != YFilter.not_set or
                                            self.bp_type.yfilter != YFilter.not_set or
                                            self.bridge_id.yfilter != YFilter.not_set or
                                            self.bridge_port_id.yfilter != YFilter.not_set or
                                            self.main_if_type.yfilter != YFilter.not_set or
                                            self.main_interface.yfilter != YFilter.not_set or
                                            self.state.yfilter != YFilter.not_set or
                                            self.virtual_if_name.yfilter != YFilter.not_set or
                                            (self.oper is not None and self.oper.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fib-main-interface-instance-bridge-port-detail" + "[bridge-port='" + self.bridge_port.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bridge_port.is_set or self.bridge_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bridge_port.get_name_leafdata())
                                        if (self.bp_type.is_set or self.bp_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bp_type.get_name_leafdata())
                                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                                        if (self.bridge_port_id.is_set or self.bridge_port_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bridge_port_id.get_name_leafdata())
                                        if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.main_if_type.get_name_leafdata())
                                        if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.main_interface.get_name_leafdata())
                                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state.get_name_leafdata())
                                        if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "oper"):
                                            if (self.oper is None):
                                                self.oper = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper()
                                                self.oper.parent = self
                                                self._children_name_map["oper"] = "oper"
                                            return self.oper

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "oper" or name == "bridge-port" or name == "bp-type" or name == "bridge-id" or name == "bridge-port-id" or name == "main-if-type" or name == "main-interface" or name == "state" or name == "virtual-if-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bridge-port"):
                                            self.bridge_port = value
                                            self.bridge_port.value_namespace = name_space
                                            self.bridge_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bp-type"):
                                            self.bp_type = value
                                            self.bp_type.value_namespace = name_space
                                            self.bp_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bridge-id"):
                                            self.bridge_id = value
                                            self.bridge_id.value_namespace = name_space
                                            self.bridge_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bridge-port-id"):
                                            self.bridge_port_id = value
                                            self.bridge_port_id.value_namespace = name_space
                                            self.bridge_port_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "main-if-type"):
                                            self.main_if_type = value
                                            self.main_if_type.value_namespace = name_space
                                            self.main_if_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "main-interface"):
                                            self.main_interface = value
                                            self.main_interface.value_namespace = name_space
                                            self.main_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state"):
                                            self.state = value
                                            self.state.value_namespace = name_space
                                            self.state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "virtual-if-name"):
                                            self.virtual_if_name = value
                                            self.virtual_if_name.value_namespace = name_space
                                            self.virtual_if_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.l2fib_main_interface_instance_bridge_port_detail:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.l2fib_main_interface_instance_bridge_port_detail:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fib-main-interface-instance-bridge-port-details" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2fib-main-interface-instance-bridge-port-detail"):
                                        for c in self.l2fib_main_interface_instance_bridge_port_detail:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.l2fib_main_interface_instance_bridge_port_detail.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2fib-main-interface-instance-bridge-port-detail"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class L2FibMainInterfaceInstanceInfo(Entity):
                                """
                                Main Interface Instance info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"

                                    self.bridge_port_count = YLeaf(YType.uint32, "bridge-port-count")

                                    self.instance = YLeaf(YType.uint32, "instance")

                                    self.instance_provisioned = YLeaf(YType.boolean, "instance-provisioned")

                                    self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                                    self.main_interface = YLeaf(YType.str, "main-interface")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bridge_port_count",
                                                    "instance",
                                                    "instance_provisioned",
                                                    "main_if_type",
                                                    "main_interface",
                                                    "state",
                                                    "virtual_if_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceInfo, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bridge_port_count.is_set or
                                        self.instance.is_set or
                                        self.instance_provisioned.is_set or
                                        self.main_if_type.is_set or
                                        self.main_interface.is_set or
                                        self.state.is_set or
                                        self.virtual_if_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bridge_port_count.yfilter != YFilter.not_set or
                                        self.instance.yfilter != YFilter.not_set or
                                        self.instance_provisioned.yfilter != YFilter.not_set or
                                        self.main_if_type.yfilter != YFilter.not_set or
                                        self.main_interface.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.virtual_if_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fib-main-interface-instance-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bridge_port_count.is_set or self.bridge_port_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_count.get_name_leafdata())
                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                    if (self.instance_provisioned.is_set or self.instance_provisioned.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_provisioned.get_name_leafdata())
                                    if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_if_type.get_name_leafdata())
                                    if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_interface.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bridge-port-count" or name == "instance" or name == "instance-provisioned" or name == "main-if-type" or name == "main-interface" or name == "state" or name == "virtual-if-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bridge-port-count"):
                                        self.bridge_port_count = value
                                        self.bridge_port_count.value_namespace = name_space
                                        self.bridge_port_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance"):
                                        self.instance = value
                                        self.instance.value_namespace = name_space
                                        self.instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-provisioned"):
                                        self.instance_provisioned = value
                                        self.instance_provisioned.value_namespace = name_space
                                        self.instance_provisioned.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-if-type"):
                                        self.main_if_type = value
                                        self.main_if_type.value_namespace = name_space
                                        self.main_if_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-interface"):
                                        self.main_interface = value
                                        self.main_interface.value_namespace = name_space
                                        self.main_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-if-name"):
                                        self.virtual_if_name = value
                                        self.virtual_if_name.value_namespace = name_space
                                        self.virtual_if_name.value_namespace_prefix = name_space_prefix


                            class L2FibMainInterfaceInstanceHardwareIngressDetailInfo(Entity):
                                """
                                Main Interface Instance hardware ingress
                                detail info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressDetailInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-hardware-ingress-detail-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"

                                    self.bridge_port_count = YLeaf(YType.uint32, "bridge-port-count")

                                    self.instance = YLeaf(YType.uint32, "instance")

                                    self.instance_provisioned = YLeaf(YType.boolean, "instance-provisioned")

                                    self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                                    self.main_interface = YLeaf(YType.str, "main-interface")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bridge_port_count",
                                                    "instance",
                                                    "instance_provisioned",
                                                    "main_if_type",
                                                    "main_interface",
                                                    "state",
                                                    "virtual_if_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressDetailInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressDetailInfo, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bridge_port_count.is_set or
                                        self.instance.is_set or
                                        self.instance_provisioned.is_set or
                                        self.main_if_type.is_set or
                                        self.main_interface.is_set or
                                        self.state.is_set or
                                        self.virtual_if_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bridge_port_count.yfilter != YFilter.not_set or
                                        self.instance.yfilter != YFilter.not_set or
                                        self.instance_provisioned.yfilter != YFilter.not_set or
                                        self.main_if_type.yfilter != YFilter.not_set or
                                        self.main_interface.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.virtual_if_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fib-main-interface-instance-hardware-ingress-detail-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bridge_port_count.is_set or self.bridge_port_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_count.get_name_leafdata())
                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                    if (self.instance_provisioned.is_set or self.instance_provisioned.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_provisioned.get_name_leafdata())
                                    if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_if_type.get_name_leafdata())
                                    if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_interface.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bridge-port-count" or name == "instance" or name == "instance-provisioned" or name == "main-if-type" or name == "main-interface" or name == "state" or name == "virtual-if-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bridge-port-count"):
                                        self.bridge_port_count = value
                                        self.bridge_port_count.value_namespace = name_space
                                        self.bridge_port_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance"):
                                        self.instance = value
                                        self.instance.value_namespace = name_space
                                        self.instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-provisioned"):
                                        self.instance_provisioned = value
                                        self.instance_provisioned.value_namespace = name_space
                                        self.instance_provisioned.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-if-type"):
                                        self.main_if_type = value
                                        self.main_if_type.value_namespace = name_space
                                        self.main_if_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-interface"):
                                        self.main_interface = value
                                        self.main_interface.value_namespace = name_space
                                        self.main_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-if-name"):
                                        self.virtual_if_name = value
                                        self.virtual_if_name.value_namespace = name_space
                                        self.virtual_if_name.value_namespace_prefix = name_space_prefix


                            class L2FibMainInterfaceInstanceHardwareEgressInfo(Entity):
                                """
                                Main Interface Instance hardware egress
                                info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-hardware-egress-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"

                                    self.bridge_port_count = YLeaf(YType.uint32, "bridge-port-count")

                                    self.instance = YLeaf(YType.uint32, "instance")

                                    self.instance_provisioned = YLeaf(YType.boolean, "instance-provisioned")

                                    self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                                    self.main_interface = YLeaf(YType.str, "main-interface")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bridge_port_count",
                                                    "instance",
                                                    "instance_provisioned",
                                                    "main_if_type",
                                                    "main_interface",
                                                    "state",
                                                    "virtual_if_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressInfo, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bridge_port_count.is_set or
                                        self.instance.is_set or
                                        self.instance_provisioned.is_set or
                                        self.main_if_type.is_set or
                                        self.main_interface.is_set or
                                        self.state.is_set or
                                        self.virtual_if_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bridge_port_count.yfilter != YFilter.not_set or
                                        self.instance.yfilter != YFilter.not_set or
                                        self.instance_provisioned.yfilter != YFilter.not_set or
                                        self.main_if_type.yfilter != YFilter.not_set or
                                        self.main_interface.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.virtual_if_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fib-main-interface-instance-hardware-egress-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bridge_port_count.is_set or self.bridge_port_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_count.get_name_leafdata())
                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                    if (self.instance_provisioned.is_set or self.instance_provisioned.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_provisioned.get_name_leafdata())
                                    if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_if_type.get_name_leafdata())
                                    if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_interface.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bridge-port-count" or name == "instance" or name == "instance-provisioned" or name == "main-if-type" or name == "main-interface" or name == "state" or name == "virtual-if-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bridge-port-count"):
                                        self.bridge_port_count = value
                                        self.bridge_port_count.value_namespace = name_space
                                        self.bridge_port_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance"):
                                        self.instance = value
                                        self.instance.value_namespace = name_space
                                        self.instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-provisioned"):
                                        self.instance_provisioned = value
                                        self.instance_provisioned.value_namespace = name_space
                                        self.instance_provisioned.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-if-type"):
                                        self.main_if_type = value
                                        self.main_if_type.value_namespace = name_space
                                        self.main_if_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-interface"):
                                        self.main_interface = value
                                        self.main_interface.value_namespace = name_space
                                        self.main_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-if-name"):
                                        self.virtual_if_name = value
                                        self.virtual_if_name.value_namespace = name_space
                                        self.virtual_if_name.value_namespace_prefix = name_space_prefix


                            class L2FibMainInterfaceInstanceHardwareIngressInfo(Entity):
                                """
                                Main Interface Instance hardware ingress
                                info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-hardware-ingress-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"

                                    self.bridge_port_count = YLeaf(YType.uint32, "bridge-port-count")

                                    self.instance = YLeaf(YType.uint32, "instance")

                                    self.instance_provisioned = YLeaf(YType.boolean, "instance-provisioned")

                                    self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                                    self.main_interface = YLeaf(YType.str, "main-interface")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bridge_port_count",
                                                    "instance",
                                                    "instance_provisioned",
                                                    "main_if_type",
                                                    "main_interface",
                                                    "state",
                                                    "virtual_if_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressInfo, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bridge_port_count.is_set or
                                        self.instance.is_set or
                                        self.instance_provisioned.is_set or
                                        self.main_if_type.is_set or
                                        self.main_interface.is_set or
                                        self.state.is_set or
                                        self.virtual_if_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bridge_port_count.yfilter != YFilter.not_set or
                                        self.instance.yfilter != YFilter.not_set or
                                        self.instance_provisioned.yfilter != YFilter.not_set or
                                        self.main_if_type.yfilter != YFilter.not_set or
                                        self.main_interface.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.virtual_if_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fib-main-interface-instance-hardware-ingress-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bridge_port_count.is_set or self.bridge_port_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_count.get_name_leafdata())
                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                    if (self.instance_provisioned.is_set or self.instance_provisioned.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_provisioned.get_name_leafdata())
                                    if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_if_type.get_name_leafdata())
                                    if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_interface.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bridge-port-count" or name == "instance" or name == "instance-provisioned" or name == "main-if-type" or name == "main-interface" or name == "state" or name == "virtual-if-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bridge-port-count"):
                                        self.bridge_port_count = value
                                        self.bridge_port_count.value_namespace = name_space
                                        self.bridge_port_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance"):
                                        self.instance = value
                                        self.instance.value_namespace = name_space
                                        self.instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-provisioned"):
                                        self.instance_provisioned = value
                                        self.instance_provisioned.value_namespace = name_space
                                        self.instance_provisioned.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-if-type"):
                                        self.main_if_type = value
                                        self.main_if_type.value_namespace = name_space
                                        self.main_if_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-interface"):
                                        self.main_interface = value
                                        self.main_interface.value_namespace = name_space
                                        self.main_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-if-name"):
                                        self.virtual_if_name = value
                                        self.virtual_if_name.value_namespace = name_space
                                        self.virtual_if_name.value_namespace_prefix = name_space_prefix


                            class L2FibMainInterfaceInstanceBridgePorts(Entity):
                                """
                                Main Interface Instance Bridge Port table
                                
                                .. attribute:: l2fib_main_interface_instance_bridge_port
                                
                                	Main Interface Bridge Port info
                                	**type**\: list of    :py:class:`L2FibMainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts.L2FibMainInterfaceInstanceBridgePort>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-bridge-ports"
                                    self.yang_parent_name = "l2fib-main-interface-instance"

                                    self.l2fib_main_interface_instance_bridge_port = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts, self).__setattr__(name, value)


                                class L2FibMainInterfaceInstanceBridgePort(Entity):
                                    """
                                    Main Interface Bridge Port info
                                    
                                    .. attribute:: bridge_port  <key>
                                    
                                    	Bridge Port
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: bp_type
                                    
                                    	Bridge Port Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: bridge_id
                                    
                                    	Bridge ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bridge_port_id
                                    
                                    	Bridge Port ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: main_if_type
                                    
                                    	Main Interface Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: main_interface
                                    
                                    	Main interface ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: virtual_if_name
                                    
                                    	Virtual Main IfName
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts.L2FibMainInterfaceInstanceBridgePort, self).__init__()

                                        self.yang_name = "l2fib-main-interface-instance-bridge-port"
                                        self.yang_parent_name = "l2fib-main-interface-instance-bridge-ports"

                                        self.bridge_port = YLeaf(YType.str, "bridge-port")

                                        self.bp_type = YLeaf(YType.uint8, "bp-type")

                                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                                        self.bridge_port_id = YLeaf(YType.str, "bridge-port-id")

                                        self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                                        self.main_interface = YLeaf(YType.str, "main-interface")

                                        self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bridge_port",
                                                        "bp_type",
                                                        "bridge_id",
                                                        "bridge_port_id",
                                                        "main_if_type",
                                                        "main_interface",
                                                        "virtual_if_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts.L2FibMainInterfaceInstanceBridgePort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts.L2FibMainInterfaceInstanceBridgePort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bridge_port.is_set or
                                            self.bp_type.is_set or
                                            self.bridge_id.is_set or
                                            self.bridge_port_id.is_set or
                                            self.main_if_type.is_set or
                                            self.main_interface.is_set or
                                            self.virtual_if_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bridge_port.yfilter != YFilter.not_set or
                                            self.bp_type.yfilter != YFilter.not_set or
                                            self.bridge_id.yfilter != YFilter.not_set or
                                            self.bridge_port_id.yfilter != YFilter.not_set or
                                            self.main_if_type.yfilter != YFilter.not_set or
                                            self.main_interface.yfilter != YFilter.not_set or
                                            self.virtual_if_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fib-main-interface-instance-bridge-port" + "[bridge-port='" + self.bridge_port.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bridge_port.is_set or self.bridge_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bridge_port.get_name_leafdata())
                                        if (self.bp_type.is_set or self.bp_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bp_type.get_name_leafdata())
                                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                                        if (self.bridge_port_id.is_set or self.bridge_port_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bridge_port_id.get_name_leafdata())
                                        if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.main_if_type.get_name_leafdata())
                                        if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.main_interface.get_name_leafdata())
                                        if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bridge-port" or name == "bp-type" or name == "bridge-id" or name == "bridge-port-id" or name == "main-if-type" or name == "main-interface" or name == "virtual-if-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bridge-port"):
                                            self.bridge_port = value
                                            self.bridge_port.value_namespace = name_space
                                            self.bridge_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bp-type"):
                                            self.bp_type = value
                                            self.bp_type.value_namespace = name_space
                                            self.bp_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bridge-id"):
                                            self.bridge_id = value
                                            self.bridge_id.value_namespace = name_space
                                            self.bridge_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bridge-port-id"):
                                            self.bridge_port_id = value
                                            self.bridge_port_id.value_namespace = name_space
                                            self.bridge_port_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "main-if-type"):
                                            self.main_if_type = value
                                            self.main_if_type.value_namespace = name_space
                                            self.main_if_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "main-interface"):
                                            self.main_interface = value
                                            self.main_interface.value_namespace = name_space
                                            self.main_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "virtual-if-name"):
                                            self.virtual_if_name = value
                                            self.virtual_if_name.value_namespace = name_space
                                            self.virtual_if_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.l2fib_main_interface_instance_bridge_port:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.l2fib_main_interface_instance_bridge_port:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fib-main-interface-instance-bridge-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2fib-main-interface-instance-bridge-port"):
                                        for c in self.l2fib_main_interface_instance_bridge_port:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts.L2FibMainInterfaceInstanceBridgePort()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.l2fib_main_interface_instance_bridge_port.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2fib-main-interface-instance-bridge-port"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class L2FibMainInterfaceInstanceHardwareEgressDetailInfo(Entity):
                                """
                                Main Interface Instance hardware egress
                                detail info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressDetailInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-hardware-egress-detail-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"

                                    self.bridge_port_count = YLeaf(YType.uint32, "bridge-port-count")

                                    self.instance = YLeaf(YType.uint32, "instance")

                                    self.instance_provisioned = YLeaf(YType.boolean, "instance-provisioned")

                                    self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                                    self.main_interface = YLeaf(YType.str, "main-interface")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bridge_port_count",
                                                    "instance",
                                                    "instance_provisioned",
                                                    "main_if_type",
                                                    "main_interface",
                                                    "state",
                                                    "virtual_if_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressDetailInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressDetailInfo, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bridge_port_count.is_set or
                                        self.instance.is_set or
                                        self.instance_provisioned.is_set or
                                        self.main_if_type.is_set or
                                        self.main_interface.is_set or
                                        self.state.is_set or
                                        self.virtual_if_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bridge_port_count.yfilter != YFilter.not_set or
                                        self.instance.yfilter != YFilter.not_set or
                                        self.instance_provisioned.yfilter != YFilter.not_set or
                                        self.main_if_type.yfilter != YFilter.not_set or
                                        self.main_interface.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.virtual_if_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fib-main-interface-instance-hardware-egress-detail-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bridge_port_count.is_set or self.bridge_port_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_count.get_name_leafdata())
                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                    if (self.instance_provisioned.is_set or self.instance_provisioned.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_provisioned.get_name_leafdata())
                                    if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_if_type.get_name_leafdata())
                                    if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.main_interface.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bridge-port-count" or name == "instance" or name == "instance-provisioned" or name == "main-if-type" or name == "main-interface" or name == "state" or name == "virtual-if-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bridge-port-count"):
                                        self.bridge_port_count = value
                                        self.bridge_port_count.value_namespace = name_space
                                        self.bridge_port_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance"):
                                        self.instance = value
                                        self.instance.value_namespace = name_space
                                        self.instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-provisioned"):
                                        self.instance_provisioned = value
                                        self.instance_provisioned.value_namespace = name_space
                                        self.instance_provisioned.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-if-type"):
                                        self.main_if_type = value
                                        self.main_if_type.value_namespace = name_space
                                        self.main_if_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "main-interface"):
                                        self.main_interface = value
                                        self.main_interface.value_namespace = name_space
                                        self.main_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "virtual-if-name"):
                                        self.virtual_if_name = value
                                        self.virtual_if_name.value_namespace = name_space
                                        self.virtual_if_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.instance.is_set or
                                    (self.l2fib_main_interface_instance_bridge_port_details is not None and self.l2fib_main_interface_instance_bridge_port_details.has_data()) or
                                    (self.l2fib_main_interface_instance_bridge_ports is not None and self.l2fib_main_interface_instance_bridge_ports.has_data()) or
                                    (self.l2fib_main_interface_instance_detail_info is not None and self.l2fib_main_interface_instance_detail_info.has_data()) or
                                    (self.l2fib_main_interface_instance_hardware_egress_detail_info is not None and self.l2fib_main_interface_instance_hardware_egress_detail_info.has_data()) or
                                    (self.l2fib_main_interface_instance_hardware_egress_info is not None and self.l2fib_main_interface_instance_hardware_egress_info.has_data()) or
                                    (self.l2fib_main_interface_instance_hardware_ingress_detail_info is not None and self.l2fib_main_interface_instance_hardware_ingress_detail_info.has_data()) or
                                    (self.l2fib_main_interface_instance_hardware_ingress_info is not None and self.l2fib_main_interface_instance_hardware_ingress_info.has_data()) or
                                    (self.l2fib_main_interface_instance_info is not None and self.l2fib_main_interface_instance_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.instance.yfilter != YFilter.not_set or
                                    (self.l2fib_main_interface_instance_bridge_port_details is not None and self.l2fib_main_interface_instance_bridge_port_details.has_operation()) or
                                    (self.l2fib_main_interface_instance_bridge_ports is not None and self.l2fib_main_interface_instance_bridge_ports.has_operation()) or
                                    (self.l2fib_main_interface_instance_detail_info is not None and self.l2fib_main_interface_instance_detail_info.has_operation()) or
                                    (self.l2fib_main_interface_instance_hardware_egress_detail_info is not None and self.l2fib_main_interface_instance_hardware_egress_detail_info.has_operation()) or
                                    (self.l2fib_main_interface_instance_hardware_egress_info is not None and self.l2fib_main_interface_instance_hardware_egress_info.has_operation()) or
                                    (self.l2fib_main_interface_instance_hardware_ingress_detail_info is not None and self.l2fib_main_interface_instance_hardware_ingress_detail_info.has_operation()) or
                                    (self.l2fib_main_interface_instance_hardware_ingress_info is not None and self.l2fib_main_interface_instance_hardware_ingress_info.has_operation()) or
                                    (self.l2fib_main_interface_instance_info is not None and self.l2fib_main_interface_instance_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2fib-main-interface-instance" + "[instance='" + self.instance.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "l2fib-main-interface-instance-bridge-port-details"):
                                    if (self.l2fib_main_interface_instance_bridge_port_details is None):
                                        self.l2fib_main_interface_instance_bridge_port_details = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails()
                                        self.l2fib_main_interface_instance_bridge_port_details.parent = self
                                        self._children_name_map["l2fib_main_interface_instance_bridge_port_details"] = "l2fib-main-interface-instance-bridge-port-details"
                                    return self.l2fib_main_interface_instance_bridge_port_details

                                if (child_yang_name == "l2fib-main-interface-instance-bridge-ports"):
                                    if (self.l2fib_main_interface_instance_bridge_ports is None):
                                        self.l2fib_main_interface_instance_bridge_ports = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts()
                                        self.l2fib_main_interface_instance_bridge_ports.parent = self
                                        self._children_name_map["l2fib_main_interface_instance_bridge_ports"] = "l2fib-main-interface-instance-bridge-ports"
                                    return self.l2fib_main_interface_instance_bridge_ports

                                if (child_yang_name == "l2fib-main-interface-instance-detail-info"):
                                    if (self.l2fib_main_interface_instance_detail_info is None):
                                        self.l2fib_main_interface_instance_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceDetailInfo()
                                        self.l2fib_main_interface_instance_detail_info.parent = self
                                        self._children_name_map["l2fib_main_interface_instance_detail_info"] = "l2fib-main-interface-instance-detail-info"
                                    return self.l2fib_main_interface_instance_detail_info

                                if (child_yang_name == "l2fib-main-interface-instance-hardware-egress-detail-info"):
                                    if (self.l2fib_main_interface_instance_hardware_egress_detail_info is None):
                                        self.l2fib_main_interface_instance_hardware_egress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressDetailInfo()
                                        self.l2fib_main_interface_instance_hardware_egress_detail_info.parent = self
                                        self._children_name_map["l2fib_main_interface_instance_hardware_egress_detail_info"] = "l2fib-main-interface-instance-hardware-egress-detail-info"
                                    return self.l2fib_main_interface_instance_hardware_egress_detail_info

                                if (child_yang_name == "l2fib-main-interface-instance-hardware-egress-info"):
                                    if (self.l2fib_main_interface_instance_hardware_egress_info is None):
                                        self.l2fib_main_interface_instance_hardware_egress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressInfo()
                                        self.l2fib_main_interface_instance_hardware_egress_info.parent = self
                                        self._children_name_map["l2fib_main_interface_instance_hardware_egress_info"] = "l2fib-main-interface-instance-hardware-egress-info"
                                    return self.l2fib_main_interface_instance_hardware_egress_info

                                if (child_yang_name == "l2fib-main-interface-instance-hardware-ingress-detail-info"):
                                    if (self.l2fib_main_interface_instance_hardware_ingress_detail_info is None):
                                        self.l2fib_main_interface_instance_hardware_ingress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressDetailInfo()
                                        self.l2fib_main_interface_instance_hardware_ingress_detail_info.parent = self
                                        self._children_name_map["l2fib_main_interface_instance_hardware_ingress_detail_info"] = "l2fib-main-interface-instance-hardware-ingress-detail-info"
                                    return self.l2fib_main_interface_instance_hardware_ingress_detail_info

                                if (child_yang_name == "l2fib-main-interface-instance-hardware-ingress-info"):
                                    if (self.l2fib_main_interface_instance_hardware_ingress_info is None):
                                        self.l2fib_main_interface_instance_hardware_ingress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressInfo()
                                        self.l2fib_main_interface_instance_hardware_ingress_info.parent = self
                                        self._children_name_map["l2fib_main_interface_instance_hardware_ingress_info"] = "l2fib-main-interface-instance-hardware-ingress-info"
                                    return self.l2fib_main_interface_instance_hardware_ingress_info

                                if (child_yang_name == "l2fib-main-interface-instance-info"):
                                    if (self.l2fib_main_interface_instance_info is None):
                                        self.l2fib_main_interface_instance_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceInfo()
                                        self.l2fib_main_interface_instance_info.parent = self
                                        self._children_name_map["l2fib_main_interface_instance_info"] = "l2fib-main-interface-instance-info"
                                    return self.l2fib_main_interface_instance_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "l2fib-main-interface-instance-bridge-port-details" or name == "l2fib-main-interface-instance-bridge-ports" or name == "l2fib-main-interface-instance-detail-info" or name == "l2fib-main-interface-instance-hardware-egress-detail-info" or name == "l2fib-main-interface-instance-hardware-egress-info" or name == "l2fib-main-interface-instance-hardware-ingress-detail-info" or name == "l2fib-main-interface-instance-hardware-ingress-info" or name == "l2fib-main-interface-instance-info" or name == "instance"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "instance"):
                                    self.instance = value
                                    self.instance.value_namespace = name_space
                                    self.instance.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.l2fib_main_interface_instance:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.l2fib_main_interface_instance:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-main-interface-instances" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "l2fib-main-interface-instance"):
                                for c in self.l2fib_main_interface_instance:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.l2fib_main_interface_instance.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "l2fib-main-interface-instance"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class L2FibMainInterfaceInfo(Entity):
                        """
                        Main Interface info
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-info"
                            self.yang_parent_name = "l2fib-main-interface"

                            self.instance_id = YLeafList(YType.uint32, "instance-id")

                            self.instances_provisioned = YLeafList(YType.boolean, "instances-provisioned")

                            self.instances_state = YLeafList(YType.enumeration, "instances-state")

                            self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                            self.main_interface = YLeaf(YType.str, "main-interface")

                            self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("instance_id",
                                            "instances_provisioned",
                                            "instances_state",
                                            "main_if_type",
                                            "main_interface",
                                            "virtual_if_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInfo, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.main_if_type.is_set or
                                self.main_interface.is_set or
                                self.virtual_if_name.is_set)

                        def has_operation(self):
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.instance_id.yfilter != YFilter.not_set or
                                self.instances_provisioned.yfilter != YFilter.not_set or
                                self.instances_state.yfilter != YFilter.not_set or
                                self.main_if_type.yfilter != YFilter.not_set or
                                self.main_interface.yfilter != YFilter.not_set or
                                self.virtual_if_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-main-interface-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_if_type.get_name_leafdata())
                            if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_interface.get_name_leafdata())
                            if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                            leaf_name_data.extend(self.instance_id.get_name_leafdata())

                            leaf_name_data.extend(self.instances_provisioned.get_name_leafdata())

                            leaf_name_data.extend(self.instances_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "instance-id" or name == "instances-provisioned" or name == "instances-state" or name == "main-if-type" or name == "main-interface" or name == "virtual-if-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "instance-id"):
                                self.instance_id.append(value)
                            if(value_path == "instances-provisioned"):
                                self.instances_provisioned.append(value)
                            if(value_path == "instances-state"):
                                self.instances_state.append(value)
                            if(value_path == "main-if-type"):
                                self.main_if_type = value
                                self.main_if_type.value_namespace = name_space
                                self.main_if_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-interface"):
                                self.main_interface = value
                                self.main_interface.value_namespace = name_space
                                self.main_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-if-name"):
                                self.virtual_if_name = value
                                self.virtual_if_name.value_namespace = name_space
                                self.virtual_if_name.value_namespace_prefix = name_space_prefix


                    class L2FibMainInterfaceDetailInfo(Entity):
                        """
                        Main Interface detail info
                        
                        .. attribute:: bridge_port_count_instance
                        
                        	Number of bridge ports per instance
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: esi_id
                        
                        	Ethernet segment ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ethernet_segment_identifier
                        
                        	Ethernet Segment Identifier
                        	**type**\:  list of int
                        
                        	**range:** 0..255
                        
                        .. attribute:: evpn_shg_local_label
                        
                        	EVPN split horizon group local label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_shg_remote_info
                        
                        	EVPN split horizon group remote info
                        	**type**\: list of    :py:class:`EvpnShgRemoteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo>`
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                        
                        .. attribute:: mac
                        
                        	MAC Address
                        	**type**\:  str
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-detail-info"
                            self.yang_parent_name = "l2fib-main-interface"

                            self.bridge_port_count_instance = YLeafList(YType.uint32, "bridge-port-count-instance")

                            self.esi_id = YLeaf(YType.uint16, "esi-id")

                            self.ethernet_segment_identifier = YLeafList(YType.uint8, "ethernet-segment-identifier")

                            self.evpn_shg_local_label = YLeaf(YType.uint32, "evpn-shg-local-label")

                            self.instance_id = YLeafList(YType.uint32, "instance-id")

                            self.instances_provisioned = YLeafList(YType.boolean, "instances-provisioned")

                            self.instances_state = YLeafList(YType.enumeration, "instances-state")

                            self.mac = YLeaf(YType.str, "mac")

                            self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                            self.main_interface = YLeaf(YType.str, "main-interface")

                            self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                            self.evpn_shg_remote_info = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bridge_port_count_instance",
                                            "esi_id",
                                            "ethernet_segment_identifier",
                                            "evpn_shg_local_label",
                                            "instance_id",
                                            "instances_provisioned",
                                            "instances_state",
                                            "mac",
                                            "main_if_type",
                                            "main_interface",
                                            "virtual_if_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo, self).__setattr__(name, value)


                        class EvpnShgRemoteInfo(Entity):
                            """
                            EVPN split horizon group remote info
                            
                            .. attribute:: remote_split_horizon_group_label
                            
                            	Remote split horizon group label
                            	**type**\:   :py:class:`RemoteSplitHorizonGroupLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo, self).__init__()

                                self.yang_name = "evpn-shg-remote-info"
                                self.yang_parent_name = "l2fib-main-interface-detail-info"

                                self.remote_split_horizon_group_label = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                self.remote_split_horizon_group_label.parent = self
                                self._children_name_map["remote_split_horizon_group_label"] = "remote-split-horizon-group-label"
                                self._children_yang_names.add("remote-split-horizon-group-label")


                            class RemoteSplitHorizonGroupLabel(Entity):
                                """
                                Remote split horizon group label
                                
                                .. attribute:: label
                                
                                	Split horizon label associated with next\-hop address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	Next\-hop IP address (v6 format)
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__init__()

                                    self.yang_name = "remote-split-horizon-group-label"
                                    self.yang_parent_name = "evpn-shg-remote-info"

                                    self.label = YLeaf(YType.uint32, "label")

                                    self.next_hop = YLeaf(YType.str, "next-hop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("label",
                                                    "next_hop") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.label.is_set or
                                        self.next_hop.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.label.yfilter != YFilter.not_set or
                                        self.next_hop.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-split-horizon-group-label" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.label.is_set or self.label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label.get_name_leafdata())
                                    if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "label" or name == "next-hop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "label"):
                                        self.label = value
                                        self.label.value_namespace = name_space
                                        self.label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop"):
                                        self.next_hop = value
                                        self.next_hop.value_namespace = name_space
                                        self.next_hop.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (self.remote_split_horizon_group_label is not None and self.remote_split_horizon_group_label.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.remote_split_horizon_group_label is not None and self.remote_split_horizon_group_label.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn-shg-remote-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "remote-split-horizon-group-label"):
                                    if (self.remote_split_horizon_group_label is None):
                                        self.remote_split_horizon_group_label = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                        self.remote_split_horizon_group_label.parent = self
                                        self._children_name_map["remote_split_horizon_group_label"] = "remote-split-horizon-group-label"
                                    return self.remote_split_horizon_group_label

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "remote-split-horizon-group-label"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            for c in self.evpn_shg_remote_info:
                                if (c.has_data()):
                                    return True
                            for leaf in self.bridge_port_count_instance.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.ethernet_segment_identifier.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.esi_id.is_set or
                                self.evpn_shg_local_label.is_set or
                                self.mac.is_set or
                                self.main_if_type.is_set or
                                self.main_interface.is_set or
                                self.virtual_if_name.is_set)

                        def has_operation(self):
                            for c in self.evpn_shg_remote_info:
                                if (c.has_operation()):
                                    return True
                            for leaf in self.bridge_port_count_instance.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.ethernet_segment_identifier.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bridge_port_count_instance.yfilter != YFilter.not_set or
                                self.esi_id.yfilter != YFilter.not_set or
                                self.ethernet_segment_identifier.yfilter != YFilter.not_set or
                                self.evpn_shg_local_label.yfilter != YFilter.not_set or
                                self.instance_id.yfilter != YFilter.not_set or
                                self.instances_provisioned.yfilter != YFilter.not_set or
                                self.instances_state.yfilter != YFilter.not_set or
                                self.mac.yfilter != YFilter.not_set or
                                self.main_if_type.yfilter != YFilter.not_set or
                                self.main_interface.yfilter != YFilter.not_set or
                                self.virtual_if_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-main-interface-detail-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.esi_id.is_set or self.esi_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.esi_id.get_name_leafdata())
                            if (self.evpn_shg_local_label.is_set or self.evpn_shg_local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_shg_local_label.get_name_leafdata())
                            if (self.mac.is_set or self.mac.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac.get_name_leafdata())
                            if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_if_type.get_name_leafdata())
                            if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_interface.get_name_leafdata())
                            if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                            leaf_name_data.extend(self.bridge_port_count_instance.get_name_leafdata())

                            leaf_name_data.extend(self.ethernet_segment_identifier.get_name_leafdata())

                            leaf_name_data.extend(self.instance_id.get_name_leafdata())

                            leaf_name_data.extend(self.instances_provisioned.get_name_leafdata())

                            leaf_name_data.extend(self.instances_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "evpn-shg-remote-info"):
                                for c in self.evpn_shg_remote_info:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.evpn_shg_remote_info.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "evpn-shg-remote-info" or name == "bridge-port-count-instance" or name == "esi-id" or name == "ethernet-segment-identifier" or name == "evpn-shg-local-label" or name == "instance-id" or name == "instances-provisioned" or name == "instances-state" or name == "mac" or name == "main-if-type" or name == "main-interface" or name == "virtual-if-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bridge-port-count-instance"):
                                self.bridge_port_count_instance.append(value)
                            if(value_path == "esi-id"):
                                self.esi_id = value
                                self.esi_id.value_namespace = name_space
                                self.esi_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ethernet-segment-identifier"):
                                self.ethernet_segment_identifier.append(value)
                            if(value_path == "evpn-shg-local-label"):
                                self.evpn_shg_local_label = value
                                self.evpn_shg_local_label.value_namespace = name_space
                                self.evpn_shg_local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "instance-id"):
                                self.instance_id.append(value)
                            if(value_path == "instances-provisioned"):
                                self.instances_provisioned.append(value)
                            if(value_path == "instances-state"):
                                self.instances_state.append(value)
                            if(value_path == "mac"):
                                self.mac = value
                                self.mac.value_namespace = name_space
                                self.mac.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-if-type"):
                                self.main_if_type = value
                                self.main_if_type.value_namespace = name_space
                                self.main_if_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-interface"):
                                self.main_interface = value
                                self.main_interface.value_namespace = name_space
                                self.main_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-if-name"):
                                self.virtual_if_name = value
                                self.virtual_if_name.value_namespace = name_space
                                self.virtual_if_name.value_namespace_prefix = name_space_prefix


                    class L2FibMainInterfaceHardwareIngressDetailInfo(Entity):
                        """
                        Main Interface hardware ingress detail info
                        
                        .. attribute:: bridge_port_count_instance
                        
                        	Number of bridge ports per instance
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: esi_id
                        
                        	Ethernet segment ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ethernet_segment_identifier
                        
                        	Ethernet Segment Identifier
                        	**type**\:  list of int
                        
                        	**range:** 0..255
                        
                        .. attribute:: evpn_shg_local_label
                        
                        	EVPN split horizon group local label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_shg_remote_info
                        
                        	EVPN split horizon group remote info
                        	**type**\: list of    :py:class:`EvpnShgRemoteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo>`
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                        
                        .. attribute:: mac
                        
                        	MAC Address
                        	**type**\:  str
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-hardware-ingress-detail-info"
                            self.yang_parent_name = "l2fib-main-interface"

                            self.bridge_port_count_instance = YLeafList(YType.uint32, "bridge-port-count-instance")

                            self.esi_id = YLeaf(YType.uint16, "esi-id")

                            self.ethernet_segment_identifier = YLeafList(YType.uint8, "ethernet-segment-identifier")

                            self.evpn_shg_local_label = YLeaf(YType.uint32, "evpn-shg-local-label")

                            self.instance_id = YLeafList(YType.uint32, "instance-id")

                            self.instances_provisioned = YLeafList(YType.boolean, "instances-provisioned")

                            self.instances_state = YLeafList(YType.enumeration, "instances-state")

                            self.mac = YLeaf(YType.str, "mac")

                            self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                            self.main_interface = YLeaf(YType.str, "main-interface")

                            self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                            self.evpn_shg_remote_info = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bridge_port_count_instance",
                                            "esi_id",
                                            "ethernet_segment_identifier",
                                            "evpn_shg_local_label",
                                            "instance_id",
                                            "instances_provisioned",
                                            "instances_state",
                                            "mac",
                                            "main_if_type",
                                            "main_interface",
                                            "virtual_if_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo, self).__setattr__(name, value)


                        class EvpnShgRemoteInfo(Entity):
                            """
                            EVPN split horizon group remote info
                            
                            .. attribute:: remote_split_horizon_group_label
                            
                            	Remote split horizon group label
                            	**type**\:   :py:class:`RemoteSplitHorizonGroupLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo, self).__init__()

                                self.yang_name = "evpn-shg-remote-info"
                                self.yang_parent_name = "l2fib-main-interface-hardware-ingress-detail-info"

                                self.remote_split_horizon_group_label = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                self.remote_split_horizon_group_label.parent = self
                                self._children_name_map["remote_split_horizon_group_label"] = "remote-split-horizon-group-label"
                                self._children_yang_names.add("remote-split-horizon-group-label")


                            class RemoteSplitHorizonGroupLabel(Entity):
                                """
                                Remote split horizon group label
                                
                                .. attribute:: label
                                
                                	Split horizon label associated with next\-hop address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	Next\-hop IP address (v6 format)
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__init__()

                                    self.yang_name = "remote-split-horizon-group-label"
                                    self.yang_parent_name = "evpn-shg-remote-info"

                                    self.label = YLeaf(YType.uint32, "label")

                                    self.next_hop = YLeaf(YType.str, "next-hop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("label",
                                                    "next_hop") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.label.is_set or
                                        self.next_hop.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.label.yfilter != YFilter.not_set or
                                        self.next_hop.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-split-horizon-group-label" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.label.is_set or self.label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label.get_name_leafdata())
                                    if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "label" or name == "next-hop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "label"):
                                        self.label = value
                                        self.label.value_namespace = name_space
                                        self.label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop"):
                                        self.next_hop = value
                                        self.next_hop.value_namespace = name_space
                                        self.next_hop.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (self.remote_split_horizon_group_label is not None and self.remote_split_horizon_group_label.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.remote_split_horizon_group_label is not None and self.remote_split_horizon_group_label.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn-shg-remote-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "remote-split-horizon-group-label"):
                                    if (self.remote_split_horizon_group_label is None):
                                        self.remote_split_horizon_group_label = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                        self.remote_split_horizon_group_label.parent = self
                                        self._children_name_map["remote_split_horizon_group_label"] = "remote-split-horizon-group-label"
                                    return self.remote_split_horizon_group_label

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "remote-split-horizon-group-label"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            for c in self.evpn_shg_remote_info:
                                if (c.has_data()):
                                    return True
                            for leaf in self.bridge_port_count_instance.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.ethernet_segment_identifier.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.esi_id.is_set or
                                self.evpn_shg_local_label.is_set or
                                self.mac.is_set or
                                self.main_if_type.is_set or
                                self.main_interface.is_set or
                                self.virtual_if_name.is_set)

                        def has_operation(self):
                            for c in self.evpn_shg_remote_info:
                                if (c.has_operation()):
                                    return True
                            for leaf in self.bridge_port_count_instance.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.ethernet_segment_identifier.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bridge_port_count_instance.yfilter != YFilter.not_set or
                                self.esi_id.yfilter != YFilter.not_set or
                                self.ethernet_segment_identifier.yfilter != YFilter.not_set or
                                self.evpn_shg_local_label.yfilter != YFilter.not_set or
                                self.instance_id.yfilter != YFilter.not_set or
                                self.instances_provisioned.yfilter != YFilter.not_set or
                                self.instances_state.yfilter != YFilter.not_set or
                                self.mac.yfilter != YFilter.not_set or
                                self.main_if_type.yfilter != YFilter.not_set or
                                self.main_interface.yfilter != YFilter.not_set or
                                self.virtual_if_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-main-interface-hardware-ingress-detail-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.esi_id.is_set or self.esi_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.esi_id.get_name_leafdata())
                            if (self.evpn_shg_local_label.is_set or self.evpn_shg_local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_shg_local_label.get_name_leafdata())
                            if (self.mac.is_set or self.mac.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac.get_name_leafdata())
                            if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_if_type.get_name_leafdata())
                            if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_interface.get_name_leafdata())
                            if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                            leaf_name_data.extend(self.bridge_port_count_instance.get_name_leafdata())

                            leaf_name_data.extend(self.ethernet_segment_identifier.get_name_leafdata())

                            leaf_name_data.extend(self.instance_id.get_name_leafdata())

                            leaf_name_data.extend(self.instances_provisioned.get_name_leafdata())

                            leaf_name_data.extend(self.instances_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "evpn-shg-remote-info"):
                                for c in self.evpn_shg_remote_info:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.evpn_shg_remote_info.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "evpn-shg-remote-info" or name == "bridge-port-count-instance" or name == "esi-id" or name == "ethernet-segment-identifier" or name == "evpn-shg-local-label" or name == "instance-id" or name == "instances-provisioned" or name == "instances-state" or name == "mac" or name == "main-if-type" or name == "main-interface" or name == "virtual-if-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bridge-port-count-instance"):
                                self.bridge_port_count_instance.append(value)
                            if(value_path == "esi-id"):
                                self.esi_id = value
                                self.esi_id.value_namespace = name_space
                                self.esi_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ethernet-segment-identifier"):
                                self.ethernet_segment_identifier.append(value)
                            if(value_path == "evpn-shg-local-label"):
                                self.evpn_shg_local_label = value
                                self.evpn_shg_local_label.value_namespace = name_space
                                self.evpn_shg_local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "instance-id"):
                                self.instance_id.append(value)
                            if(value_path == "instances-provisioned"):
                                self.instances_provisioned.append(value)
                            if(value_path == "instances-state"):
                                self.instances_state.append(value)
                            if(value_path == "mac"):
                                self.mac = value
                                self.mac.value_namespace = name_space
                                self.mac.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-if-type"):
                                self.main_if_type = value
                                self.main_if_type.value_namespace = name_space
                                self.main_if_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-interface"):
                                self.main_interface = value
                                self.main_interface.value_namespace = name_space
                                self.main_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-if-name"):
                                self.virtual_if_name = value
                                self.virtual_if_name.value_namespace = name_space
                                self.virtual_if_name.value_namespace_prefix = name_space_prefix


                    class L2FibMainInterfaceHardwareIngressInfo(Entity):
                        """
                        Main Interface hardware ingress info
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceState>`
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-hardware-ingress-info"
                            self.yang_parent_name = "l2fib-main-interface"

                            self.instance_id = YLeafList(YType.uint32, "instance-id")

                            self.instances_provisioned = YLeafList(YType.boolean, "instances-provisioned")

                            self.instances_state = YLeafList(YType.enumeration, "instances-state")

                            self.main_if_type = YLeaf(YType.uint8, "main-if-type")

                            self.main_interface = YLeaf(YType.str, "main-interface")

                            self.virtual_if_name = YLeaf(YType.str, "virtual-if-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("instance_id",
                                            "instances_provisioned",
                                            "instances_state",
                                            "main_if_type",
                                            "main_interface",
                                            "virtual_if_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressInfo, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.main_if_type.is_set or
                                self.main_interface.is_set or
                                self.virtual_if_name.is_set)

                        def has_operation(self):
                            for leaf in self.instance_id.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_provisioned.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.instances_state.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.instance_id.yfilter != YFilter.not_set or
                                self.instances_provisioned.yfilter != YFilter.not_set or
                                self.instances_state.yfilter != YFilter.not_set or
                                self.main_if_type.yfilter != YFilter.not_set or
                                self.main_interface.yfilter != YFilter.not_set or
                                self.virtual_if_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-main-interface-hardware-ingress-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.main_if_type.is_set or self.main_if_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_if_type.get_name_leafdata())
                            if (self.main_interface.is_set or self.main_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_interface.get_name_leafdata())
                            if (self.virtual_if_name.is_set or self.virtual_if_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_if_name.get_name_leafdata())

                            leaf_name_data.extend(self.instance_id.get_name_leafdata())

                            leaf_name_data.extend(self.instances_provisioned.get_name_leafdata())

                            leaf_name_data.extend(self.instances_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "instance-id" or name == "instances-provisioned" or name == "instances-state" or name == "main-if-type" or name == "main-interface" or name == "virtual-if-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "instance-id"):
                                self.instance_id.append(value)
                            if(value_path == "instances-provisioned"):
                                self.instances_provisioned.append(value)
                            if(value_path == "instances-state"):
                                self.instances_state.append(value)
                            if(value_path == "main-if-type"):
                                self.main_if_type = value
                                self.main_if_type.value_namespace = name_space
                                self.main_if_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-interface"):
                                self.main_interface = value
                                self.main_interface.value_namespace = name_space
                                self.main_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-if-name"):
                                self.virtual_if_name = value
                                self.virtual_if_name.value_namespace = name_space
                                self.virtual_if_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.main_interface_id.is_set or
                            self.main_interface_type.is_set or
                            (self.l2fib_main_interface_detail_info is not None and self.l2fib_main_interface_detail_info.has_data()) or
                            (self.l2fib_main_interface_hardware_egress_detail_info is not None and self.l2fib_main_interface_hardware_egress_detail_info.has_data()) or
                            (self.l2fib_main_interface_hardware_egress_info is not None and self.l2fib_main_interface_hardware_egress_info.has_data()) or
                            (self.l2fib_main_interface_hardware_ingress_detail_info is not None and self.l2fib_main_interface_hardware_ingress_detail_info.has_data()) or
                            (self.l2fib_main_interface_hardware_ingress_info is not None and self.l2fib_main_interface_hardware_ingress_info.has_data()) or
                            (self.l2fib_main_interface_info is not None and self.l2fib_main_interface_info.has_data()) or
                            (self.l2fib_main_interface_instances is not None and self.l2fib_main_interface_instances.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.main_interface_id.yfilter != YFilter.not_set or
                            self.main_interface_type.yfilter != YFilter.not_set or
                            (self.l2fib_main_interface_detail_info is not None and self.l2fib_main_interface_detail_info.has_operation()) or
                            (self.l2fib_main_interface_hardware_egress_detail_info is not None and self.l2fib_main_interface_hardware_egress_detail_info.has_operation()) or
                            (self.l2fib_main_interface_hardware_egress_info is not None and self.l2fib_main_interface_hardware_egress_info.has_operation()) or
                            (self.l2fib_main_interface_hardware_ingress_detail_info is not None and self.l2fib_main_interface_hardware_ingress_detail_info.has_operation()) or
                            (self.l2fib_main_interface_hardware_ingress_info is not None and self.l2fib_main_interface_hardware_ingress_info.has_operation()) or
                            (self.l2fib_main_interface_info is not None and self.l2fib_main_interface_info.has_operation()) or
                            (self.l2fib_main_interface_instances is not None and self.l2fib_main_interface_instances.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-main-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.main_interface_id.is_set or self.main_interface_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.main_interface_id.get_name_leafdata())
                        if (self.main_interface_type.is_set or self.main_interface_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.main_interface_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2fib-main-interface-detail-info"):
                            if (self.l2fib_main_interface_detail_info is None):
                                self.l2fib_main_interface_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo()
                                self.l2fib_main_interface_detail_info.parent = self
                                self._children_name_map["l2fib_main_interface_detail_info"] = "l2fib-main-interface-detail-info"
                            return self.l2fib_main_interface_detail_info

                        if (child_yang_name == "l2fib-main-interface-hardware-egress-detail-info"):
                            if (self.l2fib_main_interface_hardware_egress_detail_info is None):
                                self.l2fib_main_interface_hardware_egress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo()
                                self.l2fib_main_interface_hardware_egress_detail_info.parent = self
                                self._children_name_map["l2fib_main_interface_hardware_egress_detail_info"] = "l2fib-main-interface-hardware-egress-detail-info"
                            return self.l2fib_main_interface_hardware_egress_detail_info

                        if (child_yang_name == "l2fib-main-interface-hardware-egress-info"):
                            if (self.l2fib_main_interface_hardware_egress_info is None):
                                self.l2fib_main_interface_hardware_egress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressInfo()
                                self.l2fib_main_interface_hardware_egress_info.parent = self
                                self._children_name_map["l2fib_main_interface_hardware_egress_info"] = "l2fib-main-interface-hardware-egress-info"
                            return self.l2fib_main_interface_hardware_egress_info

                        if (child_yang_name == "l2fib-main-interface-hardware-ingress-detail-info"):
                            if (self.l2fib_main_interface_hardware_ingress_detail_info is None):
                                self.l2fib_main_interface_hardware_ingress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo()
                                self.l2fib_main_interface_hardware_ingress_detail_info.parent = self
                                self._children_name_map["l2fib_main_interface_hardware_ingress_detail_info"] = "l2fib-main-interface-hardware-ingress-detail-info"
                            return self.l2fib_main_interface_hardware_ingress_detail_info

                        if (child_yang_name == "l2fib-main-interface-hardware-ingress-info"):
                            if (self.l2fib_main_interface_hardware_ingress_info is None):
                                self.l2fib_main_interface_hardware_ingress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressInfo()
                                self.l2fib_main_interface_hardware_ingress_info.parent = self
                                self._children_name_map["l2fib_main_interface_hardware_ingress_info"] = "l2fib-main-interface-hardware-ingress-info"
                            return self.l2fib_main_interface_hardware_ingress_info

                        if (child_yang_name == "l2fib-main-interface-info"):
                            if (self.l2fib_main_interface_info is None):
                                self.l2fib_main_interface_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInfo()
                                self.l2fib_main_interface_info.parent = self
                                self._children_name_map["l2fib_main_interface_info"] = "l2fib-main-interface-info"
                            return self.l2fib_main_interface_info

                        if (child_yang_name == "l2fib-main-interface-instances"):
                            if (self.l2fib_main_interface_instances is None):
                                self.l2fib_main_interface_instances = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances()
                                self.l2fib_main_interface_instances.parent = self
                                self._children_name_map["l2fib_main_interface_instances"] = "l2fib-main-interface-instances"
                            return self.l2fib_main_interface_instances

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2fib-main-interface-detail-info" or name == "l2fib-main-interface-hardware-egress-detail-info" or name == "l2fib-main-interface-hardware-egress-info" or name == "l2fib-main-interface-hardware-ingress-detail-info" or name == "l2fib-main-interface-hardware-ingress-info" or name == "l2fib-main-interface-info" or name == "l2fib-main-interface-instances" or name == "main-interface-id" or name == "main-interface-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "main-interface-id"):
                            self.main_interface_id = value
                            self.main_interface_id.value_namespace = name_space
                            self.main_interface_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "main-interface-type"):
                            self.main_interface_type = value
                            self.main_interface_type.value_namespace = name_space
                            self.main_interface_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_main_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_main_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-main-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-main-interface"):
                        for c in self.l2fib_main_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_main_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-main-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMstpDetails(Entity):
                """
                MSTP Detail Table
                
                .. attribute:: l2fib_mstp_detail
                
                	MSTP Detail information
                	**type**\: list of    :py:class:`L2FibMstpDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMstpDetails, self).__init__()

                    self.yang_name = "l2fib-mstp-details"
                    self.yang_parent_name = "node"

                    self.l2fib_mstp_detail = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMstpDetails, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMstpDetails, self).__setattr__(name, value)


                class L2FibMstpDetail(Entity):
                    """
                    MSTP Detail information
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail.Base>`
                    
                    .. attribute:: bridge_port_array
                    
                    	Bridge port
                    	**type**\:  list of str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: internal_msti
                    
                    	multi\-spanning tree instance internal value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: learn_key
                    
                    	Learn Key
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: msti
                    
                    	MSTI context
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: msti_xr
                    
                    	multi\-spanning tree instance configured value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_interface
                    
                    	Parent interface context
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: parent_interface_xr
                    
                    	main port ID
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: state
                    
                    	MSTI state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail, self).__init__()

                        self.yang_name = "l2fib-mstp-detail"
                        self.yang_parent_name = "l2fib-mstp-details"

                        self.bridge_port_array = YLeafList(YType.str, "bridge-port-array")

                        self.internal_msti = YLeaf(YType.uint32, "internal-msti")

                        self.learn_key = YLeaf(YType.uint8, "learn-key")

                        self.msti = YLeaf(YType.int32, "msti")

                        self.msti_xr = YLeaf(YType.uint32, "msti-xr")

                        self.parent_interface = YLeaf(YType.str, "parent-interface")

                        self.parent_interface_xr = YLeaf(YType.str, "parent-interface-xr")

                        self.state = YLeaf(YType.uint32, "state")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bridge_port_array",
                                        "internal_msti",
                                        "learn_key",
                                        "msti",
                                        "msti_xr",
                                        "parent_interface",
                                        "parent_interface_xr",
                                        "state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fib-mstp-detail"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for leaf in self.bridge_port_array.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.internal_msti.is_set or
                            self.learn_key.is_set or
                            self.msti.is_set or
                            self.msti_xr.is_set or
                            self.parent_interface.is_set or
                            self.parent_interface_xr.is_set or
                            self.state.is_set or
                            (self.base is not None and self.base.has_data()))

                    def has_operation(self):
                        for leaf in self.bridge_port_array.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bridge_port_array.yfilter != YFilter.not_set or
                            self.internal_msti.yfilter != YFilter.not_set or
                            self.learn_key.yfilter != YFilter.not_set or
                            self.msti.yfilter != YFilter.not_set or
                            self.msti_xr.yfilter != YFilter.not_set or
                            self.parent_interface.yfilter != YFilter.not_set or
                            self.parent_interface_xr.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mstp-detail" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.internal_msti.is_set or self.internal_msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.internal_msti.get_name_leafdata())
                        if (self.learn_key.is_set or self.learn_key.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.learn_key.get_name_leafdata())
                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti.get_name_leafdata())
                        if (self.msti_xr.is_set or self.msti_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_xr.get_name_leafdata())
                        if (self.parent_interface.is_set or self.parent_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_interface.get_name_leafdata())
                        if (self.parent_interface_xr.is_set or self.parent_interface_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_interface_xr.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())

                        leaf_name_data.extend(self.bridge_port_array.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "bridge-port-array" or name == "internal-msti" or name == "learn-key" or name == "msti" or name == "msti-xr" or name == "parent-interface" or name == "parent-interface-xr" or name == "state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bridge-port-array"):
                            self.bridge_port_array.append(value)
                        if(value_path == "internal-msti"):
                            self.internal_msti = value
                            self.internal_msti.value_namespace = name_space
                            self.internal_msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "learn-key"):
                            self.learn_key = value
                            self.learn_key.value_namespace = name_space
                            self.learn_key.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti"):
                            self.msti = value
                            self.msti.value_namespace = name_space
                            self.msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-xr"):
                            self.msti_xr = value
                            self.msti_xr.value_namespace = name_space
                            self.msti_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-interface"):
                            self.parent_interface = value
                            self.parent_interface.value_namespace = name_space
                            self.parent_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-interface-xr"):
                            self.parent_interface_xr = value
                            self.parent_interface_xr.value_namespace = name_space
                            self.parent_interface_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_mstp_detail:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_mstp_detail:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-mstp-details" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-mstp-detail"):
                        for c in self.l2fib_mstp_detail:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_mstp_detail.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-mstp-detail"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibL2Tp(Entity):
                """
                L2TP
                
                .. attribute:: l2tpv2_sessions
                
                	L2TPV2 Session table
                	**type**\:   :py:class:`L2Tpv2Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions>`
                
                .. attribute:: l2tpv3_sessions
                
                	L2TPV3 Session table
                	**type**\:   :py:class:`L2Tpv3Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibL2Tp, self).__init__()

                    self.yang_name = "l2fib-l2tp"
                    self.yang_parent_name = "node"

                    self.l2tpv2_sessions = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions()
                    self.l2tpv2_sessions.parent = self
                    self._children_name_map["l2tpv2_sessions"] = "l2tpv2-sessions"
                    self._children_yang_names.add("l2tpv2-sessions")

                    self.l2tpv3_sessions = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions()
                    self.l2tpv3_sessions.parent = self
                    self._children_name_map["l2tpv3_sessions"] = "l2tpv3-sessions"
                    self._children_yang_names.add("l2tpv3-sessions")


                class L2Tpv3Sessions(Entity):
                    """
                    L2TPV3 Session table
                    
                    .. attribute:: l2tpv3_session
                    
                    	L2TPV3 Session
                    	**type**\: list of    :py:class:`L2Tpv3Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions, self).__init__()

                        self.yang_name = "l2tpv3-sessions"
                        self.yang_parent_name = "l2fib-l2tp"

                        self.l2tpv3_session = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions, self).__setattr__(name, value)


                    class L2Tpv3Session(Entity):
                        """
                        L2TPV3 Session
                        
                        .. attribute:: session_id  <key>
                        
                        	SessionID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: base
                        
                        	Base information
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session.Base>`
                        
                        .. attribute:: bound
                        
                        	Bind status
                        	**type**\:  bool
                        
                        .. attribute:: interface_handle
                        
                        	Interface handle of egress main interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: ipv4_table_id
                        
                        	IPv4 Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6_table_id
                        
                        	IPv6 Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nhop_ip_addr
                        
                        	NHOP IP Address of the tunnel
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: session_id_xr
                        
                        	Local Session Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: session_type
                        
                        	L2tp or L2tpv2 session
                        	**type**\:   :py:class:`L2FibL2TpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibL2TpSession>`
                        
                        .. attribute:: source_address
                        
                        	Source/Local IP address of the tunnel
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sub_interface_name
                        
                        	SubInterface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: tunnel_id_xr
                        
                        	Tunnel ID, l2tpv2
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session, self).__init__()

                            self.yang_name = "l2tpv3-session"
                            self.yang_parent_name = "l2tpv3-sessions"

                            self.session_id = YLeaf(YType.int32, "session-id")

                            self.bound = YLeaf(YType.boolean, "bound")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.ipv4_table_id = YLeaf(YType.uint32, "ipv4-table-id")

                            self.ipv6_table_id = YLeaf(YType.uint32, "ipv6-table-id")

                            self.nhop_ip_addr = YLeaf(YType.str, "nhop-ip-addr")

                            self.session_id_xr = YLeaf(YType.uint32, "session-id-xr")

                            self.session_type = YLeaf(YType.enumeration, "session-type")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.sub_interface_name = YLeaf(YType.str, "sub-interface-name")

                            self.tunnel_id_xr = YLeaf(YType.uint32, "tunnel-id-xr")

                            self.base = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._children_yang_names.add("base")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("session_id",
                                            "bound",
                                            "interface_handle",
                                            "ipv4_table_id",
                                            "ipv6_table_id",
                                            "nhop_ip_addr",
                                            "session_id_xr",
                                            "session_type",
                                            "source_address",
                                            "sub_interface_name",
                                            "tunnel_id_xr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session, self).__setattr__(name, value)


                        class Base(Entity):
                            """
                            Base information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "l2tpv3-session"

                            def has_data(self):
                                return False

                            def has_operation(self):
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "base" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.session_id.is_set or
                                self.bound.is_set or
                                self.interface_handle.is_set or
                                self.ipv4_table_id.is_set or
                                self.ipv6_table_id.is_set or
                                self.nhop_ip_addr.is_set or
                                self.session_id_xr.is_set or
                                self.session_type.is_set or
                                self.source_address.is_set or
                                self.sub_interface_name.is_set or
                                self.tunnel_id_xr.is_set or
                                (self.base is not None and self.base.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.session_id.yfilter != YFilter.not_set or
                                self.bound.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.ipv4_table_id.yfilter != YFilter.not_set or
                                self.ipv6_table_id.yfilter != YFilter.not_set or
                                self.nhop_ip_addr.yfilter != YFilter.not_set or
                                self.session_id_xr.yfilter != YFilter.not_set or
                                self.session_type.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.sub_interface_name.yfilter != YFilter.not_set or
                                self.tunnel_id_xr.yfilter != YFilter.not_set or
                                (self.base is not None and self.base.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2tpv3-session" + "[session-id='" + self.session_id.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.session_id.get_name_leafdata())
                            if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bound.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.ipv4_table_id.is_set or self.ipv4_table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_table_id.get_name_leafdata())
                            if (self.ipv6_table_id.is_set or self.ipv6_table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_table_id.get_name_leafdata())
                            if (self.nhop_ip_addr.is_set or self.nhop_ip_addr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nhop_ip_addr.get_name_leafdata())
                            if (self.session_id_xr.is_set or self.session_id_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.session_id_xr.get_name_leafdata())
                            if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.session_type.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.sub_interface_name.is_set or self.sub_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_interface_name.get_name_leafdata())
                            if (self.tunnel_id_xr.is_set or self.tunnel_id_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id_xr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "base"):
                                if (self.base is None):
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                return self.base

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "base" or name == "session-id" or name == "bound" or name == "interface-handle" or name == "ipv4-table-id" or name == "ipv6-table-id" or name == "nhop-ip-addr" or name == "session-id-xr" or name == "session-type" or name == "source-address" or name == "sub-interface-name" or name == "tunnel-id-xr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "session-id"):
                                self.session_id = value
                                self.session_id.value_namespace = name_space
                                self.session_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "bound"):
                                self.bound = value
                                self.bound.value_namespace = name_space
                                self.bound.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-table-id"):
                                self.ipv4_table_id = value
                                self.ipv4_table_id.value_namespace = name_space
                                self.ipv4_table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-table-id"):
                                self.ipv6_table_id = value
                                self.ipv6_table_id.value_namespace = name_space
                                self.ipv6_table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "nhop-ip-addr"):
                                self.nhop_ip_addr = value
                                self.nhop_ip_addr.value_namespace = name_space
                                self.nhop_ip_addr.value_namespace_prefix = name_space_prefix
                            if(value_path == "session-id-xr"):
                                self.session_id_xr = value
                                self.session_id_xr.value_namespace = name_space
                                self.session_id_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "session-type"):
                                self.session_type = value
                                self.session_type.value_namespace = name_space
                                self.session_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-interface-name"):
                                self.sub_interface_name = value
                                self.sub_interface_name.value_namespace = name_space
                                self.sub_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id-xr"):
                                self.tunnel_id_xr = value
                                self.tunnel_id_xr.value_namespace = name_space
                                self.tunnel_id_xr.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.l2tpv3_session:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.l2tpv3_session:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2tpv3-sessions" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2tpv3-session"):
                            for c in self.l2tpv3_session:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.l2tpv3_session.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2tpv3-session"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class L2Tpv2Sessions(Entity):
                    """
                    L2TPV2 Session table
                    
                    .. attribute:: l2tpv2_session
                    
                    	L2TPV2 Session
                    	**type**\: list of    :py:class:`L2Tpv2Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions, self).__init__()

                        self.yang_name = "l2tpv2-sessions"
                        self.yang_parent_name = "l2fib-l2tp"

                        self.l2tpv2_session = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions, self).__setattr__(name, value)


                    class L2Tpv2Session(Entity):
                        """
                        L2TPV2 Session
                        
                        .. attribute:: base
                        
                        	Base information
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session.Base>`
                        
                        .. attribute:: bound
                        
                        	Bind status
                        	**type**\:  bool
                        
                        .. attribute:: interface_handle
                        
                        	Interface handle of egress main interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: ipv4_table_id
                        
                        	IPv4 Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6_table_id
                        
                        	IPv6 Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nhop_ip_addr
                        
                        	NHOP IP Address of the tunnel
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: session_id
                        
                        	SessionID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: session_id_xr
                        
                        	Local Session Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: session_type
                        
                        	L2tp or L2tpv2 session
                        	**type**\:   :py:class:`L2FibL2TpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibL2TpSession>`
                        
                        .. attribute:: source_address
                        
                        	Source/Local IP address of the tunnel
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sub_interface_name
                        
                        	SubInterface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: tunnel_id
                        
                        	TunnelID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: tunnel_id_xr
                        
                        	Tunnel ID, l2tpv2
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session, self).__init__()

                            self.yang_name = "l2tpv2-session"
                            self.yang_parent_name = "l2tpv2-sessions"

                            self.bound = YLeaf(YType.boolean, "bound")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.ipv4_table_id = YLeaf(YType.uint32, "ipv4-table-id")

                            self.ipv6_table_id = YLeaf(YType.uint32, "ipv6-table-id")

                            self.nhop_ip_addr = YLeaf(YType.str, "nhop-ip-addr")

                            self.session_id = YLeaf(YType.int32, "session-id")

                            self.session_id_xr = YLeaf(YType.uint32, "session-id-xr")

                            self.session_type = YLeaf(YType.enumeration, "session-type")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.sub_interface_name = YLeaf(YType.str, "sub-interface-name")

                            self.tunnel_id = YLeaf(YType.int32, "tunnel-id")

                            self.tunnel_id_xr = YLeaf(YType.uint32, "tunnel-id-xr")

                            self.base = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._children_yang_names.add("base")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bound",
                                            "interface_handle",
                                            "ipv4_table_id",
                                            "ipv6_table_id",
                                            "nhop_ip_addr",
                                            "session_id",
                                            "session_id_xr",
                                            "session_type",
                                            "source_address",
                                            "sub_interface_name",
                                            "tunnel_id",
                                            "tunnel_id_xr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session, self).__setattr__(name, value)


                        class Base(Entity):
                            """
                            Base information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "l2tpv2-session"

                            def has_data(self):
                                return False

                            def has_operation(self):
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "base" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.bound.is_set or
                                self.interface_handle.is_set or
                                self.ipv4_table_id.is_set or
                                self.ipv6_table_id.is_set or
                                self.nhop_ip_addr.is_set or
                                self.session_id.is_set or
                                self.session_id_xr.is_set or
                                self.session_type.is_set or
                                self.source_address.is_set or
                                self.sub_interface_name.is_set or
                                self.tunnel_id.is_set or
                                self.tunnel_id_xr.is_set or
                                (self.base is not None and self.base.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bound.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.ipv4_table_id.yfilter != YFilter.not_set or
                                self.ipv6_table_id.yfilter != YFilter.not_set or
                                self.nhop_ip_addr.yfilter != YFilter.not_set or
                                self.session_id.yfilter != YFilter.not_set or
                                self.session_id_xr.yfilter != YFilter.not_set or
                                self.session_type.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.sub_interface_name.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id_xr.yfilter != YFilter.not_set or
                                (self.base is not None and self.base.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2tpv2-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bound.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.ipv4_table_id.is_set or self.ipv4_table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_table_id.get_name_leafdata())
                            if (self.ipv6_table_id.is_set or self.ipv6_table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_table_id.get_name_leafdata())
                            if (self.nhop_ip_addr.is_set or self.nhop_ip_addr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nhop_ip_addr.get_name_leafdata())
                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.session_id.get_name_leafdata())
                            if (self.session_id_xr.is_set or self.session_id_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.session_id_xr.get_name_leafdata())
                            if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.session_type.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.sub_interface_name.is_set or self.sub_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_interface_name.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())
                            if (self.tunnel_id_xr.is_set or self.tunnel_id_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id_xr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "base"):
                                if (self.base is None):
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                return self.base

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "base" or name == "bound" or name == "interface-handle" or name == "ipv4-table-id" or name == "ipv6-table-id" or name == "nhop-ip-addr" or name == "session-id" or name == "session-id-xr" or name == "session-type" or name == "source-address" or name == "sub-interface-name" or name == "tunnel-id" or name == "tunnel-id-xr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bound"):
                                self.bound = value
                                self.bound.value_namespace = name_space
                                self.bound.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-table-id"):
                                self.ipv4_table_id = value
                                self.ipv4_table_id.value_namespace = name_space
                                self.ipv4_table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-table-id"):
                                self.ipv6_table_id = value
                                self.ipv6_table_id.value_namespace = name_space
                                self.ipv6_table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "nhop-ip-addr"):
                                self.nhop_ip_addr = value
                                self.nhop_ip_addr.value_namespace = name_space
                                self.nhop_ip_addr.value_namespace_prefix = name_space_prefix
                            if(value_path == "session-id"):
                                self.session_id = value
                                self.session_id.value_namespace = name_space
                                self.session_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "session-id-xr"):
                                self.session_id_xr = value
                                self.session_id_xr.value_namespace = name_space
                                self.session_id_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "session-type"):
                                self.session_type = value
                                self.session_type.value_namespace = name_space
                                self.session_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-interface-name"):
                                self.sub_interface_name = value
                                self.sub_interface_name.value_namespace = name_space
                                self.sub_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id-xr"):
                                self.tunnel_id_xr = value
                                self.tunnel_id_xr.value_namespace = name_space
                                self.tunnel_id_xr.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.l2tpv2_session:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.l2tpv2_session:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2tpv2-sessions" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2tpv2-session"):
                            for c in self.l2tpv2_session:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.l2tpv2_session.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2tpv2-session"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.l2tpv2_sessions is not None and self.l2tpv2_sessions.has_data()) or
                        (self.l2tpv3_sessions is not None and self.l2tpv3_sessions.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.l2tpv2_sessions is not None and self.l2tpv2_sessions.has_operation()) or
                        (self.l2tpv3_sessions is not None and self.l2tpv3_sessions.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-l2tp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2tpv2-sessions"):
                        if (self.l2tpv2_sessions is None):
                            self.l2tpv2_sessions = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions()
                            self.l2tpv2_sessions.parent = self
                            self._children_name_map["l2tpv2_sessions"] = "l2tpv2-sessions"
                        return self.l2tpv2_sessions

                    if (child_yang_name == "l2tpv3-sessions"):
                        if (self.l2tpv3_sessions is None):
                            self.l2tpv3_sessions = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions()
                            self.l2tpv3_sessions.parent = self
                            self._children_name_map["l2tpv3_sessions"] = "l2tpv3-sessions"
                        return self.l2tpv3_sessions

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2tpv2-sessions" or name == "l2tpv3-sessions"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibG8032(Entity):
                """
                G8032 information
                
                .. attribute:: l2fib_g8032_rings
                
                	G8032 Ring table
                	**type**\:   :py:class:`L2FibG8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibG8032, self).__init__()

                    self.yang_name = "l2fib-g8032"
                    self.yang_parent_name = "node"

                    self.l2fib_g8032_rings = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings()
                    self.l2fib_g8032_rings.parent = self
                    self._children_name_map["l2fib_g8032_rings"] = "l2fib-g8032-rings"
                    self._children_yang_names.add("l2fib-g8032-rings")


                class L2FibG8032Rings(Entity):
                    """
                    G8032 Ring table
                    
                    .. attribute:: l2fib_g8032_ring
                    
                    	G8032 Ring
                    	**type**\: list of    :py:class:`L2FibG8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings, self).__init__()

                        self.yang_name = "l2fib-g8032-rings"
                        self.yang_parent_name = "l2fib-g8032"

                        self.l2fib_g8032_ring = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings, self).__setattr__(name, value)


                    class L2FibG8032Ring(Entity):
                        """
                        G8032 Ring
                        
                        .. attribute:: ring_name  <key>
                        
                        	Ring Name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: l2fib_g8032_ring_detail
                        
                        	G8032 Ring detailed information
                        	**type**\:   :py:class:`L2FibG8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingDetail>`
                        
                        .. attribute:: l2fib_g8032_ring_instance_details
                        
                        	G8032 Ring Instance detail table
                        	**type**\:   :py:class:`L2FibG8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails>`
                        
                        .. attribute:: l2fib_g8032_ring_instance_summaries
                        
                        	G8032 Ring Instance summary table
                        	**type**\:   :py:class:`L2FibG8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries>`
                        
                        .. attribute:: l2fib_g8032_ring_summary
                        
                        	G8032 Ring summary information
                        	**type**\:   :py:class:`L2FibG8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingSummary>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring, self).__init__()

                            self.yang_name = "l2fib-g8032-ring"
                            self.yang_parent_name = "l2fib-g8032-rings"

                            self.ring_name = YLeaf(YType.str, "ring-name")

                            self.l2fib_g8032_ring_detail = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingDetail()
                            self.l2fib_g8032_ring_detail.parent = self
                            self._children_name_map["l2fib_g8032_ring_detail"] = "l2fib-g8032-ring-detail"
                            self._children_yang_names.add("l2fib-g8032-ring-detail")

                            self.l2fib_g8032_ring_instance_details = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails()
                            self.l2fib_g8032_ring_instance_details.parent = self
                            self._children_name_map["l2fib_g8032_ring_instance_details"] = "l2fib-g8032-ring-instance-details"
                            self._children_yang_names.add("l2fib-g8032-ring-instance-details")

                            self.l2fib_g8032_ring_instance_summaries = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries()
                            self.l2fib_g8032_ring_instance_summaries.parent = self
                            self._children_name_map["l2fib_g8032_ring_instance_summaries"] = "l2fib-g8032-ring-instance-summaries"
                            self._children_yang_names.add("l2fib-g8032-ring-instance-summaries")

                            self.l2fib_g8032_ring_summary = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingSummary()
                            self.l2fib_g8032_ring_summary.parent = self
                            self._children_name_map["l2fib_g8032_ring_summary"] = "l2fib-g8032-ring-summary"
                            self._children_yang_names.add("l2fib-g8032-ring-summary")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ring_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring, self).__setattr__(name, value)


                        class L2FibG8032RingDetail(Entity):
                            """
                            G8032 Ring detailed information
                            
                            .. attribute:: is_open_ring
                            
                            	Open Ring
                            	**type**\:  bool
                            
                            .. attribute:: monitor0
                            
                            	Monitor port 0
                            	**type**\:  str
                            
                            .. attribute:: monitor1
                            
                            	Monitor port 1
                            	**type**\:  str
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\:  str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\:  str
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingDetail, self).__init__()

                                self.yang_name = "l2fib-g8032-ring-detail"
                                self.yang_parent_name = "l2fib-g8032-ring"

                                self.is_open_ring = YLeaf(YType.boolean, "is-open-ring")

                                self.monitor0 = YLeaf(YType.str, "monitor0")

                                self.monitor1 = YLeaf(YType.str, "monitor1")

                                self.port0 = YLeaf(YType.str, "port0")

                                self.port1 = YLeaf(YType.str, "port1")

                                self.ring_name = YLeaf(YType.str, "ring-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_open_ring",
                                                "monitor0",
                                                "monitor1",
                                                "port0",
                                                "port1",
                                                "ring_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingDetail, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingDetail, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.is_open_ring.is_set or
                                    self.monitor0.is_set or
                                    self.monitor1.is_set or
                                    self.port0.is_set or
                                    self.port1.is_set or
                                    self.ring_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_open_ring.yfilter != YFilter.not_set or
                                    self.monitor0.yfilter != YFilter.not_set or
                                    self.monitor1.yfilter != YFilter.not_set or
                                    self.port0.yfilter != YFilter.not_set or
                                    self.port1.yfilter != YFilter.not_set or
                                    self.ring_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2fib-g8032-ring-detail" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_open_ring.is_set or self.is_open_ring.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_open_ring.get_name_leafdata())
                                if (self.monitor0.is_set or self.monitor0.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor0.get_name_leafdata())
                                if (self.monitor1.is_set or self.monitor1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor1.get_name_leafdata())
                                if (self.port0.is_set or self.port0.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port0.get_name_leafdata())
                                if (self.port1.is_set or self.port1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port1.get_name_leafdata())
                                if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "is-open-ring" or name == "monitor0" or name == "monitor1" or name == "port0" or name == "port1" or name == "ring-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-open-ring"):
                                    self.is_open_ring = value
                                    self.is_open_ring.value_namespace = name_space
                                    self.is_open_ring.value_namespace_prefix = name_space_prefix
                                if(value_path == "monitor0"):
                                    self.monitor0 = value
                                    self.monitor0.value_namespace = name_space
                                    self.monitor0.value_namespace_prefix = name_space_prefix
                                if(value_path == "monitor1"):
                                    self.monitor1 = value
                                    self.monitor1.value_namespace = name_space
                                    self.monitor1.value_namespace_prefix = name_space_prefix
                                if(value_path == "port0"):
                                    self.port0 = value
                                    self.port0.value_namespace = name_space
                                    self.port0.value_namespace_prefix = name_space_prefix
                                if(value_path == "port1"):
                                    self.port1 = value
                                    self.port1.value_namespace = name_space
                                    self.port1.value_namespace_prefix = name_space_prefix
                                if(value_path == "ring-name"):
                                    self.ring_name = value
                                    self.ring_name.value_namespace = name_space
                                    self.ring_name.value_namespace_prefix = name_space_prefix


                        class L2FibG8032RingSummary(Entity):
                            """
                            G8032 Ring summary information
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\:  str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\:  str
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingSummary, self).__init__()

                                self.yang_name = "l2fib-g8032-ring-summary"
                                self.yang_parent_name = "l2fib-g8032-ring"

                                self.port0 = YLeaf(YType.str, "port0")

                                self.port1 = YLeaf(YType.str, "port1")

                                self.ring_name = YLeaf(YType.str, "ring-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("port0",
                                                "port1",
                                                "ring_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingSummary, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingSummary, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.port0.is_set or
                                    self.port1.is_set or
                                    self.ring_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.port0.yfilter != YFilter.not_set or
                                    self.port1.yfilter != YFilter.not_set or
                                    self.ring_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2fib-g8032-ring-summary" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.port0.is_set or self.port0.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port0.get_name_leafdata())
                                if (self.port1.is_set or self.port1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port1.get_name_leafdata())
                                if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port0" or name == "port1" or name == "ring-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "port0"):
                                    self.port0 = value
                                    self.port0.value_namespace = name_space
                                    self.port0.value_namespace_prefix = name_space_prefix
                                if(value_path == "port1"):
                                    self.port1 = value
                                    self.port1.value_namespace = name_space
                                    self.port1.value_namespace_prefix = name_space_prefix
                                if(value_path == "ring-name"):
                                    self.ring_name = value
                                    self.ring_name.value_namespace = name_space
                                    self.ring_name.value_namespace_prefix = name_space_prefix


                        class L2FibG8032RingInstanceSummaries(Entity):
                            """
                            G8032 Ring Instance summary table
                            
                            .. attribute:: l2fib_g8032_ring_instance_summary
                            
                            	G8032 Ring Instance summary information
                            	**type**\: list of    :py:class:`L2FibG8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries.L2FibG8032RingInstanceSummary>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries, self).__init__()

                                self.yang_name = "l2fib-g8032-ring-instance-summaries"
                                self.yang_parent_name = "l2fib-g8032-ring"

                                self.l2fib_g8032_ring_instance_summary = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries, self).__setattr__(name, value)


                            class L2FibG8032RingInstanceSummary(Entity):
                                """
                                G8032 Ring Instance summary information
                                
                                .. attribute:: instance  <key>
                                
                                	Instance
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries.L2FibG8032RingInstanceSummary, self).__init__()

                                    self.yang_name = "l2fib-g8032-ring-instance-summary"
                                    self.yang_parent_name = "l2fib-g8032-ring-instance-summaries"

                                    self.instance = YLeaf(YType.int32, "instance")

                                    self.aps_port0 = YLeaf(YType.str, "aps-port0")

                                    self.aps_port1 = YLeaf(YType.str, "aps-port1")

                                    self.ring_instance = YLeaf(YType.uint32, "ring-instance")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("instance",
                                                    "aps_port0",
                                                    "aps_port1",
                                                    "ring_instance") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries.L2FibG8032RingInstanceSummary, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries.L2FibG8032RingInstanceSummary, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.instance.is_set or
                                        self.aps_port0.is_set or
                                        self.aps_port1.is_set or
                                        self.ring_instance.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.instance.yfilter != YFilter.not_set or
                                        self.aps_port0.yfilter != YFilter.not_set or
                                        self.aps_port1.yfilter != YFilter.not_set or
                                        self.ring_instance.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fib-g8032-ring-instance-summary" + "[instance='" + self.instance.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                    if (self.aps_port0.is_set or self.aps_port0.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_port0.get_name_leafdata())
                                    if (self.aps_port1.is_set or self.aps_port1.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_port1.get_name_leafdata())
                                    if (self.ring_instance.is_set or self.ring_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ring_instance.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "instance" or name == "aps-port0" or name == "aps-port1" or name == "ring-instance"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "instance"):
                                        self.instance = value
                                        self.instance.value_namespace = name_space
                                        self.instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-port0"):
                                        self.aps_port0 = value
                                        self.aps_port0.value_namespace = name_space
                                        self.aps_port0.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-port1"):
                                        self.aps_port1 = value
                                        self.aps_port1.value_namespace = name_space
                                        self.aps_port1.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ring-instance"):
                                        self.ring_instance = value
                                        self.ring_instance.value_namespace = name_space
                                        self.ring_instance.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.l2fib_g8032_ring_instance_summary:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.l2fib_g8032_ring_instance_summary:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2fib-g8032-ring-instance-summaries" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "l2fib-g8032-ring-instance-summary"):
                                    for c in self.l2fib_g8032_ring_instance_summary:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries.L2FibG8032RingInstanceSummary()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.l2fib_g8032_ring_instance_summary.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "l2fib-g8032-ring-instance-summary"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2FibG8032RingInstanceDetails(Entity):
                            """
                            G8032 Ring Instance detail table
                            
                            .. attribute:: l2fib_g8032_ring_instance_detail
                            
                            	G8032 Ring Instance detailed information
                            	**type**\: list of    :py:class:`L2FibG8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails.L2FibG8032RingInstanceDetail>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails, self).__init__()

                                self.yang_name = "l2fib-g8032-ring-instance-details"
                                self.yang_parent_name = "l2fib-g8032-ring"

                                self.l2fib_g8032_ring_instance_detail = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails, self).__setattr__(name, value)


                            class L2FibG8032RingInstanceDetail(Entity):
                                """
                                G8032 Ring Instance detailed information
                                
                                .. attribute:: instance  <key>
                                
                                	Instance
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: aps_channel_level
                                
                                	APS channel level
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: aps_port_status0
                                
                                	Status of Port 0
                                	**type**\:   :py:class:`L2FibG8032ApsPortStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibG8032ApsPortStatus>`
                                
                                .. attribute:: aps_port_status1
                                
                                	Status of Port 1
                                	**type**\:   :py:class:`L2FibG8032ApsPortStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibG8032ApsPortStatus>`
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ring_profile
                                
                                	Ring Profile
                                	**type**\:  str
                                
                                .. attribute:: rpl
                                
                                	RPL
                                	**type**\:   :py:class:`L2FibG8032Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibG8032Rpl>`
                                
                                .. attribute:: vlan_ids
                                
                                	Vlan Ids
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails.L2FibG8032RingInstanceDetail, self).__init__()

                                    self.yang_name = "l2fib-g8032-ring-instance-detail"
                                    self.yang_parent_name = "l2fib-g8032-ring-instance-details"

                                    self.instance = YLeaf(YType.int32, "instance")

                                    self.aps_channel_level = YLeaf(YType.uint32, "aps-channel-level")

                                    self.aps_port0 = YLeaf(YType.str, "aps-port0")

                                    self.aps_port1 = YLeaf(YType.str, "aps-port1")

                                    self.aps_port_status0 = YLeaf(YType.enumeration, "aps-port-status0")

                                    self.aps_port_status1 = YLeaf(YType.enumeration, "aps-port-status1")

                                    self.ring_instance = YLeaf(YType.uint32, "ring-instance")

                                    self.ring_profile = YLeaf(YType.str, "ring-profile")

                                    self.rpl = YLeaf(YType.enumeration, "rpl")

                                    self.vlan_ids = YLeaf(YType.str, "vlan-ids")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("instance",
                                                    "aps_channel_level",
                                                    "aps_port0",
                                                    "aps_port1",
                                                    "aps_port_status0",
                                                    "aps_port_status1",
                                                    "ring_instance",
                                                    "ring_profile",
                                                    "rpl",
                                                    "vlan_ids") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails.L2FibG8032RingInstanceDetail, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails.L2FibG8032RingInstanceDetail, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.instance.is_set or
                                        self.aps_channel_level.is_set or
                                        self.aps_port0.is_set or
                                        self.aps_port1.is_set or
                                        self.aps_port_status0.is_set or
                                        self.aps_port_status1.is_set or
                                        self.ring_instance.is_set or
                                        self.ring_profile.is_set or
                                        self.rpl.is_set or
                                        self.vlan_ids.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.instance.yfilter != YFilter.not_set or
                                        self.aps_channel_level.yfilter != YFilter.not_set or
                                        self.aps_port0.yfilter != YFilter.not_set or
                                        self.aps_port1.yfilter != YFilter.not_set or
                                        self.aps_port_status0.yfilter != YFilter.not_set or
                                        self.aps_port_status1.yfilter != YFilter.not_set or
                                        self.ring_instance.yfilter != YFilter.not_set or
                                        self.ring_profile.yfilter != YFilter.not_set or
                                        self.rpl.yfilter != YFilter.not_set or
                                        self.vlan_ids.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fib-g8032-ring-instance-detail" + "[instance='" + self.instance.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                    if (self.aps_channel_level.is_set or self.aps_channel_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_channel_level.get_name_leafdata())
                                    if (self.aps_port0.is_set or self.aps_port0.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_port0.get_name_leafdata())
                                    if (self.aps_port1.is_set or self.aps_port1.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_port1.get_name_leafdata())
                                    if (self.aps_port_status0.is_set or self.aps_port_status0.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_port_status0.get_name_leafdata())
                                    if (self.aps_port_status1.is_set or self.aps_port_status1.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_port_status1.get_name_leafdata())
                                    if (self.ring_instance.is_set or self.ring_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ring_instance.get_name_leafdata())
                                    if (self.ring_profile.is_set or self.ring_profile.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ring_profile.get_name_leafdata())
                                    if (self.rpl.is_set or self.rpl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpl.get_name_leafdata())
                                    if (self.vlan_ids.is_set or self.vlan_ids.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_ids.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "instance" or name == "aps-channel-level" or name == "aps-port0" or name == "aps-port1" or name == "aps-port-status0" or name == "aps-port-status1" or name == "ring-instance" or name == "ring-profile" or name == "rpl" or name == "vlan-ids"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "instance"):
                                        self.instance = value
                                        self.instance.value_namespace = name_space
                                        self.instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-channel-level"):
                                        self.aps_channel_level = value
                                        self.aps_channel_level.value_namespace = name_space
                                        self.aps_channel_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-port0"):
                                        self.aps_port0 = value
                                        self.aps_port0.value_namespace = name_space
                                        self.aps_port0.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-port1"):
                                        self.aps_port1 = value
                                        self.aps_port1.value_namespace = name_space
                                        self.aps_port1.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-port-status0"):
                                        self.aps_port_status0 = value
                                        self.aps_port_status0.value_namespace = name_space
                                        self.aps_port_status0.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-port-status1"):
                                        self.aps_port_status1 = value
                                        self.aps_port_status1.value_namespace = name_space
                                        self.aps_port_status1.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ring-instance"):
                                        self.ring_instance = value
                                        self.ring_instance.value_namespace = name_space
                                        self.ring_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ring-profile"):
                                        self.ring_profile = value
                                        self.ring_profile.value_namespace = name_space
                                        self.ring_profile.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpl"):
                                        self.rpl = value
                                        self.rpl.value_namespace = name_space
                                        self.rpl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-ids"):
                                        self.vlan_ids = value
                                        self.vlan_ids.value_namespace = name_space
                                        self.vlan_ids.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.l2fib_g8032_ring_instance_detail:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.l2fib_g8032_ring_instance_detail:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2fib-g8032-ring-instance-details" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "l2fib-g8032-ring-instance-detail"):
                                    for c in self.l2fib_g8032_ring_instance_detail:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails.L2FibG8032RingInstanceDetail()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.l2fib_g8032_ring_instance_detail.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "l2fib-g8032-ring-instance-detail"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.ring_name.is_set or
                                (self.l2fib_g8032_ring_detail is not None and self.l2fib_g8032_ring_detail.has_data()) or
                                (self.l2fib_g8032_ring_instance_details is not None and self.l2fib_g8032_ring_instance_details.has_data()) or
                                (self.l2fib_g8032_ring_instance_summaries is not None and self.l2fib_g8032_ring_instance_summaries.has_data()) or
                                (self.l2fib_g8032_ring_summary is not None and self.l2fib_g8032_ring_summary.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ring_name.yfilter != YFilter.not_set or
                                (self.l2fib_g8032_ring_detail is not None and self.l2fib_g8032_ring_detail.has_operation()) or
                                (self.l2fib_g8032_ring_instance_details is not None and self.l2fib_g8032_ring_instance_details.has_operation()) or
                                (self.l2fib_g8032_ring_instance_summaries is not None and self.l2fib_g8032_ring_instance_summaries.has_operation()) or
                                (self.l2fib_g8032_ring_summary is not None and self.l2fib_g8032_ring_summary.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-g8032-ring" + "[ring-name='" + self.ring_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ring_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "l2fib-g8032-ring-detail"):
                                if (self.l2fib_g8032_ring_detail is None):
                                    self.l2fib_g8032_ring_detail = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingDetail()
                                    self.l2fib_g8032_ring_detail.parent = self
                                    self._children_name_map["l2fib_g8032_ring_detail"] = "l2fib-g8032-ring-detail"
                                return self.l2fib_g8032_ring_detail

                            if (child_yang_name == "l2fib-g8032-ring-instance-details"):
                                if (self.l2fib_g8032_ring_instance_details is None):
                                    self.l2fib_g8032_ring_instance_details = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails()
                                    self.l2fib_g8032_ring_instance_details.parent = self
                                    self._children_name_map["l2fib_g8032_ring_instance_details"] = "l2fib-g8032-ring-instance-details"
                                return self.l2fib_g8032_ring_instance_details

                            if (child_yang_name == "l2fib-g8032-ring-instance-summaries"):
                                if (self.l2fib_g8032_ring_instance_summaries is None):
                                    self.l2fib_g8032_ring_instance_summaries = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries()
                                    self.l2fib_g8032_ring_instance_summaries.parent = self
                                    self._children_name_map["l2fib_g8032_ring_instance_summaries"] = "l2fib-g8032-ring-instance-summaries"
                                return self.l2fib_g8032_ring_instance_summaries

                            if (child_yang_name == "l2fib-g8032-ring-summary"):
                                if (self.l2fib_g8032_ring_summary is None):
                                    self.l2fib_g8032_ring_summary = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingSummary()
                                    self.l2fib_g8032_ring_summary.parent = self
                                    self._children_name_map["l2fib_g8032_ring_summary"] = "l2fib-g8032-ring-summary"
                                return self.l2fib_g8032_ring_summary

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "l2fib-g8032-ring-detail" or name == "l2fib-g8032-ring-instance-details" or name == "l2fib-g8032-ring-instance-summaries" or name == "l2fib-g8032-ring-summary" or name == "ring-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ring-name"):
                                self.ring_name = value
                                self.ring_name.value_namespace = name_space
                                self.ring_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.l2fib_g8032_ring:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.l2fib_g8032_ring:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-g8032-rings" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2fib-g8032-ring"):
                            for c in self.l2fib_g8032_ring:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.l2fib_g8032_ring.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2fib-g8032-ring"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.l2fib_g8032_rings is not None and self.l2fib_g8032_rings.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.l2fib_g8032_rings is not None and self.l2fib_g8032_rings.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-g8032" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-g8032-rings"):
                        if (self.l2fib_g8032_rings is None):
                            self.l2fib_g8032_rings = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings()
                            self.l2fib_g8032_rings.parent = self
                            self._children_name_map["l2fib_g8032_rings"] = "l2fib-g8032-rings"
                        return self.l2fib_g8032_rings

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-g8032-rings"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibBridgePorts(Entity):
                """
                Bridge Port forwarding detail
                
                .. attribute:: l2fib_bridge_port
                
                	Specify Bridge Domain Name and XC ID
                	**type**\: list of    :py:class:`L2FibBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts, self).__init__()

                    self.yang_name = "l2fib-bridge-ports"
                    self.yang_parent_name = "node"

                    self.l2fib_bridge_port = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts, self).__setattr__(name, value)


                class L2FibBridgePort(Entity):
                    """
                    Specify Bridge Domain Name and XC ID
                    
                    .. attribute:: aging_time_out
                    
                    	Aging timeout
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_port_operational_info
                    
                    	Bridge port operational information
                    	**type**\:   :py:class:`BridgePortOperationalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo>`
                    
                    .. attribute:: flooding_disabled
                    
                    	Is flooding disabled
                    	**type**\:  bool
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: mac_learning_disabled
                    
                    	Is MAC learning disabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_limit
                    
                    	MAC limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_limit_action
                    
                    	MAC limit action
                    	**type**\:   :py:class:`MgmtL2FibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitAction>`
                    
                    .. attribute:: mac_port_down_flush_disabled
                    
                    	Is MAC port down flush disabled
                    	**type**\:  bool
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_hw_mac
                    
                    	Number of HW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_sw_mac
                    
                    	Number of SW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:   :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment>`
                    
                    .. attribute:: shg_id
                    
                    	Split horizon group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xc_id
                    
                    	xconnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xc_uint_id
                    
                    	XC ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort, self).__init__()

                        self.yang_name = "l2fib-bridge-port"
                        self.yang_parent_name = "l2fib-bridge-ports"

                        self.aging_time_out = YLeaf(YType.uint32, "aging-time-out")

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                        self.flooding_disabled = YLeaf(YType.boolean, "flooding-disabled")

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.mac_learning_disabled = YLeaf(YType.boolean, "mac-learning-disabled")

                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                        self.mac_port_down_flush_disabled = YLeaf(YType.boolean, "mac-port-down-flush-disabled")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.number_of_hw_mac = YLeaf(YType.uint32, "number-of-hw-mac")

                        self.number_of_sw_mac = YLeaf(YType.uint32, "number-of-sw-mac")

                        self.shg_id = YLeaf(YType.uint32, "shg-id")

                        self.xc_id = YLeaf(YType.uint32, "xc-id")

                        self.xc_uint_id = YLeaf(YType.str, "xc-uint-id")

                        self.bridge_port_operational_info = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo()
                        self.bridge_port_operational_info.parent = self
                        self._children_name_map["bridge_port_operational_info"] = "bridge-port-operational-info"
                        self._children_yang_names.add("bridge-port-operational-info")

                        self.segment = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment()
                        self.segment.parent = self
                        self._children_name_map["segment"] = "segment"
                        self._children_yang_names.add("segment")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("aging_time_out",
                                        "bd_name",
                                        "bridge_id",
                                        "flooding_disabled",
                                        "group_name",
                                        "mac_learning_disabled",
                                        "mac_limit",
                                        "mac_limit_action",
                                        "mac_port_down_flush_disabled",
                                        "mtu",
                                        "number_of_hw_mac",
                                        "number_of_sw_mac",
                                        "shg_id",
                                        "xc_id",
                                        "xc_uint_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort, self).__setattr__(name, value)


                    class Segment(Entity):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment, self).__init__()

                            self.yang_name = "segment"
                            self.yang_parent_name = "l2fib-bridge-port"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"
                            self._children_yang_names.add("evpn")

                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"
                            self._children_yang_names.add("pbb")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                            self.vni = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"
                            self._children_yang_names.add("vni")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment"

                                self.actype = YLeaf(YType.uint8, "actype")

                                self.adjacency_address = YLeaf(YType.str, "adjacency-address")

                                self.adjacency_valid = YLeaf(YType.boolean, "adjacency-valid")

                                self.attachment_circuit_id = YLeaf(YType.uint32, "attachment-circuit-id")

                                self.attachment_circuit_mtu = YLeaf(YType.uint16, "attachment-circuit-mtu")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.fxc_next_hop_valid = YLeaf(YType.boolean, "fxc-next-hop-valid")

                                self.inter_working_mode = YLeaf(YType.uint8, "inter-working-mode")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.ip_inter_working_mac = YLeaf(YType.str, "ip-inter-working-mac")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.sub_interface_handle = YLeaf(YType.str, "sub-interface-handle")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._children_yang_names.add("fxc-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actype",
                                                "adjacency_address",
                                                "adjacency_valid",
                                                "attachment_circuit_id",
                                                "attachment_circuit_mtu",
                                                "bound",
                                                "evpn_internal_label",
                                                "fxc_next_hop_valid",
                                                "inter_working_mode",
                                                "interface_handle",
                                                "ip_inter_working_mac",
                                                "redundancy_group_id",
                                                "redundancy_object_id",
                                                "sub_interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fxc-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.actype.is_set or
                                    self.adjacency_address.is_set or
                                    self.adjacency_valid.is_set or
                                    self.attachment_circuit_id.is_set or
                                    self.attachment_circuit_mtu.is_set or
                                    self.bound.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.fxc_next_hop_valid.is_set or
                                    self.inter_working_mode.is_set or
                                    self.interface_handle.is_set or
                                    self.ip_inter_working_mac.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.sub_interface_handle.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actype.yfilter != YFilter.not_set or
                                    self.adjacency_address.yfilter != YFilter.not_set or
                                    self.adjacency_valid.yfilter != YFilter.not_set or
                                    self.attachment_circuit_id.yfilter != YFilter.not_set or
                                    self.attachment_circuit_mtu.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.fxc_next_hop_valid.yfilter != YFilter.not_set or
                                    self.inter_working_mode.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.ip_inter_working_mac.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.sub_interface_handle.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.fxc_next_hop is not None and self.fxc_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actype.is_set or self.actype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actype.get_name_leafdata())
                                if (self.adjacency_address.is_set or self.adjacency_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_address.get_name_leafdata())
                                if (self.adjacency_valid.is_set or self.adjacency_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_valid.get_name_leafdata())
                                if (self.attachment_circuit_id.is_set or self.attachment_circuit_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_id.get_name_leafdata())
                                if (self.attachment_circuit_mtu.is_set or self.attachment_circuit_mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attachment_circuit_mtu.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.fxc_next_hop_valid.is_set or self.fxc_next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fxc_next_hop_valid.get_name_leafdata())
                                if (self.inter_working_mode.is_set or self.inter_working_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_working_mode.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.ip_inter_working_mac.is_set or self.ip_inter_working_mac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_inter_working_mac.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.sub_interface_handle.is_set or self.sub_interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "fxc-next-hop"):
                                    if (self.fxc_next_hop is None):
                                        self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop()
                                        self.fxc_next_hop.parent = self
                                        self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                    return self.fxc_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "fxc-next-hop" or name == "actype" or name == "adjacency-address" or name == "adjacency-valid" or name == "attachment-circuit-id" or name == "attachment-circuit-mtu" or name == "bound" or name == "evpn-internal-label" or name == "fxc-next-hop-valid" or name == "inter-working-mode" or name == "interface-handle" or name == "ip-inter-working-mac" or name == "redundancy-group-id" or name == "redundancy-object-id" or name == "sub-interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actype"):
                                    self.actype = value
                                    self.actype.value_namespace = name_space
                                    self.actype.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-address"):
                                    self.adjacency_address = value
                                    self.adjacency_address.value_namespace = name_space
                                    self.adjacency_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-valid"):
                                    self.adjacency_valid = value
                                    self.adjacency_valid.value_namespace = name_space
                                    self.adjacency_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-id"):
                                    self.attachment_circuit_id = value
                                    self.attachment_circuit_id.value_namespace = name_space
                                    self.attachment_circuit_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "attachment-circuit-mtu"):
                                    self.attachment_circuit_mtu = value
                                    self.attachment_circuit_mtu.value_namespace = name_space
                                    self.attachment_circuit_mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "fxc-next-hop-valid"):
                                    self.fxc_next_hop_valid = value
                                    self.fxc_next_hop_valid.value_namespace = name_space
                                    self.fxc_next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-working-mode"):
                                    self.inter_working_mode = value
                                    self.inter_working_mode.value_namespace = name_space
                                    self.inter_working_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "ip-inter-working-mac"):
                                    self.ip_inter_working_mac = value
                                    self.ip_inter_working_mac.value_namespace = name_space
                                    self.ip_inter_working_mac.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-interface-handle"):
                                    self.sub_interface_handle = value
                                    self.sub_interface_handle.value_namespace = name_space
                                    self.sub_interface_handle.value_namespace_prefix = name_space_prefix


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:   :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.core_pbb_evpn_enabled = YLeaf(YType.boolean, "core-pbb-evpn-enabled")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion()
                                self.pbb_union.parent = self
                                self._children_name_map["pbb_union"] = "pbb-union"
                                self._children_yang_names.add("pbb-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "core_pbb_evpn_enabled",
                                                "forward_class") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pbb"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class PbbUnion(Entity):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:   :py:class:`MgmtL2FibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridge>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion, self).__init__()

                                    self.yang_name = "pbb-union"
                                    self.yang_parent_name = "pbb"

                                    self.pbb_type = YLeaf(YType.enumeration, "pbb-type")

                                    self.core = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                    self._children_yang_names.add("core")

                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"
                                    self._children_yang_names.add("edge")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pbb_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion, self).__setattr__(name, value)


                                class Edge(Entity):
                                    """
                                    edge
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Edge, self).__init__()

                                        self.yang_name = "edge"
                                        self.yang_parent_name = "pbb-union"

                                        self.mac = YLeaf(YType.str, "mac")

                                        self.mac_configured = YLeaf(YType.boolean, "mac-configured")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mac",
                                                        "mac_configured") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Edge, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Edge, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.mac.is_set or
                                            self.mac_configured.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mac.yfilter != YFilter.not_set or
                                            self.mac_configured.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "edge" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mac.is_set or self.mac.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac.get_name_leafdata())
                                        if (self.mac_configured.is_set or self.mac_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_configured.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "mac" or name == "mac-configured"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mac"):
                                            self.mac = value
                                            self.mac.value_namespace = name_space
                                            self.mac.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-configured"):
                                            self.mac_configured = value
                                            self.mac_configured.value_namespace = name_space
                                            self.mac_configured.value_namespace_prefix = name_space_prefix


                                class Core(Entity):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Core, self).__init__()

                                        self.yang_name = "core"
                                        self.yang_parent_name = "pbb-union"

                                        self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vlan_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Core, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Core, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.vlan_id.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vlan_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "core" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vlan-id"):
                                            self.vlan_id = value
                                            self.vlan_id.value_namespace = name_space
                                            self.vlan_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.pbb_type.is_set or
                                        (self.core is not None and self.core.has_data()) or
                                        (self.edge is not None and self.edge.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pbb_type.yfilter != YFilter.not_set or
                                        (self.core is not None and self.core.has_operation()) or
                                        (self.edge is not None and self.edge.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pbb-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pbb_type.is_set or self.pbb_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pbb_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "core"):
                                        if (self.core is None):
                                            self.core = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Core()
                                            self.core.parent = self
                                            self._children_name_map["core"] = "core"
                                        return self.core

                                    if (child_yang_name == "edge"):
                                        if (self.edge is None):
                                            self.edge = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Edge()
                                            self.edge.parent = self
                                            self._children_name_map["edge"] = "edge"
                                        return self.edge

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "core" or name == "edge" or name == "pbb-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pbb-type"):
                                        self.pbb_type = value
                                        self.pbb_type.value_namespace = name_space
                                        self.pbb_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.core_pbb_evpn_enabled.is_set or
                                    self.forward_class.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.pbb_union is not None and self.pbb_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.core_pbb_evpn_enabled.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.pbb_union is not None and self.pbb_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.core_pbb_evpn_enabled.is_set or self.core_pbb_evpn_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_pbb_evpn_enabled.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "pbb-union"):
                                    if (self.pbb_union is None):
                                        self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion()
                                        self.pbb_union.parent = self
                                        self._children_name_map["pbb_union"] = "pbb-union"
                                    return self.pbb_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "pbb-union" or name == "bound" or name == "core-pbb-evpn-enabled" or name == "forward-class"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "core-pbb-evpn-enabled"):
                                    self.core_pbb_evpn_enabled = value
                                    self.core_pbb_evpn_enabled.value_namespace = name_space
                                    self.core_pbb_evpn_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment"

                                self.any_cast_ip = YLeaf(YType.str, "any-cast-ip")

                                self.anycast_mcast_ip = YLeaf(YType.str, "anycast-mcast-ip")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.encap = YLeaf(YType.uint32, "encap")

                                self.mcastip = YLeaf(YType.str, "mcastip")

                                self.parent_if = YLeaf(YType.str, "parent-if")

                                self.source_vtep_if = YLeaf(YType.str, "source-vtep-if")

                                self.srcip = YLeaf(YType.str, "srcip")

                                self.udp_port = YLeaf(YType.uint32, "udp-port")

                                self.vx_lan_mode = YLeaf(YType.uint32, "vx-lan-mode")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("any_cast_ip",
                                                "anycast_mcast_ip",
                                                "bound",
                                                "encap",
                                                "mcastip",
                                                "parent_if",
                                                "source_vtep_if",
                                                "srcip",
                                                "udp_port",
                                                "vx_lan_mode") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "vni"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.any_cast_ip.is_set or
                                    self.anycast_mcast_ip.is_set or
                                    self.bound.is_set or
                                    self.encap.is_set or
                                    self.mcastip.is_set or
                                    self.parent_if.is_set or
                                    self.source_vtep_if.is_set or
                                    self.srcip.is_set or
                                    self.udp_port.is_set or
                                    self.vx_lan_mode.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.any_cast_ip.yfilter != YFilter.not_set or
                                    self.anycast_mcast_ip.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.encap.yfilter != YFilter.not_set or
                                    self.mcastip.yfilter != YFilter.not_set or
                                    self.parent_if.yfilter != YFilter.not_set or
                                    self.source_vtep_if.yfilter != YFilter.not_set or
                                    self.srcip.yfilter != YFilter.not_set or
                                    self.udp_port.yfilter != YFilter.not_set or
                                    self.vx_lan_mode.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vni" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.any_cast_ip.is_set or self.any_cast_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.any_cast_ip.get_name_leafdata())
                                if (self.anycast_mcast_ip.is_set or self.anycast_mcast_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.anycast_mcast_ip.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.encap.is_set or self.encap.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encap.get_name_leafdata())
                                if (self.mcastip.is_set or self.mcastip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mcastip.get_name_leafdata())
                                if (self.parent_if.is_set or self.parent_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_if.get_name_leafdata())
                                if (self.source_vtep_if.is_set or self.source_vtep_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_vtep_if.get_name_leafdata())
                                if (self.srcip.is_set or self.srcip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.srcip.get_name_leafdata())
                                if (self.udp_port.is_set or self.udp_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.udp_port.get_name_leafdata())
                                if (self.vx_lan_mode.is_set or self.vx_lan_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vx_lan_mode.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "any-cast-ip" or name == "anycast-mcast-ip" or name == "bound" or name == "encap" or name == "mcastip" or name == "parent-if" or name == "source-vtep-if" or name == "srcip" or name == "udp-port" or name == "vx-lan-mode"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "any-cast-ip"):
                                    self.any_cast_ip = value
                                    self.any_cast_ip.value_namespace = name_space
                                    self.any_cast_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "anycast-mcast-ip"):
                                    self.anycast_mcast_ip = value
                                    self.anycast_mcast_ip.value_namespace = name_space
                                    self.anycast_mcast_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "encap"):
                                    self.encap = value
                                    self.encap.value_namespace = name_space
                                    self.encap.value_namespace_prefix = name_space_prefix
                                if(value_path == "mcastip"):
                                    self.mcastip = value
                                    self.mcastip.value_namespace = name_space
                                    self.mcastip.value_namespace_prefix = name_space_prefix
                                if(value_path == "parent-if"):
                                    self.parent_if = value
                                    self.parent_if.value_namespace = name_space
                                    self.parent_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-vtep-if"):
                                    self.source_vtep_if = value
                                    self.source_vtep_if.value_namespace = name_space
                                    self.source_vtep_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "srcip"):
                                    self.srcip = value
                                    self.srcip.value_namespace = name_space
                                    self.srcip.value_namespace_prefix = name_space_prefix
                                if(value_path == "udp-port"):
                                    self.udp_port = value
                                    self.udp_port.value_namespace = name_space
                                    self.udp_port.value_namespace_prefix = name_space_prefix
                                if(value_path == "vx-lan-mode"):
                                    self.vx_lan_mode = value
                                    self.vx_lan_mode.value_namespace = name_space
                                    self.vx_lan_mode.value_namespace_prefix = name_space_prefix


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment"

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.evi = YLeaf(YType.uint32, "evi")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bound",
                                                "evi",
                                                "forward_class") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "evpn"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.bound.is_set or
                                    self.evi.is_set or
                                    self.forward_class.is_set or
                                    (self.base is not None and self.base.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.evi.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evi.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "bound" or name == "evi" or name == "forward-class"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "evi"):
                                    self.evi = value
                                    self.evi.value_namespace = name_space
                                    self.evi.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBal>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment"

                                self.ac_id = YLeaf(YType.uint32, "ac-id")

                                self.active = YLeaf(YType.boolean, "active")

                                self.backup_configured = YLeaf(YType.boolean, "backup-configured")

                                self.bound = YLeaf(YType.boolean, "bound")

                                self.context = YLeaf(YType.uint16, "context")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.global_id = YLeaf(YType.uint32, "global-id")

                                self.group_id = YLeaf(YType.uint32, "group-id")

                                self.group_state = YLeaf(YType.enumeration, "group-state")

                                self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                                self.pw_load_balance_type = YLeaf(YType.enumeration, "pw-load-balance-type")

                                self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                self.sequence_resync_threshold = YLeaf(YType.uint16, "sequence-resync-threshold")

                                self.signal_capability_flags = YLeaf(YType.uint32, "signal-capability-flags")

                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._children_yang_names.add("backup-pseudo-wire")

                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                self._children_yang_names.add("pseudo-wire-union")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ac_id",
                                                "active",
                                                "backup_configured",
                                                "bound",
                                                "context",
                                                "forward_class",
                                                "global_id",
                                                "group_id",
                                                "group_state",
                                                "grouping_supported",
                                                "next_hop_valid",
                                                "pseudo_wire_id_type",
                                                "pw_flow_label_tx",
                                                "pw_id",
                                                "pw_load_balance_type",
                                                "redundancy_role",
                                                "sequence_resync_threshold",
                                                "signal_capability_flags") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"

                                def has_data(self):
                                    return False

                                def has_operation(self):
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"
                                    self._children_yang_names.add("l2tp")

                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._children_yang_names.add("l2tp-ipv6-ts")

                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"
                                    self._children_yang_names.add("l2tpv2")

                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"
                                    self._children_yang_names.add("mpls")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion, self).__setattr__(name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.Mpls, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mpls" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix


                                class L2Tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_mtu",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_mtu.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "path-mtu" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix


                                class L2Tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.protocol = YLeaf(YType.uint16, "protocol")

                                        self.pw_flags = YLeaf(YType.uint8, "pw-flags")

                                        self.rem_udp_port = YLeaf(YType.uint16, "rem-udp-port")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop_address",
                                                        "path_mtu",
                                                        "protocol",
                                                        "pw_flags",
                                                        "rem_udp_port",
                                                        "source_address",
                                                        "tos_val",
                                                        "ttl",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("session_id",
                                                            "tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.session_id.is_set or
                                                self.tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set or
                                                self.tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())
                                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "session-id" or name == "tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-id"):
                                                self.tunnel_id = value
                                                self.tunnel_id.value_namespace = name_space
                                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.next_hop_address.is_set or
                                            self.path_mtu.is_set or
                                            self.protocol.is_set or
                                            self.pw_flags.is_set or
                                            self.rem_udp_port.is_set or
                                            self.source_address.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            self.xconnect_id.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pw_flags.yfilter != YFilter.not_set or
                                            self.rem_udp_port.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv2" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pw_flags.is_set or self.pw_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flags.get_name_leafdata())
                                        if (self.rem_udp_port.is_set or self.rem_udp_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_udp_port.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "next-hop-address" or name == "path-mtu" or name == "protocol" or name == "pw-flags" or name == "rem-udp-port" or name == "source-address" or name == "tos-val" or name == "ttl" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop-address"):
                                            self.next_hop_address = value
                                            self.next_hop_address.value_namespace = name_space
                                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flags"):
                                            self.pw_flags = value
                                            self.pw_flags.value_namespace = name_space
                                            self.pw_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-udp-port"):
                                            self.rem_udp_port = value
                                            self.rem_udp_port.value_namespace = name_space
                                            self.rem_udp_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class L2TpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.path_mtu = YLeaf(YType.uint16, "path-mtu")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        self.tos_val = YLeaf(YType.uint8, "tos-val")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.local = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                        self._children_yang_names.add("local")

                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._children_yang_names.add("remote")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_address",
                                                        "path_mtu",
                                                        "remote_address",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent",
                                                        "tos_val",
                                                        "ttl") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts, self).__setattr__(name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.secondary_cookie_high_value = YLeaf(YType.uint32, "secondary-cookie-high-value")

                                            self.secondary_cookie_low_value = YLeaf(YType.uint32, "secondary-cookie-low-value")

                                            self.secondary_cookie_size = YLeaf(YType.uint8, "secondary-cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "secondary_cookie_high_value",
                                                            "secondary_cookie_low_value",
                                                            "secondary_cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Local, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.secondary_cookie_high_value.is_set or
                                                self.secondary_cookie_low_value.is_set or
                                                self.secondary_cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.secondary_cookie_high_value.is_set or self.secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_high_value.get_name_leafdata())
                                            if (self.secondary_cookie_low_value.is_set or self.secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_low_value.get_name_leafdata())
                                            if (self.secondary_cookie_size.is_set or self.secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.secondary_cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "secondary-cookie-high-value" or name == "secondary-cookie-low-value" or name == "secondary-cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-high-value"):
                                                self.secondary_cookie_high_value = value
                                                self.secondary_cookie_high_value.value_namespace = name_space
                                                self.secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-low-value"):
                                                self.secondary_cookie_low_value = value
                                                self.secondary_cookie_low_value.value_namespace = name_space
                                                self.secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "secondary-cookie-size"):
                                                self.secondary_cookie_size = value
                                                self.secondary_cookie_size.value_namespace = name_space
                                                self.secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"

                                            self.cookie_high_value = YLeaf(YType.uint32, "cookie-high-value")

                                            self.cookie_low_value = YLeaf(YType.uint32, "cookie-low-value")

                                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                            self.session_id = YLeaf(YType.uint32, "session-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cookie_high_value",
                                                            "cookie_low_value",
                                                            "cookie_size",
                                                            "session_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cookie_high_value.is_set or
                                                self.cookie_low_value.is_set or
                                                self.cookie_size.is_set or
                                                self.session_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cookie_high_value.yfilter != YFilter.not_set or
                                                self.cookie_low_value.yfilter != YFilter.not_set or
                                                self.cookie_size.yfilter != YFilter.not_set or
                                                self.session_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cookie_high_value.is_set or self.cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_high_value.get_name_leafdata())
                                            if (self.cookie_low_value.is_set or self.cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_low_value.get_name_leafdata())
                                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                            if (self.session_id.is_set or self.session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.session_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cookie-high-value" or name == "cookie-low-value" or name == "cookie-size" or name == "session-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cookie-high-value"):
                                                self.cookie_high_value = value
                                                self.cookie_high_value.value_namespace = name_space
                                                self.cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-low-value"):
                                                self.cookie_low_value = value
                                                self.cookie_low_value.value_namespace = name_space
                                                self.cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cookie-size"):
                                                self.cookie_size = value
                                                self.cookie_size.value_namespace = name_space
                                                self.cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "session-id"):
                                                self.session_id = value
                                                self.session_id.value_namespace = name_space
                                                self.session_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.local_address.is_set or
                                            self.path_mtu.is_set or
                                            self.remote_address.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set or
                                            self.tos_val.is_set or
                                            self.ttl.is_set or
                                            (self.local is not None and self.local.has_data()) or
                                            (self.remote is not None and self.remote.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.path_mtu.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set or
                                            self.tos_val.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            (self.local is not None and self.local.has_operation()) or
                                            (self.remote is not None and self.remote.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tp-ipv6-ts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.path_mtu.is_set or self.path_mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())
                                        if (self.tos_val.is_set or self.tos_val.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_val.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local"):
                                            if (self.local is None):
                                                self.local = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                                self.local.parent = self
                                                self._children_name_map["local"] = "local"
                                            return self.local

                                        if (child_yang_name == "remote"):
                                            if (self.remote is None):
                                                self.remote = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                                self.remote.parent = self
                                                self._children_name_map["remote"] = "remote"
                                            return self.remote

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local" or name == "remote" or name == "local-address" or name == "path-mtu" or name == "remote-address" or name == "sequence-number-expected" or name == "sequence-number-sent" or name == "tos-val" or name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu"):
                                            self.path_mtu = value
                                            self.path_mtu.value_namespace = name_space
                                            self.path_mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-val"):
                                            self.tos_val = value
                                            self.tos_val.value_namespace = name_space
                                            self.tos_val.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        (self.l2tp is not None and self.l2tp.has_data()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_data()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_data()) or
                                        (self.mpls is not None and self.mpls.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        (self.l2tp is not None and self.l2tp.has_operation()) or
                                        (self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts.has_operation()) or
                                        (self.l2tpv2 is not None and self.l2tpv2.has_operation()) or
                                        (self.mpls is not None and self.mpls.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudo-wire-union" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "l2tp"):
                                        if (self.l2tp is None):
                                            self.l2tp = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp()
                                            self.l2tp.parent = self
                                            self._children_name_map["l2tp"] = "l2tp"
                                        return self.l2tp

                                    if (child_yang_name == "l2tp-ipv6-ts"):
                                        if (self.l2tp_ipv6_ts is None):
                                            self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                            self.l2tp_ipv6_ts.parent = self
                                            self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                        return self.l2tp_ipv6_ts

                                    if (child_yang_name == "l2tpv2"):
                                        if (self.l2tpv2 is None):
                                            self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2()
                                            self.l2tpv2.parent = self
                                            self._children_name_map["l2tpv2"] = "l2tpv2"
                                        return self.l2tpv2

                                    if (child_yang_name == "mpls"):
                                        if (self.mpls is None):
                                            self.mpls = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                        return self.mpls

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "l2tp" or name == "l2tp-ipv6-ts" or name == "l2tpv2" or name == "mpls" or name == "data-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupState>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRole>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.backup_next_hop = YLeaf(YType.str, "backup-next-hop")

                                    self.backup_pseudo_wire_id = YLeaf(YType.uint32, "backup-pseudo-wire-id")

                                    self.backup_pseudo_wire_id_type = YLeaf(YType.enumeration, "backup-pseudo-wire-id-type")

                                    self.bound = YLeaf(YType.boolean, "bound")

                                    self.group_id = YLeaf(YType.uint32, "group-id")

                                    self.group_state = YLeaf(YType.enumeration, "group-state")

                                    self.grouping_supported = YLeaf(YType.boolean, "grouping-supported")

                                    self.pw_flow_label_tx = YLeaf(YType.boolean, "pw-flow-label-tx")

                                    self.redundancy_role = YLeaf(YType.enumeration, "redundancy-role")

                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "backup_next_hop",
                                                    "backup_pseudo_wire_id",
                                                    "backup_pseudo_wire_id_type",
                                                    "bound",
                                                    "group_id",
                                                    "group_state",
                                                    "grouping_supported",
                                                    "pw_flow_label_tx",
                                                    "redundancy_role") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"

                                        self.pw_label = YLeaf(YType.uint32, "pw-label")

                                        self.pw_local_label = YLeaf(YType.uint32, "pw-local-label")

                                        self.pw_tunnel_interface = YLeaf(YType.uint32, "pw-tunnel-interface")

                                        self.pw_xcid = YLeaf(YType.uint32, "pw-xcid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_label",
                                                        "pw_local_label",
                                                        "pw_tunnel_interface",
                                                        "pw_xcid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire.Atom, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pw_label.is_set or
                                            self.pw_local_label.is_set or
                                            self.pw_tunnel_interface.is_set or
                                            self.pw_xcid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_label.yfilter != YFilter.not_set or
                                            self.pw_local_label.yfilter != YFilter.not_set or
                                            self.pw_tunnel_interface.yfilter != YFilter.not_set or
                                            self.pw_xcid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_label.is_set or self.pw_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_label.get_name_leafdata())
                                        if (self.pw_local_label.is_set or self.pw_local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_local_label.get_name_leafdata())
                                        if (self.pw_tunnel_interface.is_set or self.pw_tunnel_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_tunnel_interface.get_name_leafdata())
                                        if (self.pw_xcid.is_set or self.pw_xcid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_xcid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pw-label" or name == "pw-local-label" or name == "pw-tunnel-interface" or name == "pw-xcid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-label"):
                                            self.pw_label = value
                                            self.pw_label.value_namespace = name_space
                                            self.pw_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-local-label"):
                                            self.pw_local_label = value
                                            self.pw_local_label.value_namespace = name_space
                                            self.pw_local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-tunnel-interface"):
                                            self.pw_tunnel_interface = value
                                            self.pw_tunnel_interface.value_namespace = name_space
                                            self.pw_tunnel_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-xcid"):
                                            self.pw_xcid = value
                                            self.pw_xcid.value_namespace = name_space
                                            self.pw_xcid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.backup_next_hop.is_set or
                                        self.backup_pseudo_wire_id.is_set or
                                        self.backup_pseudo_wire_id_type.is_set or
                                        self.bound.is_set or
                                        self.group_id.is_set or
                                        self.group_state.is_set or
                                        self.grouping_supported.is_set or
                                        self.pw_flow_label_tx.is_set or
                                        self.redundancy_role.is_set or
                                        (self.atom is not None and self.atom.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.backup_next_hop.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set or
                                        self.bound.yfilter != YFilter.not_set or
                                        self.group_id.yfilter != YFilter.not_set or
                                        self.group_state.yfilter != YFilter.not_set or
                                        self.grouping_supported.yfilter != YFilter.not_set or
                                        self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                        self.redundancy_role.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "backup-pseudo-wire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.backup_next_hop.is_set or self.backup_next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_next_hop.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id.is_set or self.backup_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id.get_name_leafdata())
                                    if (self.backup_pseudo_wire_id_type.is_set or self.backup_pseudo_wire_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pseudo_wire_id_type.get_name_leafdata())
                                    if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bound.get_name_leafdata())
                                    if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_id.get_name_leafdata())
                                    if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_state.get_name_leafdata())
                                    if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                    if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                    if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_role.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "active" or name == "backup-next-hop" or name == "backup-pseudo-wire-id" or name == "backup-pseudo-wire-id-type" or name == "bound" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "pw-flow-label-tx" or name == "redundancy-role"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-next-hop"):
                                        self.backup_next_hop = value
                                        self.backup_next_hop.value_namespace = name_space
                                        self.backup_next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id"):
                                        self.backup_pseudo_wire_id = value
                                        self.backup_pseudo_wire_id.value_namespace = name_space
                                        self.backup_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pseudo-wire-id-type"):
                                        self.backup_pseudo_wire_id_type = value
                                        self.backup_pseudo_wire_id_type.value_namespace = name_space
                                        self.backup_pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bound"):
                                        self.bound = value
                                        self.bound.value_namespace = name_space
                                        self.bound.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-id"):
                                        self.group_id = value
                                        self.group_id.value_namespace = name_space
                                        self.group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "group-state"):
                                        self.group_state = value
                                        self.group_state.value_namespace = name_space
                                        self.group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "grouping-supported"):
                                        self.grouping_supported = value
                                        self.grouping_supported.value_namespace = name_space
                                        self.grouping_supported.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-tx"):
                                        self.pw_flow_label_tx = value
                                        self.pw_flow_label_tx.value_namespace = name_space
                                        self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-role"):
                                        self.redundancy_role = value
                                        self.redundancy_role.value_namespace = name_space
                                        self.redundancy_role.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ac_id.is_set or
                                    self.active.is_set or
                                    self.backup_configured.is_set or
                                    self.bound.is_set or
                                    self.context.is_set or
                                    self.forward_class.is_set or
                                    self.global_id.is_set or
                                    self.group_id.is_set or
                                    self.group_state.is_set or
                                    self.grouping_supported.is_set or
                                    self.next_hop_valid.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_flow_label_tx.is_set or
                                    self.pw_id.is_set or
                                    self.pw_load_balance_type.is_set or
                                    self.redundancy_role.is_set or
                                    self.sequence_resync_threshold.is_set or
                                    self.signal_capability_flags.is_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_data()) or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ac_id.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.backup_configured.yfilter != YFilter.not_set or
                                    self.bound.yfilter != YFilter.not_set or
                                    self.context.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.global_id.yfilter != YFilter.not_set or
                                    self.group_id.yfilter != YFilter.not_set or
                                    self.group_state.yfilter != YFilter.not_set or
                                    self.grouping_supported.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_tx.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.pw_load_balance_type.yfilter != YFilter.not_set or
                                    self.redundancy_role.yfilter != YFilter.not_set or
                                    self.sequence_resync_threshold.yfilter != YFilter.not_set or
                                    self.signal_capability_flags.yfilter != YFilter.not_set or
                                    (self.backup_pseudo_wire is not None and self.backup_pseudo_wire.has_operation()) or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()) or
                                    (self.pseudo_wire_union is not None and self.pseudo_wire_union.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ac_id.is_set or self.ac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac_id.get_name_leafdata())
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.backup_configured.is_set or self.backup_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_configured.get_name_leafdata())
                                if (self.bound.is_set or self.bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bound.get_name_leafdata())
                                if (self.context.is_set or self.context.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.context.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.global_id.is_set or self.global_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_id.get_name_leafdata())
                                if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_id.get_name_leafdata())
                                if (self.group_state.is_set or self.group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_state.get_name_leafdata())
                                if (self.grouping_supported.is_set or self.grouping_supported.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.grouping_supported.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_flow_label_tx.is_set or self.pw_flow_label_tx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_tx.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.pw_load_balance_type.is_set or self.pw_load_balance_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_load_balance_type.get_name_leafdata())
                                if (self.redundancy_role.is_set or self.redundancy_role.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_role.get_name_leafdata())
                                if (self.sequence_resync_threshold.is_set or self.sequence_resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_resync_threshold.get_name_leafdata())
                                if (self.signal_capability_flags.is_set or self.signal_capability_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signal_capability_flags.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "backup-pseudo-wire"):
                                    if (self.backup_pseudo_wire is None):
                                        self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire()
                                        self.backup_pseudo_wire.parent = self
                                        self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                    return self.backup_pseudo_wire

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                if (child_yang_name == "pseudo-wire-union"):
                                    if (self.pseudo_wire_union is None):
                                        self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion()
                                        self.pseudo_wire_union.parent = self
                                        self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"
                                    return self.pseudo_wire_union

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backup-pseudo-wire" or name == "base" or name == "next-hop" or name == "pseudo-wire-union" or name == "ac-id" or name == "active" or name == "backup-configured" or name == "bound" or name == "context" or name == "forward-class" or name == "global-id" or name == "group-id" or name == "group-state" or name == "grouping-supported" or name == "next-hop-valid" or name == "pseudo-wire-id-type" or name == "pw-flow-label-tx" or name == "pw-id" or name == "pw-load-balance-type" or name == "redundancy-role" or name == "sequence-resync-threshold" or name == "signal-capability-flags"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ac-id"):
                                    self.ac_id = value
                                    self.ac_id.value_namespace = name_space
                                    self.ac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-configured"):
                                    self.backup_configured = value
                                    self.backup_configured.value_namespace = name_space
                                    self.backup_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "bound"):
                                    self.bound = value
                                    self.bound.value_namespace = name_space
                                    self.bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "context"):
                                    self.context = value
                                    self.context.value_namespace = name_space
                                    self.context.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "global-id"):
                                    self.global_id = value
                                    self.global_id.value_namespace = name_space
                                    self.global_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-id"):
                                    self.group_id = value
                                    self.group_id.value_namespace = name_space
                                    self.group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-state"):
                                    self.group_state = value
                                    self.group_state.value_namespace = name_space
                                    self.group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "grouping-supported"):
                                    self.grouping_supported = value
                                    self.grouping_supported.value_namespace = name_space
                                    self.grouping_supported.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-tx"):
                                    self.pw_flow_label_tx = value
                                    self.pw_flow_label_tx.value_namespace = name_space
                                    self.pw_flow_label_tx.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-load-balance-type"):
                                    self.pw_load_balance_type = value
                                    self.pw_load_balance_type.value_namespace = name_space
                                    self.pw_load_balance_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-role"):
                                    self.redundancy_role = value
                                    self.redundancy_role.value_namespace = name_space
                                    self.redundancy_role.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-resync-threshold"):
                                    self.sequence_resync_threshold = value
                                    self.sequence_resync_threshold.value_namespace = name_space
                                    self.sequence_resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "signal-capability-flags"):
                                    self.signal_capability_flags = value
                                    self.signal_capability_flags.value_namespace = name_space
                                    self.signal_capability_flags.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.evpn is not None and self.evpn.has_data()) or
                                (self.pbb is not None and self.pbb.has_data()) or
                                (self.pw is not None and self.pw.has_data()) or
                                (self.vni is not None and self.vni.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.evpn is not None and self.evpn.has_operation()) or
                                (self.pbb is not None and self.pbb.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()) or
                                (self.vni is not None and self.vni.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "evpn"):
                                if (self.evpn is None):
                                    self.evpn = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn()
                                    self.evpn.parent = self
                                    self._children_name_map["evpn"] = "evpn"
                                return self.evpn

                            if (child_yang_name == "pbb"):
                                if (self.pbb is None):
                                    self.pbb = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb()
                                    self.pbb.parent = self
                                    self._children_name_map["pbb"] = "pbb"
                                return self.pbb

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            if (child_yang_name == "vni"):
                                if (self.vni is None):
                                    self.vni = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni()
                                    self.vni.parent = self
                                    self._children_name_map["vni"] = "vni"
                                return self.vni

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "evpn" or name == "pbb" or name == "pw" or name == "vni" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix


                    class BridgePortOperationalInfo(Entity):
                        """
                        Bridge port operational information
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: operational_information
                        
                        	L2 operational information
                        	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo, self).__init__()

                            self.yang_name = "bridge-port-operational-info"
                            self.yang_parent_name = "l2fib-bridge-port"

                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                            self.operational_information = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation()
                            self.operational_information.parent = self
                            self._children_name_map["operational_information"] = "operational-information"
                            self._children_yang_names.add("operational-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("broadcast_storm_control_kb_ps",
                                            "broadcast_storm_control_pps",
                                            "multicast_storm_control_kb_ps",
                                            "multicast_storm_control_pps",
                                            "unicast_storm_control_kb_ps",
                                            "unicast_storm_control_pps") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo, self).__setattr__(name, value)


                        class OperationalInformation(Entity):
                            """
                            L2 operational information
                            
                            .. attribute:: admin_disabled
                            
                            	Is administratively disabled
                            	**type**\:  bool
                            
                            .. attribute:: bvi_configured
                            
                            	Is BVI Interface configured
                            	**type**\:  bool
                            
                            .. attribute:: dhcp_enabled
                            
                            	Is DHCP snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: dhcp_trusted
                            
                            	Is DHCP trusted
                            	**type**\:  bool
                            
                            .. attribute:: feature
                            
                            	Feature information
                            	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature>`
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Is flooding unknown unicast disabled
                            	**type**\:  bool
                            
                            .. attribute:: flooding_disabled
                            
                            	Is flooding disabled
                            	**type**\:  bool
                            
                            .. attribute:: host_routing_enabled
                            
                            	Host Routing enabled on this BD
                            	**type**\:  bool
                            
                            .. attribute:: igmp_flood_forward_enabled
                            
                            	Is IGMP flood forwarding enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\:  bool
                            
                            .. attribute:: igmp_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_snoop_enabled
                            
                            	Is IGMP snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_snoop_profile_enabled
                            
                            	Is IGMP snooping profile enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_bvi_up
                            
                            	Is BVI state UP
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_destination_mac_enabled
                            
                            	Is DAI Destination MAC Validation enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_ipv4_enabled
                            
                            	Is DAI IPv4 Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_cw_disable
                            
                            	Is EVPN CW disabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_enabled
                            
                            	Is EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_flow_label
                            
                            	Is EVPN Flow Label enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_igmp_snoop_enabled
                            
                            	Is IGMP Snooping admin enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown
                            
                            	Is MAC secure accept shutdown (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_p2mp_pw_enabled
                            
                            	Is P2MP PW enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_pbbevpn_enabled
                            
                            	Is PBBEVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_swmac_learning
                            
                            	Is SW MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_vni_enabled
                            
                            	Is VNI enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_vpls_flood_optimization_enabled
                            
                            	Is MMRP  Flood Optimization Enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in minutes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: minute
                            
                            .. attribute:: mac_aging_type
                            
                            	MAC aging type
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning_disabled
                            
                            	Is MAC learning disabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`MgmtL2FibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitAction>`
                            
                            .. attribute:: mac_limit_notification_type
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`MgmtL2FibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotify>`
                            
                            .. attribute:: mac_port_down_flush_disabled
                            
                            	Is MAC port down flush disabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC secure action
                            	**type**\:   :py:class:`MgmtL2FibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecAction>`
                            
                            .. attribute:: mld_flood_forward_enabled
                            
                            	Is MLD flood forwarding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\:  bool
                            
                            .. attribute:: mld_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_snoop_enabled
                            
                            	Is MLD snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_snoop_profile_enabled
                            
                            	Is MLD snooping profile enabled
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	Multi\-spanning tree instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_macs
                            
                            	numberOfMacs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                            
                            	nV Satellite Offload IPv4 Multicast Disabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_broadcast_enabled
                            
                            	Is broadcast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_broadcast_rate_unit
                            
                            	Storm control broadcast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                            
                            .. attribute:: storm_control_multicast_enabled
                            
                            	Is multicast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_multicast_rate_unit
                            
                            	Storm control multicast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                            
                            .. attribute:: storm_control_unicast_enabled
                            
                            	Is unicast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_unicast_rate_unit
                            
                            	Storm control unicast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnit>`
                            
                            .. attribute:: stp_participating
                            
                            	Is Spanning Tree Protocol participating
                            	**type**\:  bool
                            
                            .. attribute:: unknown_unicast_flooding_disabled
                            
                            	Unknown Unicast Flooding is disabled
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation, self).__init__()

                                self.yang_name = "operational-information"
                                self.yang_parent_name = "bridge-port-operational-info"

                                self.admin_disabled = YLeaf(YType.boolean, "admin-disabled")

                                self.bvi_configured = YLeaf(YType.boolean, "bvi-configured")

                                self.dhcp_enabled = YLeaf(YType.boolean, "dhcp-enabled")

                                self.dhcp_trusted = YLeaf(YType.boolean, "dhcp-trusted")

                                self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                self.flooding_disabled = YLeaf(YType.boolean, "flooding-disabled")

                                self.host_routing_enabled = YLeaf(YType.boolean, "host-routing-enabled")

                                self.igmp_flood_forward_enabled = YLeaf(YType.boolean, "igmp-flood-forward-enabled")

                                self.igmp_mroute_port_enabled = YLeaf(YType.boolean, "igmp-mroute-port-enabled")

                                self.igmp_route_guard_enabled = YLeaf(YType.boolean, "igmp-route-guard-enabled")

                                self.igmp_snoop_enabled = YLeaf(YType.boolean, "igmp-snoop-enabled")

                                self.igmp_snoop_profile_enabled = YLeaf(YType.boolean, "igmp-snoop-profile-enabled")

                                self.is_bvi_up = YLeaf(YType.boolean, "is-bvi-up")

                                self.is_dai_addr_validation_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-destination-mac-enabled")

                                self.is_dai_addr_validation_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-ipv4-enabled")

                                self.is_dai_addr_validation_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validation-source-mac-enabled")

                                self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                self.is_evpn_cw_disable = YLeaf(YType.boolean, "is-evpn-cw-disable")

                                self.is_evpn_enabled = YLeaf(YType.boolean, "is-evpn-enabled")

                                self.is_evpn_flow_label = YLeaf(YType.boolean, "is-evpn-flow-label")

                                self.is_igmp_snoop_enabled = YLeaf(YType.boolean, "is-igmp-snoop-enabled")

                                self.is_ipsg_enabled = YLeaf(YType.boolean, "is-ipsg-enabled")

                                self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                self.is_mac_secure_accept_shutdown = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown")

                                self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                self.is_p2mp_pw_enabled = YLeaf(YType.boolean, "is-p2mp-pw-enabled")

                                self.is_pbbevpn_enabled = YLeaf(YType.boolean, "is-pbbevpn-enabled")

                                self.is_swmac_learning = YLeaf(YType.boolean, "is-swmac-learning")

                                self.is_vni_enabled = YLeaf(YType.boolean, "is-vni-enabled")

                                self.is_vpls_flood_optimization_enabled = YLeaf(YType.boolean, "is-vpls-flood-optimization-enabled")

                                self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                self.mac_aging_type = YLeaf(YType.boolean, "mac-aging-type")

                                self.mac_learning_disabled = YLeaf(YType.boolean, "mac-learning-disabled")

                                self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                self.mac_limit_notification_type = YLeaf(YType.enumeration, "mac-limit-notification-type")

                                self.mac_port_down_flush_disabled = YLeaf(YType.boolean, "mac-port-down-flush-disabled")

                                self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                self.mld_flood_forward_enabled = YLeaf(YType.boolean, "mld-flood-forward-enabled")

                                self.mld_mroute_port_enabled = YLeaf(YType.boolean, "mld-mroute-port-enabled")

                                self.mld_route_guard_enabled = YLeaf(YType.boolean, "mld-route-guard-enabled")

                                self.mld_snoop_enabled = YLeaf(YType.boolean, "mld-snoop-enabled")

                                self.mld_snoop_profile_enabled = YLeaf(YType.boolean, "mld-snoop-profile-enabled")

                                self.msti = YLeaf(YType.uint32, "msti")

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.number_of_macs = YLeaf(YType.uint32, "number-of-macs")

                                self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                                self.storm_control_broadcast_enabled = YLeaf(YType.boolean, "storm-control-broadcast-enabled")

                                self.storm_control_broadcast_rate_unit = YLeaf(YType.enumeration, "storm-control-broadcast-rate-unit")

                                self.storm_control_multicast_enabled = YLeaf(YType.boolean, "storm-control-multicast-enabled")

                                self.storm_control_multicast_rate_unit = YLeaf(YType.enumeration, "storm-control-multicast-rate-unit")

                                self.storm_control_unicast_enabled = YLeaf(YType.boolean, "storm-control-unicast-enabled")

                                self.storm_control_unicast_rate_unit = YLeaf(YType.enumeration, "storm-control-unicast-rate-unit")

                                self.stp_participating = YLeaf(YType.boolean, "stp-participating")

                                self.unknown_unicast_flooding_disabled = YLeaf(YType.boolean, "unknown-unicast-flooding-disabled")

                                self.feature = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("admin_disabled",
                                                "bvi_configured",
                                                "dhcp_enabled",
                                                "dhcp_trusted",
                                                "flood_unknown_unicast_enabled",
                                                "flooding_disabled",
                                                "host_routing_enabled",
                                                "igmp_flood_forward_enabled",
                                                "igmp_mroute_port_enabled",
                                                "igmp_route_guard_enabled",
                                                "igmp_snoop_enabled",
                                                "igmp_snoop_profile_enabled",
                                                "is_bvi_up",
                                                "is_dai_addr_validation_destination_mac_enabled",
                                                "is_dai_addr_validation_ipv4_enabled",
                                                "is_dai_addr_validation_source_mac_enabled",
                                                "is_dai_enabled",
                                                "is_dai_logging_enabled",
                                                "is_evpn_cw_disable",
                                                "is_evpn_enabled",
                                                "is_evpn_flow_label",
                                                "is_igmp_snoop_enabled",
                                                "is_ipsg_enabled",
                                                "is_ipsg_logging_enabled",
                                                "is_mac_secure_accept_shutdown",
                                                "is_mac_secure_enabled",
                                                "is_mac_secure_logging_enabled",
                                                "is_p2mp_pw_enabled",
                                                "is_pbbevpn_enabled",
                                                "is_swmac_learning",
                                                "is_vni_enabled",
                                                "is_vpls_flood_optimization_enabled",
                                                "mac_aging_time",
                                                "mac_aging_type",
                                                "mac_learning_disabled",
                                                "mac_limit",
                                                "mac_limit_action",
                                                "mac_limit_notification_type",
                                                "mac_port_down_flush_disabled",
                                                "mac_secure_action",
                                                "mld_flood_forward_enabled",
                                                "mld_mroute_port_enabled",
                                                "mld_route_guard_enabled",
                                                "mld_snoop_enabled",
                                                "mld_snoop_profile_enabled",
                                                "msti",
                                                "mtu",
                                                "number_of_macs",
                                                "nv_satellite_offload_ipv4_multicast_disabled",
                                                "storm_control_broadcast_enabled",
                                                "storm_control_broadcast_rate_unit",
                                                "storm_control_multicast_enabled",
                                                "storm_control_multicast_rate_unit",
                                                "storm_control_unicast_enabled",
                                                "storm_control_unicast_rate_unit",
                                                "stp_participating",
                                                "unknown_unicast_flooding_disabled") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation, self).__setattr__(name, value)


                            class Feature(Entity):
                                """
                                Feature information
                                
                                .. attribute:: dhcp
                                
                                	dhcp
                                	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp>`
                                
                                .. attribute:: feature_type
                                
                                	feature type
                                	**type**\:   :py:class:`L2FibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeature>`
                                
                                .. attribute:: igmp
                                
                                	igmp
                                	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp>`
                                
                                .. attribute:: mld
                                
                                	mld
                                	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature, self).__init__()

                                    self.yang_name = "feature"
                                    self.yang_parent_name = "operational-information"

                                    self.feature_type = YLeaf(YType.enumeration, "feature-type")

                                    self.dhcp = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp()
                                    self.dhcp.parent = self
                                    self._children_name_map["dhcp"] = "dhcp"
                                    self._children_yang_names.add("dhcp")

                                    self.igmp = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp()
                                    self.igmp.parent = self
                                    self._children_name_map["igmp"] = "igmp"
                                    self._children_yang_names.add("igmp")

                                    self.mld = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld()
                                    self.mld.parent = self
                                    self._children_name_map["mld"] = "mld"
                                    self._children_yang_names.add("mld")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("feature_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature, self).__setattr__(name, value)


                                class Dhcp(Entity):
                                    """
                                    dhcp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp, self).__init__()

                                        self.yang_name = "dhcp"
                                        self.yang_parent_name = "feature"

                                        self.profile_name = YLeaf(YType.str, "profile-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("profile_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.profile_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.profile_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dhcp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.profile_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "profile-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "profile-name"):
                                            self.profile_name = value
                                            self.profile_name.value_namespace = name_space
                                            self.profile_name.value_namespace_prefix = name_space_prefix


                                class Igmp(Entity):
                                    """
                                    igmp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp, self).__init__()

                                        self.yang_name = "igmp"
                                        self.yang_parent_name = "feature"

                                        self.profile_name = YLeaf(YType.str, "profile-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("profile_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.profile_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.profile_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "igmp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.profile_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "profile-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "profile-name"):
                                            self.profile_name = value
                                            self.profile_name.value_namespace = name_space
                                            self.profile_name.value_namespace_prefix = name_space_prefix


                                class Mld(Entity):
                                    """
                                    mld
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld, self).__init__()

                                        self.yang_name = "mld"
                                        self.yang_parent_name = "feature"

                                        self.profile_name = YLeaf(YType.str, "profile-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("profile_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.profile_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.profile_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mld" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.profile_name.is_set or self.profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.profile_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "profile-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "profile-name"):
                                            self.profile_name = value
                                            self.profile_name.value_namespace = name_space
                                            self.profile_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.feature_type.is_set or
                                        (self.dhcp is not None and self.dhcp.has_data()) or
                                        (self.igmp is not None and self.igmp.has_data()) or
                                        (self.mld is not None and self.mld.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.feature_type.yfilter != YFilter.not_set or
                                        (self.dhcp is not None and self.dhcp.has_operation()) or
                                        (self.igmp is not None and self.igmp.has_operation()) or
                                        (self.mld is not None and self.mld.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "feature" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.feature_type.is_set or self.feature_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.feature_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dhcp"):
                                        if (self.dhcp is None):
                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self._children_name_map["dhcp"] = "dhcp"
                                        return self.dhcp

                                    if (child_yang_name == "igmp"):
                                        if (self.igmp is None):
                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self._children_name_map["igmp"] = "igmp"
                                        return self.igmp

                                    if (child_yang_name == "mld"):
                                        if (self.mld is None):
                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self
                                            self._children_name_map["mld"] = "mld"
                                        return self.mld

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dhcp" or name == "igmp" or name == "mld" or name == "feature-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "feature-type"):
                                        self.feature_type = value
                                        self.feature_type.value_namespace = name_space
                                        self.feature_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.feature:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.admin_disabled.is_set or
                                    self.bvi_configured.is_set or
                                    self.dhcp_enabled.is_set or
                                    self.dhcp_trusted.is_set or
                                    self.flood_unknown_unicast_enabled.is_set or
                                    self.flooding_disabled.is_set or
                                    self.host_routing_enabled.is_set or
                                    self.igmp_flood_forward_enabled.is_set or
                                    self.igmp_mroute_port_enabled.is_set or
                                    self.igmp_route_guard_enabled.is_set or
                                    self.igmp_snoop_enabled.is_set or
                                    self.igmp_snoop_profile_enabled.is_set or
                                    self.is_bvi_up.is_set or
                                    self.is_dai_addr_validation_destination_mac_enabled.is_set or
                                    self.is_dai_addr_validation_ipv4_enabled.is_set or
                                    self.is_dai_addr_validation_source_mac_enabled.is_set or
                                    self.is_dai_enabled.is_set or
                                    self.is_dai_logging_enabled.is_set or
                                    self.is_evpn_cw_disable.is_set or
                                    self.is_evpn_enabled.is_set or
                                    self.is_evpn_flow_label.is_set or
                                    self.is_igmp_snoop_enabled.is_set or
                                    self.is_ipsg_enabled.is_set or
                                    self.is_ipsg_logging_enabled.is_set or
                                    self.is_mac_secure_accept_shutdown.is_set or
                                    self.is_mac_secure_enabled.is_set or
                                    self.is_mac_secure_logging_enabled.is_set or
                                    self.is_p2mp_pw_enabled.is_set or
                                    self.is_pbbevpn_enabled.is_set or
                                    self.is_swmac_learning.is_set or
                                    self.is_vni_enabled.is_set or
                                    self.is_vpls_flood_optimization_enabled.is_set or
                                    self.mac_aging_time.is_set or
                                    self.mac_aging_type.is_set or
                                    self.mac_learning_disabled.is_set or
                                    self.mac_limit.is_set or
                                    self.mac_limit_action.is_set or
                                    self.mac_limit_notification_type.is_set or
                                    self.mac_port_down_flush_disabled.is_set or
                                    self.mac_secure_action.is_set or
                                    self.mld_flood_forward_enabled.is_set or
                                    self.mld_mroute_port_enabled.is_set or
                                    self.mld_route_guard_enabled.is_set or
                                    self.mld_snoop_enabled.is_set or
                                    self.mld_snoop_profile_enabled.is_set or
                                    self.msti.is_set or
                                    self.mtu.is_set or
                                    self.number_of_macs.is_set or
                                    self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                                    self.storm_control_broadcast_enabled.is_set or
                                    self.storm_control_broadcast_rate_unit.is_set or
                                    self.storm_control_multicast_enabled.is_set or
                                    self.storm_control_multicast_rate_unit.is_set or
                                    self.storm_control_unicast_enabled.is_set or
                                    self.storm_control_unicast_rate_unit.is_set or
                                    self.stp_participating.is_set or
                                    self.unknown_unicast_flooding_disabled.is_set)

                            def has_operation(self):
                                for c in self.feature:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.admin_disabled.yfilter != YFilter.not_set or
                                    self.bvi_configured.yfilter != YFilter.not_set or
                                    self.dhcp_enabled.yfilter != YFilter.not_set or
                                    self.dhcp_trusted.yfilter != YFilter.not_set or
                                    self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                    self.flooding_disabled.yfilter != YFilter.not_set or
                                    self.host_routing_enabled.yfilter != YFilter.not_set or
                                    self.igmp_flood_forward_enabled.yfilter != YFilter.not_set or
                                    self.igmp_mroute_port_enabled.yfilter != YFilter.not_set or
                                    self.igmp_route_guard_enabled.yfilter != YFilter.not_set or
                                    self.igmp_snoop_enabled.yfilter != YFilter.not_set or
                                    self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set or
                                    self.is_bvi_up.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_evpn_cw_disable.yfilter != YFilter.not_set or
                                    self.is_evpn_enabled.yfilter != YFilter.not_set or
                                    self.is_evpn_flow_label.yfilter != YFilter.not_set or
                                    self.is_igmp_snoop_enabled.yfilter != YFilter.not_set or
                                    self.is_ipsg_enabled.yfilter != YFilter.not_set or
                                    self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set or
                                    self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_p2mp_pw_enabled.yfilter != YFilter.not_set or
                                    self.is_pbbevpn_enabled.yfilter != YFilter.not_set or
                                    self.is_swmac_learning.yfilter != YFilter.not_set or
                                    self.is_vni_enabled.yfilter != YFilter.not_set or
                                    self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set or
                                    self.mac_aging_time.yfilter != YFilter.not_set or
                                    self.mac_aging_type.yfilter != YFilter.not_set or
                                    self.mac_learning_disabled.yfilter != YFilter.not_set or
                                    self.mac_limit.yfilter != YFilter.not_set or
                                    self.mac_limit_action.yfilter != YFilter.not_set or
                                    self.mac_limit_notification_type.yfilter != YFilter.not_set or
                                    self.mac_port_down_flush_disabled.yfilter != YFilter.not_set or
                                    self.mac_secure_action.yfilter != YFilter.not_set or
                                    self.mld_flood_forward_enabled.yfilter != YFilter.not_set or
                                    self.mld_mroute_port_enabled.yfilter != YFilter.not_set or
                                    self.mld_route_guard_enabled.yfilter != YFilter.not_set or
                                    self.mld_snoop_enabled.yfilter != YFilter.not_set or
                                    self.mld_snoop_profile_enabled.yfilter != YFilter.not_set or
                                    self.msti.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.number_of_macs.yfilter != YFilter.not_set or
                                    self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                                    self.storm_control_broadcast_enabled.yfilter != YFilter.not_set or
                                    self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set or
                                    self.storm_control_multicast_enabled.yfilter != YFilter.not_set or
                                    self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set or
                                    self.storm_control_unicast_enabled.yfilter != YFilter.not_set or
                                    self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set or
                                    self.stp_participating.yfilter != YFilter.not_set or
                                    self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "operational-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.admin_disabled.is_set or self.admin_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admin_disabled.get_name_leafdata())
                                if (self.bvi_configured.is_set or self.bvi_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_configured.get_name_leafdata())
                                if (self.dhcp_enabled.is_set or self.dhcp_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcp_enabled.get_name_leafdata())
                                if (self.dhcp_trusted.is_set or self.dhcp_trusted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcp_trusted.get_name_leafdata())
                                if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                if (self.flooding_disabled.is_set or self.flooding_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flooding_disabled.get_name_leafdata())
                                if (self.host_routing_enabled.is_set or self.host_routing_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.host_routing_enabled.get_name_leafdata())
                                if (self.igmp_flood_forward_enabled.is_set or self.igmp_flood_forward_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_flood_forward_enabled.get_name_leafdata())
                                if (self.igmp_mroute_port_enabled.is_set or self.igmp_mroute_port_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_mroute_port_enabled.get_name_leafdata())
                                if (self.igmp_route_guard_enabled.is_set or self.igmp_route_guard_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_route_guard_enabled.get_name_leafdata())
                                if (self.igmp_snoop_enabled.is_set or self.igmp_snoop_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_snoop_enabled.get_name_leafdata())
                                if (self.igmp_snoop_profile_enabled.is_set or self.igmp_snoop_profile_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_snoop_profile_enabled.get_name_leafdata())
                                if (self.is_bvi_up.is_set or self.is_bvi_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_bvi_up.get_name_leafdata())
                                if (self.is_dai_addr_validation_destination_mac_enabled.is_set or self.is_dai_addr_validation_destination_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validation_destination_mac_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validation_ipv4_enabled.is_set or self.is_dai_addr_validation_ipv4_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validation_ipv4_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validation_source_mac_enabled.is_set or self.is_dai_addr_validation_source_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validation_source_mac_enabled.get_name_leafdata())
                                if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                if (self.is_evpn_cw_disable.is_set or self.is_evpn_cw_disable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpn_cw_disable.get_name_leafdata())
                                if (self.is_evpn_enabled.is_set or self.is_evpn_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpn_enabled.get_name_leafdata())
                                if (self.is_evpn_flow_label.is_set or self.is_evpn_flow_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpn_flow_label.get_name_leafdata())
                                if (self.is_igmp_snoop_enabled.is_set or self.is_igmp_snoop_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_igmp_snoop_enabled.get_name_leafdata())
                                if (self.is_ipsg_enabled.is_set or self.is_ipsg_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ipsg_enabled.get_name_leafdata())
                                if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                if (self.is_mac_secure_accept_shutdown.is_set or self.is_mac_secure_accept_shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_accept_shutdown.get_name_leafdata())
                                if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                if (self.is_p2mp_pw_enabled.is_set or self.is_p2mp_pw_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_p2mp_pw_enabled.get_name_leafdata())
                                if (self.is_pbbevpn_enabled.is_set or self.is_pbbevpn_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pbbevpn_enabled.get_name_leafdata())
                                if (self.is_swmac_learning.is_set or self.is_swmac_learning.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_swmac_learning.get_name_leafdata())
                                if (self.is_vni_enabled.is_set or self.is_vni_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vni_enabled.get_name_leafdata())
                                if (self.is_vpls_flood_optimization_enabled.is_set or self.is_vpls_flood_optimization_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vpls_flood_optimization_enabled.get_name_leafdata())
                                if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                if (self.mac_aging_type.is_set or self.mac_aging_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_type.get_name_leafdata())
                                if (self.mac_learning_disabled.is_set or self.mac_learning_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_learning_disabled.get_name_leafdata())
                                if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                if (self.mac_limit_notification_type.is_set or self.mac_limit_notification_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_notification_type.get_name_leafdata())
                                if (self.mac_port_down_flush_disabled.is_set or self.mac_port_down_flush_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_port_down_flush_disabled.get_name_leafdata())
                                if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                if (self.mld_flood_forward_enabled.is_set or self.mld_flood_forward_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_flood_forward_enabled.get_name_leafdata())
                                if (self.mld_mroute_port_enabled.is_set or self.mld_mroute_port_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_mroute_port_enabled.get_name_leafdata())
                                if (self.mld_route_guard_enabled.is_set or self.mld_route_guard_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_route_guard_enabled.get_name_leafdata())
                                if (self.mld_snoop_enabled.is_set or self.mld_snoop_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_snoop_enabled.get_name_leafdata())
                                if (self.mld_snoop_profile_enabled.is_set or self.mld_snoop_profile_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_snoop_profile_enabled.get_name_leafdata())
                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.number_of_macs.is_set or self.number_of_macs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_of_macs.get_name_leafdata())
                                if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                                if (self.storm_control_broadcast_enabled.is_set or self.storm_control_broadcast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_broadcast_enabled.get_name_leafdata())
                                if (self.storm_control_broadcast_rate_unit.is_set or self.storm_control_broadcast_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_broadcast_rate_unit.get_name_leafdata())
                                if (self.storm_control_multicast_enabled.is_set or self.storm_control_multicast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_multicast_enabled.get_name_leafdata())
                                if (self.storm_control_multicast_rate_unit.is_set or self.storm_control_multicast_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_multicast_rate_unit.get_name_leafdata())
                                if (self.storm_control_unicast_enabled.is_set or self.storm_control_unicast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_unicast_enabled.get_name_leafdata())
                                if (self.storm_control_unicast_rate_unit.is_set or self.storm_control_unicast_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.storm_control_unicast_rate_unit.get_name_leafdata())
                                if (self.stp_participating.is_set or self.stp_participating.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stp_participating.get_name_leafdata())
                                if (self.unknown_unicast_flooding_disabled.is_set or self.unknown_unicast_flooding_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_unicast_flooding_disabled.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "feature"):
                                    for c in self.feature:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.feature.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "feature" or name == "admin-disabled" or name == "bvi-configured" or name == "dhcp-enabled" or name == "dhcp-trusted" or name == "flood-unknown-unicast-enabled" or name == "flooding-disabled" or name == "host-routing-enabled" or name == "igmp-flood-forward-enabled" or name == "igmp-mroute-port-enabled" or name == "igmp-route-guard-enabled" or name == "igmp-snoop-enabled" or name == "igmp-snoop-profile-enabled" or name == "is-bvi-up" or name == "is-dai-addr-validation-destination-mac-enabled" or name == "is-dai-addr-validation-ipv4-enabled" or name == "is-dai-addr-validation-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-evpn-cw-disable" or name == "is-evpn-enabled" or name == "is-evpn-flow-label" or name == "is-igmp-snoop-enabled" or name == "is-ipsg-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "is-p2mp-pw-enabled" or name == "is-pbbevpn-enabled" or name == "is-swmac-learning" or name == "is-vni-enabled" or name == "is-vpls-flood-optimization-enabled" or name == "mac-aging-time" or name == "mac-aging-type" or name == "mac-learning-disabled" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification-type" or name == "mac-port-down-flush-disabled" or name == "mac-secure-action" or name == "mld-flood-forward-enabled" or name == "mld-mroute-port-enabled" or name == "mld-route-guard-enabled" or name == "mld-snoop-enabled" or name == "mld-snoop-profile-enabled" or name == "msti" or name == "mtu" or name == "number-of-macs" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "storm-control-broadcast-enabled" or name == "storm-control-broadcast-rate-unit" or name == "storm-control-multicast-enabled" or name == "storm-control-multicast-rate-unit" or name == "storm-control-unicast-enabled" or name == "storm-control-unicast-rate-unit" or name == "stp-participating" or name == "unknown-unicast-flooding-disabled"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "admin-disabled"):
                                    self.admin_disabled = value
                                    self.admin_disabled.value_namespace = name_space
                                    self.admin_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-configured"):
                                    self.bvi_configured = value
                                    self.bvi_configured.value_namespace = name_space
                                    self.bvi_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcp-enabled"):
                                    self.dhcp_enabled = value
                                    self.dhcp_enabled.value_namespace = name_space
                                    self.dhcp_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcp-trusted"):
                                    self.dhcp_trusted = value
                                    self.dhcp_trusted.value_namespace = name_space
                                    self.dhcp_trusted.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-unknown-unicast-enabled"):
                                    self.flood_unknown_unicast_enabled = value
                                    self.flood_unknown_unicast_enabled.value_namespace = name_space
                                    self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "flooding-disabled"):
                                    self.flooding_disabled = value
                                    self.flooding_disabled.value_namespace = name_space
                                    self.flooding_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "host-routing-enabled"):
                                    self.host_routing_enabled = value
                                    self.host_routing_enabled.value_namespace = name_space
                                    self.host_routing_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-flood-forward-enabled"):
                                    self.igmp_flood_forward_enabled = value
                                    self.igmp_flood_forward_enabled.value_namespace = name_space
                                    self.igmp_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-mroute-port-enabled"):
                                    self.igmp_mroute_port_enabled = value
                                    self.igmp_mroute_port_enabled.value_namespace = name_space
                                    self.igmp_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-route-guard-enabled"):
                                    self.igmp_route_guard_enabled = value
                                    self.igmp_route_guard_enabled.value_namespace = name_space
                                    self.igmp_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-snoop-enabled"):
                                    self.igmp_snoop_enabled = value
                                    self.igmp_snoop_enabled.value_namespace = name_space
                                    self.igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-snoop-profile-enabled"):
                                    self.igmp_snoop_profile_enabled = value
                                    self.igmp_snoop_profile_enabled.value_namespace = name_space
                                    self.igmp_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-bvi-up"):
                                    self.is_bvi_up = value
                                    self.is_bvi_up.value_namespace = name_space
                                    self.is_bvi_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validation-destination-mac-enabled"):
                                    self.is_dai_addr_validation_destination_mac_enabled = value
                                    self.is_dai_addr_validation_destination_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validation_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validation-ipv4-enabled"):
                                    self.is_dai_addr_validation_ipv4_enabled = value
                                    self.is_dai_addr_validation_ipv4_enabled.value_namespace = name_space
                                    self.is_dai_addr_validation_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validation-source-mac-enabled"):
                                    self.is_dai_addr_validation_source_mac_enabled = value
                                    self.is_dai_addr_validation_source_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validation_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-enabled"):
                                    self.is_dai_enabled = value
                                    self.is_dai_enabled.value_namespace = name_space
                                    self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-logging-enabled"):
                                    self.is_dai_logging_enabled = value
                                    self.is_dai_logging_enabled.value_namespace = name_space
                                    self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpn-cw-disable"):
                                    self.is_evpn_cw_disable = value
                                    self.is_evpn_cw_disable.value_namespace = name_space
                                    self.is_evpn_cw_disable.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpn-enabled"):
                                    self.is_evpn_enabled = value
                                    self.is_evpn_enabled.value_namespace = name_space
                                    self.is_evpn_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpn-flow-label"):
                                    self.is_evpn_flow_label = value
                                    self.is_evpn_flow_label.value_namespace = name_space
                                    self.is_evpn_flow_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-igmp-snoop-enabled"):
                                    self.is_igmp_snoop_enabled = value
                                    self.is_igmp_snoop_enabled.value_namespace = name_space
                                    self.is_igmp_snoop_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ipsg-enabled"):
                                    self.is_ipsg_enabled = value
                                    self.is_ipsg_enabled.value_namespace = name_space
                                    self.is_ipsg_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ipsg-logging-enabled"):
                                    self.is_ipsg_logging_enabled = value
                                    self.is_ipsg_logging_enabled.value_namespace = name_space
                                    self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-accept-shutdown"):
                                    self.is_mac_secure_accept_shutdown = value
                                    self.is_mac_secure_accept_shutdown.value_namespace = name_space
                                    self.is_mac_secure_accept_shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-enabled"):
                                    self.is_mac_secure_enabled = value
                                    self.is_mac_secure_enabled.value_namespace = name_space
                                    self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-logging-enabled"):
                                    self.is_mac_secure_logging_enabled = value
                                    self.is_mac_secure_logging_enabled.value_namespace = name_space
                                    self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-p2mp-pw-enabled"):
                                    self.is_p2mp_pw_enabled = value
                                    self.is_p2mp_pw_enabled.value_namespace = name_space
                                    self.is_p2mp_pw_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pbbevpn-enabled"):
                                    self.is_pbbevpn_enabled = value
                                    self.is_pbbevpn_enabled.value_namespace = name_space
                                    self.is_pbbevpn_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-swmac-learning"):
                                    self.is_swmac_learning = value
                                    self.is_swmac_learning.value_namespace = name_space
                                    self.is_swmac_learning.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vni-enabled"):
                                    self.is_vni_enabled = value
                                    self.is_vni_enabled.value_namespace = name_space
                                    self.is_vni_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vpls-flood-optimization-enabled"):
                                    self.is_vpls_flood_optimization_enabled = value
                                    self.is_vpls_flood_optimization_enabled.value_namespace = name_space
                                    self.is_vpls_flood_optimization_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-time"):
                                    self.mac_aging_time = value
                                    self.mac_aging_time.value_namespace = name_space
                                    self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-type"):
                                    self.mac_aging_type = value
                                    self.mac_aging_type.value_namespace = name_space
                                    self.mac_aging_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-learning-disabled"):
                                    self.mac_learning_disabled = value
                                    self.mac_learning_disabled.value_namespace = name_space
                                    self.mac_learning_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit"):
                                    self.mac_limit = value
                                    self.mac_limit.value_namespace = name_space
                                    self.mac_limit.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-action"):
                                    self.mac_limit_action = value
                                    self.mac_limit_action.value_namespace = name_space
                                    self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-notification-type"):
                                    self.mac_limit_notification_type = value
                                    self.mac_limit_notification_type.value_namespace = name_space
                                    self.mac_limit_notification_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-port-down-flush-disabled"):
                                    self.mac_port_down_flush_disabled = value
                                    self.mac_port_down_flush_disabled.value_namespace = name_space
                                    self.mac_port_down_flush_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-secure-action"):
                                    self.mac_secure_action = value
                                    self.mac_secure_action.value_namespace = name_space
                                    self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-flood-forward-enabled"):
                                    self.mld_flood_forward_enabled = value
                                    self.mld_flood_forward_enabled.value_namespace = name_space
                                    self.mld_flood_forward_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-mroute-port-enabled"):
                                    self.mld_mroute_port_enabled = value
                                    self.mld_mroute_port_enabled.value_namespace = name_space
                                    self.mld_mroute_port_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-route-guard-enabled"):
                                    self.mld_route_guard_enabled = value
                                    self.mld_route_guard_enabled.value_namespace = name_space
                                    self.mld_route_guard_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-snoop-enabled"):
                                    self.mld_snoop_enabled = value
                                    self.mld_snoop_enabled.value_namespace = name_space
                                    self.mld_snoop_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-snoop-profile-enabled"):
                                    self.mld_snoop_profile_enabled = value
                                    self.mld_snoop_profile_enabled.value_namespace = name_space
                                    self.mld_snoop_profile_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti"):
                                    self.msti = value
                                    self.msti.value_namespace = name_space
                                    self.msti.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-of-macs"):
                                    self.number_of_macs = value
                                    self.number_of_macs.value_namespace = name_space
                                    self.number_of_macs.value_namespace_prefix = name_space_prefix
                                if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                                    self.nv_satellite_offload_ipv4_multicast_disabled = value
                                    self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                                    self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-broadcast-enabled"):
                                    self.storm_control_broadcast_enabled = value
                                    self.storm_control_broadcast_enabled.value_namespace = name_space
                                    self.storm_control_broadcast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-broadcast-rate-unit"):
                                    self.storm_control_broadcast_rate_unit = value
                                    self.storm_control_broadcast_rate_unit.value_namespace = name_space
                                    self.storm_control_broadcast_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-multicast-enabled"):
                                    self.storm_control_multicast_enabled = value
                                    self.storm_control_multicast_enabled.value_namespace = name_space
                                    self.storm_control_multicast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-multicast-rate-unit"):
                                    self.storm_control_multicast_rate_unit = value
                                    self.storm_control_multicast_rate_unit.value_namespace = name_space
                                    self.storm_control_multicast_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-unicast-enabled"):
                                    self.storm_control_unicast_enabled = value
                                    self.storm_control_unicast_enabled.value_namespace = name_space
                                    self.storm_control_unicast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "storm-control-unicast-rate-unit"):
                                    self.storm_control_unicast_rate_unit = value
                                    self.storm_control_unicast_rate_unit.value_namespace = name_space
                                    self.storm_control_unicast_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "stp-participating"):
                                    self.stp_participating = value
                                    self.stp_participating.value_namespace = name_space
                                    self.stp_participating.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-unicast-flooding-disabled"):
                                    self.unknown_unicast_flooding_disabled = value
                                    self.unknown_unicast_flooding_disabled.value_namespace = name_space
                                    self.unknown_unicast_flooding_disabled.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.broadcast_storm_control_kb_ps.is_set or
                                self.broadcast_storm_control_pps.is_set or
                                self.multicast_storm_control_kb_ps.is_set or
                                self.multicast_storm_control_pps.is_set or
                                self.unicast_storm_control_kb_ps.is_set or
                                self.unicast_storm_control_pps.is_set or
                                (self.operational_information is not None and self.operational_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                (self.operational_information is not None and self.operational_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-port-operational-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "operational-information"):
                                if (self.operational_information is None):
                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation()
                                    self.operational_information.parent = self
                                    self._children_name_map["operational_information"] = "operational-information"
                                return self.operational_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "operational-information" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "broadcast-storm-control-kb-ps"):
                                self.broadcast_storm_control_kb_ps = value
                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-pps"):
                                self.broadcast_storm_control_pps = value
                                self.broadcast_storm_control_pps.value_namespace = name_space
                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-kb-ps"):
                                self.multicast_storm_control_kb_ps = value
                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-pps"):
                                self.multicast_storm_control_pps = value
                                self.multicast_storm_control_pps.value_namespace = name_space
                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-kb-ps"):
                                self.unicast_storm_control_kb_ps = value
                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-pps"):
                                self.unicast_storm_control_pps = value
                                self.unicast_storm_control_pps.value_namespace = name_space
                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.aging_time_out.is_set or
                            self.bd_name.is_set or
                            self.bridge_id.is_set or
                            self.flooding_disabled.is_set or
                            self.group_name.is_set or
                            self.mac_learning_disabled.is_set or
                            self.mac_limit.is_set or
                            self.mac_limit_action.is_set or
                            self.mac_port_down_flush_disabled.is_set or
                            self.mtu.is_set or
                            self.number_of_hw_mac.is_set or
                            self.number_of_sw_mac.is_set or
                            self.shg_id.is_set or
                            self.xc_id.is_set or
                            self.xc_uint_id.is_set or
                            (self.bridge_port_operational_info is not None and self.bridge_port_operational_info.has_data()) or
                            (self.segment is not None and self.segment.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.aging_time_out.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            self.bridge_id.yfilter != YFilter.not_set or
                            self.flooding_disabled.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.mac_learning_disabled.yfilter != YFilter.not_set or
                            self.mac_limit.yfilter != YFilter.not_set or
                            self.mac_limit_action.yfilter != YFilter.not_set or
                            self.mac_port_down_flush_disabled.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.number_of_hw_mac.yfilter != YFilter.not_set or
                            self.number_of_sw_mac.yfilter != YFilter.not_set or
                            self.shg_id.yfilter != YFilter.not_set or
                            self.xc_id.yfilter != YFilter.not_set or
                            self.xc_uint_id.yfilter != YFilter.not_set or
                            (self.bridge_port_operational_info is not None and self.bridge_port_operational_info.has_operation()) or
                            (self.segment is not None and self.segment.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-bridge-port" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.aging_time_out.is_set or self.aging_time_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.aging_time_out.get_name_leafdata())
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())
                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                        if (self.flooding_disabled.is_set or self.flooding_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flooding_disabled.get_name_leafdata())
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.mac_learning_disabled.is_set or self.mac_learning_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_learning_disabled.get_name_leafdata())
                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                        if (self.mac_port_down_flush_disabled.is_set or self.mac_port_down_flush_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_port_down_flush_disabled.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.number_of_hw_mac.is_set or self.number_of_hw_mac.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_hw_mac.get_name_leafdata())
                        if (self.number_of_sw_mac.is_set or self.number_of_sw_mac.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_sw_mac.get_name_leafdata())
                        if (self.shg_id.is_set or self.shg_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shg_id.get_name_leafdata())
                        if (self.xc_id.is_set or self.xc_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xc_id.get_name_leafdata())
                        if (self.xc_uint_id.is_set or self.xc_uint_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xc_uint_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-port-operational-info"):
                            if (self.bridge_port_operational_info is None):
                                self.bridge_port_operational_info = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo()
                                self.bridge_port_operational_info.parent = self
                                self._children_name_map["bridge_port_operational_info"] = "bridge-port-operational-info"
                            return self.bridge_port_operational_info

                        if (child_yang_name == "segment"):
                            if (self.segment is None):
                                self.segment = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment()
                                self.segment.parent = self
                                self._children_name_map["segment"] = "segment"
                            return self.segment

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-port-operational-info" or name == "segment" or name == "aging-time-out" or name == "bd-name" or name == "bridge-id" or name == "flooding-disabled" or name == "group-name" or name == "mac-learning-disabled" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-port-down-flush-disabled" or name == "mtu" or name == "number-of-hw-mac" or name == "number-of-sw-mac" or name == "shg-id" or name == "xc-id" or name == "xc-uint-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "aging-time-out"):
                            self.aging_time_out = value
                            self.aging_time_out.value_namespace = name_space
                            self.aging_time_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-id"):
                            self.bridge_id = value
                            self.bridge_id.value_namespace = name_space
                            self.bridge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "flooding-disabled"):
                            self.flooding_disabled = value
                            self.flooding_disabled.value_namespace = name_space
                            self.flooding_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-learning-disabled"):
                            self.mac_learning_disabled = value
                            self.mac_learning_disabled.value_namespace = name_space
                            self.mac_learning_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit"):
                            self.mac_limit = value
                            self.mac_limit.value_namespace = name_space
                            self.mac_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-action"):
                            self.mac_limit_action = value
                            self.mac_limit_action.value_namespace = name_space
                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-port-down-flush-disabled"):
                            self.mac_port_down_flush_disabled = value
                            self.mac_port_down_flush_disabled.value_namespace = name_space
                            self.mac_port_down_flush_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-hw-mac"):
                            self.number_of_hw_mac = value
                            self.number_of_hw_mac.value_namespace = name_space
                            self.number_of_hw_mac.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-sw-mac"):
                            self.number_of_sw_mac = value
                            self.number_of_sw_mac.value_namespace = name_space
                            self.number_of_sw_mac.value_namespace_prefix = name_space_prefix
                        if(value_path == "shg-id"):
                            self.shg_id = value
                            self.shg_id.value_namespace = name_space
                            self.shg_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "xc-id"):
                            self.xc_id = value
                            self.xc_id.value_namespace = name_space
                            self.xc_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "xc-uint-id"):
                            self.xc_uint_id = value
                            self.xc_uint_id.value_namespace = name_space
                            self.xc_uint_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_bridge_port:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_bridge_port:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-bridge-ports" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-bridge-port"):
                        for c in self.l2fib_bridge_port:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_bridge_port.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-bridge-port"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibmacDetails(Entity):
                """
                Bridge MAC detail information
                
                .. attribute:: l2fibmac_detail
                
                	MAC Detail information
                	**type**\: list of    :py:class:`L2FibmacDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibmacDetails, self).__init__()

                    self.yang_name = "l2fibmac-details"
                    self.yang_parent_name = "node"

                    self.l2fibmac_detail = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacDetails, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails, self).__setattr__(name, value)


                class L2FibmacDetail(Entity):
                    """
                    MAC Detail information
                    
                    .. attribute:: address
                    
                    	Static MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Base>`
                    
                    .. attribute:: bmac_configured
                    
                    	Flag\: Configured BMAC
                    	**type**\:  bool
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge name
                    	**type**\:  str
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_ctx
                    
                    	Evpn Context
                    	**type**\:   :py:class:`EvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx>`
                    
                    .. attribute:: flag_extension
                    
                    	MAC Flag Extension
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: l3_encapsulationvlan_id
                    
                    	L3 encapsulation Vlan ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: next_hop
                    
                    	Next Hop
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop>`
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Nodeid list
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: pbb_bmac
                    
                    	Backbone MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: peer_vtep_ip
                    
                    	Peer VTEP IP for this MAC Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: platform_is_hw_learn
                    
                    	Platform is HW Learn
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:   :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment>`
                    
                    .. attribute:: vni
                    
                    	VNI Information
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_l3_flag
                    
                    	Flag\: L3 Vxlan
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail, self).__init__()

                        self.yang_name = "l2fibmac-detail"
                        self.yang_parent_name = "l2fibmac-details"

                        self.address = YLeaf(YType.str, "address")

                        self.bmac_configured = YLeaf(YType.boolean, "bmac-configured")

                        self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                        self.flag_extension = YLeaf(YType.uint16, "flag-extension")

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.l3_encapsulationvlan_id = YLeaf(YType.uint16, "l3-encapsulationvlan-id")

                        self.name = YLeaf(YType.str, "name")

                        self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                        self.node_id = YLeaf(YType.str, "node-id")

                        self.pbb_bmac = YLeaf(YType.str, "pbb-bmac")

                        self.peer_vtep_ip = YLeaf(YType.str, "peer-vtep-ip")

                        self.platform_is_hw_learn = YLeaf(YType.uint8, "platform-is-hw-learn")

                        self.vni = YLeaf(YType.uint32, "vni")

                        self.vni_l3_flag = YLeaf(YType.boolean, "vni-l3-flag")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                        self.evpn_ctx = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx()
                        self.evpn_ctx.parent = self
                        self._children_name_map["evpn_ctx"] = "evpn-ctx"
                        self._children_yang_names.add("evpn-ctx")

                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.segment = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment()
                        self.segment.parent = self
                        self._children_name_map["segment"] = "segment"
                        self._children_yang_names.add("segment")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "bmac_configured",
                                        "bridge_domain_name",
                                        "bridge_id",
                                        "flag_extension",
                                        "group_name",
                                        "l3_encapsulationvlan_id",
                                        "name",
                                        "next_hop_valid",
                                        "node_id",
                                        "pbb_bmac",
                                        "peer_vtep_ip",
                                        "platform_is_hw_learn",
                                        "vni",
                                        "vni_l3_flag") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibmac-detail"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Segment(Entity):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Evpn>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment, self).__init__()

                            self.yang_name = "segment"
                            self.yang_parent_name = "l2fibmac-detail"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"
                            self._children_yang_names.add("evpn")

                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"
                            self._children_yang_names.add("pbb")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                            self.vni = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"
                            self._children_yang_names.add("vni")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment"

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Ac, self).__setattr__(name, value)

                            def has_data(self):
                                return self.interface_handle.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment"

                                self.xcid = YLeaf(YType.uint32, "xcid")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pbb, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pbb, self).__setattr__(name, value)

                            def has_data(self):
                                return self.xcid.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment"

                                self.parent_if = YLeaf(YType.str, "parent-if")

                                self.xcid = YLeaf(YType.uint32, "xcid")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("parent_if",
                                                "xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Vni, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Vni, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.parent_if.is_set or
                                    self.xcid.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.parent_if.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vni" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.parent_if.is_set or self.parent_if.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_if.get_name_leafdata())
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parent-if" or name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "parent-if"):
                                    self.parent_if = value
                                    self.parent_if.value_namespace = name_space
                                    self.parent_if.value_namespace_prefix = name_space_prefix
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment"

                                self.xcid = YLeaf(YType.uint32, "xcid")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("xcid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Evpn, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Evpn, self).__setattr__(name, value)

                            def has_data(self):
                                return self.xcid.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.xcid.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xcid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "xcid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "xcid"):
                                    self.xcid = value
                                    self.xcid.value_namespace = name_space
                                    self.xcid.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment"

                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("next_hop_address",
                                                "pseudo_wire_id_type",
                                                "pw_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.next_hop_address.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.next_hop_address.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "pseudo-wire-id-type" or name == "pw-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "next-hop-address"):
                                    self.next_hop_address = value
                                    self.next_hop_address.value_namespace = name_space
                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.evpn is not None and self.evpn.has_data()) or
                                (self.pbb is not None and self.pbb.has_data()) or
                                (self.pw is not None and self.pw.has_data()) or
                                (self.vni is not None and self.vni.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.evpn is not None and self.evpn.has_operation()) or
                                (self.pbb is not None and self.pbb.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()) or
                                (self.vni is not None and self.vni.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "evpn"):
                                if (self.evpn is None):
                                    self.evpn = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Evpn()
                                    self.evpn.parent = self
                                    self._children_name_map["evpn"] = "evpn"
                                return self.evpn

                            if (child_yang_name == "pbb"):
                                if (self.pbb is None):
                                    self.pbb = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pbb()
                                    self.pbb.parent = self
                                    self._children_name_map["pbb"] = "pbb"
                                return self.pbb

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            if (child_yang_name == "vni"):
                                if (self.vni is None):
                                    self.vni = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Vni()
                                    self.vni.parent = self
                                    self._children_name_map["vni"] = "vni"
                                return self.vni

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "evpn" or name == "pbb" or name == "pw" or name == "vni" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix


                    class EvpnCtx(Entity):
                        """
                        Evpn Context
                        
                        .. attribute:: bp_ifh
                        
                        	BP IFH
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibBridgeMacEvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeMacEvpnCtx>`
                        
                        .. attribute:: esi_id
                        
                        	EsiID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: local_label
                        
                        	LocalLabel
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mcast_ole
                        
                        	mcast ole
                        	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx.McastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx, self).__init__()

                            self.yang_name = "evpn-ctx"
                            self.yang_parent_name = "l2fibmac-detail"

                            self.bp_ifh = YLeaf(YType.str, "bp-ifh")

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.esi_id = YLeaf(YType.uint16, "esi-id")

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx.McastOle()
                            self.mcast_ole.parent = self
                            self._children_name_map["mcast_ole"] = "mcast-ole"
                            self._children_yang_names.add("mcast-ole")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bp_ifh",
                                            "data_type",
                                            "esi_id",
                                            "local_label") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx, self).__setattr__(name, value)


                        class McastOle(Entity):
                            """
                            mcast ole
                            
                            .. attribute:: mcast_label
                            
                            	Inclusive mcast label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ipv6_addr
                            
                            	Next Hop IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx.McastOle, self).__init__()

                                self.yang_name = "mcast-ole"
                                self.yang_parent_name = "evpn-ctx"

                                self.mcast_label = YLeaf(YType.uint32, "mcast-label")

                                self.next_hop_ipv6_addr = YLeaf(YType.str, "next-hop-ipv6-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mcast_label",
                                                "next_hop_ipv6_addr") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx.McastOle, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx.McastOle, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.mcast_label.is_set or
                                    self.next_hop_ipv6_addr.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mcast_label.yfilter != YFilter.not_set or
                                    self.next_hop_ipv6_addr.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mcast-ole" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mcast_label.is_set or self.mcast_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mcast_label.get_name_leafdata())
                                if (self.next_hop_ipv6_addr.is_set or self.next_hop_ipv6_addr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ipv6_addr.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mcast-label" or name == "next-hop-ipv6-addr"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mcast-label"):
                                    self.mcast_label = value
                                    self.mcast_label.value_namespace = name_space
                                    self.mcast_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ipv6-addr"):
                                    self.next_hop_ipv6_addr = value
                                    self.next_hop_ipv6_addr.value_namespace = name_space
                                    self.next_hop_ipv6_addr.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bp_ifh.is_set or
                                self.data_type.is_set or
                                self.esi_id.is_set or
                                self.local_label.is_set or
                                (self.mcast_ole is not None and self.mcast_ole.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bp_ifh.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                self.esi_id.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                (self.mcast_ole is not None and self.mcast_ole.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "evpn-ctx" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bp_ifh.is_set or self.bp_ifh.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bp_ifh.get_name_leafdata())
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())
                            if (self.esi_id.is_set or self.esi_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.esi_id.get_name_leafdata())
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mcast-ole"):
                                if (self.mcast_ole is None):
                                    self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx.McastOle()
                                    self.mcast_ole.parent = self
                                    self._children_name_map["mcast_ole"] = "mcast-ole"
                                return self.mcast_ole

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mcast-ole" or name == "bp-ifh" or name == "data-type" or name == "esi-id" or name == "local-label"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bp-ifh"):
                                self.bp_ifh = value
                                self.bp_ifh.value_namespace = name_space
                                self.bp_ifh.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "esi-id"):
                                self.esi_id = value
                                self.esi_id.value_namespace = name_space
                                self.esi_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix


                    class NextHop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: base
                        
                        	Base Information
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop.Base>`
                        
                        .. attribute:: children_count
                        
                        	Children Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_address
                        
                        	NHOP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_internal_label
                        
                        	NHOP Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: plaformt_data_valid
                        
                        	Is Platform Data Valid
                        	**type**\:  bool
                        
                        .. attribute:: platform_data_length
                        
                        	Platform Data Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "l2fibmac-detail"

                            self.children_count = YLeaf(YType.uint32, "children-count")

                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                            self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                            self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                            self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                            self.base = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._children_yang_names.add("base")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("children_count",
                                            "next_hop_address",
                                            "next_hop_internal_label",
                                            "plaformt_data_valid",
                                            "platform_data_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop, self).__setattr__(name, value)


                        class Base(Entity):
                            """
                            Base Information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "next-hop"

                            def has_data(self):
                                return False

                            def has_operation(self):
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "base" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.children_count.is_set or
                                self.next_hop_address.is_set or
                                self.next_hop_internal_label.is_set or
                                self.plaformt_data_valid.is_set or
                                self.platform_data_length.is_set or
                                (self.base is not None and self.base.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.children_count.yfilter != YFilter.not_set or
                                self.next_hop_address.yfilter != YFilter.not_set or
                                self.next_hop_internal_label.yfilter != YFilter.not_set or
                                self.plaformt_data_valid.yfilter != YFilter.not_set or
                                self.platform_data_length.yfilter != YFilter.not_set or
                                (self.base is not None and self.base.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "next-hop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.children_count.get_name_leafdata())
                            if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                            if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                            if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                            if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "base"):
                                if (self.base is None):
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                return self.base

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "children-count"):
                                self.children_count = value
                                self.children_count.value_namespace = name_space
                                self.children_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-address"):
                                self.next_hop_address = value
                                self.next_hop_address.value_namespace = name_space
                                self.next_hop_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-internal-label"):
                                self.next_hop_internal_label = value
                                self.next_hop_internal_label.value_namespace = name_space
                                self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "plaformt-data-valid"):
                                self.plaformt_data_valid = value
                                self.plaformt_data_valid.value_namespace = name_space
                                self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                            if(value_path == "platform-data-length"):
                                self.platform_data_length = value
                                self.platform_data_length.value_namespace = name_space
                                self.platform_data_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.bmac_configured.is_set or
                            self.bridge_domain_name.is_set or
                            self.bridge_id.is_set or
                            self.flag_extension.is_set or
                            self.group_name.is_set or
                            self.l3_encapsulationvlan_id.is_set or
                            self.name.is_set or
                            self.next_hop_valid.is_set or
                            self.node_id.is_set or
                            self.pbb_bmac.is_set or
                            self.peer_vtep_ip.is_set or
                            self.platform_is_hw_learn.is_set or
                            self.vni.is_set or
                            self.vni_l3_flag.is_set or
                            (self.base is not None and self.base.has_data()) or
                            (self.evpn_ctx is not None and self.evpn_ctx.has_data()) or
                            (self.next_hop is not None and self.next_hop.has_data()) or
                            (self.segment is not None and self.segment.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.bmac_configured.yfilter != YFilter.not_set or
                            self.bridge_domain_name.yfilter != YFilter.not_set or
                            self.bridge_id.yfilter != YFilter.not_set or
                            self.flag_extension.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.l3_encapsulationvlan_id.yfilter != YFilter.not_set or
                            self.name.yfilter != YFilter.not_set or
                            self.next_hop_valid.yfilter != YFilter.not_set or
                            self.node_id.yfilter != YFilter.not_set or
                            self.pbb_bmac.yfilter != YFilter.not_set or
                            self.peer_vtep_ip.yfilter != YFilter.not_set or
                            self.platform_is_hw_learn.yfilter != YFilter.not_set or
                            self.vni.yfilter != YFilter.not_set or
                            self.vni_l3_flag.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()) or
                            (self.evpn_ctx is not None and self.evpn_ctx.has_operation()) or
                            (self.next_hop is not None and self.next_hop.has_operation()) or
                            (self.segment is not None and self.segment.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fibmac-detail" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.bmac_configured.is_set or self.bmac_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bmac_configured.get_name_leafdata())
                        if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                        if (self.flag_extension.is_set or self.flag_extension.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flag_extension.get_name_leafdata())
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.l3_encapsulationvlan_id.is_set or self.l3_encapsulationvlan_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.l3_encapsulationvlan_id.get_name_leafdata())
                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.name.get_name_leafdata())
                        if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.next_hop_valid.get_name_leafdata())
                        if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_id.get_name_leafdata())
                        if (self.pbb_bmac.is_set or self.pbb_bmac.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pbb_bmac.get_name_leafdata())
                        if (self.peer_vtep_ip.is_set or self.peer_vtep_ip.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.peer_vtep_ip.get_name_leafdata())
                        if (self.platform_is_hw_learn.is_set or self.platform_is_hw_learn.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.platform_is_hw_learn.get_name_leafdata())
                        if (self.vni.is_set or self.vni.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni.get_name_leafdata())
                        if (self.vni_l3_flag.is_set or self.vni_l3_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_l3_flag.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        if (child_yang_name == "evpn-ctx"):
                            if (self.evpn_ctx is None):
                                self.evpn_ctx = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx()
                                self.evpn_ctx.parent = self
                                self._children_name_map["evpn_ctx"] = "evpn-ctx"
                            return self.evpn_ctx

                        if (child_yang_name == "next-hop"):
                            if (self.next_hop is None):
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                            return self.next_hop

                        if (child_yang_name == "segment"):
                            if (self.segment is None):
                                self.segment = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment()
                                self.segment.parent = self
                                self._children_name_map["segment"] = "segment"
                            return self.segment

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "evpn-ctx" or name == "next-hop" or name == "segment" or name == "address" or name == "bmac-configured" or name == "bridge-domain-name" or name == "bridge-id" or name == "flag-extension" or name == "group-name" or name == "l3-encapsulationvlan-id" or name == "name" or name == "next-hop-valid" or name == "node-id" or name == "pbb-bmac" or name == "peer-vtep-ip" or name == "platform-is-hw-learn" or name == "vni" or name == "vni-l3-flag"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "bmac-configured"):
                            self.bmac_configured = value
                            self.bmac_configured.value_namespace = name_space
                            self.bmac_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-name"):
                            self.bridge_domain_name = value
                            self.bridge_domain_name.value_namespace = name_space
                            self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-id"):
                            self.bridge_id = value
                            self.bridge_id.value_namespace = name_space
                            self.bridge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "flag-extension"):
                            self.flag_extension = value
                            self.flag_extension.value_namespace = name_space
                            self.flag_extension.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "l3-encapsulationvlan-id"):
                            self.l3_encapsulationvlan_id = value
                            self.l3_encapsulationvlan_id.value_namespace = name_space
                            self.l3_encapsulationvlan_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "name"):
                            self.name = value
                            self.name.value_namespace = name_space
                            self.name.value_namespace_prefix = name_space_prefix
                        if(value_path == "next-hop-valid"):
                            self.next_hop_valid = value
                            self.next_hop_valid.value_namespace = name_space
                            self.next_hop_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-id"):
                            self.node_id = value
                            self.node_id.value_namespace = name_space
                            self.node_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "pbb-bmac"):
                            self.pbb_bmac = value
                            self.pbb_bmac.value_namespace = name_space
                            self.pbb_bmac.value_namespace_prefix = name_space_prefix
                        if(value_path == "peer-vtep-ip"):
                            self.peer_vtep_ip = value
                            self.peer_vtep_ip.value_namespace = name_space
                            self.peer_vtep_ip.value_namespace_prefix = name_space_prefix
                        if(value_path == "platform-is-hw-learn"):
                            self.platform_is_hw_learn = value
                            self.platform_is_hw_learn.value_namespace = name_space
                            self.platform_is_hw_learn.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni"):
                            self.vni = value
                            self.vni.value_namespace = name_space
                            self.vni.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni-l3-flag"):
                            self.vni_l3_flag = value
                            self.vni_l3_flag.value_namespace = name_space
                            self.vni_l3_flag.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fibmac_detail:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fibmac_detail:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fibmac-details" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fibmac-detail"):
                        for c in self.l2fibmac_detail:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fibmac_detail.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fibmac-detail"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibBridgeDomainNames(Entity):
                """
                Bridge Domain forwarding detail
                
                .. attribute:: l2fib_bridge_domain_name
                
                	Specify Bridge Domain Name
                	**type**\: list of    :py:class:`L2FibBridgeDomainName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames.L2FibBridgeDomainName>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames, self).__init__()

                    self.yang_name = "l2fib-bridge-domain-names"
                    self.yang_parent_name = "node"

                    self.l2fib_bridge_domain_name = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames, self).__setattr__(name, value)


                class L2FibBridgeDomainName(Entity):
                    """
                    Specify Bridge Domain Name
                    
                    .. attribute:: admin_disabled
                    
                    	Is administratively disabled
                    	**type**\:  bool
                    
                    .. attribute:: aging_time_out
                    
                    	Aging timeout
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_group_name
                    
                    	Name of the Bridge group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_name
                    
                    	Bridge name
                    	**type**\:  str
                    
                    .. attribute:: bridge_port_count
                    
                    	Number of bridge ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: flood_disabled
                    
                    	Is flooding disabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_learning_disabled
                    
                    	Is MAC learning disabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_limit
                    
                    	MAC limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_limit_action
                    
                    	MAC limit action
                    	**type**\:   :py:class:`MgmtL2FibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitAction>`
                    
                    .. attribute:: mac_port_down_flush_disabled
                    
                    	Is MAC port down flush disabled
                    	**type**\:  bool
                    
                    .. attribute:: msti
                    
                    	multi\-spanning tree instance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: number_of_hwmac
                    
                    	Number of HW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_shg
                    
                    	Number of split horizon groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_swmac
                    
                    	Number of SW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames.L2FibBridgeDomainName, self).__init__()

                        self.yang_name = "l2fib-bridge-domain-name"
                        self.yang_parent_name = "l2fib-bridge-domain-names"

                        self.admin_disabled = YLeaf(YType.boolean, "admin-disabled")

                        self.aging_time_out = YLeaf(YType.uint32, "aging-time-out")

                        self.bd_group_name = YLeaf(YType.str, "bd-group-name")

                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                        self.bridge_name = YLeaf(YType.str, "bridge-name")

                        self.bridge_port_count = YLeaf(YType.uint32, "bridge-port-count")

                        self.flood_disabled = YLeaf(YType.boolean, "flood-disabled")

                        self.mac_learning_disabled = YLeaf(YType.boolean, "mac-learning-disabled")

                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                        self.mac_port_down_flush_disabled = YLeaf(YType.boolean, "mac-port-down-flush-disabled")

                        self.msti = YLeaf(YType.uint32, "msti")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.name = YLeaf(YType.str, "name")

                        self.number_of_hwmac = YLeaf(YType.uint32, "number-of-hwmac")

                        self.number_of_shg = YLeaf(YType.uint32, "number-of-shg")

                        self.number_of_swmac = YLeaf(YType.uint32, "number-of-swmac")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("admin_disabled",
                                        "aging_time_out",
                                        "bd_group_name",
                                        "bridge_id",
                                        "bridge_name",
                                        "bridge_port_count",
                                        "flood_disabled",
                                        "mac_learning_disabled",
                                        "mac_limit",
                                        "mac_limit_action",
                                        "mac_port_down_flush_disabled",
                                        "msti",
                                        "mtu",
                                        "name",
                                        "number_of_hwmac",
                                        "number_of_shg",
                                        "number_of_swmac") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames.L2FibBridgeDomainName, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames.L2FibBridgeDomainName, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.admin_disabled.is_set or
                            self.aging_time_out.is_set or
                            self.bd_group_name.is_set or
                            self.bridge_id.is_set or
                            self.bridge_name.is_set or
                            self.bridge_port_count.is_set or
                            self.flood_disabled.is_set or
                            self.mac_learning_disabled.is_set or
                            self.mac_limit.is_set or
                            self.mac_limit_action.is_set or
                            self.mac_port_down_flush_disabled.is_set or
                            self.msti.is_set or
                            self.mtu.is_set or
                            self.name.is_set or
                            self.number_of_hwmac.is_set or
                            self.number_of_shg.is_set or
                            self.number_of_swmac.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.admin_disabled.yfilter != YFilter.not_set or
                            self.aging_time_out.yfilter != YFilter.not_set or
                            self.bd_group_name.yfilter != YFilter.not_set or
                            self.bridge_id.yfilter != YFilter.not_set or
                            self.bridge_name.yfilter != YFilter.not_set or
                            self.bridge_port_count.yfilter != YFilter.not_set or
                            self.flood_disabled.yfilter != YFilter.not_set or
                            self.mac_learning_disabled.yfilter != YFilter.not_set or
                            self.mac_limit.yfilter != YFilter.not_set or
                            self.mac_limit_action.yfilter != YFilter.not_set or
                            self.mac_port_down_flush_disabled.yfilter != YFilter.not_set or
                            self.msti.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.name.yfilter != YFilter.not_set or
                            self.number_of_hwmac.yfilter != YFilter.not_set or
                            self.number_of_shg.yfilter != YFilter.not_set or
                            self.number_of_swmac.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-bridge-domain-name" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.admin_disabled.is_set or self.admin_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.admin_disabled.get_name_leafdata())
                        if (self.aging_time_out.is_set or self.aging_time_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.aging_time_out.get_name_leafdata())
                        if (self.bd_group_name.is_set or self.bd_group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_group_name.get_name_leafdata())
                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                        if (self.bridge_name.is_set or self.bridge_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_name.get_name_leafdata())
                        if (self.bridge_port_count.is_set or self.bridge_port_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_port_count.get_name_leafdata())
                        if (self.flood_disabled.is_set or self.flood_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flood_disabled.get_name_leafdata())
                        if (self.mac_learning_disabled.is_set or self.mac_learning_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_learning_disabled.get_name_leafdata())
                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                        if (self.mac_port_down_flush_disabled.is_set or self.mac_port_down_flush_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_port_down_flush_disabled.get_name_leafdata())
                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.name.get_name_leafdata())
                        if (self.number_of_hwmac.is_set or self.number_of_hwmac.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_hwmac.get_name_leafdata())
                        if (self.number_of_shg.is_set or self.number_of_shg.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_shg.get_name_leafdata())
                        if (self.number_of_swmac.is_set or self.number_of_swmac.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_swmac.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "admin-disabled" or name == "aging-time-out" or name == "bd-group-name" or name == "bridge-id" or name == "bridge-name" or name == "bridge-port-count" or name == "flood-disabled" or name == "mac-learning-disabled" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-port-down-flush-disabled" or name == "msti" or name == "mtu" or name == "name" or name == "number-of-hwmac" or name == "number-of-shg" or name == "number-of-swmac"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "admin-disabled"):
                            self.admin_disabled = value
                            self.admin_disabled.value_namespace = name_space
                            self.admin_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "aging-time-out"):
                            self.aging_time_out = value
                            self.aging_time_out.value_namespace = name_space
                            self.aging_time_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-group-name"):
                            self.bd_group_name = value
                            self.bd_group_name.value_namespace = name_space
                            self.bd_group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-id"):
                            self.bridge_id = value
                            self.bridge_id.value_namespace = name_space
                            self.bridge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-name"):
                            self.bridge_name = value
                            self.bridge_name.value_namespace = name_space
                            self.bridge_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-port-count"):
                            self.bridge_port_count = value
                            self.bridge_port_count.value_namespace = name_space
                            self.bridge_port_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "flood-disabled"):
                            self.flood_disabled = value
                            self.flood_disabled.value_namespace = name_space
                            self.flood_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-learning-disabled"):
                            self.mac_learning_disabled = value
                            self.mac_learning_disabled.value_namespace = name_space
                            self.mac_learning_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit"):
                            self.mac_limit = value
                            self.mac_limit.value_namespace = name_space
                            self.mac_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-action"):
                            self.mac_limit_action = value
                            self.mac_limit_action.value_namespace = name_space
                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-port-down-flush-disabled"):
                            self.mac_port_down_flush_disabled = value
                            self.mac_port_down_flush_disabled.value_namespace = name_space
                            self.mac_port_down_flush_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti"):
                            self.msti = value
                            self.msti.value_namespace = name_space
                            self.msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "name"):
                            self.name = value
                            self.name.value_namespace = name_space
                            self.name.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-hwmac"):
                            self.number_of_hwmac = value
                            self.number_of_hwmac.value_namespace = name_space
                            self.number_of_hwmac.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-shg"):
                            self.number_of_shg = value
                            self.number_of_shg.value_namespace = name_space
                            self.number_of_shg.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-swmac"):
                            self.number_of_swmac = value
                            self.number_of_swmac.value_namespace = name_space
                            self.number_of_swmac.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_bridge_domain_name:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_bridge_domain_name:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-bridge-domain-names" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-bridge-domain-name"):
                        for c in self.l2fib_bridge_domain_name:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames.L2FibBridgeDomainName()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_bridge_domain_name.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-bridge-domain-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMroutePorts(Entity):
                """
                multicast bridge port information 
                
                .. attribute:: l2fib_mroute_port
                
                	Multicast Port Information
                	**type**\: list of    :py:class:`L2FibMroutePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts, self).__init__()

                    self.yang_name = "l2fib-mroute-ports"
                    self.yang_parent_name = "node"

                    self.l2fib_mroute_port = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts, self).__setattr__(name, value)


                class L2FibMroutePort(Entity):
                    """
                    Multicast Port Information
                    
                    .. attribute:: ac_interface_handle
                    
                    	AC If handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: base_information
                    
                    	Base Information
                    	**type**\:   :py:class:`BaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.BaseInformation>`
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_id
                    
                    	Bridge Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: csfl
                    
                    	Csfl Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:   :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:   :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats>`
                    
                    .. attribute:: group
                    
                    	Group IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_ole_master
                    
                    	Ole Master
                    	**type**\:  bool
                    
                    .. attribute:: is_ole_offloaded
                    
                    	Ole Offloaded
                    	**type**\:  bool
                    
                    .. attribute:: is_topo_hub_and_spoke
                    
                    	Topo HubAndSpoke
                    	**type**\:  bool
                    
                    .. attribute:: isid
                    
                    	Isid Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: leaf_pointer
                    
                    	Leaf Ptr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: next_hop_address
                    
                    	NHOP IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pw_id
                    
                    	PW ID
                    	**type**\:  str
                    
                    	**length:** 0..40
                    
                    .. attribute:: sat_id
                    
                    	Sat Id
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: source
                    
                    	Source IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:   :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.SourcePrefix>`
                    
                    .. attribute:: xcid
                    
                    	XConnect ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort, self).__init__()

                        self.yang_name = "l2fib-mroute-port"
                        self.yang_parent_name = "l2fib-mroute-ports"

                        self.ac_interface_handle = YLeaf(YType.str, "ac-interface-handle")

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                        self.csfl = YLeaf(YType.uint32, "csfl")

                        self.group = YLeaf(YType.str, "group")

                        self.is_ole_master = YLeaf(YType.boolean, "is-ole-master")

                        self.is_ole_offloaded = YLeaf(YType.boolean, "is-ole-offloaded")

                        self.is_topo_hub_and_spoke = YLeaf(YType.boolean, "is-topo-hub-and-spoke")

                        self.isid = YLeaf(YType.uint32, "isid")

                        self.leaf_pointer = YLeaf(YType.uint32, "leaf-pointer")

                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                        self.pw_id = YLeaf(YType.str, "pw-id")

                        self.sat_id = YLeaf(YType.uint16, "sat-id")

                        self.source = YLeaf(YType.str, "source")

                        self.xcid = YLeaf(YType.str, "xcid")

                        self.base_information = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.BaseInformation()
                        self.base_information.parent = self
                        self._children_name_map["base_information"] = "base-information"
                        self._children_yang_names.add("base-information")

                        self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self._children_name_map["destination_prefix"] = "destination-prefix"
                        self._children_yang_names.add("destination-prefix")

                        self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats()
                        self.forward_stats.parent = self
                        self._children_name_map["forward_stats"] = "forward-stats"
                        self._children_yang_names.add("forward-stats")

                        self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.SourcePrefix()
                        self.source_prefix.parent = self
                        self._children_name_map["source_prefix"] = "source-prefix"
                        self._children_yang_names.add("source-prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ac_interface_handle",
                                        "bd_name",
                                        "bridge_id",
                                        "csfl",
                                        "group",
                                        "is_ole_master",
                                        "is_ole_offloaded",
                                        "is_topo_hub_and_spoke",
                                        "isid",
                                        "leaf_pointer",
                                        "next_hop_address",
                                        "pw_id",
                                        "sat_id",
                                        "source",
                                        "xcid") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort, self).__setattr__(name, value)


                    class BaseInformation(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.BaseInformation, self).__init__()

                            self.yang_name = "base-information"
                            self.yang_parent_name = "l2fib-mroute-port"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class ForwardStats(Entity):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:   :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats, self).__init__()

                            self.yang_name = "forward-stats"
                            self.yang_parent_name = "l2fib-mroute-port"

                            self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self
                            self._children_name_map["forward_stat"] = "forward-stat"
                            self._children_yang_names.add("forward-stat")


                        class ForwardStat(Entity):
                            """
                            fwd stats
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:   :py:class:`MgmtL2FibStatsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibStatsData>`
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:   :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat, self).__init__()

                                self.yang_name = "forward-stat"
                                self.yang_parent_name = "forward-stats"

                                self.data_type = YLeaf(YType.enumeration, "data-type")

                                self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self
                                self._children_name_map["mulicast"] = "mulicast"
                                self._children_yang_names.add("mulicast")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("data_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat, self).__setattr__(name, value)


                            class Mulicast(Entity):
                                """
                                mulicast
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:   :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:   :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:   :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:   :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:   :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:   :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast, self).__init__()

                                    self.yang_name = "mulicast"
                                    self.yang_parent_name = "forward-stat"

                                    self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self._children_name_map["core_received_stat"] = "core-received-stat"
                                    self._children_yang_names.add("core-received-stat")

                                    self.drop = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self._children_name_map["drop"] = "drop"
                                    self._children_yang_names.add("drop")

                                    self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"
                                    self._children_yang_names.add("multicast-core-forward-stat")

                                    self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"
                                    self._children_yang_names.add("multicast-forward-stat")

                                    self.punt = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self._children_name_map["punt"] = "punt"
                                    self._children_yang_names.add("punt")

                                    self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self
                                    self._children_name_map["received_stat"] = "received-stat"
                                    self._children_yang_names.add("received-stat")


                                class MulticastForwardStat(Entity):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__init__()

                                        self.yang_name = "multicast-forward-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-forward-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class ReceivedStat(Entity):
                                    """
                                    received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__init__()

                                        self.yang_name = "received-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class Punt(Entity):
                                    """
                                    punted stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt, self).__init__()

                                        self.yang_name = "punt"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "punt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class Drop(Entity):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop, self).__init__()

                                        self.yang_name = "drop"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class MulticastCoreForwardStat(Entity):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__init__()

                                        self.yang_name = "multicast-core-forward-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-core-forward-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class CoreReceivedStat(Entity):
                                    """
                                    core received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__init__()

                                        self.yang_name = "core-received-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "core-received-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.core_received_stat is not None and self.core_received_stat.has_data()) or
                                        (self.drop is not None and self.drop.has_data()) or
                                        (self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat.has_data()) or
                                        (self.multicast_forward_stat is not None and self.multicast_forward_stat.has_data()) or
                                        (self.punt is not None and self.punt.has_data()) or
                                        (self.received_stat is not None and self.received_stat.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.core_received_stat is not None and self.core_received_stat.has_operation()) or
                                        (self.drop is not None and self.drop.has_operation()) or
                                        (self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat.has_operation()) or
                                        (self.multicast_forward_stat is not None and self.multicast_forward_stat.has_operation()) or
                                        (self.punt is not None and self.punt.has_operation()) or
                                        (self.received_stat is not None and self.received_stat.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mulicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "core-received-stat"):
                                        if (self.core_received_stat is None):
                                            self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                            self.core_received_stat.parent = self
                                            self._children_name_map["core_received_stat"] = "core-received-stat"
                                        return self.core_received_stat

                                    if (child_yang_name == "drop"):
                                        if (self.drop is None):
                                            self.drop = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop()
                                            self.drop.parent = self
                                            self._children_name_map["drop"] = "drop"
                                        return self.drop

                                    if (child_yang_name == "multicast-core-forward-stat"):
                                        if (self.multicast_core_forward_stat is None):
                                            self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                            self.multicast_core_forward_stat.parent = self
                                            self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"
                                        return self.multicast_core_forward_stat

                                    if (child_yang_name == "multicast-forward-stat"):
                                        if (self.multicast_forward_stat is None):
                                            self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                            self.multicast_forward_stat.parent = self
                                            self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"
                                        return self.multicast_forward_stat

                                    if (child_yang_name == "punt"):
                                        if (self.punt is None):
                                            self.punt = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt()
                                            self.punt.parent = self
                                            self._children_name_map["punt"] = "punt"
                                        return self.punt

                                    if (child_yang_name == "received-stat"):
                                        if (self.received_stat is None):
                                            self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                            self.received_stat.parent = self
                                            self._children_name_map["received_stat"] = "received-stat"
                                        return self.received_stat

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "core-received-stat" or name == "drop" or name == "multicast-core-forward-stat" or name == "multicast-forward-stat" or name == "punt" or name == "received-stat"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.data_type.is_set or
                                    (self.mulicast is not None and self.mulicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.data_type.yfilter != YFilter.not_set or
                                    (self.mulicast is not None and self.mulicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "forward-stat" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.data_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mulicast"):
                                    if (self.mulicast is None):
                                        self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast()
                                        self.mulicast.parent = self
                                        self._children_name_map["mulicast"] = "mulicast"
                                    return self.mulicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mulicast" or name == "data-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "data-type"):
                                    self.data_type = value
                                    self.data_type.value_namespace = name_space
                                    self.data_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.forward_stat is not None and self.forward_stat.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.forward_stat is not None and self.forward_stat.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "forward-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "forward-stat"):
                                if (self.forward_stat is None):
                                    self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat()
                                    self.forward_stat.parent = self
                                    self._children_name_map["forward_stat"] = "forward-stat"
                                return self.forward_stat

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "forward-stat"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SourcePrefix(Entity):
                        """
                        Source Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.SourcePrefix, self).__init__()

                            self.yang_name = "source-prefix"
                            self.yang_parent_name = "l2fib-mroute-port"

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                            self.proto = YLeaf(YType.uint8, "proto")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix",
                                            "prefix_length",
                                            "proto") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.SourcePrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.SourcePrefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.proto.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proto.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proto.is_set or self.proto.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proto.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "prefix-length" or name == "proto"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proto"):
                                self.proto = value
                                self.proto.value_namespace = name_space
                                self.proto.value_namespace_prefix = name_space_prefix


                    class DestinationPrefix(Entity):
                        """
                        Destination Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.DestinationPrefix, self).__init__()

                            self.yang_name = "destination-prefix"
                            self.yang_parent_name = "l2fib-mroute-port"

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                            self.proto = YLeaf(YType.uint8, "proto")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix",
                                            "prefix_length",
                                            "proto") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.DestinationPrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.DestinationPrefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.proto.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proto.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "destination-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proto.is_set or self.proto.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proto.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "prefix-length" or name == "proto"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proto"):
                                self.proto = value
                                self.proto.value_namespace = name_space
                                self.proto.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ac_interface_handle.is_set or
                            self.bd_name.is_set or
                            self.bridge_id.is_set or
                            self.csfl.is_set or
                            self.group.is_set or
                            self.is_ole_master.is_set or
                            self.is_ole_offloaded.is_set or
                            self.is_topo_hub_and_spoke.is_set or
                            self.isid.is_set or
                            self.leaf_pointer.is_set or
                            self.next_hop_address.is_set or
                            self.pw_id.is_set or
                            self.sat_id.is_set or
                            self.source.is_set or
                            self.xcid.is_set or
                            (self.base_information is not None and self.base_information.has_data()) or
                            (self.destination_prefix is not None and self.destination_prefix.has_data()) or
                            (self.forward_stats is not None and self.forward_stats.has_data()) or
                            (self.source_prefix is not None and self.source_prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ac_interface_handle.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            self.bridge_id.yfilter != YFilter.not_set or
                            self.csfl.yfilter != YFilter.not_set or
                            self.group.yfilter != YFilter.not_set or
                            self.is_ole_master.yfilter != YFilter.not_set or
                            self.is_ole_offloaded.yfilter != YFilter.not_set or
                            self.is_topo_hub_and_spoke.yfilter != YFilter.not_set or
                            self.isid.yfilter != YFilter.not_set or
                            self.leaf_pointer.yfilter != YFilter.not_set or
                            self.next_hop_address.yfilter != YFilter.not_set or
                            self.pw_id.yfilter != YFilter.not_set or
                            self.sat_id.yfilter != YFilter.not_set or
                            self.source.yfilter != YFilter.not_set or
                            self.xcid.yfilter != YFilter.not_set or
                            (self.base_information is not None and self.base_information.has_operation()) or
                            (self.destination_prefix is not None and self.destination_prefix.has_operation()) or
                            (self.forward_stats is not None and self.forward_stats.has_operation()) or
                            (self.source_prefix is not None and self.source_prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mroute-port" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ac_interface_handle.is_set or self.ac_interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_interface_handle.get_name_leafdata())
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())
                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                        if (self.csfl.is_set or self.csfl.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.csfl.get_name_leafdata())
                        if (self.group.is_set or self.group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group.get_name_leafdata())
                        if (self.is_ole_master.is_set or self.is_ole_master.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ole_master.get_name_leafdata())
                        if (self.is_ole_offloaded.is_set or self.is_ole_offloaded.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ole_offloaded.get_name_leafdata())
                        if (self.is_topo_hub_and_spoke.is_set or self.is_topo_hub_and_spoke.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_topo_hub_and_spoke.get_name_leafdata())
                        if (self.isid.is_set or self.isid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.isid.get_name_leafdata())
                        if (self.leaf_pointer.is_set or self.leaf_pointer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.leaf_pointer.get_name_leafdata())
                        if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                        if (self.sat_id.is_set or self.sat_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sat_id.get_name_leafdata())
                        if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source.get_name_leafdata())
                        if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xcid.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base-information"):
                            if (self.base_information is None):
                                self.base_information = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.BaseInformation()
                                self.base_information.parent = self
                                self._children_name_map["base_information"] = "base-information"
                            return self.base_information

                        if (child_yang_name == "destination-prefix"):
                            if (self.destination_prefix is None):
                                self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.DestinationPrefix()
                                self.destination_prefix.parent = self
                                self._children_name_map["destination_prefix"] = "destination-prefix"
                            return self.destination_prefix

                        if (child_yang_name == "forward-stats"):
                            if (self.forward_stats is None):
                                self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats()
                                self.forward_stats.parent = self
                                self._children_name_map["forward_stats"] = "forward-stats"
                            return self.forward_stats

                        if (child_yang_name == "source-prefix"):
                            if (self.source_prefix is None):
                                self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.SourcePrefix()
                                self.source_prefix.parent = self
                                self._children_name_map["source_prefix"] = "source-prefix"
                            return self.source_prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base-information" or name == "destination-prefix" or name == "forward-stats" or name == "source-prefix" or name == "ac-interface-handle" or name == "bd-name" or name == "bridge-id" or name == "csfl" or name == "group" or name == "is-ole-master" or name == "is-ole-offloaded" or name == "is-topo-hub-and-spoke" or name == "isid" or name == "leaf-pointer" or name == "next-hop-address" or name == "pw-id" or name == "sat-id" or name == "source" or name == "xcid"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ac-interface-handle"):
                            self.ac_interface_handle = value
                            self.ac_interface_handle.value_namespace = name_space
                            self.ac_interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-id"):
                            self.bridge_id = value
                            self.bridge_id.value_namespace = name_space
                            self.bridge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "csfl"):
                            self.csfl = value
                            self.csfl.value_namespace = name_space
                            self.csfl.value_namespace_prefix = name_space_prefix
                        if(value_path == "group"):
                            self.group = value
                            self.group.value_namespace = name_space
                            self.group.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ole-master"):
                            self.is_ole_master = value
                            self.is_ole_master.value_namespace = name_space
                            self.is_ole_master.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ole-offloaded"):
                            self.is_ole_offloaded = value
                            self.is_ole_offloaded.value_namespace = name_space
                            self.is_ole_offloaded.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-topo-hub-and-spoke"):
                            self.is_topo_hub_and_spoke = value
                            self.is_topo_hub_and_spoke.value_namespace = name_space
                            self.is_topo_hub_and_spoke.value_namespace_prefix = name_space_prefix
                        if(value_path == "isid"):
                            self.isid = value
                            self.isid.value_namespace = name_space
                            self.isid.value_namespace_prefix = name_space_prefix
                        if(value_path == "leaf-pointer"):
                            self.leaf_pointer = value
                            self.leaf_pointer.value_namespace = name_space
                            self.leaf_pointer.value_namespace_prefix = name_space_prefix
                        if(value_path == "next-hop-address"):
                            self.next_hop_address = value
                            self.next_hop_address.value_namespace = name_space
                            self.next_hop_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-id"):
                            self.pw_id = value
                            self.pw_id.value_namespace = name_space
                            self.pw_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "sat-id"):
                            self.sat_id = value
                            self.sat_id.value_namespace = name_space
                            self.sat_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "source"):
                            self.source = value
                            self.source.value_namespace = name_space
                            self.source.value_namespace_prefix = name_space_prefix
                        if(value_path == "xcid"):
                            self.xcid = value
                            self.xcid.value_namespace = name_space
                            self.xcid.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_mroute_port:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_mroute_port:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-mroute-ports" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-mroute-port"):
                        for c in self.l2fib_mroute_port:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_mroute_port.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-mroute-port"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibSummary(Entity):
                """
                L2FIB Summary information
                
                .. attribute:: bridge_domain_summary
                
                	Bridge\-domain summary info
                	**type**\:   :py:class:`BridgeDomainSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.BridgeDomainSummary>`
                
                .. attribute:: evpn_summary
                
                	evpn summary info
                	**type**\:   :py:class:`EvpnSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.EvpnSummary>`
                
                .. attribute:: global_cfg
                
                	Global configuration
                	**type**\:   :py:class:`GlobalCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg>`
                
                .. attribute:: l2tp_disposition_summary
                
                	L2TP disposition object summary
                	**type**\:   :py:class:`L2TpDispositionSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.L2TpDispositionSummary>`
                
                .. attribute:: mac_summary
                
                	mac summary info
                	**type**\:   :py:class:`MacSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.MacSummary>`
                
                .. attribute:: next_hop_summary
                
                	nhop db summry info
                	**type**\:   :py:class:`NextHopSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary>`
                
                .. attribute:: ptree_summary
                
                	P2MP PTree summary info
                	**type**\:   :py:class:`PtreeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.PtreeSummary>`
                
                .. attribute:: pw_group_summary
                
                	PWGroup summary info
                	**type**\:   :py:class:`PwGroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.PwGroupSummary>`
                
                .. attribute:: pwhe_mp_summary
                
                	PWHE Main\-port summary info
                	**type**\:   :py:class:`PwheMpSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.PwheMpSummary>`
                
                .. attribute:: queue_summary
                
                	queue summary info
                	**type**\:   :py:class:`QueueSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.QueueSummary>`
                
                .. attribute:: xconnect_summary
                
                	xconnect db summary info
                	**type**\:   :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.XconnectSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibSummary, self).__init__()

                    self.yang_name = "l2fib-summary"
                    self.yang_parent_name = "node"

                    self.bridge_domain_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.BridgeDomainSummary()
                    self.bridge_domain_summary.parent = self
                    self._children_name_map["bridge_domain_summary"] = "bridge-domain-summary"
                    self._children_yang_names.add("bridge-domain-summary")

                    self.evpn_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.EvpnSummary()
                    self.evpn_summary.parent = self
                    self._children_name_map["evpn_summary"] = "evpn-summary"
                    self._children_yang_names.add("evpn-summary")

                    self.global_cfg = L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg()
                    self.global_cfg.parent = self
                    self._children_name_map["global_cfg"] = "global-cfg"
                    self._children_yang_names.add("global-cfg")

                    self.l2tp_disposition_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.L2TpDispositionSummary()
                    self.l2tp_disposition_summary.parent = self
                    self._children_name_map["l2tp_disposition_summary"] = "l2tp-disposition-summary"
                    self._children_yang_names.add("l2tp-disposition-summary")

                    self.mac_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.MacSummary()
                    self.mac_summary.parent = self
                    self._children_name_map["mac_summary"] = "mac-summary"
                    self._children_yang_names.add("mac-summary")

                    self.next_hop_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary()
                    self.next_hop_summary.parent = self
                    self._children_name_map["next_hop_summary"] = "next-hop-summary"
                    self._children_yang_names.add("next-hop-summary")

                    self.ptree_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.PtreeSummary()
                    self.ptree_summary.parent = self
                    self._children_name_map["ptree_summary"] = "ptree-summary"
                    self._children_yang_names.add("ptree-summary")

                    self.pw_group_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.PwGroupSummary()
                    self.pw_group_summary.parent = self
                    self._children_name_map["pw_group_summary"] = "pw-group-summary"
                    self._children_yang_names.add("pw-group-summary")

                    self.pwhe_mp_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.PwheMpSummary()
                    self.pwhe_mp_summary.parent = self
                    self._children_name_map["pwhe_mp_summary"] = "pwhe-mp-summary"
                    self._children_yang_names.add("pwhe-mp-summary")

                    self.queue_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.QueueSummary()
                    self.queue_summary.parent = self
                    self._children_name_map["queue_summary"] = "queue-summary"
                    self._children_yang_names.add("queue-summary")

                    self.xconnect_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.XconnectSummary()
                    self.xconnect_summary.parent = self
                    self._children_name_map["xconnect_summary"] = "xconnect-summary"
                    self._children_yang_names.add("xconnect-summary")


                class XconnectSummary(Entity):
                    """
                    xconnect db summary info
                    
                    .. attribute:: ac_down_count_aib
                    
                    	number of down acs with reason aib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_down_count_l2vpn
                    
                    	number of down acs with reason l2vpn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_down_count_l3fib
                    
                    	number of down acs with reason fib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_down_count_vpdn
                    
                    	number of down acs with reason vpdn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_ac_count
                    
                    	number of ac\->ac entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_bp_count
                    
                    	number of ac\->bp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_l2tp
                    
                    	number of ac\->pw\-l2tp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_l2tp_ip_v6
                    
                    	number of ac\->pw\-l2tp\-ipv6 entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_l2tpv2
                    
                    	number of ac\->pw\-l2tpv2 entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_mpls
                    
                    	number of ac\->pw\-mpls entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_unknown_count
                    
                    	number of ac\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bp_count
                    
                    	number of bridge\-port xconnects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle_ac_max_exceeded_drop_cnt
                    
                    	number of xc updates dropped due to max Bundle ACs exceeded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to EVPN invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_to_bp_count
                    
                    	number of evpn\->bp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_to_unknown_count
                    
                    	number of evpn\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mon_sess_to_pw_count
                    
                    	number of monitor\_session\->pw entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mon_sess_to_unknown_count
                    
                    	number of monitor\_session\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2p_count
                    
                    	number of p2p xconnects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to PBB invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_to_bp_count
                    
                    	number of pbb\->bp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_to_unknown_count
                    
                    	number of pbb\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_to_bp_count
                    
                    	number of pw\->bp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_to_unknown_count
                    
                    	number of pw\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pwhe_l2_if_count
                    
                    	number of PWHE L2IF xconnects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_ac_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to Virtual AC invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to VNI invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_to_bp_count
                    
                    	number of vni\->bp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_to_unknown_count
                    
                    	number of vni\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpls_pw_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to VPLS PW invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpls_pw_max_exceeded_drop_cnt
                    
                    	number of xc updates dropped due to max VPLS PWs exceeded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpws_pw_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to VPWS PW invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect_count
                    
                    	total number of entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect_down_count
                    
                    	number of down entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect_up_count
                    
                    	number of up entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.XconnectSummary, self).__init__()

                        self.yang_name = "xconnect-summary"
                        self.yang_parent_name = "l2fib-summary"

                        self.ac_down_count_aib = YLeaf(YType.uint32, "ac-down-count-aib")

                        self.ac_down_count_l2vpn = YLeaf(YType.uint32, "ac-down-count-l2vpn")

                        self.ac_down_count_l3fib = YLeaf(YType.uint32, "ac-down-count-l3fib")

                        self.ac_down_count_vpdn = YLeaf(YType.uint32, "ac-down-count-vpdn")

                        self.ac_to_ac_count = YLeaf(YType.uint32, "ac-to-ac-count")

                        self.ac_to_bp_count = YLeaf(YType.uint32, "ac-to-bp-count")

                        self.ac_to_pw_count_l2tp = YLeaf(YType.uint32, "ac-to-pw-count-l2tp")

                        self.ac_to_pw_count_l2tp_ip_v6 = YLeaf(YType.uint32, "ac-to-pw-count-l2tp-ip-v6")

                        self.ac_to_pw_count_l2tpv2 = YLeaf(YType.uint32, "ac-to-pw-count-l2tpv2")

                        self.ac_to_pw_count_mpls = YLeaf(YType.uint32, "ac-to-pw-count-mpls")

                        self.ac_to_unknown_count = YLeaf(YType.uint32, "ac-to-unknown-count")

                        self.bp_count = YLeaf(YType.uint32, "bp-count")

                        self.bundle_ac_max_exceeded_drop_cnt = YLeaf(YType.uint32, "bundle-ac-max-exceeded-drop-cnt")

                        self.evpn_invalid_xid_drop_count = YLeaf(YType.uint32, "evpn-invalid-xid-drop-count")

                        self.evpn_to_bp_count = YLeaf(YType.uint32, "evpn-to-bp-count")

                        self.evpn_to_unknown_count = YLeaf(YType.uint32, "evpn-to-unknown-count")

                        self.mon_sess_to_pw_count = YLeaf(YType.uint32, "mon-sess-to-pw-count")

                        self.mon_sess_to_unknown_count = YLeaf(YType.uint32, "mon-sess-to-unknown-count")

                        self.p2p_count = YLeaf(YType.uint32, "p2p-count")

                        self.pbb_invalid_xid_drop_count = YLeaf(YType.uint32, "pbb-invalid-xid-drop-count")

                        self.pbb_to_bp_count = YLeaf(YType.uint32, "pbb-to-bp-count")

                        self.pbb_to_unknown_count = YLeaf(YType.uint32, "pbb-to-unknown-count")

                        self.pw_to_bp_count = YLeaf(YType.uint32, "pw-to-bp-count")

                        self.pw_to_unknown_count = YLeaf(YType.uint32, "pw-to-unknown-count")

                        self.pwhe_l2_if_count = YLeaf(YType.uint32, "pwhe-l2-if-count")

                        self.virtual_ac_invalid_xid_drop_count = YLeaf(YType.uint32, "virtual-ac-invalid-xid-drop-count")

                        self.vni_invalid_xid_drop_count = YLeaf(YType.uint32, "vni-invalid-xid-drop-count")

                        self.vni_to_bp_count = YLeaf(YType.uint32, "vni-to-bp-count")

                        self.vni_to_unknown_count = YLeaf(YType.uint32, "vni-to-unknown-count")

                        self.vpls_pw_invalid_xid_drop_count = YLeaf(YType.uint32, "vpls-pw-invalid-xid-drop-count")

                        self.vpls_pw_max_exceeded_drop_cnt = YLeaf(YType.uint32, "vpls-pw-max-exceeded-drop-cnt")

                        self.vpws_pw_invalid_xid_drop_count = YLeaf(YType.uint32, "vpws-pw-invalid-xid-drop-count")

                        self.xconnect_count = YLeaf(YType.uint32, "xconnect-count")

                        self.xconnect_down_count = YLeaf(YType.uint32, "xconnect-down-count")

                        self.xconnect_up_count = YLeaf(YType.uint32, "xconnect-up-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ac_down_count_aib",
                                        "ac_down_count_l2vpn",
                                        "ac_down_count_l3fib",
                                        "ac_down_count_vpdn",
                                        "ac_to_ac_count",
                                        "ac_to_bp_count",
                                        "ac_to_pw_count_l2tp",
                                        "ac_to_pw_count_l2tp_ip_v6",
                                        "ac_to_pw_count_l2tpv2",
                                        "ac_to_pw_count_mpls",
                                        "ac_to_unknown_count",
                                        "bp_count",
                                        "bundle_ac_max_exceeded_drop_cnt",
                                        "evpn_invalid_xid_drop_count",
                                        "evpn_to_bp_count",
                                        "evpn_to_unknown_count",
                                        "mon_sess_to_pw_count",
                                        "mon_sess_to_unknown_count",
                                        "p2p_count",
                                        "pbb_invalid_xid_drop_count",
                                        "pbb_to_bp_count",
                                        "pbb_to_unknown_count",
                                        "pw_to_bp_count",
                                        "pw_to_unknown_count",
                                        "pwhe_l2_if_count",
                                        "virtual_ac_invalid_xid_drop_count",
                                        "vni_invalid_xid_drop_count",
                                        "vni_to_bp_count",
                                        "vni_to_unknown_count",
                                        "vpls_pw_invalid_xid_drop_count",
                                        "vpls_pw_max_exceeded_drop_cnt",
                                        "vpws_pw_invalid_xid_drop_count",
                                        "xconnect_count",
                                        "xconnect_down_count",
                                        "xconnect_up_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.XconnectSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibSummary.XconnectSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ac_down_count_aib.is_set or
                            self.ac_down_count_l2vpn.is_set or
                            self.ac_down_count_l3fib.is_set or
                            self.ac_down_count_vpdn.is_set or
                            self.ac_to_ac_count.is_set or
                            self.ac_to_bp_count.is_set or
                            self.ac_to_pw_count_l2tp.is_set or
                            self.ac_to_pw_count_l2tp_ip_v6.is_set or
                            self.ac_to_pw_count_l2tpv2.is_set or
                            self.ac_to_pw_count_mpls.is_set or
                            self.ac_to_unknown_count.is_set or
                            self.bp_count.is_set or
                            self.bundle_ac_max_exceeded_drop_cnt.is_set or
                            self.evpn_invalid_xid_drop_count.is_set or
                            self.evpn_to_bp_count.is_set or
                            self.evpn_to_unknown_count.is_set or
                            self.mon_sess_to_pw_count.is_set or
                            self.mon_sess_to_unknown_count.is_set or
                            self.p2p_count.is_set or
                            self.pbb_invalid_xid_drop_count.is_set or
                            self.pbb_to_bp_count.is_set or
                            self.pbb_to_unknown_count.is_set or
                            self.pw_to_bp_count.is_set or
                            self.pw_to_unknown_count.is_set or
                            self.pwhe_l2_if_count.is_set or
                            self.virtual_ac_invalid_xid_drop_count.is_set or
                            self.vni_invalid_xid_drop_count.is_set or
                            self.vni_to_bp_count.is_set or
                            self.vni_to_unknown_count.is_set or
                            self.vpls_pw_invalid_xid_drop_count.is_set or
                            self.vpls_pw_max_exceeded_drop_cnt.is_set or
                            self.vpws_pw_invalid_xid_drop_count.is_set or
                            self.xconnect_count.is_set or
                            self.xconnect_down_count.is_set or
                            self.xconnect_up_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ac_down_count_aib.yfilter != YFilter.not_set or
                            self.ac_down_count_l2vpn.yfilter != YFilter.not_set or
                            self.ac_down_count_l3fib.yfilter != YFilter.not_set or
                            self.ac_down_count_vpdn.yfilter != YFilter.not_set or
                            self.ac_to_ac_count.yfilter != YFilter.not_set or
                            self.ac_to_bp_count.yfilter != YFilter.not_set or
                            self.ac_to_pw_count_l2tp.yfilter != YFilter.not_set or
                            self.ac_to_pw_count_l2tp_ip_v6.yfilter != YFilter.not_set or
                            self.ac_to_pw_count_l2tpv2.yfilter != YFilter.not_set or
                            self.ac_to_pw_count_mpls.yfilter != YFilter.not_set or
                            self.ac_to_unknown_count.yfilter != YFilter.not_set or
                            self.bp_count.yfilter != YFilter.not_set or
                            self.bundle_ac_max_exceeded_drop_cnt.yfilter != YFilter.not_set or
                            self.evpn_invalid_xid_drop_count.yfilter != YFilter.not_set or
                            self.evpn_to_bp_count.yfilter != YFilter.not_set or
                            self.evpn_to_unknown_count.yfilter != YFilter.not_set or
                            self.mon_sess_to_pw_count.yfilter != YFilter.not_set or
                            self.mon_sess_to_unknown_count.yfilter != YFilter.not_set or
                            self.p2p_count.yfilter != YFilter.not_set or
                            self.pbb_invalid_xid_drop_count.yfilter != YFilter.not_set or
                            self.pbb_to_bp_count.yfilter != YFilter.not_set or
                            self.pbb_to_unknown_count.yfilter != YFilter.not_set or
                            self.pw_to_bp_count.yfilter != YFilter.not_set or
                            self.pw_to_unknown_count.yfilter != YFilter.not_set or
                            self.pwhe_l2_if_count.yfilter != YFilter.not_set or
                            self.virtual_ac_invalid_xid_drop_count.yfilter != YFilter.not_set or
                            self.vni_invalid_xid_drop_count.yfilter != YFilter.not_set or
                            self.vni_to_bp_count.yfilter != YFilter.not_set or
                            self.vni_to_unknown_count.yfilter != YFilter.not_set or
                            self.vpls_pw_invalid_xid_drop_count.yfilter != YFilter.not_set or
                            self.vpls_pw_max_exceeded_drop_cnt.yfilter != YFilter.not_set or
                            self.vpws_pw_invalid_xid_drop_count.yfilter != YFilter.not_set or
                            self.xconnect_count.yfilter != YFilter.not_set or
                            self.xconnect_down_count.yfilter != YFilter.not_set or
                            self.xconnect_up_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "xconnect-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ac_down_count_aib.is_set or self.ac_down_count_aib.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_down_count_aib.get_name_leafdata())
                        if (self.ac_down_count_l2vpn.is_set or self.ac_down_count_l2vpn.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_down_count_l2vpn.get_name_leafdata())
                        if (self.ac_down_count_l3fib.is_set or self.ac_down_count_l3fib.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_down_count_l3fib.get_name_leafdata())
                        if (self.ac_down_count_vpdn.is_set or self.ac_down_count_vpdn.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_down_count_vpdn.get_name_leafdata())
                        if (self.ac_to_ac_count.is_set or self.ac_to_ac_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_to_ac_count.get_name_leafdata())
                        if (self.ac_to_bp_count.is_set or self.ac_to_bp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_to_bp_count.get_name_leafdata())
                        if (self.ac_to_pw_count_l2tp.is_set or self.ac_to_pw_count_l2tp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_to_pw_count_l2tp.get_name_leafdata())
                        if (self.ac_to_pw_count_l2tp_ip_v6.is_set or self.ac_to_pw_count_l2tp_ip_v6.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_to_pw_count_l2tp_ip_v6.get_name_leafdata())
                        if (self.ac_to_pw_count_l2tpv2.is_set or self.ac_to_pw_count_l2tpv2.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_to_pw_count_l2tpv2.get_name_leafdata())
                        if (self.ac_to_pw_count_mpls.is_set or self.ac_to_pw_count_mpls.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_to_pw_count_mpls.get_name_leafdata())
                        if (self.ac_to_unknown_count.is_set or self.ac_to_unknown_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac_to_unknown_count.get_name_leafdata())
                        if (self.bp_count.is_set or self.bp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bp_count.get_name_leafdata())
                        if (self.bundle_ac_max_exceeded_drop_cnt.is_set or self.bundle_ac_max_exceeded_drop_cnt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle_ac_max_exceeded_drop_cnt.get_name_leafdata())
                        if (self.evpn_invalid_xid_drop_count.is_set or self.evpn_invalid_xid_drop_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_invalid_xid_drop_count.get_name_leafdata())
                        if (self.evpn_to_bp_count.is_set or self.evpn_to_bp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_to_bp_count.get_name_leafdata())
                        if (self.evpn_to_unknown_count.is_set or self.evpn_to_unknown_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_to_unknown_count.get_name_leafdata())
                        if (self.mon_sess_to_pw_count.is_set or self.mon_sess_to_pw_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mon_sess_to_pw_count.get_name_leafdata())
                        if (self.mon_sess_to_unknown_count.is_set or self.mon_sess_to_unknown_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mon_sess_to_unknown_count.get_name_leafdata())
                        if (self.p2p_count.is_set or self.p2p_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.p2p_count.get_name_leafdata())
                        if (self.pbb_invalid_xid_drop_count.is_set or self.pbb_invalid_xid_drop_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pbb_invalid_xid_drop_count.get_name_leafdata())
                        if (self.pbb_to_bp_count.is_set or self.pbb_to_bp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pbb_to_bp_count.get_name_leafdata())
                        if (self.pbb_to_unknown_count.is_set or self.pbb_to_unknown_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pbb_to_unknown_count.get_name_leafdata())
                        if (self.pw_to_bp_count.is_set or self.pw_to_bp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_to_bp_count.get_name_leafdata())
                        if (self.pw_to_unknown_count.is_set or self.pw_to_unknown_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_to_unknown_count.get_name_leafdata())
                        if (self.pwhe_l2_if_count.is_set or self.pwhe_l2_if_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pwhe_l2_if_count.get_name_leafdata())
                        if (self.virtual_ac_invalid_xid_drop_count.is_set or self.virtual_ac_invalid_xid_drop_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_ac_invalid_xid_drop_count.get_name_leafdata())
                        if (self.vni_invalid_xid_drop_count.is_set or self.vni_invalid_xid_drop_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_invalid_xid_drop_count.get_name_leafdata())
                        if (self.vni_to_bp_count.is_set or self.vni_to_bp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_to_bp_count.get_name_leafdata())
                        if (self.vni_to_unknown_count.is_set or self.vni_to_unknown_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_to_unknown_count.get_name_leafdata())
                        if (self.vpls_pw_invalid_xid_drop_count.is_set or self.vpls_pw_invalid_xid_drop_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpls_pw_invalid_xid_drop_count.get_name_leafdata())
                        if (self.vpls_pw_max_exceeded_drop_cnt.is_set or self.vpls_pw_max_exceeded_drop_cnt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpls_pw_max_exceeded_drop_cnt.get_name_leafdata())
                        if (self.vpws_pw_invalid_xid_drop_count.is_set or self.vpws_pw_invalid_xid_drop_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpws_pw_invalid_xid_drop_count.get_name_leafdata())
                        if (self.xconnect_count.is_set or self.xconnect_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_count.get_name_leafdata())
                        if (self.xconnect_down_count.is_set or self.xconnect_down_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_down_count.get_name_leafdata())
                        if (self.xconnect_up_count.is_set or self.xconnect_up_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_up_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ac-down-count-aib" or name == "ac-down-count-l2vpn" or name == "ac-down-count-l3fib" or name == "ac-down-count-vpdn" or name == "ac-to-ac-count" or name == "ac-to-bp-count" or name == "ac-to-pw-count-l2tp" or name == "ac-to-pw-count-l2tp-ip-v6" or name == "ac-to-pw-count-l2tpv2" or name == "ac-to-pw-count-mpls" or name == "ac-to-unknown-count" or name == "bp-count" or name == "bundle-ac-max-exceeded-drop-cnt" or name == "evpn-invalid-xid-drop-count" or name == "evpn-to-bp-count" or name == "evpn-to-unknown-count" or name == "mon-sess-to-pw-count" or name == "mon-sess-to-unknown-count" or name == "p2p-count" or name == "pbb-invalid-xid-drop-count" or name == "pbb-to-bp-count" or name == "pbb-to-unknown-count" or name == "pw-to-bp-count" or name == "pw-to-unknown-count" or name == "pwhe-l2-if-count" or name == "virtual-ac-invalid-xid-drop-count" or name == "vni-invalid-xid-drop-count" or name == "vni-to-bp-count" or name == "vni-to-unknown-count" or name == "vpls-pw-invalid-xid-drop-count" or name == "vpls-pw-max-exceeded-drop-cnt" or name == "vpws-pw-invalid-xid-drop-count" or name == "xconnect-count" or name == "xconnect-down-count" or name == "xconnect-up-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ac-down-count-aib"):
                            self.ac_down_count_aib = value
                            self.ac_down_count_aib.value_namespace = name_space
                            self.ac_down_count_aib.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac-down-count-l2vpn"):
                            self.ac_down_count_l2vpn = value
                            self.ac_down_count_l2vpn.value_namespace = name_space
                            self.ac_down_count_l2vpn.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac-down-count-l3fib"):
                            self.ac_down_count_l3fib = value
                            self.ac_down_count_l3fib.value_namespace = name_space
                            self.ac_down_count_l3fib.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac-down-count-vpdn"):
                            self.ac_down_count_vpdn = value
                            self.ac_down_count_vpdn.value_namespace = name_space
                            self.ac_down_count_vpdn.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac-to-ac-count"):
                            self.ac_to_ac_count = value
                            self.ac_to_ac_count.value_namespace = name_space
                            self.ac_to_ac_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac-to-bp-count"):
                            self.ac_to_bp_count = value
                            self.ac_to_bp_count.value_namespace = name_space
                            self.ac_to_bp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac-to-pw-count-l2tp"):
                            self.ac_to_pw_count_l2tp = value
                            self.ac_to_pw_count_l2tp.value_namespace = name_space
                            self.ac_to_pw_count_l2tp.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac-to-pw-count-l2tp-ip-v6"):
                            self.ac_to_pw_count_l2tp_ip_v6 = value
                            self.ac_to_pw_count_l2tp_ip_v6.value_namespace = name_space
                            self.ac_to_pw_count_l2tp_ip_v6.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac-to-pw-count-l2tpv2"):
                            self.ac_to_pw_count_l2tpv2 = value
                            self.ac_to_pw_count_l2tpv2.value_namespace = name_space
                            self.ac_to_pw_count_l2tpv2.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac-to-pw-count-mpls"):
                            self.ac_to_pw_count_mpls = value
                            self.ac_to_pw_count_mpls.value_namespace = name_space
                            self.ac_to_pw_count_mpls.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac-to-unknown-count"):
                            self.ac_to_unknown_count = value
                            self.ac_to_unknown_count.value_namespace = name_space
                            self.ac_to_unknown_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bp-count"):
                            self.bp_count = value
                            self.bp_count.value_namespace = name_space
                            self.bp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle-ac-max-exceeded-drop-cnt"):
                            self.bundle_ac_max_exceeded_drop_cnt = value
                            self.bundle_ac_max_exceeded_drop_cnt.value_namespace = name_space
                            self.bundle_ac_max_exceeded_drop_cnt.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-invalid-xid-drop-count"):
                            self.evpn_invalid_xid_drop_count = value
                            self.evpn_invalid_xid_drop_count.value_namespace = name_space
                            self.evpn_invalid_xid_drop_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-to-bp-count"):
                            self.evpn_to_bp_count = value
                            self.evpn_to_bp_count.value_namespace = name_space
                            self.evpn_to_bp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-to-unknown-count"):
                            self.evpn_to_unknown_count = value
                            self.evpn_to_unknown_count.value_namespace = name_space
                            self.evpn_to_unknown_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mon-sess-to-pw-count"):
                            self.mon_sess_to_pw_count = value
                            self.mon_sess_to_pw_count.value_namespace = name_space
                            self.mon_sess_to_pw_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mon-sess-to-unknown-count"):
                            self.mon_sess_to_unknown_count = value
                            self.mon_sess_to_unknown_count.value_namespace = name_space
                            self.mon_sess_to_unknown_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "p2p-count"):
                            self.p2p_count = value
                            self.p2p_count.value_namespace = name_space
                            self.p2p_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "pbb-invalid-xid-drop-count"):
                            self.pbb_invalid_xid_drop_count = value
                            self.pbb_invalid_xid_drop_count.value_namespace = name_space
                            self.pbb_invalid_xid_drop_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "pbb-to-bp-count"):
                            self.pbb_to_bp_count = value
                            self.pbb_to_bp_count.value_namespace = name_space
                            self.pbb_to_bp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "pbb-to-unknown-count"):
                            self.pbb_to_unknown_count = value
                            self.pbb_to_unknown_count.value_namespace = name_space
                            self.pbb_to_unknown_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-to-bp-count"):
                            self.pw_to_bp_count = value
                            self.pw_to_bp_count.value_namespace = name_space
                            self.pw_to_bp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-to-unknown-count"):
                            self.pw_to_unknown_count = value
                            self.pw_to_unknown_count.value_namespace = name_space
                            self.pw_to_unknown_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "pwhe-l2-if-count"):
                            self.pwhe_l2_if_count = value
                            self.pwhe_l2_if_count.value_namespace = name_space
                            self.pwhe_l2_if_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-ac-invalid-xid-drop-count"):
                            self.virtual_ac_invalid_xid_drop_count = value
                            self.virtual_ac_invalid_xid_drop_count.value_namespace = name_space
                            self.virtual_ac_invalid_xid_drop_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni-invalid-xid-drop-count"):
                            self.vni_invalid_xid_drop_count = value
                            self.vni_invalid_xid_drop_count.value_namespace = name_space
                            self.vni_invalid_xid_drop_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni-to-bp-count"):
                            self.vni_to_bp_count = value
                            self.vni_to_bp_count.value_namespace = name_space
                            self.vni_to_bp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni-to-unknown-count"):
                            self.vni_to_unknown_count = value
                            self.vni_to_unknown_count.value_namespace = name_space
                            self.vni_to_unknown_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpls-pw-invalid-xid-drop-count"):
                            self.vpls_pw_invalid_xid_drop_count = value
                            self.vpls_pw_invalid_xid_drop_count.value_namespace = name_space
                            self.vpls_pw_invalid_xid_drop_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpls-pw-max-exceeded-drop-cnt"):
                            self.vpls_pw_max_exceeded_drop_cnt = value
                            self.vpls_pw_max_exceeded_drop_cnt.value_namespace = name_space
                            self.vpls_pw_max_exceeded_drop_cnt.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpws-pw-invalid-xid-drop-count"):
                            self.vpws_pw_invalid_xid_drop_count = value
                            self.vpws_pw_invalid_xid_drop_count.value_namespace = name_space
                            self.vpws_pw_invalid_xid_drop_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-count"):
                            self.xconnect_count = value
                            self.xconnect_count.value_namespace = name_space
                            self.xconnect_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-down-count"):
                            self.xconnect_down_count = value
                            self.xconnect_down_count.value_namespace = name_space
                            self.xconnect_down_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-up-count"):
                            self.xconnect_up_count = value
                            self.xconnect_up_count.value_namespace = name_space
                            self.xconnect_up_count.value_namespace_prefix = name_space_prefix


                class NextHopSummary(Entity):
                    """
                    nhop db summry info
                    
                    .. attribute:: l2tp
                    
                    	L2TP nexthop summary
                    	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.L2Tp>`
                    
                    .. attribute:: lsm
                    
                    	LSM nexthop summary
                    	**type**\:   :py:class:`Lsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Lsm>`
                    
                    .. attribute:: mpls
                    
                    	MPLS nexthop summary
                    	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Mpls>`
                    
                    .. attribute:: mpls_il
                    
                    	MPLS Internal Label nexthop summary
                    	**type**\:   :py:class:`MplsIl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.MplsIl>`
                    
                    .. attribute:: p2mp_tunnels
                    
                    	P2MPtun nexthop summary
                    	**type**\:   :py:class:`P2MpTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.P2MpTunnels>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary, self).__init__()

                        self.yang_name = "next-hop-summary"
                        self.yang_parent_name = "l2fib-summary"

                        self.l2tp = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.L2Tp()
                        self.l2tp.parent = self
                        self._children_name_map["l2tp"] = "l2tp"
                        self._children_yang_names.add("l2tp")

                        self.lsm = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Lsm()
                        self.lsm.parent = self
                        self._children_name_map["lsm"] = "lsm"
                        self._children_yang_names.add("lsm")

                        self.mpls = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Mpls()
                        self.mpls.parent = self
                        self._children_name_map["mpls"] = "mpls"
                        self._children_yang_names.add("mpls")

                        self.mpls_il = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.MplsIl()
                        self.mpls_il.parent = self
                        self._children_name_map["mpls_il"] = "mpls-il"
                        self._children_yang_names.add("mpls-il")

                        self.p2mp_tunnels = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.P2MpTunnels()
                        self.p2mp_tunnels.parent = self
                        self._children_name_map["p2mp_tunnels"] = "p2mp-tunnels"
                        self._children_yang_names.add("p2mp-tunnels")


                    class MplsIl(Entity):
                        """
                        MPLS Internal Label nexthop summary
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.MplsIl, self).__init__()

                            self.yang_name = "mpls-il"
                            self.yang_parent_name = "next-hop-summary"

                            self.bound_next_hop_count = YLeaf(YType.uint32, "bound-next-hop-count")

                            self.next_hop_count = YLeaf(YType.uint32, "next-hop-count")

                            self.next_hop_pending_registration_count = YLeaf(YType.uint32, "next-hop-pending-registration-count")

                            self.unbound_next_hop_count = YLeaf(YType.uint32, "unbound-next-hop-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bound_next_hop_count",
                                            "next_hop_count",
                                            "next_hop_pending_registration_count",
                                            "unbound_next_hop_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.MplsIl, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.MplsIl, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bound_next_hop_count.is_set or
                                self.next_hop_count.is_set or
                                self.next_hop_pending_registration_count.is_set or
                                self.unbound_next_hop_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bound_next_hop_count.yfilter != YFilter.not_set or
                                self.next_hop_count.yfilter != YFilter.not_set or
                                self.next_hop_pending_registration_count.yfilter != YFilter.not_set or
                                self.unbound_next_hop_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mpls-il" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bound_next_hop_count.is_set or self.bound_next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bound_next_hop_count.get_name_leafdata())
                            if (self.next_hop_count.is_set or self.next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_count.get_name_leafdata())
                            if (self.next_hop_pending_registration_count.is_set or self.next_hop_pending_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_pending_registration_count.get_name_leafdata())
                            if (self.unbound_next_hop_count.is_set or self.unbound_next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unbound_next_hop_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bound-next-hop-count" or name == "next-hop-count" or name == "next-hop-pending-registration-count" or name == "unbound-next-hop-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bound-next-hop-count"):
                                self.bound_next_hop_count = value
                                self.bound_next_hop_count.value_namespace = name_space
                                self.bound_next_hop_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-count"):
                                self.next_hop_count = value
                                self.next_hop_count.value_namespace = name_space
                                self.next_hop_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-pending-registration-count"):
                                self.next_hop_pending_registration_count = value
                                self.next_hop_pending_registration_count.value_namespace = name_space
                                self.next_hop_pending_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "unbound-next-hop-count"):
                                self.unbound_next_hop_count = value
                                self.unbound_next_hop_count.value_namespace = name_space
                                self.unbound_next_hop_count.value_namespace_prefix = name_space_prefix


                    class Mpls(Entity):
                        """
                        MPLS nexthop summary
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Mpls, self).__init__()

                            self.yang_name = "mpls"
                            self.yang_parent_name = "next-hop-summary"

                            self.bound_next_hop_count = YLeaf(YType.uint32, "bound-next-hop-count")

                            self.next_hop_count = YLeaf(YType.uint32, "next-hop-count")

                            self.next_hop_pending_registration_count = YLeaf(YType.uint32, "next-hop-pending-registration-count")

                            self.unbound_next_hop_count = YLeaf(YType.uint32, "unbound-next-hop-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bound_next_hop_count",
                                            "next_hop_count",
                                            "next_hop_pending_registration_count",
                                            "unbound_next_hop_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Mpls, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Mpls, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bound_next_hop_count.is_set or
                                self.next_hop_count.is_set or
                                self.next_hop_pending_registration_count.is_set or
                                self.unbound_next_hop_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bound_next_hop_count.yfilter != YFilter.not_set or
                                self.next_hop_count.yfilter != YFilter.not_set or
                                self.next_hop_pending_registration_count.yfilter != YFilter.not_set or
                                self.unbound_next_hop_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mpls" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bound_next_hop_count.is_set or self.bound_next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bound_next_hop_count.get_name_leafdata())
                            if (self.next_hop_count.is_set or self.next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_count.get_name_leafdata())
                            if (self.next_hop_pending_registration_count.is_set or self.next_hop_pending_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_pending_registration_count.get_name_leafdata())
                            if (self.unbound_next_hop_count.is_set or self.unbound_next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unbound_next_hop_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bound-next-hop-count" or name == "next-hop-count" or name == "next-hop-pending-registration-count" or name == "unbound-next-hop-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bound-next-hop-count"):
                                self.bound_next_hop_count = value
                                self.bound_next_hop_count.value_namespace = name_space
                                self.bound_next_hop_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-count"):
                                self.next_hop_count = value
                                self.next_hop_count.value_namespace = name_space
                                self.next_hop_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-pending-registration-count"):
                                self.next_hop_pending_registration_count = value
                                self.next_hop_pending_registration_count.value_namespace = name_space
                                self.next_hop_pending_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "unbound-next-hop-count"):
                                self.unbound_next_hop_count = value
                                self.unbound_next_hop_count.value_namespace = name_space
                                self.unbound_next_hop_count.value_namespace_prefix = name_space_prefix


                    class L2Tp(Entity):
                        """
                        L2TP nexthop summary
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.L2Tp, self).__init__()

                            self.yang_name = "l2tp"
                            self.yang_parent_name = "next-hop-summary"

                            self.bound_next_hop_count = YLeaf(YType.uint32, "bound-next-hop-count")

                            self.next_hop_count = YLeaf(YType.uint32, "next-hop-count")

                            self.next_hop_pending_registration_count = YLeaf(YType.uint32, "next-hop-pending-registration-count")

                            self.unbound_next_hop_count = YLeaf(YType.uint32, "unbound-next-hop-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bound_next_hop_count",
                                            "next_hop_count",
                                            "next_hop_pending_registration_count",
                                            "unbound_next_hop_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.L2Tp, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.L2Tp, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bound_next_hop_count.is_set or
                                self.next_hop_count.is_set or
                                self.next_hop_pending_registration_count.is_set or
                                self.unbound_next_hop_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bound_next_hop_count.yfilter != YFilter.not_set or
                                self.next_hop_count.yfilter != YFilter.not_set or
                                self.next_hop_pending_registration_count.yfilter != YFilter.not_set or
                                self.unbound_next_hop_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2tp" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bound_next_hop_count.is_set or self.bound_next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bound_next_hop_count.get_name_leafdata())
                            if (self.next_hop_count.is_set or self.next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_count.get_name_leafdata())
                            if (self.next_hop_pending_registration_count.is_set or self.next_hop_pending_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_pending_registration_count.get_name_leafdata())
                            if (self.unbound_next_hop_count.is_set or self.unbound_next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unbound_next_hop_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bound-next-hop-count" or name == "next-hop-count" or name == "next-hop-pending-registration-count" or name == "unbound-next-hop-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bound-next-hop-count"):
                                self.bound_next_hop_count = value
                                self.bound_next_hop_count.value_namespace = name_space
                                self.bound_next_hop_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-count"):
                                self.next_hop_count = value
                                self.next_hop_count.value_namespace = name_space
                                self.next_hop_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-pending-registration-count"):
                                self.next_hop_pending_registration_count = value
                                self.next_hop_pending_registration_count.value_namespace = name_space
                                self.next_hop_pending_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "unbound-next-hop-count"):
                                self.unbound_next_hop_count = value
                                self.unbound_next_hop_count.value_namespace = name_space
                                self.unbound_next_hop_count.value_namespace_prefix = name_space_prefix


                    class Lsm(Entity):
                        """
                        LSM nexthop summary
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Lsm, self).__init__()

                            self.yang_name = "lsm"
                            self.yang_parent_name = "next-hop-summary"

                            self.bound_next_hop_count = YLeaf(YType.uint32, "bound-next-hop-count")

                            self.next_hop_count = YLeaf(YType.uint32, "next-hop-count")

                            self.next_hop_pending_registration_count = YLeaf(YType.uint32, "next-hop-pending-registration-count")

                            self.unbound_next_hop_count = YLeaf(YType.uint32, "unbound-next-hop-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bound_next_hop_count",
                                            "next_hop_count",
                                            "next_hop_pending_registration_count",
                                            "unbound_next_hop_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Lsm, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Lsm, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bound_next_hop_count.is_set or
                                self.next_hop_count.is_set or
                                self.next_hop_pending_registration_count.is_set or
                                self.unbound_next_hop_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bound_next_hop_count.yfilter != YFilter.not_set or
                                self.next_hop_count.yfilter != YFilter.not_set or
                                self.next_hop_pending_registration_count.yfilter != YFilter.not_set or
                                self.unbound_next_hop_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "lsm" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bound_next_hop_count.is_set or self.bound_next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bound_next_hop_count.get_name_leafdata())
                            if (self.next_hop_count.is_set or self.next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_count.get_name_leafdata())
                            if (self.next_hop_pending_registration_count.is_set or self.next_hop_pending_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_pending_registration_count.get_name_leafdata())
                            if (self.unbound_next_hop_count.is_set or self.unbound_next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unbound_next_hop_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bound-next-hop-count" or name == "next-hop-count" or name == "next-hop-pending-registration-count" or name == "unbound-next-hop-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bound-next-hop-count"):
                                self.bound_next_hop_count = value
                                self.bound_next_hop_count.value_namespace = name_space
                                self.bound_next_hop_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-count"):
                                self.next_hop_count = value
                                self.next_hop_count.value_namespace = name_space
                                self.next_hop_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-pending-registration-count"):
                                self.next_hop_pending_registration_count = value
                                self.next_hop_pending_registration_count.value_namespace = name_space
                                self.next_hop_pending_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "unbound-next-hop-count"):
                                self.unbound_next_hop_count = value
                                self.unbound_next_hop_count.value_namespace = name_space
                                self.unbound_next_hop_count.value_namespace_prefix = name_space_prefix


                    class P2MpTunnels(Entity):
                        """
                        P2MPtun nexthop summary
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.P2MpTunnels, self).__init__()

                            self.yang_name = "p2mp-tunnels"
                            self.yang_parent_name = "next-hop-summary"

                            self.bound_next_hop_count = YLeaf(YType.uint32, "bound-next-hop-count")

                            self.next_hop_count = YLeaf(YType.uint32, "next-hop-count")

                            self.next_hop_pending_registration_count = YLeaf(YType.uint32, "next-hop-pending-registration-count")

                            self.unbound_next_hop_count = YLeaf(YType.uint32, "unbound-next-hop-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bound_next_hop_count",
                                            "next_hop_count",
                                            "next_hop_pending_registration_count",
                                            "unbound_next_hop_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.P2MpTunnels, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.P2MpTunnels, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bound_next_hop_count.is_set or
                                self.next_hop_count.is_set or
                                self.next_hop_pending_registration_count.is_set or
                                self.unbound_next_hop_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bound_next_hop_count.yfilter != YFilter.not_set or
                                self.next_hop_count.yfilter != YFilter.not_set or
                                self.next_hop_pending_registration_count.yfilter != YFilter.not_set or
                                self.unbound_next_hop_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-tunnels" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bound_next_hop_count.is_set or self.bound_next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bound_next_hop_count.get_name_leafdata())
                            if (self.next_hop_count.is_set or self.next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_count.get_name_leafdata())
                            if (self.next_hop_pending_registration_count.is_set or self.next_hop_pending_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_pending_registration_count.get_name_leafdata())
                            if (self.unbound_next_hop_count.is_set or self.unbound_next_hop_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unbound_next_hop_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bound-next-hop-count" or name == "next-hop-count" or name == "next-hop-pending-registration-count" or name == "unbound-next-hop-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bound-next-hop-count"):
                                self.bound_next_hop_count = value
                                self.bound_next_hop_count.value_namespace = name_space
                                self.bound_next_hop_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-count"):
                                self.next_hop_count = value
                                self.next_hop_count.value_namespace = name_space
                                self.next_hop_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-pending-registration-count"):
                                self.next_hop_pending_registration_count = value
                                self.next_hop_pending_registration_count.value_namespace = name_space
                                self.next_hop_pending_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "unbound-next-hop-count"):
                                self.unbound_next_hop_count = value
                                self.unbound_next_hop_count.value_namespace = name_space
                                self.unbound_next_hop_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            (self.l2tp is not None and self.l2tp.has_data()) or
                            (self.lsm is not None and self.lsm.has_data()) or
                            (self.mpls is not None and self.mpls.has_data()) or
                            (self.mpls_il is not None and self.mpls_il.has_data()) or
                            (self.p2mp_tunnels is not None and self.p2mp_tunnels.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.l2tp is not None and self.l2tp.has_operation()) or
                            (self.lsm is not None and self.lsm.has_operation()) or
                            (self.mpls is not None and self.mpls.has_operation()) or
                            (self.mpls_il is not None and self.mpls_il.has_operation()) or
                            (self.p2mp_tunnels is not None and self.p2mp_tunnels.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "next-hop-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2tp"):
                            if (self.l2tp is None):
                                self.l2tp = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.L2Tp()
                                self.l2tp.parent = self
                                self._children_name_map["l2tp"] = "l2tp"
                            return self.l2tp

                        if (child_yang_name == "lsm"):
                            if (self.lsm is None):
                                self.lsm = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Lsm()
                                self.lsm.parent = self
                                self._children_name_map["lsm"] = "lsm"
                            return self.lsm

                        if (child_yang_name == "mpls"):
                            if (self.mpls is None):
                                self.mpls = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Mpls()
                                self.mpls.parent = self
                                self._children_name_map["mpls"] = "mpls"
                            return self.mpls

                        if (child_yang_name == "mpls-il"):
                            if (self.mpls_il is None):
                                self.mpls_il = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.MplsIl()
                                self.mpls_il.parent = self
                                self._children_name_map["mpls_il"] = "mpls-il"
                            return self.mpls_il

                        if (child_yang_name == "p2mp-tunnels"):
                            if (self.p2mp_tunnels is None):
                                self.p2mp_tunnels = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.P2MpTunnels()
                                self.p2mp_tunnels.parent = self
                                self._children_name_map["p2mp_tunnels"] = "p2mp-tunnels"
                            return self.p2mp_tunnels

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2tp" or name == "lsm" or name == "mpls" or name == "mpls-il" or name == "p2mp-tunnels"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class L2TpDispositionSummary(Entity):
                    """
                    L2TP disposition object summary
                    
                    .. attribute:: bound_l2tp_disposition_session_count
                    
                    	number of bound l2tp dispostion objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: l2tp_disposition_session_count
                    
                    	number of l2tp disposition session objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unbound_l2tp_disposition_session_count
                    
                    	number of unbound l2tp disposition objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.L2TpDispositionSummary, self).__init__()

                        self.yang_name = "l2tp-disposition-summary"
                        self.yang_parent_name = "l2fib-summary"

                        self.bound_l2tp_disposition_session_count = YLeaf(YType.uint32, "bound-l2tp-disposition-session-count")

                        self.l2tp_disposition_session_count = YLeaf(YType.uint32, "l2tp-disposition-session-count")

                        self.unbound_l2tp_disposition_session_count = YLeaf(YType.uint32, "unbound-l2tp-disposition-session-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bound_l2tp_disposition_session_count",
                                        "l2tp_disposition_session_count",
                                        "unbound_l2tp_disposition_session_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.L2TpDispositionSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibSummary.L2TpDispositionSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bound_l2tp_disposition_session_count.is_set or
                            self.l2tp_disposition_session_count.is_set or
                            self.unbound_l2tp_disposition_session_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bound_l2tp_disposition_session_count.yfilter != YFilter.not_set or
                            self.l2tp_disposition_session_count.yfilter != YFilter.not_set or
                            self.unbound_l2tp_disposition_session_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2tp-disposition-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bound_l2tp_disposition_session_count.is_set or self.bound_l2tp_disposition_session_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bound_l2tp_disposition_session_count.get_name_leafdata())
                        if (self.l2tp_disposition_session_count.is_set or self.l2tp_disposition_session_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.l2tp_disposition_session_count.get_name_leafdata())
                        if (self.unbound_l2tp_disposition_session_count.is_set or self.unbound_l2tp_disposition_session_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unbound_l2tp_disposition_session_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bound-l2tp-disposition-session-count" or name == "l2tp-disposition-session-count" or name == "unbound-l2tp-disposition-session-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bound-l2tp-disposition-session-count"):
                            self.bound_l2tp_disposition_session_count = value
                            self.bound_l2tp_disposition_session_count.value_namespace = name_space
                            self.bound_l2tp_disposition_session_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "l2tp-disposition-session-count"):
                            self.l2tp_disposition_session_count = value
                            self.l2tp_disposition_session_count.value_namespace = name_space
                            self.l2tp_disposition_session_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "unbound-l2tp-disposition-session-count"):
                            self.unbound_l2tp_disposition_session_count = value
                            self.unbound_l2tp_disposition_session_count.value_namespace = name_space
                            self.unbound_l2tp_disposition_session_count.value_namespace_prefix = name_space_prefix


                class BridgeDomainSummary(Entity):
                    """
                    Bridge\-domain summary info
                    
                    .. attribute:: bridge_domain_count
                    
                    	Number of bridge\-domains
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_drop_count
                    
                    	Number of bridge\-domain updates dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_bvi_count
                    
                    	Number of bridge\-domains with BVI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_evpn_enabled
                    
                    	Number of bridge\-domains with EVPN enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_p2mp_enabled
                    
                    	Number of bridge\-domains with P2MP enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_pbbevpn_enabled
                    
                    	Number of bridge\-domains with PBB EVPN enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.BridgeDomainSummary, self).__init__()

                        self.yang_name = "bridge-domain-summary"
                        self.yang_parent_name = "l2fib-summary"

                        self.bridge_domain_count = YLeaf(YType.uint32, "bridge-domain-count")

                        self.bridge_domain_drop_count = YLeaf(YType.uint32, "bridge-domain-drop-count")

                        self.bridge_domain_with_bvi_count = YLeaf(YType.uint32, "bridge-domain-with-bvi-count")

                        self.bridge_domain_with_evpn_enabled = YLeaf(YType.uint32, "bridge-domain-with-evpn-enabled")

                        self.bridge_domain_with_p2mp_enabled = YLeaf(YType.uint32, "bridge-domain-with-p2mp-enabled")

                        self.bridge_domain_with_pbbevpn_enabled = YLeaf(YType.uint32, "bridge-domain-with-pbbevpn-enabled")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bridge_domain_count",
                                        "bridge_domain_drop_count",
                                        "bridge_domain_with_bvi_count",
                                        "bridge_domain_with_evpn_enabled",
                                        "bridge_domain_with_p2mp_enabled",
                                        "bridge_domain_with_pbbevpn_enabled") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.BridgeDomainSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibSummary.BridgeDomainSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bridge_domain_count.is_set or
                            self.bridge_domain_drop_count.is_set or
                            self.bridge_domain_with_bvi_count.is_set or
                            self.bridge_domain_with_evpn_enabled.is_set or
                            self.bridge_domain_with_p2mp_enabled.is_set or
                            self.bridge_domain_with_pbbevpn_enabled.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bridge_domain_count.yfilter != YFilter.not_set or
                            self.bridge_domain_drop_count.yfilter != YFilter.not_set or
                            self.bridge_domain_with_bvi_count.yfilter != YFilter.not_set or
                            self.bridge_domain_with_evpn_enabled.yfilter != YFilter.not_set or
                            self.bridge_domain_with_p2mp_enabled.yfilter != YFilter.not_set or
                            self.bridge_domain_with_pbbevpn_enabled.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-domain-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bridge_domain_count.is_set or self.bridge_domain_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_count.get_name_leafdata())
                        if (self.bridge_domain_drop_count.is_set or self.bridge_domain_drop_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_drop_count.get_name_leafdata())
                        if (self.bridge_domain_with_bvi_count.is_set or self.bridge_domain_with_bvi_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_with_bvi_count.get_name_leafdata())
                        if (self.bridge_domain_with_evpn_enabled.is_set or self.bridge_domain_with_evpn_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_with_evpn_enabled.get_name_leafdata())
                        if (self.bridge_domain_with_p2mp_enabled.is_set or self.bridge_domain_with_p2mp_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_with_p2mp_enabled.get_name_leafdata())
                        if (self.bridge_domain_with_pbbevpn_enabled.is_set or self.bridge_domain_with_pbbevpn_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_with_pbbevpn_enabled.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-domain-count" or name == "bridge-domain-drop-count" or name == "bridge-domain-with-bvi-count" or name == "bridge-domain-with-evpn-enabled" or name == "bridge-domain-with-p2mp-enabled" or name == "bridge-domain-with-pbbevpn-enabled"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bridge-domain-count"):
                            self.bridge_domain_count = value
                            self.bridge_domain_count.value_namespace = name_space
                            self.bridge_domain_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-drop-count"):
                            self.bridge_domain_drop_count = value
                            self.bridge_domain_drop_count.value_namespace = name_space
                            self.bridge_domain_drop_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-with-bvi-count"):
                            self.bridge_domain_with_bvi_count = value
                            self.bridge_domain_with_bvi_count.value_namespace = name_space
                            self.bridge_domain_with_bvi_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-with-evpn-enabled"):
                            self.bridge_domain_with_evpn_enabled = value
                            self.bridge_domain_with_evpn_enabled.value_namespace = name_space
                            self.bridge_domain_with_evpn_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-with-p2mp-enabled"):
                            self.bridge_domain_with_p2mp_enabled = value
                            self.bridge_domain_with_p2mp_enabled.value_namespace = name_space
                            self.bridge_domain_with_p2mp_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-with-pbbevpn-enabled"):
                            self.bridge_domain_with_pbbevpn_enabled = value
                            self.bridge_domain_with_pbbevpn_enabled.value_namespace = name_space
                            self.bridge_domain_with_pbbevpn_enabled.value_namespace_prefix = name_space_prefix


                class MacSummary(Entity):
                    """
                    mac summary info
                    
                    .. attribute:: bmac_count
                    
                    	number of BMACs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: local_mac_count
                    
                    	number of locally learnt macs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_count
                    
                    	number of all macs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_mac_count
                    
                    	number of remotely learned macs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: routed_mac_count
                    
                    	number of routed macs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sbmac_count
                    
                    	number of Source BMACs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: static_mac_count
                    
                    	number of static macs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.MacSummary, self).__init__()

                        self.yang_name = "mac-summary"
                        self.yang_parent_name = "l2fib-summary"

                        self.bmac_count = YLeaf(YType.uint32, "bmac-count")

                        self.local_mac_count = YLeaf(YType.uint32, "local-mac-count")

                        self.mac_count = YLeaf(YType.uint32, "mac-count")

                        self.remote_mac_count = YLeaf(YType.uint32, "remote-mac-count")

                        self.routed_mac_count = YLeaf(YType.uint32, "routed-mac-count")

                        self.sbmac_count = YLeaf(YType.uint32, "sbmac-count")

                        self.static_mac_count = YLeaf(YType.uint32, "static-mac-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bmac_count",
                                        "local_mac_count",
                                        "mac_count",
                                        "remote_mac_count",
                                        "routed_mac_count",
                                        "sbmac_count",
                                        "static_mac_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.MacSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibSummary.MacSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bmac_count.is_set or
                            self.local_mac_count.is_set or
                            self.mac_count.is_set or
                            self.remote_mac_count.is_set or
                            self.routed_mac_count.is_set or
                            self.sbmac_count.is_set or
                            self.static_mac_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bmac_count.yfilter != YFilter.not_set or
                            self.local_mac_count.yfilter != YFilter.not_set or
                            self.mac_count.yfilter != YFilter.not_set or
                            self.remote_mac_count.yfilter != YFilter.not_set or
                            self.routed_mac_count.yfilter != YFilter.not_set or
                            self.sbmac_count.yfilter != YFilter.not_set or
                            self.static_mac_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mac-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bmac_count.is_set or self.bmac_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bmac_count.get_name_leafdata())
                        if (self.local_mac_count.is_set or self.local_mac_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_mac_count.get_name_leafdata())
                        if (self.mac_count.is_set or self.mac_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_count.get_name_leafdata())
                        if (self.remote_mac_count.is_set or self.remote_mac_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_mac_count.get_name_leafdata())
                        if (self.routed_mac_count.is_set or self.routed_mac_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.routed_mac_count.get_name_leafdata())
                        if (self.sbmac_count.is_set or self.sbmac_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sbmac_count.get_name_leafdata())
                        if (self.static_mac_count.is_set or self.static_mac_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.static_mac_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bmac-count" or name == "local-mac-count" or name == "mac-count" or name == "remote-mac-count" or name == "routed-mac-count" or name == "sbmac-count" or name == "static-mac-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bmac-count"):
                            self.bmac_count = value
                            self.bmac_count.value_namespace = name_space
                            self.bmac_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-mac-count"):
                            self.local_mac_count = value
                            self.local_mac_count.value_namespace = name_space
                            self.local_mac_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-count"):
                            self.mac_count = value
                            self.mac_count.value_namespace = name_space
                            self.mac_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-mac-count"):
                            self.remote_mac_count = value
                            self.remote_mac_count.value_namespace = name_space
                            self.remote_mac_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "routed-mac-count"):
                            self.routed_mac_count = value
                            self.routed_mac_count.value_namespace = name_space
                            self.routed_mac_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sbmac-count"):
                            self.sbmac_count = value
                            self.sbmac_count.value_namespace = name_space
                            self.sbmac_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "static-mac-count"):
                            self.static_mac_count = value
                            self.static_mac_count.value_namespace = name_space
                            self.static_mac_count.value_namespace_prefix = name_space_prefix


                class QueueSummary(Entity):
                    """
                    queue summary info
                    
                    .. attribute:: del_cnt
                    
                    	number of objects in delete queues
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inline_cnt
                    
                    	number of objects in inline queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: retry_cnt
                    
                    	number of objects in retry queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_cnt
                    
                    	number of objects in update queues
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.QueueSummary, self).__init__()

                        self.yang_name = "queue-summary"
                        self.yang_parent_name = "l2fib-summary"

                        self.del_cnt = YLeaf(YType.uint32, "del-cnt")

                        self.inline_cnt = YLeaf(YType.uint32, "inline-cnt")

                        self.retry_cnt = YLeaf(YType.uint32, "retry-cnt")

                        self.update_cnt = YLeaf(YType.uint32, "update-cnt")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("del_cnt",
                                        "inline_cnt",
                                        "retry_cnt",
                                        "update_cnt") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.QueueSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibSummary.QueueSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.del_cnt.is_set or
                            self.inline_cnt.is_set or
                            self.retry_cnt.is_set or
                            self.update_cnt.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.del_cnt.yfilter != YFilter.not_set or
                            self.inline_cnt.yfilter != YFilter.not_set or
                            self.retry_cnt.yfilter != YFilter.not_set or
                            self.update_cnt.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "queue-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.del_cnt.is_set or self.del_cnt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.del_cnt.get_name_leafdata())
                        if (self.inline_cnt.is_set or self.inline_cnt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inline_cnt.get_name_leafdata())
                        if (self.retry_cnt.is_set or self.retry_cnt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.retry_cnt.get_name_leafdata())
                        if (self.update_cnt.is_set or self.update_cnt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.update_cnt.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "del-cnt" or name == "inline-cnt" or name == "retry-cnt" or name == "update-cnt"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "del-cnt"):
                            self.del_cnt = value
                            self.del_cnt.value_namespace = name_space
                            self.del_cnt.value_namespace_prefix = name_space_prefix
                        if(value_path == "inline-cnt"):
                            self.inline_cnt = value
                            self.inline_cnt.value_namespace = name_space
                            self.inline_cnt.value_namespace_prefix = name_space_prefix
                        if(value_path == "retry-cnt"):
                            self.retry_cnt = value
                            self.retry_cnt.value_namespace = name_space
                            self.retry_cnt.value_namespace_prefix = name_space_prefix
                        if(value_path == "update-cnt"):
                            self.update_cnt = value
                            self.update_cnt.value_namespace = name_space
                            self.update_cnt.value_namespace_prefix = name_space_prefix


                class EvpnSummary(Entity):
                    """
                    evpn summary info
                    
                    .. attribute:: default_count
                    
                    	Number of default leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: isid_count
                    
                    	Number of ISID leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_count
                    
                    	Number of EVPN Multicast Replication lists
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.EvpnSummary, self).__init__()

                        self.yang_name = "evpn-summary"
                        self.yang_parent_name = "l2fib-summary"

                        self.default_count = YLeaf(YType.uint32, "default-count")

                        self.isid_count = YLeaf(YType.uint32, "isid-count")

                        self.total_count = YLeaf(YType.uint32, "total-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("default_count",
                                        "isid_count",
                                        "total_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.EvpnSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibSummary.EvpnSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.default_count.is_set or
                            self.isid_count.is_set or
                            self.total_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.default_count.yfilter != YFilter.not_set or
                            self.isid_count.yfilter != YFilter.not_set or
                            self.total_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "evpn-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.default_count.is_set or self.default_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_count.get_name_leafdata())
                        if (self.isid_count.is_set or self.isid_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.isid_count.get_name_leafdata())
                        if (self.total_count.is_set or self.total_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-count" or name == "isid-count" or name == "total-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "default-count"):
                            self.default_count = value
                            self.default_count.value_namespace = name_space
                            self.default_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "isid-count"):
                            self.isid_count = value
                            self.isid_count.value_namespace = name_space
                            self.isid_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-count"):
                            self.total_count = value
                            self.total_count.value_namespace = name_space
                            self.total_count.value_namespace_prefix = name_space_prefix


                class GlobalCfg(Entity):
                    """
                    Global configuration
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg.Base>`
                    
                    .. attribute:: evpn_imc_label_block_base
                    
                    	Base of label range in use for EVPN IMC PD
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_imc_label_block_size
                    
                    	Size of label range in use for EVPN IMC PD
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: load_balance_type
                    
                    	Type of Load\-Balancing
                    	**type**\:   :py:class:`L2FibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBal>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg, self).__init__()

                        self.yang_name = "global-cfg"
                        self.yang_parent_name = "l2fib-summary"

                        self.evpn_imc_label_block_base = YLeaf(YType.uint32, "evpn-imc-label-block-base")

                        self.evpn_imc_label_block_size = YLeaf(YType.uint16, "evpn-imc-label-block-size")

                        self.load_balance_type = YLeaf(YType.enumeration, "load-balance-type")

                        self.base = L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._children_yang_names.add("base")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("evpn_imc_label_block_base",
                                        "evpn_imc_label_block_size",
                                        "load_balance_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg, self).__setattr__(name, value)


                    class Base(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "global-cfg"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "base" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.evpn_imc_label_block_base.is_set or
                            self.evpn_imc_label_block_size.is_set or
                            self.load_balance_type.is_set or
                            (self.base is not None and self.base.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.evpn_imc_label_block_base.yfilter != YFilter.not_set or
                            self.evpn_imc_label_block_size.yfilter != YFilter.not_set or
                            self.load_balance_type.yfilter != YFilter.not_set or
                            (self.base is not None and self.base.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "global-cfg" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.evpn_imc_label_block_base.is_set or self.evpn_imc_label_block_base.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_imc_label_block_base.get_name_leafdata())
                        if (self.evpn_imc_label_block_size.is_set or self.evpn_imc_label_block_size.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_imc_label_block_size.get_name_leafdata())
                        if (self.load_balance_type.is_set or self.load_balance_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "base"):
                            if (self.base is None):
                                self.base = L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                            return self.base

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "base" or name == "evpn-imc-label-block-base" or name == "evpn-imc-label-block-size" or name == "load-balance-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "evpn-imc-label-block-base"):
                            self.evpn_imc_label_block_base = value
                            self.evpn_imc_label_block_base.value_namespace = name_space
                            self.evpn_imc_label_block_base.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-imc-label-block-size"):
                            self.evpn_imc_label_block_size = value
                            self.evpn_imc_label_block_size.value_namespace = name_space
                            self.evpn_imc_label_block_size.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance-type"):
                            self.load_balance_type = value
                            self.load_balance_type.value_namespace = name_space
                            self.load_balance_type.value_namespace_prefix = name_space_prefix


                class PtreeSummary(Entity):
                    """
                    P2MP PTree summary info
                    
                    .. attribute:: lmrib_mldp_ptree_count
                    
                    	Number of MLDP PTree Objects owned by LMRIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lmrib_rsvp_te_ptree_count
                    
                    	Number of RSVP\-TE PTree Objects owned by LMRIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_enabled_ptree_count
                    
                    	Number of MLDP enabled PTree objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_enabled_ptree_count
                    
                    	Number of RSVP\-TE enabled PTree objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_ptree_count
                    
                    	Number of PTree objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.PtreeSummary, self).__init__()

                        self.yang_name = "ptree-summary"
                        self.yang_parent_name = "l2fib-summary"

                        self.lmrib_mldp_ptree_count = YLeaf(YType.uint32, "lmrib-mldp-ptree-count")

                        self.lmrib_rsvp_te_ptree_count = YLeaf(YType.uint32, "lmrib-rsvp-te-ptree-count")

                        self.mldp_enabled_ptree_count = YLeaf(YType.uint32, "mldp-enabled-ptree-count")

                        self.rsvp_te_enabled_ptree_count = YLeaf(YType.uint32, "rsvp-te-enabled-ptree-count")

                        self.total_ptree_count = YLeaf(YType.uint32, "total-ptree-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("lmrib_mldp_ptree_count",
                                        "lmrib_rsvp_te_ptree_count",
                                        "mldp_enabled_ptree_count",
                                        "rsvp_te_enabled_ptree_count",
                                        "total_ptree_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.PtreeSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibSummary.PtreeSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.lmrib_mldp_ptree_count.is_set or
                            self.lmrib_rsvp_te_ptree_count.is_set or
                            self.mldp_enabled_ptree_count.is_set or
                            self.rsvp_te_enabled_ptree_count.is_set or
                            self.total_ptree_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.lmrib_mldp_ptree_count.yfilter != YFilter.not_set or
                            self.lmrib_rsvp_te_ptree_count.yfilter != YFilter.not_set or
                            self.mldp_enabled_ptree_count.yfilter != YFilter.not_set or
                            self.rsvp_te_enabled_ptree_count.yfilter != YFilter.not_set or
                            self.total_ptree_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ptree-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.lmrib_mldp_ptree_count.is_set or self.lmrib_mldp_ptree_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lmrib_mldp_ptree_count.get_name_leafdata())
                        if (self.lmrib_rsvp_te_ptree_count.is_set or self.lmrib_rsvp_te_ptree_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lmrib_rsvp_te_ptree_count.get_name_leafdata())
                        if (self.mldp_enabled_ptree_count.is_set or self.mldp_enabled_ptree_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_enabled_ptree_count.get_name_leafdata())
                        if (self.rsvp_te_enabled_ptree_count.is_set or self.rsvp_te_enabled_ptree_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_enabled_ptree_count.get_name_leafdata())
                        if (self.total_ptree_count.is_set or self.total_ptree_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_ptree_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "lmrib-mldp-ptree-count" or name == "lmrib-rsvp-te-ptree-count" or name == "mldp-enabled-ptree-count" or name == "rsvp-te-enabled-ptree-count" or name == "total-ptree-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "lmrib-mldp-ptree-count"):
                            self.lmrib_mldp_ptree_count = value
                            self.lmrib_mldp_ptree_count.value_namespace = name_space
                            self.lmrib_mldp_ptree_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "lmrib-rsvp-te-ptree-count"):
                            self.lmrib_rsvp_te_ptree_count = value
                            self.lmrib_rsvp_te_ptree_count.value_namespace = name_space
                            self.lmrib_rsvp_te_ptree_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-enabled-ptree-count"):
                            self.mldp_enabled_ptree_count = value
                            self.mldp_enabled_ptree_count.value_namespace = name_space
                            self.mldp_enabled_ptree_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-enabled-ptree-count"):
                            self.rsvp_te_enabled_ptree_count = value
                            self.rsvp_te_enabled_ptree_count.value_namespace = name_space
                            self.rsvp_te_enabled_ptree_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-ptree-count"):
                            self.total_ptree_count = value
                            self.total_ptree_count.value_namespace = name_space
                            self.total_ptree_count.value_namespace_prefix = name_space_prefix


                class PwGroupSummary(Entity):
                    """
                    PWGroup summary info
                    
                    .. attribute:: plat_grouping_supported
                    
                    	Platform supports Grouping
                    	**type**\:  bool
                    
                    .. attribute:: pw_groups_down
                    
                    	Number of PWGROUP objects down
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_pw_groups
                    
                    	Total number of PWGROUP objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.PwGroupSummary, self).__init__()

                        self.yang_name = "pw-group-summary"
                        self.yang_parent_name = "l2fib-summary"

                        self.plat_grouping_supported = YLeaf(YType.boolean, "plat-grouping-supported")

                        self.pw_groups_down = YLeaf(YType.uint32, "pw-groups-down")

                        self.total_pw_groups = YLeaf(YType.uint32, "total-pw-groups")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("plat_grouping_supported",
                                        "pw_groups_down",
                                        "total_pw_groups") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.PwGroupSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibSummary.PwGroupSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.plat_grouping_supported.is_set or
                            self.pw_groups_down.is_set or
                            self.total_pw_groups.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.plat_grouping_supported.yfilter != YFilter.not_set or
                            self.pw_groups_down.yfilter != YFilter.not_set or
                            self.total_pw_groups.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pw-group-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.plat_grouping_supported.is_set or self.plat_grouping_supported.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.plat_grouping_supported.get_name_leafdata())
                        if (self.pw_groups_down.is_set or self.pw_groups_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_groups_down.get_name_leafdata())
                        if (self.total_pw_groups.is_set or self.total_pw_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_pw_groups.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "plat-grouping-supported" or name == "pw-groups-down" or name == "total-pw-groups"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "plat-grouping-supported"):
                            self.plat_grouping_supported = value
                            self.plat_grouping_supported.value_namespace = name_space
                            self.plat_grouping_supported.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-groups-down"):
                            self.pw_groups_down = value
                            self.pw_groups_down.value_namespace = name_space
                            self.pw_groups_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-pw-groups"):
                            self.total_pw_groups = value
                            self.total_pw_groups.value_namespace = name_space
                            self.total_pw_groups.value_namespace_prefix = name_space_prefix


                class PwheMpSummary(Entity):
                    """
                    PWHE Main\-port summary info
                    
                    .. attribute:: total_count
                    
                    	Number of PWHE Main\-ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibSummary.PwheMpSummary, self).__init__()

                        self.yang_name = "pwhe-mp-summary"
                        self.yang_parent_name = "l2fib-summary"

                        self.total_count = YLeaf(YType.uint32, "total-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("total_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibSummary.PwheMpSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibSummary.PwheMpSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return self.total_count.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.total_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pwhe-mp-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.total_count.is_set or self.total_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "total-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "total-count"):
                            self.total_count = value
                            self.total_count.value_namespace = name_space
                            self.total_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        (self.bridge_domain_summary is not None and self.bridge_domain_summary.has_data()) or
                        (self.evpn_summary is not None and self.evpn_summary.has_data()) or
                        (self.global_cfg is not None and self.global_cfg.has_data()) or
                        (self.l2tp_disposition_summary is not None and self.l2tp_disposition_summary.has_data()) or
                        (self.mac_summary is not None and self.mac_summary.has_data()) or
                        (self.next_hop_summary is not None and self.next_hop_summary.has_data()) or
                        (self.ptree_summary is not None and self.ptree_summary.has_data()) or
                        (self.pw_group_summary is not None and self.pw_group_summary.has_data()) or
                        (self.pwhe_mp_summary is not None and self.pwhe_mp_summary.has_data()) or
                        (self.queue_summary is not None and self.queue_summary.has_data()) or
                        (self.xconnect_summary is not None and self.xconnect_summary.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bridge_domain_summary is not None and self.bridge_domain_summary.has_operation()) or
                        (self.evpn_summary is not None and self.evpn_summary.has_operation()) or
                        (self.global_cfg is not None and self.global_cfg.has_operation()) or
                        (self.l2tp_disposition_summary is not None and self.l2tp_disposition_summary.has_operation()) or
                        (self.mac_summary is not None and self.mac_summary.has_operation()) or
                        (self.next_hop_summary is not None and self.next_hop_summary.has_operation()) or
                        (self.ptree_summary is not None and self.ptree_summary.has_operation()) or
                        (self.pw_group_summary is not None and self.pw_group_summary.has_operation()) or
                        (self.pwhe_mp_summary is not None and self.pwhe_mp_summary.has_operation()) or
                        (self.queue_summary is not None and self.queue_summary.has_operation()) or
                        (self.xconnect_summary is not None and self.xconnect_summary.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bridge-domain-summary"):
                        if (self.bridge_domain_summary is None):
                            self.bridge_domain_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.BridgeDomainSummary()
                            self.bridge_domain_summary.parent = self
                            self._children_name_map["bridge_domain_summary"] = "bridge-domain-summary"
                        return self.bridge_domain_summary

                    if (child_yang_name == "evpn-summary"):
                        if (self.evpn_summary is None):
                            self.evpn_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.EvpnSummary()
                            self.evpn_summary.parent = self
                            self._children_name_map["evpn_summary"] = "evpn-summary"
                        return self.evpn_summary

                    if (child_yang_name == "global-cfg"):
                        if (self.global_cfg is None):
                            self.global_cfg = L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg()
                            self.global_cfg.parent = self
                            self._children_name_map["global_cfg"] = "global-cfg"
                        return self.global_cfg

                    if (child_yang_name == "l2tp-disposition-summary"):
                        if (self.l2tp_disposition_summary is None):
                            self.l2tp_disposition_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.L2TpDispositionSummary()
                            self.l2tp_disposition_summary.parent = self
                            self._children_name_map["l2tp_disposition_summary"] = "l2tp-disposition-summary"
                        return self.l2tp_disposition_summary

                    if (child_yang_name == "mac-summary"):
                        if (self.mac_summary is None):
                            self.mac_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.MacSummary()
                            self.mac_summary.parent = self
                            self._children_name_map["mac_summary"] = "mac-summary"
                        return self.mac_summary

                    if (child_yang_name == "next-hop-summary"):
                        if (self.next_hop_summary is None):
                            self.next_hop_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary()
                            self.next_hop_summary.parent = self
                            self._children_name_map["next_hop_summary"] = "next-hop-summary"
                        return self.next_hop_summary

                    if (child_yang_name == "ptree-summary"):
                        if (self.ptree_summary is None):
                            self.ptree_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.PtreeSummary()
                            self.ptree_summary.parent = self
                            self._children_name_map["ptree_summary"] = "ptree-summary"
                        return self.ptree_summary

                    if (child_yang_name == "pw-group-summary"):
                        if (self.pw_group_summary is None):
                            self.pw_group_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.PwGroupSummary()
                            self.pw_group_summary.parent = self
                            self._children_name_map["pw_group_summary"] = "pw-group-summary"
                        return self.pw_group_summary

                    if (child_yang_name == "pwhe-mp-summary"):
                        if (self.pwhe_mp_summary is None):
                            self.pwhe_mp_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.PwheMpSummary()
                            self.pwhe_mp_summary.parent = self
                            self._children_name_map["pwhe_mp_summary"] = "pwhe-mp-summary"
                        return self.pwhe_mp_summary

                    if (child_yang_name == "queue-summary"):
                        if (self.queue_summary is None):
                            self.queue_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.QueueSummary()
                            self.queue_summary.parent = self
                            self._children_name_map["queue_summary"] = "queue-summary"
                        return self.queue_summary

                    if (child_yang_name == "xconnect-summary"):
                        if (self.xconnect_summary is None):
                            self.xconnect_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.XconnectSummary()
                            self.xconnect_summary.parent = self
                            self._children_name_map["xconnect_summary"] = "xconnect-summary"
                        return self.xconnect_summary

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bridge-domain-summary" or name == "evpn-summary" or name == "global-cfg" or name == "l2tp-disposition-summary" or name == "mac-summary" or name == "next-hop-summary" or name == "ptree-summary" or name == "pw-group-summary" or name == "pwhe-mp-summary" or name == "queue-summary" or name == "xconnect-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibNvePeers(Entity):
                """
                NVE Peer Table
                
                .. attribute:: l2fib_nve_peer
                
                	The attributes for a particular NVE Peer
                	**type**\: list of    :py:class:`L2FibNvePeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibNvePeers.L2FibNvePeer>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibNvePeers, self).__init__()

                    self.yang_name = "l2fib-nve-peers"
                    self.yang_parent_name = "node"

                    self.l2fib_nve_peer = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibNvePeers, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibNvePeers, self).__setattr__(name, value)


                class L2FibNvePeer(Entity):
                    """
                    The attributes for a particular NVE Peer
                    
                    .. attribute:: nve_if
                    
                    	Parent NVE IF Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: vn_iid
                    
                    	VNI ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vniid
                    
                    	VNI ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: vte_pip
                    
                    	Peer VTEP IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vtep_address
                    
                    	VTEP IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: xc_uint_id
                    
                    	XC ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibNvePeers.L2FibNvePeer, self).__init__()

                        self.yang_name = "l2fib-nve-peer"
                        self.yang_parent_name = "l2fib-nve-peers"

                        self.nve_if = YLeaf(YType.str, "nve-if")

                        self.vn_iid = YLeaf(YType.uint32, "vn-iid")

                        self.vniid = YLeaf(YType.str, "vniid")

                        self.vte_pip = YLeaf(YType.str, "vte-pip")

                        self.vtep_address = YLeaf(YType.str, "vtep-address")

                        self.xc_uint_id = YLeaf(YType.str, "xc-uint-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("nve_if",
                                        "vn_iid",
                                        "vniid",
                                        "vte_pip",
                                        "vtep_address",
                                        "xc_uint_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibNvePeers.L2FibNvePeer, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibNvePeers.L2FibNvePeer, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.nve_if.is_set or
                            self.vn_iid.is_set or
                            self.vniid.is_set or
                            self.vte_pip.is_set or
                            self.vtep_address.is_set or
                            self.xc_uint_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.nve_if.yfilter != YFilter.not_set or
                            self.vn_iid.yfilter != YFilter.not_set or
                            self.vniid.yfilter != YFilter.not_set or
                            self.vte_pip.yfilter != YFilter.not_set or
                            self.vtep_address.yfilter != YFilter.not_set or
                            self.xc_uint_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-nve-peer" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.nve_if.is_set or self.nve_if.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nve_if.get_name_leafdata())
                        if (self.vn_iid.is_set or self.vn_iid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vn_iid.get_name_leafdata())
                        if (self.vniid.is_set or self.vniid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vniid.get_name_leafdata())
                        if (self.vte_pip.is_set or self.vte_pip.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vte_pip.get_name_leafdata())
                        if (self.vtep_address.is_set or self.vtep_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vtep_address.get_name_leafdata())
                        if (self.xc_uint_id.is_set or self.xc_uint_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xc_uint_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "nve-if" or name == "vn-iid" or name == "vniid" or name == "vte-pip" or name == "vtep-address" or name == "xc-uint-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "nve-if"):
                            self.nve_if = value
                            self.nve_if.value_namespace = name_space
                            self.nve_if.value_namespace_prefix = name_space_prefix
                        if(value_path == "vn-iid"):
                            self.vn_iid = value
                            self.vn_iid.value_namespace = name_space
                            self.vn_iid.value_namespace_prefix = name_space_prefix
                        if(value_path == "vniid"):
                            self.vniid = value
                            self.vniid.value_namespace = name_space
                            self.vniid.value_namespace_prefix = name_space_prefix
                        if(value_path == "vte-pip"):
                            self.vte_pip = value
                            self.vte_pip.value_namespace = name_space
                            self.vte_pip.value_namespace_prefix = name_space_prefix
                        if(value_path == "vtep-address"):
                            self.vtep_address = value
                            self.vtep_address.value_namespace = name_space
                            self.vtep_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "xc-uint-id"):
                            self.xc_uint_id = value
                            self.xc_uint_id.value_namespace = name_space
                            self.xc_uint_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_nve_peer:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_nve_peer:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-nve-peers" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-nve-peer"):
                        for c in self.l2fib_nve_peer:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibNvePeers.L2FibNvePeer()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_nve_peer.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-nve-peer"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibMmrps(Entity):
                """
                mmmrp information
                
                .. attribute:: l2fib_mmrp
                
                	Bridge Domain Mmrp Information
                	**type**\: list of    :py:class:`L2FibMmrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps, self).__init__()

                    self.yang_name = "l2fib-mmrps"
                    self.yang_parent_name = "node"

                    self.l2fib_mmrp = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibMmrps, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibMmrps, self).__setattr__(name, value)


                class L2FibMmrp(Entity):
                    """
                    Bridge Domain Mmrp Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\:  str
                    
                    	**length:** 0..66
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:   :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:   :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats>`
                    
                    .. attribute:: group
                    
                    	Group Mac Address
                    	**type**\:  str
                    
                    	**length:** 1..15
                    
                    .. attribute:: hardware_information
                    
                    	Platform Hardware info
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: irb_info
                    
                    	IRB Information
                    	**type**\:   :py:class:`IrbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.IrbInfo>`
                    
                    .. attribute:: multicast_base_information
                    
                    	Base Information
                    	**type**\:   :py:class:`MulticastBaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.MulticastBaseInformation>`
                    
                    .. attribute:: platform_data
                    
                    	The mcast platform data
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: platform_data_length
                    
                    	The mcast platform data len
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: source
                    
                    	src Mac Address
                    	**type**\:  str
                    
                    	**length:** 1..15
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:   :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.SourcePrefix>`
                    
                    .. attribute:: xid_count
                    
                    	Count of XIDs
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp, self).__init__()

                        self.yang_name = "l2fib-mmrp"
                        self.yang_parent_name = "l2fib-mmrps"

                        self.bd_group_name = YLeaf(YType.str, "bd-group-name")

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                        self.bridge_id = YLeaf(YType.uint32, "bridge-id")

                        self.group = YLeaf(YType.str, "group")

                        self.hardware_information = YLeaf(YType.str, "hardware-information")

                        self.platform_data = YLeaf(YType.str, "platform-data")

                        self.platform_data_length = YLeaf(YType.uint8, "platform-data-length")

                        self.source = YLeaf(YType.str, "source")

                        self.xid_count = YLeaf(YType.uint16, "xid-count")

                        self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self._children_name_map["destination_prefix"] = "destination-prefix"
                        self._children_yang_names.add("destination-prefix")

                        self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats()
                        self.forward_stats.parent = self
                        self._children_name_map["forward_stats"] = "forward-stats"
                        self._children_yang_names.add("forward-stats")

                        self.irb_info = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.IrbInfo()
                        self.irb_info.parent = self
                        self._children_name_map["irb_info"] = "irb-info"
                        self._children_yang_names.add("irb-info")

                        self.multicast_base_information = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.MulticastBaseInformation()
                        self.multicast_base_information.parent = self
                        self._children_name_map["multicast_base_information"] = "multicast-base-information"
                        self._children_yang_names.add("multicast-base-information")

                        self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.SourcePrefix()
                        self.source_prefix.parent = self
                        self._children_name_map["source_prefix"] = "source-prefix"
                        self._children_yang_names.add("source-prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bd_group_name",
                                        "bd_name",
                                        "bridge_domain_name",
                                        "bridge_id",
                                        "group",
                                        "hardware_information",
                                        "platform_data",
                                        "platform_data_length",
                                        "source",
                                        "xid_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp, self).__setattr__(name, value)


                    class MulticastBaseInformation(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.MulticastBaseInformation, self).__init__()

                            self.yang_name = "multicast-base-information"
                            self.yang_parent_name = "l2fib-mmrp"

                        def has_data(self):
                            return False

                        def has_operation(self):
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "multicast-base-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SourcePrefix(Entity):
                        """
                        Source Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.SourcePrefix, self).__init__()

                            self.yang_name = "source-prefix"
                            self.yang_parent_name = "l2fib-mmrp"

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                            self.proto = YLeaf(YType.uint8, "proto")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix",
                                            "prefix_length",
                                            "proto") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.SourcePrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.SourcePrefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.proto.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proto.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proto.is_set or self.proto.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proto.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "prefix-length" or name == "proto"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proto"):
                                self.proto = value
                                self.proto.value_namespace = name_space
                                self.proto.value_namespace_prefix = name_space_prefix


                    class DestinationPrefix(Entity):
                        """
                        Destination Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.DestinationPrefix, self).__init__()

                            self.yang_name = "destination-prefix"
                            self.yang_parent_name = "l2fib-mmrp"

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                            self.proto = YLeaf(YType.uint8, "proto")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix",
                                            "prefix_length",
                                            "proto") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.DestinationPrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.DestinationPrefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.proto.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proto.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "destination-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proto.is_set or self.proto.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proto.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "prefix-length" or name == "proto"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proto"):
                                self.proto = value
                                self.proto.value_namespace = name_space
                                self.proto.value_namespace_prefix = name_space_prefix


                    class ForwardStats(Entity):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:   :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats, self).__init__()

                            self.yang_name = "forward-stats"
                            self.yang_parent_name = "l2fib-mmrp"

                            self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self
                            self._children_name_map["forward_stat"] = "forward-stat"
                            self._children_yang_names.add("forward-stat")


                        class ForwardStat(Entity):
                            """
                            fwd stats
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:   :py:class:`MgmtL2FibStatsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibStatsData>`
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:   :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat, self).__init__()

                                self.yang_name = "forward-stat"
                                self.yang_parent_name = "forward-stats"

                                self.data_type = YLeaf(YType.enumeration, "data-type")

                                self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self
                                self._children_name_map["mulicast"] = "mulicast"
                                self._children_yang_names.add("mulicast")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("data_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat, self).__setattr__(name, value)


                            class Mulicast(Entity):
                                """
                                mulicast
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:   :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:   :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:   :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:   :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:   :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:   :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast, self).__init__()

                                    self.yang_name = "mulicast"
                                    self.yang_parent_name = "forward-stat"

                                    self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self._children_name_map["core_received_stat"] = "core-received-stat"
                                    self._children_yang_names.add("core-received-stat")

                                    self.drop = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self._children_name_map["drop"] = "drop"
                                    self._children_yang_names.add("drop")

                                    self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"
                                    self._children_yang_names.add("multicast-core-forward-stat")

                                    self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"
                                    self._children_yang_names.add("multicast-forward-stat")

                                    self.punt = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self._children_name_map["punt"] = "punt"
                                    self._children_yang_names.add("punt")

                                    self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self
                                    self._children_name_map["received_stat"] = "received-stat"
                                    self._children_yang_names.add("received-stat")


                                class MulticastForwardStat(Entity):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__init__()

                                        self.yang_name = "multicast-forward-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-forward-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class ReceivedStat(Entity):
                                    """
                                    received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__init__()

                                        self.yang_name = "received-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class Punt(Entity):
                                    """
                                    punted stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Punt, self).__init__()

                                        self.yang_name = "punt"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Punt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Punt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "punt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class Drop(Entity):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Drop, self).__init__()

                                        self.yang_name = "drop"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Drop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Drop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class MulticastCoreForwardStat(Entity):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__init__()

                                        self.yang_name = "multicast-core-forward-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-core-forward-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix


                                class CoreReceivedStat(Entity):
                                    """
                                    core received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__init__()

                                        self.yang_name = "core-received-stat"
                                        self.yang_parent_name = "mulicast"

                                        self.bytes = YLeaf(YType.uint64, "bytes")

                                        self.packets = YLeaf(YType.uint64, "packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bytes",
                                                        "packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bytes.is_set or
                                            self.packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bytes.yfilter != YFilter.not_set or
                                            self.packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "core-received-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bytes.is_set or self.bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bytes.get_name_leafdata())
                                        if (self.packets.is_set or self.packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bytes" or name == "packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bytes"):
                                            self.bytes = value
                                            self.bytes.value_namespace = name_space
                                            self.bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packets"):
                                            self.packets = value
                                            self.packets.value_namespace = name_space
                                            self.packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.core_received_stat is not None and self.core_received_stat.has_data()) or
                                        (self.drop is not None and self.drop.has_data()) or
                                        (self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat.has_data()) or
                                        (self.multicast_forward_stat is not None and self.multicast_forward_stat.has_data()) or
                                        (self.punt is not None and self.punt.has_data()) or
                                        (self.received_stat is not None and self.received_stat.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.core_received_stat is not None and self.core_received_stat.has_operation()) or
                                        (self.drop is not None and self.drop.has_operation()) or
                                        (self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat.has_operation()) or
                                        (self.multicast_forward_stat is not None and self.multicast_forward_stat.has_operation()) or
                                        (self.punt is not None and self.punt.has_operation()) or
                                        (self.received_stat is not None and self.received_stat.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mulicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "core-received-stat"):
                                        if (self.core_received_stat is None):
                                            self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                            self.core_received_stat.parent = self
                                            self._children_name_map["core_received_stat"] = "core-received-stat"
                                        return self.core_received_stat

                                    if (child_yang_name == "drop"):
                                        if (self.drop is None):
                                            self.drop = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Drop()
                                            self.drop.parent = self
                                            self._children_name_map["drop"] = "drop"
                                        return self.drop

                                    if (child_yang_name == "multicast-core-forward-stat"):
                                        if (self.multicast_core_forward_stat is None):
                                            self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                            self.multicast_core_forward_stat.parent = self
                                            self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"
                                        return self.multicast_core_forward_stat

                                    if (child_yang_name == "multicast-forward-stat"):
                                        if (self.multicast_forward_stat is None):
                                            self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                            self.multicast_forward_stat.parent = self
                                            self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"
                                        return self.multicast_forward_stat

                                    if (child_yang_name == "punt"):
                                        if (self.punt is None):
                                            self.punt = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Punt()
                                            self.punt.parent = self
                                            self._children_name_map["punt"] = "punt"
                                        return self.punt

                                    if (child_yang_name == "received-stat"):
                                        if (self.received_stat is None):
                                            self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                            self.received_stat.parent = self
                                            self._children_name_map["received_stat"] = "received-stat"
                                        return self.received_stat

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "core-received-stat" or name == "drop" or name == "multicast-core-forward-stat" or name == "multicast-forward-stat" or name == "punt" or name == "received-stat"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.data_type.is_set or
                                    (self.mulicast is not None and self.mulicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.data_type.yfilter != YFilter.not_set or
                                    (self.mulicast is not None and self.mulicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "forward-stat" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.data_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mulicast"):
                                    if (self.mulicast is None):
                                        self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast()
                                        self.mulicast.parent = self
                                        self._children_name_map["mulicast"] = "mulicast"
                                    return self.mulicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mulicast" or name == "data-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "data-type"):
                                    self.data_type = value
                                    self.data_type.value_namespace = name_space
                                    self.data_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.forward_stat is not None and self.forward_stat.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.forward_stat is not None and self.forward_stat.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "forward-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "forward-stat"):
                                if (self.forward_stat is None):
                                    self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat()
                                    self.forward_stat.parent = self
                                    self._children_name_map["forward_stat"] = "forward-stat"
                                return self.forward_stat

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "forward-stat"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class IrbInfo(Entity):
                        """
                        IRB Information
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        .. attribute:: mxid_ac_interface_handle
                        
                        	Master XID AC If handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mxid_next_hop_address
                        
                        	Master XID NHOP IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mxid_pw_id
                        
                        	Master XID PW ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.IrbInfo, self).__init__()

                            self.yang_name = "irb-info"
                            self.yang_parent_name = "l2fib-mmrp"

                            self.irb_plat_data = YLeafList(YType.uint32, "irb-plat-data")

                            self.irb_plat_data_len = YLeaf(YType.uint16, "irb-plat-data-len")

                            self.mxid_ac_interface_handle = YLeaf(YType.str, "mxid-ac-interface-handle")

                            self.mxid_next_hop_address = YLeaf(YType.str, "mxid-next-hop-address")

                            self.mxid_pw_id = YLeaf(YType.uint32, "mxid-pw-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("irb_plat_data",
                                            "irb_plat_data_len",
                                            "mxid_ac_interface_handle",
                                            "mxid_next_hop_address",
                                            "mxid_pw_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.IrbInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.IrbInfo, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.irb_plat_data.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.irb_plat_data_len.is_set or
                                self.mxid_ac_interface_handle.is_set or
                                self.mxid_next_hop_address.is_set or
                                self.mxid_pw_id.is_set)

                        def has_operation(self):
                            for leaf in self.irb_plat_data.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.irb_plat_data.yfilter != YFilter.not_set or
                                self.irb_plat_data_len.yfilter != YFilter.not_set or
                                self.mxid_ac_interface_handle.yfilter != YFilter.not_set or
                                self.mxid_next_hop_address.yfilter != YFilter.not_set or
                                self.mxid_pw_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "irb-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.irb_plat_data_len.is_set or self.irb_plat_data_len.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.irb_plat_data_len.get_name_leafdata())
                            if (self.mxid_ac_interface_handle.is_set or self.mxid_ac_interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mxid_ac_interface_handle.get_name_leafdata())
                            if (self.mxid_next_hop_address.is_set or self.mxid_next_hop_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mxid_next_hop_address.get_name_leafdata())
                            if (self.mxid_pw_id.is_set or self.mxid_pw_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mxid_pw_id.get_name_leafdata())

                            leaf_name_data.extend(self.irb_plat_data.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "irb-plat-data" or name == "irb-plat-data-len" or name == "mxid-ac-interface-handle" or name == "mxid-next-hop-address" or name == "mxid-pw-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "irb-plat-data"):
                                self.irb_plat_data.append(value)
                            if(value_path == "irb-plat-data-len"):
                                self.irb_plat_data_len = value
                                self.irb_plat_data_len.value_namespace = name_space
                                self.irb_plat_data_len.value_namespace_prefix = name_space_prefix
                            if(value_path == "mxid-ac-interface-handle"):
                                self.mxid_ac_interface_handle = value
                                self.mxid_ac_interface_handle.value_namespace = name_space
                                self.mxid_ac_interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "mxid-next-hop-address"):
                                self.mxid_next_hop_address = value
                                self.mxid_next_hop_address.value_namespace = name_space
                                self.mxid_next_hop_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mxid-pw-id"):
                                self.mxid_pw_id = value
                                self.mxid_pw_id.value_namespace = name_space
                                self.mxid_pw_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bd_group_name.is_set or
                            self.bd_name.is_set or
                            self.bridge_domain_name.is_set or
                            self.bridge_id.is_set or
                            self.group.is_set or
                            self.hardware_information.is_set or
                            self.platform_data.is_set or
                            self.platform_data_length.is_set or
                            self.source.is_set or
                            self.xid_count.is_set or
                            (self.destination_prefix is not None and self.destination_prefix.has_data()) or
                            (self.forward_stats is not None and self.forward_stats.has_data()) or
                            (self.irb_info is not None and self.irb_info.has_data()) or
                            (self.multicast_base_information is not None and self.multicast_base_information.has_data()) or
                            (self.source_prefix is not None and self.source_prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bd_group_name.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            self.bridge_domain_name.yfilter != YFilter.not_set or
                            self.bridge_id.yfilter != YFilter.not_set or
                            self.group.yfilter != YFilter.not_set or
                            self.hardware_information.yfilter != YFilter.not_set or
                            self.platform_data.yfilter != YFilter.not_set or
                            self.platform_data_length.yfilter != YFilter.not_set or
                            self.source.yfilter != YFilter.not_set or
                            self.xid_count.yfilter != YFilter.not_set or
                            (self.destination_prefix is not None and self.destination_prefix.has_operation()) or
                            (self.forward_stats is not None and self.forward_stats.has_operation()) or
                            (self.irb_info is not None and self.irb_info.has_operation()) or
                            (self.multicast_base_information is not None and self.multicast_base_information.has_operation()) or
                            (self.source_prefix is not None and self.source_prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-mmrp" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bd_group_name.is_set or self.bd_group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_group_name.get_name_leafdata())
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())
                        if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                        if (self.bridge_id.is_set or self.bridge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_id.get_name_leafdata())
                        if (self.group.is_set or self.group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group.get_name_leafdata())
                        if (self.hardware_information.is_set or self.hardware_information.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hardware_information.get_name_leafdata())
                        if (self.platform_data.is_set or self.platform_data.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.platform_data.get_name_leafdata())
                        if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.platform_data_length.get_name_leafdata())
                        if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source.get_name_leafdata())
                        if (self.xid_count.is_set or self.xid_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xid_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "destination-prefix"):
                            if (self.destination_prefix is None):
                                self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.DestinationPrefix()
                                self.destination_prefix.parent = self
                                self._children_name_map["destination_prefix"] = "destination-prefix"
                            return self.destination_prefix

                        if (child_yang_name == "forward-stats"):
                            if (self.forward_stats is None):
                                self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats()
                                self.forward_stats.parent = self
                                self._children_name_map["forward_stats"] = "forward-stats"
                            return self.forward_stats

                        if (child_yang_name == "irb-info"):
                            if (self.irb_info is None):
                                self.irb_info = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.IrbInfo()
                                self.irb_info.parent = self
                                self._children_name_map["irb_info"] = "irb-info"
                            return self.irb_info

                        if (child_yang_name == "multicast-base-information"):
                            if (self.multicast_base_information is None):
                                self.multicast_base_information = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.MulticastBaseInformation()
                                self.multicast_base_information.parent = self
                                self._children_name_map["multicast_base_information"] = "multicast-base-information"
                            return self.multicast_base_information

                        if (child_yang_name == "source-prefix"):
                            if (self.source_prefix is None):
                                self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.SourcePrefix()
                                self.source_prefix.parent = self
                                self._children_name_map["source_prefix"] = "source-prefix"
                            return self.source_prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "destination-prefix" or name == "forward-stats" or name == "irb-info" or name == "multicast-base-information" or name == "source-prefix" or name == "bd-group-name" or name == "bd-name" or name == "bridge-domain-name" or name == "bridge-id" or name == "group" or name == "hardware-information" or name == "platform-data" or name == "platform-data-length" or name == "source" or name == "xid-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bd-group-name"):
                            self.bd_group_name = value
                            self.bd_group_name.value_namespace = name_space
                            self.bd_group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-name"):
                            self.bridge_domain_name = value
                            self.bridge_domain_name.value_namespace = name_space
                            self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-id"):
                            self.bridge_id = value
                            self.bridge_id.value_namespace = name_space
                            self.bridge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "group"):
                            self.group = value
                            self.group.value_namespace = name_space
                            self.group.value_namespace_prefix = name_space_prefix
                        if(value_path == "hardware-information"):
                            self.hardware_information = value
                            self.hardware_information.value_namespace = name_space
                            self.hardware_information.value_namespace_prefix = name_space_prefix
                        if(value_path == "platform-data"):
                            self.platform_data = value
                            self.platform_data.value_namespace = name_space
                            self.platform_data.value_namespace_prefix = name_space_prefix
                        if(value_path == "platform-data-length"):
                            self.platform_data_length = value
                            self.platform_data_length.value_namespace = name_space
                            self.platform_data_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "source"):
                            self.source = value
                            self.source.value_namespace = name_space
                            self.source.value_namespace_prefix = name_space_prefix
                        if(value_path == "xid-count"):
                            self.xid_count = value
                            self.xid_count.value_namespace = name_space
                            self.xid_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_mmrp:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_mmrp:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-mmrps" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-mmrp"):
                        for c in self.l2fib_mmrp:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_mmrp.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-mmrp"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibEvpnIp6Macs(Entity):
                """
                EVPN IPv6\-MAC Table
                
                .. attribute:: l2fib_evpn_ip6mac
                
                	The attributes for a particular EVPN IPv6\-MAC Entry
                	**type**\: list of    :py:class:`L2FibEvpnIp6Mac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs, self).__init__()

                    self.yang_name = "l2fib-evpn-ip6macs"
                    self.yang_parent_name = "node"

                    self.l2fib_evpn_ip6mac = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs, self).__setattr__(name, value)


                class L2FibEvpnIp6Mac(Entity):
                    """
                    The attributes for a particular EVPN IPv6\-MAC
                    Entry
                    
                    .. attribute:: arp_nd_delete_pending
                    
                    	Delete to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: arp_nd_probe_pending
                    
                    	Probe to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: arp_nd_sync_pending
                    
                    	Sync to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: bdid
                    
                    	BD ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: bdid_xr
                    
                    	BD ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ip_address
                    
                    	IP Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: ip_address_xr
                    
                    	IP Address
                    	**type**\:   :py:class:`IpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac.IpAddressXr>`
                    
                    .. attribute:: is_local
                    
                    	Entry is locally learned
                    	**type**\:  bool
                    
                    .. attribute:: is_local_xr
                    
                    	IP\-MAC Route is locally learned
                    	**type**\:  bool
                    
                    .. attribute:: mac_address
                    
                    	MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: mac_address_xr
                    
                    	MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac, self).__init__()

                        self.yang_name = "l2fib-evpn-ip6mac"
                        self.yang_parent_name = "l2fib-evpn-ip6macs"

                        self.arp_nd_delete_pending = YLeaf(YType.boolean, "arp-nd-delete-pending")

                        self.arp_nd_probe_pending = YLeaf(YType.boolean, "arp-nd-probe-pending")

                        self.arp_nd_sync_pending = YLeaf(YType.boolean, "arp-nd-sync-pending")

                        self.bdid = YLeaf(YType.int32, "bdid")

                        self.bdid_xr = YLeaf(YType.uint32, "bdid-xr")

                        self.ip_address = YLeaf(YType.str, "ip-address")

                        self.is_local = YLeaf(YType.boolean, "is-local")

                        self.is_local_xr = YLeaf(YType.boolean, "is-local-xr")

                        self.mac_address = YLeaf(YType.str, "mac-address")

                        self.mac_address_xr = YLeaf(YType.str, "mac-address-xr")

                        self.ip_address_xr = L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac.IpAddressXr()
                        self.ip_address_xr.parent = self
                        self._children_name_map["ip_address_xr"] = "ip-address-xr"
                        self._children_yang_names.add("ip-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("arp_nd_delete_pending",
                                        "arp_nd_probe_pending",
                                        "arp_nd_sync_pending",
                                        "bdid",
                                        "bdid_xr",
                                        "ip_address",
                                        "is_local",
                                        "is_local_xr",
                                        "mac_address",
                                        "mac_address_xr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac, self).__setattr__(name, value)


                    class IpAddressXr(Entity):
                        """
                        IP Address
                        
                        .. attribute:: addr_type
                        
                        	addr type
                        	**type**\:   :py:class:`L2FibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibIpAddr>`
                        
                        .. attribute:: ip
                        
                        	ip
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac.IpAddressXr, self).__init__()

                            self.yang_name = "ip-address-xr"
                            self.yang_parent_name = "l2fib-evpn-ip6mac"

                            self.addr_type = YLeaf(YType.enumeration, "addr-type")

                            self.ip = YLeaf(YType.str, "ip")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("addr_type",
                                            "ip") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac.IpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac.IpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.addr_type.is_set or
                                self.ip.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.addr_type.yfilter != YFilter.not_set or
                                self.ip.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ip-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.addr_type.is_set or self.addr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.addr_type.get_name_leafdata())
                            if (self.ip.is_set or self.ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ip.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "addr-type" or name == "ip"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "addr-type"):
                                self.addr_type = value
                                self.addr_type.value_namespace = name_space
                                self.addr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "ip"):
                                self.ip = value
                                self.ip.value_namespace = name_space
                                self.ip.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.arp_nd_delete_pending.is_set or
                            self.arp_nd_probe_pending.is_set or
                            self.arp_nd_sync_pending.is_set or
                            self.bdid.is_set or
                            self.bdid_xr.is_set or
                            self.ip_address.is_set or
                            self.is_local.is_set or
                            self.is_local_xr.is_set or
                            self.mac_address.is_set or
                            self.mac_address_xr.is_set or
                            (self.ip_address_xr is not None and self.ip_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.arp_nd_delete_pending.yfilter != YFilter.not_set or
                            self.arp_nd_probe_pending.yfilter != YFilter.not_set or
                            self.arp_nd_sync_pending.yfilter != YFilter.not_set or
                            self.bdid.yfilter != YFilter.not_set or
                            self.bdid_xr.yfilter != YFilter.not_set or
                            self.ip_address.yfilter != YFilter.not_set or
                            self.is_local.yfilter != YFilter.not_set or
                            self.is_local_xr.yfilter != YFilter.not_set or
                            self.mac_address.yfilter != YFilter.not_set or
                            self.mac_address_xr.yfilter != YFilter.not_set or
                            (self.ip_address_xr is not None and self.ip_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-evpn-ip6mac" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.arp_nd_delete_pending.is_set or self.arp_nd_delete_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.arp_nd_delete_pending.get_name_leafdata())
                        if (self.arp_nd_probe_pending.is_set or self.arp_nd_probe_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.arp_nd_probe_pending.get_name_leafdata())
                        if (self.arp_nd_sync_pending.is_set or self.arp_nd_sync_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.arp_nd_sync_pending.get_name_leafdata())
                        if (self.bdid.is_set or self.bdid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bdid.get_name_leafdata())
                        if (self.bdid_xr.is_set or self.bdid_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bdid_xr.get_name_leafdata())
                        if (self.ip_address.is_set or self.ip_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ip_address.get_name_leafdata())
                        if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_local.get_name_leafdata())
                        if (self.is_local_xr.is_set or self.is_local_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_local_xr.get_name_leafdata())
                        if (self.mac_address.is_set or self.mac_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_address.get_name_leafdata())
                        if (self.mac_address_xr.is_set or self.mac_address_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_address_xr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ip-address-xr"):
                            if (self.ip_address_xr is None):
                                self.ip_address_xr = L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac.IpAddressXr()
                                self.ip_address_xr.parent = self
                                self._children_name_map["ip_address_xr"] = "ip-address-xr"
                            return self.ip_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ip-address-xr" or name == "arp-nd-delete-pending" or name == "arp-nd-probe-pending" or name == "arp-nd-sync-pending" or name == "bdid" or name == "bdid-xr" or name == "ip-address" or name == "is-local" or name == "is-local-xr" or name == "mac-address" or name == "mac-address-xr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "arp-nd-delete-pending"):
                            self.arp_nd_delete_pending = value
                            self.arp_nd_delete_pending.value_namespace = name_space
                            self.arp_nd_delete_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "arp-nd-probe-pending"):
                            self.arp_nd_probe_pending = value
                            self.arp_nd_probe_pending.value_namespace = name_space
                            self.arp_nd_probe_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "arp-nd-sync-pending"):
                            self.arp_nd_sync_pending = value
                            self.arp_nd_sync_pending.value_namespace = name_space
                            self.arp_nd_sync_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "bdid"):
                            self.bdid = value
                            self.bdid.value_namespace = name_space
                            self.bdid.value_namespace_prefix = name_space_prefix
                        if(value_path == "bdid-xr"):
                            self.bdid_xr = value
                            self.bdid_xr.value_namespace = name_space
                            self.bdid_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "ip-address"):
                            self.ip_address = value
                            self.ip_address.value_namespace = name_space
                            self.ip_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-local"):
                            self.is_local = value
                            self.is_local.value_namespace = name_space
                            self.is_local.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-local-xr"):
                            self.is_local_xr = value
                            self.is_local_xr.value_namespace = name_space
                            self.is_local_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-address"):
                            self.mac_address = value
                            self.mac_address.value_namespace = name_space
                            self.mac_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-address-xr"):
                            self.mac_address_xr = value
                            self.mac_address_xr.value_namespace = name_space
                            self.mac_address_xr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_evpn_ip6mac:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_evpn_ip6mac:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-evpn-ip6macs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-evpn-ip6mac"):
                        for c in self.l2fib_evpn_ip6mac:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_evpn_ip6mac.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-evpn-ip6mac"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibDhcpBindingSummaries(Entity):
                """
                DHCP binding forwarding summary
                
                .. attribute:: l2fib_dhcp_binding_summary
                
                	Specify DHCP binding summary
                	**type**\: list of    :py:class:`L2FibDhcpBindingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries, self).__init__()

                    self.yang_name = "l2fib-dhcp-binding-summaries"
                    self.yang_parent_name = "node"

                    self.l2fib_dhcp_binding_summary = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries, self).__setattr__(name, value)


                class L2FibDhcpBindingSummary(Entity):
                    """
                    Specify DHCP binding summary
                    
                    .. attribute:: xcid  <key>
                    
                    	XConnect ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: bindings
                    
                    	DHCP binding count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port
                    
                    	Union of Port information
                    	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary, self).__init__()

                        self.yang_name = "l2fib-dhcp-binding-summary"
                        self.yang_parent_name = "l2fib-dhcp-binding-summaries"

                        self.xcid = YLeaf(YType.str, "xcid")

                        self.bindings = YLeaf(YType.uint32, "bindings")

                        self.port = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"
                        self._children_yang_names.add("port")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("xcid",
                                        "bindings") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary, self).__setattr__(name, value)


                    class Port(Entity):
                        """
                        Union of Port information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibData>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "l2fib-dhcp-binding-summary"

                            self.data_type = YLeaf(YType.enumeration, "data-type")

                            self.ac = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"
                            self._children_yang_names.add("ac")

                            self.pw = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._children_yang_names.add("pw")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("data_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port, self).__setattr__(name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "port"

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Ac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Ac, self).__setattr__(name, value)

                            def has_data(self):
                                return self.interface_handle.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwId>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "port"

                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                self.pseudo_wire_id_type = YLeaf(YType.enumeration, "pseudo-wire-id-type")

                                self.pw_id = YLeaf(YType.uint64, "pw-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("next_hop_address",
                                                "pseudo_wire_id_type",
                                                "pw_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Pw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Pw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.next_hop_address.is_set or
                                    self.pseudo_wire_id_type.is_set or
                                    self.pw_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.next_hop_address.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id_type.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                if (self.pseudo_wire_id_type.is_set or self.pseudo_wire_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id_type.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "pseudo-wire-id-type" or name == "pw-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "next-hop-address"):
                                    self.next_hop_address = value
                                    self.next_hop_address.value_namespace = name_space
                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id-type"):
                                    self.pseudo_wire_id_type = value
                                    self.pseudo_wire_id_type.value_namespace = name_space
                                    self.pseudo_wire_id_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.data_type.is_set or
                                (self.ac is not None and self.ac.has_data()) or
                                (self.pw is not None and self.pw.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.data_type.yfilter != YFilter.not_set or
                                (self.ac is not None and self.ac.has_operation()) or
                                (self.pw is not None and self.pw.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "port" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac"):
                                if (self.ac is None):
                                    self.ac = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Ac()
                                    self.ac.parent = self
                                    self._children_name_map["ac"] = "ac"
                                return self.ac

                            if (child_yang_name == "pw"):
                                if (self.pw is None):
                                    self.pw = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Pw()
                                    self.pw.parent = self
                                    self._children_name_map["pw"] = "pw"
                                return self.pw

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac" or name == "pw" or name == "data-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "data-type"):
                                self.data_type = value
                                self.data_type.value_namespace = name_space
                                self.data_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.xcid.is_set or
                            self.bindings.is_set or
                            (self.port is not None and self.port.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.xcid.yfilter != YFilter.not_set or
                            self.bindings.yfilter != YFilter.not_set or
                            (self.port is not None and self.port.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-dhcp-binding-summary" + "[xcid='" + self.xcid.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.xcid.is_set or self.xcid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xcid.get_name_leafdata())
                        if (self.bindings.is_set or self.bindings.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bindings.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "port"):
                            if (self.port is None):
                                self.port = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                            return self.port

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "port" or name == "xcid" or name == "bindings"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "xcid"):
                            self.xcid = value
                            self.xcid.value_namespace = name_space
                            self.xcid.value_namespace_prefix = name_space_prefix
                        if(value_path == "bindings"):
                            self.bindings = value
                            self.bindings.value_namespace = name_space
                            self.bindings.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_dhcp_binding_summary:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_dhcp_binding_summary:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-dhcp-binding-summaries" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-dhcp-binding-summary"):
                        for c in self.l2fib_dhcp_binding_summary:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_dhcp_binding_summary.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-dhcp-binding-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2FibEvpnInclMCasts(Entity):
                """
                L2VPN forwarding bridge\-domain evpn inclusive
                multicast Table
                
                .. attribute:: l2fib_evpn_incl_m_cast
                
                	Specify bridge domain name
                	**type**\: list of    :py:class:`L2FibEvpnInclMCast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts, self).__init__()

                    self.yang_name = "l2fib-evpn-incl-m-casts"
                    self.yang_parent_name = "node"

                    self.l2fib_evpn_incl_m_cast = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts, self).__setattr__(name, value)


                class L2FibEvpnInclMCast(Entity):
                    """
                    Specify bridge domain name
                    
                    .. attribute:: bd_name  <key>
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: l2fib_evpn_incl_m_cast_oles
                    
                    	EVPN ingress mcast ole Information
                    	**type**\:   :py:class:`L2FibEvpnInclMCastOles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles>`
                    
                    .. attribute:: mcast_replication_list
                    
                    	Information of pbb\-evpn/evpn ingress mcast replication list for a particular bridge domain
                    	**type**\:   :py:class:`McastReplicationList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.McastReplicationList>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast, self).__init__()

                        self.yang_name = "l2fib-evpn-incl-m-cast"
                        self.yang_parent_name = "l2fib-evpn-incl-m-casts"

                        self.bd_name = YLeaf(YType.str, "bd-name")

                        self.l2fib_evpn_incl_m_cast_oles = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles()
                        self.l2fib_evpn_incl_m_cast_oles.parent = self
                        self._children_name_map["l2fib_evpn_incl_m_cast_oles"] = "l2fib-evpn-incl-m-cast-oles"
                        self._children_yang_names.add("l2fib-evpn-incl-m-cast-oles")

                        self.mcast_replication_list = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.McastReplicationList()
                        self.mcast_replication_list.parent = self
                        self._children_name_map["mcast_replication_list"] = "mcast-replication-list"
                        self._children_yang_names.add("mcast-replication-list")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bd_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast, self).__setattr__(name, value)


                    class McastReplicationList(Entity):
                        """
                        Information of pbb\-evpn/evpn ingress mcast
                        replication list for a particular bridge domain
                        
                        .. attribute:: bridge_domain_id
                        
                        	bdid value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_domain_name
                        
                        	Bridge\-domain name
                        	**type**\:  str
                        
                        .. attribute:: is_bound
                        
                        	Is bound
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.McastReplicationList, self).__init__()

                            self.yang_name = "mcast-replication-list"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast"

                            self.bridge_domain_id = YLeaf(YType.uint32, "bridge-domain-id")

                            self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                            self.is_bound = YLeaf(YType.boolean, "is-bound")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bridge_domain_id",
                                            "bridge_domain_name",
                                            "is_bound") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.McastReplicationList, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.McastReplicationList, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bridge_domain_id.is_set or
                                self.bridge_domain_name.is_set or
                                self.is_bound.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bridge_domain_id.yfilter != YFilter.not_set or
                                self.bridge_domain_name.yfilter != YFilter.not_set or
                                self.is_bound.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mcast-replication-list" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bridge_domain_id.is_set or self.bridge_domain_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_domain_id.get_name_leafdata())
                            if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())
                            if (self.is_bound.is_set or self.is_bound.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bound.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-domain-id" or name == "bridge-domain-name" or name == "is-bound"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bridge-domain-id"):
                                self.bridge_domain_id = value
                                self.bridge_domain_id.value_namespace = name_space
                                self.bridge_domain_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-domain-name"):
                                self.bridge_domain_name = value
                                self.bridge_domain_name.value_namespace = name_space
                                self.bridge_domain_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bound"):
                                self.is_bound = value
                                self.is_bound.value_namespace = name_space
                                self.is_bound.value_namespace_prefix = name_space_prefix


                    class L2FibEvpnInclMCastOles(Entity):
                        """
                        EVPN ingress mcast ole Information
                        
                        .. attribute:: l2fib_evpn_incl_m_cast_ole
                        
                        	Information on a particular output path of the pbb\-evpn/evpn ingress replication list
                        	**type**\: list of    :py:class:`L2FibEvpnInclMCastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles, self).__init__()

                            self.yang_name = "l2fib-evpn-incl-m-cast-oles"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast"

                            self.l2fib_evpn_incl_m_cast_ole = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles, self).__setattr__(name, value)


                        class L2FibEvpnInclMCastOle(Entity):
                            """
                            Information on a particular output path of the
                            pbb\-evpn/evpn ingress replication list
                            
                            .. attribute:: next_hop_address  <key>
                            
                            	Next Hop Address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_bound
                            
                            	Is bound
                            	**type**\:  bool
                            
                            .. attribute:: mcast_ole
                            
                            	Mcast Ole Info
                            	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle, self).__init__()

                                self.yang_name = "l2fib-evpn-incl-m-cast-ole"
                                self.yang_parent_name = "l2fib-evpn-incl-m-cast-oles"

                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                self.is_bound = YLeaf(YType.boolean, "is-bound")

                                self.next_hop_valid = YLeaf(YType.boolean, "next-hop-valid")

                                self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle()
                                self.mcast_ole.parent = self
                                self._children_name_map["mcast_ole"] = "mcast-ole"
                                self._children_yang_names.add("mcast-ole")

                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._children_yang_names.add("next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("next_hop_address",
                                                "is_bound",
                                                "next_hop_valid") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle, self).__setattr__(name, value)


                            class McastOle(Entity):
                                """
                                Mcast Ole Info
                                
                                .. attribute:: mcast_label
                                
                                	Inclusive mcast label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ipv6_addr
                                
                                	Next Hop IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle, self).__init__()

                                    self.yang_name = "mcast-ole"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"

                                    self.mcast_label = YLeaf(YType.uint32, "mcast-label")

                                    self.next_hop_ipv6_addr = YLeaf(YType.str, "next-hop-ipv6-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mcast_label",
                                                    "next_hop_ipv6_addr") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.mcast_label.is_set or
                                        self.next_hop_ipv6_addr.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mcast_label.yfilter != YFilter.not_set or
                                        self.next_hop_ipv6_addr.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mcast-ole" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mcast_label.is_set or self.mcast_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mcast_label.get_name_leafdata())
                                    if (self.next_hop_ipv6_addr.is_set or self.next_hop_ipv6_addr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ipv6_addr.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mcast-label" or name == "next-hop-ipv6-addr"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mcast-label"):
                                        self.mcast_label = value
                                        self.mcast_label.value_namespace = name_space
                                        self.mcast_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ipv6-addr"):
                                        self.next_hop_ipv6_addr = value
                                        self.next_hop_ipv6_addr.value_namespace = name_space
                                        self.next_hop_ipv6_addr.value_namespace_prefix = name_space_prefix


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"

                                    self.children_count = YLeaf(YType.uint32, "children-count")

                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                    self.next_hop_internal_label = YLeaf(YType.uint32, "next-hop-internal-label")

                                    self.plaformt_data_valid = YLeaf(YType.boolean, "plaformt-data-valid")

                                    self.platform_data_length = YLeaf(YType.uint32, "platform-data-length")

                                    self.base = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("children_count",
                                                    "next_hop_address",
                                                    "next_hop_internal_label",
                                                    "plaformt_data_valid",
                                                    "platform_data_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"

                                    def has_data(self):
                                        return False

                                    def has_operation(self):
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.children_count.is_set or
                                        self.next_hop_address.is_set or
                                        self.next_hop_internal_label.is_set or
                                        self.plaformt_data_valid.is_set or
                                        self.platform_data_length.is_set or
                                        (self.base is not None and self.base.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.children_count.yfilter != YFilter.not_set or
                                        self.next_hop_address.yfilter != YFilter.not_set or
                                        self.next_hop_internal_label.yfilter != YFilter.not_set or
                                        self.plaformt_data_valid.yfilter != YFilter.not_set or
                                        self.platform_data_length.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.children_count.is_set or self.children_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.children_count.get_name_leafdata())
                                    if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                    if (self.next_hop_internal_label.is_set or self.next_hop_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_internal_label.get_name_leafdata())
                                    if (self.plaformt_data_valid.is_set or self.plaformt_data_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.plaformt_data_valid.get_name_leafdata())
                                    if (self.platform_data_length.is_set or self.platform_data_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.platform_data_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "children-count" or name == "next-hop-address" or name == "next-hop-internal-label" or name == "plaformt-data-valid" or name == "platform-data-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "children-count"):
                                        self.children_count = value
                                        self.children_count.value_namespace = name_space
                                        self.children_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-address"):
                                        self.next_hop_address = value
                                        self.next_hop_address.value_namespace = name_space
                                        self.next_hop_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-internal-label"):
                                        self.next_hop_internal_label = value
                                        self.next_hop_internal_label.value_namespace = name_space
                                        self.next_hop_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "plaformt-data-valid"):
                                        self.plaformt_data_valid = value
                                        self.plaformt_data_valid.value_namespace = name_space
                                        self.plaformt_data_valid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "platform-data-length"):
                                        self.platform_data_length = value
                                        self.platform_data_length.value_namespace = name_space
                                        self.platform_data_length.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.next_hop_address.is_set or
                                    self.is_bound.is_set or
                                    self.next_hop_valid.is_set or
                                    (self.mcast_ole is not None and self.mcast_ole.has_data()) or
                                    (self.next_hop is not None and self.next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.next_hop_address.yfilter != YFilter.not_set or
                                    self.is_bound.yfilter != YFilter.not_set or
                                    self.next_hop_valid.yfilter != YFilter.not_set or
                                    (self.mcast_ole is not None and self.mcast_ole.has_operation()) or
                                    (self.next_hop is not None and self.next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2fib-evpn-incl-m-cast-ole" + "[next-hop-address='" + self.next_hop_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.next_hop_address.is_set or self.next_hop_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_address.get_name_leafdata())
                                if (self.is_bound.is_set or self.is_bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_bound.get_name_leafdata())
                                if (self.next_hop_valid.is_set or self.next_hop_valid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_valid.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mcast-ole"):
                                    if (self.mcast_ole is None):
                                        self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle()
                                        self.mcast_ole.parent = self
                                        self._children_name_map["mcast_ole"] = "mcast-ole"
                                    return self.mcast_ole

                                if (child_yang_name == "next-hop"):
                                    if (self.next_hop is None):
                                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop()
                                        self.next_hop.parent = self
                                        self._children_name_map["next_hop"] = "next-hop"
                                    return self.next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mcast-ole" or name == "next-hop" or name == "next-hop-address" or name == "is-bound" or name == "next-hop-valid"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "next-hop-address"):
                                    self.next_hop_address = value
                                    self.next_hop_address.value_namespace = name_space
                                    self.next_hop_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-bound"):
                                    self.is_bound = value
                                    self.is_bound.value_namespace = name_space
                                    self.is_bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-valid"):
                                    self.next_hop_valid = value
                                    self.next_hop_valid.value_namespace = name_space
                                    self.next_hop_valid.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.l2fib_evpn_incl_m_cast_ole:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.l2fib_evpn_incl_m_cast_ole:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2fib-evpn-incl-m-cast-oles" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "l2fib-evpn-incl-m-cast-ole"):
                                for c in self.l2fib_evpn_incl_m_cast_ole:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.l2fib_evpn_incl_m_cast_ole.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "l2fib-evpn-incl-m-cast-ole"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.bd_name.is_set or
                            (self.l2fib_evpn_incl_m_cast_oles is not None and self.l2fib_evpn_incl_m_cast_oles.has_data()) or
                            (self.mcast_replication_list is not None and self.mcast_replication_list.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bd_name.yfilter != YFilter.not_set or
                            (self.l2fib_evpn_incl_m_cast_oles is not None and self.l2fib_evpn_incl_m_cast_oles.has_operation()) or
                            (self.mcast_replication_list is not None and self.mcast_replication_list.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2fib-evpn-incl-m-cast" + "[bd-name='" + self.bd_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bd_name.is_set or self.bd_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2fib-evpn-incl-m-cast-oles"):
                            if (self.l2fib_evpn_incl_m_cast_oles is None):
                                self.l2fib_evpn_incl_m_cast_oles = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles()
                                self.l2fib_evpn_incl_m_cast_oles.parent = self
                                self._children_name_map["l2fib_evpn_incl_m_cast_oles"] = "l2fib-evpn-incl-m-cast-oles"
                            return self.l2fib_evpn_incl_m_cast_oles

                        if (child_yang_name == "mcast-replication-list"):
                            if (self.mcast_replication_list is None):
                                self.mcast_replication_list = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.McastReplicationList()
                                self.mcast_replication_list.parent = self
                                self._children_name_map["mcast_replication_list"] = "mcast-replication-list"
                            return self.mcast_replication_list

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2fib-evpn-incl-m-cast-oles" or name == "mcast-replication-list" or name == "bd-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bd-name"):
                            self.bd_name = value
                            self.bd_name.value_namespace = name_space
                            self.bd_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.l2fib_evpn_incl_m_cast:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.l2fib_evpn_incl_m_cast:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2fib-evpn-incl-m-casts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2fib-evpn-incl-m-cast"):
                        for c in self.l2fib_evpn_incl_m_cast:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.l2fib_evpn_incl_m_cast.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2fib-evpn-incl-m-cast"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.node_id.is_set or
                    (self.l2fib_bridge_domain_names is not None and self.l2fib_bridge_domain_names.has_data()) or
                    (self.l2fib_bridge_domains is not None and self.l2fib_bridge_domains.has_data()) or
                    (self.l2fib_bridge_ports is not None and self.l2fib_bridge_ports.has_data()) or
                    (self.l2fib_dhcp_binding_count is not None and self.l2fib_dhcp_binding_count.has_data()) or
                    (self.l2fib_dhcp_binding_details is not None and self.l2fib_dhcp_binding_details.has_data()) or
                    (self.l2fib_dhcp_binding_summaries is not None and self.l2fib_dhcp_binding_summaries.has_data()) or
                    (self.l2fib_evpn_incl_m_cast_hardware_egresses is not None and self.l2fib_evpn_incl_m_cast_hardware_egresses.has_data()) or
                    (self.l2fib_evpn_incl_m_cast_hardware_ingresses is not None and self.l2fib_evpn_incl_m_cast_hardware_ingresses.has_data()) or
                    (self.l2fib_evpn_incl_m_casts is not None and self.l2fib_evpn_incl_m_casts.has_data()) or
                    (self.l2fib_evpn_ip4macs is not None and self.l2fib_evpn_ip4macs.has_data()) or
                    (self.l2fib_evpn_ip6macs is not None and self.l2fib_evpn_ip6macs.has_data()) or
                    (self.l2fib_g8032 is not None and self.l2fib_g8032.has_data()) or
                    (self.l2fib_l2tp is not None and self.l2fib_l2tp.has_data()) or
                    (self.l2fib_mac_learning is not None and self.l2fib_mac_learning.has_data()) or
                    (self.l2fib_main_interfaces is not None and self.l2fib_main_interfaces.has_data()) or
                    (self.l2fib_message_summary is not None and self.l2fib_message_summary.has_data()) or
                    (self.l2fib_mmrp_summaries is not None and self.l2fib_mmrp_summaries.has_data()) or
                    (self.l2fib_mmrps is not None and self.l2fib_mmrps.has_data()) or
                    (self.l2fib_mon_sess_x_cons is not None and self.l2fib_mon_sess_x_cons.has_data()) or
                    (self.l2fib_mroute_ipv6s is not None and self.l2fib_mroute_ipv6s.has_data()) or
                    (self.l2fib_mroute_ports is not None and self.l2fib_mroute_ports.has_data()) or
                    (self.l2fib_mroute_summaries is not None and self.l2fib_mroute_summaries.has_data()) or
                    (self.l2fib_mroutes is not None and self.l2fib_mroutes.has_data()) or
                    (self.l2fib_mstp_details is not None and self.l2fib_mstp_details.has_data()) or
                    (self.l2fib_mstp_summaries is not None and self.l2fib_mstp_summaries.has_data()) or
                    (self.l2fib_nve_peers is not None and self.l2fib_nve_peers.has_data()) or
                    (self.l2fib_p2mp is not None and self.l2fib_p2mp.has_data()) or
                    (self.l2fib_pw_groups is not None and self.l2fib_pw_groups.has_data()) or
                    (self.l2fib_pwhe_main_ports is not None and self.l2fib_pwhe_main_ports.has_data()) or
                    (self.l2fib_resource_availability is not None and self.l2fib_resource_availability.has_data()) or
                    (self.l2fib_summary is not None and self.l2fib_summary.has_data()) or
                    (self.l2fibmac_details is not None and self.l2fibmac_details.has_data()) or
                    (self.l2fibmac_hardware_egresses is not None and self.l2fibmac_hardware_egresses.has_data()) or
                    (self.l2fibmac_hardware_ingresses is not None and self.l2fibmac_hardware_ingresses.has_data()) or
                    (self.l2fibx_con_l2tpv2s is not None and self.l2fibx_con_l2tpv2s.has_data()) or
                    (self.l2fibx_con_locals is not None and self.l2fibx_con_locals.has_data()) or
                    (self.l2fibx_cons is not None and self.l2fibx_cons.has_data()) or
                    (self.pbb_bmac_sa is not None and self.pbb_bmac_sa.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.node_id.yfilter != YFilter.not_set or
                    (self.l2fib_bridge_domain_names is not None and self.l2fib_bridge_domain_names.has_operation()) or
                    (self.l2fib_bridge_domains is not None and self.l2fib_bridge_domains.has_operation()) or
                    (self.l2fib_bridge_ports is not None and self.l2fib_bridge_ports.has_operation()) or
                    (self.l2fib_dhcp_binding_count is not None and self.l2fib_dhcp_binding_count.has_operation()) or
                    (self.l2fib_dhcp_binding_details is not None and self.l2fib_dhcp_binding_details.has_operation()) or
                    (self.l2fib_dhcp_binding_summaries is not None and self.l2fib_dhcp_binding_summaries.has_operation()) or
                    (self.l2fib_evpn_incl_m_cast_hardware_egresses is not None and self.l2fib_evpn_incl_m_cast_hardware_egresses.has_operation()) or
                    (self.l2fib_evpn_incl_m_cast_hardware_ingresses is not None and self.l2fib_evpn_incl_m_cast_hardware_ingresses.has_operation()) or
                    (self.l2fib_evpn_incl_m_casts is not None and self.l2fib_evpn_incl_m_casts.has_operation()) or
                    (self.l2fib_evpn_ip4macs is not None and self.l2fib_evpn_ip4macs.has_operation()) or
                    (self.l2fib_evpn_ip6macs is not None and self.l2fib_evpn_ip6macs.has_operation()) or
                    (self.l2fib_g8032 is not None and self.l2fib_g8032.has_operation()) or
                    (self.l2fib_l2tp is not None and self.l2fib_l2tp.has_operation()) or
                    (self.l2fib_mac_learning is not None and self.l2fib_mac_learning.has_operation()) or
                    (self.l2fib_main_interfaces is not None and self.l2fib_main_interfaces.has_operation()) or
                    (self.l2fib_message_summary is not None and self.l2fib_message_summary.has_operation()) or
                    (self.l2fib_mmrp_summaries is not None and self.l2fib_mmrp_summaries.has_operation()) or
                    (self.l2fib_mmrps is not None and self.l2fib_mmrps.has_operation()) or
                    (self.l2fib_mon_sess_x_cons is not None and self.l2fib_mon_sess_x_cons.has_operation()) or
                    (self.l2fib_mroute_ipv6s is not None and self.l2fib_mroute_ipv6s.has_operation()) or
                    (self.l2fib_mroute_ports is not None and self.l2fib_mroute_ports.has_operation()) or
                    (self.l2fib_mroute_summaries is not None and self.l2fib_mroute_summaries.has_operation()) or
                    (self.l2fib_mroutes is not None and self.l2fib_mroutes.has_operation()) or
                    (self.l2fib_mstp_details is not None and self.l2fib_mstp_details.has_operation()) or
                    (self.l2fib_mstp_summaries is not None and self.l2fib_mstp_summaries.has_operation()) or
                    (self.l2fib_nve_peers is not None and self.l2fib_nve_peers.has_operation()) or
                    (self.l2fib_p2mp is not None and self.l2fib_p2mp.has_operation()) or
                    (self.l2fib_pw_groups is not None and self.l2fib_pw_groups.has_operation()) or
                    (self.l2fib_pwhe_main_ports is not None and self.l2fib_pwhe_main_ports.has_operation()) or
                    (self.l2fib_resource_availability is not None and self.l2fib_resource_availability.has_operation()) or
                    (self.l2fib_summary is not None and self.l2fib_summary.has_operation()) or
                    (self.l2fibmac_details is not None and self.l2fibmac_details.has_operation()) or
                    (self.l2fibmac_hardware_egresses is not None and self.l2fibmac_hardware_egresses.has_operation()) or
                    (self.l2fibmac_hardware_ingresses is not None and self.l2fibmac_hardware_ingresses.has_operation()) or
                    (self.l2fibx_con_l2tpv2s is not None and self.l2fibx_con_l2tpv2s.has_operation()) or
                    (self.l2fibx_con_locals is not None and self.l2fibx_con_locals.has_operation()) or
                    (self.l2fibx_cons is not None and self.l2fibx_cons.has_operation()) or
                    (self.pbb_bmac_sa is not None and self.pbb_bmac_sa.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "node" + "[node-id='" + self.node_id.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn-forwarding/nodes/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_id.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "l2fib-bridge-domain-names"):
                    if (self.l2fib_bridge_domain_names is None):
                        self.l2fib_bridge_domain_names = L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames()
                        self.l2fib_bridge_domain_names.parent = self
                        self._children_name_map["l2fib_bridge_domain_names"] = "l2fib-bridge-domain-names"
                    return self.l2fib_bridge_domain_names

                if (child_yang_name == "l2fib-bridge-domains"):
                    if (self.l2fib_bridge_domains is None):
                        self.l2fib_bridge_domains = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains()
                        self.l2fib_bridge_domains.parent = self
                        self._children_name_map["l2fib_bridge_domains"] = "l2fib-bridge-domains"
                    return self.l2fib_bridge_domains

                if (child_yang_name == "l2fib-bridge-ports"):
                    if (self.l2fib_bridge_ports is None):
                        self.l2fib_bridge_ports = L2VpnForwarding.Nodes.Node.L2FibBridgePorts()
                        self.l2fib_bridge_ports.parent = self
                        self._children_name_map["l2fib_bridge_ports"] = "l2fib-bridge-ports"
                    return self.l2fib_bridge_ports

                if (child_yang_name == "l2fib-dhcp-binding-count"):
                    if (self.l2fib_dhcp_binding_count is None):
                        self.l2fib_dhcp_binding_count = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingCount()
                        self.l2fib_dhcp_binding_count.parent = self
                        self._children_name_map["l2fib_dhcp_binding_count"] = "l2fib-dhcp-binding-count"
                    return self.l2fib_dhcp_binding_count

                if (child_yang_name == "l2fib-dhcp-binding-details"):
                    if (self.l2fib_dhcp_binding_details is None):
                        self.l2fib_dhcp_binding_details = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails()
                        self.l2fib_dhcp_binding_details.parent = self
                        self._children_name_map["l2fib_dhcp_binding_details"] = "l2fib-dhcp-binding-details"
                    return self.l2fib_dhcp_binding_details

                if (child_yang_name == "l2fib-dhcp-binding-summaries"):
                    if (self.l2fib_dhcp_binding_summaries is None):
                        self.l2fib_dhcp_binding_summaries = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries()
                        self.l2fib_dhcp_binding_summaries.parent = self
                        self._children_name_map["l2fib_dhcp_binding_summaries"] = "l2fib-dhcp-binding-summaries"
                    return self.l2fib_dhcp_binding_summaries

                if (child_yang_name == "l2fib-evpn-incl-m-cast-hardware-egresses"):
                    if (self.l2fib_evpn_incl_m_cast_hardware_egresses is None):
                        self.l2fib_evpn_incl_m_cast_hardware_egresses = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses()
                        self.l2fib_evpn_incl_m_cast_hardware_egresses.parent = self
                        self._children_name_map["l2fib_evpn_incl_m_cast_hardware_egresses"] = "l2fib-evpn-incl-m-cast-hardware-egresses"
                    return self.l2fib_evpn_incl_m_cast_hardware_egresses

                if (child_yang_name == "l2fib-evpn-incl-m-cast-hardware-ingresses"):
                    if (self.l2fib_evpn_incl_m_cast_hardware_ingresses is None):
                        self.l2fib_evpn_incl_m_cast_hardware_ingresses = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses()
                        self.l2fib_evpn_incl_m_cast_hardware_ingresses.parent = self
                        self._children_name_map["l2fib_evpn_incl_m_cast_hardware_ingresses"] = "l2fib-evpn-incl-m-cast-hardware-ingresses"
                    return self.l2fib_evpn_incl_m_cast_hardware_ingresses

                if (child_yang_name == "l2fib-evpn-incl-m-casts"):
                    if (self.l2fib_evpn_incl_m_casts is None):
                        self.l2fib_evpn_incl_m_casts = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts()
                        self.l2fib_evpn_incl_m_casts.parent = self
                        self._children_name_map["l2fib_evpn_incl_m_casts"] = "l2fib-evpn-incl-m-casts"
                    return self.l2fib_evpn_incl_m_casts

                if (child_yang_name == "l2fib-evpn-ip4macs"):
                    if (self.l2fib_evpn_ip4macs is None):
                        self.l2fib_evpn_ip4macs = L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs()
                        self.l2fib_evpn_ip4macs.parent = self
                        self._children_name_map["l2fib_evpn_ip4macs"] = "l2fib-evpn-ip4macs"
                    return self.l2fib_evpn_ip4macs

                if (child_yang_name == "l2fib-evpn-ip6macs"):
                    if (self.l2fib_evpn_ip6macs is None):
                        self.l2fib_evpn_ip6macs = L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs()
                        self.l2fib_evpn_ip6macs.parent = self
                        self._children_name_map["l2fib_evpn_ip6macs"] = "l2fib-evpn-ip6macs"
                    return self.l2fib_evpn_ip6macs

                if (child_yang_name == "l2fib-g8032"):
                    if (self.l2fib_g8032 is None):
                        self.l2fib_g8032 = L2VpnForwarding.Nodes.Node.L2FibG8032()
                        self.l2fib_g8032.parent = self
                        self._children_name_map["l2fib_g8032"] = "l2fib-g8032"
                    return self.l2fib_g8032

                if (child_yang_name == "l2fib-l2tp"):
                    if (self.l2fib_l2tp is None):
                        self.l2fib_l2tp = L2VpnForwarding.Nodes.Node.L2FibL2Tp()
                        self.l2fib_l2tp.parent = self
                        self._children_name_map["l2fib_l2tp"] = "l2fib-l2tp"
                    return self.l2fib_l2tp

                if (child_yang_name == "l2fib-mac-learning"):
                    if (self.l2fib_mac_learning is None):
                        self.l2fib_mac_learning = L2VpnForwarding.Nodes.Node.L2FibMacLearning()
                        self.l2fib_mac_learning.parent = self
                        self._children_name_map["l2fib_mac_learning"] = "l2fib-mac-learning"
                    return self.l2fib_mac_learning

                if (child_yang_name == "l2fib-main-interfaces"):
                    if (self.l2fib_main_interfaces is None):
                        self.l2fib_main_interfaces = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces()
                        self.l2fib_main_interfaces.parent = self
                        self._children_name_map["l2fib_main_interfaces"] = "l2fib-main-interfaces"
                    return self.l2fib_main_interfaces

                if (child_yang_name == "l2fib-message-summary"):
                    if (self.l2fib_message_summary is None):
                        self.l2fib_message_summary = L2VpnForwarding.Nodes.Node.L2FibMessageSummary()
                        self.l2fib_message_summary.parent = self
                        self._children_name_map["l2fib_message_summary"] = "l2fib-message-summary"
                    return self.l2fib_message_summary

                if (child_yang_name == "l2fib-mmrp-summaries"):
                    if (self.l2fib_mmrp_summaries is None):
                        self.l2fib_mmrp_summaries = L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries()
                        self.l2fib_mmrp_summaries.parent = self
                        self._children_name_map["l2fib_mmrp_summaries"] = "l2fib-mmrp-summaries"
                    return self.l2fib_mmrp_summaries

                if (child_yang_name == "l2fib-mmrps"):
                    if (self.l2fib_mmrps is None):
                        self.l2fib_mmrps = L2VpnForwarding.Nodes.Node.L2FibMmrps()
                        self.l2fib_mmrps.parent = self
                        self._children_name_map["l2fib_mmrps"] = "l2fib-mmrps"
                    return self.l2fib_mmrps

                if (child_yang_name == "l2fib-mon-sess-x-cons"):
                    if (self.l2fib_mon_sess_x_cons is None):
                        self.l2fib_mon_sess_x_cons = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons()
                        self.l2fib_mon_sess_x_cons.parent = self
                        self._children_name_map["l2fib_mon_sess_x_cons"] = "l2fib-mon-sess-x-cons"
                    return self.l2fib_mon_sess_x_cons

                if (child_yang_name == "l2fib-mroute-ipv6s"):
                    if (self.l2fib_mroute_ipv6s is None):
                        self.l2fib_mroute_ipv6s = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S()
                        self.l2fib_mroute_ipv6s.parent = self
                        self._children_name_map["l2fib_mroute_ipv6s"] = "l2fib-mroute-ipv6s"
                    return self.l2fib_mroute_ipv6s

                if (child_yang_name == "l2fib-mroute-ports"):
                    if (self.l2fib_mroute_ports is None):
                        self.l2fib_mroute_ports = L2VpnForwarding.Nodes.Node.L2FibMroutePorts()
                        self.l2fib_mroute_ports.parent = self
                        self._children_name_map["l2fib_mroute_ports"] = "l2fib-mroute-ports"
                    return self.l2fib_mroute_ports

                if (child_yang_name == "l2fib-mroute-summaries"):
                    if (self.l2fib_mroute_summaries is None):
                        self.l2fib_mroute_summaries = L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries()
                        self.l2fib_mroute_summaries.parent = self
                        self._children_name_map["l2fib_mroute_summaries"] = "l2fib-mroute-summaries"
                    return self.l2fib_mroute_summaries

                if (child_yang_name == "l2fib-mroutes"):
                    if (self.l2fib_mroutes is None):
                        self.l2fib_mroutes = L2VpnForwarding.Nodes.Node.L2FibMroutes()
                        self.l2fib_mroutes.parent = self
                        self._children_name_map["l2fib_mroutes"] = "l2fib-mroutes"
                    return self.l2fib_mroutes

                if (child_yang_name == "l2fib-mstp-details"):
                    if (self.l2fib_mstp_details is None):
                        self.l2fib_mstp_details = L2VpnForwarding.Nodes.Node.L2FibMstpDetails()
                        self.l2fib_mstp_details.parent = self
                        self._children_name_map["l2fib_mstp_details"] = "l2fib-mstp-details"
                    return self.l2fib_mstp_details

                if (child_yang_name == "l2fib-mstp-summaries"):
                    if (self.l2fib_mstp_summaries is None):
                        self.l2fib_mstp_summaries = L2VpnForwarding.Nodes.Node.L2FibMstpSummaries()
                        self.l2fib_mstp_summaries.parent = self
                        self._children_name_map["l2fib_mstp_summaries"] = "l2fib-mstp-summaries"
                    return self.l2fib_mstp_summaries

                if (child_yang_name == "l2fib-nve-peers"):
                    if (self.l2fib_nve_peers is None):
                        self.l2fib_nve_peers = L2VpnForwarding.Nodes.Node.L2FibNvePeers()
                        self.l2fib_nve_peers.parent = self
                        self._children_name_map["l2fib_nve_peers"] = "l2fib-nve-peers"
                    return self.l2fib_nve_peers

                if (child_yang_name == "l2fib-p2mp"):
                    if (self.l2fib_p2mp is None):
                        self.l2fib_p2mp = L2VpnForwarding.Nodes.Node.L2FibP2Mp()
                        self.l2fib_p2mp.parent = self
                        self._children_name_map["l2fib_p2mp"] = "l2fib-p2mp"
                    return self.l2fib_p2mp

                if (child_yang_name == "l2fib-pw-groups"):
                    if (self.l2fib_pw_groups is None):
                        self.l2fib_pw_groups = L2VpnForwarding.Nodes.Node.L2FibPwGroups()
                        self.l2fib_pw_groups.parent = self
                        self._children_name_map["l2fib_pw_groups"] = "l2fib-pw-groups"
                    return self.l2fib_pw_groups

                if (child_yang_name == "l2fib-pwhe-main-ports"):
                    if (self.l2fib_pwhe_main_ports is None):
                        self.l2fib_pwhe_main_ports = L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts()
                        self.l2fib_pwhe_main_ports.parent = self
                        self._children_name_map["l2fib_pwhe_main_ports"] = "l2fib-pwhe-main-ports"
                    return self.l2fib_pwhe_main_ports

                if (child_yang_name == "l2fib-resource-availability"):
                    if (self.l2fib_resource_availability is None):
                        self.l2fib_resource_availability = L2VpnForwarding.Nodes.Node.L2FibResourceAvailability()
                        self.l2fib_resource_availability.parent = self
                        self._children_name_map["l2fib_resource_availability"] = "l2fib-resource-availability"
                    return self.l2fib_resource_availability

                if (child_yang_name == "l2fib-summary"):
                    if (self.l2fib_summary is None):
                        self.l2fib_summary = L2VpnForwarding.Nodes.Node.L2FibSummary()
                        self.l2fib_summary.parent = self
                        self._children_name_map["l2fib_summary"] = "l2fib-summary"
                    return self.l2fib_summary

                if (child_yang_name == "l2fibmac-details"):
                    if (self.l2fibmac_details is None):
                        self.l2fibmac_details = L2VpnForwarding.Nodes.Node.L2FibmacDetails()
                        self.l2fibmac_details.parent = self
                        self._children_name_map["l2fibmac_details"] = "l2fibmac-details"
                    return self.l2fibmac_details

                if (child_yang_name == "l2fibmac-hardware-egresses"):
                    if (self.l2fibmac_hardware_egresses is None):
                        self.l2fibmac_hardware_egresses = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses()
                        self.l2fibmac_hardware_egresses.parent = self
                        self._children_name_map["l2fibmac_hardware_egresses"] = "l2fibmac-hardware-egresses"
                    return self.l2fibmac_hardware_egresses

                if (child_yang_name == "l2fibmac-hardware-ingresses"):
                    if (self.l2fibmac_hardware_ingresses is None):
                        self.l2fibmac_hardware_ingresses = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses()
                        self.l2fibmac_hardware_ingresses.parent = self
                        self._children_name_map["l2fibmac_hardware_ingresses"] = "l2fibmac-hardware-ingresses"
                    return self.l2fibmac_hardware_ingresses

                if (child_yang_name == "l2fibx-con-l2tpv2s"):
                    if (self.l2fibx_con_l2tpv2s is None):
                        self.l2fibx_con_l2tpv2s = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S()
                        self.l2fibx_con_l2tpv2s.parent = self
                        self._children_name_map["l2fibx_con_l2tpv2s"] = "l2fibx-con-l2tpv2s"
                    return self.l2fibx_con_l2tpv2s

                if (child_yang_name == "l2fibx-con-locals"):
                    if (self.l2fibx_con_locals is None):
                        self.l2fibx_con_locals = L2VpnForwarding.Nodes.Node.L2FibxConLocals()
                        self.l2fibx_con_locals.parent = self
                        self._children_name_map["l2fibx_con_locals"] = "l2fibx-con-locals"
                    return self.l2fibx_con_locals

                if (child_yang_name == "l2fibx-cons"):
                    if (self.l2fibx_cons is None):
                        self.l2fibx_cons = L2VpnForwarding.Nodes.Node.L2FibxCons()
                        self.l2fibx_cons.parent = self
                        self._children_name_map["l2fibx_cons"] = "l2fibx-cons"
                    return self.l2fibx_cons

                if (child_yang_name == "pbb-bmac-sa"):
                    if (self.pbb_bmac_sa is None):
                        self.pbb_bmac_sa = L2VpnForwarding.Nodes.Node.PbbBmacSa()
                        self.pbb_bmac_sa.parent = self
                        self._children_name_map["pbb_bmac_sa"] = "pbb-bmac-sa"
                    return self.pbb_bmac_sa

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "l2fib-bridge-domain-names" or name == "l2fib-bridge-domains" or name == "l2fib-bridge-ports" or name == "l2fib-dhcp-binding-count" or name == "l2fib-dhcp-binding-details" or name == "l2fib-dhcp-binding-summaries" or name == "l2fib-evpn-incl-m-cast-hardware-egresses" or name == "l2fib-evpn-incl-m-cast-hardware-ingresses" or name == "l2fib-evpn-incl-m-casts" or name == "l2fib-evpn-ip4macs" or name == "l2fib-evpn-ip6macs" or name == "l2fib-g8032" or name == "l2fib-l2tp" or name == "l2fib-mac-learning" or name == "l2fib-main-interfaces" or name == "l2fib-message-summary" or name == "l2fib-mmrp-summaries" or name == "l2fib-mmrps" or name == "l2fib-mon-sess-x-cons" or name == "l2fib-mroute-ipv6s" or name == "l2fib-mroute-ports" or name == "l2fib-mroute-summaries" or name == "l2fib-mroutes" or name == "l2fib-mstp-details" or name == "l2fib-mstp-summaries" or name == "l2fib-nve-peers" or name == "l2fib-p2mp" or name == "l2fib-pw-groups" or name == "l2fib-pwhe-main-ports" or name == "l2fib-resource-availability" or name == "l2fib-summary" or name == "l2fibmac-details" or name == "l2fibmac-hardware-egresses" or name == "l2fibmac-hardware-ingresses" or name == "l2fibx-con-l2tpv2s" or name == "l2fibx-con-locals" or name == "l2fibx-cons" or name == "pbb-bmac-sa" or name == "node-id"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "node-id"):
                    self.node_id = value
                    self.node_id.value_namespace = name_space
                    self.node_id.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.node:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.node:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "nodes" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn-forwarding/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "node"):
                for c in self.node:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2VpnForwarding.Nodes.Node()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.node.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "node"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (self.nodes is not None and self.nodes.has_data())

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.nodes is not None and self.nodes.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn-forwarding" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "nodes"):
            if (self.nodes is None):
                self.nodes = L2VpnForwarding.Nodes()
                self.nodes.parent = self
                self._children_name_map["nodes"] = "nodes"
            return self.nodes

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "nodes"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = L2VpnForwarding()
        return self._top_entity

class L2Vpnv2(Entity):
    """
    l2vpnv2
    
    .. attribute:: active
    
    	Active L2VPN operational data
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active>`
    
    .. attribute:: nodes
    
    	Table of L2VPN operational data for a particular node
    	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes>`
    
    .. attribute:: standby
    
    	Standby L2VPN operational data
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(L2Vpnv2, self).__init__()
        self._top_entity = None

        self.yang_name = "l2vpnv2"
        self.yang_parent_name = "Cisco-IOS-XR-l2vpn-oper"

        self.active = L2Vpnv2.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.nodes = L2Vpnv2.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._children_yang_names.add("nodes")

        self.standby = L2Vpnv2.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")


    class Standby(Entity):
        """
        Standby L2VPN operational data
        
        .. attribute:: bridge_domains
        
        	VPLS Bridge Domain Information
        	**type**\:   :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains>`
        
        .. attribute:: bridge_summary
        
        	Bridge Domain summary information
        	**type**\:   :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeSummary>`
        
        .. attribute:: discoveries
        
        	Discovery Table
        	**type**\:   :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries>`
        
        .. attribute:: discovery_summary
        
        	Discovery summary information
        	**type**\:   :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.DiscoverySummary>`
        
        .. attribute:: flexible_xconnect_service_summary
        
        	Flexible XConnect Service summary information
        	**type**\:   :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServiceSummary>`
        
        .. attribute:: flexible_xconnect_services
        
        	Flexible XConnect Service Table
        	**type**\:   :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices>`
        
        .. attribute:: g8032
        
        	G8032 information
        	**type**\:   :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032>`
        
        .. attribute:: generic_interface_list_details
        
        	L2VPN generic interface list Detail Table
        	**type**\:   :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails>`
        
        .. attribute:: generic_interfaces
        
        	L2VPN generic interface list Table
        	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaces>`
        
        .. attribute:: global_settings
        
        	L2VPN global settings
        	**type**\:   :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GlobalSettings>`
        
        .. attribute:: iccp_sm
        
        	ICCP\-based Service Multi\-homing operational data
        	**type**\:   :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm>`
        
        .. attribute:: indexes
        
        	ID Manager Index Table
        	**type**\:   :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Indexes>`
        
        .. attribute:: l2vpn_collaborators
        
        	L2VPN collaborator information
        	**type**\:   :py:class:`L2VpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.L2VpnCollaborators>`
        
        .. attribute:: l2vpn_pbb_bsa
        
        	L2VPN PBB Backbone Source MAC information
        	**type**\:   :py:class:`L2VpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.L2VpnPbbBsa>`
        
        .. attribute:: l2vpn_resource_state
        
        	L2VPN resource state information
        	**type**\:   :py:class:`L2VpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.L2VpnResourceState>`
        
        .. attribute:: main_interfaces
        
        	Main Interface
        	**type**\:   :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces>`
        
        .. attribute:: mstp_ports
        
        	L2VPN MSTP Port Table
        	**type**\:   :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpPorts>`
        
        .. attribute:: mstp_vlans
        
        	L2VPN MSTP VLAN Table
        	**type**\:   :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpVlans>`
        
        .. attribute:: mvrp
        
        	MVRP
        	**type**\:   :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp>`
        
        .. attribute:: nsr
        
        	L2VPN NSR information
        	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr>`
        
        .. attribute:: proc_fsm
        
        	L2VPN Process FSM information
        	**type**\:   :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm>`
        
        .. attribute:: pseudowire_classes
        
        	List of pseudowire classes
        	**type**\:   :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses>`
        
        .. attribute:: pwr
        
        	Pseudowire Routing Table
        	**type**\:   :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr>`
        
        .. attribute:: xconnect_brief
        
        	XConnect brief information
        	**type**\:   :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectBrief>`
        
        .. attribute:: xconnect_groups
        
        	XConnect group Table
        	**type**\:   :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectGroups>`
        
        .. attribute:: xconnect_mp2mp_ce2ces
        
        	XConnect MP2MP CE2CE Table
        	**type**\:   :py:class:`XconnectMp2MpCe2Ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2MpCe2Ces>`
        
        .. attribute:: xconnect_mp2mps
        
        	XConnect MP2MP Table
        	**type**\:   :py:class:`XconnectMp2Mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps>`
        
        .. attribute:: xconnect_summary
        
        	XConnect summary information
        	**type**\:   :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectSummary>`
        
        .. attribute:: xconnects
        
        	XConnect Table
        	**type**\:   :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpnv2.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "l2vpnv2"

            self.bridge_domains = L2Vpnv2.Standby.BridgeDomains()
            self.bridge_domains.parent = self
            self._children_name_map["bridge_domains"] = "bridge-domains"
            self._children_yang_names.add("bridge-domains")

            self.bridge_summary = L2Vpnv2.Standby.BridgeSummary()
            self.bridge_summary.parent = self
            self._children_name_map["bridge_summary"] = "bridge-summary"
            self._children_yang_names.add("bridge-summary")

            self.discoveries = L2Vpnv2.Standby.Discoveries()
            self.discoveries.parent = self
            self._children_name_map["discoveries"] = "discoveries"
            self._children_yang_names.add("discoveries")

            self.discovery_summary = L2Vpnv2.Standby.DiscoverySummary()
            self.discovery_summary.parent = self
            self._children_name_map["discovery_summary"] = "discovery-summary"
            self._children_yang_names.add("discovery-summary")

            self.flexible_xconnect_service_summary = L2Vpnv2.Standby.FlexibleXconnectServiceSummary()
            self.flexible_xconnect_service_summary.parent = self
            self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"
            self._children_yang_names.add("flexible-xconnect-service-summary")

            self.flexible_xconnect_services = L2Vpnv2.Standby.FlexibleXconnectServices()
            self.flexible_xconnect_services.parent = self
            self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"
            self._children_yang_names.add("flexible-xconnect-services")

            self.g8032 = L2Vpnv2.Standby.G8032()
            self.g8032.parent = self
            self._children_name_map["g8032"] = "g8032"
            self._children_yang_names.add("g8032")

            self.generic_interface_list_details = L2Vpnv2.Standby.GenericInterfaceListDetails()
            self.generic_interface_list_details.parent = self
            self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"
            self._children_yang_names.add("generic-interface-list-details")

            self.generic_interfaces = L2Vpnv2.Standby.GenericInterfaces()
            self.generic_interfaces.parent = self
            self._children_name_map["generic_interfaces"] = "generic-interfaces"
            self._children_yang_names.add("generic-interfaces")

            self.global_settings = L2Vpnv2.Standby.GlobalSettings()
            self.global_settings.parent = self
            self._children_name_map["global_settings"] = "global-settings"
            self._children_yang_names.add("global-settings")

            self.iccp_sm = L2Vpnv2.Standby.IccpSm()
            self.iccp_sm.parent = self
            self._children_name_map["iccp_sm"] = "iccp-sm"
            self._children_yang_names.add("iccp-sm")

            self.indexes = L2Vpnv2.Standby.Indexes()
            self.indexes.parent = self
            self._children_name_map["indexes"] = "indexes"
            self._children_yang_names.add("indexes")

            self.l2vpn_collaborators = L2Vpnv2.Standby.L2VpnCollaborators()
            self.l2vpn_collaborators.parent = self
            self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"
            self._children_yang_names.add("l2vpn-collaborators")

            self.l2vpn_pbb_bsa = L2Vpnv2.Standby.L2VpnPbbBsa()
            self.l2vpn_pbb_bsa.parent = self
            self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"
            self._children_yang_names.add("l2vpn-pbb-bsa")

            self.l2vpn_resource_state = L2Vpnv2.Standby.L2VpnResourceState()
            self.l2vpn_resource_state.parent = self
            self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"
            self._children_yang_names.add("l2vpn-resource-state")

            self.main_interfaces = L2Vpnv2.Standby.MainInterfaces()
            self.main_interfaces.parent = self
            self._children_name_map["main_interfaces"] = "main-interfaces"
            self._children_yang_names.add("main-interfaces")

            self.mstp_ports = L2Vpnv2.Standby.MstpPorts()
            self.mstp_ports.parent = self
            self._children_name_map["mstp_ports"] = "mstp-ports"
            self._children_yang_names.add("mstp-ports")

            self.mstp_vlans = L2Vpnv2.Standby.MstpVlans()
            self.mstp_vlans.parent = self
            self._children_name_map["mstp_vlans"] = "mstp-vlans"
            self._children_yang_names.add("mstp-vlans")

            self.mvrp = L2Vpnv2.Standby.Mvrp()
            self.mvrp.parent = self
            self._children_name_map["mvrp"] = "mvrp"
            self._children_yang_names.add("mvrp")

            self.nsr = L2Vpnv2.Standby.Nsr()
            self.nsr.parent = self
            self._children_name_map["nsr"] = "nsr"
            self._children_yang_names.add("nsr")

            self.proc_fsm = L2Vpnv2.Standby.ProcFsm()
            self.proc_fsm.parent = self
            self._children_name_map["proc_fsm"] = "proc-fsm"
            self._children_yang_names.add("proc-fsm")

            self.pseudowire_classes = L2Vpnv2.Standby.PseudowireClasses()
            self.pseudowire_classes.parent = self
            self._children_name_map["pseudowire_classes"] = "pseudowire-classes"
            self._children_yang_names.add("pseudowire-classes")

            self.pwr = L2Vpnv2.Standby.Pwr()
            self.pwr.parent = self
            self._children_name_map["pwr"] = "pwr"
            self._children_yang_names.add("pwr")

            self.xconnect_brief = L2Vpnv2.Standby.XconnectBrief()
            self.xconnect_brief.parent = self
            self._children_name_map["xconnect_brief"] = "xconnect-brief"
            self._children_yang_names.add("xconnect-brief")

            self.xconnect_groups = L2Vpnv2.Standby.XconnectGroups()
            self.xconnect_groups.parent = self
            self._children_name_map["xconnect_groups"] = "xconnect-groups"
            self._children_yang_names.add("xconnect-groups")

            self.xconnect_mp2mp_ce2ces = L2Vpnv2.Standby.XconnectMp2MpCe2Ces()
            self.xconnect_mp2mp_ce2ces.parent = self
            self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"
            self._children_yang_names.add("xconnect-mp2mp-ce2ces")

            self.xconnect_mp2mps = L2Vpnv2.Standby.XconnectMp2Mps()
            self.xconnect_mp2mps.parent = self
            self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"
            self._children_yang_names.add("xconnect-mp2mps")

            self.xconnect_summary = L2Vpnv2.Standby.XconnectSummary()
            self.xconnect_summary.parent = self
            self._children_name_map["xconnect_summary"] = "xconnect-summary"
            self._children_yang_names.add("xconnect-summary")

            self.xconnects = L2Vpnv2.Standby.Xconnects()
            self.xconnects.parent = self
            self._children_name_map["xconnects"] = "xconnects"
            self._children_yang_names.add("xconnects")


        class Discoveries(Entity):
            """
            Discovery Table
            
            .. attribute:: discovery
            
            	VPLS Discovery information
            	**type**\: list of    :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.Discoveries, self).__init__()

                self.yang_name = "discoveries"
                self.yang_parent_name = "standby"

                self.discovery = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.Discoveries, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.Discoveries, self).__setattr__(name, value)


            class Discovery(Entity):
                """
                VPLS Discovery information
                
                .. attribute:: group_name
                
                	Group Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: is_service_connected
                
                	Is the service connected
                	**type**\:  bool
                
                .. attribute:: mtu_mismatch_ignore
                
                	Ignore MTU Mismatch
                	**type**\:  bool
                
                .. attribute:: number_vpn
                
                	Number of vpns
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: service_name
                
                	Service type
                	**type**\:   :py:class:`L2VpnService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnService>`
                
                .. attribute:: service_name_xr
                
                	Service Type
                	**type**\:  str
                
                .. attribute:: signalling_info
                
                	Info about signalling protocol
                	**type**\:   :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo>`
                
                .. attribute:: vpn_id
                
                	VPN id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_name
                
                	VPN Name
                	**type**\:  str
                
                	**length:** 1..27
                
                .. attribute:: vpn_name_xr
                
                	VPN instance name
                	**type**\:  str
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Discoveries.Discovery, self).__init__()

                    self.yang_name = "discovery"
                    self.yang_parent_name = "discoveries"

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                    self.is_service_connected = YLeaf(YType.boolean, "is-service-connected")

                    self.mtu_mismatch_ignore = YLeaf(YType.boolean, "mtu-mismatch-ignore")

                    self.number_vpn = YLeaf(YType.uint32, "number-vpn")

                    self.service_name = YLeaf(YType.enumeration, "service-name")

                    self.service_name_xr = YLeaf(YType.str, "service-name-xr")

                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                    self.vpn_name = YLeaf(YType.str, "vpn-name")

                    self.vpn_name_xr = YLeaf(YType.str, "vpn-name-xr")

                    self.signalling_info = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo()
                    self.signalling_info.parent = self
                    self._children_name_map["signalling_info"] = "signalling-info"
                    self._children_yang_names.add("signalling-info")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_name",
                                    "group_name_xr",
                                    "is_service_connected",
                                    "mtu_mismatch_ignore",
                                    "number_vpn",
                                    "service_name",
                                    "service_name_xr",
                                    "vpn_id",
                                    "vpn_name",
                                    "vpn_name_xr") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Discoveries.Discovery, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Discoveries.Discovery, self).__setattr__(name, value)


                class SignallingInfo(Entity):
                    """
                    Info about signalling protocol
                    
                    .. attribute:: ad_signalling_method
                    
                    	ADSignallingMethod
                    	**type**\:   :py:class:`L2VpnAdSigMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdSigMethod>`
                    
                    .. attribute:: bgp_sig_info
                    
                    	bgp sig info
                    	**type**\:   :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                    
                    .. attribute:: ldp_sig_info
                    
                    	ldp sig info
                    	**type**\:   :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo, self).__init__()

                        self.yang_name = "signalling-info"
                        self.yang_parent_name = "discovery"

                        self.ad_signalling_method = YLeaf(YType.enumeration, "ad-signalling-method")

                        self.bgp_sig_info = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                        self.bgp_sig_info.parent = self
                        self._children_name_map["bgp_sig_info"] = "bgp-sig-info"
                        self._children_yang_names.add("bgp-sig-info")

                        self.ldp_sig_info = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                        self.ldp_sig_info.parent = self
                        self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                        self._children_yang_names.add("ldp-sig-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ad_signalling_method") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo, self).__setattr__(name, value)


                    class BgpSigInfo(Entity):
                        """
                        bgp sig info
                        
                        .. attribute:: edge
                        
                        	List of edge ids
                        	**type**\: list of    :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                        
                        .. attribute:: number_edges
                        
                        	Number of Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redge
                        
                        	List of edge ids
                        	**type**\: list of    :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__init__()

                            self.yang_name = "bgp-sig-info"
                            self.yang_parent_name = "signalling-info"

                            self.number_edges = YLeaf(YType.uint32, "number-edges")

                            self.number_remote_edges = YLeaf(YType.uint32, "number-remote-edges")

                            self.edge = YList(self)
                            self.redge = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("number_edges",
                                            "number_remote_edges") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__setattr__(name, value)


                        class Edge(Entity):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__init__()

                                self.yang_name = "edge"
                                self.yang_parent_name = "bgp-sig-info"

                                self.edge_id = YLeaf(YType.uint32, "edge-id")

                                self.label_count = YLeaf(YType.uint32, "label-count")

                                self.label_block = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("edge_id",
                                                "label_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__setattr__(name, value)


                            class LabelBlock(Entity):
                                """
                                List of label blocks
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:   :py:class:`L2VpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErr>`
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\:  list of int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__init__()

                                    self.yang_name = "label-block"
                                    self.yang_parent_name = "edge"

                                    self.block_offset = YLeaf(YType.uint32, "block-offset")

                                    self.block_size = YLeaf(YType.uint32, "block-size")

                                    self.label_base = YLeaf(YType.uint32, "label-base")

                                    self.label_error = YLeaf(YType.enumeration, "label-error")

                                    self.label_time_created = YLeaf(YType.uint32, "label-time-created")

                                    self.local_edge_id = YLeaf(YType.uint32, "local-edge-id")

                                    self.next_hop = YLeaf(YType.str, "next-hop")

                                    self.status_vector = YLeafList(YType.uint8, "status-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("block_offset",
                                                    "block_size",
                                                    "label_base",
                                                    "label_error",
                                                    "label_time_created",
                                                    "local_edge_id",
                                                    "next_hop",
                                                    "status_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__setattr__(name, value)

                                def has_data(self):
                                    for leaf in self.status_vector.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.block_offset.is_set or
                                        self.block_size.is_set or
                                        self.label_base.is_set or
                                        self.label_error.is_set or
                                        self.label_time_created.is_set or
                                        self.local_edge_id.is_set or
                                        self.next_hop.is_set)

                                def has_operation(self):
                                    for leaf in self.status_vector.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.block_offset.yfilter != YFilter.not_set or
                                        self.block_size.yfilter != YFilter.not_set or
                                        self.label_base.yfilter != YFilter.not_set or
                                        self.label_error.yfilter != YFilter.not_set or
                                        self.label_time_created.yfilter != YFilter.not_set or
                                        self.local_edge_id.yfilter != YFilter.not_set or
                                        self.next_hop.yfilter != YFilter.not_set or
                                        self.status_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "label-block" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/bgp-sig-info/edge/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.block_offset.is_set or self.block_offset.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.block_offset.get_name_leafdata())
                                    if (self.block_size.is_set or self.block_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.block_size.get_name_leafdata())
                                    if (self.label_base.is_set or self.label_base.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_base.get_name_leafdata())
                                    if (self.label_error.is_set or self.label_error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_error.get_name_leafdata())
                                    if (self.label_time_created.is_set or self.label_time_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_time_created.get_name_leafdata())
                                    if (self.local_edge_id.is_set or self.local_edge_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_edge_id.get_name_leafdata())
                                    if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop.get_name_leafdata())

                                    leaf_name_data.extend(self.status_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "block-offset" or name == "block-size" or name == "label-base" or name == "label-error" or name == "label-time-created" or name == "local-edge-id" or name == "next-hop" or name == "status-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "block-offset"):
                                        self.block_offset = value
                                        self.block_offset.value_namespace = name_space
                                        self.block_offset.value_namespace_prefix = name_space_prefix
                                    if(value_path == "block-size"):
                                        self.block_size = value
                                        self.block_size.value_namespace = name_space
                                        self.block_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-base"):
                                        self.label_base = value
                                        self.label_base.value_namespace = name_space
                                        self.label_base.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-error"):
                                        self.label_error = value
                                        self.label_error.value_namespace = name_space
                                        self.label_error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-time-created"):
                                        self.label_time_created = value
                                        self.label_time_created.value_namespace = name_space
                                        self.label_time_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-edge-id"):
                                        self.local_edge_id = value
                                        self.local_edge_id.value_namespace = name_space
                                        self.local_edge_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop"):
                                        self.next_hop = value
                                        self.next_hop.value_namespace = name_space
                                        self.next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "status-vector"):
                                        self.status_vector.append(value)

                            def has_data(self):
                                for c in self.label_block:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.edge_id.is_set or
                                    self.label_count.is_set)

                            def has_operation(self):
                                for c in self.label_block:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.edge_id.yfilter != YFilter.not_set or
                                    self.label_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "edge" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/bgp-sig-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.edge_id.is_set or self.edge_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.edge_id.get_name_leafdata())
                                if (self.label_count.is_set or self.label_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "label-block"):
                                    for c in self.label_block:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.label_block.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "label-block" or name == "edge-id" or name == "label-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "edge-id"):
                                    self.edge_id = value
                                    self.edge_id.value_namespace = name_space
                                    self.edge_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "label-count"):
                                    self.label_count = value
                                    self.label_count.value_namespace = name_space
                                    self.label_count.value_namespace_prefix = name_space_prefix


                        class Redge(Entity):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__init__()

                                self.yang_name = "redge"
                                self.yang_parent_name = "bgp-sig-info"

                                self.edge_id = YLeaf(YType.uint32, "edge-id")

                                self.label_count = YLeaf(YType.uint32, "label-count")

                                self.label_block = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("edge_id",
                                                "label_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__setattr__(name, value)


                            class LabelBlock(Entity):
                                """
                                List of label blocks
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:   :py:class:`L2VpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErr>`
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\:  list of int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__init__()

                                    self.yang_name = "label-block"
                                    self.yang_parent_name = "redge"

                                    self.block_offset = YLeaf(YType.uint32, "block-offset")

                                    self.block_size = YLeaf(YType.uint32, "block-size")

                                    self.label_base = YLeaf(YType.uint32, "label-base")

                                    self.label_error = YLeaf(YType.enumeration, "label-error")

                                    self.label_time_created = YLeaf(YType.uint32, "label-time-created")

                                    self.local_edge_id = YLeaf(YType.uint32, "local-edge-id")

                                    self.next_hop = YLeaf(YType.str, "next-hop")

                                    self.status_vector = YLeafList(YType.uint8, "status-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("block_offset",
                                                    "block_size",
                                                    "label_base",
                                                    "label_error",
                                                    "label_time_created",
                                                    "local_edge_id",
                                                    "next_hop",
                                                    "status_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__setattr__(name, value)

                                def has_data(self):
                                    for leaf in self.status_vector.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.block_offset.is_set or
                                        self.block_size.is_set or
                                        self.label_base.is_set or
                                        self.label_error.is_set or
                                        self.label_time_created.is_set or
                                        self.local_edge_id.is_set or
                                        self.next_hop.is_set)

                                def has_operation(self):
                                    for leaf in self.status_vector.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.block_offset.yfilter != YFilter.not_set or
                                        self.block_size.yfilter != YFilter.not_set or
                                        self.label_base.yfilter != YFilter.not_set or
                                        self.label_error.yfilter != YFilter.not_set or
                                        self.label_time_created.yfilter != YFilter.not_set or
                                        self.local_edge_id.yfilter != YFilter.not_set or
                                        self.next_hop.yfilter != YFilter.not_set or
                                        self.status_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "label-block" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/bgp-sig-info/redge/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.block_offset.is_set or self.block_offset.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.block_offset.get_name_leafdata())
                                    if (self.block_size.is_set or self.block_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.block_size.get_name_leafdata())
                                    if (self.label_base.is_set or self.label_base.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_base.get_name_leafdata())
                                    if (self.label_error.is_set or self.label_error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_error.get_name_leafdata())
                                    if (self.label_time_created.is_set or self.label_time_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_time_created.get_name_leafdata())
                                    if (self.local_edge_id.is_set or self.local_edge_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_edge_id.get_name_leafdata())
                                    if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop.get_name_leafdata())

                                    leaf_name_data.extend(self.status_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "block-offset" or name == "block-size" or name == "label-base" or name == "label-error" or name == "label-time-created" or name == "local-edge-id" or name == "next-hop" or name == "status-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "block-offset"):
                                        self.block_offset = value
                                        self.block_offset.value_namespace = name_space
                                        self.block_offset.value_namespace_prefix = name_space_prefix
                                    if(value_path == "block-size"):
                                        self.block_size = value
                                        self.block_size.value_namespace = name_space
                                        self.block_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-base"):
                                        self.label_base = value
                                        self.label_base.value_namespace = name_space
                                        self.label_base.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-error"):
                                        self.label_error = value
                                        self.label_error.value_namespace = name_space
                                        self.label_error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-time-created"):
                                        self.label_time_created = value
                                        self.label_time_created.value_namespace = name_space
                                        self.label_time_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-edge-id"):
                                        self.local_edge_id = value
                                        self.local_edge_id.value_namespace = name_space
                                        self.local_edge_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop"):
                                        self.next_hop = value
                                        self.next_hop.value_namespace = name_space
                                        self.next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "status-vector"):
                                        self.status_vector.append(value)

                            def has_data(self):
                                for c in self.label_block:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.edge_id.is_set or
                                    self.label_count.is_set)

                            def has_operation(self):
                                for c in self.label_block:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.edge_id.yfilter != YFilter.not_set or
                                    self.label_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redge" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/bgp-sig-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.edge_id.is_set or self.edge_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.edge_id.get_name_leafdata())
                                if (self.label_count.is_set or self.label_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "label-block"):
                                    for c in self.label_block:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.label_block.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "label-block" or name == "edge-id" or name == "label-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "edge-id"):
                                    self.edge_id = value
                                    self.edge_id.value_namespace = name_space
                                    self.edge_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "label-count"):
                                    self.label_count = value
                                    self.label_count.value_namespace = name_space
                                    self.label_count.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.edge:
                                if (c.has_data()):
                                    return True
                            for c in self.redge:
                                if (c.has_data()):
                                    return True
                            return (
                                self.number_edges.is_set or
                                self.number_remote_edges.is_set)

                        def has_operation(self):
                            for c in self.edge:
                                if (c.has_operation()):
                                    return True
                            for c in self.redge:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.number_edges.yfilter != YFilter.not_set or
                                self.number_remote_edges.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bgp-sig-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.number_edges.is_set or self.number_edges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_edges.get_name_leafdata())
                            if (self.number_remote_edges.is_set or self.number_remote_edges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_remote_edges.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "edge"):
                                for c in self.edge:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.edge.append(c)
                                return c

                            if (child_yang_name == "redge"):
                                for c in self.redge:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.redge.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "edge" or name == "redge" or name == "number-edges" or name == "number-remote-edges"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "number-edges"):
                                self.number_edges = value
                                self.number_edges.value_namespace = name_space
                                self.number_edges.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-remote-edges"):
                                self.number_remote_edges = value
                                self.number_remote_edges.value_namespace = name_space
                                self.number_remote_edges.value_namespace_prefix = name_space_prefix


                    class LdpSigInfo(Entity):
                        """
                        ldp sig info
                        
                        .. attribute:: local_l2_router_id
                        
                        	Local L2VPN Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_vpls_id
                        
                        	Local VPLS\-ID
                        	**type**\:   :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_nlri
                        
                        	List of NLRIs
                        	**type**\: list of    :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__init__()

                            self.yang_name = "ldp-sig-info"
                            self.yang_parent_name = "signalling-info"

                            self.local_l2_router_id = YLeaf(YType.str, "local-l2-router-id")

                            self.number_remote_edges = YLeaf(YType.uint32, "number-remote-edges")

                            self.local_vpls_id = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                            self.local_vpls_id.parent = self
                            self._children_name_map["local_vpls_id"] = "local-vpls-id"
                            self._children_yang_names.add("local-vpls-id")

                            self.remote_nlri = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("local_l2_router_id",
                                            "number_remote_edges") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__setattr__(name, value)


                        class LocalVplsId(Entity):
                            """
                            Local VPLS\-ID
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                            
                            .. attribute:: vpls_id_type
                            
                            	VPLS ID TYPE
                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__init__()

                                self.yang_name = "local-vpls-id"
                                self.yang_parent_name = "ldp-sig-info"

                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                self.auto = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                                self._children_yang_names.add("auto")

                                self.two_byte_as = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("vpls_id_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__setattr__(name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: asn
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpn_id
                                
                                	VPN ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "local-vpls-id"

                                    self.asn = YLeaf(YType.uint16, "asn")

                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("asn",
                                                    "vpn_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.asn.is_set or
                                        self.vpn_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.asn.yfilter != YFilter.not_set or
                                        self.vpn_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "auto" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "asn" or name == "vpn-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "asn"):
                                        self.asn = value
                                        self.asn.value_namespace = name_space
                                        self.asn.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpn-id"):
                                        self.vpn_id = value
                                        self.vpn_id.value_namespace = name_space
                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "local-vpls-id"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "local-vpls-id"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.vpls_id_type.is_set or
                                    (self.auto is not None and self.auto.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                    (self.auto is not None and self.auto.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-vpls-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/ldp-sig-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "auto"):
                                    if (self.auto is None):
                                        self.auto = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                    return self.auto

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "vpls-id-type"):
                                    self.vpls_id_type = value
                                    self.vpls_id_type.value_namespace = name_space
                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                        class RemoteNlri(Entity):
                            """
                            List of NLRIs
                            
                            .. attribute:: local_address
                            
                            	Local BGP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nlri_time_created
                            
                            	NLRI creation time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote BGP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_l2_router_id
                            
                            	Remote L2VPN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__init__()

                                self.yang_name = "remote-nlri"
                                self.yang_parent_name = "ldp-sig-info"

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.nlri_time_created = YLeaf(YType.uint32, "nlri-time-created")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                                self.remote_l2_router_id = YLeaf(YType.str, "remote-l2-router-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_address",
                                                "nlri_time_created",
                                                "remote_address",
                                                "remote_l2_router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_address.is_set or
                                    self.nlri_time_created.is_set or
                                    self.remote_address.is_set or
                                    self.remote_l2_router_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.nlri_time_created.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set or
                                    self.remote_l2_router_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-nlri" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/ldp-sig-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.nlri_time_created.is_set or self.nlri_time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nlri_time_created.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())
                                if (self.remote_l2_router_id.is_set or self.remote_l2_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_l2_router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-address" or name == "nlri-time-created" or name == "remote-address" or name == "remote-l2-router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "nlri-time-created"):
                                    self.nlri_time_created = value
                                    self.nlri_time_created.value_namespace = name_space
                                    self.nlri_time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-l2-router-id"):
                                    self.remote_l2_router_id = value
                                    self.remote_l2_router_id.value_namespace = name_space
                                    self.remote_l2_router_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.remote_nlri:
                                if (c.has_data()):
                                    return True
                            return (
                                self.local_l2_router_id.is_set or
                                self.number_remote_edges.is_set or
                                (self.local_vpls_id is not None and self.local_vpls_id.has_data()))

                        def has_operation(self):
                            for c in self.remote_nlri:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.local_l2_router_id.yfilter != YFilter.not_set or
                                self.number_remote_edges.yfilter != YFilter.not_set or
                                (self.local_vpls_id is not None and self.local_vpls_id.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ldp-sig-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.local_l2_router_id.is_set or self.local_l2_router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_l2_router_id.get_name_leafdata())
                            if (self.number_remote_edges.is_set or self.number_remote_edges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_remote_edges.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "local-vpls-id"):
                                if (self.local_vpls_id is None):
                                    self.local_vpls_id = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                                    self.local_vpls_id.parent = self
                                    self._children_name_map["local_vpls_id"] = "local-vpls-id"
                                return self.local_vpls_id

                            if (child_yang_name == "remote-nlri"):
                                for c in self.remote_nlri:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.remote_nlri.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-vpls-id" or name == "remote-nlri" or name == "local-l2-router-id" or name == "number-remote-edges"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "local-l2-router-id"):
                                self.local_l2_router_id = value
                                self.local_l2_router_id.value_namespace = name_space
                                self.local_l2_router_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-remote-edges"):
                                self.number_remote_edges = value
                                self.number_remote_edges.value_namespace = name_space
                                self.number_remote_edges.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ad_signalling_method.is_set or
                            (self.bgp_sig_info is not None and self.bgp_sig_info.has_data()) or
                            (self.ldp_sig_info is not None and self.ldp_sig_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ad_signalling_method.yfilter != YFilter.not_set or
                            (self.bgp_sig_info is not None and self.bgp_sig_info.has_operation()) or
                            (self.ldp_sig_info is not None and self.ldp_sig_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "signalling-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bgp-sig-info"):
                            if (self.bgp_sig_info is None):
                                self.bgp_sig_info = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                                self.bgp_sig_info.parent = self
                                self._children_name_map["bgp_sig_info"] = "bgp-sig-info"
                            return self.bgp_sig_info

                        if (child_yang_name == "ldp-sig-info"):
                            if (self.ldp_sig_info is None):
                                self.ldp_sig_info = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                                self.ldp_sig_info.parent = self
                                self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                            return self.ldp_sig_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bgp-sig-info" or name == "ldp-sig-info" or name == "ad-signalling-method"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ad-signalling-method"):
                            self.ad_signalling_method = value
                            self.ad_signalling_method.value_namespace = name_space
                            self.ad_signalling_method.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.group_name.is_set or
                        self.group_name_xr.is_set or
                        self.is_service_connected.is_set or
                        self.mtu_mismatch_ignore.is_set or
                        self.number_vpn.is_set or
                        self.service_name.is_set or
                        self.service_name_xr.is_set or
                        self.vpn_id.is_set or
                        self.vpn_name.is_set or
                        self.vpn_name_xr.is_set or
                        (self.signalling_info is not None and self.signalling_info.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.group_name_xr.yfilter != YFilter.not_set or
                        self.is_service_connected.yfilter != YFilter.not_set or
                        self.mtu_mismatch_ignore.yfilter != YFilter.not_set or
                        self.number_vpn.yfilter != YFilter.not_set or
                        self.service_name.yfilter != YFilter.not_set or
                        self.service_name_xr.yfilter != YFilter.not_set or
                        self.vpn_id.yfilter != YFilter.not_set or
                        self.vpn_name.yfilter != YFilter.not_set or
                        self.vpn_name_xr.yfilter != YFilter.not_set or
                        (self.signalling_info is not None and self.signalling_info.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "discovery" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                    if (self.is_service_connected.is_set or self.is_service_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_service_connected.get_name_leafdata())
                    if (self.mtu_mismatch_ignore.is_set or self.mtu_mismatch_ignore.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mtu_mismatch_ignore.get_name_leafdata())
                    if (self.number_vpn.is_set or self.number_vpn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_vpn.get_name_leafdata())
                    if (self.service_name.is_set or self.service_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.service_name.get_name_leafdata())
                    if (self.service_name_xr.is_set or self.service_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.service_name_xr.get_name_leafdata())
                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_id.get_name_leafdata())
                    if (self.vpn_name.is_set or self.vpn_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_name.get_name_leafdata())
                    if (self.vpn_name_xr.is_set or self.vpn_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_name_xr.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "signalling-info"):
                        if (self.signalling_info is None):
                            self.signalling_info = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo()
                            self.signalling_info.parent = self
                            self._children_name_map["signalling_info"] = "signalling-info"
                        return self.signalling_info

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "signalling-info" or name == "group-name" or name == "group-name-xr" or name == "is-service-connected" or name == "mtu-mismatch-ignore" or name == "number-vpn" or name == "service-name" or name == "service-name-xr" or name == "vpn-id" or name == "vpn-name" or name == "vpn-name-xr"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name-xr"):
                        self.group_name_xr = value
                        self.group_name_xr.value_namespace = name_space
                        self.group_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-service-connected"):
                        self.is_service_connected = value
                        self.is_service_connected.value_namespace = name_space
                        self.is_service_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "mtu-mismatch-ignore"):
                        self.mtu_mismatch_ignore = value
                        self.mtu_mismatch_ignore.value_namespace = name_space
                        self.mtu_mismatch_ignore.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-vpn"):
                        self.number_vpn = value
                        self.number_vpn.value_namespace = name_space
                        self.number_vpn.value_namespace_prefix = name_space_prefix
                    if(value_path == "service-name"):
                        self.service_name = value
                        self.service_name.value_namespace = name_space
                        self.service_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "service-name-xr"):
                        self.service_name_xr = value
                        self.service_name_xr.value_namespace = name_space
                        self.service_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-id"):
                        self.vpn_id = value
                        self.vpn_id.value_namespace = name_space
                        self.vpn_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-name"):
                        self.vpn_name = value
                        self.vpn_name.value_namespace = name_space
                        self.vpn_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-name-xr"):
                        self.vpn_name_xr = value
                        self.vpn_name_xr.value_namespace = name_space
                        self.vpn_name_xr.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.discovery:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.discovery:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "discoveries" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "discovery"):
                    for c in self.discovery:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.Discoveries.Discovery()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.discovery.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "discovery"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class FlexibleXconnectServiceSummary(Entity):
            """
            Flexible XConnect Service summary information
            
            .. attribute:: number_fxc
            
            	Number of flexible xconnect services
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_down
            
            	Number of flexible xconnect services whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_up
            
            	Number of flexible xconnect services whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.FlexibleXconnectServiceSummary, self).__init__()

                self.yang_name = "flexible-xconnect-service-summary"
                self.yang_parent_name = "standby"

                self.number_fxc = YLeaf(YType.uint32, "number-fxc")

                self.number_fxc_down = YLeaf(YType.uint32, "number-fxc-down")

                self.number_fxc_up = YLeaf(YType.uint32, "number-fxc-up")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("number_fxc",
                                "number_fxc_down",
                                "number_fxc_up") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.FlexibleXconnectServiceSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.FlexibleXconnectServiceSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.number_fxc.is_set or
                    self.number_fxc_down.is_set or
                    self.number_fxc_up.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.number_fxc.yfilter != YFilter.not_set or
                    self.number_fxc_down.yfilter != YFilter.not_set or
                    self.number_fxc_up.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "flexible-xconnect-service-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.number_fxc.is_set or self.number_fxc.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_fxc.get_name_leafdata())
                if (self.number_fxc_down.is_set or self.number_fxc_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_fxc_down.get_name_leafdata())
                if (self.number_fxc_up.is_set or self.number_fxc_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_fxc_up.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "number-fxc" or name == "number-fxc-down" or name == "number-fxc-up"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "number-fxc"):
                    self.number_fxc = value
                    self.number_fxc.value_namespace = name_space
                    self.number_fxc.value_namespace_prefix = name_space_prefix
                if(value_path == "number-fxc-down"):
                    self.number_fxc_down = value
                    self.number_fxc_down.value_namespace = name_space
                    self.number_fxc_down.value_namespace_prefix = name_space_prefix
                if(value_path == "number-fxc-up"):
                    self.number_fxc_up = value
                    self.number_fxc_up.value_namespace = name_space
                    self.number_fxc_up.value_namespace_prefix = name_space_prefix


        class MainInterfaces(Entity):
            """
            Main Interface
            
            .. attribute:: main_interface
            
            	Main Interface Table
            	**type**\: list of    :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.MainInterfaces, self).__init__()

                self.yang_name = "main-interfaces"
                self.yang_parent_name = "standby"

                self.main_interface = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.MainInterfaces, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.MainInterfaces, self).__setattr__(name, value)


            class MainInterface(Entity):
                """
                Main Interface Table
                
                .. attribute:: interface_name  <key>
                
                	Main interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: main_interface_info
                
                	Main Interface info
                	**type**\:   :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo>`
                
                .. attribute:: main_interface_instances
                
                	Main Interface Instance table
                	**type**\:   :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.MainInterfaces.MainInterface, self).__init__()

                    self.yang_name = "main-interface"
                    self.yang_parent_name = "main-interfaces"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.main_interface_info = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo()
                    self.main_interface_info.parent = self
                    self._children_name_map["main_interface_info"] = "main-interface-info"
                    self._children_yang_names.add("main-interface-info")

                    self.main_interface_instances = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances()
                    self.main_interface_instances.parent = self
                    self._children_name_map["main_interface_instances"] = "main-interface-instances"
                    self._children_yang_names.add("main-interface-instances")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.MainInterfaces.MainInterface, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.MainInterfaces.MainInterface, self).__setattr__(name, value)


                class MainInterfaceInstances(Entity):
                    """
                    Main Interface Instance table
                    
                    .. attribute:: main_interface_instance
                    
                    	Main Interface Instance
                    	**type**\: list of    :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances, self).__init__()

                        self.yang_name = "main-interface-instances"
                        self.yang_parent_name = "main-interface"

                        self.main_interface_instance = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances, self).__setattr__(name, value)


                    class MainInterfaceInstance(Entity):
                        """
                        Main Interface Instance
                        
                        .. attribute:: instance  <key>
                        
                        	Instance
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: main_interface_instance_bridge_ports
                        
                        	Main Interface Instance Bridge Port table
                        	**type**\:   :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                        
                        .. attribute:: main_interface_instance_info
                        
                        	Main Interface Instance info
                        	**type**\:   :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__init__()

                            self.yang_name = "main-interface-instance"
                            self.yang_parent_name = "main-interface-instances"

                            self.instance = YLeaf(YType.int32, "instance")

                            self.main_interface_instance_bridge_ports = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                            self.main_interface_instance_bridge_ports.parent = self
                            self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                            self._children_yang_names.add("main-interface-instance-bridge-ports")

                            self.main_interface_instance_info = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                            self.main_interface_instance_info.parent = self
                            self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"
                            self._children_yang_names.add("main-interface-instance-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("instance") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__setattr__(name, value)


                        class MainInterfaceInstanceInfo(Entity):
                            """
                            Main Interface Instance info
                            
                            .. attribute:: configured_instance
                            
                            	Configured Instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flush_count
                            
                            	Flush count 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_flags
                            
                            	Instance Flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_id
                            
                            	Instance ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_state
                            
                            	Instance State
                            	**type**\:   :py:class:`L2VpnMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfInstanceState>`
                            
                            .. attribute:: interface_count
                            
                            	Interface count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__init__()

                                self.yang_name = "main-interface-instance-info"
                                self.yang_parent_name = "main-interface-instance"

                                self.configured_instance = YLeaf(YType.uint32, "configured-instance")

                                self.flush_count = YLeaf(YType.uint32, "flush-count")

                                self.instance_flags = YLeaf(YType.uint32, "instance-flags")

                                self.instance_id = YLeaf(YType.uint32, "instance-id")

                                self.instance_state = YLeaf(YType.enumeration, "instance-state")

                                self.interface_count = YLeaf(YType.uint32, "interface-count")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configured_instance",
                                                "flush_count",
                                                "instance_flags",
                                                "instance_id",
                                                "instance_state",
                                                "interface_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.configured_instance.is_set or
                                    self.flush_count.is_set or
                                    self.instance_flags.is_set or
                                    self.instance_id.is_set or
                                    self.instance_state.is_set or
                                    self.interface_count.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configured_instance.yfilter != YFilter.not_set or
                                    self.flush_count.yfilter != YFilter.not_set or
                                    self.instance_flags.yfilter != YFilter.not_set or
                                    self.instance_id.yfilter != YFilter.not_set or
                                    self.instance_state.yfilter != YFilter.not_set or
                                    self.interface_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "main-interface-instance-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configured_instance.is_set or self.configured_instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_instance.get_name_leafdata())
                                if (self.flush_count.is_set or self.flush_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flush_count.get_name_leafdata())
                                if (self.instance_flags.is_set or self.instance_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance_flags.get_name_leafdata())
                                if (self.instance_id.is_set or self.instance_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance_id.get_name_leafdata())
                                if (self.instance_state.is_set or self.instance_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance_state.get_name_leafdata())
                                if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "configured-instance" or name == "flush-count" or name == "instance-flags" or name == "instance-id" or name == "instance-state" or name == "interface-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configured-instance"):
                                    self.configured_instance = value
                                    self.configured_instance.value_namespace = name_space
                                    self.configured_instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "flush-count"):
                                    self.flush_count = value
                                    self.flush_count.value_namespace = name_space
                                    self.flush_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "instance-flags"):
                                    self.instance_flags = value
                                    self.instance_flags.value_namespace = name_space
                                    self.instance_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "instance-id"):
                                    self.instance_id = value
                                    self.instance_id.value_namespace = name_space
                                    self.instance_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "instance-state"):
                                    self.instance_state = value
                                    self.instance_state.value_namespace = name_space
                                    self.instance_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-count"):
                                    self.interface_count = value
                                    self.interface_count.value_namespace = name_space
                                    self.interface_count.value_namespace_prefix = name_space_prefix


                        class MainInterfaceInstanceBridgePorts(Entity):
                            """
                            Main Interface Instance Bridge Port table
                            
                            .. attribute:: main_interface_instance_bridge_port
                            
                            	Main Interface Bridge Port info
                            	**type**\: list of    :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__init__()

                                self.yang_name = "main-interface-instance-bridge-ports"
                                self.yang_parent_name = "main-interface-instance"

                                self.main_interface_instance_bridge_port = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__setattr__(name, value)


                            class MainInterfaceInstanceBridgePort(Entity):
                                """
                                Main Interface Bridge Port info
                                
                                .. attribute:: bridge_port  <key>
                                
                                	Bridge Port
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: bridge_port_xr
                                
                                	Bridge port ifhandle
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: instance_id
                                
                                	Instance ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__init__()

                                    self.yang_name = "main-interface-instance-bridge-port"
                                    self.yang_parent_name = "main-interface-instance-bridge-ports"

                                    self.bridge_port = YLeaf(YType.str, "bridge-port")

                                    self.bridge_port_xr = YLeaf(YType.str, "bridge-port-xr")

                                    self.instance_id = YLeaf(YType.uint32, "instance-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bridge_port",
                                                    "bridge_port_xr",
                                                    "instance_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bridge_port.is_set or
                                        self.bridge_port_xr.is_set or
                                        self.instance_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bridge_port.yfilter != YFilter.not_set or
                                        self.bridge_port_xr.yfilter != YFilter.not_set or
                                        self.instance_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "main-interface-instance-bridge-port" + "[bridge-port='" + self.bridge_port.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bridge_port.is_set or self.bridge_port.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port.get_name_leafdata())
                                    if (self.bridge_port_xr.is_set or self.bridge_port_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_xr.get_name_leafdata())
                                    if (self.instance_id.is_set or self.instance_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bridge-port" or name == "bridge-port-xr" or name == "instance-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bridge-port"):
                                        self.bridge_port = value
                                        self.bridge_port.value_namespace = name_space
                                        self.bridge_port.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bridge-port-xr"):
                                        self.bridge_port_xr = value
                                        self.bridge_port_xr.value_namespace = name_space
                                        self.bridge_port_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-id"):
                                        self.instance_id = value
                                        self.instance_id.value_namespace = name_space
                                        self.instance_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.main_interface_instance_bridge_port:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.main_interface_instance_bridge_port:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "main-interface-instance-bridge-ports" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "main-interface-instance-bridge-port"):
                                    for c in self.main_interface_instance_bridge_port:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.main_interface_instance_bridge_port.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "main-interface-instance-bridge-port"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.instance.is_set or
                                (self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports.has_data()) or
                                (self.main_interface_instance_info is not None and self.main_interface_instance_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.instance.yfilter != YFilter.not_set or
                                (self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports.has_operation()) or
                                (self.main_interface_instance_info is not None and self.main_interface_instance_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "main-interface-instance" + "[instance='" + self.instance.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.instance.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "main-interface-instance-bridge-ports"):
                                if (self.main_interface_instance_bridge_ports is None):
                                    self.main_interface_instance_bridge_ports = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                                    self.main_interface_instance_bridge_ports.parent = self
                                    self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                                return self.main_interface_instance_bridge_ports

                            if (child_yang_name == "main-interface-instance-info"):
                                if (self.main_interface_instance_info is None):
                                    self.main_interface_instance_info = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                                    self.main_interface_instance_info.parent = self
                                    self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"
                                return self.main_interface_instance_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "main-interface-instance-bridge-ports" or name == "main-interface-instance-info" or name == "instance"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "instance"):
                                self.instance = value
                                self.instance.value_namespace = name_space
                                self.instance.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.main_interface_instance:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.main_interface_instance:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "main-interface-instances" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "main-interface-instance"):
                            for c in self.main_interface_instance:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.main_interface_instance.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "main-interface-instance"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MainInterfaceInfo(Entity):
                    """
                    Main Interface info
                    
                    .. attribute:: interface_count
                    
                    	Sub Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: main_interface_handle
                    
                    	Main Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: protected
                    
                    	Protected
                    	**type**\:   :py:class:`L2VpnMainIfProtectected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfProtectected>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo, self).__init__()

                        self.yang_name = "main-interface-info"
                        self.yang_parent_name = "main-interface"

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                        self.main_interface_handle = YLeaf(YType.str, "main-interface-handle")

                        self.protected = YLeaf(YType.enumeration, "protected")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_count",
                                        "main_interface_handle",
                                        "protected") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_count.is_set or
                            self.main_interface_handle.is_set or
                            self.protected.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set or
                            self.main_interface_handle.yfilter != YFilter.not_set or
                            self.protected.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "main-interface-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())
                        if (self.main_interface_handle.is_set or self.main_interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.main_interface_handle.get_name_leafdata())
                        if (self.protected.is_set or self.protected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protected.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-count" or name == "main-interface-handle" or name == "protected"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "main-interface-handle"):
                            self.main_interface_handle = value
                            self.main_interface_handle.value_namespace = name_space
                            self.main_interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "protected"):
                            self.protected = value
                            self.protected.value_namespace = name_space
                            self.protected.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        (self.main_interface_info is not None and self.main_interface_info.has_data()) or
                        (self.main_interface_instances is not None and self.main_interface_instances.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        (self.main_interface_info is not None and self.main_interface_info.has_operation()) or
                        (self.main_interface_instances is not None and self.main_interface_instances.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "main-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/main-interfaces/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "main-interface-info"):
                        if (self.main_interface_info is None):
                            self.main_interface_info = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo()
                            self.main_interface_info.parent = self
                            self._children_name_map["main_interface_info"] = "main-interface-info"
                        return self.main_interface_info

                    if (child_yang_name == "main-interface-instances"):
                        if (self.main_interface_instances is None):
                            self.main_interface_instances = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances()
                            self.main_interface_instances.parent = self
                            self._children_name_map["main_interface_instances"] = "main-interface-instances"
                        return self.main_interface_instances

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "main-interface-info" or name == "main-interface-instances" or name == "interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.main_interface:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.main_interface:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "main-interfaces" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "main-interface"):
                    for c in self.main_interface:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.MainInterfaces.MainInterface()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.main_interface.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "main-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class IccpSm(Entity):
            """
            ICCP\-based Service Multi\-homing operational data
            
            .. attribute:: iccp_groups
            
            	ICCP Group Table
            	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups>`
            
            .. attribute:: iccp_sm_summary
            
            	ICCP\-based Service Multi\-homing database summary
            	**type**\:   :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpSmSummary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.IccpSm, self).__init__()

                self.yang_name = "iccp-sm"
                self.yang_parent_name = "standby"

                self.iccp_groups = L2Vpnv2.Standby.IccpSm.IccpGroups()
                self.iccp_groups.parent = self
                self._children_name_map["iccp_groups"] = "iccp-groups"
                self._children_yang_names.add("iccp-groups")

                self.iccp_sm_summary = L2Vpnv2.Standby.IccpSm.IccpSmSummary()
                self.iccp_sm_summary.parent = self
                self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"
                self._children_yang_names.add("iccp-sm-summary")


            class IccpSmSummary(Entity):
                """
                ICCP\-based Service Multi\-homing database
                summary
                
                .. attribute:: connected_groups
                
                	Number of Connected Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: connecting_groups
                
                	Number of Connecting Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: failed_ports
                
                	Number of Failed Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groups
                
                	Total Number of Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: operational_ports
                
                	Number of Operational Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ports
                
                	Total Number of Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: provisioned_groups
                
                	Number of Provisioned Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reverting_ports
                
                	Number of Reverting Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronized_groups
                
                	Number of Synchronized Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronizing_groups
                
                	Number of Synchronizing Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unconfigured_ports
                
                	Number of Unconfigured Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_ports
                
                	Number of Unknown Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_groups
                
                	Number of Unresolved Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsynchronized_ports
                
                	Number of Unsynchronized Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.IccpSm.IccpSmSummary, self).__init__()

                    self.yang_name = "iccp-sm-summary"
                    self.yang_parent_name = "iccp-sm"

                    self.connected_groups = YLeaf(YType.uint32, "connected-groups")

                    self.connecting_groups = YLeaf(YType.uint32, "connecting-groups")

                    self.failed_ports = YLeaf(YType.uint32, "failed-ports")

                    self.groups = YLeaf(YType.uint32, "groups")

                    self.operational_ports = YLeaf(YType.uint32, "operational-ports")

                    self.ports = YLeaf(YType.uint32, "ports")

                    self.provisioned_groups = YLeaf(YType.uint32, "provisioned-groups")

                    self.reverting_ports = YLeaf(YType.uint32, "reverting-ports")

                    self.synchronized_groups = YLeaf(YType.uint32, "synchronized-groups")

                    self.synchronizing_groups = YLeaf(YType.uint32, "synchronizing-groups")

                    self.unconfigured_ports = YLeaf(YType.uint32, "unconfigured-ports")

                    self.unknown_ports = YLeaf(YType.uint32, "unknown-ports")

                    self.unresolved_groups = YLeaf(YType.uint32, "unresolved-groups")

                    self.unsynchronized_ports = YLeaf(YType.uint32, "unsynchronized-ports")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("connected_groups",
                                    "connecting_groups",
                                    "failed_ports",
                                    "groups",
                                    "operational_ports",
                                    "ports",
                                    "provisioned_groups",
                                    "reverting_ports",
                                    "synchronized_groups",
                                    "synchronizing_groups",
                                    "unconfigured_ports",
                                    "unknown_ports",
                                    "unresolved_groups",
                                    "unsynchronized_ports") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.IccpSm.IccpSmSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.IccpSm.IccpSmSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.connected_groups.is_set or
                        self.connecting_groups.is_set or
                        self.failed_ports.is_set or
                        self.groups.is_set or
                        self.operational_ports.is_set or
                        self.ports.is_set or
                        self.provisioned_groups.is_set or
                        self.reverting_ports.is_set or
                        self.synchronized_groups.is_set or
                        self.synchronizing_groups.is_set or
                        self.unconfigured_ports.is_set or
                        self.unknown_ports.is_set or
                        self.unresolved_groups.is_set or
                        self.unsynchronized_ports.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.connected_groups.yfilter != YFilter.not_set or
                        self.connecting_groups.yfilter != YFilter.not_set or
                        self.failed_ports.yfilter != YFilter.not_set or
                        self.groups.yfilter != YFilter.not_set or
                        self.operational_ports.yfilter != YFilter.not_set or
                        self.ports.yfilter != YFilter.not_set or
                        self.provisioned_groups.yfilter != YFilter.not_set or
                        self.reverting_ports.yfilter != YFilter.not_set or
                        self.synchronized_groups.yfilter != YFilter.not_set or
                        self.synchronizing_groups.yfilter != YFilter.not_set or
                        self.unconfigured_ports.yfilter != YFilter.not_set or
                        self.unknown_ports.yfilter != YFilter.not_set or
                        self.unresolved_groups.yfilter != YFilter.not_set or
                        self.unsynchronized_ports.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "iccp-sm-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/iccp-sm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.connected_groups.is_set or self.connected_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.connected_groups.get_name_leafdata())
                    if (self.connecting_groups.is_set or self.connecting_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.connecting_groups.get_name_leafdata())
                    if (self.failed_ports.is_set or self.failed_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.failed_ports.get_name_leafdata())
                    if (self.groups.is_set or self.groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.groups.get_name_leafdata())
                    if (self.operational_ports.is_set or self.operational_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.operational_ports.get_name_leafdata())
                    if (self.ports.is_set or self.ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ports.get_name_leafdata())
                    if (self.provisioned_groups.is_set or self.provisioned_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.provisioned_groups.get_name_leafdata())
                    if (self.reverting_ports.is_set or self.reverting_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reverting_ports.get_name_leafdata())
                    if (self.synchronized_groups.is_set or self.synchronized_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.synchronized_groups.get_name_leafdata())
                    if (self.synchronizing_groups.is_set or self.synchronizing_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.synchronizing_groups.get_name_leafdata())
                    if (self.unconfigured_ports.is_set or self.unconfigured_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unconfigured_ports.get_name_leafdata())
                    if (self.unknown_ports.is_set or self.unknown_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unknown_ports.get_name_leafdata())
                    if (self.unresolved_groups.is_set or self.unresolved_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unresolved_groups.get_name_leafdata())
                    if (self.unsynchronized_ports.is_set or self.unsynchronized_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unsynchronized_ports.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "connected-groups" or name == "connecting-groups" or name == "failed-ports" or name == "groups" or name == "operational-ports" or name == "ports" or name == "provisioned-groups" or name == "reverting-ports" or name == "synchronized-groups" or name == "synchronizing-groups" or name == "unconfigured-ports" or name == "unknown-ports" or name == "unresolved-groups" or name == "unsynchronized-ports"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "connected-groups"):
                        self.connected_groups = value
                        self.connected_groups.value_namespace = name_space
                        self.connected_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "connecting-groups"):
                        self.connecting_groups = value
                        self.connecting_groups.value_namespace = name_space
                        self.connecting_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "failed-ports"):
                        self.failed_ports = value
                        self.failed_ports.value_namespace = name_space
                        self.failed_ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "groups"):
                        self.groups = value
                        self.groups.value_namespace = name_space
                        self.groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "operational-ports"):
                        self.operational_ports = value
                        self.operational_ports.value_namespace = name_space
                        self.operational_ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "ports"):
                        self.ports = value
                        self.ports.value_namespace = name_space
                        self.ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "provisioned-groups"):
                        self.provisioned_groups = value
                        self.provisioned_groups.value_namespace = name_space
                        self.provisioned_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "reverting-ports"):
                        self.reverting_ports = value
                        self.reverting_ports.value_namespace = name_space
                        self.reverting_ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "synchronized-groups"):
                        self.synchronized_groups = value
                        self.synchronized_groups.value_namespace = name_space
                        self.synchronized_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "synchronizing-groups"):
                        self.synchronizing_groups = value
                        self.synchronizing_groups.value_namespace = name_space
                        self.synchronizing_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "unconfigured-ports"):
                        self.unconfigured_ports = value
                        self.unconfigured_ports.value_namespace = name_space
                        self.unconfigured_ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "unknown-ports"):
                        self.unknown_ports = value
                        self.unknown_ports.value_namespace = name_space
                        self.unknown_ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "unresolved-groups"):
                        self.unresolved_groups = value
                        self.unresolved_groups.value_namespace = name_space
                        self.unresolved_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "unsynchronized-ports"):
                        self.unsynchronized_ports = value
                        self.unsynchronized_ports.value_namespace = name_space
                        self.unsynchronized_ports.value_namespace_prefix = name_space_prefix


            class IccpGroups(Entity):
                """
                ICCP Group Table
                
                .. attribute:: iccp_group
                
                	ICCP Group
                	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.IccpSm.IccpGroups, self).__init__()

                    self.yang_name = "iccp-groups"
                    self.yang_parent_name = "iccp-sm"

                    self.iccp_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.IccpSm.IccpGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.IccpSm.IccpGroups, self).__setattr__(name, value)


                class IccpGroup(Entity):
                    """
                    ICCP Group
                    
                    .. attribute:: group_id  <key>
                    
                    	Group ID
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: iccp_group_info
                    
                    	ICCP Group Information
                    	**type**\:   :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                    
                    .. attribute:: iccp_ports
                    
                    	ICCP Port Table
                    	**type**\:   :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup, self).__init__()

                        self.yang_name = "iccp-group"
                        self.yang_parent_name = "iccp-groups"

                        self.group_id = YLeaf(YType.uint32, "group-id")

                        self.iccp_group_info = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                        self.iccp_group_info.parent = self
                        self._children_name_map["iccp_group_info"] = "iccp-group-info"
                        self._children_yang_names.add("iccp-group-info")

                        self.iccp_ports = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                        self.iccp_ports.parent = self
                        self._children_name_map["iccp_ports"] = "iccp-ports"
                        self._children_yang_names.add("iccp-ports")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup, self).__setattr__(name, value)


                    class IccpGroupInfo(Entity):
                        """
                        ICCP Group Information
                        
                        .. attribute:: group_id
                        
                        	Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: iccp_member_up
                        
                        	ICCP Member Up
                        	**type**\:  bool
                        
                        .. attribute:: iccp_transport_up
                        
                        	ICCP Transport Up
                        	**type**\:  bool
                        
                        .. attribute:: local_node_id
                        
                        	Local Node ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ports
                        
                        	List of ports in the group
                        	**type**\: list of    :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                        
                        .. attribute:: remote_node_id
                        
                        	Remote Node ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`IccpSmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmState>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__init__()

                            self.yang_name = "iccp-group-info"
                            self.yang_parent_name = "iccp-group"

                            self.group_id = YLeaf(YType.uint32, "group-id")

                            self.iccp_member_up = YLeaf(YType.boolean, "iccp-member-up")

                            self.iccp_transport_up = YLeaf(YType.boolean, "iccp-transport-up")

                            self.local_node_id = YLeaf(YType.uint8, "local-node-id")

                            self.remote_node_id = YLeaf(YType.uint8, "remote-node-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.ports = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_id",
                                            "iccp_member_up",
                                            "iccp_transport_up",
                                            "local_node_id",
                                            "remote_node_id",
                                            "state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__setattr__(name, value)


                        class Ports(Entity):
                            """
                            List of ports in the group
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\:  bool
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__init__()

                                self.yang_name = "ports"
                                self.yang_parent_name = "iccp-group-info"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.mac_flush_tcn = YLeaf(YType.boolean, "mac-flush-tcn")

                                self.local_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                self.local_port.parent = self
                                self._children_name_map["local_port"] = "local-port"
                                self._children_yang_names.add("local-port")

                                self.remote_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                self.remote_port.parent = self
                                self._children_name_map["remote_port"] = "remote-port"
                                self._children_yang_names.add("remote-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "mac_flush_tcn") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__setattr__(name, value)


                            class LocalPort(Entity):
                                """
                                Local port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__init__()

                                    self.yang_name = "local-port"
                                    self.yang_parent_name = "ports"

                                    self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                    self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                    self.port_state = YLeaf(YType.enumeration, "port-state")

                                    self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                    self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                    self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                    self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fsm_state",
                                                    "port_fail_code",
                                                    "port_state",
                                                    "reversion_time",
                                                    "reversion_time_remaining",
                                                    "vlan_state",
                                                    "vlan_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.fsm_state.is_set or
                                        self.port_fail_code.is_set or
                                        self.port_state.is_set or
                                        self.reversion_time.is_set or
                                        self.reversion_time_remaining.is_set or
                                        self.vlan_state.is_set or
                                        self.vlan_vector.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fsm_state.yfilter != YFilter.not_set or
                                        self.port_fail_code.yfilter != YFilter.not_set or
                                        self.port_state.yfilter != YFilter.not_set or
                                        self.reversion_time.yfilter != YFilter.not_set or
                                        self.reversion_time_remaining.yfilter != YFilter.not_set or
                                        self.vlan_state.yfilter != YFilter.not_set or
                                        self.vlan_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                    if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                    if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_state.get_name_leafdata())
                                    if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                    if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                    if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                    if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fsm-state"):
                                        self.fsm_state = value
                                        self.fsm_state.value_namespace = name_space
                                        self.fsm_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-fail-code"):
                                        self.port_fail_code = value
                                        self.port_fail_code.value_namespace = name_space
                                        self.port_fail_code.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-state"):
                                        self.port_state = value
                                        self.port_state.value_namespace = name_space
                                        self.port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time"):
                                        self.reversion_time = value
                                        self.reversion_time.value_namespace = name_space
                                        self.reversion_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time-remaining"):
                                        self.reversion_time_remaining = value
                                        self.reversion_time_remaining.value_namespace = name_space
                                        self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-state"):
                                        self.vlan_state = value
                                        self.vlan_state.value_namespace = name_space
                                        self.vlan_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-vector"):
                                        self.vlan_vector = value
                                        self.vlan_vector.value_namespace = name_space
                                        self.vlan_vector.value_namespace_prefix = name_space_prefix


                            class RemotePort(Entity):
                                """
                                Remote port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__init__()

                                    self.yang_name = "remote-port"
                                    self.yang_parent_name = "ports"

                                    self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                    self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                    self.port_state = YLeaf(YType.enumeration, "port-state")

                                    self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                    self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                    self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                    self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fsm_state",
                                                    "port_fail_code",
                                                    "port_state",
                                                    "reversion_time",
                                                    "reversion_time_remaining",
                                                    "vlan_state",
                                                    "vlan_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.fsm_state.is_set or
                                        self.port_fail_code.is_set or
                                        self.port_state.is_set or
                                        self.reversion_time.is_set or
                                        self.reversion_time_remaining.is_set or
                                        self.vlan_state.is_set or
                                        self.vlan_vector.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fsm_state.yfilter != YFilter.not_set or
                                        self.port_fail_code.yfilter != YFilter.not_set or
                                        self.port_state.yfilter != YFilter.not_set or
                                        self.reversion_time.yfilter != YFilter.not_set or
                                        self.reversion_time_remaining.yfilter != YFilter.not_set or
                                        self.vlan_state.yfilter != YFilter.not_set or
                                        self.vlan_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                    if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                    if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_state.get_name_leafdata())
                                    if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                    if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                    if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                    if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fsm-state"):
                                        self.fsm_state = value
                                        self.fsm_state.value_namespace = name_space
                                        self.fsm_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-fail-code"):
                                        self.port_fail_code = value
                                        self.port_fail_code.value_namespace = name_space
                                        self.port_fail_code.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-state"):
                                        self.port_state = value
                                        self.port_state.value_namespace = name_space
                                        self.port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time"):
                                        self.reversion_time = value
                                        self.reversion_time.value_namespace = name_space
                                        self.reversion_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time-remaining"):
                                        self.reversion_time_remaining = value
                                        self.reversion_time_remaining.value_namespace = name_space
                                        self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-state"):
                                        self.vlan_state = value
                                        self.vlan_state.value_namespace = name_space
                                        self.vlan_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-vector"):
                                        self.vlan_vector = value
                                        self.vlan_vector.value_namespace = name_space
                                        self.vlan_vector.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.interface_name.is_set or
                                    self.mac_flush_tcn.is_set or
                                    (self.local_port is not None and self.local_port.has_data()) or
                                    (self.remote_port is not None and self.remote_port.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.mac_flush_tcn.yfilter != YFilter.not_set or
                                    (self.local_port is not None and self.local_port.has_operation()) or
                                    (self.remote_port is not None and self.remote_port.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ports" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.mac_flush_tcn.is_set or self.mac_flush_tcn.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_flush_tcn.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-port"):
                                    if (self.local_port is None):
                                        self.local_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                        self.local_port.parent = self
                                        self._children_name_map["local_port"] = "local-port"
                                    return self.local_port

                                if (child_yang_name == "remote-port"):
                                    if (self.remote_port is None):
                                        self.remote_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                        self.remote_port.parent = self
                                        self._children_name_map["remote_port"] = "remote-port"
                                    return self.remote_port

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-port" or name == "remote-port" or name == "interface-name" or name == "mac-flush-tcn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-flush-tcn"):
                                    self.mac_flush_tcn = value
                                    self.mac_flush_tcn.value_namespace = name_space
                                    self.mac_flush_tcn.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ports:
                                if (c.has_data()):
                                    return True
                            return (
                                self.group_id.is_set or
                                self.iccp_member_up.is_set or
                                self.iccp_transport_up.is_set or
                                self.local_node_id.is_set or
                                self.remote_node_id.is_set or
                                self.state.is_set)

                        def has_operation(self):
                            for c in self.ports:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_id.yfilter != YFilter.not_set or
                                self.iccp_member_up.yfilter != YFilter.not_set or
                                self.iccp_transport_up.yfilter != YFilter.not_set or
                                self.local_node_id.yfilter != YFilter.not_set or
                                self.remote_node_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_id.get_name_leafdata())
                            if (self.iccp_member_up.is_set or self.iccp_member_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_member_up.get_name_leafdata())
                            if (self.iccp_transport_up.is_set or self.iccp_transport_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_transport_up.get_name_leafdata())
                            if (self.local_node_id.is_set or self.local_node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_node_id.get_name_leafdata())
                            if (self.remote_node_id.is_set or self.remote_node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_node_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ports"):
                                for c in self.ports:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ports.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ports" or name == "group-id" or name == "iccp-member-up" or name == "iccp-transport-up" or name == "local-node-id" or name == "remote-node-id" or name == "state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-id"):
                                self.group_id = value
                                self.group_id.value_namespace = name_space
                                self.group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-member-up"):
                                self.iccp_member_up = value
                                self.iccp_member_up.value_namespace = name_space
                                self.iccp_member_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-transport-up"):
                                self.iccp_transport_up = value
                                self.iccp_transport_up.value_namespace = name_space
                                self.iccp_transport_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-node-id"):
                                self.local_node_id = value
                                self.local_node_id.value_namespace = name_space
                                self.local_node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-node-id"):
                                self.remote_node_id = value
                                self.remote_node_id.value_namespace = name_space
                                self.remote_node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix


                    class IccpPorts(Entity):
                        """
                        ICCP Port Table
                        
                        .. attribute:: iccp_port
                        
                        	ICCP Port
                        	**type**\: list of    :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__init__()

                            self.yang_name = "iccp-ports"
                            self.yang_parent_name = "iccp-group"

                            self.iccp_port = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__setattr__(name, value)


                        class IccpPort(Entity):
                            """
                            ICCP Port
                            
                            .. attribute:: interface  <key>
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\:  bool
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__init__()

                                self.yang_name = "iccp-port"
                                self.yang_parent_name = "iccp-ports"

                                self.interface = YLeaf(YType.str, "interface")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.mac_flush_tcn = YLeaf(YType.boolean, "mac-flush-tcn")

                                self.local_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                self.local_port.parent = self
                                self._children_name_map["local_port"] = "local-port"
                                self._children_yang_names.add("local-port")

                                self.remote_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                self.remote_port.parent = self
                                self._children_name_map["remote_port"] = "remote-port"
                                self._children_yang_names.add("remote-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface",
                                                "interface_name",
                                                "mac_flush_tcn") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__setattr__(name, value)


                            class LocalPort(Entity):
                                """
                                Local port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__init__()

                                    self.yang_name = "local-port"
                                    self.yang_parent_name = "iccp-port"

                                    self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                    self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                    self.port_state = YLeaf(YType.enumeration, "port-state")

                                    self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                    self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                    self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                    self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fsm_state",
                                                    "port_fail_code",
                                                    "port_state",
                                                    "reversion_time",
                                                    "reversion_time_remaining",
                                                    "vlan_state",
                                                    "vlan_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.fsm_state.is_set or
                                        self.port_fail_code.is_set or
                                        self.port_state.is_set or
                                        self.reversion_time.is_set or
                                        self.reversion_time_remaining.is_set or
                                        self.vlan_state.is_set or
                                        self.vlan_vector.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fsm_state.yfilter != YFilter.not_set or
                                        self.port_fail_code.yfilter != YFilter.not_set or
                                        self.port_state.yfilter != YFilter.not_set or
                                        self.reversion_time.yfilter != YFilter.not_set or
                                        self.reversion_time_remaining.yfilter != YFilter.not_set or
                                        self.vlan_state.yfilter != YFilter.not_set or
                                        self.vlan_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                    if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                    if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_state.get_name_leafdata())
                                    if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                    if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                    if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                    if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fsm-state"):
                                        self.fsm_state = value
                                        self.fsm_state.value_namespace = name_space
                                        self.fsm_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-fail-code"):
                                        self.port_fail_code = value
                                        self.port_fail_code.value_namespace = name_space
                                        self.port_fail_code.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-state"):
                                        self.port_state = value
                                        self.port_state.value_namespace = name_space
                                        self.port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time"):
                                        self.reversion_time = value
                                        self.reversion_time.value_namespace = name_space
                                        self.reversion_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time-remaining"):
                                        self.reversion_time_remaining = value
                                        self.reversion_time_remaining.value_namespace = name_space
                                        self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-state"):
                                        self.vlan_state = value
                                        self.vlan_state.value_namespace = name_space
                                        self.vlan_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-vector"):
                                        self.vlan_vector = value
                                        self.vlan_vector.value_namespace = name_space
                                        self.vlan_vector.value_namespace_prefix = name_space_prefix


                            class RemotePort(Entity):
                                """
                                Remote port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__init__()

                                    self.yang_name = "remote-port"
                                    self.yang_parent_name = "iccp-port"

                                    self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                    self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                    self.port_state = YLeaf(YType.enumeration, "port-state")

                                    self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                    self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                    self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                    self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fsm_state",
                                                    "port_fail_code",
                                                    "port_state",
                                                    "reversion_time",
                                                    "reversion_time_remaining",
                                                    "vlan_state",
                                                    "vlan_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.fsm_state.is_set or
                                        self.port_fail_code.is_set or
                                        self.port_state.is_set or
                                        self.reversion_time.is_set or
                                        self.reversion_time_remaining.is_set or
                                        self.vlan_state.is_set or
                                        self.vlan_vector.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fsm_state.yfilter != YFilter.not_set or
                                        self.port_fail_code.yfilter != YFilter.not_set or
                                        self.port_state.yfilter != YFilter.not_set or
                                        self.reversion_time.yfilter != YFilter.not_set or
                                        self.reversion_time_remaining.yfilter != YFilter.not_set or
                                        self.vlan_state.yfilter != YFilter.not_set or
                                        self.vlan_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                    if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                    if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_state.get_name_leafdata())
                                    if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                    if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                    if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                    if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fsm-state"):
                                        self.fsm_state = value
                                        self.fsm_state.value_namespace = name_space
                                        self.fsm_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-fail-code"):
                                        self.port_fail_code = value
                                        self.port_fail_code.value_namespace = name_space
                                        self.port_fail_code.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-state"):
                                        self.port_state = value
                                        self.port_state.value_namespace = name_space
                                        self.port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time"):
                                        self.reversion_time = value
                                        self.reversion_time.value_namespace = name_space
                                        self.reversion_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time-remaining"):
                                        self.reversion_time_remaining = value
                                        self.reversion_time_remaining.value_namespace = name_space
                                        self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-state"):
                                        self.vlan_state = value
                                        self.vlan_state.value_namespace = name_space
                                        self.vlan_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-vector"):
                                        self.vlan_vector = value
                                        self.vlan_vector.value_namespace = name_space
                                        self.vlan_vector.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.interface.is_set or
                                    self.interface_name.is_set or
                                    self.mac_flush_tcn.is_set or
                                    (self.local_port is not None and self.local_port.has_data()) or
                                    (self.remote_port is not None and self.remote_port.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.mac_flush_tcn.yfilter != YFilter.not_set or
                                    (self.local_port is not None and self.local_port.has_operation()) or
                                    (self.remote_port is not None and self.remote_port.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-port" + "[interface='" + self.interface.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.mac_flush_tcn.is_set or self.mac_flush_tcn.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_flush_tcn.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-port"):
                                    if (self.local_port is None):
                                        self.local_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                        self.local_port.parent = self
                                        self._children_name_map["local_port"] = "local-port"
                                    return self.local_port

                                if (child_yang_name == "remote-port"):
                                    if (self.remote_port is None):
                                        self.remote_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                        self.remote_port.parent = self
                                        self._children_name_map["remote_port"] = "remote-port"
                                    return self.remote_port

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-port" or name == "remote-port" or name == "interface" or name == "interface-name" or name == "mac-flush-tcn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface"):
                                    self.interface = value
                                    self.interface.value_namespace = name_space
                                    self.interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-flush-tcn"):
                                    self.mac_flush_tcn = value
                                    self.mac_flush_tcn.value_namespace = name_space
                                    self.mac_flush_tcn.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.iccp_port:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.iccp_port:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-ports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "iccp-port"):
                                for c in self.iccp_port:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.iccp_port.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "iccp-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.group_id.is_set or
                            (self.iccp_group_info is not None and self.iccp_group_info.has_data()) or
                            (self.iccp_ports is not None and self.iccp_ports.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_id.yfilter != YFilter.not_set or
                            (self.iccp_group_info is not None and self.iccp_group_info.has_operation()) or
                            (self.iccp_ports is not None and self.iccp_ports.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-group" + "[group-id='" + self.group_id.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/iccp-sm/iccp-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-group-info"):
                            if (self.iccp_group_info is None):
                                self.iccp_group_info = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                                self.iccp_group_info.parent = self
                                self._children_name_map["iccp_group_info"] = "iccp-group-info"
                            return self.iccp_group_info

                        if (child_yang_name == "iccp-ports"):
                            if (self.iccp_ports is None):
                                self.iccp_ports = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                                self.iccp_ports.parent = self
                                self._children_name_map["iccp_ports"] = "iccp-ports"
                            return self.iccp_ports

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-group-info" or name == "iccp-ports" or name == "group-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-id"):
                            self.group_id = value
                            self.group_id.value_namespace = name_space
                            self.group_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.iccp_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.iccp_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "iccp-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/iccp-sm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "iccp-group"):
                        for c in self.iccp_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.iccp_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.iccp_groups is not None and self.iccp_groups.has_data()) or
                    (self.iccp_sm_summary is not None and self.iccp_sm_summary.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.iccp_groups is not None and self.iccp_groups.has_operation()) or
                    (self.iccp_sm_summary is not None and self.iccp_sm_summary.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "iccp-sm" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "iccp-groups"):
                    if (self.iccp_groups is None):
                        self.iccp_groups = L2Vpnv2.Standby.IccpSm.IccpGroups()
                        self.iccp_groups.parent = self
                        self._children_name_map["iccp_groups"] = "iccp-groups"
                    return self.iccp_groups

                if (child_yang_name == "iccp-sm-summary"):
                    if (self.iccp_sm_summary is None):
                        self.iccp_sm_summary = L2Vpnv2.Standby.IccpSm.IccpSmSummary()
                        self.iccp_sm_summary.parent = self
                        self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"
                    return self.iccp_sm_summary

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "iccp-groups" or name == "iccp-sm-summary"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class BridgeSummary(Entity):
            """
            Bridge Domain summary information
            
            .. attribute:: num_vn_is
            
            	Number of VNIs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_down
            
            	Number of VNIs down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_unresolved
            
            	Number of VNIs unresolved
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_up
            
            	Number of VNIs up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs
            
            	Number of attachment circuits
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs_up
            
            	Number of attachment circuits whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains
            
            	Number of bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_shut
            
            	Number of bridge\-domains admin disabled
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_up
            
            	Number of bridge\-domains up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_default_bridge_doamins
            
            	Number of default bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp
            
            	Number of P2MPs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_down
            
            	Number of P2MPs whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_up
            
            	Number of P2MPs whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p_ws_up
            
            	Number of pseudowires whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_core
            
            	Number of PBB Core
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_edge
            
            	Number of PBB Edge
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pseudowires
            
            	Number of pseudowires
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_a_cs
            
            	Number of partially programmed attachment circuits
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_bridges
            
            	Number of partially programmed bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_pseudowires
            
            	Number of partially programmed pseudowires
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_pseudowires
            
            	Number of pseudowires whose state is standby
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.BridgeSummary, self).__init__()

                self.yang_name = "bridge-summary"
                self.yang_parent_name = "standby"

                self.num_vn_is = YLeaf(YType.uint32, "num-vn-is")

                self.num_vn_is_down = YLeaf(YType.uint32, "num-vn-is-down")

                self.num_vn_is_unresolved = YLeaf(YType.uint32, "num-vn-is-unresolved")

                self.num_vn_is_up = YLeaf(YType.uint32, "num-vn-is-up")

                self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                self.number_bridge_domains = YLeaf(YType.uint32, "number-bridge-domains")

                self.number_bridge_domains_shut = YLeaf(YType.uint32, "number-bridge-domains-shut")

                self.number_bridge_domains_up = YLeaf(YType.uint32, "number-bridge-domains-up")

                self.number_default_bridge_doamins = YLeaf(YType.uint32, "number-default-bridge-doamins")

                self.number_groups = YLeaf(YType.uint32, "number-groups")

                self.number_p2mp = YLeaf(YType.uint32, "number-p2mp")

                self.number_p2mp_down = YLeaf(YType.uint32, "number-p2mp-down")

                self.number_p2mp_up = YLeaf(YType.uint32, "number-p2mp-up")

                self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                self.number_pbb_core = YLeaf(YType.uint32, "number-pbb-core")

                self.number_pbb_edge = YLeaf(YType.uint32, "number-pbb-edge")

                self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                self.partially_programmed_a_cs = YLeaf(YType.uint32, "partially-programmed-a-cs")

                self.partially_programmed_bridges = YLeaf(YType.uint32, "partially-programmed-bridges")

                self.partially_programmed_pseudowires = YLeaf(YType.uint32, "partially-programmed-pseudowires")

                self.standby_pseudowires = YLeaf(YType.uint32, "standby-pseudowires")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("num_vn_is",
                                "num_vn_is_down",
                                "num_vn_is_unresolved",
                                "num_vn_is_up",
                                "number_a_cs",
                                "number_a_cs_up",
                                "number_bridge_domains",
                                "number_bridge_domains_shut",
                                "number_bridge_domains_up",
                                "number_default_bridge_doamins",
                                "number_groups",
                                "number_p2mp",
                                "number_p2mp_down",
                                "number_p2mp_up",
                                "number_p_ws_up",
                                "number_pbb_core",
                                "number_pbb_edge",
                                "number_pseudowires",
                                "out_of_memory_state",
                                "partially_programmed_a_cs",
                                "partially_programmed_bridges",
                                "partially_programmed_pseudowires",
                                "standby_pseudowires") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.BridgeSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.BridgeSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.num_vn_is.is_set or
                    self.num_vn_is_down.is_set or
                    self.num_vn_is_unresolved.is_set or
                    self.num_vn_is_up.is_set or
                    self.number_a_cs.is_set or
                    self.number_a_cs_up.is_set or
                    self.number_bridge_domains.is_set or
                    self.number_bridge_domains_shut.is_set or
                    self.number_bridge_domains_up.is_set or
                    self.number_default_bridge_doamins.is_set or
                    self.number_groups.is_set or
                    self.number_p2mp.is_set or
                    self.number_p2mp_down.is_set or
                    self.number_p2mp_up.is_set or
                    self.number_p_ws_up.is_set or
                    self.number_pbb_core.is_set or
                    self.number_pbb_edge.is_set or
                    self.number_pseudowires.is_set or
                    self.out_of_memory_state.is_set or
                    self.partially_programmed_a_cs.is_set or
                    self.partially_programmed_bridges.is_set or
                    self.partially_programmed_pseudowires.is_set or
                    self.standby_pseudowires.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.num_vn_is.yfilter != YFilter.not_set or
                    self.num_vn_is_down.yfilter != YFilter.not_set or
                    self.num_vn_is_unresolved.yfilter != YFilter.not_set or
                    self.num_vn_is_up.yfilter != YFilter.not_set or
                    self.number_a_cs.yfilter != YFilter.not_set or
                    self.number_a_cs_up.yfilter != YFilter.not_set or
                    self.number_bridge_domains.yfilter != YFilter.not_set or
                    self.number_bridge_domains_shut.yfilter != YFilter.not_set or
                    self.number_bridge_domains_up.yfilter != YFilter.not_set or
                    self.number_default_bridge_doamins.yfilter != YFilter.not_set or
                    self.number_groups.yfilter != YFilter.not_set or
                    self.number_p2mp.yfilter != YFilter.not_set or
                    self.number_p2mp_down.yfilter != YFilter.not_set or
                    self.number_p2mp_up.yfilter != YFilter.not_set or
                    self.number_p_ws_up.yfilter != YFilter.not_set or
                    self.number_pbb_core.yfilter != YFilter.not_set or
                    self.number_pbb_edge.yfilter != YFilter.not_set or
                    self.number_pseudowires.yfilter != YFilter.not_set or
                    self.out_of_memory_state.yfilter != YFilter.not_set or
                    self.partially_programmed_a_cs.yfilter != YFilter.not_set or
                    self.partially_programmed_bridges.yfilter != YFilter.not_set or
                    self.partially_programmed_pseudowires.yfilter != YFilter.not_set or
                    self.standby_pseudowires.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bridge-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.num_vn_is.is_set or self.num_vn_is.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.num_vn_is.get_name_leafdata())
                if (self.num_vn_is_down.is_set or self.num_vn_is_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.num_vn_is_down.get_name_leafdata())
                if (self.num_vn_is_unresolved.is_set or self.num_vn_is_unresolved.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.num_vn_is_unresolved.get_name_leafdata())
                if (self.num_vn_is_up.is_set or self.num_vn_is_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.num_vn_is_up.get_name_leafdata())
                if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                if (self.number_bridge_domains.is_set or self.number_bridge_domains.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_bridge_domains.get_name_leafdata())
                if (self.number_bridge_domains_shut.is_set or self.number_bridge_domains_shut.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_bridge_domains_shut.get_name_leafdata())
                if (self.number_bridge_domains_up.is_set or self.number_bridge_domains_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_bridge_domains_up.get_name_leafdata())
                if (self.number_default_bridge_doamins.is_set or self.number_default_bridge_doamins.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_default_bridge_doamins.get_name_leafdata())
                if (self.number_groups.is_set or self.number_groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_groups.get_name_leafdata())
                if (self.number_p2mp.is_set or self.number_p2mp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_p2mp.get_name_leafdata())
                if (self.number_p2mp_down.is_set or self.number_p2mp_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_p2mp_down.get_name_leafdata())
                if (self.number_p2mp_up.is_set or self.number_p2mp_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_p2mp_up.get_name_leafdata())
                if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                if (self.number_pbb_core.is_set or self.number_pbb_core.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_pbb_core.get_name_leafdata())
                if (self.number_pbb_edge.is_set or self.number_pbb_edge.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_pbb_edge.get_name_leafdata())
                if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                if (self.partially_programmed_a_cs.is_set or self.partially_programmed_a_cs.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.partially_programmed_a_cs.get_name_leafdata())
                if (self.partially_programmed_bridges.is_set or self.partially_programmed_bridges.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.partially_programmed_bridges.get_name_leafdata())
                if (self.partially_programmed_pseudowires.is_set or self.partially_programmed_pseudowires.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.partially_programmed_pseudowires.get_name_leafdata())
                if (self.standby_pseudowires.is_set or self.standby_pseudowires.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.standby_pseudowires.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "num-vn-is" or name == "num-vn-is-down" or name == "num-vn-is-unresolved" or name == "num-vn-is-up" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-bridge-domains" or name == "number-bridge-domains-shut" or name == "number-bridge-domains-up" or name == "number-default-bridge-doamins" or name == "number-groups" or name == "number-p2mp" or name == "number-p2mp-down" or name == "number-p2mp-up" or name == "number-p-ws-up" or name == "number-pbb-core" or name == "number-pbb-edge" or name == "number-pseudowires" or name == "out-of-memory-state" or name == "partially-programmed-a-cs" or name == "partially-programmed-bridges" or name == "partially-programmed-pseudowires" or name == "standby-pseudowires"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "num-vn-is"):
                    self.num_vn_is = value
                    self.num_vn_is.value_namespace = name_space
                    self.num_vn_is.value_namespace_prefix = name_space_prefix
                if(value_path == "num-vn-is-down"):
                    self.num_vn_is_down = value
                    self.num_vn_is_down.value_namespace = name_space
                    self.num_vn_is_down.value_namespace_prefix = name_space_prefix
                if(value_path == "num-vn-is-unresolved"):
                    self.num_vn_is_unresolved = value
                    self.num_vn_is_unresolved.value_namespace = name_space
                    self.num_vn_is_unresolved.value_namespace_prefix = name_space_prefix
                if(value_path == "num-vn-is-up"):
                    self.num_vn_is_up = value
                    self.num_vn_is_up.value_namespace = name_space
                    self.num_vn_is_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-a-cs"):
                    self.number_a_cs = value
                    self.number_a_cs.value_namespace = name_space
                    self.number_a_cs.value_namespace_prefix = name_space_prefix
                if(value_path == "number-a-cs-up"):
                    self.number_a_cs_up = value
                    self.number_a_cs_up.value_namespace = name_space
                    self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-bridge-domains"):
                    self.number_bridge_domains = value
                    self.number_bridge_domains.value_namespace = name_space
                    self.number_bridge_domains.value_namespace_prefix = name_space_prefix
                if(value_path == "number-bridge-domains-shut"):
                    self.number_bridge_domains_shut = value
                    self.number_bridge_domains_shut.value_namespace = name_space
                    self.number_bridge_domains_shut.value_namespace_prefix = name_space_prefix
                if(value_path == "number-bridge-domains-up"):
                    self.number_bridge_domains_up = value
                    self.number_bridge_domains_up.value_namespace = name_space
                    self.number_bridge_domains_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-default-bridge-doamins"):
                    self.number_default_bridge_doamins = value
                    self.number_default_bridge_doamins.value_namespace = name_space
                    self.number_default_bridge_doamins.value_namespace_prefix = name_space_prefix
                if(value_path == "number-groups"):
                    self.number_groups = value
                    self.number_groups.value_namespace = name_space
                    self.number_groups.value_namespace_prefix = name_space_prefix
                if(value_path == "number-p2mp"):
                    self.number_p2mp = value
                    self.number_p2mp.value_namespace = name_space
                    self.number_p2mp.value_namespace_prefix = name_space_prefix
                if(value_path == "number-p2mp-down"):
                    self.number_p2mp_down = value
                    self.number_p2mp_down.value_namespace = name_space
                    self.number_p2mp_down.value_namespace_prefix = name_space_prefix
                if(value_path == "number-p2mp-up"):
                    self.number_p2mp_up = value
                    self.number_p2mp_up.value_namespace = name_space
                    self.number_p2mp_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-p-ws-up"):
                    self.number_p_ws_up = value
                    self.number_p_ws_up.value_namespace = name_space
                    self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-pbb-core"):
                    self.number_pbb_core = value
                    self.number_pbb_core.value_namespace = name_space
                    self.number_pbb_core.value_namespace_prefix = name_space_prefix
                if(value_path == "number-pbb-edge"):
                    self.number_pbb_edge = value
                    self.number_pbb_edge.value_namespace = name_space
                    self.number_pbb_edge.value_namespace_prefix = name_space_prefix
                if(value_path == "number-pseudowires"):
                    self.number_pseudowires = value
                    self.number_pseudowires.value_namespace = name_space
                    self.number_pseudowires.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-memory-state"):
                    self.out_of_memory_state = value
                    self.out_of_memory_state.value_namespace = name_space
                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                if(value_path == "partially-programmed-a-cs"):
                    self.partially_programmed_a_cs = value
                    self.partially_programmed_a_cs.value_namespace = name_space
                    self.partially_programmed_a_cs.value_namespace_prefix = name_space_prefix
                if(value_path == "partially-programmed-bridges"):
                    self.partially_programmed_bridges = value
                    self.partially_programmed_bridges.value_namespace = name_space
                    self.partially_programmed_bridges.value_namespace_prefix = name_space_prefix
                if(value_path == "partially-programmed-pseudowires"):
                    self.partially_programmed_pseudowires = value
                    self.partially_programmed_pseudowires.value_namespace = name_space
                    self.partially_programmed_pseudowires.value_namespace_prefix = name_space_prefix
                if(value_path == "standby-pseudowires"):
                    self.standby_pseudowires = value
                    self.standby_pseudowires.value_namespace = name_space
                    self.standby_pseudowires.value_namespace_prefix = name_space_prefix


        class Nsr(Entity):
            """
            L2VPN NSR information
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.EventHistory>`
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.FailoverStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.IssuStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.NsrStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.ReportCard>`
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\:  bool
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.XidInfo>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.Nsr, self).__init__()

                self.yang_name = "nsr"
                self.yang_parent_name = "standby"

                self.process_role = YLeaf(YType.uint8, "process-role")

                self.process_state = YLeaf(YType.uint8, "process-state")

                self.state_transition_time = YLeafList(YType.uint32, "state-transition-time")

                self.sw_install_in_progress = YLeaf(YType.boolean, "sw-install-in-progress")

                self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                self.failover_status = L2Vpnv2.Standby.Nsr.FailoverStatus()
                self.failover_status.parent = self
                self._children_name_map["failover_status"] = "failover-status"
                self._children_yang_names.add("failover-status")

                self.issu_status = L2Vpnv2.Standby.Nsr.IssuStatus()
                self.issu_status.parent = self
                self._children_name_map["issu_status"] = "issu-status"
                self._children_yang_names.add("issu-status")

                self.nsr_status = L2Vpnv2.Standby.Nsr.NsrStatus()
                self.nsr_status.parent = self
                self._children_name_map["nsr_status"] = "nsr-status"
                self._children_yang_names.add("nsr-status")

                self.event_history = YList(self)
                self.report_card = YList(self)
                self.xid_info = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("process_role",
                                "process_state",
                                "state_transition_time",
                                "sw_install_in_progress",
                                "sync_flags") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.Nsr, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.Nsr, self).__setattr__(name, value)


            class FailoverStatus(Entity):
                """
                L2VPN failover status
                
                .. attribute:: master_time
                
                	Master time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Nsr.FailoverStatus, self).__init__()

                    self.yang_name = "failover-status"
                    self.yang_parent_name = "nsr"

                    self.master_time = YLeaf(YType.uint32, "master-time")

                    self.start_time = YLeaf(YType.uint32, "start-time")

                    self.triggered_time = YLeaf(YType.uint32, "triggered-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("master_time",
                                    "start_time",
                                    "triggered_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Nsr.FailoverStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Nsr.FailoverStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.master_time.is_set or
                        self.start_time.is_set or
                        self.triggered_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.master_time.yfilter != YFilter.not_set or
                        self.start_time.yfilter != YFilter.not_set or
                        self.triggered_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "failover-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.master_time.is_set or self.master_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.master_time.get_name_leafdata())
                    if (self.start_time.is_set or self.start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.start_time.get_name_leafdata())
                    if (self.triggered_time.is_set or self.triggered_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.triggered_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "master-time" or name == "start-time" or name == "triggered-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "master-time"):
                        self.master_time = value
                        self.master_time.value_namespace = name_space
                        self.master_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "start-time"):
                        self.start_time = value
                        self.start_time.value_namespace = name_space
                        self.start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "triggered-time"):
                        self.triggered_time = value
                        self.triggered_time.value_namespace = name_space
                        self.triggered_time.value_namespace_prefix = name_space_prefix


            class NsrStatus(Entity):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Nsr.NsrStatus, self).__init__()

                    self.yang_name = "nsr-status"
                    self.yang_parent_name = "nsr"

                    self.role = YLeaf(YType.enumeration, "role")

                    self.idt_status = L2Vpnv2.Standby.Nsr.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"
                    self._children_yang_names.add("idt-status")

                    self.previ_ous_idt_status = L2Vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._children_yang_names.add("previ-ous-idt-status")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("role") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Nsr.NsrStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Nsr.NsrStatus, self).__setattr__(name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Nsr.NsrStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "nsr-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Nsr.NsrStatus.IdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Nsr.NsrStatus.IdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/nsr-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "nsr-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "previ-ous-idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/nsr-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.role.is_set or
                        (self.idt_status is not None and self.idt_status.has_data()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.role.yfilter != YFilter.not_set or
                        (self.idt_status is not None and self.idt_status.has_operation()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "idt-status"):
                        if (self.idt_status is None):
                            self.idt_status = L2Vpnv2.Standby.Nsr.NsrStatus.IdtStatus()
                            self.idt_status.parent = self
                            self._children_name_map["idt_status"] = "idt-status"
                        return self.idt_status

                    if (child_yang_name == "previ-ous-idt-status"):
                        if (self.previ_ous_idt_status is None):
                            self.previ_ous_idt_status = L2Vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus()
                            self.previ_ous_idt_status.parent = self
                            self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        return self.previ_ous_idt_status

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "role"):
                        self.role = value
                        self.role.value_namespace = name_space
                        self.role.value_namespace_prefix = name_space_prefix


            class IssuStatus(Entity):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Nsr.IssuStatus, self).__init__()

                    self.yang_name = "issu-status"
                    self.yang_parent_name = "nsr"

                    self.role = YLeaf(YType.enumeration, "role")

                    self.idt_status = L2Vpnv2.Standby.Nsr.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"
                    self._children_yang_names.add("idt-status")

                    self.previ_ous_idt_status = L2Vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._children_yang_names.add("previ-ous-idt-status")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("role") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Nsr.IssuStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Nsr.IssuStatus, self).__setattr__(name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Nsr.IssuStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "issu-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Nsr.IssuStatus.IdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Nsr.IssuStatus.IdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/issu-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "issu-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "previ-ous-idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/issu-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.role.is_set or
                        (self.idt_status is not None and self.idt_status.has_data()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.role.yfilter != YFilter.not_set or
                        (self.idt_status is not None and self.idt_status.has_operation()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "issu-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "idt-status"):
                        if (self.idt_status is None):
                            self.idt_status = L2Vpnv2.Standby.Nsr.IssuStatus.IdtStatus()
                            self.idt_status.parent = self
                            self._children_name_map["idt_status"] = "idt-status"
                        return self.idt_status

                    if (child_yang_name == "previ-ous-idt-status"):
                        if (self.previ_ous_idt_status is None):
                            self.previ_ous_idt_status = L2Vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus()
                            self.previ_ous_idt_status.parent = self
                            self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        return self.previ_ous_idt_status

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "role"):
                        self.role = value
                        self.role.value_namespace = name_space
                        self.role.value_namespace_prefix = name_space_prefix


            class XidInfo(Entity):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Nsr.XidInfo, self).__init__()

                    self.yang_name = "xid-info"
                    self.yang_parent_name = "nsr"

                    self.app_type = YLeaf(YType.enumeration, "app-type")

                    self.sent_ids = YLeaf(YType.uint32, "sent-ids")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("app_type",
                                    "sent_ids") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Nsr.XidInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Nsr.XidInfo, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.app_type.is_set or
                        self.sent_ids.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.app_type.yfilter != YFilter.not_set or
                        self.sent_ids.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xid-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.app_type.is_set or self.app_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.app_type.get_name_leafdata())
                    if (self.sent_ids.is_set or self.sent_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sent_ids.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "app-type" or name == "sent-ids"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "app-type"):
                        self.app_type = value
                        self.app_type.value_namespace = name_space
                        self.app_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "sent-ids"):
                        self.sent_ids = value
                        self.sent_ids.value_namespace = name_space
                        self.sent_ids.value_namespace_prefix = name_space_prefix


            class ReportCard(Entity):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\:  bool
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\:  bool
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\:  bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Nsr.ReportCard, self).__init__()

                    self.yang_name = "report-card"
                    self.yang_parent_name = "nsr"

                    self.collaborator_idt_done = YLeaf(YType.boolean, "collaborator-idt-done")

                    self.collaborator_is_connected = YLeaf(YType.boolean, "collaborator-is-connected")

                    self.collaborator_skipped = YLeaf(YType.boolean, "collaborator-skipped")

                    self.connection_change_time = YLeaf(YType.uint32, "connection-change-time")

                    self.idt_time = YLeaf(YType.uint32, "idt-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("collaborator_idt_done",
                                    "collaborator_is_connected",
                                    "collaborator_skipped",
                                    "connection_change_time",
                                    "idt_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Nsr.ReportCard, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Nsr.ReportCard, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.collaborator_idt_done.is_set or
                        self.collaborator_is_connected.is_set or
                        self.collaborator_skipped.is_set or
                        self.connection_change_time.is_set or
                        self.idt_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.collaborator_idt_done.yfilter != YFilter.not_set or
                        self.collaborator_is_connected.yfilter != YFilter.not_set or
                        self.collaborator_skipped.yfilter != YFilter.not_set or
                        self.connection_change_time.yfilter != YFilter.not_set or
                        self.idt_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "report-card" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.collaborator_idt_done.is_set or self.collaborator_idt_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_idt_done.get_name_leafdata())
                    if (self.collaborator_is_connected.is_set or self.collaborator_is_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_is_connected.get_name_leafdata())
                    if (self.collaborator_skipped.is_set or self.collaborator_skipped.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_skipped.get_name_leafdata())
                    if (self.connection_change_time.is_set or self.connection_change_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.connection_change_time.get_name_leafdata())
                    if (self.idt_time.is_set or self.idt_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "collaborator-idt-done" or name == "collaborator-is-connected" or name == "collaborator-skipped" or name == "connection-change-time" or name == "idt-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "collaborator-idt-done"):
                        self.collaborator_idt_done = value
                        self.collaborator_idt_done.value_namespace = name_space
                        self.collaborator_idt_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "collaborator-is-connected"):
                        self.collaborator_is_connected = value
                        self.collaborator_is_connected.value_namespace = name_space
                        self.collaborator_is_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "collaborator-skipped"):
                        self.collaborator_skipped = value
                        self.collaborator_skipped.value_namespace = name_space
                        self.collaborator_skipped.value_namespace_prefix = name_space_prefix
                    if(value_path == "connection-change-time"):
                        self.connection_change_time = value
                        self.connection_change_time.value_namespace = name_space
                        self.connection_change_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-time"):
                        self.idt_time = value
                        self.idt_time.value_namespace = name_space
                        self.idt_time.value_namespace_prefix = name_space_prefix


            class EventHistory(Entity):
                """
                L2VPN Process event history
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: new_state
                
                	New state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: process_event
                
                	Process event
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Nsr.EventHistory, self).__init__()

                    self.yang_name = "event-history"
                    self.yang_parent_name = "nsr"

                    self.event_timestamp = YLeaf(YType.uint32, "event-timestamp")

                    self.new_state = YLeaf(YType.uint8, "new-state")

                    self.previous_state = YLeaf(YType.uint8, "previous-state")

                    self.process_collaborator = YLeaf(YType.uint16, "process-collaborator")

                    self.process_event = YLeaf(YType.uint16, "process-event")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("event_timestamp",
                                    "new_state",
                                    "previous_state",
                                    "process_collaborator",
                                    "process_event") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Nsr.EventHistory, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Nsr.EventHistory, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.event_timestamp.is_set or
                        self.new_state.is_set or
                        self.previous_state.is_set or
                        self.process_collaborator.is_set or
                        self.process_event.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.event_timestamp.yfilter != YFilter.not_set or
                        self.new_state.yfilter != YFilter.not_set or
                        self.previous_state.yfilter != YFilter.not_set or
                        self.process_collaborator.yfilter != YFilter.not_set or
                        self.process_event.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "event-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.event_timestamp.is_set or self.event_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.event_timestamp.get_name_leafdata())
                    if (self.new_state.is_set or self.new_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.new_state.get_name_leafdata())
                    if (self.previous_state.is_set or self.previous_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.previous_state.get_name_leafdata())
                    if (self.process_collaborator.is_set or self.process_collaborator.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_collaborator.get_name_leafdata())
                    if (self.process_event.is_set or self.process_event.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_event.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "event-timestamp" or name == "new-state" or name == "previous-state" or name == "process-collaborator" or name == "process-event"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "event-timestamp"):
                        self.event_timestamp = value
                        self.event_timestamp.value_namespace = name_space
                        self.event_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "new-state"):
                        self.new_state = value
                        self.new_state.value_namespace = name_space
                        self.new_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "previous-state"):
                        self.previous_state = value
                        self.previous_state.value_namespace = name_space
                        self.previous_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-collaborator"):
                        self.process_collaborator = value
                        self.process_collaborator.value_namespace = name_space
                        self.process_collaborator.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-event"):
                        self.process_event = value
                        self.process_event.value_namespace = name_space
                        self.process_event.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.event_history:
                    if (c.has_data()):
                        return True
                for c in self.report_card:
                    if (c.has_data()):
                        return True
                for c in self.xid_info:
                    if (c.has_data()):
                        return True
                for leaf in self.state_transition_time.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                return (
                    self.process_role.is_set or
                    self.process_state.is_set or
                    self.sw_install_in_progress.is_set or
                    self.sync_flags.is_set or
                    (self.failover_status is not None and self.failover_status.has_data()) or
                    (self.issu_status is not None and self.issu_status.has_data()) or
                    (self.nsr_status is not None and self.nsr_status.has_data()))

            def has_operation(self):
                for c in self.event_history:
                    if (c.has_operation()):
                        return True
                for c in self.report_card:
                    if (c.has_operation()):
                        return True
                for c in self.xid_info:
                    if (c.has_operation()):
                        return True
                for leaf in self.state_transition_time.getYLeafs():
                    if (leaf.is_set):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.process_role.yfilter != YFilter.not_set or
                    self.process_state.yfilter != YFilter.not_set or
                    self.state_transition_time.yfilter != YFilter.not_set or
                    self.sw_install_in_progress.yfilter != YFilter.not_set or
                    self.sync_flags.yfilter != YFilter.not_set or
                    (self.failover_status is not None and self.failover_status.has_operation()) or
                    (self.issu_status is not None and self.issu_status.has_operation()) or
                    (self.nsr_status is not None and self.nsr_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "nsr" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.process_role.is_set or self.process_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_role.get_name_leafdata())
                if (self.process_state.is_set or self.process_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_state.get_name_leafdata())
                if (self.sw_install_in_progress.is_set or self.sw_install_in_progress.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sw_install_in_progress.get_name_leafdata())
                if (self.sync_flags.is_set or self.sync_flags.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sync_flags.get_name_leafdata())

                leaf_name_data.extend(self.state_transition_time.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "event-history"):
                    for c in self.event_history:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.Nsr.EventHistory()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.event_history.append(c)
                    return c

                if (child_yang_name == "failover-status"):
                    if (self.failover_status is None):
                        self.failover_status = L2Vpnv2.Standby.Nsr.FailoverStatus()
                        self.failover_status.parent = self
                        self._children_name_map["failover_status"] = "failover-status"
                    return self.failover_status

                if (child_yang_name == "issu-status"):
                    if (self.issu_status is None):
                        self.issu_status = L2Vpnv2.Standby.Nsr.IssuStatus()
                        self.issu_status.parent = self
                        self._children_name_map["issu_status"] = "issu-status"
                    return self.issu_status

                if (child_yang_name == "nsr-status"):
                    if (self.nsr_status is None):
                        self.nsr_status = L2Vpnv2.Standby.Nsr.NsrStatus()
                        self.nsr_status.parent = self
                        self._children_name_map["nsr_status"] = "nsr-status"
                    return self.nsr_status

                if (child_yang_name == "report-card"):
                    for c in self.report_card:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.Nsr.ReportCard()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.report_card.append(c)
                    return c

                if (child_yang_name == "xid-info"):
                    for c in self.xid_info:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.Nsr.XidInfo()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xid_info.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "event-history" or name == "failover-status" or name == "issu-status" or name == "nsr-status" or name == "report-card" or name == "xid-info" or name == "process-role" or name == "process-state" or name == "state-transition-time" or name == "sw-install-in-progress" or name == "sync-flags"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "process-role"):
                    self.process_role = value
                    self.process_role.value_namespace = name_space
                    self.process_role.value_namespace_prefix = name_space_prefix
                if(value_path == "process-state"):
                    self.process_state = value
                    self.process_state.value_namespace = name_space
                    self.process_state.value_namespace_prefix = name_space_prefix
                if(value_path == "state-transition-time"):
                    self.state_transition_time.append(value)
                if(value_path == "sw-install-in-progress"):
                    self.sw_install_in_progress = value
                    self.sw_install_in_progress.value_namespace = name_space
                    self.sw_install_in_progress.value_namespace_prefix = name_space_prefix
                if(value_path == "sync-flags"):
                    self.sync_flags = value
                    self.sync_flags.value_namespace = name_space
                    self.sync_flags.value_namespace_prefix = name_space_prefix


        class GlobalSettings(Entity):
            """
            L2VPN global settings
            
            .. attribute:: going_active
            
            	transitioning to Active functional role
            	**type**\:  bool
            
            .. attribute:: ha_role
            
            	Node redundancy role
            	**type**\:  str
            
            .. attribute:: issu_role
            
            	Node ISSU role
            	**type**\:  str
            
            .. attribute:: logging_bd_enabled
            
            	Logging BD state changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_df_election_enabled
            
            	Logging EVPN Designated Forwarder changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_nsr_enabled
            
            	Logging NSR state changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_pw_enabled
            
            	Logging PW enabled
            	**type**\:  bool
            
            .. attribute:: logging_vfi_enabled
            
            	Logging VFI state changes enabled
            	**type**\:  bool
            
            .. attribute:: process_fsm
            
            	Current L2VPN FSM role
            	**type**\:  str
            
            .. attribute:: pw_grouping_enabled
            
            	PW Grouping enabled
            	**type**\:  bool
            
            .. attribute:: pw_oam_refresh_transmit_time
            
            	PW OAM refresh transmit (seconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: pw_status_enabled
            
            	PW Status enabled
            	**type**\:  bool
            
            .. attribute:: tcn_propagation_enabled
            
            	TCN propagation enabled
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.GlobalSettings, self).__init__()

                self.yang_name = "global-settings"
                self.yang_parent_name = "standby"

                self.going_active = YLeaf(YType.boolean, "going-active")

                self.ha_role = YLeaf(YType.str, "ha-role")

                self.issu_role = YLeaf(YType.str, "issu-role")

                self.logging_bd_enabled = YLeaf(YType.boolean, "logging-bd-enabled")

                self.logging_df_election_enabled = YLeaf(YType.boolean, "logging-df-election-enabled")

                self.logging_nsr_enabled = YLeaf(YType.boolean, "logging-nsr-enabled")

                self.logging_pw_enabled = YLeaf(YType.boolean, "logging-pw-enabled")

                self.logging_vfi_enabled = YLeaf(YType.boolean, "logging-vfi-enabled")

                self.process_fsm = YLeaf(YType.str, "process-fsm")

                self.pw_grouping_enabled = YLeaf(YType.boolean, "pw-grouping-enabled")

                self.pw_oam_refresh_transmit_time = YLeaf(YType.uint32, "pw-oam-refresh-transmit-time")

                self.pw_status_enabled = YLeaf(YType.boolean, "pw-status-enabled")

                self.tcn_propagation_enabled = YLeaf(YType.boolean, "tcn-propagation-enabled")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("going_active",
                                "ha_role",
                                "issu_role",
                                "logging_bd_enabled",
                                "logging_df_election_enabled",
                                "logging_nsr_enabled",
                                "logging_pw_enabled",
                                "logging_vfi_enabled",
                                "process_fsm",
                                "pw_grouping_enabled",
                                "pw_oam_refresh_transmit_time",
                                "pw_status_enabled",
                                "tcn_propagation_enabled") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.GlobalSettings, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.GlobalSettings, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.going_active.is_set or
                    self.ha_role.is_set or
                    self.issu_role.is_set or
                    self.logging_bd_enabled.is_set or
                    self.logging_df_election_enabled.is_set or
                    self.logging_nsr_enabled.is_set or
                    self.logging_pw_enabled.is_set or
                    self.logging_vfi_enabled.is_set or
                    self.process_fsm.is_set or
                    self.pw_grouping_enabled.is_set or
                    self.pw_oam_refresh_transmit_time.is_set or
                    self.pw_status_enabled.is_set or
                    self.tcn_propagation_enabled.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.going_active.yfilter != YFilter.not_set or
                    self.ha_role.yfilter != YFilter.not_set or
                    self.issu_role.yfilter != YFilter.not_set or
                    self.logging_bd_enabled.yfilter != YFilter.not_set or
                    self.logging_df_election_enabled.yfilter != YFilter.not_set or
                    self.logging_nsr_enabled.yfilter != YFilter.not_set or
                    self.logging_pw_enabled.yfilter != YFilter.not_set or
                    self.logging_vfi_enabled.yfilter != YFilter.not_set or
                    self.process_fsm.yfilter != YFilter.not_set or
                    self.pw_grouping_enabled.yfilter != YFilter.not_set or
                    self.pw_oam_refresh_transmit_time.yfilter != YFilter.not_set or
                    self.pw_status_enabled.yfilter != YFilter.not_set or
                    self.tcn_propagation_enabled.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "global-settings" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.going_active.is_set or self.going_active.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.going_active.get_name_leafdata())
                if (self.ha_role.is_set or self.ha_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ha_role.get_name_leafdata())
                if (self.issu_role.is_set or self.issu_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.issu_role.get_name_leafdata())
                if (self.logging_bd_enabled.is_set or self.logging_bd_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.logging_bd_enabled.get_name_leafdata())
                if (self.logging_df_election_enabled.is_set or self.logging_df_election_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.logging_df_election_enabled.get_name_leafdata())
                if (self.logging_nsr_enabled.is_set or self.logging_nsr_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.logging_nsr_enabled.get_name_leafdata())
                if (self.logging_pw_enabled.is_set or self.logging_pw_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.logging_pw_enabled.get_name_leafdata())
                if (self.logging_vfi_enabled.is_set or self.logging_vfi_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.logging_vfi_enabled.get_name_leafdata())
                if (self.process_fsm.is_set or self.process_fsm.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_fsm.get_name_leafdata())
                if (self.pw_grouping_enabled.is_set or self.pw_grouping_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pw_grouping_enabled.get_name_leafdata())
                if (self.pw_oam_refresh_transmit_time.is_set or self.pw_oam_refresh_transmit_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pw_oam_refresh_transmit_time.get_name_leafdata())
                if (self.pw_status_enabled.is_set or self.pw_status_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pw_status_enabled.get_name_leafdata())
                if (self.tcn_propagation_enabled.is_set or self.tcn_propagation_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.tcn_propagation_enabled.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "going-active" or name == "ha-role" or name == "issu-role" or name == "logging-bd-enabled" or name == "logging-df-election-enabled" or name == "logging-nsr-enabled" or name == "logging-pw-enabled" or name == "logging-vfi-enabled" or name == "process-fsm" or name == "pw-grouping-enabled" or name == "pw-oam-refresh-transmit-time" or name == "pw-status-enabled" or name == "tcn-propagation-enabled"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "going-active"):
                    self.going_active = value
                    self.going_active.value_namespace = name_space
                    self.going_active.value_namespace_prefix = name_space_prefix
                if(value_path == "ha-role"):
                    self.ha_role = value
                    self.ha_role.value_namespace = name_space
                    self.ha_role.value_namespace_prefix = name_space_prefix
                if(value_path == "issu-role"):
                    self.issu_role = value
                    self.issu_role.value_namespace = name_space
                    self.issu_role.value_namespace_prefix = name_space_prefix
                if(value_path == "logging-bd-enabled"):
                    self.logging_bd_enabled = value
                    self.logging_bd_enabled.value_namespace = name_space
                    self.logging_bd_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "logging-df-election-enabled"):
                    self.logging_df_election_enabled = value
                    self.logging_df_election_enabled.value_namespace = name_space
                    self.logging_df_election_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "logging-nsr-enabled"):
                    self.logging_nsr_enabled = value
                    self.logging_nsr_enabled.value_namespace = name_space
                    self.logging_nsr_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "logging-pw-enabled"):
                    self.logging_pw_enabled = value
                    self.logging_pw_enabled.value_namespace = name_space
                    self.logging_pw_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "logging-vfi-enabled"):
                    self.logging_vfi_enabled = value
                    self.logging_vfi_enabled.value_namespace = name_space
                    self.logging_vfi_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "process-fsm"):
                    self.process_fsm = value
                    self.process_fsm.value_namespace = name_space
                    self.process_fsm.value_namespace_prefix = name_space_prefix
                if(value_path == "pw-grouping-enabled"):
                    self.pw_grouping_enabled = value
                    self.pw_grouping_enabled.value_namespace = name_space
                    self.pw_grouping_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "pw-oam-refresh-transmit-time"):
                    self.pw_oam_refresh_transmit_time = value
                    self.pw_oam_refresh_transmit_time.value_namespace = name_space
                    self.pw_oam_refresh_transmit_time.value_namespace_prefix = name_space_prefix
                if(value_path == "pw-status-enabled"):
                    self.pw_status_enabled = value
                    self.pw_status_enabled.value_namespace = name_space
                    self.pw_status_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "tcn-propagation-enabled"):
                    self.tcn_propagation_enabled = value
                    self.tcn_propagation_enabled.value_namespace = name_space
                    self.tcn_propagation_enabled.value_namespace_prefix = name_space_prefix


        class Pwr(Entity):
            """
            Pseudowire Routing Table
            
            .. attribute:: summary
            
            	L2VPN Pseudowire Routing Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.Pwr, self).__init__()

                self.yang_name = "pwr"
                self.yang_parent_name = "standby"

                self.summary = L2Vpnv2.Standby.Pwr.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")


            class Summary(Entity):
                """
                L2VPN Pseudowire Routing Summary
                
                .. attribute:: bgp_as
                
                	BGP AS number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_router_id
                
                	BGP Router ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: cfg_global_id
                
                	Configured Global ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: cfg_router_id
                
                	Configured Router ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: l2vpn_has_bgp_eod
                
                	L2VPN got BGP EOD
                	**type**\:  bool
                
                .. attribute:: rd_auto
                
                	Automatic Route Distingtuisher
                	**type**\:   :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdAuto>`
                
                .. attribute:: rd_configured
                
                	Configured Route Distinguisher
                	**type**\:   :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdConfigured>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Pwr.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "pwr"

                    self.bgp_as = YLeaf(YType.uint32, "bgp-as")

                    self.bgp_router_id = YLeaf(YType.str, "bgp-router-id")

                    self.cfg_global_id = YLeaf(YType.uint32, "cfg-global-id")

                    self.cfg_router_id = YLeaf(YType.str, "cfg-router-id")

                    self.l2vpn_has_bgp_eod = YLeaf(YType.boolean, "l2vpn-has-bgp-eod")

                    self.rd_auto = L2Vpnv2.Standby.Pwr.Summary.RdAuto()
                    self.rd_auto.parent = self
                    self._children_name_map["rd_auto"] = "rd-auto"
                    self._children_yang_names.add("rd-auto")

                    self.rd_configured = L2Vpnv2.Standby.Pwr.Summary.RdConfigured()
                    self.rd_configured.parent = self
                    self._children_name_map["rd_configured"] = "rd-configured"
                    self._children_yang_names.add("rd-configured")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bgp_as",
                                    "bgp_router_id",
                                    "cfg_global_id",
                                    "cfg_router_id",
                                    "l2vpn_has_bgp_eod") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Pwr.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Pwr.Summary, self).__setattr__(name, value)


                class RdAuto(Entity):
                    """
                    Automatic Route Distingtuisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdAuto.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Pwr.Summary.RdAuto, self).__init__()

                        self.yang_name = "rd-auto"
                        self.yang_parent_name = "summary"

                        self.rd = YLeaf(YType.enumeration, "rd")

                        self.auto = L2Vpnv2.Standby.Pwr.Summary.RdAuto.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"
                        self._children_yang_names.add("auto")

                        self.four_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"
                        self._children_yang_names.add("four-byte-as")

                        self.two_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"
                        self._children_yang_names.add("two-byte-as")

                        self.v4_addr = L2Vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._children_yang_names.add("v4-addr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("rd") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Pwr.Summary.RdAuto, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Pwr.Summary.RdAuto, self).__setattr__(name, value)


                    class Auto(Entity):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "rd-auto"

                            self.auto_index = YLeaf(YType.uint16, "auto-index")

                            self.router_id = YLeaf(YType.str, "router-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("auto_index",
                                            "router_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.Auto, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.Auto, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.auto_index.is_set or
                                self.router_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.auto_index.yfilter != YFilter.not_set or
                                self.router_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "auto" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-auto/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_index.get_name_leafdata())
                            if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto-index" or name == "router-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "auto-index"):
                                self.auto_index = value
                                self.auto_index.value_namespace = name_space
                                self.auto_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-id"):
                                self.router_id = value
                                self.router_id.value_namespace = name_space
                                self.router_id.value_namespace_prefix = name_space_prefix


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "rd-auto"

                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_index",
                                            "two_byte_as") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_index.is_set or
                                self.two_byte_as.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_index.yfilter != YFilter.not_set or
                                self.two_byte_as.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "two-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-auto/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-index" or name == "two-byte-as"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-index"):
                                self.four_byte_index = value
                                self.four_byte_index.value_namespace = name_space
                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-as"):
                                self.two_byte_as = value
                                self.two_byte_as.value_namespace = name_space
                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "rd-auto"

                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_as",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_as.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_as.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "four-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-auto/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-as" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-as"):
                                self.four_byte_as = value
                                self.four_byte_as.value_namespace = name_space
                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "rd-auto"

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ipv4_address",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ipv4_address.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "v4-addr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-auto/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4-address" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.rd.is_set or
                            (self.auto is not None and self.auto.has_data()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                            (self.v4_addr is not None and self.v4_addr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.rd.yfilter != YFilter.not_set or
                            (self.auto is not None and self.auto.has_operation()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rd-auto" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rd.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "auto"):
                            if (self.auto is None):
                                self.auto = L2Vpnv2.Standby.Pwr.Summary.RdAuto.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                            return self.auto

                        if (child_yang_name == "four-byte-as"):
                            if (self.four_byte_as is None):
                                self.four_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                            return self.four_byte_as

                        if (child_yang_name == "two-byte-as"):
                            if (self.two_byte_as is None):
                                self.two_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                            return self.two_byte_as

                        if (child_yang_name == "v4-addr"):
                            if (self.v4_addr is None):
                                self.v4_addr = L2Vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                            return self.v4_addr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "rd"):
                            self.rd = value
                            self.rd.value_namespace = name_space
                            self.rd.value_namespace_prefix = name_space_prefix


                class RdConfigured(Entity):
                    """
                    Configured Route Distinguisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdConfigured.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured, self).__init__()

                        self.yang_name = "rd-configured"
                        self.yang_parent_name = "summary"

                        self.rd = YLeaf(YType.enumeration, "rd")

                        self.auto = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"
                        self._children_yang_names.add("auto")

                        self.four_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"
                        self._children_yang_names.add("four-byte-as")

                        self.two_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"
                        self._children_yang_names.add("two-byte-as")

                        self.v4_addr = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._children_yang_names.add("v4-addr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("rd") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured, self).__setattr__(name, value)


                    class Auto(Entity):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "rd-configured"

                            self.auto_index = YLeaf(YType.uint16, "auto-index")

                            self.router_id = YLeaf(YType.str, "router-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("auto_index",
                                            "router_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.Auto, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.Auto, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.auto_index.is_set or
                                self.router_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.auto_index.yfilter != YFilter.not_set or
                                self.router_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "auto" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-configured/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_index.get_name_leafdata())
                            if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto-index" or name == "router-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "auto-index"):
                                self.auto_index = value
                                self.auto_index.value_namespace = name_space
                                self.auto_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-id"):
                                self.router_id = value
                                self.router_id.value_namespace = name_space
                                self.router_id.value_namespace_prefix = name_space_prefix


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "rd-configured"

                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_index",
                                            "two_byte_as") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_index.is_set or
                                self.two_byte_as.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_index.yfilter != YFilter.not_set or
                                self.two_byte_as.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "two-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-configured/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-index" or name == "two-byte-as"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-index"):
                                self.four_byte_index = value
                                self.four_byte_index.value_namespace = name_space
                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-as"):
                                self.two_byte_as = value
                                self.two_byte_as.value_namespace = name_space
                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "rd-configured"

                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_as",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_as.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_as.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "four-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-configured/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-as" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-as"):
                                self.four_byte_as = value
                                self.four_byte_as.value_namespace = name_space
                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "rd-configured"

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ipv4_address",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ipv4_address.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "v4-addr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-configured/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4-address" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.rd.is_set or
                            (self.auto is not None and self.auto.has_data()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                            (self.v4_addr is not None and self.v4_addr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.rd.yfilter != YFilter.not_set or
                            (self.auto is not None and self.auto.has_operation()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rd-configured" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rd.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "auto"):
                            if (self.auto is None):
                                self.auto = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                            return self.auto

                        if (child_yang_name == "four-byte-as"):
                            if (self.four_byte_as is None):
                                self.four_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                            return self.four_byte_as

                        if (child_yang_name == "two-byte-as"):
                            if (self.two_byte_as is None):
                                self.two_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                            return self.two_byte_as

                        if (child_yang_name == "v4-addr"):
                            if (self.v4_addr is None):
                                self.v4_addr = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                            return self.v4_addr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "rd"):
                            self.rd = value
                            self.rd.value_namespace = name_space
                            self.rd.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bgp_as.is_set or
                        self.bgp_router_id.is_set or
                        self.cfg_global_id.is_set or
                        self.cfg_router_id.is_set or
                        self.l2vpn_has_bgp_eod.is_set or
                        (self.rd_auto is not None and self.rd_auto.has_data()) or
                        (self.rd_configured is not None and self.rd_configured.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bgp_as.yfilter != YFilter.not_set or
                        self.bgp_router_id.yfilter != YFilter.not_set or
                        self.cfg_global_id.yfilter != YFilter.not_set or
                        self.cfg_router_id.yfilter != YFilter.not_set or
                        self.l2vpn_has_bgp_eod.yfilter != YFilter.not_set or
                        (self.rd_auto is not None and self.rd_auto.has_operation()) or
                        (self.rd_configured is not None and self.rd_configured.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bgp_as.is_set or self.bgp_as.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_as.get_name_leafdata())
                    if (self.bgp_router_id.is_set or self.bgp_router_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_router_id.get_name_leafdata())
                    if (self.cfg_global_id.is_set or self.cfg_global_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cfg_global_id.get_name_leafdata())
                    if (self.cfg_router_id.is_set or self.cfg_router_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cfg_router_id.get_name_leafdata())
                    if (self.l2vpn_has_bgp_eod.is_set or self.l2vpn_has_bgp_eod.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.l2vpn_has_bgp_eod.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rd-auto"):
                        if (self.rd_auto is None):
                            self.rd_auto = L2Vpnv2.Standby.Pwr.Summary.RdAuto()
                            self.rd_auto.parent = self
                            self._children_name_map["rd_auto"] = "rd-auto"
                        return self.rd_auto

                    if (child_yang_name == "rd-configured"):
                        if (self.rd_configured is None):
                            self.rd_configured = L2Vpnv2.Standby.Pwr.Summary.RdConfigured()
                            self.rd_configured.parent = self
                            self._children_name_map["rd_configured"] = "rd-configured"
                        return self.rd_configured

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rd-auto" or name == "rd-configured" or name == "bgp-as" or name == "bgp-router-id" or name == "cfg-global-id" or name == "cfg-router-id" or name == "l2vpn-has-bgp-eod"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bgp-as"):
                        self.bgp_as = value
                        self.bgp_as.value_namespace = name_space
                        self.bgp_as.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-router-id"):
                        self.bgp_router_id = value
                        self.bgp_router_id.value_namespace = name_space
                        self.bgp_router_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "cfg-global-id"):
                        self.cfg_global_id = value
                        self.cfg_global_id.value_namespace = name_space
                        self.cfg_global_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "cfg-router-id"):
                        self.cfg_router_id = value
                        self.cfg_router_id.value_namespace = name_space
                        self.cfg_router_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "l2vpn-has-bgp-eod"):
                        self.l2vpn_has_bgp_eod = value
                        self.l2vpn_has_bgp_eod.value_namespace = name_space
                        self.l2vpn_has_bgp_eod.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.summary is not None and self.summary.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.summary is not None and self.summary.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "pwr" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = L2Vpnv2.Standby.Pwr.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "summary"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class XconnectMp2MpCe2Ces(Entity):
            """
            XConnect MP2MP CE2CE Table
            
            .. attribute:: xconnect_mp2mp_ce2ce
            
            	XConnect MP2MP CE2CE information
            	**type**\: list of    :py:class:`XconnectMp2MpCe2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.XconnectMp2MpCe2Ces, self).__init__()

                self.yang_name = "xconnect-mp2mp-ce2ces"
                self.yang_parent_name = "standby"

                self.xconnect_mp2mp_ce2ce = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.XconnectMp2MpCe2Ces, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.XconnectMp2MpCe2Ces, self).__setattr__(name, value)


            class XconnectMp2MpCe2Ce(Entity):
                """
                XConnect MP2MP CE2CE information
                
                .. attribute:: ce_added
                
                	CE2CE Advertised
                	**type**\:  bool
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: local_ceid
                
                	Local CE ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: local_customer_edge_id
                
                	Local CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\:  str
                
                	**length:** 1..26
                
                .. attribute:: remote_ceid
                
                	Remote CE ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: remote_customer_edge_id
                
                	Remote CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__init__()

                    self.yang_name = "xconnect-mp2mp-ce2ce"
                    self.yang_parent_name = "xconnect-mp2mp-ce2ces"

                    self.ce_added = YLeaf(YType.boolean, "ce-added")

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                    self.local_customer_edge_id = YLeaf(YType.uint16, "local-customer-edge-id")

                    self.mp2_mp_name = YLeaf(YType.str, "mp2-mp-name")

                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                    self.remote_customer_edge_id = YLeaf(YType.uint16, "remote-customer-edge-id")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ce_added",
                                    "group_name",
                                    "local_ceid",
                                    "local_customer_edge_id",
                                    "mp2_mp_name",
                                    "remote_ceid",
                                    "remote_customer_edge_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ce_added.is_set or
                        self.group_name.is_set or
                        self.local_ceid.is_set or
                        self.local_customer_edge_id.is_set or
                        self.mp2_mp_name.is_set or
                        self.remote_ceid.is_set or
                        self.remote_customer_edge_id.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ce_added.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.local_ceid.yfilter != YFilter.not_set or
                        self.local_customer_edge_id.yfilter != YFilter.not_set or
                        self.mp2_mp_name.yfilter != YFilter.not_set or
                        self.remote_ceid.yfilter != YFilter.not_set or
                        self.remote_customer_edge_id.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-mp2mp-ce2ce" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mp-ce2ces/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ce_added.is_set or self.ce_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ce_added.get_name_leafdata())
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                    if (self.local_customer_edge_id.is_set or self.local_customer_edge_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_customer_edge_id.get_name_leafdata())
                    if (self.mp2_mp_name.is_set or self.mp2_mp_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mp2_mp_name.get_name_leafdata())
                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                    if (self.remote_customer_edge_id.is_set or self.remote_customer_edge_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote_customer_edge_id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ce-added" or name == "group-name" or name == "local-ceid" or name == "local-customer-edge-id" or name == "mp2-mp-name" or name == "remote-ceid" or name == "remote-customer-edge-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ce-added"):
                        self.ce_added = value
                        self.ce_added.value_namespace = name_space
                        self.ce_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-ceid"):
                        self.local_ceid = value
                        self.local_ceid.value_namespace = name_space
                        self.local_ceid.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-customer-edge-id"):
                        self.local_customer_edge_id = value
                        self.local_customer_edge_id.value_namespace = name_space
                        self.local_customer_edge_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "mp2-mp-name"):
                        self.mp2_mp_name = value
                        self.mp2_mp_name.value_namespace = name_space
                        self.mp2_mp_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote-ceid"):
                        self.remote_ceid = value
                        self.remote_ceid.value_namespace = name_space
                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote-customer-edge-id"):
                        self.remote_customer_edge_id = value
                        self.remote_customer_edge_id.value_namespace = name_space
                        self.remote_customer_edge_id.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.xconnect_mp2mp_ce2ce:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.xconnect_mp2mp_ce2ce:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-mp2mp-ce2ces" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "xconnect-mp2mp-ce2ce"):
                    for c in self.xconnect_mp2mp_ce2ce:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xconnect_mp2mp_ce2ce.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "xconnect-mp2mp-ce2ce"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Xconnects(Entity):
            """
            XConnect Table
            
            .. attribute:: xconnect
            
            	XConnect information
            	**type**\: list of    :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.Xconnects, self).__init__()

                self.yang_name = "xconnects"
                self.yang_parent_name = "standby"

                self.xconnect = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.Xconnects, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.Xconnects, self).__setattr__(name, value)


            class Xconnect(Entity):
                """
                XConnect information
                
                .. attribute:: backup
                
                	LCR backup
                	**type**\:   :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup>`
                
                .. attribute:: backup_segment
                
                	Backup Segment
                	**type**\: list of    :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment>`
                
                .. attribute:: ce2ce
                
                	CE2CE
                	**type**\:   :py:class:`Ce2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Ce2Ce>`
                
                .. attribute:: description
                
                	P2P Description
                	**type**\:  str
                
                .. attribute:: diag_mask
                
                	Mask indicating what if anything is missing before the XC can be provisioned
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: interworking
                
                	Interworking type
                	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                
                .. attribute:: is_mp2mp
                
                	xconnect is mp2mp
                	**type**\:  bool
                
                .. attribute:: number_of_backup_p_ws
                
                	Number of backups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: segment1
                
                	Segment 1
                	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1>`
                
                .. attribute:: segment2
                
                	Segment 2
                	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2>`
                
                .. attribute:: state
                
                	State of the xconnect
                	**type**\:   :py:class:`L2VpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcState>`
                
                .. attribute:: xconnect_name
                
                	XConnect Name
                	**type**\:  str
                
                	**length:** 1..38
                
                .. attribute:: xconnect_name_xr
                
                	XConnect name
                	**type**\:  str
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Xconnects.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "xconnects"

                    self.description = YLeaf(YType.str, "description")

                    self.diag_mask = YLeaf(YType.uint32, "diag-mask")

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                    self.interworking = YLeaf(YType.enumeration, "interworking")

                    self.is_mp2mp = YLeaf(YType.boolean, "is-mp2mp")

                    self.number_of_backup_p_ws = YLeaf(YType.uint32, "number-of-backup-p-ws")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.xconnect_name = YLeaf(YType.str, "xconnect-name")

                    self.xconnect_name_xr = YLeaf(YType.str, "xconnect-name-xr")

                    self.backup = L2Vpnv2.Standby.Xconnects.Xconnect.Backup()
                    self.backup.parent = self
                    self._children_name_map["backup"] = "backup"
                    self._children_yang_names.add("backup")

                    self.ce2ce = L2Vpnv2.Standby.Xconnects.Xconnect.Ce2Ce()
                    self.ce2ce.parent = self
                    self._children_name_map["ce2ce"] = "ce2ce"
                    self._children_yang_names.add("ce2ce")

                    self.segment1 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1()
                    self.segment1.parent = self
                    self._children_name_map["segment1"] = "segment1"
                    self._children_yang_names.add("segment1")

                    self.segment2 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2()
                    self.segment2.parent = self
                    self._children_name_map["segment2"] = "segment2"
                    self._children_yang_names.add("segment2")

                    self.backup_segment = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("description",
                                    "diag_mask",
                                    "group_name",
                                    "group_name_xr",
                                    "interworking",
                                    "is_mp2mp",
                                    "number_of_backup_p_ws",
                                    "state",
                                    "xconnect_name",
                                    "xconnect_name_xr") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Xconnects.Xconnect, self).__setattr__(name, value)


                class Backup(Entity):
                    """
                    LCR backup
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup, self).__init__()

                        self.yang_name = "backup"
                        self.yang_parent_name = "xconnect"

                        self.segment_type = YLeaf(YType.enumeration, "segment-type")

                        self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        self._children_yang_names.add("attachment-circuit")

                        self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._children_yang_names.add("pseudo-wire")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("segment_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup, self).__setattr__(name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "backup"

                            self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                            self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                            self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                            self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                            self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                            self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                            self.msti = YLeaf(YType.str, "msti")

                            self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                            self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")

                            self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._children_yang_names.add("l2vpn-protection")

                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_mac_conflict",
                                            "bvi_no_port_up",
                                            "control_word_mismatched",
                                            "encapsulation_error",
                                            "encapsulation_mismatched",
                                            "evpn_internal_label",
                                            "interface_handle",
                                            "internal_ms_ti",
                                            "interworking",
                                            "is_ac_partially_programmed",
                                            "mac_limit_oper_down",
                                            "ms_ti_mismatch",
                                            "msti",
                                            "msti_mismatch_down",
                                            "mtu_mismatched",
                                            "node_id",
                                            "out_of_memory_state",
                                            "redundancy_group_id",
                                            "redundancy_group_state",
                                            "redundancy_object_id",
                                            "state",
                                            "tdm_media_mismatched",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"

                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2VpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"

                                self.active = YLeaf(YType.boolean, "active")

                                self.protected_name = YLeaf(YType.str, "protected-name")

                                self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                self.protection_name = YLeaf(YType.str, "protection-name")

                                self.protection_type = YLeaf(YType.enumeration, "protection-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active",
                                                "protected_name",
                                                "protection_configured",
                                                "protection_name",
                                                "protection_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.active.is_set or
                                    self.protected_name.is_set or
                                    self.protection_configured.is_set or
                                    self.protection_name.is_set or
                                    self.protection_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.protected_name.yfilter != YFilter.not_set or
                                    self.protection_configured.yfilter != YFilter.not_set or
                                    self.protection_name.yfilter != YFilter.not_set or
                                    self.protection_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2vpn-protection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_name.get_name_leafdata())
                                if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_name.get_name_leafdata())
                                if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-name"):
                                    self.protected_name = value
                                    self.protected_name.value_namespace = name_space
                                    self.protected_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-configured"):
                                    self.protection_configured = value
                                    self.protection_configured.value_namespace = name_space
                                    self.protection_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-name"):
                                    self.protection_name = value
                                    self.protection_name.value_namespace = name_space
                                    self.protection_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-type"):
                                    self.protection_type = value
                                    self.protection_type.value_namespace = name_space
                                    self.protection_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bvi_mac_conflict.is_set or
                                self.bvi_no_port_up.is_set or
                                self.control_word_mismatched.is_set or
                                self.encapsulation_error.is_set or
                                self.encapsulation_mismatched.is_set or
                                self.evpn_internal_label.is_set or
                                self.interface_handle.is_set or
                                self.internal_ms_ti.is_set or
                                self.interworking.is_set or
                                self.is_ac_partially_programmed.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.ms_ti_mismatch.is_set or
                                self.msti.is_set or
                                self.msti_mismatch_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.node_id.is_set or
                                self.out_of_memory_state.is_set or
                                self.redundancy_group_id.is_set or
                                self.redundancy_group_state.is_set or
                                self.redundancy_object_id.is_set or
                                self.state.is_set or
                                self.tdm_media_mismatched.is_set or
                                self.xconnect_id.is_set or
                                (self.interface is not None and self.interface.has_data()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                self.bvi_no_port_up.yfilter != YFilter.not_set or
                                self.control_word_mismatched.yfilter != YFilter.not_set or
                                self.encapsulation_error.yfilter != YFilter.not_set or
                                self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                self.evpn_internal_label.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.internal_ms_ti.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                self.msti.yfilter != YFilter.not_set or
                                self.msti_mismatch_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.redundancy_group_id.yfilter != YFilter.not_set or
                                self.redundancy_group_state.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.interface is not None and self.interface.has_operation()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment-circuit" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                            if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                            if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                            if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                            if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                            if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                            if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti.get_name_leafdata())
                            if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                            if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                if (self.interface is None):
                                    self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                return self.interface

                            if (child_yang_name == "l2vpn-protection"):
                                if (self.l2vpn_protection is None):
                                    self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                return self.l2vpn_protection

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-mac-conflict"):
                                self.bvi_mac_conflict = value
                                self.bvi_mac_conflict.value_namespace = name_space
                                self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-no-port-up"):
                                self.bvi_no_port_up = value
                                self.bvi_no_port_up.value_namespace = name_space
                                self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-word-mismatched"):
                                self.control_word_mismatched = value
                                self.control_word_mismatched.value_namespace = name_space
                                self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-error"):
                                self.encapsulation_error = value
                                self.encapsulation_error.value_namespace = name_space
                                self.encapsulation_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-mismatched"):
                                self.encapsulation_mismatched = value
                                self.encapsulation_mismatched.value_namespace = name_space
                                self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-internal-label"):
                                self.evpn_internal_label = value
                                self.evpn_internal_label.value_namespace = name_space
                                self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-ms-ti"):
                                self.internal_ms_ti = value
                                self.internal_ms_ti.value_namespace = name_space
                                self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ac-partially-programmed"):
                                self.is_ac_partially_programmed = value
                                self.is_ac_partially_programmed.value_namespace = name_space
                                self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ms-ti-mismatch"):
                                self.ms_ti_mismatch = value
                                self.ms_ti_mismatch.value_namespace = name_space
                                self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti"):
                                self.msti = value
                                self.msti.value_namespace = name_space
                                self.msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-mismatch-down"):
                                self.msti_mismatch_down = value
                                self.msti_mismatch_down.value_namespace = name_space
                                self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-id"):
                                self.redundancy_group_id = value
                                self.redundancy_group_id.value_namespace = name_space
                                self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-state"):
                                self.redundancy_group_state = value
                                self.redundancy_group_state.value_namespace = name_space
                                self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "tdm-media-mismatched"):
                                self.tdm_media_mismatched = value
                                self.tdm_media_mismatched.value_namespace = name_space
                                self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "backup"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"

                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudo-wire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.segment_type.is_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.segment_type.yfilter != YFilter.not_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "backup" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment-circuit"):
                            if (self.attachment_circuit is None):
                                self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            return self.attachment_circuit

                        if (child_yang_name == "pseudo-wire"):
                            if (self.pseudo_wire is None):
                                self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire()
                                self.pseudo_wire.parent = self
                                self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            return self.pseudo_wire

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "segment-type"):
                            self.segment_type = value
                            self.segment_type.value_namespace = name_space
                            self.segment_type.value_namespace_prefix = name_space_prefix


                class Segment1(Entity):
                    """
                    Segment 1
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1, self).__init__()

                        self.yang_name = "segment1"
                        self.yang_parent_name = "xconnect"

                        self.segment_type = YLeaf(YType.enumeration, "segment-type")

                        self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        self._children_yang_names.add("attachment-circuit")

                        self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._children_yang_names.add("pseudo-wire")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("segment_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1, self).__setattr__(name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "segment1"

                            self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                            self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                            self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                            self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                            self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                            self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                            self.msti = YLeaf(YType.str, "msti")

                            self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                            self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")

                            self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._children_yang_names.add("l2vpn-protection")

                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_mac_conflict",
                                            "bvi_no_port_up",
                                            "control_word_mismatched",
                                            "encapsulation_error",
                                            "encapsulation_mismatched",
                                            "evpn_internal_label",
                                            "interface_handle",
                                            "internal_ms_ti",
                                            "interworking",
                                            "is_ac_partially_programmed",
                                            "mac_limit_oper_down",
                                            "ms_ti_mismatch",
                                            "msti",
                                            "msti_mismatch_down",
                                            "mtu_mismatched",
                                            "node_id",
                                            "out_of_memory_state",
                                            "redundancy_group_id",
                                            "redundancy_group_state",
                                            "redundancy_object_id",
                                            "state",
                                            "tdm_media_mismatched",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"

                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2VpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"

                                self.active = YLeaf(YType.boolean, "active")

                                self.protected_name = YLeaf(YType.str, "protected-name")

                                self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                self.protection_name = YLeaf(YType.str, "protection-name")

                                self.protection_type = YLeaf(YType.enumeration, "protection-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active",
                                                "protected_name",
                                                "protection_configured",
                                                "protection_name",
                                                "protection_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.active.is_set or
                                    self.protected_name.is_set or
                                    self.protection_configured.is_set or
                                    self.protection_name.is_set or
                                    self.protection_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.protected_name.yfilter != YFilter.not_set or
                                    self.protection_configured.yfilter != YFilter.not_set or
                                    self.protection_name.yfilter != YFilter.not_set or
                                    self.protection_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2vpn-protection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_name.get_name_leafdata())
                                if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_name.get_name_leafdata())
                                if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-name"):
                                    self.protected_name = value
                                    self.protected_name.value_namespace = name_space
                                    self.protected_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-configured"):
                                    self.protection_configured = value
                                    self.protection_configured.value_namespace = name_space
                                    self.protection_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-name"):
                                    self.protection_name = value
                                    self.protection_name.value_namespace = name_space
                                    self.protection_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-type"):
                                    self.protection_type = value
                                    self.protection_type.value_namespace = name_space
                                    self.protection_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bvi_mac_conflict.is_set or
                                self.bvi_no_port_up.is_set or
                                self.control_word_mismatched.is_set or
                                self.encapsulation_error.is_set or
                                self.encapsulation_mismatched.is_set or
                                self.evpn_internal_label.is_set or
                                self.interface_handle.is_set or
                                self.internal_ms_ti.is_set or
                                self.interworking.is_set or
                                self.is_ac_partially_programmed.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.ms_ti_mismatch.is_set or
                                self.msti.is_set or
                                self.msti_mismatch_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.node_id.is_set or
                                self.out_of_memory_state.is_set or
                                self.redundancy_group_id.is_set or
                                self.redundancy_group_state.is_set or
                                self.redundancy_object_id.is_set or
                                self.state.is_set or
                                self.tdm_media_mismatched.is_set or
                                self.xconnect_id.is_set or
                                (self.interface is not None and self.interface.has_data()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                self.bvi_no_port_up.yfilter != YFilter.not_set or
                                self.control_word_mismatched.yfilter != YFilter.not_set or
                                self.encapsulation_error.yfilter != YFilter.not_set or
                                self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                self.evpn_internal_label.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.internal_ms_ti.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                self.msti.yfilter != YFilter.not_set or
                                self.msti_mismatch_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.redundancy_group_id.yfilter != YFilter.not_set or
                                self.redundancy_group_state.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.interface is not None and self.interface.has_operation()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment-circuit" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                            if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                            if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                            if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                            if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                            if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                            if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti.get_name_leafdata())
                            if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                            if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                if (self.interface is None):
                                    self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                return self.interface

                            if (child_yang_name == "l2vpn-protection"):
                                if (self.l2vpn_protection is None):
                                    self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                return self.l2vpn_protection

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-mac-conflict"):
                                self.bvi_mac_conflict = value
                                self.bvi_mac_conflict.value_namespace = name_space
                                self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-no-port-up"):
                                self.bvi_no_port_up = value
                                self.bvi_no_port_up.value_namespace = name_space
                                self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-word-mismatched"):
                                self.control_word_mismatched = value
                                self.control_word_mismatched.value_namespace = name_space
                                self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-error"):
                                self.encapsulation_error = value
                                self.encapsulation_error.value_namespace = name_space
                                self.encapsulation_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-mismatched"):
                                self.encapsulation_mismatched = value
                                self.encapsulation_mismatched.value_namespace = name_space
                                self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-internal-label"):
                                self.evpn_internal_label = value
                                self.evpn_internal_label.value_namespace = name_space
                                self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-ms-ti"):
                                self.internal_ms_ti = value
                                self.internal_ms_ti.value_namespace = name_space
                                self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ac-partially-programmed"):
                                self.is_ac_partially_programmed = value
                                self.is_ac_partially_programmed.value_namespace = name_space
                                self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ms-ti-mismatch"):
                                self.ms_ti_mismatch = value
                                self.ms_ti_mismatch.value_namespace = name_space
                                self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti"):
                                self.msti = value
                                self.msti.value_namespace = name_space
                                self.msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-mismatch-down"):
                                self.msti_mismatch_down = value
                                self.msti_mismatch_down.value_namespace = name_space
                                self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-id"):
                                self.redundancy_group_id = value
                                self.redundancy_group_id.value_namespace = name_space
                                self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-state"):
                                self.redundancy_group_state = value
                                self.redundancy_group_state.value_namespace = name_space
                                self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "tdm-media-mismatched"):
                                self.tdm_media_mismatched = value
                                self.tdm_media_mismatched.value_namespace = name_space
                                self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "segment1"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"

                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudo-wire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.segment_type.is_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.segment_type.yfilter != YFilter.not_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "segment1" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment-circuit"):
                            if (self.attachment_circuit is None):
                                self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            return self.attachment_circuit

                        if (child_yang_name == "pseudo-wire"):
                            if (self.pseudo_wire is None):
                                self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire()
                                self.pseudo_wire.parent = self
                                self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            return self.pseudo_wire

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "segment-type"):
                            self.segment_type = value
                            self.segment_type.value_namespace = name_space
                            self.segment_type.value_namespace_prefix = name_space_prefix


                class Segment2(Entity):
                    """
                    Segment 2
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2, self).__init__()

                        self.yang_name = "segment2"
                        self.yang_parent_name = "xconnect"

                        self.segment_type = YLeaf(YType.enumeration, "segment-type")

                        self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        self._children_yang_names.add("attachment-circuit")

                        self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._children_yang_names.add("pseudo-wire")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("segment_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2, self).__setattr__(name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "segment2"

                            self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                            self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                            self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                            self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                            self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                            self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                            self.msti = YLeaf(YType.str, "msti")

                            self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                            self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")

                            self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._children_yang_names.add("l2vpn-protection")

                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_mac_conflict",
                                            "bvi_no_port_up",
                                            "control_word_mismatched",
                                            "encapsulation_error",
                                            "encapsulation_mismatched",
                                            "evpn_internal_label",
                                            "interface_handle",
                                            "internal_ms_ti",
                                            "interworking",
                                            "is_ac_partially_programmed",
                                            "mac_limit_oper_down",
                                            "ms_ti_mismatch",
                                            "msti",
                                            "msti_mismatch_down",
                                            "mtu_mismatched",
                                            "node_id",
                                            "out_of_memory_state",
                                            "redundancy_group_id",
                                            "redundancy_group_state",
                                            "redundancy_object_id",
                                            "state",
                                            "tdm_media_mismatched",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"

                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2VpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"

                                self.active = YLeaf(YType.boolean, "active")

                                self.protected_name = YLeaf(YType.str, "protected-name")

                                self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                self.protection_name = YLeaf(YType.str, "protection-name")

                                self.protection_type = YLeaf(YType.enumeration, "protection-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active",
                                                "protected_name",
                                                "protection_configured",
                                                "protection_name",
                                                "protection_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.active.is_set or
                                    self.protected_name.is_set or
                                    self.protection_configured.is_set or
                                    self.protection_name.is_set or
                                    self.protection_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.protected_name.yfilter != YFilter.not_set or
                                    self.protection_configured.yfilter != YFilter.not_set or
                                    self.protection_name.yfilter != YFilter.not_set or
                                    self.protection_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2vpn-protection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_name.get_name_leafdata())
                                if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_name.get_name_leafdata())
                                if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-name"):
                                    self.protected_name = value
                                    self.protected_name.value_namespace = name_space
                                    self.protected_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-configured"):
                                    self.protection_configured = value
                                    self.protection_configured.value_namespace = name_space
                                    self.protection_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-name"):
                                    self.protection_name = value
                                    self.protection_name.value_namespace = name_space
                                    self.protection_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-type"):
                                    self.protection_type = value
                                    self.protection_type.value_namespace = name_space
                                    self.protection_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bvi_mac_conflict.is_set or
                                self.bvi_no_port_up.is_set or
                                self.control_word_mismatched.is_set or
                                self.encapsulation_error.is_set or
                                self.encapsulation_mismatched.is_set or
                                self.evpn_internal_label.is_set or
                                self.interface_handle.is_set or
                                self.internal_ms_ti.is_set or
                                self.interworking.is_set or
                                self.is_ac_partially_programmed.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.ms_ti_mismatch.is_set or
                                self.msti.is_set or
                                self.msti_mismatch_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.node_id.is_set or
                                self.out_of_memory_state.is_set or
                                self.redundancy_group_id.is_set or
                                self.redundancy_group_state.is_set or
                                self.redundancy_object_id.is_set or
                                self.state.is_set or
                                self.tdm_media_mismatched.is_set or
                                self.xconnect_id.is_set or
                                (self.interface is not None and self.interface.has_data()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                self.bvi_no_port_up.yfilter != YFilter.not_set or
                                self.control_word_mismatched.yfilter != YFilter.not_set or
                                self.encapsulation_error.yfilter != YFilter.not_set or
                                self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                self.evpn_internal_label.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.internal_ms_ti.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                self.msti.yfilter != YFilter.not_set or
                                self.msti_mismatch_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.redundancy_group_id.yfilter != YFilter.not_set or
                                self.redundancy_group_state.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.interface is not None and self.interface.has_operation()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment-circuit" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                            if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                            if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                            if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                            if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                            if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                            if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti.get_name_leafdata())
                            if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                            if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                if (self.interface is None):
                                    self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                return self.interface

                            if (child_yang_name == "l2vpn-protection"):
                                if (self.l2vpn_protection is None):
                                    self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                return self.l2vpn_protection

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-mac-conflict"):
                                self.bvi_mac_conflict = value
                                self.bvi_mac_conflict.value_namespace = name_space
                                self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-no-port-up"):
                                self.bvi_no_port_up = value
                                self.bvi_no_port_up.value_namespace = name_space
                                self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-word-mismatched"):
                                self.control_word_mismatched = value
                                self.control_word_mismatched.value_namespace = name_space
                                self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-error"):
                                self.encapsulation_error = value
                                self.encapsulation_error.value_namespace = name_space
                                self.encapsulation_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-mismatched"):
                                self.encapsulation_mismatched = value
                                self.encapsulation_mismatched.value_namespace = name_space
                                self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-internal-label"):
                                self.evpn_internal_label = value
                                self.evpn_internal_label.value_namespace = name_space
                                self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-ms-ti"):
                                self.internal_ms_ti = value
                                self.internal_ms_ti.value_namespace = name_space
                                self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ac-partially-programmed"):
                                self.is_ac_partially_programmed = value
                                self.is_ac_partially_programmed.value_namespace = name_space
                                self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ms-ti-mismatch"):
                                self.ms_ti_mismatch = value
                                self.ms_ti_mismatch.value_namespace = name_space
                                self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti"):
                                self.msti = value
                                self.msti.value_namespace = name_space
                                self.msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-mismatch-down"):
                                self.msti_mismatch_down = value
                                self.msti_mismatch_down.value_namespace = name_space
                                self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-id"):
                                self.redundancy_group_id = value
                                self.redundancy_group_id.value_namespace = name_space
                                self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-state"):
                                self.redundancy_group_state = value
                                self.redundancy_group_state.value_namespace = name_space
                                self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "tdm-media-mismatched"):
                                self.tdm_media_mismatched = value
                                self.tdm_media_mismatched.value_namespace = name_space
                                self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "segment2"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"

                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudo-wire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.segment_type.is_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.segment_type.yfilter != YFilter.not_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "segment2" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment-circuit"):
                            if (self.attachment_circuit is None):
                                self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            return self.attachment_circuit

                        if (child_yang_name == "pseudo-wire"):
                            if (self.pseudo_wire is None):
                                self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire()
                                self.pseudo_wire.parent = self
                                self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            return self.pseudo_wire

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "segment-type"):
                            self.segment_type = value
                            self.segment_type.value_namespace = name_space
                            self.segment_type.value_namespace_prefix = name_space_prefix


                class Ce2Ce(Entity):
                    """
                    CE2CE
                    
                    .. attribute:: ce_added
                    
                    	CE2CE Advertised
                    	**type**\:  bool
                    
                    .. attribute:: local_customer_edge_id
                    
                    	Local CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: remote_customer_edge_id
                    
                    	Remote CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Xconnects.Xconnect.Ce2Ce, self).__init__()

                        self.yang_name = "ce2ce"
                        self.yang_parent_name = "xconnect"

                        self.ce_added = YLeaf(YType.boolean, "ce-added")

                        self.local_customer_edge_id = YLeaf(YType.uint16, "local-customer-edge-id")

                        self.remote_customer_edge_id = YLeaf(YType.uint16, "remote-customer-edge-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ce_added",
                                        "local_customer_edge_id",
                                        "remote_customer_edge_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.Ce2Ce, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.Ce2Ce, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ce_added.is_set or
                            self.local_customer_edge_id.is_set or
                            self.remote_customer_edge_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ce_added.yfilter != YFilter.not_set or
                            self.local_customer_edge_id.yfilter != YFilter.not_set or
                            self.remote_customer_edge_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ce2ce" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ce_added.is_set or self.ce_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ce_added.get_name_leafdata())
                        if (self.local_customer_edge_id.is_set or self.local_customer_edge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_customer_edge_id.get_name_leafdata())
                        if (self.remote_customer_edge_id.is_set or self.remote_customer_edge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_customer_edge_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ce-added" or name == "local-customer-edge-id" or name == "remote-customer-edge-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ce-added"):
                            self.ce_added = value
                            self.ce_added.value_namespace = name_space
                            self.ce_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-customer-edge-id"):
                            self.local_customer_edge_id = value
                            self.local_customer_edge_id.value_namespace = name_space
                            self.local_customer_edge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-customer-edge-id"):
                            self.remote_customer_edge_id = value
                            self.remote_customer_edge_id.value_namespace = name_space
                            self.remote_customer_edge_id.value_namespace_prefix = name_space_prefix


                class BackupSegment(Entity):
                    """
                    Backup Segment
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment, self).__init__()

                        self.yang_name = "backup-segment"
                        self.yang_parent_name = "xconnect"

                        self.segment_type = YLeaf(YType.enumeration, "segment-type")

                        self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        self._children_yang_names.add("attachment-circuit")

                        self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._children_yang_names.add("pseudo-wire")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("segment_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment, self).__setattr__(name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "backup-segment"

                            self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                            self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                            self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                            self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                            self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                            self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                            self.msti = YLeaf(YType.str, "msti")

                            self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                            self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")

                            self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._children_yang_names.add("l2vpn-protection")

                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_mac_conflict",
                                            "bvi_no_port_up",
                                            "control_word_mismatched",
                                            "encapsulation_error",
                                            "encapsulation_mismatched",
                                            "evpn_internal_label",
                                            "interface_handle",
                                            "internal_ms_ti",
                                            "interworking",
                                            "is_ac_partially_programmed",
                                            "mac_limit_oper_down",
                                            "ms_ti_mismatch",
                                            "msti",
                                            "msti_mismatch_down",
                                            "mtu_mismatched",
                                            "node_id",
                                            "out_of_memory_state",
                                            "redundancy_group_id",
                                            "redundancy_group_state",
                                            "redundancy_object_id",
                                            "state",
                                            "tdm_media_mismatched",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"

                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2VpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"

                                self.active = YLeaf(YType.boolean, "active")

                                self.protected_name = YLeaf(YType.str, "protected-name")

                                self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                self.protection_name = YLeaf(YType.str, "protection-name")

                                self.protection_type = YLeaf(YType.enumeration, "protection-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active",
                                                "protected_name",
                                                "protection_configured",
                                                "protection_name",
                                                "protection_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.active.is_set or
                                    self.protected_name.is_set or
                                    self.protection_configured.is_set or
                                    self.protection_name.is_set or
                                    self.protection_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.protected_name.yfilter != YFilter.not_set or
                                    self.protection_configured.yfilter != YFilter.not_set or
                                    self.protection_name.yfilter != YFilter.not_set or
                                    self.protection_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2vpn-protection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_name.get_name_leafdata())
                                if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_name.get_name_leafdata())
                                if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-name"):
                                    self.protected_name = value
                                    self.protected_name.value_namespace = name_space
                                    self.protected_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-configured"):
                                    self.protection_configured = value
                                    self.protection_configured.value_namespace = name_space
                                    self.protection_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-name"):
                                    self.protection_name = value
                                    self.protection_name.value_namespace = name_space
                                    self.protection_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-type"):
                                    self.protection_type = value
                                    self.protection_type.value_namespace = name_space
                                    self.protection_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bvi_mac_conflict.is_set or
                                self.bvi_no_port_up.is_set or
                                self.control_word_mismatched.is_set or
                                self.encapsulation_error.is_set or
                                self.encapsulation_mismatched.is_set or
                                self.evpn_internal_label.is_set or
                                self.interface_handle.is_set or
                                self.internal_ms_ti.is_set or
                                self.interworking.is_set or
                                self.is_ac_partially_programmed.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.ms_ti_mismatch.is_set or
                                self.msti.is_set or
                                self.msti_mismatch_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.node_id.is_set or
                                self.out_of_memory_state.is_set or
                                self.redundancy_group_id.is_set or
                                self.redundancy_group_state.is_set or
                                self.redundancy_object_id.is_set or
                                self.state.is_set or
                                self.tdm_media_mismatched.is_set or
                                self.xconnect_id.is_set or
                                (self.interface is not None and self.interface.has_data()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                self.bvi_no_port_up.yfilter != YFilter.not_set or
                                self.control_word_mismatched.yfilter != YFilter.not_set or
                                self.encapsulation_error.yfilter != YFilter.not_set or
                                self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                self.evpn_internal_label.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.internal_ms_ti.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                self.msti.yfilter != YFilter.not_set or
                                self.msti_mismatch_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.redundancy_group_id.yfilter != YFilter.not_set or
                                self.redundancy_group_state.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.interface is not None and self.interface.has_operation()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment-circuit" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                            if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                            if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                            if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                            if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                            if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                            if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti.get_name_leafdata())
                            if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                            if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                if (self.interface is None):
                                    self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                return self.interface

                            if (child_yang_name == "l2vpn-protection"):
                                if (self.l2vpn_protection is None):
                                    self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                return self.l2vpn_protection

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-mac-conflict"):
                                self.bvi_mac_conflict = value
                                self.bvi_mac_conflict.value_namespace = name_space
                                self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-no-port-up"):
                                self.bvi_no_port_up = value
                                self.bvi_no_port_up.value_namespace = name_space
                                self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-word-mismatched"):
                                self.control_word_mismatched = value
                                self.control_word_mismatched.value_namespace = name_space
                                self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-error"):
                                self.encapsulation_error = value
                                self.encapsulation_error.value_namespace = name_space
                                self.encapsulation_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-mismatched"):
                                self.encapsulation_mismatched = value
                                self.encapsulation_mismatched.value_namespace = name_space
                                self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-internal-label"):
                                self.evpn_internal_label = value
                                self.evpn_internal_label.value_namespace = name_space
                                self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-ms-ti"):
                                self.internal_ms_ti = value
                                self.internal_ms_ti.value_namespace = name_space
                                self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ac-partially-programmed"):
                                self.is_ac_partially_programmed = value
                                self.is_ac_partially_programmed.value_namespace = name_space
                                self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ms-ti-mismatch"):
                                self.ms_ti_mismatch = value
                                self.ms_ti_mismatch.value_namespace = name_space
                                self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti"):
                                self.msti = value
                                self.msti.value_namespace = name_space
                                self.msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-mismatch-down"):
                                self.msti_mismatch_down = value
                                self.msti_mismatch_down.value_namespace = name_space
                                self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-id"):
                                self.redundancy_group_id = value
                                self.redundancy_group_id.value_namespace = name_space
                                self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-state"):
                                self.redundancy_group_state = value
                                self.redundancy_group_state.value_namespace = name_space
                                self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "tdm-media-mismatched"):
                                self.tdm_media_mismatched = value
                                self.tdm_media_mismatched.value_namespace = name_space
                                self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "backup-segment"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"

                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudo-wire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.segment_type.is_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.segment_type.yfilter != YFilter.not_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "backup-segment" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment-circuit"):
                            if (self.attachment_circuit is None):
                                self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            return self.attachment_circuit

                        if (child_yang_name == "pseudo-wire"):
                            if (self.pseudo_wire is None):
                                self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire()
                                self.pseudo_wire.parent = self
                                self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            return self.pseudo_wire

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "segment-type"):
                            self.segment_type = value
                            self.segment_type.value_namespace = name_space
                            self.segment_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.backup_segment:
                        if (c.has_data()):
                            return True
                    return (
                        self.description.is_set or
                        self.diag_mask.is_set or
                        self.group_name.is_set or
                        self.group_name_xr.is_set or
                        self.interworking.is_set or
                        self.is_mp2mp.is_set or
                        self.number_of_backup_p_ws.is_set or
                        self.state.is_set or
                        self.xconnect_name.is_set or
                        self.xconnect_name_xr.is_set or
                        (self.backup is not None and self.backup.has_data()) or
                        (self.ce2ce is not None and self.ce2ce.has_data()) or
                        (self.segment1 is not None and self.segment1.has_data()) or
                        (self.segment2 is not None and self.segment2.has_data()))

                def has_operation(self):
                    for c in self.backup_segment:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.description.yfilter != YFilter.not_set or
                        self.diag_mask.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.group_name_xr.yfilter != YFilter.not_set or
                        self.interworking.yfilter != YFilter.not_set or
                        self.is_mp2mp.yfilter != YFilter.not_set or
                        self.number_of_backup_p_ws.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set or
                        self.xconnect_name.yfilter != YFilter.not_set or
                        self.xconnect_name_xr.yfilter != YFilter.not_set or
                        (self.backup is not None and self.backup.has_operation()) or
                        (self.ce2ce is not None and self.ce2ce.has_operation()) or
                        (self.segment1 is not None and self.segment1.has_operation()) or
                        (self.segment2 is not None and self.segment2.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.description.get_name_leafdata())
                    if (self.diag_mask.is_set or self.diag_mask.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.diag_mask.get_name_leafdata())
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                    if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interworking.get_name_leafdata())
                    if (self.is_mp2mp.is_set or self.is_mp2mp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mp2mp.get_name_leafdata())
                    if (self.number_of_backup_p_ws.is_set or self.number_of_backup_p_ws.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_of_backup_p_ws.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())
                    if (self.xconnect_name.is_set or self.xconnect_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.xconnect_name.get_name_leafdata())
                    if (self.xconnect_name_xr.is_set or self.xconnect_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.xconnect_name_xr.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "backup"):
                        if (self.backup is None):
                            self.backup = L2Vpnv2.Standby.Xconnects.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                        return self.backup

                    if (child_yang_name == "backup-segment"):
                        for c in self.backup_segment:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.backup_segment.append(c)
                        return c

                    if (child_yang_name == "ce2ce"):
                        if (self.ce2ce is None):
                            self.ce2ce = L2Vpnv2.Standby.Xconnects.Xconnect.Ce2Ce()
                            self.ce2ce.parent = self
                            self._children_name_map["ce2ce"] = "ce2ce"
                        return self.ce2ce

                    if (child_yang_name == "segment1"):
                        if (self.segment1 is None):
                            self.segment1 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1()
                            self.segment1.parent = self
                            self._children_name_map["segment1"] = "segment1"
                        return self.segment1

                    if (child_yang_name == "segment2"):
                        if (self.segment2 is None):
                            self.segment2 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2()
                            self.segment2.parent = self
                            self._children_name_map["segment2"] = "segment2"
                        return self.segment2

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "backup" or name == "backup-segment" or name == "ce2ce" or name == "segment1" or name == "segment2" or name == "description" or name == "diag-mask" or name == "group-name" or name == "group-name-xr" or name == "interworking" or name == "is-mp2mp" or name == "number-of-backup-p-ws" or name == "state" or name == "xconnect-name" or name == "xconnect-name-xr"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "description"):
                        self.description = value
                        self.description.value_namespace = name_space
                        self.description.value_namespace_prefix = name_space_prefix
                    if(value_path == "diag-mask"):
                        self.diag_mask = value
                        self.diag_mask.value_namespace = name_space
                        self.diag_mask.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name-xr"):
                        self.group_name_xr = value
                        self.group_name_xr.value_namespace = name_space
                        self.group_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "interworking"):
                        self.interworking = value
                        self.interworking.value_namespace = name_space
                        self.interworking.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mp2mp"):
                        self.is_mp2mp = value
                        self.is_mp2mp.value_namespace = name_space
                        self.is_mp2mp.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-of-backup-p-ws"):
                        self.number_of_backup_p_ws = value
                        self.number_of_backup_p_ws.value_namespace = name_space
                        self.number_of_backup_p_ws.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix
                    if(value_path == "xconnect-name"):
                        self.xconnect_name = value
                        self.xconnect_name.value_namespace = name_space
                        self.xconnect_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "xconnect-name-xr"):
                        self.xconnect_name_xr = value
                        self.xconnect_name_xr.value_namespace = name_space
                        self.xconnect_name_xr.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.xconnect:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.xconnect:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnects" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "xconnect"):
                    for c in self.xconnect:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.Xconnects.Xconnect()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xconnect.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "xconnect"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class XconnectGroups(Entity):
            """
            XConnect group Table
            
            .. attribute:: xconnect_group
            
            	XConnect group information
            	**type**\: list of    :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectGroups.XconnectGroup>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.XconnectGroups, self).__init__()

                self.yang_name = "xconnect-groups"
                self.yang_parent_name = "standby"

                self.xconnect_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.XconnectGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.XconnectGroups, self).__setattr__(name, value)


            class XconnectGroup(Entity):
                """
                XConnect group information
                
                .. attribute:: group_name  <key>
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: number_xconnects
                
                	Number of xconnects
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.XconnectGroups.XconnectGroup, self).__init__()

                    self.yang_name = "xconnect-group"
                    self.yang_parent_name = "xconnect-groups"

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                    self.number_xconnects = YLeaf(YType.uint32, "number-xconnects")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_name",
                                    "group_name_xr",
                                    "number_xconnects") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.XconnectGroups.XconnectGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.XconnectGroups.XconnectGroup, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.group_name.is_set or
                        self.group_name_xr.is_set or
                        self.number_xconnects.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.group_name_xr.yfilter != YFilter.not_set or
                        self.number_xconnects.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-group" + "[group-name='" + self.group_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                    if (self.number_xconnects.is_set or self.number_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-name" or name == "group-name-xr" or name == "number-xconnects"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name-xr"):
                        self.group_name_xr = value
                        self.group_name_xr.value_namespace = name_space
                        self.group_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects"):
                        self.number_xconnects = value
                        self.number_xconnects.value_namespace = name_space
                        self.number_xconnects.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.xconnect_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.xconnect_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "xconnect-group"):
                    for c in self.xconnect_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.XconnectGroups.XconnectGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xconnect_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "xconnect-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class XconnectMp2Mps(Entity):
            """
            XConnect MP2MP Table
            
            .. attribute:: xconnect_mp2mp
            
            	XConnect MP2MP information
            	**type**\: list of    :py:class:`XconnectMp2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.XconnectMp2Mps, self).__init__()

                self.yang_name = "xconnect-mp2mps"
                self.yang_parent_name = "standby"

                self.xconnect_mp2mp = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.XconnectMp2Mps, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.XconnectMp2Mps, self).__setattr__(name, value)


            class XconnectMp2Mp(Entity):
                """
                XConnect MP2MP information
                
                .. attribute:: discovery
                
                	l2vpn xc auto discovery info
                	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery>`
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: l2_encapsulation
                
                	L2 Encapsulation
                	**type**\:   :py:class:`L2VpnBagAdEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagAdEncap>`
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\:  str
                
                	**length:** 1..26
                
                .. attribute:: mp2mp_name
                
                	MP2MP name
                	**type**\:  str
                
                .. attribute:: mp2mpid
                
                	Identification Number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_id
                
                	Vpn ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_mtu
                
                	VPN MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: xconnect_shutdown
                
                	Administratively disabled
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp, self).__init__()

                    self.yang_name = "xconnect-mp2mp"
                    self.yang_parent_name = "xconnect-mp2mps"

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                    self.l2_encapsulation = YLeaf(YType.enumeration, "l2-encapsulation")

                    self.mp2_mp_name = YLeaf(YType.str, "mp2-mp-name")

                    self.mp2mp_name = YLeaf(YType.str, "mp2mp-name")

                    self.mp2mpid = YLeaf(YType.uint32, "mp2mpid")

                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                    self.vpn_mtu = YLeaf(YType.uint32, "vpn-mtu")

                    self.xconnect_shutdown = YLeaf(YType.boolean, "xconnect-shutdown")

                    self.discovery = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                    self.discovery.parent = self
                    self._children_name_map["discovery"] = "discovery"
                    self._children_yang_names.add("discovery")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_name",
                                    "group_name_xr",
                                    "l2_encapsulation",
                                    "mp2_mp_name",
                                    "mp2mp_name",
                                    "mp2mpid",
                                    "vpn_id",
                                    "vpn_mtu",
                                    "xconnect_shutdown") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp, self).__setattr__(name, value)


                class Discovery(Entity):
                    """
                    l2vpn xc auto discovery info
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery Method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_service_connected
                    
                    	Service Connected
                    	**type**\:  bool
                    
                    .. attribute:: ad_signalling_method
                    
                    	Signaling Protocol
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ce_range
                    
                    	CE Range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: export_route_policy
                    
                    	Export Route Policy
                    	**type**\:  str
                    
                    .. attribute:: export_rt
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt>`
                    
                    .. attribute:: import_rt
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt>`
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2c_es
                    
                    	Number of ce2ce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2ce_advertised
                    
                    	Number of ce2ce Advertised
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rd_value
                    
                    	Route Distinguisher
                    	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue>`
                    
                    .. attribute:: vpn_added
                    
                    	VPN Added
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__init__()

                        self.yang_name = "discovery"
                        self.yang_parent_name = "xconnect-mp2mp"

                        self.ad_method = YLeaf(YType.uint32, "ad-method")

                        self.ad_service_connected = YLeaf(YType.boolean, "ad-service-connected")

                        self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                        self.ce_range = YLeaf(YType.uint16, "ce-range")

                        self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                        self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                        self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                        self.number_ce2c_es = YLeaf(YType.uint32, "number-ce2c-es")

                        self.number_ce2ce_advertised = YLeaf(YType.uint32, "number-ce2ce-advertised")

                        self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                        self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                        self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                        self.rd_value = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                        self.rd_value.parent = self
                        self._children_name_map["rd_value"] = "rd-value"
                        self._children_yang_names.add("rd-value")

                        self.export_rt = YList(self)
                        self.import_rt = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ad_method",
                                        "ad_service_connected",
                                        "ad_signalling_method",
                                        "ce_range",
                                        "export_route_policy",
                                        "number_a_cs",
                                        "number_a_cs_up",
                                        "number_ce2c_es",
                                        "number_ce2ce_advertised",
                                        "number_p_ws_up",
                                        "number_pseudowires",
                                        "vpn_added") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__setattr__(name, value)


                    class RdValue(Entity):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__init__()

                            self.yang_name = "rd-value"
                            self.yang_parent_name = "discovery"

                            self.rd = YLeaf(YType.enumeration, "rd")

                            self.auto = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"
                            self._children_yang_names.add("auto")

                            self.four_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                            self._children_yang_names.add("four-byte-as")

                            self.two_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rd") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__setattr__(name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd-value"

                                self.auto_index = YLeaf(YType.uint16, "auto-index")

                                self.router_id = YLeaf(YType.str, "router-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("auto_index",
                                                "router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.auto_index.is_set or
                                    self.router_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.auto_index.yfilter != YFilter.not_set or
                                    self.router_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "auto" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_index.get_name_leafdata())
                                if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto-index" or name == "router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "auto-index"):
                                    self.auto_index = value
                                    self.auto_index.value_namespace = name_space
                                    self.auto_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-id"):
                                    self.router_id = value
                                    self.router_id.value_namespace = name_space
                                    self.router_id.value_namespace_prefix = name_space_prefix


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd-value"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd-value"

                                self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_as",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_as.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_as.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "four-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-as" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-as"):
                                    self.four_byte_as = value
                                    self.four_byte_as.value_namespace = name_space
                                    self.four_byte_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd-value"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.rd.is_set or
                                (self.auto is not None and self.auto.has_data()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rd.yfilter != YFilter.not_set or
                                (self.auto is not None and self.auto.has_operation()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rd-value" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rd.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "auto"):
                                if (self.auto is None):
                                    self.auto = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                return self.auto

                            if (child_yang_name == "four-byte-as"):
                                if (self.four_byte_as is None):
                                    self.four_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                return self.four_byte_as

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rd"):
                                self.rd = value
                                self.rd.value_namespace = name_space
                                self.rd.value_namespace_prefix = name_space_prefix


                    class ImportRt(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__init__()

                            self.yang_name = "import-rt"
                            self.yang_parent_name = "discovery"

                            self.rt = YLeaf(YType.enumeration, "rt")

                            self.es_import = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                            self.es_import.parent = self
                            self._children_name_map["es_import"] = "es-import"
                            self._children_yang_names.add("es-import")

                            self.four_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                            self._children_yang_names.add("four-byte-as")

                            self.two_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rt") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__setattr__(name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "import-rt"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "import-rt"

                                self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_as",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_as.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_as.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "four-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-as" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-as"):
                                    self.four_byte_as = value
                                    self.four_byte_as.value_namespace = name_space
                                    self.four_byte_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "import-rt"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class EsImport(Entity):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__init__()

                                self.yang_name = "es-import"
                                self.yang_parent_name = "import-rt"

                                self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("high_bytes",
                                                "low_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.high_bytes.is_set or
                                    self.low_bytes.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.high_bytes.yfilter != YFilter.not_set or
                                    self.low_bytes.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "es-import" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "high-bytes" or name == "low-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "high-bytes"):
                                    self.high_bytes = value
                                    self.high_bytes.value_namespace = name_space
                                    self.high_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "low-bytes"):
                                    self.low_bytes = value
                                    self.low_bytes.value_namespace = name_space
                                    self.low_bytes.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.rt.is_set or
                                (self.es_import is not None and self.es_import.has_data()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rt.yfilter != YFilter.not_set or
                                (self.es_import is not None and self.es_import.has_operation()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "import-rt" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rt.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "es-import"):
                                if (self.es_import is None):
                                    self.es_import = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                return self.es_import

                            if (child_yang_name == "four-byte-as"):
                                if (self.four_byte_as is None):
                                    self.four_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                return self.four_byte_as

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rt"):
                                self.rt = value
                                self.rt.value_namespace = name_space
                                self.rt.value_namespace_prefix = name_space_prefix


                    class ExportRt(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__init__()

                            self.yang_name = "export-rt"
                            self.yang_parent_name = "discovery"

                            self.rt = YLeaf(YType.enumeration, "rt")

                            self.es_import = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                            self.es_import.parent = self
                            self._children_name_map["es_import"] = "es-import"
                            self._children_yang_names.add("es-import")

                            self.four_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                            self._children_yang_names.add("four-byte-as")

                            self.two_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rt") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__setattr__(name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "export-rt"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "export-rt"

                                self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_as",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_as.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_as.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "four-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-as" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-as"):
                                    self.four_byte_as = value
                                    self.four_byte_as.value_namespace = name_space
                                    self.four_byte_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "export-rt"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class EsImport(Entity):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__init__()

                                self.yang_name = "es-import"
                                self.yang_parent_name = "export-rt"

                                self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("high_bytes",
                                                "low_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.high_bytes.is_set or
                                    self.low_bytes.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.high_bytes.yfilter != YFilter.not_set or
                                    self.low_bytes.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "es-import" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "high-bytes" or name == "low-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "high-bytes"):
                                    self.high_bytes = value
                                    self.high_bytes.value_namespace = name_space
                                    self.high_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "low-bytes"):
                                    self.low_bytes = value
                                    self.low_bytes.value_namespace = name_space
                                    self.low_bytes.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.rt.is_set or
                                (self.es_import is not None and self.es_import.has_data()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rt.yfilter != YFilter.not_set or
                                (self.es_import is not None and self.es_import.has_operation()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "export-rt" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rt.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "es-import"):
                                if (self.es_import is None):
                                    self.es_import = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                return self.es_import

                            if (child_yang_name == "four-byte-as"):
                                if (self.four_byte_as is None):
                                    self.four_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                return self.four_byte_as

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rt"):
                                self.rt = value
                                self.rt.value_namespace = name_space
                                self.rt.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.export_rt:
                            if (c.has_data()):
                                return True
                        for c in self.import_rt:
                            if (c.has_data()):
                                return True
                        return (
                            self.ad_method.is_set or
                            self.ad_service_connected.is_set or
                            self.ad_signalling_method.is_set or
                            self.ce_range.is_set or
                            self.export_route_policy.is_set or
                            self.number_a_cs.is_set or
                            self.number_a_cs_up.is_set or
                            self.number_ce2c_es.is_set or
                            self.number_ce2ce_advertised.is_set or
                            self.number_p_ws_up.is_set or
                            self.number_pseudowires.is_set or
                            self.vpn_added.is_set or
                            (self.rd_value is not None and self.rd_value.has_data()))

                    def has_operation(self):
                        for c in self.export_rt:
                            if (c.has_operation()):
                                return True
                        for c in self.import_rt:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ad_method.yfilter != YFilter.not_set or
                            self.ad_service_connected.yfilter != YFilter.not_set or
                            self.ad_signalling_method.yfilter != YFilter.not_set or
                            self.ce_range.yfilter != YFilter.not_set or
                            self.export_route_policy.yfilter != YFilter.not_set or
                            self.number_a_cs.yfilter != YFilter.not_set or
                            self.number_a_cs_up.yfilter != YFilter.not_set or
                            self.number_ce2c_es.yfilter != YFilter.not_set or
                            self.number_ce2ce_advertised.yfilter != YFilter.not_set or
                            self.number_p_ws_up.yfilter != YFilter.not_set or
                            self.number_pseudowires.yfilter != YFilter.not_set or
                            self.vpn_added.yfilter != YFilter.not_set or
                            (self.rd_value is not None and self.rd_value.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "discovery" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_method.get_name_leafdata())
                        if (self.ad_service_connected.is_set or self.ad_service_connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_service_connected.get_name_leafdata())
                        if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                        if (self.ce_range.is_set or self.ce_range.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ce_range.get_name_leafdata())
                        if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                        if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                        if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                        if (self.number_ce2c_es.is_set or self.number_ce2c_es.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_ce2c_es.get_name_leafdata())
                        if (self.number_ce2ce_advertised.is_set or self.number_ce2ce_advertised.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_ce2ce_advertised.get_name_leafdata())
                        if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                        if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                        if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_added.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "export-rt"):
                            for c in self.export_rt:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.export_rt.append(c)
                            return c

                        if (child_yang_name == "import-rt"):
                            for c in self.import_rt:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.import_rt.append(c)
                            return c

                        if (child_yang_name == "rd-value"):
                            if (self.rd_value is None):
                                self.rd_value = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                                self.rd_value.parent = self
                                self._children_name_map["rd_value"] = "rd-value"
                            return self.rd_value

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "ad-method" or name == "ad-service-connected" or name == "ad-signalling-method" or name == "ce-range" or name == "export-route-policy" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-ce2c-es" or name == "number-ce2ce-advertised" or name == "number-p-ws-up" or name == "number-pseudowires" or name == "vpn-added"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ad-method"):
                            self.ad_method = value
                            self.ad_method.value_namespace = name_space
                            self.ad_method.value_namespace_prefix = name_space_prefix
                        if(value_path == "ad-service-connected"):
                            self.ad_service_connected = value
                            self.ad_service_connected.value_namespace = name_space
                            self.ad_service_connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "ad-signalling-method"):
                            self.ad_signalling_method = value
                            self.ad_signalling_method.value_namespace = name_space
                            self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                        if(value_path == "ce-range"):
                            self.ce_range = value
                            self.ce_range.value_namespace = name_space
                            self.ce_range.value_namespace_prefix = name_space_prefix
                        if(value_path == "export-route-policy"):
                            self.export_route_policy = value
                            self.export_route_policy.value_namespace = name_space
                            self.export_route_policy.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-a-cs"):
                            self.number_a_cs = value
                            self.number_a_cs.value_namespace = name_space
                            self.number_a_cs.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-a-cs-up"):
                            self.number_a_cs_up = value
                            self.number_a_cs_up.value_namespace = name_space
                            self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-ce2c-es"):
                            self.number_ce2c_es = value
                            self.number_ce2c_es.value_namespace = name_space
                            self.number_ce2c_es.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-ce2ce-advertised"):
                            self.number_ce2ce_advertised = value
                            self.number_ce2ce_advertised.value_namespace = name_space
                            self.number_ce2ce_advertised.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-p-ws-up"):
                            self.number_p_ws_up = value
                            self.number_p_ws_up.value_namespace = name_space
                            self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-pseudowires"):
                            self.number_pseudowires = value
                            self.number_pseudowires.value_namespace = name_space
                            self.number_pseudowires.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-added"):
                            self.vpn_added = value
                            self.vpn_added.value_namespace = name_space
                            self.vpn_added.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.group_name.is_set or
                        self.group_name_xr.is_set or
                        self.l2_encapsulation.is_set or
                        self.mp2_mp_name.is_set or
                        self.mp2mp_name.is_set or
                        self.mp2mpid.is_set or
                        self.vpn_id.is_set or
                        self.vpn_mtu.is_set or
                        self.xconnect_shutdown.is_set or
                        (self.discovery is not None and self.discovery.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.group_name_xr.yfilter != YFilter.not_set or
                        self.l2_encapsulation.yfilter != YFilter.not_set or
                        self.mp2_mp_name.yfilter != YFilter.not_set or
                        self.mp2mp_name.yfilter != YFilter.not_set or
                        self.mp2mpid.yfilter != YFilter.not_set or
                        self.vpn_id.yfilter != YFilter.not_set or
                        self.vpn_mtu.yfilter != YFilter.not_set or
                        self.xconnect_shutdown.yfilter != YFilter.not_set or
                        (self.discovery is not None and self.discovery.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-mp2mp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                    if (self.l2_encapsulation.is_set or self.l2_encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.l2_encapsulation.get_name_leafdata())
                    if (self.mp2_mp_name.is_set or self.mp2_mp_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mp2_mp_name.get_name_leafdata())
                    if (self.mp2mp_name.is_set or self.mp2mp_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mp2mp_name.get_name_leafdata())
                    if (self.mp2mpid.is_set or self.mp2mpid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mp2mpid.get_name_leafdata())
                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_id.get_name_leafdata())
                    if (self.vpn_mtu.is_set or self.vpn_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_mtu.get_name_leafdata())
                    if (self.xconnect_shutdown.is_set or self.xconnect_shutdown.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.xconnect_shutdown.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "discovery"):
                        if (self.discovery is None):
                            self.discovery = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                            self.discovery.parent = self
                            self._children_name_map["discovery"] = "discovery"
                        return self.discovery

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "discovery" or name == "group-name" or name == "group-name-xr" or name == "l2-encapsulation" or name == "mp2-mp-name" or name == "mp2mp-name" or name == "mp2mpid" or name == "vpn-id" or name == "vpn-mtu" or name == "xconnect-shutdown"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name-xr"):
                        self.group_name_xr = value
                        self.group_name_xr.value_namespace = name_space
                        self.group_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "l2-encapsulation"):
                        self.l2_encapsulation = value
                        self.l2_encapsulation.value_namespace = name_space
                        self.l2_encapsulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mp2-mp-name"):
                        self.mp2_mp_name = value
                        self.mp2_mp_name.value_namespace = name_space
                        self.mp2_mp_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mp2mp-name"):
                        self.mp2mp_name = value
                        self.mp2mp_name.value_namespace = name_space
                        self.mp2mp_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mp2mpid"):
                        self.mp2mpid = value
                        self.mp2mpid.value_namespace = name_space
                        self.mp2mpid.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-id"):
                        self.vpn_id = value
                        self.vpn_id.value_namespace = name_space
                        self.vpn_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-mtu"):
                        self.vpn_mtu = value
                        self.vpn_mtu.value_namespace = name_space
                        self.vpn_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "xconnect-shutdown"):
                        self.xconnect_shutdown = value
                        self.xconnect_shutdown.value_namespace = name_space
                        self.xconnect_shutdown.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.xconnect_mp2mp:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.xconnect_mp2mp:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-mp2mps" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "xconnect-mp2mp"):
                    for c in self.xconnect_mp2mp:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xconnect_mp2mp.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "xconnect-mp2mp"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Indexes(Entity):
            """
            ID Manager Index Table
            
            .. attribute:: index
            
            	ID Manager Index Pool
            	**type**\: list of    :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Indexes.Index>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.Indexes, self).__init__()

                self.yang_name = "indexes"
                self.yang_parent_name = "standby"

                self.index = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.Indexes, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.Indexes, self).__setattr__(name, value)


            class Index(Entity):
                """
                ID Manager Index Pool
                
                .. attribute:: pool_id  <key>
                
                	Pool ID
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                .. attribute:: allocated_ids
                
                	Number of IDs allocated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: application_type
                
                	Application Type
                	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
                
                .. attribute:: max_num_id_mgr
                
                	Maximum number of pool extensions
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_id_mgr_in_use
                
                	ID mgr instances in use
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pool_id_xr
                
                	Pool Id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pool_size
                
                	Pool size
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: zombied_ids
                
                	Number of IDs allocated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Indexes.Index, self).__init__()

                    self.yang_name = "index"
                    self.yang_parent_name = "indexes"

                    self.pool_id = YLeaf(YType.str, "pool-id")

                    self.allocated_ids = YLeaf(YType.uint32, "allocated-ids")

                    self.application_type = YLeaf(YType.enumeration, "application-type")

                    self.max_num_id_mgr = YLeaf(YType.uint32, "max-num-id-mgr")

                    self.num_id_mgr_in_use = YLeaf(YType.uint32, "num-id-mgr-in-use")

                    self.pool_id_xr = YLeaf(YType.uint32, "pool-id-xr")

                    self.pool_size = YLeaf(YType.uint32, "pool-size")

                    self.zombied_ids = YLeaf(YType.uint32, "zombied-ids")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("pool_id",
                                    "allocated_ids",
                                    "application_type",
                                    "max_num_id_mgr",
                                    "num_id_mgr_in_use",
                                    "pool_id_xr",
                                    "pool_size",
                                    "zombied_ids") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Indexes.Index, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Indexes.Index, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.pool_id.is_set or
                        self.allocated_ids.is_set or
                        self.application_type.is_set or
                        self.max_num_id_mgr.is_set or
                        self.num_id_mgr_in_use.is_set or
                        self.pool_id_xr.is_set or
                        self.pool_size.is_set or
                        self.zombied_ids.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.pool_id.yfilter != YFilter.not_set or
                        self.allocated_ids.yfilter != YFilter.not_set or
                        self.application_type.yfilter != YFilter.not_set or
                        self.max_num_id_mgr.yfilter != YFilter.not_set or
                        self.num_id_mgr_in_use.yfilter != YFilter.not_set or
                        self.pool_id_xr.yfilter != YFilter.not_set or
                        self.pool_size.yfilter != YFilter.not_set or
                        self.zombied_ids.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "index" + "[pool-id='" + self.pool_id.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/indexes/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.pool_id.is_set or self.pool_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pool_id.get_name_leafdata())
                    if (self.allocated_ids.is_set or self.allocated_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allocated_ids.get_name_leafdata())
                    if (self.application_type.is_set or self.application_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.application_type.get_name_leafdata())
                    if (self.max_num_id_mgr.is_set or self.max_num_id_mgr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.max_num_id_mgr.get_name_leafdata())
                    if (self.num_id_mgr_in_use.is_set or self.num_id_mgr_in_use.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.num_id_mgr_in_use.get_name_leafdata())
                    if (self.pool_id_xr.is_set or self.pool_id_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pool_id_xr.get_name_leafdata())
                    if (self.pool_size.is_set or self.pool_size.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pool_size.get_name_leafdata())
                    if (self.zombied_ids.is_set or self.zombied_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.zombied_ids.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pool-id" or name == "allocated-ids" or name == "application-type" or name == "max-num-id-mgr" or name == "num-id-mgr-in-use" or name == "pool-id-xr" or name == "pool-size" or name == "zombied-ids"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "pool-id"):
                        self.pool_id = value
                        self.pool_id.value_namespace = name_space
                        self.pool_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "allocated-ids"):
                        self.allocated_ids = value
                        self.allocated_ids.value_namespace = name_space
                        self.allocated_ids.value_namespace_prefix = name_space_prefix
                    if(value_path == "application-type"):
                        self.application_type = value
                        self.application_type.value_namespace = name_space
                        self.application_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "max-num-id-mgr"):
                        self.max_num_id_mgr = value
                        self.max_num_id_mgr.value_namespace = name_space
                        self.max_num_id_mgr.value_namespace_prefix = name_space_prefix
                    if(value_path == "num-id-mgr-in-use"):
                        self.num_id_mgr_in_use = value
                        self.num_id_mgr_in_use.value_namespace = name_space
                        self.num_id_mgr_in_use.value_namespace_prefix = name_space_prefix
                    if(value_path == "pool-id-xr"):
                        self.pool_id_xr = value
                        self.pool_id_xr.value_namespace = name_space
                        self.pool_id_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "pool-size"):
                        self.pool_size = value
                        self.pool_size.value_namespace = name_space
                        self.pool_size.value_namespace_prefix = name_space_prefix
                    if(value_path == "zombied-ids"):
                        self.zombied_ids = value
                        self.zombied_ids.value_namespace = name_space
                        self.zombied_ids.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.index:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.index:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "indexes" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "index"):
                    for c in self.index:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.Indexes.Index()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.index.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "index"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class XconnectSummary(Entity):
            """
            XConnect summary information
            
            .. attribute:: admin_down_backup_interface_xconnects
            
            	Number of XCs with backup interface in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_backup_xconnects
            
            	Number of XCs with backup PW in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_interface_xconnects
            
            	Number of XCs with backup interface in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_xconnects
            
            	Number of XCs with backup PW in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2_ceconnections
            
            	Number of Ce2Ce connections
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_advertized
            
            	Number of CE2CE connections that have been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_not_advertized
            
            	Number of CE2CE connections that have not been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects
            
            	Number of mp2mp xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_advertised
            
            	Number of Mp2mp XCs that have been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_down
            
            	Number of Mp2mp XCs that have ben admined down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_up
            
            	Number of Mp2mp XCs that have been admined up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnectss_not_advertised
            
            	Number of Mp2mp XCs that have not been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects
            
            	Number of xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_administratively_down
            
            	Number of xconnects with segments in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup
            
            	Number of XCs currently using backup PW (UP state)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup_interface
            
            	Number of XCs currently using backup interface (UP state)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_down
            
            	Number of xconnects whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_locally_switched
            
            	Number of locally switched xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
            
            	Number of xconnects of type attachment circuit to pseudowire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
            
            	Number of xconnects of type monitor session to pseudowire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
            
            	Number of xconnects of type PseudoWire To PseudoWire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_unresolved
            
            	Number of xconnects whose state is unresolved
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_up
            
            	Numxber of xconnects whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_interface
            
            	Number of XCs configured with backup interface
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_pw
            
            	Number of XCs configured with backup PW
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_xconnects
            
            	Number of cross\-connects partially programmed
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_interface_xconnects
            
            	Number of XCs with backup interface in standby state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_xconnects
            
            	Number of XCs with backup PW in standby state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_ready_backup_xconnects
            
            	Number of XCs with backup PW in standby ready state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_interface_xconnects
            
            	Number of XCs with backup interface in unresolved state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_xconnects
            
            	Number of XCs with backup PW in unresolved state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.XconnectSummary, self).__init__()

                self.yang_name = "xconnect-summary"
                self.yang_parent_name = "standby"

                self.admin_down_backup_interface_xconnects = YLeaf(YType.uint32, "admin-down-backup-interface-xconnects")

                self.admin_down_backup_xconnects = YLeaf(YType.uint32, "admin-down-backup-xconnects")

                self.down_backup_interface_xconnects = YLeaf(YType.uint32, "down-backup-interface-xconnects")

                self.down_backup_xconnects = YLeaf(YType.uint32, "down-backup-xconnects")

                self.number_ce2_ceconnections = YLeaf(YType.uint32, "number-ce2-ceconnections")

                self.number_ce2ce_advertized = YLeaf(YType.uint32, "number-ce2ce-advertized")

                self.number_ce2ce_not_advertized = YLeaf(YType.uint32, "number-ce2ce-not-advertized")

                self.number_groups = YLeaf(YType.uint32, "number-groups")

                self.number_mp2mp_xconnects = YLeaf(YType.uint32, "number-mp2mp-xconnects")

                self.number_mp2mp_xconnects_advertised = YLeaf(YType.uint32, "number-mp2mp-xconnects-advertised")

                self.number_mp2mp_xconnects_down = YLeaf(YType.uint32, "number-mp2mp-xconnects-down")

                self.number_mp2mp_xconnects_up = YLeaf(YType.uint32, "number-mp2mp-xconnects-up")

                self.number_mp2mp_xconnectss_not_advertised = YLeaf(YType.uint32, "number-mp2mp-xconnectss-not-advertised")

                self.number_xconnects = YLeaf(YType.uint32, "number-xconnects")

                self.number_xconnects_administratively_down = YLeaf(YType.uint32, "number-xconnects-administratively-down")

                self.number_xconnects_currently_using_backup = YLeaf(YType.uint32, "number-xconnects-currently-using-backup")

                self.number_xconnects_currently_using_backup_interface = YLeaf(YType.uint32, "number-xconnects-currently-using-backup-interface")

                self.number_xconnects_down = YLeaf(YType.uint32, "number-xconnects-down")

                self.number_xconnects_locally_switched = YLeaf(YType.uint32, "number-xconnects-locally-switched")

                self.number_xconnects_type_attachment_circuit_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-attachment-circuit-to-pseudo-wire")

                self.number_xconnects_type_monitor_session_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-monitor-session-to-pseudo-wire")

                self.number_xconnects_type_pseudo_wire_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-pseudo-wire-to-pseudo-wire")

                self.number_xconnects_unresolved = YLeaf(YType.uint32, "number-xconnects-unresolved")

                self.number_xconnects_up = YLeaf(YType.uint32, "number-xconnects-up")

                self.number_xconnects_with_backup_interface = YLeaf(YType.uint32, "number-xconnects-with-backup-interface")

                self.number_xconnects_with_backup_pw = YLeaf(YType.uint32, "number-xconnects-with-backup-pw")

                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                self.partially_programmed_xconnects = YLeaf(YType.uint32, "partially-programmed-xconnects")

                self.standby_backup_interface_xconnects = YLeaf(YType.uint32, "standby-backup-interface-xconnects")

                self.standby_backup_xconnects = YLeaf(YType.uint32, "standby-backup-xconnects")

                self.standby_ready_backup_xconnects = YLeaf(YType.uint32, "standby-ready-backup-xconnects")

                self.unresolved_backup_interface_xconnects = YLeaf(YType.uint32, "unresolved-backup-interface-xconnects")

                self.unresolved_backup_xconnects = YLeaf(YType.uint32, "unresolved-backup-xconnects")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("admin_down_backup_interface_xconnects",
                                "admin_down_backup_xconnects",
                                "down_backup_interface_xconnects",
                                "down_backup_xconnects",
                                "number_ce2_ceconnections",
                                "number_ce2ce_advertized",
                                "number_ce2ce_not_advertized",
                                "number_groups",
                                "number_mp2mp_xconnects",
                                "number_mp2mp_xconnects_advertised",
                                "number_mp2mp_xconnects_down",
                                "number_mp2mp_xconnects_up",
                                "number_mp2mp_xconnectss_not_advertised",
                                "number_xconnects",
                                "number_xconnects_administratively_down",
                                "number_xconnects_currently_using_backup",
                                "number_xconnects_currently_using_backup_interface",
                                "number_xconnects_down",
                                "number_xconnects_locally_switched",
                                "number_xconnects_type_attachment_circuit_to_pseudo_wire",
                                "number_xconnects_type_monitor_session_to_pseudo_wire",
                                "number_xconnects_type_pseudo_wire_to_pseudo_wire",
                                "number_xconnects_unresolved",
                                "number_xconnects_up",
                                "number_xconnects_with_backup_interface",
                                "number_xconnects_with_backup_pw",
                                "out_of_memory_state",
                                "partially_programmed_xconnects",
                                "standby_backup_interface_xconnects",
                                "standby_backup_xconnects",
                                "standby_ready_backup_xconnects",
                                "unresolved_backup_interface_xconnects",
                                "unresolved_backup_xconnects") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.XconnectSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.XconnectSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.admin_down_backup_interface_xconnects.is_set or
                    self.admin_down_backup_xconnects.is_set or
                    self.down_backup_interface_xconnects.is_set or
                    self.down_backup_xconnects.is_set or
                    self.number_ce2_ceconnections.is_set or
                    self.number_ce2ce_advertized.is_set or
                    self.number_ce2ce_not_advertized.is_set or
                    self.number_groups.is_set or
                    self.number_mp2mp_xconnects.is_set or
                    self.number_mp2mp_xconnects_advertised.is_set or
                    self.number_mp2mp_xconnects_down.is_set or
                    self.number_mp2mp_xconnects_up.is_set or
                    self.number_mp2mp_xconnectss_not_advertised.is_set or
                    self.number_xconnects.is_set or
                    self.number_xconnects_administratively_down.is_set or
                    self.number_xconnects_currently_using_backup.is_set or
                    self.number_xconnects_currently_using_backup_interface.is_set or
                    self.number_xconnects_down.is_set or
                    self.number_xconnects_locally_switched.is_set or
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire.is_set or
                    self.number_xconnects_type_monitor_session_to_pseudo_wire.is_set or
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire.is_set or
                    self.number_xconnects_unresolved.is_set or
                    self.number_xconnects_up.is_set or
                    self.number_xconnects_with_backup_interface.is_set or
                    self.number_xconnects_with_backup_pw.is_set or
                    self.out_of_memory_state.is_set or
                    self.partially_programmed_xconnects.is_set or
                    self.standby_backup_interface_xconnects.is_set or
                    self.standby_backup_xconnects.is_set or
                    self.standby_ready_backup_xconnects.is_set or
                    self.unresolved_backup_interface_xconnects.is_set or
                    self.unresolved_backup_xconnects.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.admin_down_backup_interface_xconnects.yfilter != YFilter.not_set or
                    self.admin_down_backup_xconnects.yfilter != YFilter.not_set or
                    self.down_backup_interface_xconnects.yfilter != YFilter.not_set or
                    self.down_backup_xconnects.yfilter != YFilter.not_set or
                    self.number_ce2_ceconnections.yfilter != YFilter.not_set or
                    self.number_ce2ce_advertized.yfilter != YFilter.not_set or
                    self.number_ce2ce_not_advertized.yfilter != YFilter.not_set or
                    self.number_groups.yfilter != YFilter.not_set or
                    self.number_mp2mp_xconnects.yfilter != YFilter.not_set or
                    self.number_mp2mp_xconnects_advertised.yfilter != YFilter.not_set or
                    self.number_mp2mp_xconnects_down.yfilter != YFilter.not_set or
                    self.number_mp2mp_xconnects_up.yfilter != YFilter.not_set or
                    self.number_mp2mp_xconnectss_not_advertised.yfilter != YFilter.not_set or
                    self.number_xconnects.yfilter != YFilter.not_set or
                    self.number_xconnects_administratively_down.yfilter != YFilter.not_set or
                    self.number_xconnects_currently_using_backup.yfilter != YFilter.not_set or
                    self.number_xconnects_currently_using_backup_interface.yfilter != YFilter.not_set or
                    self.number_xconnects_down.yfilter != YFilter.not_set or
                    self.number_xconnects_locally_switched.yfilter != YFilter.not_set or
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire.yfilter != YFilter.not_set or
                    self.number_xconnects_type_monitor_session_to_pseudo_wire.yfilter != YFilter.not_set or
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire.yfilter != YFilter.not_set or
                    self.number_xconnects_unresolved.yfilter != YFilter.not_set or
                    self.number_xconnects_up.yfilter != YFilter.not_set or
                    self.number_xconnects_with_backup_interface.yfilter != YFilter.not_set or
                    self.number_xconnects_with_backup_pw.yfilter != YFilter.not_set or
                    self.out_of_memory_state.yfilter != YFilter.not_set or
                    self.partially_programmed_xconnects.yfilter != YFilter.not_set or
                    self.standby_backup_interface_xconnects.yfilter != YFilter.not_set or
                    self.standby_backup_xconnects.yfilter != YFilter.not_set or
                    self.standby_ready_backup_xconnects.yfilter != YFilter.not_set or
                    self.unresolved_backup_interface_xconnects.yfilter != YFilter.not_set or
                    self.unresolved_backup_xconnects.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.admin_down_backup_interface_xconnects.is_set or self.admin_down_backup_interface_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.admin_down_backup_interface_xconnects.get_name_leafdata())
                if (self.admin_down_backup_xconnects.is_set or self.admin_down_backup_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.admin_down_backup_xconnects.get_name_leafdata())
                if (self.down_backup_interface_xconnects.is_set or self.down_backup_interface_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.down_backup_interface_xconnects.get_name_leafdata())
                if (self.down_backup_xconnects.is_set or self.down_backup_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.down_backup_xconnects.get_name_leafdata())
                if (self.number_ce2_ceconnections.is_set or self.number_ce2_ceconnections.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_ce2_ceconnections.get_name_leafdata())
                if (self.number_ce2ce_advertized.is_set or self.number_ce2ce_advertized.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_ce2ce_advertized.get_name_leafdata())
                if (self.number_ce2ce_not_advertized.is_set or self.number_ce2ce_not_advertized.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_ce2ce_not_advertized.get_name_leafdata())
                if (self.number_groups.is_set or self.number_groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_groups.get_name_leafdata())
                if (self.number_mp2mp_xconnects.is_set or self.number_mp2mp_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2mp_xconnects.get_name_leafdata())
                if (self.number_mp2mp_xconnects_advertised.is_set or self.number_mp2mp_xconnects_advertised.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2mp_xconnects_advertised.get_name_leafdata())
                if (self.number_mp2mp_xconnects_down.is_set or self.number_mp2mp_xconnects_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2mp_xconnects_down.get_name_leafdata())
                if (self.number_mp2mp_xconnects_up.is_set or self.number_mp2mp_xconnects_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2mp_xconnects_up.get_name_leafdata())
                if (self.number_mp2mp_xconnectss_not_advertised.is_set or self.number_mp2mp_xconnectss_not_advertised.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2mp_xconnectss_not_advertised.get_name_leafdata())
                if (self.number_xconnects.is_set or self.number_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects.get_name_leafdata())
                if (self.number_xconnects_administratively_down.is_set or self.number_xconnects_administratively_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_administratively_down.get_name_leafdata())
                if (self.number_xconnects_currently_using_backup.is_set or self.number_xconnects_currently_using_backup.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_currently_using_backup.get_name_leafdata())
                if (self.number_xconnects_currently_using_backup_interface.is_set or self.number_xconnects_currently_using_backup_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_currently_using_backup_interface.get_name_leafdata())
                if (self.number_xconnects_down.is_set or self.number_xconnects_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_down.get_name_leafdata())
                if (self.number_xconnects_locally_switched.is_set or self.number_xconnects_locally_switched.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_locally_switched.get_name_leafdata())
                if (self.number_xconnects_type_attachment_circuit_to_pseudo_wire.is_set or self.number_xconnects_type_attachment_circuit_to_pseudo_wire.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_type_attachment_circuit_to_pseudo_wire.get_name_leafdata())
                if (self.number_xconnects_type_monitor_session_to_pseudo_wire.is_set or self.number_xconnects_type_monitor_session_to_pseudo_wire.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_type_monitor_session_to_pseudo_wire.get_name_leafdata())
                if (self.number_xconnects_type_pseudo_wire_to_pseudo_wire.is_set or self.number_xconnects_type_pseudo_wire_to_pseudo_wire.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_type_pseudo_wire_to_pseudo_wire.get_name_leafdata())
                if (self.number_xconnects_unresolved.is_set or self.number_xconnects_unresolved.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_unresolved.get_name_leafdata())
                if (self.number_xconnects_up.is_set or self.number_xconnects_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_up.get_name_leafdata())
                if (self.number_xconnects_with_backup_interface.is_set or self.number_xconnects_with_backup_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_with_backup_interface.get_name_leafdata())
                if (self.number_xconnects_with_backup_pw.is_set or self.number_xconnects_with_backup_pw.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_with_backup_pw.get_name_leafdata())
                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                if (self.partially_programmed_xconnects.is_set or self.partially_programmed_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.partially_programmed_xconnects.get_name_leafdata())
                if (self.standby_backup_interface_xconnects.is_set or self.standby_backup_interface_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.standby_backup_interface_xconnects.get_name_leafdata())
                if (self.standby_backup_xconnects.is_set or self.standby_backup_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.standby_backup_xconnects.get_name_leafdata())
                if (self.standby_ready_backup_xconnects.is_set or self.standby_ready_backup_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.standby_ready_backup_xconnects.get_name_leafdata())
                if (self.unresolved_backup_interface_xconnects.is_set or self.unresolved_backup_interface_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unresolved_backup_interface_xconnects.get_name_leafdata())
                if (self.unresolved_backup_xconnects.is_set or self.unresolved_backup_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unresolved_backup_xconnects.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "admin-down-backup-interface-xconnects" or name == "admin-down-backup-xconnects" or name == "down-backup-interface-xconnects" or name == "down-backup-xconnects" or name == "number-ce2-ceconnections" or name == "number-ce2ce-advertized" or name == "number-ce2ce-not-advertized" or name == "number-groups" or name == "number-mp2mp-xconnects" or name == "number-mp2mp-xconnects-advertised" or name == "number-mp2mp-xconnects-down" or name == "number-mp2mp-xconnects-up" or name == "number-mp2mp-xconnectss-not-advertised" or name == "number-xconnects" or name == "number-xconnects-administratively-down" or name == "number-xconnects-currently-using-backup" or name == "number-xconnects-currently-using-backup-interface" or name == "number-xconnects-down" or name == "number-xconnects-locally-switched" or name == "number-xconnects-type-attachment-circuit-to-pseudo-wire" or name == "number-xconnects-type-monitor-session-to-pseudo-wire" or name == "number-xconnects-type-pseudo-wire-to-pseudo-wire" or name == "number-xconnects-unresolved" or name == "number-xconnects-up" or name == "number-xconnects-with-backup-interface" or name == "number-xconnects-with-backup-pw" or name == "out-of-memory-state" or name == "partially-programmed-xconnects" or name == "standby-backup-interface-xconnects" or name == "standby-backup-xconnects" or name == "standby-ready-backup-xconnects" or name == "unresolved-backup-interface-xconnects" or name == "unresolved-backup-xconnects"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "admin-down-backup-interface-xconnects"):
                    self.admin_down_backup_interface_xconnects = value
                    self.admin_down_backup_interface_xconnects.value_namespace = name_space
                    self.admin_down_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "admin-down-backup-xconnects"):
                    self.admin_down_backup_xconnects = value
                    self.admin_down_backup_xconnects.value_namespace = name_space
                    self.admin_down_backup_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "down-backup-interface-xconnects"):
                    self.down_backup_interface_xconnects = value
                    self.down_backup_interface_xconnects.value_namespace = name_space
                    self.down_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "down-backup-xconnects"):
                    self.down_backup_xconnects = value
                    self.down_backup_xconnects.value_namespace = name_space
                    self.down_backup_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "number-ce2-ceconnections"):
                    self.number_ce2_ceconnections = value
                    self.number_ce2_ceconnections.value_namespace = name_space
                    self.number_ce2_ceconnections.value_namespace_prefix = name_space_prefix
                if(value_path == "number-ce2ce-advertized"):
                    self.number_ce2ce_advertized = value
                    self.number_ce2ce_advertized.value_namespace = name_space
                    self.number_ce2ce_advertized.value_namespace_prefix = name_space_prefix
                if(value_path == "number-ce2ce-not-advertized"):
                    self.number_ce2ce_not_advertized = value
                    self.number_ce2ce_not_advertized.value_namespace = name_space
                    self.number_ce2ce_not_advertized.value_namespace_prefix = name_space_prefix
                if(value_path == "number-groups"):
                    self.number_groups = value
                    self.number_groups.value_namespace = name_space
                    self.number_groups.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2mp-xconnects"):
                    self.number_mp2mp_xconnects = value
                    self.number_mp2mp_xconnects.value_namespace = name_space
                    self.number_mp2mp_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2mp-xconnects-advertised"):
                    self.number_mp2mp_xconnects_advertised = value
                    self.number_mp2mp_xconnects_advertised.value_namespace = name_space
                    self.number_mp2mp_xconnects_advertised.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2mp-xconnects-down"):
                    self.number_mp2mp_xconnects_down = value
                    self.number_mp2mp_xconnects_down.value_namespace = name_space
                    self.number_mp2mp_xconnects_down.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2mp-xconnects-up"):
                    self.number_mp2mp_xconnects_up = value
                    self.number_mp2mp_xconnects_up.value_namespace = name_space
                    self.number_mp2mp_xconnects_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2mp-xconnectss-not-advertised"):
                    self.number_mp2mp_xconnectss_not_advertised = value
                    self.number_mp2mp_xconnectss_not_advertised.value_namespace = name_space
                    self.number_mp2mp_xconnectss_not_advertised.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects"):
                    self.number_xconnects = value
                    self.number_xconnects.value_namespace = name_space
                    self.number_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-administratively-down"):
                    self.number_xconnects_administratively_down = value
                    self.number_xconnects_administratively_down.value_namespace = name_space
                    self.number_xconnects_administratively_down.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-currently-using-backup"):
                    self.number_xconnects_currently_using_backup = value
                    self.number_xconnects_currently_using_backup.value_namespace = name_space
                    self.number_xconnects_currently_using_backup.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-currently-using-backup-interface"):
                    self.number_xconnects_currently_using_backup_interface = value
                    self.number_xconnects_currently_using_backup_interface.value_namespace = name_space
                    self.number_xconnects_currently_using_backup_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-down"):
                    self.number_xconnects_down = value
                    self.number_xconnects_down.value_namespace = name_space
                    self.number_xconnects_down.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-locally-switched"):
                    self.number_xconnects_locally_switched = value
                    self.number_xconnects_locally_switched.value_namespace = name_space
                    self.number_xconnects_locally_switched.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-type-attachment-circuit-to-pseudo-wire"):
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire = value
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire.value_namespace = name_space
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-type-monitor-session-to-pseudo-wire"):
                    self.number_xconnects_type_monitor_session_to_pseudo_wire = value
                    self.number_xconnects_type_monitor_session_to_pseudo_wire.value_namespace = name_space
                    self.number_xconnects_type_monitor_session_to_pseudo_wire.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-type-pseudo-wire-to-pseudo-wire"):
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire = value
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire.value_namespace = name_space
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-unresolved"):
                    self.number_xconnects_unresolved = value
                    self.number_xconnects_unresolved.value_namespace = name_space
                    self.number_xconnects_unresolved.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-up"):
                    self.number_xconnects_up = value
                    self.number_xconnects_up.value_namespace = name_space
                    self.number_xconnects_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-with-backup-interface"):
                    self.number_xconnects_with_backup_interface = value
                    self.number_xconnects_with_backup_interface.value_namespace = name_space
                    self.number_xconnects_with_backup_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-with-backup-pw"):
                    self.number_xconnects_with_backup_pw = value
                    self.number_xconnects_with_backup_pw.value_namespace = name_space
                    self.number_xconnects_with_backup_pw.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-memory-state"):
                    self.out_of_memory_state = value
                    self.out_of_memory_state.value_namespace = name_space
                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                if(value_path == "partially-programmed-xconnects"):
                    self.partially_programmed_xconnects = value
                    self.partially_programmed_xconnects.value_namespace = name_space
                    self.partially_programmed_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "standby-backup-interface-xconnects"):
                    self.standby_backup_interface_xconnects = value
                    self.standby_backup_interface_xconnects.value_namespace = name_space
                    self.standby_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "standby-backup-xconnects"):
                    self.standby_backup_xconnects = value
                    self.standby_backup_xconnects.value_namespace = name_space
                    self.standby_backup_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "standby-ready-backup-xconnects"):
                    self.standby_ready_backup_xconnects = value
                    self.standby_ready_backup_xconnects.value_namespace = name_space
                    self.standby_ready_backup_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "unresolved-backup-interface-xconnects"):
                    self.unresolved_backup_interface_xconnects = value
                    self.unresolved_backup_interface_xconnects.value_namespace = name_space
                    self.unresolved_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "unresolved-backup-xconnects"):
                    self.unresolved_backup_xconnects = value
                    self.unresolved_backup_xconnects.value_namespace = name_space
                    self.unresolved_backup_xconnects.value_namespace_prefix = name_space_prefix


        class ProcFsm(Entity):
            """
            L2VPN Process FSM information
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.EventHistory>`
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.FailoverStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.IssuStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.NsrStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.ReportCard>`
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\:  bool
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.XidInfo>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.ProcFsm, self).__init__()

                self.yang_name = "proc-fsm"
                self.yang_parent_name = "standby"

                self.process_role = YLeaf(YType.uint8, "process-role")

                self.process_state = YLeaf(YType.uint8, "process-state")

                self.state_transition_time = YLeafList(YType.uint32, "state-transition-time")

                self.sw_install_in_progress = YLeaf(YType.boolean, "sw-install-in-progress")

                self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                self.failover_status = L2Vpnv2.Standby.ProcFsm.FailoverStatus()
                self.failover_status.parent = self
                self._children_name_map["failover_status"] = "failover-status"
                self._children_yang_names.add("failover-status")

                self.issu_status = L2Vpnv2.Standby.ProcFsm.IssuStatus()
                self.issu_status.parent = self
                self._children_name_map["issu_status"] = "issu-status"
                self._children_yang_names.add("issu-status")

                self.nsr_status = L2Vpnv2.Standby.ProcFsm.NsrStatus()
                self.nsr_status.parent = self
                self._children_name_map["nsr_status"] = "nsr-status"
                self._children_yang_names.add("nsr-status")

                self.event_history = YList(self)
                self.report_card = YList(self)
                self.xid_info = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("process_role",
                                "process_state",
                                "state_transition_time",
                                "sw_install_in_progress",
                                "sync_flags") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.ProcFsm, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.ProcFsm, self).__setattr__(name, value)


            class FailoverStatus(Entity):
                """
                L2VPN failover status
                
                .. attribute:: master_time
                
                	Master time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.ProcFsm.FailoverStatus, self).__init__()

                    self.yang_name = "failover-status"
                    self.yang_parent_name = "proc-fsm"

                    self.master_time = YLeaf(YType.uint32, "master-time")

                    self.start_time = YLeaf(YType.uint32, "start-time")

                    self.triggered_time = YLeaf(YType.uint32, "triggered-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("master_time",
                                    "start_time",
                                    "triggered_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.ProcFsm.FailoverStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.ProcFsm.FailoverStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.master_time.is_set or
                        self.start_time.is_set or
                        self.triggered_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.master_time.yfilter != YFilter.not_set or
                        self.start_time.yfilter != YFilter.not_set or
                        self.triggered_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "failover-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.master_time.is_set or self.master_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.master_time.get_name_leafdata())
                    if (self.start_time.is_set or self.start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.start_time.get_name_leafdata())
                    if (self.triggered_time.is_set or self.triggered_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.triggered_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "master-time" or name == "start-time" or name == "triggered-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "master-time"):
                        self.master_time = value
                        self.master_time.value_namespace = name_space
                        self.master_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "start-time"):
                        self.start_time = value
                        self.start_time.value_namespace = name_space
                        self.start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "triggered-time"):
                        self.triggered_time = value
                        self.triggered_time.value_namespace = name_space
                        self.triggered_time.value_namespace_prefix = name_space_prefix


            class NsrStatus(Entity):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.ProcFsm.NsrStatus, self).__init__()

                    self.yang_name = "nsr-status"
                    self.yang_parent_name = "proc-fsm"

                    self.role = YLeaf(YType.enumeration, "role")

                    self.idt_status = L2Vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"
                    self._children_yang_names.add("idt-status")

                    self.previ_ous_idt_status = L2Vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._children_yang_names.add("previ-ous-idt-status")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("role") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.ProcFsm.NsrStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.ProcFsm.NsrStatus, self).__setattr__(name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "nsr-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/nsr-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "nsr-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "previ-ous-idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/nsr-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.role.is_set or
                        (self.idt_status is not None and self.idt_status.has_data()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.role.yfilter != YFilter.not_set or
                        (self.idt_status is not None and self.idt_status.has_operation()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "idt-status"):
                        if (self.idt_status is None):
                            self.idt_status = L2Vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus()
                            self.idt_status.parent = self
                            self._children_name_map["idt_status"] = "idt-status"
                        return self.idt_status

                    if (child_yang_name == "previ-ous-idt-status"):
                        if (self.previ_ous_idt_status is None):
                            self.previ_ous_idt_status = L2Vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus()
                            self.previ_ous_idt_status.parent = self
                            self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        return self.previ_ous_idt_status

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "role"):
                        self.role = value
                        self.role.value_namespace = name_space
                        self.role.value_namespace_prefix = name_space_prefix


            class IssuStatus(Entity):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.ProcFsm.IssuStatus, self).__init__()

                    self.yang_name = "issu-status"
                    self.yang_parent_name = "proc-fsm"

                    self.role = YLeaf(YType.enumeration, "role")

                    self.idt_status = L2Vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"
                    self._children_yang_names.add("idt-status")

                    self.previ_ous_idt_status = L2Vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._children_yang_names.add("previ-ous-idt-status")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("role") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.ProcFsm.IssuStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.ProcFsm.IssuStatus, self).__setattr__(name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "issu-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/issu-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "issu-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "previ-ous-idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/issu-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.role.is_set or
                        (self.idt_status is not None and self.idt_status.has_data()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.role.yfilter != YFilter.not_set or
                        (self.idt_status is not None and self.idt_status.has_operation()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "issu-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "idt-status"):
                        if (self.idt_status is None):
                            self.idt_status = L2Vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus()
                            self.idt_status.parent = self
                            self._children_name_map["idt_status"] = "idt-status"
                        return self.idt_status

                    if (child_yang_name == "previ-ous-idt-status"):
                        if (self.previ_ous_idt_status is None):
                            self.previ_ous_idt_status = L2Vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus()
                            self.previ_ous_idt_status.parent = self
                            self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        return self.previ_ous_idt_status

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "role"):
                        self.role = value
                        self.role.value_namespace = name_space
                        self.role.value_namespace_prefix = name_space_prefix


            class XidInfo(Entity):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.ProcFsm.XidInfo, self).__init__()

                    self.yang_name = "xid-info"
                    self.yang_parent_name = "proc-fsm"

                    self.app_type = YLeaf(YType.enumeration, "app-type")

                    self.sent_ids = YLeaf(YType.uint32, "sent-ids")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("app_type",
                                    "sent_ids") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.ProcFsm.XidInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.ProcFsm.XidInfo, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.app_type.is_set or
                        self.sent_ids.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.app_type.yfilter != YFilter.not_set or
                        self.sent_ids.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xid-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.app_type.is_set or self.app_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.app_type.get_name_leafdata())
                    if (self.sent_ids.is_set or self.sent_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sent_ids.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "app-type" or name == "sent-ids"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "app-type"):
                        self.app_type = value
                        self.app_type.value_namespace = name_space
                        self.app_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "sent-ids"):
                        self.sent_ids = value
                        self.sent_ids.value_namespace = name_space
                        self.sent_ids.value_namespace_prefix = name_space_prefix


            class ReportCard(Entity):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\:  bool
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\:  bool
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\:  bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.ProcFsm.ReportCard, self).__init__()

                    self.yang_name = "report-card"
                    self.yang_parent_name = "proc-fsm"

                    self.collaborator_idt_done = YLeaf(YType.boolean, "collaborator-idt-done")

                    self.collaborator_is_connected = YLeaf(YType.boolean, "collaborator-is-connected")

                    self.collaborator_skipped = YLeaf(YType.boolean, "collaborator-skipped")

                    self.connection_change_time = YLeaf(YType.uint32, "connection-change-time")

                    self.idt_time = YLeaf(YType.uint32, "idt-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("collaborator_idt_done",
                                    "collaborator_is_connected",
                                    "collaborator_skipped",
                                    "connection_change_time",
                                    "idt_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.ProcFsm.ReportCard, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.ProcFsm.ReportCard, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.collaborator_idt_done.is_set or
                        self.collaborator_is_connected.is_set or
                        self.collaborator_skipped.is_set or
                        self.connection_change_time.is_set or
                        self.idt_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.collaborator_idt_done.yfilter != YFilter.not_set or
                        self.collaborator_is_connected.yfilter != YFilter.not_set or
                        self.collaborator_skipped.yfilter != YFilter.not_set or
                        self.connection_change_time.yfilter != YFilter.not_set or
                        self.idt_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "report-card" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.collaborator_idt_done.is_set or self.collaborator_idt_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_idt_done.get_name_leafdata())
                    if (self.collaborator_is_connected.is_set or self.collaborator_is_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_is_connected.get_name_leafdata())
                    if (self.collaborator_skipped.is_set or self.collaborator_skipped.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_skipped.get_name_leafdata())
                    if (self.connection_change_time.is_set or self.connection_change_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.connection_change_time.get_name_leafdata())
                    if (self.idt_time.is_set or self.idt_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "collaborator-idt-done" or name == "collaborator-is-connected" or name == "collaborator-skipped" or name == "connection-change-time" or name == "idt-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "collaborator-idt-done"):
                        self.collaborator_idt_done = value
                        self.collaborator_idt_done.value_namespace = name_space
                        self.collaborator_idt_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "collaborator-is-connected"):
                        self.collaborator_is_connected = value
                        self.collaborator_is_connected.value_namespace = name_space
                        self.collaborator_is_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "collaborator-skipped"):
                        self.collaborator_skipped = value
                        self.collaborator_skipped.value_namespace = name_space
                        self.collaborator_skipped.value_namespace_prefix = name_space_prefix
                    if(value_path == "connection-change-time"):
                        self.connection_change_time = value
                        self.connection_change_time.value_namespace = name_space
                        self.connection_change_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-time"):
                        self.idt_time = value
                        self.idt_time.value_namespace = name_space
                        self.idt_time.value_namespace_prefix = name_space_prefix


            class EventHistory(Entity):
                """
                L2VPN Process event history
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: new_state
                
                	New state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: process_event
                
                	Process event
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.ProcFsm.EventHistory, self).__init__()

                    self.yang_name = "event-history"
                    self.yang_parent_name = "proc-fsm"

                    self.event_timestamp = YLeaf(YType.uint32, "event-timestamp")

                    self.new_state = YLeaf(YType.uint8, "new-state")

                    self.previous_state = YLeaf(YType.uint8, "previous-state")

                    self.process_collaborator = YLeaf(YType.uint16, "process-collaborator")

                    self.process_event = YLeaf(YType.uint16, "process-event")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("event_timestamp",
                                    "new_state",
                                    "previous_state",
                                    "process_collaborator",
                                    "process_event") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.ProcFsm.EventHistory, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.ProcFsm.EventHistory, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.event_timestamp.is_set or
                        self.new_state.is_set or
                        self.previous_state.is_set or
                        self.process_collaborator.is_set or
                        self.process_event.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.event_timestamp.yfilter != YFilter.not_set or
                        self.new_state.yfilter != YFilter.not_set or
                        self.previous_state.yfilter != YFilter.not_set or
                        self.process_collaborator.yfilter != YFilter.not_set or
                        self.process_event.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "event-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.event_timestamp.is_set or self.event_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.event_timestamp.get_name_leafdata())
                    if (self.new_state.is_set or self.new_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.new_state.get_name_leafdata())
                    if (self.previous_state.is_set or self.previous_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.previous_state.get_name_leafdata())
                    if (self.process_collaborator.is_set or self.process_collaborator.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_collaborator.get_name_leafdata())
                    if (self.process_event.is_set or self.process_event.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_event.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "event-timestamp" or name == "new-state" or name == "previous-state" or name == "process-collaborator" or name == "process-event"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "event-timestamp"):
                        self.event_timestamp = value
                        self.event_timestamp.value_namespace = name_space
                        self.event_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "new-state"):
                        self.new_state = value
                        self.new_state.value_namespace = name_space
                        self.new_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "previous-state"):
                        self.previous_state = value
                        self.previous_state.value_namespace = name_space
                        self.previous_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-collaborator"):
                        self.process_collaborator = value
                        self.process_collaborator.value_namespace = name_space
                        self.process_collaborator.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-event"):
                        self.process_event = value
                        self.process_event.value_namespace = name_space
                        self.process_event.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.event_history:
                    if (c.has_data()):
                        return True
                for c in self.report_card:
                    if (c.has_data()):
                        return True
                for c in self.xid_info:
                    if (c.has_data()):
                        return True
                for leaf in self.state_transition_time.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                return (
                    self.process_role.is_set or
                    self.process_state.is_set or
                    self.sw_install_in_progress.is_set or
                    self.sync_flags.is_set or
                    (self.failover_status is not None and self.failover_status.has_data()) or
                    (self.issu_status is not None and self.issu_status.has_data()) or
                    (self.nsr_status is not None and self.nsr_status.has_data()))

            def has_operation(self):
                for c in self.event_history:
                    if (c.has_operation()):
                        return True
                for c in self.report_card:
                    if (c.has_operation()):
                        return True
                for c in self.xid_info:
                    if (c.has_operation()):
                        return True
                for leaf in self.state_transition_time.getYLeafs():
                    if (leaf.is_set):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.process_role.yfilter != YFilter.not_set or
                    self.process_state.yfilter != YFilter.not_set or
                    self.state_transition_time.yfilter != YFilter.not_set or
                    self.sw_install_in_progress.yfilter != YFilter.not_set or
                    self.sync_flags.yfilter != YFilter.not_set or
                    (self.failover_status is not None and self.failover_status.has_operation()) or
                    (self.issu_status is not None and self.issu_status.has_operation()) or
                    (self.nsr_status is not None and self.nsr_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "proc-fsm" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.process_role.is_set or self.process_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_role.get_name_leafdata())
                if (self.process_state.is_set or self.process_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_state.get_name_leafdata())
                if (self.sw_install_in_progress.is_set or self.sw_install_in_progress.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sw_install_in_progress.get_name_leafdata())
                if (self.sync_flags.is_set or self.sync_flags.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sync_flags.get_name_leafdata())

                leaf_name_data.extend(self.state_transition_time.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "event-history"):
                    for c in self.event_history:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.ProcFsm.EventHistory()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.event_history.append(c)
                    return c

                if (child_yang_name == "failover-status"):
                    if (self.failover_status is None):
                        self.failover_status = L2Vpnv2.Standby.ProcFsm.FailoverStatus()
                        self.failover_status.parent = self
                        self._children_name_map["failover_status"] = "failover-status"
                    return self.failover_status

                if (child_yang_name == "issu-status"):
                    if (self.issu_status is None):
                        self.issu_status = L2Vpnv2.Standby.ProcFsm.IssuStatus()
                        self.issu_status.parent = self
                        self._children_name_map["issu_status"] = "issu-status"
                    return self.issu_status

                if (child_yang_name == "nsr-status"):
                    if (self.nsr_status is None):
                        self.nsr_status = L2Vpnv2.Standby.ProcFsm.NsrStatus()
                        self.nsr_status.parent = self
                        self._children_name_map["nsr_status"] = "nsr-status"
                    return self.nsr_status

                if (child_yang_name == "report-card"):
                    for c in self.report_card:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.ProcFsm.ReportCard()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.report_card.append(c)
                    return c

                if (child_yang_name == "xid-info"):
                    for c in self.xid_info:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.ProcFsm.XidInfo()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xid_info.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "event-history" or name == "failover-status" or name == "issu-status" or name == "nsr-status" or name == "report-card" or name == "xid-info" or name == "process-role" or name == "process-state" or name == "state-transition-time" or name == "sw-install-in-progress" or name == "sync-flags"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "process-role"):
                    self.process_role = value
                    self.process_role.value_namespace = name_space
                    self.process_role.value_namespace_prefix = name_space_prefix
                if(value_path == "process-state"):
                    self.process_state = value
                    self.process_state.value_namespace = name_space
                    self.process_state.value_namespace_prefix = name_space_prefix
                if(value_path == "state-transition-time"):
                    self.state_transition_time.append(value)
                if(value_path == "sw-install-in-progress"):
                    self.sw_install_in_progress = value
                    self.sw_install_in_progress.value_namespace = name_space
                    self.sw_install_in_progress.value_namespace_prefix = name_space_prefix
                if(value_path == "sync-flags"):
                    self.sync_flags = value
                    self.sync_flags.value_namespace = name_space
                    self.sync_flags.value_namespace_prefix = name_space_prefix


        class MstpPorts(Entity):
            """
            L2VPN MSTP Port Table
            
            .. attribute:: mstp_port
            
            	MSTP Port information
            	**type**\: list of    :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpPorts.MstpPort>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.MstpPorts, self).__init__()

                self.yang_name = "mstp-ports"
                self.yang_parent_name = "standby"

                self.mstp_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.MstpPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.MstpPorts, self).__setattr__(name, value)


            class MstpPort(Entity):
                """
                MSTP Port information
                
                .. attribute:: interface  <key>
                
                	Interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\:  str
                
                .. attribute:: msti_entry
                
                	MSTI
                	**type**\: list of    :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry>`
                
                .. attribute:: mstp_interface_handle
                
                	Interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: protected
                
                	Protected
                	**type**\:  bool
                
                .. attribute:: reference_count
                
                	Reference Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.MstpPorts.MstpPort, self).__init__()

                    self.yang_name = "mstp-port"
                    self.yang_parent_name = "mstp-ports"

                    self.interface = YLeaf(YType.str, "interface")

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.mstp_interface_handle = YLeaf(YType.str, "mstp-interface-handle")

                    self.protected = YLeaf(YType.boolean, "protected")

                    self.reference_count = YLeaf(YType.uint32, "reference-count")

                    self.msti_entry = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface",
                                    "interface_name",
                                    "mstp_interface_handle",
                                    "protected",
                                    "reference_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.MstpPorts.MstpPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.MstpPorts.MstpPort, self).__setattr__(name, value)


                class MstiEntry(Entity):
                    """
                    MSTI
                    
                    .. attribute:: ack_count
                    
                    	Ack count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_count
                    
                    	BD count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_entry
                    
                    	BD entries
                    	**type**\: list of    :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                    
                    .. attribute:: cfg_ms_ti
                    
                    	 Configured MSTi
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: flush_count
                    
                    	Flush count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_flags
                    
                    	Msti Flags
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_state
                    
                    	Msti State
                    	**type**\:   :py:class:`L2VpnMstiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMstiState>`
                    
                    .. attribute:: nack_count
                    
                    	Nack count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rcv_count
                    
                    	Receive count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry, self).__init__()

                        self.yang_name = "msti-entry"
                        self.yang_parent_name = "mstp-port"

                        self.ack_count = YLeaf(YType.uint32, "ack-count")

                        self.bd_count = YLeaf(YType.uint32, "bd-count")

                        self.cfg_ms_ti = YLeaf(YType.uint32, "cfg-ms-ti")

                        self.flush_count = YLeaf(YType.uint32, "flush-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                        self.msti_flags = YLeaf(YType.uint32, "msti-flags")

                        self.msti_state = YLeaf(YType.enumeration, "msti-state")

                        self.nack_count = YLeaf(YType.uint32, "nack-count")

                        self.rcv_count = YLeaf(YType.uint32, "rcv-count")

                        self.bd_entry = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ack_count",
                                        "bd_count",
                                        "cfg_ms_ti",
                                        "flush_count",
                                        "interface_count",
                                        "msti_flags",
                                        "msti_state",
                                        "nack_count",
                                        "rcv_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry, self).__setattr__(name, value)


                    class BdEntry(Entity):
                        """
                        BD entries
                        
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bdif_count
                        
                        	BD Intf Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__init__()

                            self.yang_name = "bd-entry"
                            self.yang_parent_name = "msti-entry"

                            self.bdid = YLeaf(YType.uint32, "bdid")

                            self.bdif_count = YLeaf(YType.uint32, "bdif-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bdid",
                                            "bdif_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bdid.is_set or
                                self.bdif_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bdid.yfilter != YFilter.not_set or
                                self.bdif_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bd-entry" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bdid.is_set or self.bdid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bdid.get_name_leafdata())
                            if (self.bdif_count.is_set or self.bdif_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bdif_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bdid" or name == "bdif-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bdid"):
                                self.bdid = value
                                self.bdid.value_namespace = name_space
                                self.bdid.value_namespace_prefix = name_space_prefix
                            if(value_path == "bdif-count"):
                                self.bdif_count = value
                                self.bdif_count.value_namespace = name_space
                                self.bdif_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bd_entry:
                            if (c.has_data()):
                                return True
                        return (
                            self.ack_count.is_set or
                            self.bd_count.is_set or
                            self.cfg_ms_ti.is_set or
                            self.flush_count.is_set or
                            self.interface_count.is_set or
                            self.msti_flags.is_set or
                            self.msti_state.is_set or
                            self.nack_count.is_set or
                            self.rcv_count.is_set)

                    def has_operation(self):
                        for c in self.bd_entry:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ack_count.yfilter != YFilter.not_set or
                            self.bd_count.yfilter != YFilter.not_set or
                            self.cfg_ms_ti.yfilter != YFilter.not_set or
                            self.flush_count.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set or
                            self.msti_flags.yfilter != YFilter.not_set or
                            self.msti_state.yfilter != YFilter.not_set or
                            self.nack_count.yfilter != YFilter.not_set or
                            self.rcv_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "msti-entry" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ack_count.is_set or self.ack_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ack_count.get_name_leafdata())
                        if (self.bd_count.is_set or self.bd_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_count.get_name_leafdata())
                        if (self.cfg_ms_ti.is_set or self.cfg_ms_ti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cfg_ms_ti.get_name_leafdata())
                        if (self.flush_count.is_set or self.flush_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flush_count.get_name_leafdata())
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())
                        if (self.msti_flags.is_set or self.msti_flags.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_flags.get_name_leafdata())
                        if (self.msti_state.is_set or self.msti_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_state.get_name_leafdata())
                        if (self.nack_count.is_set or self.nack_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nack_count.get_name_leafdata())
                        if (self.rcv_count.is_set or self.rcv_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rcv_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bd-entry"):
                            for c in self.bd_entry:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bd_entry.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bd-entry" or name == "ack-count" or name == "bd-count" or name == "cfg-ms-ti" or name == "flush-count" or name == "interface-count" or name == "msti-flags" or name == "msti-state" or name == "nack-count" or name == "rcv-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ack-count"):
                            self.ack_count = value
                            self.ack_count.value_namespace = name_space
                            self.ack_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-count"):
                            self.bd_count = value
                            self.bd_count.value_namespace = name_space
                            self.bd_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "cfg-ms-ti"):
                            self.cfg_ms_ti = value
                            self.cfg_ms_ti.value_namespace = name_space
                            self.cfg_ms_ti.value_namespace_prefix = name_space_prefix
                        if(value_path == "flush-count"):
                            self.flush_count = value
                            self.flush_count.value_namespace = name_space
                            self.flush_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-flags"):
                            self.msti_flags = value
                            self.msti_flags.value_namespace = name_space
                            self.msti_flags.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-state"):
                            self.msti_state = value
                            self.msti_state.value_namespace = name_space
                            self.msti_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "nack-count"):
                            self.nack_count = value
                            self.nack_count.value_namespace = name_space
                            self.nack_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "rcv-count"):
                            self.rcv_count = value
                            self.rcv_count.value_namespace = name_space
                            self.rcv_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.msti_entry:
                        if (c.has_data()):
                            return True
                    return (
                        self.interface.is_set or
                        self.interface_name.is_set or
                        self.mstp_interface_handle.is_set or
                        self.protected.is_set or
                        self.reference_count.is_set)

                def has_operation(self):
                    for c in self.msti_entry:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.mstp_interface_handle.yfilter != YFilter.not_set or
                        self.protected.yfilter != YFilter.not_set or
                        self.reference_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mstp-port" + "[interface='" + self.interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/mstp-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface.get_name_leafdata())
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.mstp_interface_handle.is_set or self.mstp_interface_handle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mstp_interface_handle.get_name_leafdata())
                    if (self.protected.is_set or self.protected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.protected.get_name_leafdata())
                    if (self.reference_count.is_set or self.reference_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reference_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "msti-entry"):
                        for c in self.msti_entry:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.msti_entry.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "msti-entry" or name == "interface" or name == "interface-name" or name == "mstp-interface-handle" or name == "protected" or name == "reference-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface"):
                        self.interface = value
                        self.interface.value_namespace = name_space
                        self.interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mstp-interface-handle"):
                        self.mstp_interface_handle = value
                        self.mstp_interface_handle.value_namespace = name_space
                        self.mstp_interface_handle.value_namespace_prefix = name_space_prefix
                    if(value_path == "protected"):
                        self.protected = value
                        self.protected.value_namespace = name_space
                        self.protected.value_namespace_prefix = name_space_prefix
                    if(value_path == "reference-count"):
                        self.reference_count = value
                        self.reference_count.value_namespace = name_space
                        self.reference_count.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.mstp_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.mstp_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mstp-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mstp-port"):
                    for c in self.mstp_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.MstpPorts.MstpPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.mstp_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mstp-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class GenericInterfaceListDetails(Entity):
            """
            L2VPN generic interface list Detail Table
            
            .. attribute:: generic_interface_list_detail
            
            	Generic Interface List detail information
            	**type**\: list of    :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.GenericInterfaceListDetails, self).__init__()

                self.yang_name = "generic-interface-list-details"
                self.yang_parent_name = "standby"

                self.generic_interface_list_detail = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.GenericInterfaceListDetails, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.GenericInterfaceListDetails, self).__setattr__(name, value)


            class GenericInterfaceListDetail(Entity):
                """
                Generic Interface List detail information
                
                .. attribute:: interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\:  bool
                
                .. attribute:: items
                
                	Number of items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: psedowire_ether_items
                
                	Number PW Ether Items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pseudowire_ether_range
                
                	PW\-Ether ranges
                	**type**\: list of    :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
                
                .. attribute:: pseudowire_iw_items
                
                	Number PW IW Items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pseudowire_iw_range
                
                	PW\-IW ranges
                	**type**\: list of    :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
                
                .. attribute:: summary
                
                	Summary information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__init__()

                    self.yang_name = "generic-interface-list-detail"
                    self.yang_parent_name = "generic-interface-list-details"

                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                    self.is_provisioned = YLeaf(YType.boolean, "is-provisioned")

                    self.items = YLeaf(YType.uint32, "items")

                    self.psedowire_ether_items = YLeaf(YType.uint32, "psedowire-ether-items")

                    self.pseudowire_iw_items = YLeaf(YType.uint32, "pseudowire-iw-items")

                    self.summary = L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.interface = YList(self)
                    self.pseudowire_ether_range = YList(self)
                    self.pseudowire_iw_range = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_list_name",
                                    "is_provisioned",
                                    "items",
                                    "psedowire_ether_items",
                                    "pseudowire_iw_items") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__setattr__(name, value)


                class Summary(Entity):
                    """
                    Summary information
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_list_name_xr
                    
                    	Interface\-list name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_interfaces
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "generic-interface-list-detail"

                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                        self.interface_list_name_xr = YLeaf(YType.str, "interface-list-name-xr")

                        self.items = YLeaf(YType.uint32, "items")

                        self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_list_id",
                                        "interface_list_name_xr",
                                        "items",
                                        "number_of_interfaces") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                            self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                            self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "is_fib_downloaded",
                                            "not_supported_replications",
                                            "pending_replications") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.is_fib_downloaded.is_set or
                                self.not_supported_replications.is_set or
                                self.pending_replications.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_fib_downloaded.yfilter != YFilter.not_set or
                                self.not_supported_replications.yfilter != YFilter.not_set or
                                self.pending_replications.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                            if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                            if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pending_replications.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-fib-downloaded"):
                                self.is_fib_downloaded = value
                                self.is_fib_downloaded.value_namespace = name_space
                                self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-replications"):
                                self.not_supported_replications = value
                                self.not_supported_replications.value_namespace = name_space
                                self.not_supported_replications.value_namespace_prefix = name_space_prefix
                            if(value_path == "pending-replications"):
                                self.pending_replications = value
                                self.pending_replications.value_namespace = name_space
                                self.pending_replications.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_list_id.is_set or
                            self.interface_list_name_xr.is_set or
                            self.items.is_set or
                            self.number_of_interfaces.is_set)

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_list_id.yfilter != YFilter.not_set or
                            self.interface_list_name_xr.yfilter != YFilter.not_set or
                            self.items.yfilter != YFilter.not_set or
                            self.number_of_interfaces.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                        if (self.interface_list_name_xr.is_set or self.interface_list_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_list_name_xr.get_name_leafdata())
                        if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.items.get_name_leafdata())
                        if (self.number_of_interfaces.is_set or self.number_of_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_interfaces.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name-xr" or name == "items" or name == "number-of-interfaces"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-list-id"):
                            self.interface_list_id = value
                            self.interface_list_id.value_namespace = name_space
                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-list-name-xr"):
                            self.interface_list_name_xr = value
                            self.interface_list_name_xr.value_namespace = name_space
                            self.interface_list_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "items"):
                            self.items = value
                            self.items.value_namespace = name_space
                            self.items.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-interfaces"):
                            self.number_of_interfaces = value
                            self.number_of_interfaces.value_namespace = name_space
                            self.number_of_interfaces.value_namespace_prefix = name_space_prefix


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface-list-detail"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                        self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                        self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_fib_downloaded",
                                        "not_supported_replications",
                                        "pending_replications") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.is_fib_downloaded.is_set or
                            self.not_supported_replications.is_set or
                            self.pending_replications.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_fib_downloaded.yfilter != YFilter.not_set or
                            self.not_supported_replications.yfilter != YFilter.not_set or
                            self.pending_replications.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                        if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                        if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pending_replications.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-fib-downloaded"):
                            self.is_fib_downloaded = value
                            self.is_fib_downloaded.value_namespace = name_space
                            self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-replications"):
                            self.not_supported_replications = value
                            self.not_supported_replications.value_namespace = name_space
                            self.not_supported_replications.value_namespace_prefix = name_space_prefix
                        if(value_path == "pending-replications"):
                            self.pending_replications = value
                            self.pending_replications.value_namespace = name_space
                            self.pending_replications.value_namespace_prefix = name_space_prefix


                class PseudowireEtherRange(Entity):
                    """
                    PW\-Ether ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__init__()

                        self.yang_name = "pseudowire-ether-range"
                        self.yang_parent_name = "generic-interface-list-detail"

                        self.lower = YLeaf(YType.uint16, "lower")

                        self.upper = YLeaf(YType.uint16, "upper")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("lower",
                                        "upper") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.lower.is_set or
                            self.upper.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.lower.yfilter != YFilter.not_set or
                            self.upper.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pseudowire-ether-range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lower.get_name_leafdata())
                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.upper.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "lower" or name == "upper"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "lower"):
                            self.lower = value
                            self.lower.value_namespace = name_space
                            self.lower.value_namespace_prefix = name_space_prefix
                        if(value_path == "upper"):
                            self.upper = value
                            self.upper.value_namespace = name_space
                            self.upper.value_namespace_prefix = name_space_prefix


                class PseudowireIwRange(Entity):
                    """
                    PW\-IW ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__init__()

                        self.yang_name = "pseudowire-iw-range"
                        self.yang_parent_name = "generic-interface-list-detail"

                        self.lower = YLeaf(YType.uint16, "lower")

                        self.upper = YLeaf(YType.uint16, "upper")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("lower",
                                        "upper") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.lower.is_set or
                            self.upper.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.lower.yfilter != YFilter.not_set or
                            self.upper.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pseudowire-iw-range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lower.get_name_leafdata())
                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.upper.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "lower" or name == "upper"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "lower"):
                            self.lower = value
                            self.lower.value_namespace = name_space
                            self.lower.value_namespace_prefix = name_space_prefix
                        if(value_path == "upper"):
                            self.upper = value
                            self.upper.value_namespace = name_space
                            self.upper.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    for c in self.pseudowire_ether_range:
                        if (c.has_data()):
                            return True
                    for c in self.pseudowire_iw_range:
                        if (c.has_data()):
                            return True
                    return (
                        self.interface_list_name.is_set or
                        self.is_provisioned.is_set or
                        self.items.is_set or
                        self.psedowire_ether_items.is_set or
                        self.pseudowire_iw_items.is_set or
                        (self.summary is not None and self.summary.has_data()))

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    for c in self.pseudowire_ether_range:
                        if (c.has_operation()):
                            return True
                    for c in self.pseudowire_iw_range:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_list_name.yfilter != YFilter.not_set or
                        self.is_provisioned.yfilter != YFilter.not_set or
                        self.items.yfilter != YFilter.not_set or
                        self.psedowire_ether_items.yfilter != YFilter.not_set or
                        self.pseudowire_iw_items.yfilter != YFilter.not_set or
                        (self.summary is not None and self.summary.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-interface-list-detail" + "[interface-list-name='" + self.interface_list_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/generic-interface-list-details/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                    if (self.is_provisioned.is_set or self.is_provisioned.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_provisioned.get_name_leafdata())
                    if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.items.get_name_leafdata())
                    if (self.psedowire_ether_items.is_set or self.psedowire_ether_items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.psedowire_ether_items.get_name_leafdata())
                    if (self.pseudowire_iw_items.is_set or self.pseudowire_iw_items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pseudowire_iw_items.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    if (child_yang_name == "pseudowire-ether-range"):
                        for c in self.pseudowire_ether_range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.pseudowire_ether_range.append(c)
                        return c

                    if (child_yang_name == "pseudowire-iw-range"):
                        for c in self.pseudowire_iw_range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.pseudowire_iw_range.append(c)
                        return c

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "pseudowire-ether-range" or name == "pseudowire-iw-range" or name == "summary" or name == "interface-list-name" or name == "is-provisioned" or name == "items" or name == "psedowire-ether-items" or name == "pseudowire-iw-items"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-list-name"):
                        self.interface_list_name = value
                        self.interface_list_name.value_namespace = name_space
                        self.interface_list_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-provisioned"):
                        self.is_provisioned = value
                        self.is_provisioned.value_namespace = name_space
                        self.is_provisioned.value_namespace_prefix = name_space_prefix
                    if(value_path == "items"):
                        self.items = value
                        self.items.value_namespace = name_space
                        self.items.value_namespace_prefix = name_space_prefix
                    if(value_path == "psedowire-ether-items"):
                        self.psedowire_ether_items = value
                        self.psedowire_ether_items.value_namespace = name_space
                        self.psedowire_ether_items.value_namespace_prefix = name_space_prefix
                    if(value_path == "pseudowire-iw-items"):
                        self.pseudowire_iw_items = value
                        self.pseudowire_iw_items.value_namespace = name_space
                        self.pseudowire_iw_items.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.generic_interface_list_detail:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.generic_interface_list_detail:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "generic-interface-list-details" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "generic-interface-list-detail"):
                    for c in self.generic_interface_list_detail:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.generic_interface_list_detail.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-interface-list-detail"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class L2VpnResourceState(Entity):
            """
            L2VPN resource state information
            
            .. attribute:: resource_out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.L2VpnResourceState, self).__init__()

                self.yang_name = "l2vpn-resource-state"
                self.yang_parent_name = "standby"

                self.resource_out_of_memory_state = YLeaf(YType.uint32, "resource-out-of-memory-state")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("resource_out_of_memory_state") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.L2VpnResourceState, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.L2VpnResourceState, self).__setattr__(name, value)

            def has_data(self):
                return self.resource_out_of_memory_state.is_set

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.resource_out_of_memory_state.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "l2vpn-resource-state" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.resource_out_of_memory_state.is_set or self.resource_out_of_memory_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.resource_out_of_memory_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "resource-out-of-memory-state"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "resource-out-of-memory-state"):
                    self.resource_out_of_memory_state = value
                    self.resource_out_of_memory_state.value_namespace = name_space
                    self.resource_out_of_memory_state.value_namespace_prefix = name_space_prefix


        class BridgeDomains(Entity):
            """
            VPLS Bridge Domain Information
            
            .. attribute:: bridge_domain
            
            	VPLS Bridge Domain Information
            	**type**\: list of    :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.BridgeDomains, self).__init__()

                self.yang_name = "bridge-domains"
                self.yang_parent_name = "standby"

                self.bridge_domain = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.BridgeDomains, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.BridgeDomains, self).__setattr__(name, value)


            class BridgeDomain(Entity):
                """
                VPLS Bridge Domain Information
                
                .. attribute:: bridge_access_pws
                
                	VPLS Bridge Domain Access Pseudowire Table
                	**type**\:   :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws>`
                
                .. attribute:: bridge_access_vfi_table
                
                	Bridge Domain Access VFI Table
                	**type**\:   :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
                
                .. attribute:: bridge_acs
                
                	VPLS Bridge Domain Attachment Circuit Table
                	**type**\:   :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs>`
                
                .. attribute:: bridge_core_vfi_table
                
                	Bridge Domain Core VFI Table
                	**type**\:   :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
                
                .. attribute:: bridge_domain_group_name
                
                	Bridge Domain Group Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: bridge_domain_info
                
                	VPLS Bridge Domain Information
                	**type**\:   :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
                
                .. attribute:: bridge_domain_name
                
                	Bridge Domain Name
                	**type**\:  str
                
                	**length:** 1..27
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain, self).__init__()

                    self.yang_name = "bridge-domain"
                    self.yang_parent_name = "bridge-domains"

                    self.bridge_domain_group_name = YLeaf(YType.str, "bridge-domain-group-name")

                    self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                    self.bridge_access_pws = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws()
                    self.bridge_access_pws.parent = self
                    self._children_name_map["bridge_access_pws"] = "bridge-access-pws"
                    self._children_yang_names.add("bridge-access-pws")

                    self.bridge_access_vfi_table = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                    self.bridge_access_vfi_table.parent = self
                    self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"
                    self._children_yang_names.add("bridge-access-vfi-table")

                    self.bridge_acs = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs()
                    self.bridge_acs.parent = self
                    self._children_name_map["bridge_acs"] = "bridge-acs"
                    self._children_yang_names.add("bridge-acs")

                    self.bridge_core_vfi_table = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                    self.bridge_core_vfi_table.parent = self
                    self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"
                    self._children_yang_names.add("bridge-core-vfi-table")

                    self.bridge_domain_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                    self.bridge_domain_info.parent = self
                    self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                    self._children_yang_names.add("bridge-domain-info")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bridge_domain_group_name",
                                    "bridge_domain_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain, self).__setattr__(name, value)


                class BridgeAccessVfiTable(Entity):
                    """
                    Bridge Domain Access VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable, self).__init__()

                        self.yang_name = "bridge-access-vfi-table"
                        self.yang_parent_name = "bridge-domain"

                        self.bridge_pws = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                        self.bridge_pws.parent = self
                        self._children_name_map["bridge_pws"] = "bridge-pws"
                        self._children_yang_names.add("bridge-pws")


                    class BridgePws(Entity):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	VPLS Bridge Domain Pseudowire
                        	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__init__()

                            self.yang_name = "bridge-pws"
                            self.yang_parent_name = "bridge-access-vfi-table"

                            self.bridge_pw = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__setattr__(name, value)


                        class BridgePw(Entity):
                            """
                            VPLS Bridge Domain Pseudowire
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:   :py:class:`L2Vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnpw>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__init__()

                                self.yang_name = "bridge-pw"
                                self.yang_parent_name = "bridge-pws"

                                self.is_access = YLeaf(YType.boolean, "is-access")

                                self.neighbor = YLeaf(YType.str, "neighbor")

                                self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                                self.pw_type = YLeaf(YType.enumeration, "pw-type")

                                self.ve_id_vpls_id_0_3 = YLeaf(YType.uint32, "ve-id-vpls-id-0-3")

                                self.vpls_id_4_7 = YLeaf(YType.uint32, "vpls-id-4-7")

                                self.pseudowire = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"
                                self._children_yang_names.add("pseudowire")

                                self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                                self.static_mac = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_access",
                                                "neighbor",
                                                "pseudowire_id",
                                                "pw_type",
                                                "ve_id_vpls_id_0_3",
                                                "vpls_id_4_7") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)


                            class Pseudowire(Entity):
                                """
                                Pseudowire
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\:  bool
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\:  bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\:  bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\:  bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\:  bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\:  bool
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\:  bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\:  bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\:  bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\:  bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\:  bool
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_evpnvpws_type
                                
                                	is EVPN VPWS
                                	**type**\:  bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\:  bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\:  bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\:  bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\:  bool
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\:  bool
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\:  bool
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\:  bool
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\:  bool
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\:  bool
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\:  bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\:  bool
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\:  bool
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\:  bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\:  bool
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\:  bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\:  bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\:  bool
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\:  str
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                    self.yang_name = "pseudowire"
                                    self.yang_parent_name = "bridge-pw"

                                    self.ad_method = YLeaf(YType.uint32, "ad-method")

                                    self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                    self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                    self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                    self.backup_active = YLeaf(YType.boolean, "backup-active")

                                    self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                    self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                    self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                    self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                    self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                    self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                    self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                    self.disable_never = YLeaf(YType.boolean, "disable-never")

                                    self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                    self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                    self.forward_class = YLeaf(YType.uint8, "forward-class")

                                    self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                    self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                    self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                    self.interworking = YLeaf(YType.enumeration, "interworking")

                                    self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                    self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                    self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                    self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                    self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                    self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                    self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                    self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                    self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                    self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                    self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                    self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                    self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                    self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                    self.local_source_address = YLeaf(YType.str, "local-source-address")

                                    self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                    self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                    self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                    self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                    self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                    self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                    self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                    self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                    self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                    self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                    self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                    self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                    self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                    self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                    self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                    self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                    self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                    self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                    self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                    self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                    self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                    self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                    self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                    self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                    self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                    self.required_bw = YLeaf(YType.uint32, "required-bw")

                                    self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                    self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                    self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                    self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                    self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                    self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                    self.time_created = YLeaf(YType.str, "time-created")

                                    self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                    self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                    self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                    self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.encapsulation_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    self._children_yang_names.add("encapsulation-info")

                                    self.local_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                    self._children_yang_names.add("local-interface")

                                    self.local_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                    self._children_yang_names.add("local-signalling")

                                    self.p2mp_pw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    self._children_yang_names.add("p2mp-pw")

                                    self.peer_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                    self._children_yang_names.add("peer-id")

                                    self.preferred_path = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                    self._children_yang_names.add("preferred-path")

                                    self.remote_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                    self._children_yang_names.add("remote-interface")

                                    self.remote_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                    self._children_yang_names.add("remote-signalling")

                                    self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._children_yang_names.add("statistics")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ad_method",
                                                    "ad_remote_down",
                                                    "admited_bw",
                                                    "auto_discovery",
                                                    "backup_active",
                                                    "backup_force_active",
                                                    "backup_pw",
                                                    "bitrate_mismatched",
                                                    "bridge_pw_type_mismatch",
                                                    "cas_mismatched",
                                                    "diff_ts_mismatched",
                                                    "disable_delay",
                                                    "disable_never",
                                                    "evpn_src_acid",
                                                    "fe_ctype",
                                                    "forward_class",
                                                    "freq_mismatched",
                                                    "illegal_control_word",
                                                    "imposed_vlan_id",
                                                    "interworking",
                                                    "ipv6_local_source_address",
                                                    "is_evpnvpws_type",
                                                    "is_flow_label_static",
                                                    "is_multi_segment_pseudowire",
                                                    "is_partially_programmed",
                                                    "is_pwr_type",
                                                    "is_vfi",
                                                    "last_time_status_changed",
                                                    "last_time_status_down",
                                                    "ldp_label_advertise_failed",
                                                    "load_balance",
                                                    "local_control_word",
                                                    "local_label_failed",
                                                    "local_pseudo_wire_type",
                                                    "local_source_address",
                                                    "mac_limit_oper_down",
                                                    "mtu_mismatched",
                                                    "not_supported_qinq",
                                                    "num_ma_cwithdraw_msg_received",
                                                    "number_ma_cwithdraw_message_sent",
                                                    "out_of_memory_state",
                                                    "payload_bytes_mismatched",
                                                    "payload_type_mismatched",
                                                    "preferred_path_disable_fallback",
                                                    "primary_peer_id",
                                                    "primary_pseudo_wire_id",
                                                    "primary_pw",
                                                    "protocol",
                                                    "pseudo_wire_id",
                                                    "pseudo_wire_state",
                                                    "pseudo_wire_type_mismatched",
                                                    "pw_class_name",
                                                    "pw_flow_label_code17_disabled",
                                                    "pw_flow_label_type",
                                                    "pw_flow_label_type_cfg",
                                                    "pw_redundancy_initial_delay",
                                                    "pw_redundancy_one_way",
                                                    "pw_status_use",
                                                    "pwlsd_rewrite_failed",
                                                    "remote_control_word",
                                                    "remote_label_failed",
                                                    "remote_pseudo_wire_type",
                                                    "required_bw",
                                                    "resync_enabled",
                                                    "resync_threshold",
                                                    "rtp_mismatched",
                                                    "sequencing_type",
                                                    "shutdown",
                                                    "sig_pkts_mismatched",
                                                    "ssrc_mismatched",
                                                    "state",
                                                    "table_policy_name",
                                                    "tag_rewrite",
                                                    "time_created",
                                                    "time_elapsed_creation",
                                                    "time_elapsed_status_changed",
                                                    "time_elapsed_status_down",
                                                    "transport_lsp_down",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)


                                class PeerId(Entity):
                                    """
                                    Peer
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                        self.yang_name = "peer-id"
                                        self.yang_parent_name = "pseudowire"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                        self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                        self.type = YLeaf(YType.enumeration, "type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "ipv4_peer_id",
                                                        "ipv6_peer_id",
                                                        "type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.ipv4_peer_id.is_set or
                                            self.ipv6_peer_id.is_set or
                                            self.type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.ipv4_peer_id.yfilter != YFilter.not_set or
                                            self.ipv6_peer_id.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "peer-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                        if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-peer-id"):
                                            self.ipv4_peer_id = value
                                            self.ipv4_peer_id.value_namespace = name_space
                                            self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-peer-id"):
                                            self.ipv6_peer_id = value
                                            self.ipv6_peer_id.value_namespace = name_space
                                            self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix


                                class EncapsulationInfo(Entity):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                        self.yang_name = "encapsulation-info"
                                        self.yang_parent_name = "pseudowire"

                                        self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                        self.atom = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                        self._children_yang_names.add("atom")

                                        self.l2tpv3 = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                        self._children_yang_names.add("l2tpv3")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                    class Atom(Entity):
                                        """
                                        atom
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                            self.yang_name = "atom"
                                            self.yang_parent_name = "encapsulation-info"

                                            self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                            self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                            self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                            self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                            self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                            self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                            self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                            self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                            self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                            self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                            self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                            self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                            self.local_veid = YLeaf(YType.uint32, "local-veid")

                                            self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                            self.rem_saii = YLeaf(YType.str, "rem-saii")

                                            self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                            self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                            self.rem_taii = YLeaf(YType.str, "rem-taii")

                                            self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                            self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                            self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                            self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                            self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                            self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                                            self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                            self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                            self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                            self.saii = YLeaf(YType.str, "saii")

                                            self.source_address = YLeaf(YType.str, "source-address")

                                            self.taii = YLeaf(YType.str, "taii")

                                            self.local_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                            self._children_yang_names.add("local-agi")

                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            self._children_yang_names.add("multi-segment-pseudowire-stats")

                                            self.remote_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                            self._children_yang_names.add("remote-agi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("is_pseudowire_headend",
                                                            "is_sai_itype2",
                                                            "is_tai_itype2",
                                                            "ldp_label_advertisment_failed",
                                                            "local_c_ctype",
                                                            "local_ceid",
                                                            "local_cv_type",
                                                            "local_group_id",
                                                            "local_label",
                                                            "local_ldp_id",
                                                            "local_saii_gbl_id",
                                                            "local_saiiac_id",
                                                            "local_taii_gbl_id",
                                                            "local_taiiac_id",
                                                            "local_veid",
                                                            "lsd_rewrite_failed",
                                                            "rem_saii",
                                                            "rem_saii_gbl_id",
                                                            "rem_saiiac_id",
                                                            "rem_taii",
                                                            "rem_taii_gbl_id",
                                                            "rem_taiiac_id",
                                                            "remote_c_ctype",
                                                            "remote_ceid",
                                                            "remote_cv_type",
                                                            "remote_group_id",
                                                            "remote_label",
                                                            "remote_ldp_id",
                                                            "remote_source_address",
                                                            "remote_veid",
                                                            "saii",
                                                            "source_address",
                                                            "taii") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                        class LocalAgi(Entity):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                self.yang_name = "local-agi"
                                                self.yang_parent_name = "atom"

                                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                                self._children_yang_names.add("auto")

                                                self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                                self._children_yang_names.add("two-byte-as")

                                                self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._children_yang_names.add("v4-addr")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vpls_id_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "local-agi"

                                                    self.asn = YLeaf(YType.uint16, "asn")

                                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("asn",
                                                                    "vpn_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.asn.is_set or
                                                        self.vpn_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.asn.yfilter != YFilter.not_set or
                                                        self.vpn_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "auto" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "asn" or name == "vpn-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "asn"):
                                                        self.asn = value
                                                        self.asn.value_namespace = name_space
                                                        self.asn.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpn-id"):
                                                        self.vpn_id = value
                                                        self.vpn_id.value_namespace = name_space
                                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "local-agi"

                                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("four_byte_index",
                                                                    "two_byte_as") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.four_byte_index.is_set or
                                                        self.two_byte_as.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.four_byte_index.yfilter != YFilter.not_set or
                                                        self.two_byte_as.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "two-byte-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "four-byte-index"):
                                                        self.four_byte_index = value
                                                        self.four_byte_index.value_namespace = name_space
                                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-as"):
                                                        self.two_byte_as = value
                                                        self.two_byte_as.value_namespace = name_space
                                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "local-agi"

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ipv4_address",
                                                                    "two_byte_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ipv4_address.is_set or
                                                        self.two_byte_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ipv4_address.yfilter != YFilter.not_set or
                                                        self.two_byte_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "v4-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ipv4-address"):
                                                        self.ipv4_address = value
                                                        self.ipv4_address.value_namespace = name_space
                                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-index"):
                                                        self.two_byte_index = value
                                                        self.two_byte_index.value_namespace = name_space
                                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.vpls_id_type.is_set or
                                                    (self.auto is not None and self.auto.has_data()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                                    (self.auto is not None and self.auto.has_operation()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "local-agi" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "auto"):
                                                    if (self.auto is None):
                                                        self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                        self.auto.parent = self
                                                        self._children_name_map["auto"] = "auto"
                                                    return self.auto

                                                if (child_yang_name == "two-byte-as"):
                                                    if (self.two_byte_as is None):
                                                        self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                        self.two_byte_as.parent = self
                                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    return self.two_byte_as

                                                if (child_yang_name == "v4-addr"):
                                                    if (self.v4_addr is None):
                                                        self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                        self.v4_addr.parent = self
                                                        self._children_name_map["v4_addr"] = "v4-addr"
                                                    return self.v4_addr

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vpls-id-type"):
                                                    self.vpls_id_type = value
                                                    self.vpls_id_type.value_namespace = name_space
                                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                        class RemoteAgi(Entity):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                self.yang_name = "remote-agi"
                                                self.yang_parent_name = "atom"

                                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                                self._children_yang_names.add("auto")

                                                self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                                self._children_yang_names.add("two-byte-as")

                                                self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._children_yang_names.add("v4-addr")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vpls_id_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.asn = YLeaf(YType.uint16, "asn")

                                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("asn",
                                                                    "vpn_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.asn.is_set or
                                                        self.vpn_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.asn.yfilter != YFilter.not_set or
                                                        self.vpn_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "auto" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "asn" or name == "vpn-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "asn"):
                                                        self.asn = value
                                                        self.asn.value_namespace = name_space
                                                        self.asn.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpn-id"):
                                                        self.vpn_id = value
                                                        self.vpn_id.value_namespace = name_space
                                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("four_byte_index",
                                                                    "two_byte_as") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.four_byte_index.is_set or
                                                        self.two_byte_as.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.four_byte_index.yfilter != YFilter.not_set or
                                                        self.two_byte_as.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "two-byte-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "four-byte-index"):
                                                        self.four_byte_index = value
                                                        self.four_byte_index.value_namespace = name_space
                                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-as"):
                                                        self.two_byte_as = value
                                                        self.two_byte_as.value_namespace = name_space
                                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ipv4_address",
                                                                    "two_byte_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ipv4_address.is_set or
                                                        self.two_byte_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ipv4_address.yfilter != YFilter.not_set or
                                                        self.two_byte_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "v4-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ipv4-address"):
                                                        self.ipv4_address = value
                                                        self.ipv4_address.value_namespace = name_space
                                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-index"):
                                                        self.two_byte_index = value
                                                        self.two_byte_index.value_namespace = name_space
                                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.vpls_id_type.is_set or
                                                    (self.auto is not None and self.auto.has_data()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                                    (self.auto is not None and self.auto.has_operation()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-agi" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "auto"):
                                                    if (self.auto is None):
                                                        self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                        self.auto.parent = self
                                                        self._children_name_map["auto"] = "auto"
                                                    return self.auto

                                                if (child_yang_name == "two-byte-as"):
                                                    if (self.two_byte_as is None):
                                                        self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                        self.two_byte_as.parent = self
                                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    return self.two_byte_as

                                                if (child_yang_name == "v4-addr"):
                                                    if (self.v4_addr is None):
                                                        self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                        self.v4_addr.parent = self
                                                        self._children_name_map["v4_addr"] = "v4-addr"
                                                    return self.v4_addr

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vpls-id-type"):
                                                    self.vpls_id_type = value
                                                    self.vpls_id_type.value_namespace = name_space
                                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                        class MultiSegmentPseudowireStats(Entity):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                self.yang_name = "multi-segment-pseudowire-stats"
                                                self.yang_parent_name = "atom"

                                                self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                                self.received_packets = YLeaf(YType.uint64, "received-packets")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("received_bytes",
                                                                "received_packets") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.received_bytes.is_set or
                                                    self.received_packets.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.received_bytes.yfilter != YFilter.not_set or
                                                    self.received_packets.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                                if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.received_packets.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "received-bytes" or name == "received-packets"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "received-bytes"):
                                                    self.received_bytes = value
                                                    self.received_bytes.value_namespace = name_space
                                                    self.received_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "received-packets"):
                                                    self.received_packets = value
                                                    self.received_packets.value_namespace = name_space
                                                    self.received_packets.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.is_pseudowire_headend.is_set or
                                                self.is_sai_itype2.is_set or
                                                self.is_tai_itype2.is_set or
                                                self.ldp_label_advertisment_failed.is_set or
                                                self.local_c_ctype.is_set or
                                                self.local_ceid.is_set or
                                                self.local_cv_type.is_set or
                                                self.local_group_id.is_set or
                                                self.local_label.is_set or
                                                self.local_ldp_id.is_set or
                                                self.local_saii_gbl_id.is_set or
                                                self.local_saiiac_id.is_set or
                                                self.local_taii_gbl_id.is_set or
                                                self.local_taiiac_id.is_set or
                                                self.local_veid.is_set or
                                                self.lsd_rewrite_failed.is_set or
                                                self.rem_saii.is_set or
                                                self.rem_saii_gbl_id.is_set or
                                                self.rem_saiiac_id.is_set or
                                                self.rem_taii.is_set or
                                                self.rem_taii_gbl_id.is_set or
                                                self.rem_taiiac_id.is_set or
                                                self.remote_c_ctype.is_set or
                                                self.remote_ceid.is_set or
                                                self.remote_cv_type.is_set or
                                                self.remote_group_id.is_set or
                                                self.remote_label.is_set or
                                                self.remote_ldp_id.is_set or
                                                self.remote_source_address.is_set or
                                                self.remote_veid.is_set or
                                                self.saii.is_set or
                                                self.source_address.is_set or
                                                self.taii.is_set or
                                                (self.local_agi is not None and self.local_agi.has_data()) or
                                                (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                                (self.remote_agi is not None and self.remote_agi.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                                self.is_sai_itype2.yfilter != YFilter.not_set or
                                                self.is_tai_itype2.yfilter != YFilter.not_set or
                                                self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                                self.local_c_ctype.yfilter != YFilter.not_set or
                                                self.local_ceid.yfilter != YFilter.not_set or
                                                self.local_cv_type.yfilter != YFilter.not_set or
                                                self.local_group_id.yfilter != YFilter.not_set or
                                                self.local_label.yfilter != YFilter.not_set or
                                                self.local_ldp_id.yfilter != YFilter.not_set or
                                                self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                                self.local_saiiac_id.yfilter != YFilter.not_set or
                                                self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                                self.local_taiiac_id.yfilter != YFilter.not_set or
                                                self.local_veid.yfilter != YFilter.not_set or
                                                self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                                self.rem_saii.yfilter != YFilter.not_set or
                                                self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                                self.rem_saiiac_id.yfilter != YFilter.not_set or
                                                self.rem_taii.yfilter != YFilter.not_set or
                                                self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                                self.rem_taiiac_id.yfilter != YFilter.not_set or
                                                self.remote_c_ctype.yfilter != YFilter.not_set or
                                                self.remote_ceid.yfilter != YFilter.not_set or
                                                self.remote_cv_type.yfilter != YFilter.not_set or
                                                self.remote_group_id.yfilter != YFilter.not_set or
                                                self.remote_label.yfilter != YFilter.not_set or
                                                self.remote_ldp_id.yfilter != YFilter.not_set or
                                                self.remote_source_address.yfilter != YFilter.not_set or
                                                self.remote_veid.yfilter != YFilter.not_set or
                                                self.saii.yfilter != YFilter.not_set or
                                                self.source_address.yfilter != YFilter.not_set or
                                                self.taii.yfilter != YFilter.not_set or
                                                (self.local_agi is not None and self.local_agi.has_operation()) or
                                                (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                                (self.remote_agi is not None and self.remote_agi.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atom" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                            if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                            if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                            if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                            if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                            if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                            if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                            if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_label.get_name_leafdata())
                                            if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                            if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                            if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                            if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                            if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                            if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_veid.get_name_leafdata())
                                            if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                            if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                            if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                            if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                            if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                            if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                            if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                            if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                            if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                            if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                            if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                                            if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                            if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                            if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                            if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.saii.get_name_leafdata())
                                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.source_address.get_name_leafdata())
                                            if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.taii.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "local-agi"):
                                                if (self.local_agi is None):
                                                    self.local_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                    self.local_agi.parent = self
                                                    self._children_name_map["local_agi"] = "local-agi"
                                                return self.local_agi

                                            if (child_yang_name == "multi-segment-pseudowire-stats"):
                                                if (self.multi_segment_pseudowire_stats is None):
                                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                    self.multi_segment_pseudowire_stats.parent = self
                                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                return self.multi_segment_pseudowire_stats

                                            if (child_yang_name == "remote-agi"):
                                                if (self.remote_agi is None):
                                                    self.remote_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                    self.remote_agi.parent = self
                                                    self._children_name_map["remote_agi"] = "remote-agi"
                                                return self.remote_agi

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "is-pseudowire-headend"):
                                                self.is_pseudowire_headend = value
                                                self.is_pseudowire_headend.value_namespace = name_space
                                                self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-sai-itype2"):
                                                self.is_sai_itype2 = value
                                                self.is_sai_itype2.value_namespace = name_space
                                                self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-tai-itype2"):
                                                self.is_tai_itype2 = value
                                                self.is_tai_itype2.value_namespace = name_space
                                                self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ldp-label-advertisment-failed"):
                                                self.ldp_label_advertisment_failed = value
                                                self.ldp_label_advertisment_failed.value_namespace = name_space
                                                self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-c-ctype"):
                                                self.local_c_ctype = value
                                                self.local_c_ctype.value_namespace = name_space
                                                self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ceid"):
                                                self.local_ceid = value
                                                self.local_ceid.value_namespace = name_space
                                                self.local_ceid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cv-type"):
                                                self.local_cv_type = value
                                                self.local_cv_type.value_namespace = name_space
                                                self.local_cv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-group-id"):
                                                self.local_group_id = value
                                                self.local_group_id.value_namespace = name_space
                                                self.local_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-label"):
                                                self.local_label = value
                                                self.local_label.value_namespace = name_space
                                                self.local_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ldp-id"):
                                                self.local_ldp_id = value
                                                self.local_ldp_id.value_namespace = name_space
                                                self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-saii-gbl-id"):
                                                self.local_saii_gbl_id = value
                                                self.local_saii_gbl_id.value_namespace = name_space
                                                self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-saiiac-id"):
                                                self.local_saiiac_id = value
                                                self.local_saiiac_id.value_namespace = name_space
                                                self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-taii-gbl-id"):
                                                self.local_taii_gbl_id = value
                                                self.local_taii_gbl_id.value_namespace = name_space
                                                self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-taiiac-id"):
                                                self.local_taiiac_id = value
                                                self.local_taiiac_id.value_namespace = name_space
                                                self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-veid"):
                                                self.local_veid = value
                                                self.local_veid.value_namespace = name_space
                                                self.local_veid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsd-rewrite-failed"):
                                                self.lsd_rewrite_failed = value
                                                self.lsd_rewrite_failed.value_namespace = name_space
                                                self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saii"):
                                                self.rem_saii = value
                                                self.rem_saii.value_namespace = name_space
                                                self.rem_saii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saii-gbl-id"):
                                                self.rem_saii_gbl_id = value
                                                self.rem_saii_gbl_id.value_namespace = name_space
                                                self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saiiac-id"):
                                                self.rem_saiiac_id = value
                                                self.rem_saiiac_id.value_namespace = name_space
                                                self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taii"):
                                                self.rem_taii = value
                                                self.rem_taii.value_namespace = name_space
                                                self.rem_taii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taii-gbl-id"):
                                                self.rem_taii_gbl_id = value
                                                self.rem_taii_gbl_id.value_namespace = name_space
                                                self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taiiac-id"):
                                                self.rem_taiiac_id = value
                                                self.rem_taiiac_id.value_namespace = name_space
                                                self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-c-ctype"):
                                                self.remote_c_ctype = value
                                                self.remote_c_ctype.value_namespace = name_space
                                                self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ceid"):
                                                self.remote_ceid = value
                                                self.remote_ceid.value_namespace = name_space
                                                self.remote_ceid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cv-type"):
                                                self.remote_cv_type = value
                                                self.remote_cv_type.value_namespace = name_space
                                                self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-group-id"):
                                                self.remote_group_id = value
                                                self.remote_group_id.value_namespace = name_space
                                                self.remote_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-label"):
                                                self.remote_label = value
                                                self.remote_label.value_namespace = name_space
                                                self.remote_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ldp-id"):
                                                self.remote_ldp_id = value
                                                self.remote_ldp_id.value_namespace = name_space
                                                self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-source-address"):
                                                self.remote_source_address = value
                                                self.remote_source_address.value_namespace = name_space
                                                self.remote_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-veid"):
                                                self.remote_veid = value
                                                self.remote_veid.value_namespace = name_space
                                                self.remote_veid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "saii"):
                                                self.saii = value
                                                self.saii.value_namespace = name_space
                                                self.saii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "source-address"):
                                                self.source_address = value
                                                self.source_address.value_namespace = name_space
                                                self.source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "taii"):
                                                self.taii = value
                                                self.taii.value_namespace = name_space
                                                self.taii.value_namespace_prefix = name_space_prefix


                                    class L2Tpv3(Entity):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\:  bool
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\:  str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                            self.yang_name = "l2tpv3"
                                            self.yang_parent_name = "encapsulation-info"

                                            self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                            self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                            self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                            self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                            self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                            self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                            self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                            self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                            self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                            self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                            self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                            self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                            self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                            self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                            self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                            self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                            self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                            self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                            self.tos = YLeaf(YType.uint8, "tos")

                                            self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                            self.ttl = YLeaf(YType.uint8, "ttl")

                                            self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dont_fragment_bit",
                                                            "ipv4_source_address",
                                                            "ipv6_source_address",
                                                            "l2tp_class_name",
                                                            "local_cookie_high_value",
                                                            "local_cookie_low_value",
                                                            "local_cookie_size",
                                                            "local_secondary_cookie_high_value",
                                                            "local_secondary_cookie_low_value",
                                                            "local_secondary_cookie_size",
                                                            "local_session_id",
                                                            "path_mtu_enabled",
                                                            "path_mtu_max_value",
                                                            "remote_circuit_status_up",
                                                            "remote_cookie_high_value",
                                                            "remote_cookie_low_value",
                                                            "remote_cookie_size",
                                                            "remote_session_id",
                                                            "tos",
                                                            "tos_mode",
                                                            "ttl",
                                                            "tunnel_state") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dont_fragment_bit.is_set or
                                                self.ipv4_source_address.is_set or
                                                self.ipv6_source_address.is_set or
                                                self.l2tp_class_name.is_set or
                                                self.local_cookie_high_value.is_set or
                                                self.local_cookie_low_value.is_set or
                                                self.local_cookie_size.is_set or
                                                self.local_secondary_cookie_high_value.is_set or
                                                self.local_secondary_cookie_low_value.is_set or
                                                self.local_secondary_cookie_size.is_set or
                                                self.local_session_id.is_set or
                                                self.path_mtu_enabled.is_set or
                                                self.path_mtu_max_value.is_set or
                                                self.remote_circuit_status_up.is_set or
                                                self.remote_cookie_high_value.is_set or
                                                self.remote_cookie_low_value.is_set or
                                                self.remote_cookie_size.is_set or
                                                self.remote_session_id.is_set or
                                                self.tos.is_set or
                                                self.tos_mode.is_set or
                                                self.ttl.is_set or
                                                self.tunnel_state.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dont_fragment_bit.yfilter != YFilter.not_set or
                                                self.ipv4_source_address.yfilter != YFilter.not_set or
                                                self.ipv6_source_address.yfilter != YFilter.not_set or
                                                self.l2tp_class_name.yfilter != YFilter.not_set or
                                                self.local_cookie_high_value.yfilter != YFilter.not_set or
                                                self.local_cookie_low_value.yfilter != YFilter.not_set or
                                                self.local_cookie_size.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.local_session_id.yfilter != YFilter.not_set or
                                                self.path_mtu_enabled.yfilter != YFilter.not_set or
                                                self.path_mtu_max_value.yfilter != YFilter.not_set or
                                                self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                                self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                                self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                                self.remote_cookie_size.yfilter != YFilter.not_set or
                                                self.remote_session_id.yfilter != YFilter.not_set or
                                                self.tos.yfilter != YFilter.not_set or
                                                self.tos_mode.yfilter != YFilter.not_set or
                                                self.ttl.yfilter != YFilter.not_set or
                                                self.tunnel_state.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2tpv3" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                            if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                            if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                            if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                            if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                            if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                            if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                            if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                            if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                            if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                            if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                            if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                            if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                            if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                            if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                            if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                            if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                            if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                            if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos.get_name_leafdata())
                                            if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                            if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ttl.get_name_leafdata())
                                            if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dont-fragment-bit"):
                                                self.dont_fragment_bit = value
                                                self.dont_fragment_bit.value_namespace = name_space
                                                self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-source-address"):
                                                self.ipv4_source_address = value
                                                self.ipv4_source_address.value_namespace = name_space
                                                self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-source-address"):
                                                self.ipv6_source_address = value
                                                self.ipv6_source_address.value_namespace = name_space
                                                self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "l2tp-class-name"):
                                                self.l2tp_class_name = value
                                                self.l2tp_class_name.value_namespace = name_space
                                                self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-high-value"):
                                                self.local_cookie_high_value = value
                                                self.local_cookie_high_value.value_namespace = name_space
                                                self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-low-value"):
                                                self.local_cookie_low_value = value
                                                self.local_cookie_low_value.value_namespace = name_space
                                                self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-size"):
                                                self.local_cookie_size = value
                                                self.local_cookie_size.value_namespace = name_space
                                                self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-high-value"):
                                                self.local_secondary_cookie_high_value = value
                                                self.local_secondary_cookie_high_value.value_namespace = name_space
                                                self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-low-value"):
                                                self.local_secondary_cookie_low_value = value
                                                self.local_secondary_cookie_low_value.value_namespace = name_space
                                                self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-size"):
                                                self.local_secondary_cookie_size = value
                                                self.local_secondary_cookie_size.value_namespace = name_space
                                                self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-session-id"):
                                                self.local_session_id = value
                                                self.local_session_id.value_namespace = name_space
                                                self.local_session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "path-mtu-enabled"):
                                                self.path_mtu_enabled = value
                                                self.path_mtu_enabled.value_namespace = name_space
                                                self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "path-mtu-max-value"):
                                                self.path_mtu_max_value = value
                                                self.path_mtu_max_value.value_namespace = name_space
                                                self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-circuit-status-up"):
                                                self.remote_circuit_status_up = value
                                                self.remote_circuit_status_up.value_namespace = name_space
                                                self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-high-value"):
                                                self.remote_cookie_high_value = value
                                                self.remote_cookie_high_value.value_namespace = name_space
                                                self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-low-value"):
                                                self.remote_cookie_low_value = value
                                                self.remote_cookie_low_value.value_namespace = name_space
                                                self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-size"):
                                                self.remote_cookie_size = value
                                                self.remote_cookie_size.value_namespace = name_space
                                                self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-session-id"):
                                                self.remote_session_id = value
                                                self.remote_session_id.value_namespace = name_space
                                                self.remote_session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos"):
                                                self.tos = value
                                                self.tos.value_namespace = name_space
                                                self.tos.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos-mode"):
                                                self.tos_mode = value
                                                self.tos_mode.value_namespace = name_space
                                                self.tos_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ttl"):
                                                self.ttl = value
                                                self.ttl.value_namespace = name_space
                                                self.ttl.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-state"):
                                                self.tunnel_state = value
                                                self.tunnel_state.value_namespace = name_space
                                                self.tunnel_state.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.encapsulation.is_set or
                                            (self.atom is not None and self.atom.has_data()) or
                                            (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation.yfilter != YFilter.not_set or
                                            (self.atom is not None and self.atom.has_operation()) or
                                            (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "encapsulation-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atom"):
                                            if (self.atom is None):
                                                self.atom = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                                self.atom.parent = self
                                                self._children_name_map["atom"] = "atom"
                                            return self.atom

                                        if (child_yang_name == "l2tpv3"):
                                            if (self.l2tpv3 is None):
                                                self.l2tpv3 = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                                self.l2tpv3.parent = self
                                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                            return self.l2tpv3

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation"):
                                            self.encapsulation = value
                                            self.encapsulation.value_namespace = name_space
                                            self.encapsulation.value_namespace_prefix = name_space_prefix


                                class LocalInterface(Entity):
                                    """
                                    Local interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                        self.yang_name = "local-interface"
                                        self.yang_parent_name = "pseudowire"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "local-interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class RemoteInterface(Entity):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                        self.yang_name = "remote-interface"
                                        self.yang_parent_name = "pseudowire"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "remote-interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class PreferredPath(Entity):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                        self.yang_name = "preferred-path"
                                        self.yang_parent_name = "pseudowire"

                                        self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                        self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                        self.option = YLeaf(YType.enumeration, "option")

                                        self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                        self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ip_tunnel_interface_number",
                                                        "next_hop_ip",
                                                        "option",
                                                        "te_tunnel_interface_number",
                                                        "tp_tunnel_interface_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ip_tunnel_interface_number.is_set or
                                            self.next_hop_ip.is_set or
                                            self.option.is_set or
                                            self.te_tunnel_interface_number.is_set or
                                            self.tp_tunnel_interface_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                            self.next_hop_ip.yfilter != YFilter.not_set or
                                            self.option.yfilter != YFilter.not_set or
                                            self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                            self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "preferred-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                        if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.option.get_name_leafdata())
                                        if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                        if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ip-tunnel-interface-number"):
                                            self.ip_tunnel_interface_number = value
                                            self.ip_tunnel_interface_number.value_namespace = name_space
                                            self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop-ip"):
                                            self.next_hop_ip = value
                                            self.next_hop_ip.value_namespace = name_space
                                            self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                        if(value_path == "option"):
                                            self.option = value
                                            self.option.value_namespace = name_space
                                            self.option.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-tunnel-interface-number"):
                                            self.te_tunnel_interface_number = value
                                            self.te_tunnel_interface_number.value_namespace = name_space
                                            self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tp-tunnel-interface-number"):
                                            self.tp_tunnel_interface_number = value
                                            self.tp_tunnel_interface_number.value_namespace = name_space
                                            self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                                class LocalSignalling(Entity):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                        self.yang_name = "local-signalling"
                                        self.yang_parent_name = "pseudowire"

                                        self.pw_status = YLeaf(YType.uint32, "pw-status")

                                        self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                        self._children_yang_names.add("status-tlv")

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "local-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "status-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "local-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.pw_status.is_set or
                                            (self.status_tlv is not None and self.status_tlv.has_data()))

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_status.yfilter != YFilter.not_set or
                                            (self.status_tlv is not None and self.status_tlv.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-signalling" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "status-tlv"):
                                            if (self.status_tlv is None):
                                                self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                                self.status_tlv.parent = self
                                                self._children_name_map["status_tlv"] = "status-tlv"
                                            return self.status_tlv

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-status"):
                                            self.pw_status = value
                                            self.pw_status.value_namespace = name_space
                                            self.pw_status.value_namespace_prefix = name_space_prefix


                                class RemoteSignalling(Entity):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                        self.yang_name = "remote-signalling"
                                        self.yang_parent_name = "pseudowire"

                                        self.pw_status = YLeaf(YType.uint32, "pw-status")

                                        self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                        self._children_yang_names.add("status-tlv")

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "remote-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "status-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "remote-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.pw_status.is_set or
                                            (self.status_tlv is not None and self.status_tlv.has_data()))

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_status.yfilter != YFilter.not_set or
                                            (self.status_tlv is not None and self.status_tlv.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-signalling" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "status-tlv"):
                                            if (self.status_tlv is None):
                                                self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                                self.status_tlv.parent = self
                                                self._children_name_map["status_tlv"] = "status-tlv"
                                            return self.status_tlv

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-status"):
                                            self.pw_status = value
                                            self.pw_status.value_namespace = name_space
                                            self.pw_status.value_namespace_prefix = name_space_prefix


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "pseudowire"

                                        self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        self._children_yang_names.add("dispostion-stats")

                                        self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                        self._children_yang_names.add("impostion-stats")

                                        self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._children_yang_names.add("sequence-number")


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                            self._children_yang_names.add("broadcast")

                                            self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            self._children_yang_names.add("imposition-mtu-drop")

                                            self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                            self._children_yang_names.add("imposition-stat")

                                            self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            self._children_yang_names.add("impostion-tail-drop")

                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            self._children_yang_names.add("l2fsbi-drop")

                                            self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                            self._children_yang_names.add("multicast")

                                            self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._children_yang_names.add("unknown-unicast")


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class L2FsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2fsbi-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast is not None and self.broadcast.has_data()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                (self.multicast is not None and self.multicast.has_data()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast is not None and self.broadcast.has_operation()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                (self.multicast is not None and self.multicast.has_operation()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast"):
                                                if (self.broadcast is None):
                                                    self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                    self.broadcast.parent = self
                                                    self._children_name_map["broadcast"] = "broadcast"
                                                return self.broadcast

                                            if (child_yang_name == "imposition-mtu-drop"):
                                                if (self.imposition_mtu_drop is None):
                                                    self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                    self.imposition_mtu_drop.parent = self
                                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                return self.imposition_mtu_drop

                                            if (child_yang_name == "imposition-stat"):
                                                if (self.imposition_stat is None):
                                                    self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                    self.imposition_stat.parent = self
                                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                                return self.imposition_stat

                                            if (child_yang_name == "impostion-tail-drop"):
                                                if (self.impostion_tail_drop is None):
                                                    self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                    self.impostion_tail_drop.parent = self
                                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                return self.impostion_tail_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "l2fsbi-drop"):
                                                if (self.l2fsbi_drop is None):
                                                    self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                    self.l2fsbi_drop.parent = self
                                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                return self.l2fsbi_drop

                                            if (child_yang_name == "multicast"):
                                                if (self.multicast is None):
                                                    self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                    self.multicast.parent = self
                                                    self._children_name_map["multicast"] = "multicast"
                                                return self.multicast

                                            if (child_yang_name == "unknown-unicast"):
                                                if (self.unknown_unicast is None):
                                                    self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                    self.unknown_unicast.parent = self
                                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                return self.unknown_unicast

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            self._children_yang_names.add("broadcast-drop")

                                            self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                            self._children_yang_names.add("dai-drop")

                                            self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            self._children_yang_names.add("disposition-mtu-drop")

                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            self._children_yang_names.add("disposition-oo-o-drops")

                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            self._children_yang_names.add("disposition-p2mp-stats")

                                            self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                            self._children_yang_names.add("disposition-stat")

                                            self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            self._children_yang_names.add("disposition-tail-drop")

                                            self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            self._children_yang_names.add("ipsg-drop")

                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._children_yang_names.add("mac-move")

                                            self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                            self._children_yang_names.add("multicast-drop")

                                            self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                            self._children_yang_names.add("received-drops")

                                            self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                            self._children_yang_names.add("unicast-drop")


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "received-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dai-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipsg-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-oo-o-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionP2MpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-p2mp-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mac-move" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.mac_move is not None and self.mac_move.has_data()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                (self.received_drops is not None and self.received_drops.has_data()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.mac_move is not None and self.mac_move.has_operation()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                (self.received_drops is not None and self.received_drops.has_operation()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dispostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast-drop"):
                                                if (self.broadcast_drop is None):
                                                    self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                    self.broadcast_drop.parent = self
                                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                return self.broadcast_drop

                                            if (child_yang_name == "dai-drop"):
                                                if (self.dai_drop is None):
                                                    self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                    self.dai_drop.parent = self
                                                    self._children_name_map["dai_drop"] = "dai-drop"
                                                return self.dai_drop

                                            if (child_yang_name == "disposition-mtu-drop"):
                                                if (self.disposition_mtu_drop is None):
                                                    self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                    self.disposition_mtu_drop.parent = self
                                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                return self.disposition_mtu_drop

                                            if (child_yang_name == "disposition-oo-o-drops"):
                                                if (self.disposition_oo_o_drops is None):
                                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                    self.disposition_oo_o_drops.parent = self
                                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                return self.disposition_oo_o_drops

                                            if (child_yang_name == "disposition-p2mp-stats"):
                                                if (self.disposition_p2mp_stats is None):
                                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                    self.disposition_p2mp_stats.parent = self
                                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                return self.disposition_p2mp_stats

                                            if (child_yang_name == "disposition-stat"):
                                                if (self.disposition_stat is None):
                                                    self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                    self.disposition_stat.parent = self
                                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                                return self.disposition_stat

                                            if (child_yang_name == "disposition-tail-drop"):
                                                if (self.disposition_tail_drop is None):
                                                    self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                    self.disposition_tail_drop.parent = self
                                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                return self.disposition_tail_drop

                                            if (child_yang_name == "ipsg-drop"):
                                                if (self.ipsg_drop is None):
                                                    self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                    self.ipsg_drop.parent = self
                                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                return self.ipsg_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "mac-move"):
                                                if (self.mac_move is None):
                                                    self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                    self.mac_move.parent = self
                                                    self._children_name_map["mac_move"] = "mac-move"
                                                return self.mac_move

                                            if (child_yang_name == "multicast-drop"):
                                                if (self.multicast_drop is None):
                                                    self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                    self.multicast_drop.parent = self
                                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                                return self.multicast_drop

                                            if (child_yang_name == "received-drops"):
                                                if (self.received_drops is None):
                                                    self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                    self.received_drops.parent = self
                                                    self._children_name_map["received_drops"] = "received-drops"
                                                return self.received_drops

                                            if (child_yang_name == "unicast-drop"):
                                                if (self.unicast_drop is None):
                                                    self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                    self.unicast_drop.parent = self
                                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                                return self.unicast_drop

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"

                                            self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                            self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                            self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                            self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bypassed_inbound_sequence_packet",
                                                            "bypassed_out_sequence_packet",
                                                            "sequence_number_expected",
                                                            "sequence_number_sent") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bypassed_inbound_sequence_packet.is_set or
                                                self.bypassed_out_sequence_packet.is_set or
                                                self.sequence_number_expected.is_set or
                                                self.sequence_number_sent.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                self.sequence_number_expected.yfilter != YFilter.not_set or
                                                self.sequence_number_sent.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sequence-number" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                            if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                            if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                            if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bypassed-inbound-sequence-packet"):
                                                self.bypassed_inbound_sequence_packet = value
                                                self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bypassed-out-sequence-packet"):
                                                self.bypassed_out_sequence_packet = value
                                                self.bypassed_out_sequence_packet.value_namespace = name_space
                                                self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-expected"):
                                                self.sequence_number_expected = value
                                                self.sequence_number_expected.value_namespace = name_space
                                                self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-sent"):
                                                self.sequence_number_sent = value
                                                self.sequence_number_sent.value_namespace = name_space
                                                self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                            (self.sequence_number is not None and self.sequence_number.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                            (self.sequence_number is not None and self.sequence_number.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "statistics" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dispostion-stats"):
                                            if (self.dispostion_stats is None):
                                                self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                                self.dispostion_stats.parent = self
                                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            return self.dispostion_stats

                                        if (child_yang_name == "impostion-stats"):
                                            if (self.impostion_stats is None):
                                                self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                                self.impostion_stats.parent = self
                                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                            return self.impostion_stats

                                        if (child_yang_name == "sequence-number"):
                                            if (self.sequence_number is None):
                                                self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                                self.sequence_number.parent = self
                                                self._children_name_map["sequence_number"] = "sequence-number"
                                            return self.sequence_number

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class P2MpPw(Entity):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__init__()

                                        self.yang_name = "p2mp-pw"
                                        self.yang_parent_name = "pseudowire"

                                        self.local_available = YLeaf(YType.boolean, "local-available")

                                        self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                        self.local_flags = YLeaf(YType.uint8, "local-flags")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                        self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                        self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                        self.remote_available = YLeaf(YType.boolean, "remote-available")

                                        self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                        self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                        self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                        self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_available",
                                                        "local_extended_tunnel_id",
                                                        "local_flags",
                                                        "local_label",
                                                        "local_p2mp_id",
                                                        "local_ptree_type",
                                                        "local_tunnel_id",
                                                        "remote_available",
                                                        "remote_extended_tunnel_id",
                                                        "remote_flags",
                                                        "remote_label",
                                                        "remote_p2mp_id",
                                                        "remote_ptree_type",
                                                        "remote_tunnel_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_available.is_set or
                                            self.local_extended_tunnel_id.is_set or
                                            self.local_flags.is_set or
                                            self.local_label.is_set or
                                            self.local_p2mp_id.is_set or
                                            self.local_ptree_type.is_set or
                                            self.local_tunnel_id.is_set or
                                            self.remote_available.is_set or
                                            self.remote_extended_tunnel_id.is_set or
                                            self.remote_flags.is_set or
                                            self.remote_label.is_set or
                                            self.remote_p2mp_id.is_set or
                                            self.remote_ptree_type.is_set or
                                            self.remote_tunnel_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_available.yfilter != YFilter.not_set or
                                            self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                            self.local_flags.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_p2mp_id.yfilter != YFilter.not_set or
                                            self.local_ptree_type.yfilter != YFilter.not_set or
                                            self.local_tunnel_id.yfilter != YFilter.not_set or
                                            self.remote_available.yfilter != YFilter.not_set or
                                            self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                            self.remote_flags.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_p2mp_id.yfilter != YFilter.not_set or
                                            self.remote_ptree_type.yfilter != YFilter.not_set or
                                            self.remote_tunnel_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "p2mp-pw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_available.get_name_leafdata())
                                        if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                        if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_flags.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                        if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                        if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                        if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_available.get_name_leafdata())
                                        if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                        if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                        if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                        if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-available"):
                                            self.local_available = value
                                            self.local_available.value_namespace = name_space
                                            self.local_available.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-extended-tunnel-id"):
                                            self.local_extended_tunnel_id = value
                                            self.local_extended_tunnel_id.value_namespace = name_space
                                            self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-flags"):
                                            self.local_flags = value
                                            self.local_flags.value_namespace = name_space
                                            self.local_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-p2mp-id"):
                                            self.local_p2mp_id = value
                                            self.local_p2mp_id.value_namespace = name_space
                                            self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ptree-type"):
                                            self.local_ptree_type = value
                                            self.local_ptree_type.value_namespace = name_space
                                            self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-tunnel-id"):
                                            self.local_tunnel_id = value
                                            self.local_tunnel_id.value_namespace = name_space
                                            self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-available"):
                                            self.remote_available = value
                                            self.remote_available.value_namespace = name_space
                                            self.remote_available.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-extended-tunnel-id"):
                                            self.remote_extended_tunnel_id = value
                                            self.remote_extended_tunnel_id.value_namespace = name_space
                                            self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-flags"):
                                            self.remote_flags = value
                                            self.remote_flags.value_namespace = name_space
                                            self.remote_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-p2mp-id"):
                                            self.remote_p2mp_id = value
                                            self.remote_p2mp_id.value_namespace = name_space
                                            self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ptree-type"):
                                            self.remote_ptree_type = value
                                            self.remote_ptree_type.value_namespace = name_space
                                            self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-tunnel-id"):
                                            self.remote_tunnel_id = value
                                            self.remote_tunnel_id.value_namespace = name_space
                                            self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.ad_method.is_set or
                                        self.ad_remote_down.is_set or
                                        self.admited_bw.is_set or
                                        self.auto_discovery.is_set or
                                        self.backup_active.is_set or
                                        self.backup_force_active.is_set or
                                        self.backup_pw.is_set or
                                        self.bitrate_mismatched.is_set or
                                        self.bridge_pw_type_mismatch.is_set or
                                        self.cas_mismatched.is_set or
                                        self.diff_ts_mismatched.is_set or
                                        self.disable_delay.is_set or
                                        self.disable_never.is_set or
                                        self.evpn_src_acid.is_set or
                                        self.fe_ctype.is_set or
                                        self.forward_class.is_set or
                                        self.freq_mismatched.is_set or
                                        self.illegal_control_word.is_set or
                                        self.imposed_vlan_id.is_set or
                                        self.interworking.is_set or
                                        self.ipv6_local_source_address.is_set or
                                        self.is_evpnvpws_type.is_set or
                                        self.is_flow_label_static.is_set or
                                        self.is_multi_segment_pseudowire.is_set or
                                        self.is_partially_programmed.is_set or
                                        self.is_pwr_type.is_set or
                                        self.is_vfi.is_set or
                                        self.last_time_status_changed.is_set or
                                        self.last_time_status_down.is_set or
                                        self.ldp_label_advertise_failed.is_set or
                                        self.load_balance.is_set or
                                        self.local_control_word.is_set or
                                        self.local_label_failed.is_set or
                                        self.local_pseudo_wire_type.is_set or
                                        self.local_source_address.is_set or
                                        self.mac_limit_oper_down.is_set or
                                        self.mtu_mismatched.is_set or
                                        self.not_supported_qinq.is_set or
                                        self.num_ma_cwithdraw_msg_received.is_set or
                                        self.number_ma_cwithdraw_message_sent.is_set or
                                        self.out_of_memory_state.is_set or
                                        self.payload_bytes_mismatched.is_set or
                                        self.payload_type_mismatched.is_set or
                                        self.preferred_path_disable_fallback.is_set or
                                        self.primary_peer_id.is_set or
                                        self.primary_pseudo_wire_id.is_set or
                                        self.primary_pw.is_set or
                                        self.protocol.is_set or
                                        self.pseudo_wire_id.is_set or
                                        self.pseudo_wire_state.is_set or
                                        self.pseudo_wire_type_mismatched.is_set or
                                        self.pw_class_name.is_set or
                                        self.pw_flow_label_code17_disabled.is_set or
                                        self.pw_flow_label_type.is_set or
                                        self.pw_flow_label_type_cfg.is_set or
                                        self.pw_redundancy_initial_delay.is_set or
                                        self.pw_redundancy_one_way.is_set or
                                        self.pw_status_use.is_set or
                                        self.pwlsd_rewrite_failed.is_set or
                                        self.remote_control_word.is_set or
                                        self.remote_label_failed.is_set or
                                        self.remote_pseudo_wire_type.is_set or
                                        self.required_bw.is_set or
                                        self.resync_enabled.is_set or
                                        self.resync_threshold.is_set or
                                        self.rtp_mismatched.is_set or
                                        self.sequencing_type.is_set or
                                        self.shutdown.is_set or
                                        self.sig_pkts_mismatched.is_set or
                                        self.ssrc_mismatched.is_set or
                                        self.state.is_set or
                                        self.table_policy_name.is_set or
                                        self.tag_rewrite.is_set or
                                        self.time_created.is_set or
                                        self.time_elapsed_creation.is_set or
                                        self.time_elapsed_status_changed.is_set or
                                        self.time_elapsed_status_down.is_set or
                                        self.transport_lsp_down.is_set or
                                        self.xconnect_id.is_set or
                                        (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                        (self.local_interface is not None and self.local_interface.has_data()) or
                                        (self.local_signalling is not None and self.local_signalling.has_data()) or
                                        (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                        (self.peer_id is not None and self.peer_id.has_data()) or
                                        (self.preferred_path is not None and self.preferred_path.has_data()) or
                                        (self.remote_interface is not None and self.remote_interface.has_data()) or
                                        (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                        (self.statistics is not None and self.statistics.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ad_method.yfilter != YFilter.not_set or
                                        self.ad_remote_down.yfilter != YFilter.not_set or
                                        self.admited_bw.yfilter != YFilter.not_set or
                                        self.auto_discovery.yfilter != YFilter.not_set or
                                        self.backup_active.yfilter != YFilter.not_set or
                                        self.backup_force_active.yfilter != YFilter.not_set or
                                        self.backup_pw.yfilter != YFilter.not_set or
                                        self.bitrate_mismatched.yfilter != YFilter.not_set or
                                        self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                        self.cas_mismatched.yfilter != YFilter.not_set or
                                        self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                        self.disable_delay.yfilter != YFilter.not_set or
                                        self.disable_never.yfilter != YFilter.not_set or
                                        self.evpn_src_acid.yfilter != YFilter.not_set or
                                        self.fe_ctype.yfilter != YFilter.not_set or
                                        self.forward_class.yfilter != YFilter.not_set or
                                        self.freq_mismatched.yfilter != YFilter.not_set or
                                        self.illegal_control_word.yfilter != YFilter.not_set or
                                        self.imposed_vlan_id.yfilter != YFilter.not_set or
                                        self.interworking.yfilter != YFilter.not_set or
                                        self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                        self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                        self.is_flow_label_static.yfilter != YFilter.not_set or
                                        self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                        self.is_partially_programmed.yfilter != YFilter.not_set or
                                        self.is_pwr_type.yfilter != YFilter.not_set or
                                        self.is_vfi.yfilter != YFilter.not_set or
                                        self.last_time_status_changed.yfilter != YFilter.not_set or
                                        self.last_time_status_down.yfilter != YFilter.not_set or
                                        self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                        self.load_balance.yfilter != YFilter.not_set or
                                        self.local_control_word.yfilter != YFilter.not_set or
                                        self.local_label_failed.yfilter != YFilter.not_set or
                                        self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                        self.local_source_address.yfilter != YFilter.not_set or
                                        self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                        self.mtu_mismatched.yfilter != YFilter.not_set or
                                        self.not_supported_qinq.yfilter != YFilter.not_set or
                                        self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                        self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                        self.out_of_memory_state.yfilter != YFilter.not_set or
                                        self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                        self.payload_type_mismatched.yfilter != YFilter.not_set or
                                        self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                        self.primary_peer_id.yfilter != YFilter.not_set or
                                        self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.primary_pw.yfilter != YFilter.not_set or
                                        self.protocol.yfilter != YFilter.not_set or
                                        self.pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.pseudo_wire_state.yfilter != YFilter.not_set or
                                        self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                        self.pw_class_name.yfilter != YFilter.not_set or
                                        self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                        self.pw_flow_label_type.yfilter != YFilter.not_set or
                                        self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                        self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                        self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                        self.pw_status_use.yfilter != YFilter.not_set or
                                        self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.remote_control_word.yfilter != YFilter.not_set or
                                        self.remote_label_failed.yfilter != YFilter.not_set or
                                        self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                        self.required_bw.yfilter != YFilter.not_set or
                                        self.resync_enabled.yfilter != YFilter.not_set or
                                        self.resync_threshold.yfilter != YFilter.not_set or
                                        self.rtp_mismatched.yfilter != YFilter.not_set or
                                        self.sequencing_type.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                        self.ssrc_mismatched.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.table_policy_name.yfilter != YFilter.not_set or
                                        self.tag_rewrite.yfilter != YFilter.not_set or
                                        self.time_created.yfilter != YFilter.not_set or
                                        self.time_elapsed_creation.yfilter != YFilter.not_set or
                                        self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                        self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                        self.transport_lsp_down.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                        (self.local_interface is not None and self.local_interface.has_operation()) or
                                        (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                        (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                        (self.peer_id is not None and self.peer_id.has_operation()) or
                                        (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                        (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                        (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                        (self.statistics is not None and self.statistics.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_method.get_name_leafdata())
                                    if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                    if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                    if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                    if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_active.get_name_leafdata())
                                    if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                    if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                    if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                    if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                    if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                    if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                    if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                    if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_never.get_name_leafdata())
                                    if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                    if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                    if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.forward_class.get_name_leafdata())
                                    if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                    if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                    if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                    if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interworking.get_name_leafdata())
                                    if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                    if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                    if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                    if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                    if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                    if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                    if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                    if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                    if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                    if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                    if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.load_balance.get_name_leafdata())
                                    if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                    if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                    if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                    if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                    if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                    if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                    if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                    if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                    if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                    if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                    if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                    if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                    if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                    if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                    if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                    if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol.get_name_leafdata())
                                    if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                    if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                    if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                    if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                    if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                    if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                    if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                    if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                    if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                    if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                    if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                    if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                    if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                    if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                    if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.required_bw.get_name_leafdata())
                                    if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                    if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                    if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                    if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                    if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                    if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                    if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_created.get_name_leafdata())
                                    if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                    if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                    if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                    if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "encapsulation-info"):
                                        if (self.encapsulation_info is None):
                                            self.encapsulation_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                            self.encapsulation_info.parent = self
                                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                        return self.encapsulation_info

                                    if (child_yang_name == "local-interface"):
                                        if (self.local_interface is None):
                                            self.local_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                            self.local_interface.parent = self
                                            self._children_name_map["local_interface"] = "local-interface"
                                        return self.local_interface

                                    if (child_yang_name == "local-signalling"):
                                        if (self.local_signalling is None):
                                            self.local_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                            self.local_signalling.parent = self
                                            self._children_name_map["local_signalling"] = "local-signalling"
                                        return self.local_signalling

                                    if (child_yang_name == "p2mp-pw"):
                                        if (self.p2mp_pw is None):
                                            self.p2mp_pw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                            self.p2mp_pw.parent = self
                                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                        return self.p2mp_pw

                                    if (child_yang_name == "peer-id"):
                                        if (self.peer_id is None):
                                            self.peer_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                            self.peer_id.parent = self
                                            self._children_name_map["peer_id"] = "peer-id"
                                        return self.peer_id

                                    if (child_yang_name == "preferred-path"):
                                        if (self.preferred_path is None):
                                            self.preferred_path = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                            self.preferred_path.parent = self
                                            self._children_name_map["preferred_path"] = "preferred-path"
                                        return self.preferred_path

                                    if (child_yang_name == "remote-interface"):
                                        if (self.remote_interface is None):
                                            self.remote_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                            self.remote_interface.parent = self
                                            self._children_name_map["remote_interface"] = "remote-interface"
                                        return self.remote_interface

                                    if (child_yang_name == "remote-signalling"):
                                        if (self.remote_signalling is None):
                                            self.remote_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                            self.remote_signalling.parent = self
                                            self._children_name_map["remote_signalling"] = "remote-signalling"
                                        return self.remote_signalling

                                    if (child_yang_name == "statistics"):
                                        if (self.statistics is None):
                                            self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                            self.statistics.parent = self
                                            self._children_name_map["statistics"] = "statistics"
                                        return self.statistics

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ad-method"):
                                        self.ad_method = value
                                        self.ad_method.value_namespace = name_space
                                        self.ad_method.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ad-remote-down"):
                                        self.ad_remote_down = value
                                        self.ad_remote_down.value_namespace = name_space
                                        self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "admited-bw"):
                                        self.admited_bw = value
                                        self.admited_bw.value_namespace = name_space
                                        self.admited_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "auto-discovery"):
                                        self.auto_discovery = value
                                        self.auto_discovery.value_namespace = name_space
                                        self.auto_discovery.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-active"):
                                        self.backup_active = value
                                        self.backup_active.value_namespace = name_space
                                        self.backup_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-force-active"):
                                        self.backup_force_active = value
                                        self.backup_force_active.value_namespace = name_space
                                        self.backup_force_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pw"):
                                        self.backup_pw = value
                                        self.backup_pw.value_namespace = name_space
                                        self.backup_pw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bitrate-mismatched"):
                                        self.bitrate_mismatched = value
                                        self.bitrate_mismatched.value_namespace = name_space
                                        self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bridge-pw-type-mismatch"):
                                        self.bridge_pw_type_mismatch = value
                                        self.bridge_pw_type_mismatch.value_namespace = name_space
                                        self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cas-mismatched"):
                                        self.cas_mismatched = value
                                        self.cas_mismatched.value_namespace = name_space
                                        self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "diff-ts-mismatched"):
                                        self.diff_ts_mismatched = value
                                        self.diff_ts_mismatched.value_namespace = name_space
                                        self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-delay"):
                                        self.disable_delay = value
                                        self.disable_delay.value_namespace = name_space
                                        self.disable_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-never"):
                                        self.disable_never = value
                                        self.disable_never.value_namespace = name_space
                                        self.disable_never.value_namespace_prefix = name_space_prefix
                                    if(value_path == "evpn-src-acid"):
                                        self.evpn_src_acid = value
                                        self.evpn_src_acid.value_namespace = name_space
                                        self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fe-ctype"):
                                        self.fe_ctype = value
                                        self.fe_ctype.value_namespace = name_space
                                        self.fe_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "forward-class"):
                                        self.forward_class = value
                                        self.forward_class.value_namespace = name_space
                                        self.forward_class.value_namespace_prefix = name_space_prefix
                                    if(value_path == "freq-mismatched"):
                                        self.freq_mismatched = value
                                        self.freq_mismatched.value_namespace = name_space
                                        self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "illegal-control-word"):
                                        self.illegal_control_word = value
                                        self.illegal_control_word.value_namespace = name_space
                                        self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "imposed-vlan-id"):
                                        self.imposed_vlan_id = value
                                        self.imposed_vlan_id.value_namespace = name_space
                                        self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interworking"):
                                        self.interworking = value
                                        self.interworking.value_namespace = name_space
                                        self.interworking.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-local-source-address"):
                                        self.ipv6_local_source_address = value
                                        self.ipv6_local_source_address.value_namespace = name_space
                                        self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-evpnvpws-type"):
                                        self.is_evpnvpws_type = value
                                        self.is_evpnvpws_type.value_namespace = name_space
                                        self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-flow-label-static"):
                                        self.is_flow_label_static = value
                                        self.is_flow_label_static.value_namespace = name_space
                                        self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-multi-segment-pseudowire"):
                                        self.is_multi_segment_pseudowire = value
                                        self.is_multi_segment_pseudowire.value_namespace = name_space
                                        self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-partially-programmed"):
                                        self.is_partially_programmed = value
                                        self.is_partially_programmed.value_namespace = name_space
                                        self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-pwr-type"):
                                        self.is_pwr_type = value
                                        self.is_pwr_type.value_namespace = name_space
                                        self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-vfi"):
                                        self.is_vfi = value
                                        self.is_vfi.value_namespace = name_space
                                        self.is_vfi.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-time-status-changed"):
                                        self.last_time_status_changed = value
                                        self.last_time_status_changed.value_namespace = name_space
                                        self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-time-status-down"):
                                        self.last_time_status_down = value
                                        self.last_time_status_down.value_namespace = name_space
                                        self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertise-failed"):
                                        self.ldp_label_advertise_failed = value
                                        self.ldp_label_advertise_failed.value_namespace = name_space
                                        self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "load-balance"):
                                        self.load_balance = value
                                        self.load_balance.value_namespace = name_space
                                        self.load_balance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-control-word"):
                                        self.local_control_word = value
                                        self.local_control_word.value_namespace = name_space
                                        self.local_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label-failed"):
                                        self.local_label_failed = value
                                        self.local_label_failed.value_namespace = name_space
                                        self.local_label_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-pseudo-wire-type"):
                                        self.local_pseudo_wire_type = value
                                        self.local_pseudo_wire_type.value_namespace = name_space
                                        self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-source-address"):
                                        self.local_source_address = value
                                        self.local_source_address.value_namespace = name_space
                                        self.local_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-oper-down"):
                                        self.mac_limit_oper_down = value
                                        self.mac_limit_oper_down.value_namespace = name_space
                                        self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-mismatched"):
                                        self.mtu_mismatched = value
                                        self.mtu_mismatched.value_namespace = name_space
                                        self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "not-supported-qinq"):
                                        self.not_supported_qinq = value
                                        self.not_supported_qinq.value_namespace = name_space
                                        self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                    if(value_path == "num-ma-cwithdraw-msg-received"):
                                        self.num_ma_cwithdraw_msg_received = value
                                        self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                        self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                    if(value_path == "number-ma-cwithdraw-message-sent"):
                                        self.number_ma_cwithdraw_message_sent = value
                                        self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                        self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                    if(value_path == "out-of-memory-state"):
                                        self.out_of_memory_state = value
                                        self.out_of_memory_state.value_namespace = name_space
                                        self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes-mismatched"):
                                        self.payload_bytes_mismatched = value
                                        self.payload_bytes_mismatched.value_namespace = name_space
                                        self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-type-mismatched"):
                                        self.payload_type_mismatched = value
                                        self.payload_type_mismatched.value_namespace = name_space
                                        self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "preferred-path-disable-fallback"):
                                        self.preferred_path_disable_fallback = value
                                        self.preferred_path_disable_fallback.value_namespace = name_space
                                        self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-peer-id"):
                                        self.primary_peer_id = value
                                        self.primary_peer_id.value_namespace = name_space
                                        self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-pseudo-wire-id"):
                                        self.primary_pseudo_wire_id = value
                                        self.primary_pseudo_wire_id.value_namespace = name_space
                                        self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-pw"):
                                        self.primary_pw = value
                                        self.primary_pw.value_namespace = name_space
                                        self.primary_pw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol"):
                                        self.protocol = value
                                        self.protocol.value_namespace = name_space
                                        self.protocol.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-id"):
                                        self.pseudo_wire_id = value
                                        self.pseudo_wire_id.value_namespace = name_space
                                        self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-state"):
                                        self.pseudo_wire_state = value
                                        self.pseudo_wire_state.value_namespace = name_space
                                        self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-type-mismatched"):
                                        self.pseudo_wire_type_mismatched = value
                                        self.pseudo_wire_type_mismatched.value_namespace = name_space
                                        self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-class-name"):
                                        self.pw_class_name = value
                                        self.pw_class_name.value_namespace = name_space
                                        self.pw_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-code17-disabled"):
                                        self.pw_flow_label_code17_disabled = value
                                        self.pw_flow_label_code17_disabled.value_namespace = name_space
                                        self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-type"):
                                        self.pw_flow_label_type = value
                                        self.pw_flow_label_type.value_namespace = name_space
                                        self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-type-cfg"):
                                        self.pw_flow_label_type_cfg = value
                                        self.pw_flow_label_type_cfg.value_namespace = name_space
                                        self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-redundancy-initial-delay"):
                                        self.pw_redundancy_initial_delay = value
                                        self.pw_redundancy_initial_delay.value_namespace = name_space
                                        self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-redundancy-one-way"):
                                        self.pw_redundancy_one_way = value
                                        self.pw_redundancy_one_way.value_namespace = name_space
                                        self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-status-use"):
                                        self.pw_status_use = value
                                        self.pw_status_use.value_namespace = name_space
                                        self.pw_status_use.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pwlsd-rewrite-failed"):
                                        self.pwlsd_rewrite_failed = value
                                        self.pwlsd_rewrite_failed.value_namespace = name_space
                                        self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-control-word"):
                                        self.remote_control_word = value
                                        self.remote_control_word.value_namespace = name_space
                                        self.remote_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label-failed"):
                                        self.remote_label_failed = value
                                        self.remote_label_failed.value_namespace = name_space
                                        self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-pseudo-wire-type"):
                                        self.remote_pseudo_wire_type = value
                                        self.remote_pseudo_wire_type.value_namespace = name_space
                                        self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "required-bw"):
                                        self.required_bw = value
                                        self.required_bw.value_namespace = name_space
                                        self.required_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resync-enabled"):
                                        self.resync_enabled = value
                                        self.resync_enabled.value_namespace = name_space
                                        self.resync_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resync-threshold"):
                                        self.resync_threshold = value
                                        self.resync_threshold.value_namespace = name_space
                                        self.resync_threshold.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rtp-mismatched"):
                                        self.rtp_mismatched = value
                                        self.rtp_mismatched.value_namespace = name_space
                                        self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequencing-type"):
                                        self.sequencing_type = value
                                        self.sequencing_type.value_namespace = name_space
                                        self.sequencing_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sig-pkts-mismatched"):
                                        self.sig_pkts_mismatched = value
                                        self.sig_pkts_mismatched.value_namespace = name_space
                                        self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ssrc-mismatched"):
                                        self.ssrc_mismatched = value
                                        self.ssrc_mismatched.value_namespace = name_space
                                        self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "table-policy-name"):
                                        self.table_policy_name = value
                                        self.table_policy_name.value_namespace = name_space
                                        self.table_policy_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tag-rewrite"):
                                        self.tag_rewrite = value
                                        self.tag_rewrite.value_namespace = name_space
                                        self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-created"):
                                        self.time_created = value
                                        self.time_created.value_namespace = name_space
                                        self.time_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-creation"):
                                        self.time_elapsed_creation = value
                                        self.time_elapsed_creation.value_namespace = name_space
                                        self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-status-changed"):
                                        self.time_elapsed_status_changed = value
                                        self.time_elapsed_status_changed.value_namespace = name_space
                                        self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-status-down"):
                                        self.time_elapsed_status_down = value
                                        self.time_elapsed_status_down.value_namespace = name_space
                                        self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transport-lsp-down"):
                                        self.transport_lsp_down = value
                                        self.transport_lsp_down.value_namespace = name_space
                                        self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-pw"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/base/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-pw"

                                    self.address = YLeaf(YType.str, "address")

                                    self.bmac = YLeaf(YType.str, "bmac")

                                    self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "bmac",
                                                    "next_hop_ip") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.bmac.is_set or
                                        self.next_hop_ip.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.bmac.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "static-mac" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bmac.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bmac"):
                                        self.bmac = value
                                        self.bmac.value_namespace = name_space
                                        self.bmac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.static_mac:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.is_access.is_set or
                                    self.neighbor.is_set or
                                    self.pseudowire_id.is_set or
                                    self.pw_type.is_set or
                                    self.ve_id_vpls_id_0_3.is_set or
                                    self.vpls_id_4_7.is_set or
                                    (self.pseudowire is not None and self.pseudowire.has_data()) or
                                    (self.security_parameters is not None and self.security_parameters.has_data()))

                            def has_operation(self):
                                for c in self.static_mac:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_access.yfilter != YFilter.not_set or
                                    self.neighbor.yfilter != YFilter.not_set or
                                    self.pseudowire_id.yfilter != YFilter.not_set or
                                    self.pw_type.yfilter != YFilter.not_set or
                                    self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set or
                                    self.vpls_id_4_7.yfilter != YFilter.not_set or
                                    (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bridge-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_access.get_name_leafdata())
                                if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor.get_name_leafdata())
                                if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudowire_id.get_name_leafdata())
                                if (self.pw_type.is_set or self.pw_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_type.get_name_leafdata())
                                if (self.ve_id_vpls_id_0_3.is_set or self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_id_vpls_id_0_3.get_name_leafdata())
                                if (self.vpls_id_4_7.is_set or self.vpls_id_4_7.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_4_7.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "pseudowire"):
                                    if (self.pseudowire is None):
                                        self.pseudowire = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                        self.pseudowire.parent = self
                                        self._children_name_map["pseudowire"] = "pseudowire"
                                    return self.pseudowire

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                if (child_yang_name == "static-mac"):
                                    for c in self.static_mac:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.static_mac.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id" or name == "pw-type" or name == "ve-id-vpls-id-0-3" or name == "vpls-id-4-7"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-access"):
                                    self.is_access = value
                                    self.is_access.value_namespace = name_space
                                    self.is_access.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor"):
                                    self.neighbor = value
                                    self.neighbor.value_namespace = name_space
                                    self.neighbor.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudowire-id"):
                                    self.pseudowire_id = value
                                    self.pseudowire_id.value_namespace = name_space
                                    self.pseudowire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-type"):
                                    self.pw_type = value
                                    self.pw_type.value_namespace = name_space
                                    self.pw_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-id-vpls-id-0-3"):
                                    self.ve_id_vpls_id_0_3 = value
                                    self.ve_id_vpls_id_0_3.value_namespace = name_space
                                    self.ve_id_vpls_id_0_3.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpls-id-4-7"):
                                    self.vpls_id_4_7 = value
                                    self.vpls_id_4_7.value_namespace = name_space
                                    self.vpls_id_4_7.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bridge_pw:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bridge_pw:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-pws" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bridge-pw"):
                                for c in self.bridge_pw:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bridge_pw.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-pw"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (self.bridge_pws is not None and self.bridge_pws.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bridge_pws is not None and self.bridge_pws.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-access-vfi-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-pws"):
                            if (self.bridge_pws is None):
                                self.bridge_pws = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                                self.bridge_pws.parent = self
                                self._children_name_map["bridge_pws"] = "bridge-pws"
                            return self.bridge_pws

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-pws"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BridgeCoreVfiTable(Entity):
                    """
                    Bridge Domain Core VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable, self).__init__()

                        self.yang_name = "bridge-core-vfi-table"
                        self.yang_parent_name = "bridge-domain"

                        self.bridge_pws = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                        self.bridge_pws.parent = self
                        self._children_name_map["bridge_pws"] = "bridge-pws"
                        self._children_yang_names.add("bridge-pws")


                    class BridgePws(Entity):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	VPLS Bridge Domain Pseudowire
                        	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__init__()

                            self.yang_name = "bridge-pws"
                            self.yang_parent_name = "bridge-core-vfi-table"

                            self.bridge_pw = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__setattr__(name, value)


                        class BridgePw(Entity):
                            """
                            VPLS Bridge Domain Pseudowire
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:   :py:class:`L2Vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnpw>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__init__()

                                self.yang_name = "bridge-pw"
                                self.yang_parent_name = "bridge-pws"

                                self.is_access = YLeaf(YType.boolean, "is-access")

                                self.neighbor = YLeaf(YType.str, "neighbor")

                                self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                                self.pw_type = YLeaf(YType.enumeration, "pw-type")

                                self.ve_id_vpls_id_0_3 = YLeaf(YType.uint32, "ve-id-vpls-id-0-3")

                                self.vpls_id_4_7 = YLeaf(YType.uint32, "vpls-id-4-7")

                                self.pseudowire = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"
                                self._children_yang_names.add("pseudowire")

                                self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                                self.static_mac = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_access",
                                                "neighbor",
                                                "pseudowire_id",
                                                "pw_type",
                                                "ve_id_vpls_id_0_3",
                                                "vpls_id_4_7") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)


                            class Pseudowire(Entity):
                                """
                                Pseudowire
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\:  bool
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\:  bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\:  bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\:  bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\:  bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\:  bool
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\:  bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\:  bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\:  bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\:  bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\:  bool
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_evpnvpws_type
                                
                                	is EVPN VPWS
                                	**type**\:  bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\:  bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\:  bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\:  bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\:  bool
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\:  bool
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\:  bool
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\:  bool
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\:  bool
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\:  bool
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\:  bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\:  bool
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\:  bool
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\:  bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\:  bool
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\:  bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\:  bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\:  bool
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\:  str
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                    self.yang_name = "pseudowire"
                                    self.yang_parent_name = "bridge-pw"

                                    self.ad_method = YLeaf(YType.uint32, "ad-method")

                                    self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                    self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                    self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                    self.backup_active = YLeaf(YType.boolean, "backup-active")

                                    self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                    self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                    self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                    self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                    self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                    self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                    self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                    self.disable_never = YLeaf(YType.boolean, "disable-never")

                                    self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                    self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                    self.forward_class = YLeaf(YType.uint8, "forward-class")

                                    self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                    self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                    self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                    self.interworking = YLeaf(YType.enumeration, "interworking")

                                    self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                    self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                    self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                    self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                    self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                    self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                    self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                    self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                    self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                    self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                    self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                    self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                    self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                    self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                    self.local_source_address = YLeaf(YType.str, "local-source-address")

                                    self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                    self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                    self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                    self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                    self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                    self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                    self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                    self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                    self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                    self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                    self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                    self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                    self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                    self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                    self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                    self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                    self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                    self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                    self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                    self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                    self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                    self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                    self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                    self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                    self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                    self.required_bw = YLeaf(YType.uint32, "required-bw")

                                    self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                    self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                    self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                    self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                    self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                    self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                    self.time_created = YLeaf(YType.str, "time-created")

                                    self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                    self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                    self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                    self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.encapsulation_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    self._children_yang_names.add("encapsulation-info")

                                    self.local_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                    self._children_yang_names.add("local-interface")

                                    self.local_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                    self._children_yang_names.add("local-signalling")

                                    self.p2mp_pw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    self._children_yang_names.add("p2mp-pw")

                                    self.peer_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                    self._children_yang_names.add("peer-id")

                                    self.preferred_path = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                    self._children_yang_names.add("preferred-path")

                                    self.remote_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                    self._children_yang_names.add("remote-interface")

                                    self.remote_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                    self._children_yang_names.add("remote-signalling")

                                    self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._children_yang_names.add("statistics")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ad_method",
                                                    "ad_remote_down",
                                                    "admited_bw",
                                                    "auto_discovery",
                                                    "backup_active",
                                                    "backup_force_active",
                                                    "backup_pw",
                                                    "bitrate_mismatched",
                                                    "bridge_pw_type_mismatch",
                                                    "cas_mismatched",
                                                    "diff_ts_mismatched",
                                                    "disable_delay",
                                                    "disable_never",
                                                    "evpn_src_acid",
                                                    "fe_ctype",
                                                    "forward_class",
                                                    "freq_mismatched",
                                                    "illegal_control_word",
                                                    "imposed_vlan_id",
                                                    "interworking",
                                                    "ipv6_local_source_address",
                                                    "is_evpnvpws_type",
                                                    "is_flow_label_static",
                                                    "is_multi_segment_pseudowire",
                                                    "is_partially_programmed",
                                                    "is_pwr_type",
                                                    "is_vfi",
                                                    "last_time_status_changed",
                                                    "last_time_status_down",
                                                    "ldp_label_advertise_failed",
                                                    "load_balance",
                                                    "local_control_word",
                                                    "local_label_failed",
                                                    "local_pseudo_wire_type",
                                                    "local_source_address",
                                                    "mac_limit_oper_down",
                                                    "mtu_mismatched",
                                                    "not_supported_qinq",
                                                    "num_ma_cwithdraw_msg_received",
                                                    "number_ma_cwithdraw_message_sent",
                                                    "out_of_memory_state",
                                                    "payload_bytes_mismatched",
                                                    "payload_type_mismatched",
                                                    "preferred_path_disable_fallback",
                                                    "primary_peer_id",
                                                    "primary_pseudo_wire_id",
                                                    "primary_pw",
                                                    "protocol",
                                                    "pseudo_wire_id",
                                                    "pseudo_wire_state",
                                                    "pseudo_wire_type_mismatched",
                                                    "pw_class_name",
                                                    "pw_flow_label_code17_disabled",
                                                    "pw_flow_label_type",
                                                    "pw_flow_label_type_cfg",
                                                    "pw_redundancy_initial_delay",
                                                    "pw_redundancy_one_way",
                                                    "pw_status_use",
                                                    "pwlsd_rewrite_failed",
                                                    "remote_control_word",
                                                    "remote_label_failed",
                                                    "remote_pseudo_wire_type",
                                                    "required_bw",
                                                    "resync_enabled",
                                                    "resync_threshold",
                                                    "rtp_mismatched",
                                                    "sequencing_type",
                                                    "shutdown",
                                                    "sig_pkts_mismatched",
                                                    "ssrc_mismatched",
                                                    "state",
                                                    "table_policy_name",
                                                    "tag_rewrite",
                                                    "time_created",
                                                    "time_elapsed_creation",
                                                    "time_elapsed_status_changed",
                                                    "time_elapsed_status_down",
                                                    "transport_lsp_down",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)


                                class PeerId(Entity):
                                    """
                                    Peer
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                        self.yang_name = "peer-id"
                                        self.yang_parent_name = "pseudowire"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                        self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                        self.type = YLeaf(YType.enumeration, "type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "ipv4_peer_id",
                                                        "ipv6_peer_id",
                                                        "type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.ipv4_peer_id.is_set or
                                            self.ipv6_peer_id.is_set or
                                            self.type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.ipv4_peer_id.yfilter != YFilter.not_set or
                                            self.ipv6_peer_id.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "peer-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                        if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-peer-id"):
                                            self.ipv4_peer_id = value
                                            self.ipv4_peer_id.value_namespace = name_space
                                            self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-peer-id"):
                                            self.ipv6_peer_id = value
                                            self.ipv6_peer_id.value_namespace = name_space
                                            self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix


                                class EncapsulationInfo(Entity):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                        self.yang_name = "encapsulation-info"
                                        self.yang_parent_name = "pseudowire"

                                        self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                        self.atom = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                        self._children_yang_names.add("atom")

                                        self.l2tpv3 = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                        self._children_yang_names.add("l2tpv3")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                    class Atom(Entity):
                                        """
                                        atom
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                            self.yang_name = "atom"
                                            self.yang_parent_name = "encapsulation-info"

                                            self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                            self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                            self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                            self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                            self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                            self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                            self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                            self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                            self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                            self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                            self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                            self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                            self.local_veid = YLeaf(YType.uint32, "local-veid")

                                            self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                            self.rem_saii = YLeaf(YType.str, "rem-saii")

                                            self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                            self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                            self.rem_taii = YLeaf(YType.str, "rem-taii")

                                            self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                            self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                            self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                            self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                            self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                            self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                                            self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                            self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                            self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                            self.saii = YLeaf(YType.str, "saii")

                                            self.source_address = YLeaf(YType.str, "source-address")

                                            self.taii = YLeaf(YType.str, "taii")

                                            self.local_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                            self._children_yang_names.add("local-agi")

                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            self._children_yang_names.add("multi-segment-pseudowire-stats")

                                            self.remote_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                            self._children_yang_names.add("remote-agi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("is_pseudowire_headend",
                                                            "is_sai_itype2",
                                                            "is_tai_itype2",
                                                            "ldp_label_advertisment_failed",
                                                            "local_c_ctype",
                                                            "local_ceid",
                                                            "local_cv_type",
                                                            "local_group_id",
                                                            "local_label",
                                                            "local_ldp_id",
                                                            "local_saii_gbl_id",
                                                            "local_saiiac_id",
                                                            "local_taii_gbl_id",
                                                            "local_taiiac_id",
                                                            "local_veid",
                                                            "lsd_rewrite_failed",
                                                            "rem_saii",
                                                            "rem_saii_gbl_id",
                                                            "rem_saiiac_id",
                                                            "rem_taii",
                                                            "rem_taii_gbl_id",
                                                            "rem_taiiac_id",
                                                            "remote_c_ctype",
                                                            "remote_ceid",
                                                            "remote_cv_type",
                                                            "remote_group_id",
                                                            "remote_label",
                                                            "remote_ldp_id",
                                                            "remote_source_address",
                                                            "remote_veid",
                                                            "saii",
                                                            "source_address",
                                                            "taii") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                        class LocalAgi(Entity):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                self.yang_name = "local-agi"
                                                self.yang_parent_name = "atom"

                                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                                self._children_yang_names.add("auto")

                                                self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                                self._children_yang_names.add("two-byte-as")

                                                self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._children_yang_names.add("v4-addr")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vpls_id_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "local-agi"

                                                    self.asn = YLeaf(YType.uint16, "asn")

                                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("asn",
                                                                    "vpn_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.asn.is_set or
                                                        self.vpn_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.asn.yfilter != YFilter.not_set or
                                                        self.vpn_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "auto" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "asn" or name == "vpn-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "asn"):
                                                        self.asn = value
                                                        self.asn.value_namespace = name_space
                                                        self.asn.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpn-id"):
                                                        self.vpn_id = value
                                                        self.vpn_id.value_namespace = name_space
                                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "local-agi"

                                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("four_byte_index",
                                                                    "two_byte_as") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.four_byte_index.is_set or
                                                        self.two_byte_as.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.four_byte_index.yfilter != YFilter.not_set or
                                                        self.two_byte_as.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "two-byte-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "four-byte-index"):
                                                        self.four_byte_index = value
                                                        self.four_byte_index.value_namespace = name_space
                                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-as"):
                                                        self.two_byte_as = value
                                                        self.two_byte_as.value_namespace = name_space
                                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "local-agi"

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ipv4_address",
                                                                    "two_byte_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ipv4_address.is_set or
                                                        self.two_byte_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ipv4_address.yfilter != YFilter.not_set or
                                                        self.two_byte_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "v4-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ipv4-address"):
                                                        self.ipv4_address = value
                                                        self.ipv4_address.value_namespace = name_space
                                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-index"):
                                                        self.two_byte_index = value
                                                        self.two_byte_index.value_namespace = name_space
                                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.vpls_id_type.is_set or
                                                    (self.auto is not None and self.auto.has_data()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                                    (self.auto is not None and self.auto.has_operation()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "local-agi" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "auto"):
                                                    if (self.auto is None):
                                                        self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                        self.auto.parent = self
                                                        self._children_name_map["auto"] = "auto"
                                                    return self.auto

                                                if (child_yang_name == "two-byte-as"):
                                                    if (self.two_byte_as is None):
                                                        self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                        self.two_byte_as.parent = self
                                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    return self.two_byte_as

                                                if (child_yang_name == "v4-addr"):
                                                    if (self.v4_addr is None):
                                                        self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                        self.v4_addr.parent = self
                                                        self._children_name_map["v4_addr"] = "v4-addr"
                                                    return self.v4_addr

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vpls-id-type"):
                                                    self.vpls_id_type = value
                                                    self.vpls_id_type.value_namespace = name_space
                                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                        class RemoteAgi(Entity):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                self.yang_name = "remote-agi"
                                                self.yang_parent_name = "atom"

                                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                                self._children_yang_names.add("auto")

                                                self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                                self._children_yang_names.add("two-byte-as")

                                                self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._children_yang_names.add("v4-addr")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vpls_id_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.asn = YLeaf(YType.uint16, "asn")

                                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("asn",
                                                                    "vpn_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.asn.is_set or
                                                        self.vpn_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.asn.yfilter != YFilter.not_set or
                                                        self.vpn_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "auto" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "asn" or name == "vpn-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "asn"):
                                                        self.asn = value
                                                        self.asn.value_namespace = name_space
                                                        self.asn.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpn-id"):
                                                        self.vpn_id = value
                                                        self.vpn_id.value_namespace = name_space
                                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("four_byte_index",
                                                                    "two_byte_as") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.four_byte_index.is_set or
                                                        self.two_byte_as.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.four_byte_index.yfilter != YFilter.not_set or
                                                        self.two_byte_as.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "two-byte-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "four-byte-index"):
                                                        self.four_byte_index = value
                                                        self.four_byte_index.value_namespace = name_space
                                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-as"):
                                                        self.two_byte_as = value
                                                        self.two_byte_as.value_namespace = name_space
                                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ipv4_address",
                                                                    "two_byte_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ipv4_address.is_set or
                                                        self.two_byte_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ipv4_address.yfilter != YFilter.not_set or
                                                        self.two_byte_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "v4-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ipv4-address"):
                                                        self.ipv4_address = value
                                                        self.ipv4_address.value_namespace = name_space
                                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-index"):
                                                        self.two_byte_index = value
                                                        self.two_byte_index.value_namespace = name_space
                                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.vpls_id_type.is_set or
                                                    (self.auto is not None and self.auto.has_data()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                                    (self.auto is not None and self.auto.has_operation()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-agi" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "auto"):
                                                    if (self.auto is None):
                                                        self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                        self.auto.parent = self
                                                        self._children_name_map["auto"] = "auto"
                                                    return self.auto

                                                if (child_yang_name == "two-byte-as"):
                                                    if (self.two_byte_as is None):
                                                        self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                        self.two_byte_as.parent = self
                                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    return self.two_byte_as

                                                if (child_yang_name == "v4-addr"):
                                                    if (self.v4_addr is None):
                                                        self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                        self.v4_addr.parent = self
                                                        self._children_name_map["v4_addr"] = "v4-addr"
                                                    return self.v4_addr

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vpls-id-type"):
                                                    self.vpls_id_type = value
                                                    self.vpls_id_type.value_namespace = name_space
                                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                        class MultiSegmentPseudowireStats(Entity):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                self.yang_name = "multi-segment-pseudowire-stats"
                                                self.yang_parent_name = "atom"

                                                self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                                self.received_packets = YLeaf(YType.uint64, "received-packets")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("received_bytes",
                                                                "received_packets") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.received_bytes.is_set or
                                                    self.received_packets.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.received_bytes.yfilter != YFilter.not_set or
                                                    self.received_packets.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                                if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.received_packets.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "received-bytes" or name == "received-packets"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "received-bytes"):
                                                    self.received_bytes = value
                                                    self.received_bytes.value_namespace = name_space
                                                    self.received_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "received-packets"):
                                                    self.received_packets = value
                                                    self.received_packets.value_namespace = name_space
                                                    self.received_packets.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.is_pseudowire_headend.is_set or
                                                self.is_sai_itype2.is_set or
                                                self.is_tai_itype2.is_set or
                                                self.ldp_label_advertisment_failed.is_set or
                                                self.local_c_ctype.is_set or
                                                self.local_ceid.is_set or
                                                self.local_cv_type.is_set or
                                                self.local_group_id.is_set or
                                                self.local_label.is_set or
                                                self.local_ldp_id.is_set or
                                                self.local_saii_gbl_id.is_set or
                                                self.local_saiiac_id.is_set or
                                                self.local_taii_gbl_id.is_set or
                                                self.local_taiiac_id.is_set or
                                                self.local_veid.is_set or
                                                self.lsd_rewrite_failed.is_set or
                                                self.rem_saii.is_set or
                                                self.rem_saii_gbl_id.is_set or
                                                self.rem_saiiac_id.is_set or
                                                self.rem_taii.is_set or
                                                self.rem_taii_gbl_id.is_set or
                                                self.rem_taiiac_id.is_set or
                                                self.remote_c_ctype.is_set or
                                                self.remote_ceid.is_set or
                                                self.remote_cv_type.is_set or
                                                self.remote_group_id.is_set or
                                                self.remote_label.is_set or
                                                self.remote_ldp_id.is_set or
                                                self.remote_source_address.is_set or
                                                self.remote_veid.is_set or
                                                self.saii.is_set or
                                                self.source_address.is_set or
                                                self.taii.is_set or
                                                (self.local_agi is not None and self.local_agi.has_data()) or
                                                (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                                (self.remote_agi is not None and self.remote_agi.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                                self.is_sai_itype2.yfilter != YFilter.not_set or
                                                self.is_tai_itype2.yfilter != YFilter.not_set or
                                                self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                                self.local_c_ctype.yfilter != YFilter.not_set or
                                                self.local_ceid.yfilter != YFilter.not_set or
                                                self.local_cv_type.yfilter != YFilter.not_set or
                                                self.local_group_id.yfilter != YFilter.not_set or
                                                self.local_label.yfilter != YFilter.not_set or
                                                self.local_ldp_id.yfilter != YFilter.not_set or
                                                self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                                self.local_saiiac_id.yfilter != YFilter.not_set or
                                                self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                                self.local_taiiac_id.yfilter != YFilter.not_set or
                                                self.local_veid.yfilter != YFilter.not_set or
                                                self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                                self.rem_saii.yfilter != YFilter.not_set or
                                                self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                                self.rem_saiiac_id.yfilter != YFilter.not_set or
                                                self.rem_taii.yfilter != YFilter.not_set or
                                                self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                                self.rem_taiiac_id.yfilter != YFilter.not_set or
                                                self.remote_c_ctype.yfilter != YFilter.not_set or
                                                self.remote_ceid.yfilter != YFilter.not_set or
                                                self.remote_cv_type.yfilter != YFilter.not_set or
                                                self.remote_group_id.yfilter != YFilter.not_set or
                                                self.remote_label.yfilter != YFilter.not_set or
                                                self.remote_ldp_id.yfilter != YFilter.not_set or
                                                self.remote_source_address.yfilter != YFilter.not_set or
                                                self.remote_veid.yfilter != YFilter.not_set or
                                                self.saii.yfilter != YFilter.not_set or
                                                self.source_address.yfilter != YFilter.not_set or
                                                self.taii.yfilter != YFilter.not_set or
                                                (self.local_agi is not None and self.local_agi.has_operation()) or
                                                (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                                (self.remote_agi is not None and self.remote_agi.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atom" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                            if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                            if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                            if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                            if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                            if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                            if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                            if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_label.get_name_leafdata())
                                            if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                            if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                            if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                            if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                            if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                            if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_veid.get_name_leafdata())
                                            if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                            if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                            if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                            if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                            if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                            if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                            if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                            if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                            if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                            if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                            if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                                            if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                            if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                            if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                            if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.saii.get_name_leafdata())
                                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.source_address.get_name_leafdata())
                                            if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.taii.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "local-agi"):
                                                if (self.local_agi is None):
                                                    self.local_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                    self.local_agi.parent = self
                                                    self._children_name_map["local_agi"] = "local-agi"
                                                return self.local_agi

                                            if (child_yang_name == "multi-segment-pseudowire-stats"):
                                                if (self.multi_segment_pseudowire_stats is None):
                                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                    self.multi_segment_pseudowire_stats.parent = self
                                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                return self.multi_segment_pseudowire_stats

                                            if (child_yang_name == "remote-agi"):
                                                if (self.remote_agi is None):
                                                    self.remote_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                    self.remote_agi.parent = self
                                                    self._children_name_map["remote_agi"] = "remote-agi"
                                                return self.remote_agi

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "is-pseudowire-headend"):
                                                self.is_pseudowire_headend = value
                                                self.is_pseudowire_headend.value_namespace = name_space
                                                self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-sai-itype2"):
                                                self.is_sai_itype2 = value
                                                self.is_sai_itype2.value_namespace = name_space
                                                self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-tai-itype2"):
                                                self.is_tai_itype2 = value
                                                self.is_tai_itype2.value_namespace = name_space
                                                self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ldp-label-advertisment-failed"):
                                                self.ldp_label_advertisment_failed = value
                                                self.ldp_label_advertisment_failed.value_namespace = name_space
                                                self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-c-ctype"):
                                                self.local_c_ctype = value
                                                self.local_c_ctype.value_namespace = name_space
                                                self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ceid"):
                                                self.local_ceid = value
                                                self.local_ceid.value_namespace = name_space
                                                self.local_ceid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cv-type"):
                                                self.local_cv_type = value
                                                self.local_cv_type.value_namespace = name_space
                                                self.local_cv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-group-id"):
                                                self.local_group_id = value
                                                self.local_group_id.value_namespace = name_space
                                                self.local_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-label"):
                                                self.local_label = value
                                                self.local_label.value_namespace = name_space
                                                self.local_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ldp-id"):
                                                self.local_ldp_id = value
                                                self.local_ldp_id.value_namespace = name_space
                                                self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-saii-gbl-id"):
                                                self.local_saii_gbl_id = value
                                                self.local_saii_gbl_id.value_namespace = name_space
                                                self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-saiiac-id"):
                                                self.local_saiiac_id = value
                                                self.local_saiiac_id.value_namespace = name_space
                                                self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-taii-gbl-id"):
                                                self.local_taii_gbl_id = value
                                                self.local_taii_gbl_id.value_namespace = name_space
                                                self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-taiiac-id"):
                                                self.local_taiiac_id = value
                                                self.local_taiiac_id.value_namespace = name_space
                                                self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-veid"):
                                                self.local_veid = value
                                                self.local_veid.value_namespace = name_space
                                                self.local_veid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsd-rewrite-failed"):
                                                self.lsd_rewrite_failed = value
                                                self.lsd_rewrite_failed.value_namespace = name_space
                                                self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saii"):
                                                self.rem_saii = value
                                                self.rem_saii.value_namespace = name_space
                                                self.rem_saii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saii-gbl-id"):
                                                self.rem_saii_gbl_id = value
                                                self.rem_saii_gbl_id.value_namespace = name_space
                                                self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saiiac-id"):
                                                self.rem_saiiac_id = value
                                                self.rem_saiiac_id.value_namespace = name_space
                                                self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taii"):
                                                self.rem_taii = value
                                                self.rem_taii.value_namespace = name_space
                                                self.rem_taii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taii-gbl-id"):
                                                self.rem_taii_gbl_id = value
                                                self.rem_taii_gbl_id.value_namespace = name_space
                                                self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taiiac-id"):
                                                self.rem_taiiac_id = value
                                                self.rem_taiiac_id.value_namespace = name_space
                                                self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-c-ctype"):
                                                self.remote_c_ctype = value
                                                self.remote_c_ctype.value_namespace = name_space
                                                self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ceid"):
                                                self.remote_ceid = value
                                                self.remote_ceid.value_namespace = name_space
                                                self.remote_ceid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cv-type"):
                                                self.remote_cv_type = value
                                                self.remote_cv_type.value_namespace = name_space
                                                self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-group-id"):
                                                self.remote_group_id = value
                                                self.remote_group_id.value_namespace = name_space
                                                self.remote_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-label"):
                                                self.remote_label = value
                                                self.remote_label.value_namespace = name_space
                                                self.remote_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ldp-id"):
                                                self.remote_ldp_id = value
                                                self.remote_ldp_id.value_namespace = name_space
                                                self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-source-address"):
                                                self.remote_source_address = value
                                                self.remote_source_address.value_namespace = name_space
                                                self.remote_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-veid"):
                                                self.remote_veid = value
                                                self.remote_veid.value_namespace = name_space
                                                self.remote_veid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "saii"):
                                                self.saii = value
                                                self.saii.value_namespace = name_space
                                                self.saii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "source-address"):
                                                self.source_address = value
                                                self.source_address.value_namespace = name_space
                                                self.source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "taii"):
                                                self.taii = value
                                                self.taii.value_namespace = name_space
                                                self.taii.value_namespace_prefix = name_space_prefix


                                    class L2Tpv3(Entity):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\:  bool
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\:  str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                            self.yang_name = "l2tpv3"
                                            self.yang_parent_name = "encapsulation-info"

                                            self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                            self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                            self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                            self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                            self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                            self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                            self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                            self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                            self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                            self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                            self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                            self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                            self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                            self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                            self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                            self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                            self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                            self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                            self.tos = YLeaf(YType.uint8, "tos")

                                            self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                            self.ttl = YLeaf(YType.uint8, "ttl")

                                            self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dont_fragment_bit",
                                                            "ipv4_source_address",
                                                            "ipv6_source_address",
                                                            "l2tp_class_name",
                                                            "local_cookie_high_value",
                                                            "local_cookie_low_value",
                                                            "local_cookie_size",
                                                            "local_secondary_cookie_high_value",
                                                            "local_secondary_cookie_low_value",
                                                            "local_secondary_cookie_size",
                                                            "local_session_id",
                                                            "path_mtu_enabled",
                                                            "path_mtu_max_value",
                                                            "remote_circuit_status_up",
                                                            "remote_cookie_high_value",
                                                            "remote_cookie_low_value",
                                                            "remote_cookie_size",
                                                            "remote_session_id",
                                                            "tos",
                                                            "tos_mode",
                                                            "ttl",
                                                            "tunnel_state") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dont_fragment_bit.is_set or
                                                self.ipv4_source_address.is_set or
                                                self.ipv6_source_address.is_set or
                                                self.l2tp_class_name.is_set or
                                                self.local_cookie_high_value.is_set or
                                                self.local_cookie_low_value.is_set or
                                                self.local_cookie_size.is_set or
                                                self.local_secondary_cookie_high_value.is_set or
                                                self.local_secondary_cookie_low_value.is_set or
                                                self.local_secondary_cookie_size.is_set or
                                                self.local_session_id.is_set or
                                                self.path_mtu_enabled.is_set or
                                                self.path_mtu_max_value.is_set or
                                                self.remote_circuit_status_up.is_set or
                                                self.remote_cookie_high_value.is_set or
                                                self.remote_cookie_low_value.is_set or
                                                self.remote_cookie_size.is_set or
                                                self.remote_session_id.is_set or
                                                self.tos.is_set or
                                                self.tos_mode.is_set or
                                                self.ttl.is_set or
                                                self.tunnel_state.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dont_fragment_bit.yfilter != YFilter.not_set or
                                                self.ipv4_source_address.yfilter != YFilter.not_set or
                                                self.ipv6_source_address.yfilter != YFilter.not_set or
                                                self.l2tp_class_name.yfilter != YFilter.not_set or
                                                self.local_cookie_high_value.yfilter != YFilter.not_set or
                                                self.local_cookie_low_value.yfilter != YFilter.not_set or
                                                self.local_cookie_size.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.local_session_id.yfilter != YFilter.not_set or
                                                self.path_mtu_enabled.yfilter != YFilter.not_set or
                                                self.path_mtu_max_value.yfilter != YFilter.not_set or
                                                self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                                self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                                self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                                self.remote_cookie_size.yfilter != YFilter.not_set or
                                                self.remote_session_id.yfilter != YFilter.not_set or
                                                self.tos.yfilter != YFilter.not_set or
                                                self.tos_mode.yfilter != YFilter.not_set or
                                                self.ttl.yfilter != YFilter.not_set or
                                                self.tunnel_state.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2tpv3" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                            if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                            if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                            if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                            if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                            if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                            if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                            if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                            if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                            if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                            if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                            if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                            if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                            if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                            if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                            if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                            if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                            if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                            if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos.get_name_leafdata())
                                            if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                            if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ttl.get_name_leafdata())
                                            if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dont-fragment-bit"):
                                                self.dont_fragment_bit = value
                                                self.dont_fragment_bit.value_namespace = name_space
                                                self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-source-address"):
                                                self.ipv4_source_address = value
                                                self.ipv4_source_address.value_namespace = name_space
                                                self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-source-address"):
                                                self.ipv6_source_address = value
                                                self.ipv6_source_address.value_namespace = name_space
                                                self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "l2tp-class-name"):
                                                self.l2tp_class_name = value
                                                self.l2tp_class_name.value_namespace = name_space
                                                self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-high-value"):
                                                self.local_cookie_high_value = value
                                                self.local_cookie_high_value.value_namespace = name_space
                                                self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-low-value"):
                                                self.local_cookie_low_value = value
                                                self.local_cookie_low_value.value_namespace = name_space
                                                self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-size"):
                                                self.local_cookie_size = value
                                                self.local_cookie_size.value_namespace = name_space
                                                self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-high-value"):
                                                self.local_secondary_cookie_high_value = value
                                                self.local_secondary_cookie_high_value.value_namespace = name_space
                                                self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-low-value"):
                                                self.local_secondary_cookie_low_value = value
                                                self.local_secondary_cookie_low_value.value_namespace = name_space
                                                self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-size"):
                                                self.local_secondary_cookie_size = value
                                                self.local_secondary_cookie_size.value_namespace = name_space
                                                self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-session-id"):
                                                self.local_session_id = value
                                                self.local_session_id.value_namespace = name_space
                                                self.local_session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "path-mtu-enabled"):
                                                self.path_mtu_enabled = value
                                                self.path_mtu_enabled.value_namespace = name_space
                                                self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "path-mtu-max-value"):
                                                self.path_mtu_max_value = value
                                                self.path_mtu_max_value.value_namespace = name_space
                                                self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-circuit-status-up"):
                                                self.remote_circuit_status_up = value
                                                self.remote_circuit_status_up.value_namespace = name_space
                                                self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-high-value"):
                                                self.remote_cookie_high_value = value
                                                self.remote_cookie_high_value.value_namespace = name_space
                                                self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-low-value"):
                                                self.remote_cookie_low_value = value
                                                self.remote_cookie_low_value.value_namespace = name_space
                                                self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-size"):
                                                self.remote_cookie_size = value
                                                self.remote_cookie_size.value_namespace = name_space
                                                self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-session-id"):
                                                self.remote_session_id = value
                                                self.remote_session_id.value_namespace = name_space
                                                self.remote_session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos"):
                                                self.tos = value
                                                self.tos.value_namespace = name_space
                                                self.tos.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos-mode"):
                                                self.tos_mode = value
                                                self.tos_mode.value_namespace = name_space
                                                self.tos_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ttl"):
                                                self.ttl = value
                                                self.ttl.value_namespace = name_space
                                                self.ttl.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-state"):
                                                self.tunnel_state = value
                                                self.tunnel_state.value_namespace = name_space
                                                self.tunnel_state.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.encapsulation.is_set or
                                            (self.atom is not None and self.atom.has_data()) or
                                            (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation.yfilter != YFilter.not_set or
                                            (self.atom is not None and self.atom.has_operation()) or
                                            (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "encapsulation-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atom"):
                                            if (self.atom is None):
                                                self.atom = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                                self.atom.parent = self
                                                self._children_name_map["atom"] = "atom"
                                            return self.atom

                                        if (child_yang_name == "l2tpv3"):
                                            if (self.l2tpv3 is None):
                                                self.l2tpv3 = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                                self.l2tpv3.parent = self
                                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                            return self.l2tpv3

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation"):
                                            self.encapsulation = value
                                            self.encapsulation.value_namespace = name_space
                                            self.encapsulation.value_namespace_prefix = name_space_prefix


                                class LocalInterface(Entity):
                                    """
                                    Local interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                        self.yang_name = "local-interface"
                                        self.yang_parent_name = "pseudowire"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "local-interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class RemoteInterface(Entity):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                        self.yang_name = "remote-interface"
                                        self.yang_parent_name = "pseudowire"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "remote-interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class PreferredPath(Entity):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                        self.yang_name = "preferred-path"
                                        self.yang_parent_name = "pseudowire"

                                        self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                        self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                        self.option = YLeaf(YType.enumeration, "option")

                                        self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                        self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ip_tunnel_interface_number",
                                                        "next_hop_ip",
                                                        "option",
                                                        "te_tunnel_interface_number",
                                                        "tp_tunnel_interface_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ip_tunnel_interface_number.is_set or
                                            self.next_hop_ip.is_set or
                                            self.option.is_set or
                                            self.te_tunnel_interface_number.is_set or
                                            self.tp_tunnel_interface_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                            self.next_hop_ip.yfilter != YFilter.not_set or
                                            self.option.yfilter != YFilter.not_set or
                                            self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                            self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "preferred-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                        if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.option.get_name_leafdata())
                                        if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                        if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ip-tunnel-interface-number"):
                                            self.ip_tunnel_interface_number = value
                                            self.ip_tunnel_interface_number.value_namespace = name_space
                                            self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop-ip"):
                                            self.next_hop_ip = value
                                            self.next_hop_ip.value_namespace = name_space
                                            self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                        if(value_path == "option"):
                                            self.option = value
                                            self.option.value_namespace = name_space
                                            self.option.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-tunnel-interface-number"):
                                            self.te_tunnel_interface_number = value
                                            self.te_tunnel_interface_number.value_namespace = name_space
                                            self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tp-tunnel-interface-number"):
                                            self.tp_tunnel_interface_number = value
                                            self.tp_tunnel_interface_number.value_namespace = name_space
                                            self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                                class LocalSignalling(Entity):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                        self.yang_name = "local-signalling"
                                        self.yang_parent_name = "pseudowire"

                                        self.pw_status = YLeaf(YType.uint32, "pw-status")

                                        self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                        self._children_yang_names.add("status-tlv")

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "local-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "status-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "local-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.pw_status.is_set or
                                            (self.status_tlv is not None and self.status_tlv.has_data()))

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_status.yfilter != YFilter.not_set or
                                            (self.status_tlv is not None and self.status_tlv.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-signalling" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "status-tlv"):
                                            if (self.status_tlv is None):
                                                self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                                self.status_tlv.parent = self
                                                self._children_name_map["status_tlv"] = "status-tlv"
                                            return self.status_tlv

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-status"):
                                            self.pw_status = value
                                            self.pw_status.value_namespace = name_space
                                            self.pw_status.value_namespace_prefix = name_space_prefix


                                class RemoteSignalling(Entity):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                        self.yang_name = "remote-signalling"
                                        self.yang_parent_name = "pseudowire"

                                        self.pw_status = YLeaf(YType.uint32, "pw-status")

                                        self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                        self._children_yang_names.add("status-tlv")

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "remote-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "status-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "remote-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.pw_status.is_set or
                                            (self.status_tlv is not None and self.status_tlv.has_data()))

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_status.yfilter != YFilter.not_set or
                                            (self.status_tlv is not None and self.status_tlv.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-signalling" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "status-tlv"):
                                            if (self.status_tlv is None):
                                                self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                                self.status_tlv.parent = self
                                                self._children_name_map["status_tlv"] = "status-tlv"
                                            return self.status_tlv

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-status"):
                                            self.pw_status = value
                                            self.pw_status.value_namespace = name_space
                                            self.pw_status.value_namespace_prefix = name_space_prefix


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "pseudowire"

                                        self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        self._children_yang_names.add("dispostion-stats")

                                        self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                        self._children_yang_names.add("impostion-stats")

                                        self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._children_yang_names.add("sequence-number")


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                            self._children_yang_names.add("broadcast")

                                            self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            self._children_yang_names.add("imposition-mtu-drop")

                                            self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                            self._children_yang_names.add("imposition-stat")

                                            self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            self._children_yang_names.add("impostion-tail-drop")

                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            self._children_yang_names.add("l2fsbi-drop")

                                            self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                            self._children_yang_names.add("multicast")

                                            self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._children_yang_names.add("unknown-unicast")


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class L2FsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2fsbi-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast is not None and self.broadcast.has_data()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                (self.multicast is not None and self.multicast.has_data()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast is not None and self.broadcast.has_operation()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                (self.multicast is not None and self.multicast.has_operation()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast"):
                                                if (self.broadcast is None):
                                                    self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                    self.broadcast.parent = self
                                                    self._children_name_map["broadcast"] = "broadcast"
                                                return self.broadcast

                                            if (child_yang_name == "imposition-mtu-drop"):
                                                if (self.imposition_mtu_drop is None):
                                                    self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                    self.imposition_mtu_drop.parent = self
                                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                return self.imposition_mtu_drop

                                            if (child_yang_name == "imposition-stat"):
                                                if (self.imposition_stat is None):
                                                    self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                    self.imposition_stat.parent = self
                                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                                return self.imposition_stat

                                            if (child_yang_name == "impostion-tail-drop"):
                                                if (self.impostion_tail_drop is None):
                                                    self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                    self.impostion_tail_drop.parent = self
                                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                return self.impostion_tail_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "l2fsbi-drop"):
                                                if (self.l2fsbi_drop is None):
                                                    self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                    self.l2fsbi_drop.parent = self
                                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                return self.l2fsbi_drop

                                            if (child_yang_name == "multicast"):
                                                if (self.multicast is None):
                                                    self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                    self.multicast.parent = self
                                                    self._children_name_map["multicast"] = "multicast"
                                                return self.multicast

                                            if (child_yang_name == "unknown-unicast"):
                                                if (self.unknown_unicast is None):
                                                    self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                    self.unknown_unicast.parent = self
                                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                return self.unknown_unicast

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            self._children_yang_names.add("broadcast-drop")

                                            self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                            self._children_yang_names.add("dai-drop")

                                            self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            self._children_yang_names.add("disposition-mtu-drop")

                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            self._children_yang_names.add("disposition-oo-o-drops")

                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            self._children_yang_names.add("disposition-p2mp-stats")

                                            self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                            self._children_yang_names.add("disposition-stat")

                                            self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            self._children_yang_names.add("disposition-tail-drop")

                                            self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            self._children_yang_names.add("ipsg-drop")

                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._children_yang_names.add("mac-move")

                                            self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                            self._children_yang_names.add("multicast-drop")

                                            self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                            self._children_yang_names.add("received-drops")

                                            self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                            self._children_yang_names.add("unicast-drop")


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "received-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dai-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipsg-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-oo-o-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionP2MpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-p2mp-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mac-move" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.mac_move is not None and self.mac_move.has_data()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                (self.received_drops is not None and self.received_drops.has_data()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.mac_move is not None and self.mac_move.has_operation()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                (self.received_drops is not None and self.received_drops.has_operation()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dispostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast-drop"):
                                                if (self.broadcast_drop is None):
                                                    self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                    self.broadcast_drop.parent = self
                                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                return self.broadcast_drop

                                            if (child_yang_name == "dai-drop"):
                                                if (self.dai_drop is None):
                                                    self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                    self.dai_drop.parent = self
                                                    self._children_name_map["dai_drop"] = "dai-drop"
                                                return self.dai_drop

                                            if (child_yang_name == "disposition-mtu-drop"):
                                                if (self.disposition_mtu_drop is None):
                                                    self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                    self.disposition_mtu_drop.parent = self
                                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                return self.disposition_mtu_drop

                                            if (child_yang_name == "disposition-oo-o-drops"):
                                                if (self.disposition_oo_o_drops is None):
                                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                    self.disposition_oo_o_drops.parent = self
                                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                return self.disposition_oo_o_drops

                                            if (child_yang_name == "disposition-p2mp-stats"):
                                                if (self.disposition_p2mp_stats is None):
                                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                    self.disposition_p2mp_stats.parent = self
                                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                return self.disposition_p2mp_stats

                                            if (child_yang_name == "disposition-stat"):
                                                if (self.disposition_stat is None):
                                                    self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                    self.disposition_stat.parent = self
                                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                                return self.disposition_stat

                                            if (child_yang_name == "disposition-tail-drop"):
                                                if (self.disposition_tail_drop is None):
                                                    self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                    self.disposition_tail_drop.parent = self
                                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                return self.disposition_tail_drop

                                            if (child_yang_name == "ipsg-drop"):
                                                if (self.ipsg_drop is None):
                                                    self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                    self.ipsg_drop.parent = self
                                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                return self.ipsg_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "mac-move"):
                                                if (self.mac_move is None):
                                                    self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                    self.mac_move.parent = self
                                                    self._children_name_map["mac_move"] = "mac-move"
                                                return self.mac_move

                                            if (child_yang_name == "multicast-drop"):
                                                if (self.multicast_drop is None):
                                                    self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                    self.multicast_drop.parent = self
                                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                                return self.multicast_drop

                                            if (child_yang_name == "received-drops"):
                                                if (self.received_drops is None):
                                                    self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                    self.received_drops.parent = self
                                                    self._children_name_map["received_drops"] = "received-drops"
                                                return self.received_drops

                                            if (child_yang_name == "unicast-drop"):
                                                if (self.unicast_drop is None):
                                                    self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                    self.unicast_drop.parent = self
                                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                                return self.unicast_drop

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"

                                            self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                            self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                            self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                            self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bypassed_inbound_sequence_packet",
                                                            "bypassed_out_sequence_packet",
                                                            "sequence_number_expected",
                                                            "sequence_number_sent") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bypassed_inbound_sequence_packet.is_set or
                                                self.bypassed_out_sequence_packet.is_set or
                                                self.sequence_number_expected.is_set or
                                                self.sequence_number_sent.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                self.sequence_number_expected.yfilter != YFilter.not_set or
                                                self.sequence_number_sent.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sequence-number" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                            if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                            if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                            if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bypassed-inbound-sequence-packet"):
                                                self.bypassed_inbound_sequence_packet = value
                                                self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bypassed-out-sequence-packet"):
                                                self.bypassed_out_sequence_packet = value
                                                self.bypassed_out_sequence_packet.value_namespace = name_space
                                                self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-expected"):
                                                self.sequence_number_expected = value
                                                self.sequence_number_expected.value_namespace = name_space
                                                self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-sent"):
                                                self.sequence_number_sent = value
                                                self.sequence_number_sent.value_namespace = name_space
                                                self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                            (self.sequence_number is not None and self.sequence_number.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                            (self.sequence_number is not None and self.sequence_number.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "statistics" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dispostion-stats"):
                                            if (self.dispostion_stats is None):
                                                self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                                self.dispostion_stats.parent = self
                                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            return self.dispostion_stats

                                        if (child_yang_name == "impostion-stats"):
                                            if (self.impostion_stats is None):
                                                self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                                self.impostion_stats.parent = self
                                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                            return self.impostion_stats

                                        if (child_yang_name == "sequence-number"):
                                            if (self.sequence_number is None):
                                                self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                                self.sequence_number.parent = self
                                                self._children_name_map["sequence_number"] = "sequence-number"
                                            return self.sequence_number

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class P2MpPw(Entity):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__init__()

                                        self.yang_name = "p2mp-pw"
                                        self.yang_parent_name = "pseudowire"

                                        self.local_available = YLeaf(YType.boolean, "local-available")

                                        self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                        self.local_flags = YLeaf(YType.uint8, "local-flags")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                        self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                        self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                        self.remote_available = YLeaf(YType.boolean, "remote-available")

                                        self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                        self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                        self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                        self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_available",
                                                        "local_extended_tunnel_id",
                                                        "local_flags",
                                                        "local_label",
                                                        "local_p2mp_id",
                                                        "local_ptree_type",
                                                        "local_tunnel_id",
                                                        "remote_available",
                                                        "remote_extended_tunnel_id",
                                                        "remote_flags",
                                                        "remote_label",
                                                        "remote_p2mp_id",
                                                        "remote_ptree_type",
                                                        "remote_tunnel_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_available.is_set or
                                            self.local_extended_tunnel_id.is_set or
                                            self.local_flags.is_set or
                                            self.local_label.is_set or
                                            self.local_p2mp_id.is_set or
                                            self.local_ptree_type.is_set or
                                            self.local_tunnel_id.is_set or
                                            self.remote_available.is_set or
                                            self.remote_extended_tunnel_id.is_set or
                                            self.remote_flags.is_set or
                                            self.remote_label.is_set or
                                            self.remote_p2mp_id.is_set or
                                            self.remote_ptree_type.is_set or
                                            self.remote_tunnel_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_available.yfilter != YFilter.not_set or
                                            self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                            self.local_flags.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_p2mp_id.yfilter != YFilter.not_set or
                                            self.local_ptree_type.yfilter != YFilter.not_set or
                                            self.local_tunnel_id.yfilter != YFilter.not_set or
                                            self.remote_available.yfilter != YFilter.not_set or
                                            self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                            self.remote_flags.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_p2mp_id.yfilter != YFilter.not_set or
                                            self.remote_ptree_type.yfilter != YFilter.not_set or
                                            self.remote_tunnel_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "p2mp-pw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_available.get_name_leafdata())
                                        if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                        if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_flags.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                        if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                        if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                        if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_available.get_name_leafdata())
                                        if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                        if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                        if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                        if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-available"):
                                            self.local_available = value
                                            self.local_available.value_namespace = name_space
                                            self.local_available.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-extended-tunnel-id"):
                                            self.local_extended_tunnel_id = value
                                            self.local_extended_tunnel_id.value_namespace = name_space
                                            self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-flags"):
                                            self.local_flags = value
                                            self.local_flags.value_namespace = name_space
                                            self.local_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-p2mp-id"):
                                            self.local_p2mp_id = value
                                            self.local_p2mp_id.value_namespace = name_space
                                            self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ptree-type"):
                                            self.local_ptree_type = value
                                            self.local_ptree_type.value_namespace = name_space
                                            self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-tunnel-id"):
                                            self.local_tunnel_id = value
                                            self.local_tunnel_id.value_namespace = name_space
                                            self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-available"):
                                            self.remote_available = value
                                            self.remote_available.value_namespace = name_space
                                            self.remote_available.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-extended-tunnel-id"):
                                            self.remote_extended_tunnel_id = value
                                            self.remote_extended_tunnel_id.value_namespace = name_space
                                            self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-flags"):
                                            self.remote_flags = value
                                            self.remote_flags.value_namespace = name_space
                                            self.remote_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-p2mp-id"):
                                            self.remote_p2mp_id = value
                                            self.remote_p2mp_id.value_namespace = name_space
                                            self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ptree-type"):
                                            self.remote_ptree_type = value
                                            self.remote_ptree_type.value_namespace = name_space
                                            self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-tunnel-id"):
                                            self.remote_tunnel_id = value
                                            self.remote_tunnel_id.value_namespace = name_space
                                            self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.ad_method.is_set or
                                        self.ad_remote_down.is_set or
                                        self.admited_bw.is_set or
                                        self.auto_discovery.is_set or
                                        self.backup_active.is_set or
                                        self.backup_force_active.is_set or
                                        self.backup_pw.is_set or
                                        self.bitrate_mismatched.is_set or
                                        self.bridge_pw_type_mismatch.is_set or
                                        self.cas_mismatched.is_set or
                                        self.diff_ts_mismatched.is_set or
                                        self.disable_delay.is_set or
                                        self.disable_never.is_set or
                                        self.evpn_src_acid.is_set or
                                        self.fe_ctype.is_set or
                                        self.forward_class.is_set or
                                        self.freq_mismatched.is_set or
                                        self.illegal_control_word.is_set or
                                        self.imposed_vlan_id.is_set or
                                        self.interworking.is_set or
                                        self.ipv6_local_source_address.is_set or
                                        self.is_evpnvpws_type.is_set or
                                        self.is_flow_label_static.is_set or
                                        self.is_multi_segment_pseudowire.is_set or
                                        self.is_partially_programmed.is_set or
                                        self.is_pwr_type.is_set or
                                        self.is_vfi.is_set or
                                        self.last_time_status_changed.is_set or
                                        self.last_time_status_down.is_set or
                                        self.ldp_label_advertise_failed.is_set or
                                        self.load_balance.is_set or
                                        self.local_control_word.is_set or
                                        self.local_label_failed.is_set or
                                        self.local_pseudo_wire_type.is_set or
                                        self.local_source_address.is_set or
                                        self.mac_limit_oper_down.is_set or
                                        self.mtu_mismatched.is_set or
                                        self.not_supported_qinq.is_set or
                                        self.num_ma_cwithdraw_msg_received.is_set or
                                        self.number_ma_cwithdraw_message_sent.is_set or
                                        self.out_of_memory_state.is_set or
                                        self.payload_bytes_mismatched.is_set or
                                        self.payload_type_mismatched.is_set or
                                        self.preferred_path_disable_fallback.is_set or
                                        self.primary_peer_id.is_set or
                                        self.primary_pseudo_wire_id.is_set or
                                        self.primary_pw.is_set or
                                        self.protocol.is_set or
                                        self.pseudo_wire_id.is_set or
                                        self.pseudo_wire_state.is_set or
                                        self.pseudo_wire_type_mismatched.is_set or
                                        self.pw_class_name.is_set or
                                        self.pw_flow_label_code17_disabled.is_set or
                                        self.pw_flow_label_type.is_set or
                                        self.pw_flow_label_type_cfg.is_set or
                                        self.pw_redundancy_initial_delay.is_set or
                                        self.pw_redundancy_one_way.is_set or
                                        self.pw_status_use.is_set or
                                        self.pwlsd_rewrite_failed.is_set or
                                        self.remote_control_word.is_set or
                                        self.remote_label_failed.is_set or
                                        self.remote_pseudo_wire_type.is_set or
                                        self.required_bw.is_set or
                                        self.resync_enabled.is_set or
                                        self.resync_threshold.is_set or
                                        self.rtp_mismatched.is_set or
                                        self.sequencing_type.is_set or
                                        self.shutdown.is_set or
                                        self.sig_pkts_mismatched.is_set or
                                        self.ssrc_mismatched.is_set or
                                        self.state.is_set or
                                        self.table_policy_name.is_set or
                                        self.tag_rewrite.is_set or
                                        self.time_created.is_set or
                                        self.time_elapsed_creation.is_set or
                                        self.time_elapsed_status_changed.is_set or
                                        self.time_elapsed_status_down.is_set or
                                        self.transport_lsp_down.is_set or
                                        self.xconnect_id.is_set or
                                        (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                        (self.local_interface is not None and self.local_interface.has_data()) or
                                        (self.local_signalling is not None and self.local_signalling.has_data()) or
                                        (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                        (self.peer_id is not None and self.peer_id.has_data()) or
                                        (self.preferred_path is not None and self.preferred_path.has_data()) or
                                        (self.remote_interface is not None and self.remote_interface.has_data()) or
                                        (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                        (self.statistics is not None and self.statistics.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ad_method.yfilter != YFilter.not_set or
                                        self.ad_remote_down.yfilter != YFilter.not_set or
                                        self.admited_bw.yfilter != YFilter.not_set or
                                        self.auto_discovery.yfilter != YFilter.not_set or
                                        self.backup_active.yfilter != YFilter.not_set or
                                        self.backup_force_active.yfilter != YFilter.not_set or
                                        self.backup_pw.yfilter != YFilter.not_set or
                                        self.bitrate_mismatched.yfilter != YFilter.not_set or
                                        self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                        self.cas_mismatched.yfilter != YFilter.not_set or
                                        self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                        self.disable_delay.yfilter != YFilter.not_set or
                                        self.disable_never.yfilter != YFilter.not_set or
                                        self.evpn_src_acid.yfilter != YFilter.not_set or
                                        self.fe_ctype.yfilter != YFilter.not_set or
                                        self.forward_class.yfilter != YFilter.not_set or
                                        self.freq_mismatched.yfilter != YFilter.not_set or
                                        self.illegal_control_word.yfilter != YFilter.not_set or
                                        self.imposed_vlan_id.yfilter != YFilter.not_set or
                                        self.interworking.yfilter != YFilter.not_set or
                                        self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                        self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                        self.is_flow_label_static.yfilter != YFilter.not_set or
                                        self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                        self.is_partially_programmed.yfilter != YFilter.not_set or
                                        self.is_pwr_type.yfilter != YFilter.not_set or
                                        self.is_vfi.yfilter != YFilter.not_set or
                                        self.last_time_status_changed.yfilter != YFilter.not_set or
                                        self.last_time_status_down.yfilter != YFilter.not_set or
                                        self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                        self.load_balance.yfilter != YFilter.not_set or
                                        self.local_control_word.yfilter != YFilter.not_set or
                                        self.local_label_failed.yfilter != YFilter.not_set or
                                        self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                        self.local_source_address.yfilter != YFilter.not_set or
                                        self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                        self.mtu_mismatched.yfilter != YFilter.not_set or
                                        self.not_supported_qinq.yfilter != YFilter.not_set or
                                        self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                        self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                        self.out_of_memory_state.yfilter != YFilter.not_set or
                                        self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                        self.payload_type_mismatched.yfilter != YFilter.not_set or
                                        self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                        self.primary_peer_id.yfilter != YFilter.not_set or
                                        self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.primary_pw.yfilter != YFilter.not_set or
                                        self.protocol.yfilter != YFilter.not_set or
                                        self.pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.pseudo_wire_state.yfilter != YFilter.not_set or
                                        self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                        self.pw_class_name.yfilter != YFilter.not_set or
                                        self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                        self.pw_flow_label_type.yfilter != YFilter.not_set or
                                        self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                        self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                        self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                        self.pw_status_use.yfilter != YFilter.not_set or
                                        self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.remote_control_word.yfilter != YFilter.not_set or
                                        self.remote_label_failed.yfilter != YFilter.not_set or
                                        self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                        self.required_bw.yfilter != YFilter.not_set or
                                        self.resync_enabled.yfilter != YFilter.not_set or
                                        self.resync_threshold.yfilter != YFilter.not_set or
                                        self.rtp_mismatched.yfilter != YFilter.not_set or
                                        self.sequencing_type.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                        self.ssrc_mismatched.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.table_policy_name.yfilter != YFilter.not_set or
                                        self.tag_rewrite.yfilter != YFilter.not_set or
                                        self.time_created.yfilter != YFilter.not_set or
                                        self.time_elapsed_creation.yfilter != YFilter.not_set or
                                        self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                        self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                        self.transport_lsp_down.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                        (self.local_interface is not None and self.local_interface.has_operation()) or
                                        (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                        (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                        (self.peer_id is not None and self.peer_id.has_operation()) or
                                        (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                        (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                        (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                        (self.statistics is not None and self.statistics.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_method.get_name_leafdata())
                                    if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                    if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                    if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                    if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_active.get_name_leafdata())
                                    if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                    if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                    if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                    if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                    if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                    if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                    if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                    if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_never.get_name_leafdata())
                                    if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                    if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                    if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.forward_class.get_name_leafdata())
                                    if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                    if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                    if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                    if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interworking.get_name_leafdata())
                                    if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                    if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                    if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                    if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                    if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                    if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                    if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                    if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                    if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                    if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                    if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.load_balance.get_name_leafdata())
                                    if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                    if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                    if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                    if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                    if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                    if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                    if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                    if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                    if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                    if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                    if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                    if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                    if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                    if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                    if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                    if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol.get_name_leafdata())
                                    if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                    if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                    if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                    if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                    if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                    if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                    if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                    if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                    if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                    if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                    if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                    if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                    if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                    if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                    if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.required_bw.get_name_leafdata())
                                    if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                    if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                    if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                    if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                    if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                    if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                    if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_created.get_name_leafdata())
                                    if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                    if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                    if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                    if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "encapsulation-info"):
                                        if (self.encapsulation_info is None):
                                            self.encapsulation_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                            self.encapsulation_info.parent = self
                                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                        return self.encapsulation_info

                                    if (child_yang_name == "local-interface"):
                                        if (self.local_interface is None):
                                            self.local_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                            self.local_interface.parent = self
                                            self._children_name_map["local_interface"] = "local-interface"
                                        return self.local_interface

                                    if (child_yang_name == "local-signalling"):
                                        if (self.local_signalling is None):
                                            self.local_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                            self.local_signalling.parent = self
                                            self._children_name_map["local_signalling"] = "local-signalling"
                                        return self.local_signalling

                                    if (child_yang_name == "p2mp-pw"):
                                        if (self.p2mp_pw is None):
                                            self.p2mp_pw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                            self.p2mp_pw.parent = self
                                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                        return self.p2mp_pw

                                    if (child_yang_name == "peer-id"):
                                        if (self.peer_id is None):
                                            self.peer_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                            self.peer_id.parent = self
                                            self._children_name_map["peer_id"] = "peer-id"
                                        return self.peer_id

                                    if (child_yang_name == "preferred-path"):
                                        if (self.preferred_path is None):
                                            self.preferred_path = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                            self.preferred_path.parent = self
                                            self._children_name_map["preferred_path"] = "preferred-path"
                                        return self.preferred_path

                                    if (child_yang_name == "remote-interface"):
                                        if (self.remote_interface is None):
                                            self.remote_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                            self.remote_interface.parent = self
                                            self._children_name_map["remote_interface"] = "remote-interface"
                                        return self.remote_interface

                                    if (child_yang_name == "remote-signalling"):
                                        if (self.remote_signalling is None):
                                            self.remote_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                            self.remote_signalling.parent = self
                                            self._children_name_map["remote_signalling"] = "remote-signalling"
                                        return self.remote_signalling

                                    if (child_yang_name == "statistics"):
                                        if (self.statistics is None):
                                            self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                            self.statistics.parent = self
                                            self._children_name_map["statistics"] = "statistics"
                                        return self.statistics

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ad-method"):
                                        self.ad_method = value
                                        self.ad_method.value_namespace = name_space
                                        self.ad_method.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ad-remote-down"):
                                        self.ad_remote_down = value
                                        self.ad_remote_down.value_namespace = name_space
                                        self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "admited-bw"):
                                        self.admited_bw = value
                                        self.admited_bw.value_namespace = name_space
                                        self.admited_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "auto-discovery"):
                                        self.auto_discovery = value
                                        self.auto_discovery.value_namespace = name_space
                                        self.auto_discovery.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-active"):
                                        self.backup_active = value
                                        self.backup_active.value_namespace = name_space
                                        self.backup_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-force-active"):
                                        self.backup_force_active = value
                                        self.backup_force_active.value_namespace = name_space
                                        self.backup_force_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pw"):
                                        self.backup_pw = value
                                        self.backup_pw.value_namespace = name_space
                                        self.backup_pw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bitrate-mismatched"):
                                        self.bitrate_mismatched = value
                                        self.bitrate_mismatched.value_namespace = name_space
                                        self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bridge-pw-type-mismatch"):
                                        self.bridge_pw_type_mismatch = value
                                        self.bridge_pw_type_mismatch.value_namespace = name_space
                                        self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cas-mismatched"):
                                        self.cas_mismatched = value
                                        self.cas_mismatched.value_namespace = name_space
                                        self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "diff-ts-mismatched"):
                                        self.diff_ts_mismatched = value
                                        self.diff_ts_mismatched.value_namespace = name_space
                                        self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-delay"):
                                        self.disable_delay = value
                                        self.disable_delay.value_namespace = name_space
                                        self.disable_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-never"):
                                        self.disable_never = value
                                        self.disable_never.value_namespace = name_space
                                        self.disable_never.value_namespace_prefix = name_space_prefix
                                    if(value_path == "evpn-src-acid"):
                                        self.evpn_src_acid = value
                                        self.evpn_src_acid.value_namespace = name_space
                                        self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fe-ctype"):
                                        self.fe_ctype = value
                                        self.fe_ctype.value_namespace = name_space
                                        self.fe_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "forward-class"):
                                        self.forward_class = value
                                        self.forward_class.value_namespace = name_space
                                        self.forward_class.value_namespace_prefix = name_space_prefix
                                    if(value_path == "freq-mismatched"):
                                        self.freq_mismatched = value
                                        self.freq_mismatched.value_namespace = name_space
                                        self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "illegal-control-word"):
                                        self.illegal_control_word = value
                                        self.illegal_control_word.value_namespace = name_space
                                        self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "imposed-vlan-id"):
                                        self.imposed_vlan_id = value
                                        self.imposed_vlan_id.value_namespace = name_space
                                        self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interworking"):
                                        self.interworking = value
                                        self.interworking.value_namespace = name_space
                                        self.interworking.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-local-source-address"):
                                        self.ipv6_local_source_address = value
                                        self.ipv6_local_source_address.value_namespace = name_space
                                        self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-evpnvpws-type"):
                                        self.is_evpnvpws_type = value
                                        self.is_evpnvpws_type.value_namespace = name_space
                                        self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-flow-label-static"):
                                        self.is_flow_label_static = value
                                        self.is_flow_label_static.value_namespace = name_space
                                        self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-multi-segment-pseudowire"):
                                        self.is_multi_segment_pseudowire = value
                                        self.is_multi_segment_pseudowire.value_namespace = name_space
                                        self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-partially-programmed"):
                                        self.is_partially_programmed = value
                                        self.is_partially_programmed.value_namespace = name_space
                                        self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-pwr-type"):
                                        self.is_pwr_type = value
                                        self.is_pwr_type.value_namespace = name_space
                                        self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-vfi"):
                                        self.is_vfi = value
                                        self.is_vfi.value_namespace = name_space
                                        self.is_vfi.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-time-status-changed"):
                                        self.last_time_status_changed = value
                                        self.last_time_status_changed.value_namespace = name_space
                                        self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-time-status-down"):
                                        self.last_time_status_down = value
                                        self.last_time_status_down.value_namespace = name_space
                                        self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertise-failed"):
                                        self.ldp_label_advertise_failed = value
                                        self.ldp_label_advertise_failed.value_namespace = name_space
                                        self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "load-balance"):
                                        self.load_balance = value
                                        self.load_balance.value_namespace = name_space
                                        self.load_balance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-control-word"):
                                        self.local_control_word = value
                                        self.local_control_word.value_namespace = name_space
                                        self.local_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label-failed"):
                                        self.local_label_failed = value
                                        self.local_label_failed.value_namespace = name_space
                                        self.local_label_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-pseudo-wire-type"):
                                        self.local_pseudo_wire_type = value
                                        self.local_pseudo_wire_type.value_namespace = name_space
                                        self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-source-address"):
                                        self.local_source_address = value
                                        self.local_source_address.value_namespace = name_space
                                        self.local_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-oper-down"):
                                        self.mac_limit_oper_down = value
                                        self.mac_limit_oper_down.value_namespace = name_space
                                        self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-mismatched"):
                                        self.mtu_mismatched = value
                                        self.mtu_mismatched.value_namespace = name_space
                                        self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "not-supported-qinq"):
                                        self.not_supported_qinq = value
                                        self.not_supported_qinq.value_namespace = name_space
                                        self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                    if(value_path == "num-ma-cwithdraw-msg-received"):
                                        self.num_ma_cwithdraw_msg_received = value
                                        self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                        self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                    if(value_path == "number-ma-cwithdraw-message-sent"):
                                        self.number_ma_cwithdraw_message_sent = value
                                        self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                        self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                    if(value_path == "out-of-memory-state"):
                                        self.out_of_memory_state = value
                                        self.out_of_memory_state.value_namespace = name_space
                                        self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes-mismatched"):
                                        self.payload_bytes_mismatched = value
                                        self.payload_bytes_mismatched.value_namespace = name_space
                                        self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-type-mismatched"):
                                        self.payload_type_mismatched = value
                                        self.payload_type_mismatched.value_namespace = name_space
                                        self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "preferred-path-disable-fallback"):
                                        self.preferred_path_disable_fallback = value
                                        self.preferred_path_disable_fallback.value_namespace = name_space
                                        self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-peer-id"):
                                        self.primary_peer_id = value
                                        self.primary_peer_id.value_namespace = name_space
                                        self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-pseudo-wire-id"):
                                        self.primary_pseudo_wire_id = value
                                        self.primary_pseudo_wire_id.value_namespace = name_space
                                        self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-pw"):
                                        self.primary_pw = value
                                        self.primary_pw.value_namespace = name_space
                                        self.primary_pw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol"):
                                        self.protocol = value
                                        self.protocol.value_namespace = name_space
                                        self.protocol.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-id"):
                                        self.pseudo_wire_id = value
                                        self.pseudo_wire_id.value_namespace = name_space
                                        self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-state"):
                                        self.pseudo_wire_state = value
                                        self.pseudo_wire_state.value_namespace = name_space
                                        self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-type-mismatched"):
                                        self.pseudo_wire_type_mismatched = value
                                        self.pseudo_wire_type_mismatched.value_namespace = name_space
                                        self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-class-name"):
                                        self.pw_class_name = value
                                        self.pw_class_name.value_namespace = name_space
                                        self.pw_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-code17-disabled"):
                                        self.pw_flow_label_code17_disabled = value
                                        self.pw_flow_label_code17_disabled.value_namespace = name_space
                                        self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-type"):
                                        self.pw_flow_label_type = value
                                        self.pw_flow_label_type.value_namespace = name_space
                                        self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-type-cfg"):
                                        self.pw_flow_label_type_cfg = value
                                        self.pw_flow_label_type_cfg.value_namespace = name_space
                                        self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-redundancy-initial-delay"):
                                        self.pw_redundancy_initial_delay = value
                                        self.pw_redundancy_initial_delay.value_namespace = name_space
                                        self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-redundancy-one-way"):
                                        self.pw_redundancy_one_way = value
                                        self.pw_redundancy_one_way.value_namespace = name_space
                                        self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-status-use"):
                                        self.pw_status_use = value
                                        self.pw_status_use.value_namespace = name_space
                                        self.pw_status_use.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pwlsd-rewrite-failed"):
                                        self.pwlsd_rewrite_failed = value
                                        self.pwlsd_rewrite_failed.value_namespace = name_space
                                        self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-control-word"):
                                        self.remote_control_word = value
                                        self.remote_control_word.value_namespace = name_space
                                        self.remote_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label-failed"):
                                        self.remote_label_failed = value
                                        self.remote_label_failed.value_namespace = name_space
                                        self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-pseudo-wire-type"):
                                        self.remote_pseudo_wire_type = value
                                        self.remote_pseudo_wire_type.value_namespace = name_space
                                        self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "required-bw"):
                                        self.required_bw = value
                                        self.required_bw.value_namespace = name_space
                                        self.required_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resync-enabled"):
                                        self.resync_enabled = value
                                        self.resync_enabled.value_namespace = name_space
                                        self.resync_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resync-threshold"):
                                        self.resync_threshold = value
                                        self.resync_threshold.value_namespace = name_space
                                        self.resync_threshold.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rtp-mismatched"):
                                        self.rtp_mismatched = value
                                        self.rtp_mismatched.value_namespace = name_space
                                        self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequencing-type"):
                                        self.sequencing_type = value
                                        self.sequencing_type.value_namespace = name_space
                                        self.sequencing_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sig-pkts-mismatched"):
                                        self.sig_pkts_mismatched = value
                                        self.sig_pkts_mismatched.value_namespace = name_space
                                        self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ssrc-mismatched"):
                                        self.ssrc_mismatched = value
                                        self.ssrc_mismatched.value_namespace = name_space
                                        self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "table-policy-name"):
                                        self.table_policy_name = value
                                        self.table_policy_name.value_namespace = name_space
                                        self.table_policy_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tag-rewrite"):
                                        self.tag_rewrite = value
                                        self.tag_rewrite.value_namespace = name_space
                                        self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-created"):
                                        self.time_created = value
                                        self.time_created.value_namespace = name_space
                                        self.time_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-creation"):
                                        self.time_elapsed_creation = value
                                        self.time_elapsed_creation.value_namespace = name_space
                                        self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-status-changed"):
                                        self.time_elapsed_status_changed = value
                                        self.time_elapsed_status_changed.value_namespace = name_space
                                        self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-status-down"):
                                        self.time_elapsed_status_down = value
                                        self.time_elapsed_status_down.value_namespace = name_space
                                        self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transport-lsp-down"):
                                        self.transport_lsp_down = value
                                        self.transport_lsp_down.value_namespace = name_space
                                        self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-pw"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/base/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-pw"

                                    self.address = YLeaf(YType.str, "address")

                                    self.bmac = YLeaf(YType.str, "bmac")

                                    self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "bmac",
                                                    "next_hop_ip") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.bmac.is_set or
                                        self.next_hop_ip.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.bmac.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "static-mac" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bmac.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bmac"):
                                        self.bmac = value
                                        self.bmac.value_namespace = name_space
                                        self.bmac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.static_mac:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.is_access.is_set or
                                    self.neighbor.is_set or
                                    self.pseudowire_id.is_set or
                                    self.pw_type.is_set or
                                    self.ve_id_vpls_id_0_3.is_set or
                                    self.vpls_id_4_7.is_set or
                                    (self.pseudowire is not None and self.pseudowire.has_data()) or
                                    (self.security_parameters is not None and self.security_parameters.has_data()))

                            def has_operation(self):
                                for c in self.static_mac:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_access.yfilter != YFilter.not_set or
                                    self.neighbor.yfilter != YFilter.not_set or
                                    self.pseudowire_id.yfilter != YFilter.not_set or
                                    self.pw_type.yfilter != YFilter.not_set or
                                    self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set or
                                    self.vpls_id_4_7.yfilter != YFilter.not_set or
                                    (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bridge-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_access.get_name_leafdata())
                                if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor.get_name_leafdata())
                                if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudowire_id.get_name_leafdata())
                                if (self.pw_type.is_set or self.pw_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_type.get_name_leafdata())
                                if (self.ve_id_vpls_id_0_3.is_set or self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_id_vpls_id_0_3.get_name_leafdata())
                                if (self.vpls_id_4_7.is_set or self.vpls_id_4_7.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_4_7.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "pseudowire"):
                                    if (self.pseudowire is None):
                                        self.pseudowire = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                        self.pseudowire.parent = self
                                        self._children_name_map["pseudowire"] = "pseudowire"
                                    return self.pseudowire

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                if (child_yang_name == "static-mac"):
                                    for c in self.static_mac:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.static_mac.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id" or name == "pw-type" or name == "ve-id-vpls-id-0-3" or name == "vpls-id-4-7"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-access"):
                                    self.is_access = value
                                    self.is_access.value_namespace = name_space
                                    self.is_access.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor"):
                                    self.neighbor = value
                                    self.neighbor.value_namespace = name_space
                                    self.neighbor.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudowire-id"):
                                    self.pseudowire_id = value
                                    self.pseudowire_id.value_namespace = name_space
                                    self.pseudowire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-type"):
                                    self.pw_type = value
                                    self.pw_type.value_namespace = name_space
                                    self.pw_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-id-vpls-id-0-3"):
                                    self.ve_id_vpls_id_0_3 = value
                                    self.ve_id_vpls_id_0_3.value_namespace = name_space
                                    self.ve_id_vpls_id_0_3.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpls-id-4-7"):
                                    self.vpls_id_4_7 = value
                                    self.vpls_id_4_7.value_namespace = name_space
                                    self.vpls_id_4_7.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bridge_pw:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bridge_pw:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-pws" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bridge-pw"):
                                for c in self.bridge_pw:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bridge_pw.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-pw"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (self.bridge_pws is not None and self.bridge_pws.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bridge_pws is not None and self.bridge_pws.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-core-vfi-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-pws"):
                            if (self.bridge_pws is None):
                                self.bridge_pws = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                                self.bridge_pws.parent = self
                                self._children_name_map["bridge_pws"] = "bridge-pws"
                            return self.bridge_pws

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-pws"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BridgeAcs(Entity):
                    """
                    VPLS Bridge Domain Attachment Circuit Table
                    
                    .. attribute:: bridge_ac
                    
                    	VPLS Bridge Domain Attachment Circuit
                    	**type**\: list of    :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs, self).__init__()

                        self.yang_name = "bridge-acs"
                        self.yang_parent_name = "bridge-domain"

                        self.bridge_ac = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs, self).__setattr__(name, value)


                    class BridgeAc(Entity):
                        """
                        VPLS Bridge Domain Attachment Circuit
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                        
                        .. attribute:: bvi_mac_index
                        
                        	MyMac Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bvimac
                        
                        	BVI MAC addresses
                        	**type**\: list of    :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__init__()

                            self.yang_name = "bridge-ac"
                            self.yang_parent_name = "bridge-acs"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.bvi_mac_index = YLeaf(YType.uint16, "bvi-mac-index")

                            self.attachment_circuit = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            self._children_yang_names.add("attachment-circuit")

                            self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                            self._children_yang_names.add("security-parameters")

                            self.bvimac = YList(self)
                            self.static_mac = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "bvi_mac_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__setattr__(name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "bridge-ac"

                                self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                                self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                                self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                                self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                                self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                                self.msti = YLeaf(YType.str, "msti")

                                self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.node_id = YLeaf(YType.str, "node-id")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._children_yang_names.add("interface")

                                self.l2vpn_protection = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._children_yang_names.add("l2vpn-protection")

                                self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bvi_mac_conflict",
                                                "bvi_no_port_up",
                                                "control_word_mismatched",
                                                "encapsulation_error",
                                                "encapsulation_mismatched",
                                                "evpn_internal_label",
                                                "interface_handle",
                                                "internal_ms_ti",
                                                "interworking",
                                                "is_ac_partially_programmed",
                                                "mac_limit_oper_down",
                                                "ms_ti_mismatch",
                                                "msti",
                                                "msti_mismatch_down",
                                                "mtu_mismatched",
                                                "node_id",
                                                "out_of_memory_state",
                                                "redundancy_group_id",
                                                "redundancy_group_state",
                                                "redundancy_object_id",
                                                "state",
                                                "tdm_media_mismatched",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__setattr__(name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class L2VpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.protected_name = YLeaf(YType.str, "protected-name")

                                    self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                    self.protection_name = YLeaf(YType.str, "protection-name")

                                    self.protection_type = YLeaf(YType.enumeration, "protection-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "protected_name",
                                                    "protection_configured",
                                                    "protection_name",
                                                    "protection_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.protected_name.is_set or
                                        self.protection_configured.is_set or
                                        self.protection_name.is_set or
                                        self.protection_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.protected_name.yfilter != YFilter.not_set or
                                        self.protection_configured.yfilter != YFilter.not_set or
                                        self.protection_name.yfilter != YFilter.not_set or
                                        self.protection_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2vpn-protection" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protected_name.get_name_leafdata())
                                    if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                    if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_name.get_name_leafdata())
                                    if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protected-name"):
                                        self.protected_name = value
                                        self.protected_name.value_namespace = name_space
                                        self.protected_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-configured"):
                                        self.protection_configured = value
                                        self.protection_configured.value_namespace = name_space
                                        self.protection_configured.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-name"):
                                        self.protection_name = value
                                        self.protection_name.value_namespace = name_space
                                        self.protection_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-type"):
                                        self.protection_type = value
                                        self.protection_type.value_namespace = name_space
                                        self.protection_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bvi_mac_conflict.is_set or
                                    self.bvi_no_port_up.is_set or
                                    self.control_word_mismatched.is_set or
                                    self.encapsulation_error.is_set or
                                    self.encapsulation_mismatched.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.interface_handle.is_set or
                                    self.internal_ms_ti.is_set or
                                    self.interworking.is_set or
                                    self.is_ac_partially_programmed.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.ms_ti_mismatch.is_set or
                                    self.msti.is_set or
                                    self.msti_mismatch_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.node_id.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_group_state.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.state.is_set or
                                    self.tdm_media_mismatched.is_set or
                                    self.xconnect_id.is_set or
                                    (self.interface is not None and self.interface.has_data()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                    self.bvi_no_port_up.yfilter != YFilter.not_set or
                                    self.control_word_mismatched.yfilter != YFilter.not_set or
                                    self.encapsulation_error.yfilter != YFilter.not_set or
                                    self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.internal_ms_ti.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                    self.msti.yfilter != YFilter.not_set or
                                    self.msti_mismatch_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_group_state.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.interface is not None and self.interface.has_operation()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "attachment-circuit" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                                if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                                if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                                if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                                if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface"):
                                    if (self.interface is None):
                                        self.interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                        self.interface.parent = self
                                        self._children_name_map["interface"] = "interface"
                                    return self.interface

                                if (child_yang_name == "l2vpn-protection"):
                                    if (self.l2vpn_protection is None):
                                        self.l2vpn_protection = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                                        self.l2vpn_protection.parent = self
                                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    return self.l2vpn_protection

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bvi-mac-conflict"):
                                    self.bvi_mac_conflict = value
                                    self.bvi_mac_conflict.value_namespace = name_space
                                    self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-no-port-up"):
                                    self.bvi_no_port_up = value
                                    self.bvi_no_port_up.value_namespace = name_space
                                    self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-word-mismatched"):
                                    self.control_word_mismatched = value
                                    self.control_word_mismatched.value_namespace = name_space
                                    self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-error"):
                                    self.encapsulation_error = value
                                    self.encapsulation_error.value_namespace = name_space
                                    self.encapsulation_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-mismatched"):
                                    self.encapsulation_mismatched = value
                                    self.encapsulation_mismatched.value_namespace = name_space
                                    self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-ms-ti"):
                                    self.internal_ms_ti = value
                                    self.internal_ms_ti.value_namespace = name_space
                                    self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ac-partially-programmed"):
                                    self.is_ac_partially_programmed = value
                                    self.is_ac_partially_programmed.value_namespace = name_space
                                    self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ms-ti-mismatch"):
                                    self.ms_ti_mismatch = value
                                    self.ms_ti_mismatch.value_namespace = name_space
                                    self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti"):
                                    self.msti = value
                                    self.msti.value_namespace = name_space
                                    self.msti.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-mismatch-down"):
                                    self.msti_mismatch_down = value
                                    self.msti_mismatch_down.value_namespace = name_space
                                    self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-state"):
                                    self.redundancy_group_state = value
                                    self.redundancy_group_state.value_namespace = name_space
                                    self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "tdm-media-mismatched"):
                                    self.tdm_media_mismatched = value
                                    self.tdm_media_mismatched.value_namespace = name_space
                                    self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-ac"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dhcpv4_trust",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                    self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                    self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                    self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                    self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                    self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                    self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                    self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                    self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                    self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                    self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                    self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                    self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                    self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                    self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                    self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                    self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                    self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                    self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                    self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                    self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                    self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                    self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                    self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                    self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                    self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                    self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                    self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                    self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                    self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dai_address_validation_mask",
                                                    "dhcpv4_profile_name",
                                                    "dhcpv4_snoop",
                                                    "flood_unknown_unicast_enabled",
                                                    "flood_uu_disabled_mac_limit_action",
                                                    "igm_pv4_disabled",
                                                    "igm_pv4_profile_name",
                                                    "is_dai_addr_validate_destination_mac_enabled",
                                                    "is_dai_addr_validate_ipv4_enabled",
                                                    "is_dai_addr_validate_source_mac_enabled",
                                                    "is_dai_enabled",
                                                    "is_dai_logging_enabled",
                                                    "is_ip_source_guard_enabled",
                                                    "is_ipsg_logging_enabled",
                                                    "is_mac_secure_accept_shutdown_enabled",
                                                    "is_mac_secure_enabled",
                                                    "is_mac_secure_logging_enabled",
                                                    "learn_disabled_mac_limit_action",
                                                    "mac_aging_mode",
                                                    "mac_aging_time",
                                                    "mac_flooding",
                                                    "mac_learning",
                                                    "mac_limit",
                                                    "mac_limit_action",
                                                    "mac_limit_notification",
                                                    "mac_limit_reached",
                                                    "mac_port_down_flush_enabled",
                                                    "mac_secure_action",
                                                    "mld_profile_name",
                                                    "mmrp_flood_optimization",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "split_horizon_group_id",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__setattr__(name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dai_address_validation_mask.is_set or
                                        self.dhcpv4_profile_name.is_set or
                                        self.dhcpv4_snoop.is_set or
                                        self.flood_unknown_unicast_enabled.is_set or
                                        self.flood_uu_disabled_mac_limit_action.is_set or
                                        self.igm_pv4_disabled.is_set or
                                        self.igm_pv4_profile_name.is_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                        self.is_dai_addr_validate_ipv4_enabled.is_set or
                                        self.is_dai_addr_validate_source_mac_enabled.is_set or
                                        self.is_dai_enabled.is_set or
                                        self.is_dai_logging_enabled.is_set or
                                        self.is_ip_source_guard_enabled.is_set or
                                        self.is_ipsg_logging_enabled.is_set or
                                        self.is_mac_secure_accept_shutdown_enabled.is_set or
                                        self.is_mac_secure_enabled.is_set or
                                        self.is_mac_secure_logging_enabled.is_set or
                                        self.learn_disabled_mac_limit_action.is_set or
                                        self.mac_aging_mode.is_set or
                                        self.mac_aging_time.is_set or
                                        self.mac_flooding.is_set or
                                        self.mac_learning.is_set or
                                        self.mac_limit.is_set or
                                        self.mac_limit_action.is_set or
                                        self.mac_limit_notification.is_set or
                                        self.mac_limit_reached.is_set or
                                        self.mac_port_down_flush_enabled.is_set or
                                        self.mac_secure_action.is_set or
                                        self.mld_profile_name.is_set or
                                        self.mmrp_flood_optimization.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.split_horizon_group_id.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                        self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                        self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                        self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                        self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                        self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                        self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                        self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_aging_mode.yfilter != YFilter.not_set or
                                        self.mac_aging_time.yfilter != YFilter.not_set or
                                        self.mac_flooding.yfilter != YFilter.not_set or
                                        self.mac_learning.yfilter != YFilter.not_set or
                                        self.mac_limit.yfilter != YFilter.not_set or
                                        self.mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_limit_notification.yfilter != YFilter.not_set or
                                        self.mac_limit_reached.yfilter != YFilter.not_set or
                                        self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                        self.mac_secure_action.yfilter != YFilter.not_set or
                                        self.mld_profile_name.yfilter != YFilter.not_set or
                                        self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.split_horizon_group_id.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                    if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                    if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                    if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                    if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                    if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                    if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                    if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                    if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                    if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                    if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                    if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                    if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                    if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                    if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                    if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                    if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                    if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                    if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                    if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                    if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                    if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dai-address-validation-mask"):
                                        self.dai_address_validation_mask = value
                                        self.dai_address_validation_mask.value_namespace = name_space
                                        self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-profile-name"):
                                        self.dhcpv4_profile_name = value
                                        self.dhcpv4_profile_name.value_namespace = name_space
                                        self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-snoop"):
                                        self.dhcpv4_snoop = value
                                        self.dhcpv4_snoop.value_namespace = name_space
                                        self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-unknown-unicast-enabled"):
                                        self.flood_unknown_unicast_enabled = value
                                        self.flood_unknown_unicast_enabled.value_namespace = name_space
                                        self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-uu-disabled-mac-limit-action"):
                                        self.flood_uu_disabled_mac_limit_action = value
                                        self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                        self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-disabled"):
                                        self.igm_pv4_disabled = value
                                        self.igm_pv4_disabled.value_namespace = name_space
                                        self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-profile-name"):
                                        self.igm_pv4_profile_name = value
                                        self.igm_pv4_profile_name.value_namespace = name_space
                                        self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                        self.is_dai_addr_validate_destination_mac_enabled = value
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                        self.is_dai_addr_validate_ipv4_enabled = value
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                        self.is_dai_addr_validate_source_mac_enabled = value
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-enabled"):
                                        self.is_dai_enabled = value
                                        self.is_dai_enabled.value_namespace = name_space
                                        self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-logging-enabled"):
                                        self.is_dai_logging_enabled = value
                                        self.is_dai_logging_enabled.value_namespace = name_space
                                        self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ip-source-guard-enabled"):
                                        self.is_ip_source_guard_enabled = value
                                        self.is_ip_source_guard_enabled.value_namespace = name_space
                                        self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ipsg-logging-enabled"):
                                        self.is_ipsg_logging_enabled = value
                                        self.is_ipsg_logging_enabled.value_namespace = name_space
                                        self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                        self.is_mac_secure_accept_shutdown_enabled = value
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-enabled"):
                                        self.is_mac_secure_enabled = value
                                        self.is_mac_secure_enabled.value_namespace = name_space
                                        self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-logging-enabled"):
                                        self.is_mac_secure_logging_enabled = value
                                        self.is_mac_secure_logging_enabled.value_namespace = name_space
                                        self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "learn-disabled-mac-limit-action"):
                                        self.learn_disabled_mac_limit_action = value
                                        self.learn_disabled_mac_limit_action.value_namespace = name_space
                                        self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-mode"):
                                        self.mac_aging_mode = value
                                        self.mac_aging_mode.value_namespace = name_space
                                        self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-time"):
                                        self.mac_aging_time = value
                                        self.mac_aging_time.value_namespace = name_space
                                        self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flooding"):
                                        self.mac_flooding = value
                                        self.mac_flooding.value_namespace = name_space
                                        self.mac_flooding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-learning"):
                                        self.mac_learning = value
                                        self.mac_learning.value_namespace = name_space
                                        self.mac_learning.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit"):
                                        self.mac_limit = value
                                        self.mac_limit.value_namespace = name_space
                                        self.mac_limit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-action"):
                                        self.mac_limit_action = value
                                        self.mac_limit_action.value_namespace = name_space
                                        self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-notification"):
                                        self.mac_limit_notification = value
                                        self.mac_limit_notification.value_namespace = name_space
                                        self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-reached"):
                                        self.mac_limit_reached = value
                                        self.mac_limit_reached.value_namespace = name_space
                                        self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-port-down-flush-enabled"):
                                        self.mac_port_down_flush_enabled = value
                                        self.mac_port_down_flush_enabled.value_namespace = name_space
                                        self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-secure-action"):
                                        self.mac_secure_action = value
                                        self.mac_secure_action.value_namespace = name_space
                                        self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mld-profile-name"):
                                        self.mld_profile_name = value
                                        self.mld_profile_name.value_namespace = name_space
                                        self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mmrp-flood-optimization"):
                                        self.mmrp_flood_optimization = value
                                        self.mmrp_flood_optimization.value_namespace = name_space
                                        self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "split-horizon-group-id"):
                                        self.split_horizon_group_id = value
                                        self.split_horizon_group_id.value_namespace = name_space
                                        self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dhcpv4_trust.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dhcpv4_trust.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-trust"):
                                    self.dhcpv4_trust = value
                                    self.dhcpv4_trust.value_namespace = name_space
                                    self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "bridge-ac"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "static-mac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix


                        class Bvimac(Entity):
                            """
                            BVI MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__init__()

                                self.yang_name = "bvimac"
                                self.yang_parent_name = "bridge-ac"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bvimac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bvimac:
                                if (c.has_data()):
                                    return True
                            for c in self.static_mac:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.bvi_mac_index.is_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                                (self.security_parameters is not None and self.security_parameters.has_data()))

                        def has_operation(self):
                            for c in self.bvimac:
                                if (c.has_operation()):
                                    return True
                            for c in self.static_mac:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.bvi_mac_index.yfilter != YFilter.not_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                                (self.security_parameters is not None and self.security_parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-ac" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-acs/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.bvi_mac_index.is_set or self.bvi_mac_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "attachment-circuit"):
                                if (self.attachment_circuit is None):
                                    self.attachment_circuit = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                                    self.attachment_circuit.parent = self
                                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                return self.attachment_circuit

                            if (child_yang_name == "bvimac"):
                                for c in self.bvimac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bvimac.append(c)
                                return c

                            if (child_yang_name == "security-parameters"):
                                if (self.security_parameters is None):
                                    self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                return self.security_parameters

                            if (child_yang_name == "static-mac"):
                                for c in self.static_mac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.static_mac.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "attachment-circuit" or name == "bvimac" or name == "security-parameters" or name == "static-mac" or name == "interface-name" or name == "bvi-mac-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-mac-index"):
                                self.bvi_mac_index = value
                                self.bvi_mac_index.value_namespace = name_space
                                self.bvi_mac_index.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bridge_ac:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bridge_ac:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-acs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-ac"):
                            for c in self.bridge_ac:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bridge_ac.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-ac"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BridgeAccessPws(Entity):
                    """
                    VPLS Bridge Domain Access Pseudowire Table
                    
                    .. attribute:: bridge_access_pw
                    
                    	VPLS Bridge Domain Access Pseudowire
                    	**type**\: list of    :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__init__()

                        self.yang_name = "bridge-access-pws"
                        self.yang_parent_name = "bridge-domain"

                        self.bridge_access_pw = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__setattr__(name, value)


                    class BridgeAccessPw(Entity):
                        """
                        VPLS Bridge Domain Access Pseudowire
                        
                        .. attribute:: is_access
                        
                        	Is Access PW
                        	**type**\:  bool
                        
                        .. attribute:: neighbor
                        
                        	Neighbor IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                        
                        .. attribute:: pseudowire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__init__()

                            self.yang_name = "bridge-access-pw"
                            self.yang_parent_name = "bridge-access-pws"

                            self.is_access = YLeaf(YType.boolean, "is-access")

                            self.neighbor = YLeaf(YType.str, "neighbor")

                            self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                            self.pseudowire = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                            self.pseudowire.parent = self
                            self._children_name_map["pseudowire"] = "pseudowire"
                            self._children_yang_names.add("pseudowire")

                            self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                            self._children_yang_names.add("security-parameters")

                            self.static_mac = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("is_access",
                                            "neighbor",
                                            "pseudowire_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__setattr__(name, value)


                        class Pseudowire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__init__()

                                self.yang_name = "pseudowire"
                                self.yang_parent_name = "bridge-access-pw"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                self.backup_active = YLeaf(YType.boolean, "backup-active")

                                self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                self.disable_never = YLeaf(YType.boolean, "disable-never")

                                self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                self.local_source_address = YLeaf(YType.str, "local-source-address")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                self.required_bw = YLeaf(YType.uint32, "required-bw")

                                self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                self.time_created = YLeaf(YType.str, "time-created")

                                self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.encapsulation_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                self._children_yang_names.add("encapsulation-info")

                                self.local_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                                self._children_yang_names.add("local-interface")

                                self.local_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                                self._children_yang_names.add("local-signalling")

                                self.p2mp_pw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._children_yang_names.add("p2mp-pw")

                                self.peer_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                                self._children_yang_names.add("peer-id")

                                self.preferred_path = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                                self._children_yang_names.add("preferred-path")

                                self.remote_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                                self._children_yang_names.add("remote-interface")

                                self.remote_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                self._children_yang_names.add("remote-signalling")

                                self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_remote_down",
                                                "admited_bw",
                                                "auto_discovery",
                                                "backup_active",
                                                "backup_force_active",
                                                "backup_pw",
                                                "bitrate_mismatched",
                                                "bridge_pw_type_mismatch",
                                                "cas_mismatched",
                                                "diff_ts_mismatched",
                                                "disable_delay",
                                                "disable_never",
                                                "evpn_src_acid",
                                                "fe_ctype",
                                                "forward_class",
                                                "freq_mismatched",
                                                "illegal_control_word",
                                                "imposed_vlan_id",
                                                "interworking",
                                                "ipv6_local_source_address",
                                                "is_evpnvpws_type",
                                                "is_flow_label_static",
                                                "is_multi_segment_pseudowire",
                                                "is_partially_programmed",
                                                "is_pwr_type",
                                                "is_vfi",
                                                "last_time_status_changed",
                                                "last_time_status_down",
                                                "ldp_label_advertise_failed",
                                                "load_balance",
                                                "local_control_word",
                                                "local_label_failed",
                                                "local_pseudo_wire_type",
                                                "local_source_address",
                                                "mac_limit_oper_down",
                                                "mtu_mismatched",
                                                "not_supported_qinq",
                                                "num_ma_cwithdraw_msg_received",
                                                "number_ma_cwithdraw_message_sent",
                                                "out_of_memory_state",
                                                "payload_bytes_mismatched",
                                                "payload_type_mismatched",
                                                "preferred_path_disable_fallback",
                                                "primary_peer_id",
                                                "primary_pseudo_wire_id",
                                                "primary_pw",
                                                "protocol",
                                                "pseudo_wire_id",
                                                "pseudo_wire_state",
                                                "pseudo_wire_type_mismatched",
                                                "pw_class_name",
                                                "pw_flow_label_code17_disabled",
                                                "pw_flow_label_type",
                                                "pw_flow_label_type_cfg",
                                                "pw_redundancy_initial_delay",
                                                "pw_redundancy_one_way",
                                                "pw_status_use",
                                                "pwlsd_rewrite_failed",
                                                "remote_control_word",
                                                "remote_label_failed",
                                                "remote_pseudo_wire_type",
                                                "required_bw",
                                                "resync_enabled",
                                                "resync_threshold",
                                                "rtp_mismatched",
                                                "sequencing_type",
                                                "shutdown",
                                                "sig_pkts_mismatched",
                                                "ssrc_mismatched",
                                                "state",
                                                "table_policy_name",
                                                "tag_rewrite",
                                                "time_created",
                                                "time_elapsed_creation",
                                                "time_elapsed_status_changed",
                                                "time_elapsed_status_down",
                                                "transport_lsp_down",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__setattr__(name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudowire"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                    self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                    self.type = YLeaf(YType.enumeration, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "ipv4_peer_id",
                                                    "ipv6_peer_id",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.ipv4_peer_id.is_set or
                                        self.ipv6_peer_id.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.ipv4_peer_id.yfilter != YFilter.not_set or
                                        self.ipv6_peer_id.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "peer-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                    if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-peer-id"):
                                        self.ipv4_peer_id = value
                                        self.ipv4_peer_id.value_namespace = name_space
                                        self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-peer-id"):
                                        self.ipv6_peer_id = value
                                        self.ipv6_peer_id.value_namespace = name_space
                                        self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudowire"

                                    self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                    self.atom = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                    self.l2tpv3 = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._children_yang_names.add("l2tpv3")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                        self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                        self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                        self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                        self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                        self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                        self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                        self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                        self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                        self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                        self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                        self.local_veid = YLeaf(YType.uint32, "local-veid")

                                        self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                        self.rem_saii = YLeaf(YType.str, "rem-saii")

                                        self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                        self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                        self.rem_taii = YLeaf(YType.str, "rem-taii")

                                        self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                        self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                        self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                        self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                        self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                        self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                        self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                        self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                        self.saii = YLeaf(YType.str, "saii")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.taii = YLeaf(YType.str, "taii")

                                        self.local_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                        self._children_yang_names.add("local-agi")

                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._children_yang_names.add("multi-segment-pseudowire-stats")

                                        self.remote_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                        self._children_yang_names.add("remote-agi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_pseudowire_headend",
                                                        "is_sai_itype2",
                                                        "is_tai_itype2",
                                                        "ldp_label_advertisment_failed",
                                                        "local_c_ctype",
                                                        "local_ceid",
                                                        "local_cv_type",
                                                        "local_group_id",
                                                        "local_label",
                                                        "local_ldp_id",
                                                        "local_saii_gbl_id",
                                                        "local_saiiac_id",
                                                        "local_taii_gbl_id",
                                                        "local_taiiac_id",
                                                        "local_veid",
                                                        "lsd_rewrite_failed",
                                                        "rem_saii",
                                                        "rem_saii_gbl_id",
                                                        "rem_saiiac_id",
                                                        "rem_taii",
                                                        "rem_taii_gbl_id",
                                                        "rem_taiiac_id",
                                                        "remote_c_ctype",
                                                        "remote_ceid",
                                                        "remote_cv_type",
                                                        "remote_group_id",
                                                        "remote_label",
                                                        "remote_ldp_id",
                                                        "remote_source_address",
                                                        "remote_veid",
                                                        "saii",
                                                        "source_address",
                                                        "taii") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"

                                            self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                            self.received_packets = YLeaf(YType.uint64, "received-packets")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("received_bytes",
                                                            "received_packets") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.received_bytes.is_set or
                                                self.received_packets.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.received_bytes.yfilter != YFilter.not_set or
                                                self.received_packets.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                            if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_packets.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "received-bytes" or name == "received-packets"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "received-bytes"):
                                                self.received_bytes = value
                                                self.received_bytes.value_namespace = name_space
                                                self.received_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "received-packets"):
                                                self.received_packets = value
                                                self.received_packets.value_namespace = name_space
                                                self.received_packets.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_pseudowire_headend.is_set or
                                            self.is_sai_itype2.is_set or
                                            self.is_tai_itype2.is_set or
                                            self.ldp_label_advertisment_failed.is_set or
                                            self.local_c_ctype.is_set or
                                            self.local_ceid.is_set or
                                            self.local_cv_type.is_set or
                                            self.local_group_id.is_set or
                                            self.local_label.is_set or
                                            self.local_ldp_id.is_set or
                                            self.local_saii_gbl_id.is_set or
                                            self.local_saiiac_id.is_set or
                                            self.local_taii_gbl_id.is_set or
                                            self.local_taiiac_id.is_set or
                                            self.local_veid.is_set or
                                            self.lsd_rewrite_failed.is_set or
                                            self.rem_saii.is_set or
                                            self.rem_saii_gbl_id.is_set or
                                            self.rem_saiiac_id.is_set or
                                            self.rem_taii.is_set or
                                            self.rem_taii_gbl_id.is_set or
                                            self.rem_taiiac_id.is_set or
                                            self.remote_c_ctype.is_set or
                                            self.remote_ceid.is_set or
                                            self.remote_cv_type.is_set or
                                            self.remote_group_id.is_set or
                                            self.remote_label.is_set or
                                            self.remote_ldp_id.is_set or
                                            self.remote_source_address.is_set or
                                            self.remote_veid.is_set or
                                            self.saii.is_set or
                                            self.source_address.is_set or
                                            self.taii.is_set or
                                            (self.local_agi is not None and self.local_agi.has_data()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                            (self.remote_agi is not None and self.remote_agi.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                            self.is_sai_itype2.yfilter != YFilter.not_set or
                                            self.is_tai_itype2.yfilter != YFilter.not_set or
                                            self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                            self.local_c_ctype.yfilter != YFilter.not_set or
                                            self.local_ceid.yfilter != YFilter.not_set or
                                            self.local_cv_type.yfilter != YFilter.not_set or
                                            self.local_group_id.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_ldp_id.yfilter != YFilter.not_set or
                                            self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_saiiac_id.yfilter != YFilter.not_set or
                                            self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_taiiac_id.yfilter != YFilter.not_set or
                                            self.local_veid.yfilter != YFilter.not_set or
                                            self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.rem_saii.yfilter != YFilter.not_set or
                                            self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_saiiac_id.yfilter != YFilter.not_set or
                                            self.rem_taii.yfilter != YFilter.not_set or
                                            self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_taiiac_id.yfilter != YFilter.not_set or
                                            self.remote_c_ctype.yfilter != YFilter.not_set or
                                            self.remote_ceid.yfilter != YFilter.not_set or
                                            self.remote_cv_type.yfilter != YFilter.not_set or
                                            self.remote_group_id.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_ldp_id.yfilter != YFilter.not_set or
                                            self.remote_source_address.yfilter != YFilter.not_set or
                                            self.remote_veid.yfilter != YFilter.not_set or
                                            self.saii.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.taii.yfilter != YFilter.not_set or
                                            (self.local_agi is not None and self.local_agi.has_operation()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                            (self.remote_agi is not None and self.remote_agi.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                        if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                        if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                        if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                        if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                        if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                        if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                        if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                        if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                        if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                        if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                        if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                        if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_veid.get_name_leafdata())
                                        if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                        if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                        if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                        if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                        if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                        if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                        if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                        if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                        if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                        if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                        if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                        if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                        if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                        if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saii.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.taii.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local-agi"):
                                            if (self.local_agi is None):
                                                self.local_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                            return self.local_agi

                                        if (child_yang_name == "multi-segment-pseudowire-stats"):
                                            if (self.multi_segment_pseudowire_stats is None):
                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            return self.multi_segment_pseudowire_stats

                                        if (child_yang_name == "remote-agi"):
                                            if (self.remote_agi is None):
                                                self.remote_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                            return self.remote_agi

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-pseudowire-headend"):
                                            self.is_pseudowire_headend = value
                                            self.is_pseudowire_headend.value_namespace = name_space
                                            self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-sai-itype2"):
                                            self.is_sai_itype2 = value
                                            self.is_sai_itype2.value_namespace = name_space
                                            self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-tai-itype2"):
                                            self.is_tai_itype2 = value
                                            self.is_tai_itype2.value_namespace = name_space
                                            self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertisment-failed"):
                                            self.ldp_label_advertisment_failed = value
                                            self.ldp_label_advertisment_failed.value_namespace = name_space
                                            self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-c-ctype"):
                                            self.local_c_ctype = value
                                            self.local_c_ctype.value_namespace = name_space
                                            self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ceid"):
                                            self.local_ceid = value
                                            self.local_ceid.value_namespace = name_space
                                            self.local_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cv-type"):
                                            self.local_cv_type = value
                                            self.local_cv_type.value_namespace = name_space
                                            self.local_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-group-id"):
                                            self.local_group_id = value
                                            self.local_group_id.value_namespace = name_space
                                            self.local_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ldp-id"):
                                            self.local_ldp_id = value
                                            self.local_ldp_id.value_namespace = name_space
                                            self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saii-gbl-id"):
                                            self.local_saii_gbl_id = value
                                            self.local_saii_gbl_id.value_namespace = name_space
                                            self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saiiac-id"):
                                            self.local_saiiac_id = value
                                            self.local_saiiac_id.value_namespace = name_space
                                            self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taii-gbl-id"):
                                            self.local_taii_gbl_id = value
                                            self.local_taii_gbl_id.value_namespace = name_space
                                            self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taiiac-id"):
                                            self.local_taiiac_id = value
                                            self.local_taiiac_id.value_namespace = name_space
                                            self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-veid"):
                                            self.local_veid = value
                                            self.local_veid.value_namespace = name_space
                                            self.local_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsd-rewrite-failed"):
                                            self.lsd_rewrite_failed = value
                                            self.lsd_rewrite_failed.value_namespace = name_space
                                            self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii"):
                                            self.rem_saii = value
                                            self.rem_saii.value_namespace = name_space
                                            self.rem_saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii-gbl-id"):
                                            self.rem_saii_gbl_id = value
                                            self.rem_saii_gbl_id.value_namespace = name_space
                                            self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saiiac-id"):
                                            self.rem_saiiac_id = value
                                            self.rem_saiiac_id.value_namespace = name_space
                                            self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii"):
                                            self.rem_taii = value
                                            self.rem_taii.value_namespace = name_space
                                            self.rem_taii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii-gbl-id"):
                                            self.rem_taii_gbl_id = value
                                            self.rem_taii_gbl_id.value_namespace = name_space
                                            self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taiiac-id"):
                                            self.rem_taiiac_id = value
                                            self.rem_taiiac_id.value_namespace = name_space
                                            self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-c-ctype"):
                                            self.remote_c_ctype = value
                                            self.remote_c_ctype.value_namespace = name_space
                                            self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ceid"):
                                            self.remote_ceid = value
                                            self.remote_ceid.value_namespace = name_space
                                            self.remote_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cv-type"):
                                            self.remote_cv_type = value
                                            self.remote_cv_type.value_namespace = name_space
                                            self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-group-id"):
                                            self.remote_group_id = value
                                            self.remote_group_id.value_namespace = name_space
                                            self.remote_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ldp-id"):
                                            self.remote_ldp_id = value
                                            self.remote_ldp_id.value_namespace = name_space
                                            self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-source-address"):
                                            self.remote_source_address = value
                                            self.remote_source_address.value_namespace = name_space
                                            self.remote_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-veid"):
                                            self.remote_veid = value
                                            self.remote_veid.value_namespace = name_space
                                            self.remote_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saii"):
                                            self.saii = value
                                            self.saii.value_namespace = name_space
                                            self.saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "taii"):
                                            self.taii = value
                                            self.taii.value_namespace = name_space
                                            self.taii.value_namespace_prefix = name_space_prefix


                                class L2Tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                        self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                        self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                        self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                        self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                        self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                        self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                        self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                        self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                        self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                        self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                        self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                        self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                        self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                        self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                        self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                        self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                        self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                        self.tos = YLeaf(YType.uint8, "tos")

                                        self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dont_fragment_bit",
                                                        "ipv4_source_address",
                                                        "ipv6_source_address",
                                                        "l2tp_class_name",
                                                        "local_cookie_high_value",
                                                        "local_cookie_low_value",
                                                        "local_cookie_size",
                                                        "local_secondary_cookie_high_value",
                                                        "local_secondary_cookie_low_value",
                                                        "local_secondary_cookie_size",
                                                        "local_session_id",
                                                        "path_mtu_enabled",
                                                        "path_mtu_max_value",
                                                        "remote_circuit_status_up",
                                                        "remote_cookie_high_value",
                                                        "remote_cookie_low_value",
                                                        "remote_cookie_size",
                                                        "remote_session_id",
                                                        "tos",
                                                        "tos_mode",
                                                        "ttl",
                                                        "tunnel_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dont_fragment_bit.is_set or
                                            self.ipv4_source_address.is_set or
                                            self.ipv6_source_address.is_set or
                                            self.l2tp_class_name.is_set or
                                            self.local_cookie_high_value.is_set or
                                            self.local_cookie_low_value.is_set or
                                            self.local_cookie_size.is_set or
                                            self.local_secondary_cookie_high_value.is_set or
                                            self.local_secondary_cookie_low_value.is_set or
                                            self.local_secondary_cookie_size.is_set or
                                            self.local_session_id.is_set or
                                            self.path_mtu_enabled.is_set or
                                            self.path_mtu_max_value.is_set or
                                            self.remote_circuit_status_up.is_set or
                                            self.remote_cookie_high_value.is_set or
                                            self.remote_cookie_low_value.is_set or
                                            self.remote_cookie_size.is_set or
                                            self.remote_session_id.is_set or
                                            self.tos.is_set or
                                            self.tos_mode.is_set or
                                            self.ttl.is_set or
                                            self.tunnel_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dont_fragment_bit.yfilter != YFilter.not_set or
                                            self.ipv4_source_address.yfilter != YFilter.not_set or
                                            self.ipv6_source_address.yfilter != YFilter.not_set or
                                            self.l2tp_class_name.yfilter != YFilter.not_set or
                                            self.local_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_cookie_size.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                            self.local_session_id.yfilter != YFilter.not_set or
                                            self.path_mtu_enabled.yfilter != YFilter.not_set or
                                            self.path_mtu_max_value.yfilter != YFilter.not_set or
                                            self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                            self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_size.yfilter != YFilter.not_set or
                                            self.remote_session_id.yfilter != YFilter.not_set or
                                            self.tos.yfilter != YFilter.not_set or
                                            self.tos_mode.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.tunnel_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv3" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                        if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                        if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                        if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                        if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                        if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                        if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                        if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                        if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                        if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                        if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                        if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                        if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                        if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                        if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                        if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                        if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos.get_name_leafdata())
                                        if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dont-fragment-bit"):
                                            self.dont_fragment_bit = value
                                            self.dont_fragment_bit.value_namespace = name_space
                                            self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-source-address"):
                                            self.ipv4_source_address = value
                                            self.ipv4_source_address.value_namespace = name_space
                                            self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-source-address"):
                                            self.ipv6_source_address = value
                                            self.ipv6_source_address.value_namespace = name_space
                                            self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l2tp-class-name"):
                                            self.l2tp_class_name = value
                                            self.l2tp_class_name.value_namespace = name_space
                                            self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-high-value"):
                                            self.local_cookie_high_value = value
                                            self.local_cookie_high_value.value_namespace = name_space
                                            self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-low-value"):
                                            self.local_cookie_low_value = value
                                            self.local_cookie_low_value.value_namespace = name_space
                                            self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-size"):
                                            self.local_cookie_size = value
                                            self.local_cookie_size.value_namespace = name_space
                                            self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-high-value"):
                                            self.local_secondary_cookie_high_value = value
                                            self.local_secondary_cookie_high_value.value_namespace = name_space
                                            self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-low-value"):
                                            self.local_secondary_cookie_low_value = value
                                            self.local_secondary_cookie_low_value.value_namespace = name_space
                                            self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-size"):
                                            self.local_secondary_cookie_size = value
                                            self.local_secondary_cookie_size.value_namespace = name_space
                                            self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-session-id"):
                                            self.local_session_id = value
                                            self.local_session_id.value_namespace = name_space
                                            self.local_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-enabled"):
                                            self.path_mtu_enabled = value
                                            self.path_mtu_enabled.value_namespace = name_space
                                            self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-max-value"):
                                            self.path_mtu_max_value = value
                                            self.path_mtu_max_value.value_namespace = name_space
                                            self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-circuit-status-up"):
                                            self.remote_circuit_status_up = value
                                            self.remote_circuit_status_up.value_namespace = name_space
                                            self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-high-value"):
                                            self.remote_cookie_high_value = value
                                            self.remote_cookie_high_value.value_namespace = name_space
                                            self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-low-value"):
                                            self.remote_cookie_low_value = value
                                            self.remote_cookie_low_value.value_namespace = name_space
                                            self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-size"):
                                            self.remote_cookie_size = value
                                            self.remote_cookie_size.value_namespace = name_space
                                            self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-session-id"):
                                            self.remote_session_id = value
                                            self.remote_session_id.value_namespace = name_space
                                            self.remote_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos"):
                                            self.tos = value
                                            self.tos.value_namespace = name_space
                                            self.tos.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-mode"):
                                            self.tos_mode = value
                                            self.tos_mode.value_namespace = name_space
                                            self.tos_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tunnel-state"):
                                            self.tunnel_state = value
                                            self.tunnel_state.value_namespace = name_space
                                            self.tunnel_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.encapsulation.is_set or
                                        (self.atom is not None and self.atom.has_data()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "encapsulation-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    if (child_yang_name == "l2tpv3"):
                                        if (self.l2tpv3 is None):
                                            self.l2tpv3 = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                        return self.l2tpv3

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation"):
                                        self.encapsulation = value
                                        self.encapsulation.value_namespace = name_space
                                        self.encapsulation.value_namespace_prefix = name_space_prefix


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudowire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudowire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudowire"

                                    self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                    self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                    self.option = YLeaf(YType.enumeration, "option")

                                    self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                    self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ip_tunnel_interface_number",
                                                    "next_hop_ip",
                                                    "option",
                                                    "te_tunnel_interface_number",
                                                    "tp_tunnel_interface_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ip_tunnel_interface_number.is_set or
                                        self.next_hop_ip.is_set or
                                        self.option.is_set or
                                        self.te_tunnel_interface_number.is_set or
                                        self.tp_tunnel_interface_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set or
                                        self.option.yfilter != YFilter.not_set or
                                        self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "preferred-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                    if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.option.get_name_leafdata())
                                    if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                    if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ip-tunnel-interface-number"):
                                        self.ip_tunnel_interface_number = value
                                        self.ip_tunnel_interface_number.value_namespace = name_space
                                        self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                    if(value_path == "option"):
                                        self.option = value
                                        self.option.value_namespace = name_space
                                        self.option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-tunnel-interface-number"):
                                        self.te_tunnel_interface_number = value
                                        self.te_tunnel_interface_number.value_namespace = name_space
                                        self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tp-tunnel-interface-number"):
                                        self.tp_tunnel_interface_number = value
                                        self.tp_tunnel_interface_number.value_namespace = name_space
                                        self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudowire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudowire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudowire"

                                    self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class P2MpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudowire"

                                    self.local_available = YLeaf(YType.boolean, "local-available")

                                    self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                    self.local_flags = YLeaf(YType.uint8, "local-flags")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                    self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                    self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                    self.remote_available = YLeaf(YType.boolean, "remote-available")

                                    self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                    self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                    self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                    self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_available",
                                                    "local_extended_tunnel_id",
                                                    "local_flags",
                                                    "local_label",
                                                    "local_p2mp_id",
                                                    "local_ptree_type",
                                                    "local_tunnel_id",
                                                    "remote_available",
                                                    "remote_extended_tunnel_id",
                                                    "remote_flags",
                                                    "remote_label",
                                                    "remote_p2mp_id",
                                                    "remote_ptree_type",
                                                    "remote_tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_available.is_set or
                                        self.local_extended_tunnel_id.is_set or
                                        self.local_flags.is_set or
                                        self.local_label.is_set or
                                        self.local_p2mp_id.is_set or
                                        self.local_ptree_type.is_set or
                                        self.local_tunnel_id.is_set or
                                        self.remote_available.is_set or
                                        self.remote_extended_tunnel_id.is_set or
                                        self.remote_flags.is_set or
                                        self.remote_label.is_set or
                                        self.remote_p2mp_id.is_set or
                                        self.remote_ptree_type.is_set or
                                        self.remote_tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_available.yfilter != YFilter.not_set or
                                        self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.local_flags.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_p2mp_id.yfilter != YFilter.not_set or
                                        self.local_ptree_type.yfilter != YFilter.not_set or
                                        self.local_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_available.yfilter != YFilter.not_set or
                                        self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_flags.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_p2mp_id.yfilter != YFilter.not_set or
                                        self.remote_ptree_type.yfilter != YFilter.not_set or
                                        self.remote_tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_available.get_name_leafdata())
                                    if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                    if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_flags.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                    if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                    if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                    if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_available.get_name_leafdata())
                                    if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                    if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                    if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                    if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-available"):
                                        self.local_available = value
                                        self.local_available.value_namespace = name_space
                                        self.local_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-extended-tunnel-id"):
                                        self.local_extended_tunnel_id = value
                                        self.local_extended_tunnel_id.value_namespace = name_space
                                        self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-flags"):
                                        self.local_flags = value
                                        self.local_flags.value_namespace = name_space
                                        self.local_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-p2mp-id"):
                                        self.local_p2mp_id = value
                                        self.local_p2mp_id.value_namespace = name_space
                                        self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ptree-type"):
                                        self.local_ptree_type = value
                                        self.local_ptree_type.value_namespace = name_space
                                        self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-tunnel-id"):
                                        self.local_tunnel_id = value
                                        self.local_tunnel_id.value_namespace = name_space
                                        self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-available"):
                                        self.remote_available = value
                                        self.remote_available.value_namespace = name_space
                                        self.remote_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-extended-tunnel-id"):
                                        self.remote_extended_tunnel_id = value
                                        self.remote_extended_tunnel_id.value_namespace = name_space
                                        self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-flags"):
                                        self.remote_flags = value
                                        self.remote_flags.value_namespace = name_space
                                        self.remote_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-p2mp-id"):
                                        self.remote_p2mp_id = value
                                        self.remote_p2mp_id.value_namespace = name_space
                                        self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ptree-type"):
                                        self.remote_ptree_type = value
                                        self.remote_ptree_type.value_namespace = name_space
                                        self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-tunnel-id"):
                                        self.remote_tunnel_id = value
                                        self.remote_tunnel_id.value_namespace = name_space
                                        self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ad_method.is_set or
                                    self.ad_remote_down.is_set or
                                    self.admited_bw.is_set or
                                    self.auto_discovery.is_set or
                                    self.backup_active.is_set or
                                    self.backup_force_active.is_set or
                                    self.backup_pw.is_set or
                                    self.bitrate_mismatched.is_set or
                                    self.bridge_pw_type_mismatch.is_set or
                                    self.cas_mismatched.is_set or
                                    self.diff_ts_mismatched.is_set or
                                    self.disable_delay.is_set or
                                    self.disable_never.is_set or
                                    self.evpn_src_acid.is_set or
                                    self.fe_ctype.is_set or
                                    self.forward_class.is_set or
                                    self.freq_mismatched.is_set or
                                    self.illegal_control_word.is_set or
                                    self.imposed_vlan_id.is_set or
                                    self.interworking.is_set or
                                    self.ipv6_local_source_address.is_set or
                                    self.is_evpnvpws_type.is_set or
                                    self.is_flow_label_static.is_set or
                                    self.is_multi_segment_pseudowire.is_set or
                                    self.is_partially_programmed.is_set or
                                    self.is_pwr_type.is_set or
                                    self.is_vfi.is_set or
                                    self.last_time_status_changed.is_set or
                                    self.last_time_status_down.is_set or
                                    self.ldp_label_advertise_failed.is_set or
                                    self.load_balance.is_set or
                                    self.local_control_word.is_set or
                                    self.local_label_failed.is_set or
                                    self.local_pseudo_wire_type.is_set or
                                    self.local_source_address.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.not_supported_qinq.is_set or
                                    self.num_ma_cwithdraw_msg_received.is_set or
                                    self.number_ma_cwithdraw_message_sent.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.payload_bytes_mismatched.is_set or
                                    self.payload_type_mismatched.is_set or
                                    self.preferred_path_disable_fallback.is_set or
                                    self.primary_peer_id.is_set or
                                    self.primary_pseudo_wire_id.is_set or
                                    self.primary_pw.is_set or
                                    self.protocol.is_set or
                                    self.pseudo_wire_id.is_set or
                                    self.pseudo_wire_state.is_set or
                                    self.pseudo_wire_type_mismatched.is_set or
                                    self.pw_class_name.is_set or
                                    self.pw_flow_label_code17_disabled.is_set or
                                    self.pw_flow_label_type.is_set or
                                    self.pw_flow_label_type_cfg.is_set or
                                    self.pw_redundancy_initial_delay.is_set or
                                    self.pw_redundancy_one_way.is_set or
                                    self.pw_status_use.is_set or
                                    self.pwlsd_rewrite_failed.is_set or
                                    self.remote_control_word.is_set or
                                    self.remote_label_failed.is_set or
                                    self.remote_pseudo_wire_type.is_set or
                                    self.required_bw.is_set or
                                    self.resync_enabled.is_set or
                                    self.resync_threshold.is_set or
                                    self.rtp_mismatched.is_set or
                                    self.sequencing_type.is_set or
                                    self.shutdown.is_set or
                                    self.sig_pkts_mismatched.is_set or
                                    self.ssrc_mismatched.is_set or
                                    self.state.is_set or
                                    self.table_policy_name.is_set or
                                    self.tag_rewrite.is_set or
                                    self.time_created.is_set or
                                    self.time_elapsed_creation.is_set or
                                    self.time_elapsed_status_changed.is_set or
                                    self.time_elapsed_status_down.is_set or
                                    self.transport_lsp_down.is_set or
                                    self.xconnect_id.is_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                    (self.local_interface is not None and self.local_interface.has_data()) or
                                    (self.local_signalling is not None and self.local_signalling.has_data()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                    (self.peer_id is not None and self.peer_id.has_data()) or
                                    (self.preferred_path is not None and self.preferred_path.has_data()) or
                                    (self.remote_interface is not None and self.remote_interface.has_data()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_remote_down.yfilter != YFilter.not_set or
                                    self.admited_bw.yfilter != YFilter.not_set or
                                    self.auto_discovery.yfilter != YFilter.not_set or
                                    self.backup_active.yfilter != YFilter.not_set or
                                    self.backup_force_active.yfilter != YFilter.not_set or
                                    self.backup_pw.yfilter != YFilter.not_set or
                                    self.bitrate_mismatched.yfilter != YFilter.not_set or
                                    self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                    self.cas_mismatched.yfilter != YFilter.not_set or
                                    self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                    self.disable_delay.yfilter != YFilter.not_set or
                                    self.disable_never.yfilter != YFilter.not_set or
                                    self.evpn_src_acid.yfilter != YFilter.not_set or
                                    self.fe_ctype.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.freq_mismatched.yfilter != YFilter.not_set or
                                    self.illegal_control_word.yfilter != YFilter.not_set or
                                    self.imposed_vlan_id.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                    self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                    self.is_flow_label_static.yfilter != YFilter.not_set or
                                    self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                    self.is_partially_programmed.yfilter != YFilter.not_set or
                                    self.is_pwr_type.yfilter != YFilter.not_set or
                                    self.is_vfi.yfilter != YFilter.not_set or
                                    self.last_time_status_changed.yfilter != YFilter.not_set or
                                    self.last_time_status_down.yfilter != YFilter.not_set or
                                    self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                    self.load_balance.yfilter != YFilter.not_set or
                                    self.local_control_word.yfilter != YFilter.not_set or
                                    self.local_label_failed.yfilter != YFilter.not_set or
                                    self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.local_source_address.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.not_supported_qinq.yfilter != YFilter.not_set or
                                    self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                    self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                    self.payload_type_mismatched.yfilter != YFilter.not_set or
                                    self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                    self.primary_peer_id.yfilter != YFilter.not_set or
                                    self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.primary_pw.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.pseudo_wire_state.yfilter != YFilter.not_set or
                                    self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                    self.pw_class_name.yfilter != YFilter.not_set or
                                    self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                    self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                    self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                    self.pw_status_use.yfilter != YFilter.not_set or
                                    self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.remote_control_word.yfilter != YFilter.not_set or
                                    self.remote_label_failed.yfilter != YFilter.not_set or
                                    self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.required_bw.yfilter != YFilter.not_set or
                                    self.resync_enabled.yfilter != YFilter.not_set or
                                    self.resync_threshold.yfilter != YFilter.not_set or
                                    self.rtp_mismatched.yfilter != YFilter.not_set or
                                    self.sequencing_type.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                    self.ssrc_mismatched.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.table_policy_name.yfilter != YFilter.not_set or
                                    self.tag_rewrite.yfilter != YFilter.not_set or
                                    self.time_created.yfilter != YFilter.not_set or
                                    self.time_elapsed_creation.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                    self.transport_lsp_down.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                    (self.local_interface is not None and self.local_interface.has_operation()) or
                                    (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                    (self.peer_id is not None and self.peer_id.has_operation()) or
                                    (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                    (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pseudowire" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_active.get_name_leafdata())
                                if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_never.get_name_leafdata())
                                if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance.get_name_leafdata())
                                if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())
                                if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.required_bw.get_name_leafdata())
                                if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_created.get_name_leafdata())
                                if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "encapsulation-info"):
                                    if (self.encapsulation_info is None):
                                        self.encapsulation_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    return self.encapsulation_info

                                if (child_yang_name == "local-interface"):
                                    if (self.local_interface is None):
                                        self.local_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                    return self.local_interface

                                if (child_yang_name == "local-signalling"):
                                    if (self.local_signalling is None):
                                        self.local_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                    return self.local_signalling

                                if (child_yang_name == "p2mp-pw"):
                                    if (self.p2mp_pw is None):
                                        self.p2mp_pw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    return self.p2mp_pw

                                if (child_yang_name == "peer-id"):
                                    if (self.peer_id is None):
                                        self.peer_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                    return self.peer_id

                                if (child_yang_name == "preferred-path"):
                                    if (self.preferred_path is None):
                                        self.preferred_path = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                    return self.preferred_path

                                if (child_yang_name == "remote-interface"):
                                    if (self.remote_interface is None):
                                        self.remote_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                    return self.remote_interface

                                if (child_yang_name == "remote-signalling"):
                                    if (self.remote_signalling is None):
                                        self.remote_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                    return self.remote_signalling

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-remote-down"):
                                    self.ad_remote_down = value
                                    self.ad_remote_down.value_namespace = name_space
                                    self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "admited-bw"):
                                    self.admited_bw = value
                                    self.admited_bw.value_namespace = name_space
                                    self.admited_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "auto-discovery"):
                                    self.auto_discovery = value
                                    self.auto_discovery.value_namespace = name_space
                                    self.auto_discovery.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-active"):
                                    self.backup_active = value
                                    self.backup_active.value_namespace = name_space
                                    self.backup_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-force-active"):
                                    self.backup_force_active = value
                                    self.backup_force_active.value_namespace = name_space
                                    self.backup_force_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-pw"):
                                    self.backup_pw = value
                                    self.backup_pw.value_namespace = name_space
                                    self.backup_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "bitrate-mismatched"):
                                    self.bitrate_mismatched = value
                                    self.bitrate_mismatched.value_namespace = name_space
                                    self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-pw-type-mismatch"):
                                    self.bridge_pw_type_mismatch = value
                                    self.bridge_pw_type_mismatch.value_namespace = name_space
                                    self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "cas-mismatched"):
                                    self.cas_mismatched = value
                                    self.cas_mismatched.value_namespace = name_space
                                    self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "diff-ts-mismatched"):
                                    self.diff_ts_mismatched = value
                                    self.diff_ts_mismatched.value_namespace = name_space
                                    self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-delay"):
                                    self.disable_delay = value
                                    self.disable_delay.value_namespace = name_space
                                    self.disable_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-never"):
                                    self.disable_never = value
                                    self.disable_never.value_namespace = name_space
                                    self.disable_never.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-src-acid"):
                                    self.evpn_src_acid = value
                                    self.evpn_src_acid.value_namespace = name_space
                                    self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                if(value_path == "fe-ctype"):
                                    self.fe_ctype = value
                                    self.fe_ctype.value_namespace = name_space
                                    self.fe_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "freq-mismatched"):
                                    self.freq_mismatched = value
                                    self.freq_mismatched.value_namespace = name_space
                                    self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-control-word"):
                                    self.illegal_control_word = value
                                    self.illegal_control_word.value_namespace = name_space
                                    self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "imposed-vlan-id"):
                                    self.imposed_vlan_id = value
                                    self.imposed_vlan_id.value_namespace = name_space
                                    self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-local-source-address"):
                                    self.ipv6_local_source_address = value
                                    self.ipv6_local_source_address.value_namespace = name_space
                                    self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpnvpws-type"):
                                    self.is_evpnvpws_type = value
                                    self.is_evpnvpws_type.value_namespace = name_space
                                    self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-flow-label-static"):
                                    self.is_flow_label_static = value
                                    self.is_flow_label_static.value_namespace = name_space
                                    self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-multi-segment-pseudowire"):
                                    self.is_multi_segment_pseudowire = value
                                    self.is_multi_segment_pseudowire.value_namespace = name_space
                                    self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-partially-programmed"):
                                    self.is_partially_programmed = value
                                    self.is_partially_programmed.value_namespace = name_space
                                    self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pwr-type"):
                                    self.is_pwr_type = value
                                    self.is_pwr_type.value_namespace = name_space
                                    self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vfi"):
                                    self.is_vfi = value
                                    self.is_vfi.value_namespace = name_space
                                    self.is_vfi.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-changed"):
                                    self.last_time_status_changed = value
                                    self.last_time_status_changed.value_namespace = name_space
                                    self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-down"):
                                    self.last_time_status_down = value
                                    self.last_time_status_down.value_namespace = name_space
                                    self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertise-failed"):
                                    self.ldp_label_advertise_failed = value
                                    self.ldp_label_advertise_failed.value_namespace = name_space
                                    self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance"):
                                    self.load_balance = value
                                    self.load_balance.value_namespace = name_space
                                    self.load_balance.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-control-word"):
                                    self.local_control_word = value
                                    self.local_control_word.value_namespace = name_space
                                    self.local_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label-failed"):
                                    self.local_label_failed = value
                                    self.local_label_failed.value_namespace = name_space
                                    self.local_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-pseudo-wire-type"):
                                    self.local_pseudo_wire_type = value
                                    self.local_pseudo_wire_type.value_namespace = name_space
                                    self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-source-address"):
                                    self.local_source_address = value
                                    self.local_source_address.value_namespace = name_space
                                    self.local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-supported-qinq"):
                                    self.not_supported_qinq = value
                                    self.not_supported_qinq.value_namespace = name_space
                                    self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                if(value_path == "num-ma-cwithdraw-msg-received"):
                                    self.num_ma_cwithdraw_msg_received = value
                                    self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                    self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-ma-cwithdraw-message-sent"):
                                    self.number_ma_cwithdraw_message_sent = value
                                    self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                    self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes-mismatched"):
                                    self.payload_bytes_mismatched = value
                                    self.payload_bytes_mismatched.value_namespace = name_space
                                    self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-type-mismatched"):
                                    self.payload_type_mismatched = value
                                    self.payload_type_mismatched.value_namespace = name_space
                                    self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "preferred-path-disable-fallback"):
                                    self.preferred_path_disable_fallback = value
                                    self.preferred_path_disable_fallback.value_namespace = name_space
                                    self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-peer-id"):
                                    self.primary_peer_id = value
                                    self.primary_peer_id.value_namespace = name_space
                                    self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pseudo-wire-id"):
                                    self.primary_pseudo_wire_id = value
                                    self.primary_pseudo_wire_id.value_namespace = name_space
                                    self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pw"):
                                    self.primary_pw = value
                                    self.primary_pw.value_namespace = name_space
                                    self.primary_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id"):
                                    self.pseudo_wire_id = value
                                    self.pseudo_wire_id.value_namespace = name_space
                                    self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-state"):
                                    self.pseudo_wire_state = value
                                    self.pseudo_wire_state.value_namespace = name_space
                                    self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-type-mismatched"):
                                    self.pseudo_wire_type_mismatched = value
                                    self.pseudo_wire_type_mismatched.value_namespace = name_space
                                    self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-class-name"):
                                    self.pw_class_name = value
                                    self.pw_class_name.value_namespace = name_space
                                    self.pw_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-code17-disabled"):
                                    self.pw_flow_label_code17_disabled = value
                                    self.pw_flow_label_code17_disabled.value_namespace = name_space
                                    self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type"):
                                    self.pw_flow_label_type = value
                                    self.pw_flow_label_type.value_namespace = name_space
                                    self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type-cfg"):
                                    self.pw_flow_label_type_cfg = value
                                    self.pw_flow_label_type_cfg.value_namespace = name_space
                                    self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-initial-delay"):
                                    self.pw_redundancy_initial_delay = value
                                    self.pw_redundancy_initial_delay.value_namespace = name_space
                                    self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-one-way"):
                                    self.pw_redundancy_one_way = value
                                    self.pw_redundancy_one_way.value_namespace = name_space
                                    self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-status-use"):
                                    self.pw_status_use = value
                                    self.pw_status_use.value_namespace = name_space
                                    self.pw_status_use.value_namespace_prefix = name_space_prefix
                                if(value_path == "pwlsd-rewrite-failed"):
                                    self.pwlsd_rewrite_failed = value
                                    self.pwlsd_rewrite_failed.value_namespace = name_space
                                    self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-control-word"):
                                    self.remote_control_word = value
                                    self.remote_control_word.value_namespace = name_space
                                    self.remote_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label-failed"):
                                    self.remote_label_failed = value
                                    self.remote_label_failed.value_namespace = name_space
                                    self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-pseudo-wire-type"):
                                    self.remote_pseudo_wire_type = value
                                    self.remote_pseudo_wire_type.value_namespace = name_space
                                    self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "required-bw"):
                                    self.required_bw = value
                                    self.required_bw.value_namespace = name_space
                                    self.required_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-enabled"):
                                    self.resync_enabled = value
                                    self.resync_enabled.value_namespace = name_space
                                    self.resync_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-threshold"):
                                    self.resync_threshold = value
                                    self.resync_threshold.value_namespace = name_space
                                    self.resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "rtp-mismatched"):
                                    self.rtp_mismatched = value
                                    self.rtp_mismatched.value_namespace = name_space
                                    self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequencing-type"):
                                    self.sequencing_type = value
                                    self.sequencing_type.value_namespace = name_space
                                    self.sequencing_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "sig-pkts-mismatched"):
                                    self.sig_pkts_mismatched = value
                                    self.sig_pkts_mismatched.value_namespace = name_space
                                    self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "ssrc-mismatched"):
                                    self.ssrc_mismatched = value
                                    self.ssrc_mismatched.value_namespace = name_space
                                    self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-policy-name"):
                                    self.table_policy_name = value
                                    self.table_policy_name.value_namespace = name_space
                                    self.table_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag-rewrite"):
                                    self.tag_rewrite = value
                                    self.tag_rewrite.value_namespace = name_space
                                    self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-created"):
                                    self.time_created = value
                                    self.time_created.value_namespace = name_space
                                    self.time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-creation"):
                                    self.time_elapsed_creation = value
                                    self.time_elapsed_creation.value_namespace = name_space
                                    self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-changed"):
                                    self.time_elapsed_status_changed = value
                                    self.time_elapsed_status_changed.value_namespace = name_space
                                    self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-down"):
                                    self.time_elapsed_status_down = value
                                    self.time_elapsed_status_down.value_namespace = name_space
                                    self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-lsp-down"):
                                    self.transport_lsp_down = value
                                    self.transport_lsp_down.value_namespace = name_space
                                    self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-access-pw"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dhcpv4_trust",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                    self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                    self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                    self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                    self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                    self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                    self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                    self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                    self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                    self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                    self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                    self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                    self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                    self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                    self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                    self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                    self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                    self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                    self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                    self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                    self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                    self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                    self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                    self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                    self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                    self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                    self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                    self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                    self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                    self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dai_address_validation_mask",
                                                    "dhcpv4_profile_name",
                                                    "dhcpv4_snoop",
                                                    "flood_unknown_unicast_enabled",
                                                    "flood_uu_disabled_mac_limit_action",
                                                    "igm_pv4_disabled",
                                                    "igm_pv4_profile_name",
                                                    "is_dai_addr_validate_destination_mac_enabled",
                                                    "is_dai_addr_validate_ipv4_enabled",
                                                    "is_dai_addr_validate_source_mac_enabled",
                                                    "is_dai_enabled",
                                                    "is_dai_logging_enabled",
                                                    "is_ip_source_guard_enabled",
                                                    "is_ipsg_logging_enabled",
                                                    "is_mac_secure_accept_shutdown_enabled",
                                                    "is_mac_secure_enabled",
                                                    "is_mac_secure_logging_enabled",
                                                    "learn_disabled_mac_limit_action",
                                                    "mac_aging_mode",
                                                    "mac_aging_time",
                                                    "mac_flooding",
                                                    "mac_learning",
                                                    "mac_limit",
                                                    "mac_limit_action",
                                                    "mac_limit_notification",
                                                    "mac_limit_reached",
                                                    "mac_port_down_flush_enabled",
                                                    "mac_secure_action",
                                                    "mld_profile_name",
                                                    "mmrp_flood_optimization",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "split_horizon_group_id",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__setattr__(name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/base/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dai_address_validation_mask.is_set or
                                        self.dhcpv4_profile_name.is_set or
                                        self.dhcpv4_snoop.is_set or
                                        self.flood_unknown_unicast_enabled.is_set or
                                        self.flood_uu_disabled_mac_limit_action.is_set or
                                        self.igm_pv4_disabled.is_set or
                                        self.igm_pv4_profile_name.is_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                        self.is_dai_addr_validate_ipv4_enabled.is_set or
                                        self.is_dai_addr_validate_source_mac_enabled.is_set or
                                        self.is_dai_enabled.is_set or
                                        self.is_dai_logging_enabled.is_set or
                                        self.is_ip_source_guard_enabled.is_set or
                                        self.is_ipsg_logging_enabled.is_set or
                                        self.is_mac_secure_accept_shutdown_enabled.is_set or
                                        self.is_mac_secure_enabled.is_set or
                                        self.is_mac_secure_logging_enabled.is_set or
                                        self.learn_disabled_mac_limit_action.is_set or
                                        self.mac_aging_mode.is_set or
                                        self.mac_aging_time.is_set or
                                        self.mac_flooding.is_set or
                                        self.mac_learning.is_set or
                                        self.mac_limit.is_set or
                                        self.mac_limit_action.is_set or
                                        self.mac_limit_notification.is_set or
                                        self.mac_limit_reached.is_set or
                                        self.mac_port_down_flush_enabled.is_set or
                                        self.mac_secure_action.is_set or
                                        self.mld_profile_name.is_set or
                                        self.mmrp_flood_optimization.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.split_horizon_group_id.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                        self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                        self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                        self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                        self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                        self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                        self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                        self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_aging_mode.yfilter != YFilter.not_set or
                                        self.mac_aging_time.yfilter != YFilter.not_set or
                                        self.mac_flooding.yfilter != YFilter.not_set or
                                        self.mac_learning.yfilter != YFilter.not_set or
                                        self.mac_limit.yfilter != YFilter.not_set or
                                        self.mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_limit_notification.yfilter != YFilter.not_set or
                                        self.mac_limit_reached.yfilter != YFilter.not_set or
                                        self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                        self.mac_secure_action.yfilter != YFilter.not_set or
                                        self.mld_profile_name.yfilter != YFilter.not_set or
                                        self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.split_horizon_group_id.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                    if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                    if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                    if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                    if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                    if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                    if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                    if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                    if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                    if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                    if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                    if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                    if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                    if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                    if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                    if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                    if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                    if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                    if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                    if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                    if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                    if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dai-address-validation-mask"):
                                        self.dai_address_validation_mask = value
                                        self.dai_address_validation_mask.value_namespace = name_space
                                        self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-profile-name"):
                                        self.dhcpv4_profile_name = value
                                        self.dhcpv4_profile_name.value_namespace = name_space
                                        self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-snoop"):
                                        self.dhcpv4_snoop = value
                                        self.dhcpv4_snoop.value_namespace = name_space
                                        self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-unknown-unicast-enabled"):
                                        self.flood_unknown_unicast_enabled = value
                                        self.flood_unknown_unicast_enabled.value_namespace = name_space
                                        self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-uu-disabled-mac-limit-action"):
                                        self.flood_uu_disabled_mac_limit_action = value
                                        self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                        self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-disabled"):
                                        self.igm_pv4_disabled = value
                                        self.igm_pv4_disabled.value_namespace = name_space
                                        self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-profile-name"):
                                        self.igm_pv4_profile_name = value
                                        self.igm_pv4_profile_name.value_namespace = name_space
                                        self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                        self.is_dai_addr_validate_destination_mac_enabled = value
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                        self.is_dai_addr_validate_ipv4_enabled = value
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                        self.is_dai_addr_validate_source_mac_enabled = value
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-enabled"):
                                        self.is_dai_enabled = value
                                        self.is_dai_enabled.value_namespace = name_space
                                        self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-logging-enabled"):
                                        self.is_dai_logging_enabled = value
                                        self.is_dai_logging_enabled.value_namespace = name_space
                                        self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ip-source-guard-enabled"):
                                        self.is_ip_source_guard_enabled = value
                                        self.is_ip_source_guard_enabled.value_namespace = name_space
                                        self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ipsg-logging-enabled"):
                                        self.is_ipsg_logging_enabled = value
                                        self.is_ipsg_logging_enabled.value_namespace = name_space
                                        self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                        self.is_mac_secure_accept_shutdown_enabled = value
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-enabled"):
                                        self.is_mac_secure_enabled = value
                                        self.is_mac_secure_enabled.value_namespace = name_space
                                        self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-logging-enabled"):
                                        self.is_mac_secure_logging_enabled = value
                                        self.is_mac_secure_logging_enabled.value_namespace = name_space
                                        self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "learn-disabled-mac-limit-action"):
                                        self.learn_disabled_mac_limit_action = value
                                        self.learn_disabled_mac_limit_action.value_namespace = name_space
                                        self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-mode"):
                                        self.mac_aging_mode = value
                                        self.mac_aging_mode.value_namespace = name_space
                                        self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-time"):
                                        self.mac_aging_time = value
                                        self.mac_aging_time.value_namespace = name_space
                                        self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flooding"):
                                        self.mac_flooding = value
                                        self.mac_flooding.value_namespace = name_space
                                        self.mac_flooding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-learning"):
                                        self.mac_learning = value
                                        self.mac_learning.value_namespace = name_space
                                        self.mac_learning.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit"):
                                        self.mac_limit = value
                                        self.mac_limit.value_namespace = name_space
                                        self.mac_limit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-action"):
                                        self.mac_limit_action = value
                                        self.mac_limit_action.value_namespace = name_space
                                        self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-notification"):
                                        self.mac_limit_notification = value
                                        self.mac_limit_notification.value_namespace = name_space
                                        self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-reached"):
                                        self.mac_limit_reached = value
                                        self.mac_limit_reached.value_namespace = name_space
                                        self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-port-down-flush-enabled"):
                                        self.mac_port_down_flush_enabled = value
                                        self.mac_port_down_flush_enabled.value_namespace = name_space
                                        self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-secure-action"):
                                        self.mac_secure_action = value
                                        self.mac_secure_action.value_namespace = name_space
                                        self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mld-profile-name"):
                                        self.mld_profile_name = value
                                        self.mld_profile_name.value_namespace = name_space
                                        self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mmrp-flood-optimization"):
                                        self.mmrp_flood_optimization = value
                                        self.mmrp_flood_optimization.value_namespace = name_space
                                        self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "split-horizon-group-id"):
                                        self.split_horizon_group_id = value
                                        self.split_horizon_group_id.value_namespace = name_space
                                        self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dhcpv4_trust.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dhcpv4_trust.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-trust"):
                                    self.dhcpv4_trust = value
                                    self.dhcpv4_trust.value_namespace = name_space
                                    self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "bridge-access-pw"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "static-mac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.static_mac:
                                if (c.has_data()):
                                    return True
                            return (
                                self.is_access.is_set or
                                self.neighbor.is_set or
                                self.pseudowire_id.is_set or
                                (self.pseudowire is not None and self.pseudowire.has_data()) or
                                (self.security_parameters is not None and self.security_parameters.has_data()))

                        def has_operation(self):
                            for c in self.static_mac:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.is_access.yfilter != YFilter.not_set or
                                self.neighbor.yfilter != YFilter.not_set or
                                self.pseudowire_id.yfilter != YFilter.not_set or
                                (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                (self.security_parameters is not None and self.security_parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-access-pw" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_access.get_name_leafdata())
                            if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor.get_name_leafdata())
                            if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudowire_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "pseudowire"):
                                if (self.pseudowire is None):
                                    self.pseudowire = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                                    self.pseudowire.parent = self
                                    self._children_name_map["pseudowire"] = "pseudowire"
                                return self.pseudowire

                            if (child_yang_name == "security-parameters"):
                                if (self.security_parameters is None):
                                    self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                return self.security_parameters

                            if (child_yang_name == "static-mac"):
                                for c in self.static_mac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.static_mac.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "is-access"):
                                self.is_access = value
                                self.is_access.value_namespace = name_space
                                self.is_access.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor"):
                                self.neighbor = value
                                self.neighbor.value_namespace = name_space
                                self.neighbor.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudowire-id"):
                                self.pseudowire_id = value
                                self.pseudowire_id.value_namespace = name_space
                                self.pseudowire_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bridge_access_pw:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bridge_access_pw:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-access-pws" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-access-pw"):
                            for c in self.bridge_access_pw:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bridge_access_pw.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-access-pw"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BridgeDomainInfo(Entity):
                    """
                    VPLS Bridge Domain Information
                    
                    .. attribute:: acpwup
                    
                    	Number of bridge ports (AC,PW) which are up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: as_
                    
                    	BGP AS number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_access_vfi
                    
                    	Access Virtual Forwarding Interfaces
                    	**type**\: list of    :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                    
                    .. attribute:: bridge_coupled_state
                    
                    	Bridge\-domain coupled state
                    	**type**\:   :py:class:`L2VpnBridgeCoupledState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeCoupledState>`
                    
                    .. attribute:: bridge_description
                    
                    	Human\-readable bridge\-domain description
                    	**type**\:  str
                    
                    .. attribute:: bridge_domain_id
                    
                    	Identification number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_internal_msti
                    
                    	Bridge\-domain internal msti
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_msti
                    
                    	Bridge\-domain msti
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_mtu
                    
                    	Maximum transmission unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_name
                    
                    	Bridge\-domain name
                    	**type**\:  str
                    
                    .. attribute:: bridge_shg_id
                    
                    	Bridge\-domain shgid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_state
                    
                    	Bridge\-domain state
                    	**type**\:   :py:class:`L2VpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeState>`
                    
                    .. attribute:: bridge_type
                    
                    	Bridge\-domain type
                    	**type**\:   :py:class:`L2VpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridge>`
                    
                    .. attribute:: bridge_vfi
                    
                    	Virtual Forwarding Interfaces
                    	**type**\: list of    :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                    
                    .. attribute:: configured
                    
                    	Bridge\-domain is configured
                    	**type**\:  bool
                    
                    .. attribute:: disposition_bytecount
                    
                    	EVPN Disposition Byte Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: disposition_pkt_count
                    
                    	EVPN Disposition Packet Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: evi
                    
                    	E\-VPN id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_parameters
                    
                    	EVPN parameters
                    	**type**\:   :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                    
                    .. attribute:: flodd_group_id_down
                    
                    	Oper down because no FGID
                    	**type**\:  bool
                    
                    .. attribute:: group_name
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: imposition_byte_count
                    
                    	EVPN Imposition Byte Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: imposition_pkt_count
                    
                    	EVPN Imposition Packet Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: is_bridge_partially_programmed
                    
                    	Bridge is partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_rd_configured
                    
                    	Config or Auto
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the bridge domain status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                    
                    .. attribute:: mac_filter
                    
                    	MAC addresses for filtering
                    	**type**\: list of    :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                    
                    .. attribute:: mac_limit_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw
                    
                    	MAC withdraw enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw_access
                    
                    	MAC Access PW withdraw enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw_option
                    
                    	Event on which MAC withdraw is sent
                    	**type**\:   :py:class:`L2VpnBagMacWithdrawOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacWithdrawOption>`
                    
                    .. attribute:: mac_withdraw_relay
                    
                    	MAC Access PW withdraw relaying from access to access enabled
                    	**type**\:  bool
                    
                    .. attribute:: num_vn_is
                    
                    	Number of VNIs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: num_vn_is_up
                    
                    	Number of VNIs up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_access_vf_is
                    
                    	Number of Access VFIs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pb_bs
                    
                    	Number of pbbs
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_pb_bs_up
                    
                    	Number of pbbs up
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_vf_is
                    
                    	Number of virtual forwarding interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                    
                    	nV Satellite Offload IPv4 Multicast Disabled
                    	**type**\:  bool
                    
                    .. attribute:: p2mp_enabled
                    
                    	P2MP Enabled on this Bridge Domain
                    	**type**\:  bool
                    
                    .. attribute:: partially_programmed_a_cs
                    
                    	Number of attachment circuits partially programmed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partially_programmed_pseudowires
                    
                    	Number of pseudowires partially programmed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_parameters
                    
                    	PBB parameters
                    	**type**\:   :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                    
                    .. attribute:: rd
                    
                    	Route Distinguisher
                    	**type**\:   :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                    
                    .. attribute:: security_parameters
                    
                    	Security parameters
                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                    
                    .. attribute:: shutdown
                    
                    	Administratively disabled
                    	**type**\:  bool
                    
                    .. attribute:: standby_pseudowires
                    
                    	Number of pseudowires standby
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_created
                    
                    	Time when the bridge domain was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: vine_fsm_state
                    
                    	VNI, IRB, Native\-Evpn state
                    	**type**\:  str
                    
                    .. attribute:: vni_parameters
                    
                    	VNI parameters
                    	**type**\:   :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__init__()

                        self.yang_name = "bridge-domain-info"
                        self.yang_parent_name = "bridge-domain"

                        self.acpwup = YLeaf(YType.uint32, "acpwup")

                        self.as_ = YLeaf(YType.uint32, "as")

                        self.bridge_coupled_state = YLeaf(YType.enumeration, "bridge-coupled-state")

                        self.bridge_description = YLeaf(YType.str, "bridge-description")

                        self.bridge_domain_id = YLeaf(YType.uint32, "bridge-domain-id")

                        self.bridge_internal_msti = YLeaf(YType.uint32, "bridge-internal-msti")

                        self.bridge_msti = YLeaf(YType.uint32, "bridge-msti")

                        self.bridge_mtu = YLeaf(YType.uint32, "bridge-mtu")

                        self.bridge_name = YLeaf(YType.str, "bridge-name")

                        self.bridge_shg_id = YLeaf(YType.uint32, "bridge-shg-id")

                        self.bridge_state = YLeaf(YType.enumeration, "bridge-state")

                        self.bridge_type = YLeaf(YType.enumeration, "bridge-type")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.disposition_bytecount = YLeaf(YType.uint64, "disposition-bytecount")

                        self.disposition_pkt_count = YLeaf(YType.uint64, "disposition-pkt-count")

                        self.evi = YLeaf(YType.uint32, "evi")

                        self.flodd_group_id_down = YLeaf(YType.boolean, "flodd-group-id-down")

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.imposition_byte_count = YLeaf(YType.uint64, "imposition-byte-count")

                        self.imposition_pkt_count = YLeaf(YType.uint64, "imposition-pkt-count")

                        self.is_bridge_partially_programmed = YLeaf(YType.boolean, "is-bridge-partially-programmed")

                        self.is_rd_configured = YLeaf(YType.boolean, "is-rd-configured")

                        self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                        self.load_balance = YLeaf(YType.enumeration, "load-balance")

                        self.mac_limit_down = YLeaf(YType.boolean, "mac-limit-down")

                        self.mac_withdraw = YLeaf(YType.boolean, "mac-withdraw")

                        self.mac_withdraw_access = YLeaf(YType.boolean, "mac-withdraw-access")

                        self.mac_withdraw_option = YLeaf(YType.enumeration, "mac-withdraw-option")

                        self.mac_withdraw_relay = YLeaf(YType.boolean, "mac-withdraw-relay")

                        self.num_vn_is = YLeaf(YType.uint32, "num-vn-is")

                        self.num_vn_is_up = YLeaf(YType.uint32, "num-vn-is-up")

                        self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                        self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                        self.number_access_vf_is = YLeaf(YType.uint32, "number-access-vf-is")

                        self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                        self.number_pb_bs = YLeaf(YType.uint8, "number-pb-bs")

                        self.number_pb_bs_up = YLeaf(YType.uint8, "number-pb-bs-up")

                        self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                        self.number_vf_is = YLeaf(YType.uint32, "number-vf-is")

                        self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                        self.p2mp_enabled = YLeaf(YType.boolean, "p2mp-enabled")

                        self.partially_programmed_a_cs = YLeaf(YType.uint32, "partially-programmed-a-cs")

                        self.partially_programmed_pseudowires = YLeaf(YType.uint32, "partially-programmed-pseudowires")

                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                        self.standby_pseudowires = YLeaf(YType.uint32, "standby-pseudowires")

                        self.time_created = YLeaf(YType.str, "time-created")

                        self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                        self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                        self.vine_fsm_state = YLeaf(YType.str, "vine-fsm-state")

                        self.evpn_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                        self.evpn_parameters.parent = self
                        self._children_name_map["evpn_parameters"] = "evpn-parameters"
                        self._children_yang_names.add("evpn-parameters")

                        self.pbb_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                        self.pbb_parameters.parent = self
                        self._children_name_map["pbb_parameters"] = "pbb-parameters"
                        self._children_yang_names.add("pbb-parameters")

                        self.rd = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                        self.rd.parent = self
                        self._children_name_map["rd"] = "rd"
                        self._children_yang_names.add("rd")

                        self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                        self.security_parameters.parent = self
                        self._children_name_map["security_parameters"] = "security-parameters"
                        self._children_yang_names.add("security-parameters")

                        self.vni_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                        self.vni_parameters.parent = self
                        self._children_name_map["vni_parameters"] = "vni-parameters"
                        self._children_yang_names.add("vni-parameters")

                        self.bridge_access_vfi = YList(self)
                        self.bridge_vfi = YList(self)
                        self.mac_filter = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("acpwup",
                                        "as_",
                                        "bridge_coupled_state",
                                        "bridge_description",
                                        "bridge_domain_id",
                                        "bridge_internal_msti",
                                        "bridge_msti",
                                        "bridge_mtu",
                                        "bridge_name",
                                        "bridge_shg_id",
                                        "bridge_state",
                                        "bridge_type",
                                        "configured",
                                        "disposition_bytecount",
                                        "disposition_pkt_count",
                                        "evi",
                                        "flodd_group_id_down",
                                        "group_name",
                                        "imposition_byte_count",
                                        "imposition_pkt_count",
                                        "is_bridge_partially_programmed",
                                        "is_rd_configured",
                                        "last_time_status_changed",
                                        "load_balance",
                                        "mac_limit_down",
                                        "mac_withdraw",
                                        "mac_withdraw_access",
                                        "mac_withdraw_option",
                                        "mac_withdraw_relay",
                                        "num_vn_is",
                                        "num_vn_is_up",
                                        "number_a_cs",
                                        "number_a_cs_up",
                                        "number_access_vf_is",
                                        "number_p_ws_up",
                                        "number_pb_bs",
                                        "number_pb_bs_up",
                                        "number_pseudowires",
                                        "number_vf_is",
                                        "nv_satellite_offload_ipv4_multicast_disabled",
                                        "p2mp_enabled",
                                        "partially_programmed_a_cs",
                                        "partially_programmed_pseudowires",
                                        "shutdown",
                                        "standby_pseudowires",
                                        "time_created",
                                        "time_elapsed_creation",
                                        "time_elapsed_status_changed",
                                        "vine_fsm_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__setattr__(name, value)


                    class SecurityParameters(Entity):
                        """
                        Security parameters
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        .. attribute:: dai_address_validation_mask
                        
                        	DAI Address Validation mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dhcpv4_profile_name
                        
                        	DHCPv4 Profile Name
                        	**type**\:  str
                        
                        .. attribute:: dhcpv4_snoop
                        
                        	DHCPv4 Snoop Status
                        	**type**\:  bool
                        
                        .. attribute:: flood_unknown_unicast_enabled
                        
                        	Flooding unknown unicast enabled
                        	**type**\:  bool
                        
                        .. attribute:: flood_uu_disabled_mac_limit_action
                        
                        	Flooding of unknown\-unicast disabled due to MAC limit action
                        	**type**\:  bool
                        
                        .. attribute:: igm_pv4_disabled
                        
                        	IGMPv4 Disabled
                        	**type**\:  bool
                        
                        .. attribute:: igm_pv4_profile_name
                        
                        	IGMPv4 Profile Name
                        	**type**\:  str
                        
                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                        
                        	Is DAI Dstination MAC Address Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                        
                        	Is DAI IPv4 Addr Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                        
                        	Is DAI Source MAC Address Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_enabled
                        
                        	Is Dynamic ARP Inspection Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_logging_enabled
                        
                        	Is DAI Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_source_guard_enabled
                        
                        	Is IP Source Guard Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_ipsg_logging_enabled
                        
                        	Is IP Source Guard Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                        
                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_enabled
                        
                        	Is MAC Secure Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_logging_enabled
                        
                        	Is MAC Secure Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: learn_disabled_mac_limit_action
                        
                        	Learning disabled due to MAC limit action
                        	**type**\:  bool
                        
                        .. attribute:: mac_aging_mode
                        
                        	MAC Aging Mode
                        	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                        
                        .. attribute:: mac_aging_time
                        
                        	MAC aging time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: mac_flooding
                        
                        	MAC flooding enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_learning
                        
                        	MAC learning enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_limit
                        
                        	MAC address limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_limit_action
                        
                        	MAC limit action
                        	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                        
                        .. attribute:: mac_limit_notification
                        
                        	MAC limit notification
                        	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                        
                        .. attribute:: mac_limit_reached
                        
                        	MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mac_port_down_flush_enabled
                        
                        	MAC Flush when port goes down
                        	**type**\:  bool
                        
                        .. attribute:: mac_secure_action
                        
                        	MAC Secure Action
                        	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                        
                        .. attribute:: mld_profile_name
                        
                        	MLD Profile Name
                        	**type**\:  str
                        
                        .. attribute:: mmrp_flood_optimization
                        
                        	MMRP Flood Optimization Status
                        	**type**\:  bool
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        .. attribute:: split_horizon_group_id
                        
                        	Split Horizon Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__init__()

                            self.yang_name = "security-parameters"
                            self.yang_parent_name = "bridge-domain-info"

                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                            self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                            self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                            self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                            self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                            self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                            self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                            self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                            self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                            self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                            self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                            self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                            self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                            self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                            self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                            self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                            self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                            self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                            self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                            self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                            self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                            self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                            self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                            self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                            self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                            self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                            self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                            self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                            self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                            self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                            self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                            self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self._children_name_map["storm_control"] = "storm-control"
                            self._children_yang_names.add("storm-control")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("broadcast_storm_control_kb_ps",
                                            "broadcast_storm_control_pps",
                                            "broadcast_storm_control_rate_unit",
                                            "dai_address_validation_mask",
                                            "dhcpv4_profile_name",
                                            "dhcpv4_snoop",
                                            "flood_unknown_unicast_enabled",
                                            "flood_uu_disabled_mac_limit_action",
                                            "igm_pv4_disabled",
                                            "igm_pv4_profile_name",
                                            "is_dai_addr_validate_destination_mac_enabled",
                                            "is_dai_addr_validate_ipv4_enabled",
                                            "is_dai_addr_validate_source_mac_enabled",
                                            "is_dai_enabled",
                                            "is_dai_logging_enabled",
                                            "is_ip_source_guard_enabled",
                                            "is_ipsg_logging_enabled",
                                            "is_mac_secure_accept_shutdown_enabled",
                                            "is_mac_secure_enabled",
                                            "is_mac_secure_logging_enabled",
                                            "learn_disabled_mac_limit_action",
                                            "mac_aging_mode",
                                            "mac_aging_time",
                                            "mac_flooding",
                                            "mac_learning",
                                            "mac_limit",
                                            "mac_limit_action",
                                            "mac_limit_notification",
                                            "mac_limit_reached",
                                            "mac_port_down_flush_enabled",
                                            "mac_secure_action",
                                            "mld_profile_name",
                                            "mmrp_flood_optimization",
                                            "multicast_storm_control_kb_ps",
                                            "multicast_storm_control_pps",
                                            "multicast_storm_control_rate_unit",
                                            "split_horizon_group_id",
                                            "unicast_storm_control_kb_ps",
                                            "unicast_storm_control_pps",
                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__setattr__(name, value)


                        class StormControl(Entity):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\:  bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__init__()

                                self.yang_name = "storm-control"
                                self.yang_parent_name = "security-parameters"

                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                self.multicast = YLeaf(YType.boolean, "multicast")

                                self.unicast = YLeaf(YType.boolean, "unicast")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bd_policer",
                                                "broadcast",
                                                "multicast",
                                                "unicast") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bd_policer.is_set or
                                    self.broadcast.is_set or
                                    self.multicast.is_set or
                                    self.unicast.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bd_policer.yfilter != YFilter.not_set or
                                    self.broadcast.yfilter != YFilter.not_set or
                                    self.multicast.yfilter != YFilter.not_set or
                                    self.unicast.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "storm-control" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/security-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bd-policer"):
                                    self.bd_policer = value
                                    self.bd_policer.value_namespace = name_space
                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast"):
                                    self.broadcast = value
                                    self.broadcast.value_namespace = name_space
                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast"):
                                    self.multicast = value
                                    self.multicast.value_namespace = name_space
                                    self.multicast.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast"):
                                    self.unicast = value
                                    self.unicast.value_namespace = name_space
                                    self.unicast.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.broadcast_storm_control_kb_ps.is_set or
                                self.broadcast_storm_control_pps.is_set or
                                self.broadcast_storm_control_rate_unit.is_set or
                                self.dai_address_validation_mask.is_set or
                                self.dhcpv4_profile_name.is_set or
                                self.dhcpv4_snoop.is_set or
                                self.flood_unknown_unicast_enabled.is_set or
                                self.flood_uu_disabled_mac_limit_action.is_set or
                                self.igm_pv4_disabled.is_set or
                                self.igm_pv4_profile_name.is_set or
                                self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                self.is_dai_addr_validate_ipv4_enabled.is_set or
                                self.is_dai_addr_validate_source_mac_enabled.is_set or
                                self.is_dai_enabled.is_set or
                                self.is_dai_logging_enabled.is_set or
                                self.is_ip_source_guard_enabled.is_set or
                                self.is_ipsg_logging_enabled.is_set or
                                self.is_mac_secure_accept_shutdown_enabled.is_set or
                                self.is_mac_secure_enabled.is_set or
                                self.is_mac_secure_logging_enabled.is_set or
                                self.learn_disabled_mac_limit_action.is_set or
                                self.mac_aging_mode.is_set or
                                self.mac_aging_time.is_set or
                                self.mac_flooding.is_set or
                                self.mac_learning.is_set or
                                self.mac_limit.is_set or
                                self.mac_limit_action.is_set or
                                self.mac_limit_notification.is_set or
                                self.mac_limit_reached.is_set or
                                self.mac_port_down_flush_enabled.is_set or
                                self.mac_secure_action.is_set or
                                self.mld_profile_name.is_set or
                                self.mmrp_flood_optimization.is_set or
                                self.multicast_storm_control_kb_ps.is_set or
                                self.multicast_storm_control_pps.is_set or
                                self.multicast_storm_control_rate_unit.is_set or
                                self.split_horizon_group_id.is_set or
                                self.unicast_storm_control_kb_ps.is_set or
                                self.unicast_storm_control_pps.is_set or
                                self.unicast_storm_control_rate_unit.is_set or
                                (self.storm_control is not None and self.storm_control.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                self.is_dai_enabled.yfilter != YFilter.not_set or
                                self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                self.mac_aging_mode.yfilter != YFilter.not_set or
                                self.mac_aging_time.yfilter != YFilter.not_set or
                                self.mac_flooding.yfilter != YFilter.not_set or
                                self.mac_learning.yfilter != YFilter.not_set or
                                self.mac_limit.yfilter != YFilter.not_set or
                                self.mac_limit_action.yfilter != YFilter.not_set or
                                self.mac_limit_notification.yfilter != YFilter.not_set or
                                self.mac_limit_reached.yfilter != YFilter.not_set or
                                self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                self.mac_secure_action.yfilter != YFilter.not_set or
                                self.mld_profile_name.yfilter != YFilter.not_set or
                                self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                self.split_horizon_group_id.yfilter != YFilter.not_set or
                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                (self.storm_control is not None and self.storm_control.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "security-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                            if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                            if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                            if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                            if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                            if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                            if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                            if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                            if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                            if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                            if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                            if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                            if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                            if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                            if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                            if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                            if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                            if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                            if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                            if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                            if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                            if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                            if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_learning.get_name_leafdata())
                            if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit.get_name_leafdata())
                            if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                            if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                            if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                            if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                            if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                            if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                            if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                            if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "storm-control"):
                                if (self.storm_control is None):
                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                return self.storm_control

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "broadcast-storm-control-kb-ps"):
                                self.broadcast_storm_control_kb_ps = value
                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-pps"):
                                self.broadcast_storm_control_pps = value
                                self.broadcast_storm_control_pps.value_namespace = name_space
                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-rate-unit"):
                                self.broadcast_storm_control_rate_unit = value
                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "dai-address-validation-mask"):
                                self.dai_address_validation_mask = value
                                self.dai_address_validation_mask.value_namespace = name_space
                                self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "dhcpv4-profile-name"):
                                self.dhcpv4_profile_name = value
                                self.dhcpv4_profile_name.value_namespace = name_space
                                self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "dhcpv4-snoop"):
                                self.dhcpv4_snoop = value
                                self.dhcpv4_snoop.value_namespace = name_space
                                self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                            if(value_path == "flood-unknown-unicast-enabled"):
                                self.flood_unknown_unicast_enabled = value
                                self.flood_unknown_unicast_enabled.value_namespace = name_space
                                self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "flood-uu-disabled-mac-limit-action"):
                                self.flood_uu_disabled_mac_limit_action = value
                                self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                            if(value_path == "igm-pv4-disabled"):
                                self.igm_pv4_disabled = value
                                self.igm_pv4_disabled.value_namespace = name_space
                                self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "igm-pv4-profile-name"):
                                self.igm_pv4_profile_name = value
                                self.igm_pv4_profile_name.value_namespace = name_space
                                self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                self.is_dai_addr_validate_destination_mac_enabled = value
                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                self.is_dai_addr_validate_ipv4_enabled = value
                                self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                self.is_dai_addr_validate_source_mac_enabled = value
                                self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dai-enabled"):
                                self.is_dai_enabled = value
                                self.is_dai_enabled.value_namespace = name_space
                                self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dai-logging-enabled"):
                                self.is_dai_logging_enabled = value
                                self.is_dai_logging_enabled.value_namespace = name_space
                                self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-source-guard-enabled"):
                                self.is_ip_source_guard_enabled = value
                                self.is_ip_source_guard_enabled.value_namespace = name_space
                                self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ipsg-logging-enabled"):
                                self.is_ipsg_logging_enabled = value
                                self.is_ipsg_logging_enabled.value_namespace = name_space
                                self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                self.is_mac_secure_accept_shutdown_enabled = value
                                self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-mac-secure-enabled"):
                                self.is_mac_secure_enabled = value
                                self.is_mac_secure_enabled.value_namespace = name_space
                                self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-mac-secure-logging-enabled"):
                                self.is_mac_secure_logging_enabled = value
                                self.is_mac_secure_logging_enabled.value_namespace = name_space
                                self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "learn-disabled-mac-limit-action"):
                                self.learn_disabled_mac_limit_action = value
                                self.learn_disabled_mac_limit_action.value_namespace = name_space
                                self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-aging-mode"):
                                self.mac_aging_mode = value
                                self.mac_aging_mode.value_namespace = name_space
                                self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-aging-time"):
                                self.mac_aging_time = value
                                self.mac_aging_time.value_namespace = name_space
                                self.mac_aging_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-flooding"):
                                self.mac_flooding = value
                                self.mac_flooding.value_namespace = name_space
                                self.mac_flooding.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-learning"):
                                self.mac_learning = value
                                self.mac_learning.value_namespace = name_space
                                self.mac_learning.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit"):
                                self.mac_limit = value
                                self.mac_limit.value_namespace = name_space
                                self.mac_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-action"):
                                self.mac_limit_action = value
                                self.mac_limit_action.value_namespace = name_space
                                self.mac_limit_action.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-notification"):
                                self.mac_limit_notification = value
                                self.mac_limit_notification.value_namespace = name_space
                                self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-reached"):
                                self.mac_limit_reached = value
                                self.mac_limit_reached.value_namespace = name_space
                                self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-port-down-flush-enabled"):
                                self.mac_port_down_flush_enabled = value
                                self.mac_port_down_flush_enabled.value_namespace = name_space
                                self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-secure-action"):
                                self.mac_secure_action = value
                                self.mac_secure_action.value_namespace = name_space
                                self.mac_secure_action.value_namespace_prefix = name_space_prefix
                            if(value_path == "mld-profile-name"):
                                self.mld_profile_name = value
                                self.mld_profile_name.value_namespace = name_space
                                self.mld_profile_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "mmrp-flood-optimization"):
                                self.mmrp_flood_optimization = value
                                self.mmrp_flood_optimization.value_namespace = name_space
                                self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-kb-ps"):
                                self.multicast_storm_control_kb_ps = value
                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-pps"):
                                self.multicast_storm_control_pps = value
                                self.multicast_storm_control_pps.value_namespace = name_space
                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-rate-unit"):
                                self.multicast_storm_control_rate_unit = value
                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "split-horizon-group-id"):
                                self.split_horizon_group_id = value
                                self.split_horizon_group_id.value_namespace = name_space
                                self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-kb-ps"):
                                self.unicast_storm_control_kb_ps = value
                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-pps"):
                                self.unicast_storm_control_pps = value
                                self.unicast_storm_control_pps.value_namespace = name_space
                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-rate-unit"):
                                self.unicast_storm_control_rate_unit = value
                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                    class PbbParameters(Entity):
                        """
                        PBB parameters
                        
                        .. attribute:: pbb_core
                        
                        	PBB Core
                        	**type**\:   :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                        
                        .. attribute:: pbb_edge
                        
                        	PBB Edge
                        	**type**\:   :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                        
                        .. attribute:: type
                        
                        	Type
                        	**type**\:   :py:class:`L2VpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__init__()

                            self.yang_name = "pbb-parameters"
                            self.yang_parent_name = "bridge-domain-info"

                            self.type = YLeaf(YType.enumeration, "type")

                            self.pbb_core = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                            self.pbb_core.parent = self
                            self._children_name_map["pbb_core"] = "pbb-core"
                            self._children_yang_names.add("pbb-core")

                            self.pbb_edge = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                            self.pbb_edge.parent = self
                            self._children_name_map["pbb_edge"] = "pbb-edge"
                            self._children_yang_names.add("pbb-edge")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__setattr__(name, value)


                        class PbbEdge(Entity):
                            """
                            PBB Edge
                            
                            .. attribute:: core_bridge_name
                            
                            	Core Bridge Domain Name
                            	**type**\:  str
                            
                            .. attribute:: core_bridge_state
                            
                            	Core Bridge State
                            	**type**\:   :py:class:`L2VpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeState>`
                            
                            .. attribute:: edge_port
                            
                            	PBB Edge Port
                            	**type**\:   :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                            
                            .. attribute:: i_sid
                            
                            	SID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mirp_lite_protocol
                            
                            	MIRP\-lite protocol info
                            	**type**\:   :py:class:`L2VpnMirpLiteProtocolInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteProtocolInfo>`
                            
                            .. attribute:: mirp_lite_status
                            
                            	MIRP\-lite Status
                            	**type**\:   :py:class:`L2VpnMirpLiteStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteStatus>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__init__()

                                self.yang_name = "pbb-edge"
                                self.yang_parent_name = "pbb-parameters"

                                self.core_bridge_name = YLeaf(YType.str, "core-bridge-name")

                                self.core_bridge_state = YLeaf(YType.enumeration, "core-bridge-state")

                                self.i_sid = YLeaf(YType.uint32, "i-sid")

                                self.mirp_lite_protocol = YLeaf(YType.enumeration, "mirp-lite-protocol")

                                self.mirp_lite_status = YLeaf(YType.enumeration, "mirp-lite-status")

                                self.edge_port = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                self.edge_port.parent = self
                                self._children_name_map["edge_port"] = "edge-port"
                                self._children_yang_names.add("edge-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("core_bridge_name",
                                                "core_bridge_state",
                                                "i_sid",
                                                "mirp_lite_protocol",
                                                "mirp_lite_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__setattr__(name, value)


                            class EdgePort(Entity):
                                """
                                PBB Edge Port
                                
                                .. attribute:: bmac_mapping
                                
                                	CMAC to BMAC Mapping
                                	**type**\: list of    :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                                
                                .. attribute:: edge_port_state
                                
                                	PBB Edge Port State
                                	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                                
                                .. attribute:: unknown_unicast_mac
                                
                                	Unknown Unicast MAC
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: unknown_unicast_mac_set
                                
                                	Unknown Unicast MAC Configured
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__init__()

                                    self.yang_name = "edge-port"
                                    self.yang_parent_name = "pbb-edge"

                                    self.edge_port_state = YLeaf(YType.enumeration, "edge-port-state")

                                    self.unknown_unicast_mac = YLeaf(YType.str, "unknown-unicast-mac")

                                    self.unknown_unicast_mac_set = YLeaf(YType.boolean, "unknown-unicast-mac-set")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                    self._children_yang_names.add("security-parameters")

                                    self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._children_yang_names.add("statistics")

                                    self.bmac_mapping = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("edge_port_state",
                                                    "unknown_unicast_mac",
                                                    "unknown_unicast_mac_set",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__setattr__(name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "edge-port"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                        self._children_yang_names.add("base")

                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dhcpv4_trust",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__setattr__(name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"

                                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                            self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                            self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                            self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                            self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                            self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                            self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                            self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                            self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                            self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                            self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                            self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                            self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                            self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                            self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                            self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                            self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                            self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                            self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                            self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                            self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                            self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                            self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                            self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                            self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                            self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                            self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                            self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                            self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                            self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                            self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                            self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._children_yang_names.add("storm-control")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("broadcast_storm_control_kb_ps",
                                                            "broadcast_storm_control_pps",
                                                            "broadcast_storm_control_rate_unit",
                                                            "dai_address_validation_mask",
                                                            "dhcpv4_profile_name",
                                                            "dhcpv4_snoop",
                                                            "flood_unknown_unicast_enabled",
                                                            "flood_uu_disabled_mac_limit_action",
                                                            "igm_pv4_disabled",
                                                            "igm_pv4_profile_name",
                                                            "is_dai_addr_validate_destination_mac_enabled",
                                                            "is_dai_addr_validate_ipv4_enabled",
                                                            "is_dai_addr_validate_source_mac_enabled",
                                                            "is_dai_enabled",
                                                            "is_dai_logging_enabled",
                                                            "is_ip_source_guard_enabled",
                                                            "is_ipsg_logging_enabled",
                                                            "is_mac_secure_accept_shutdown_enabled",
                                                            "is_mac_secure_enabled",
                                                            "is_mac_secure_logging_enabled",
                                                            "learn_disabled_mac_limit_action",
                                                            "mac_aging_mode",
                                                            "mac_aging_time",
                                                            "mac_flooding",
                                                            "mac_learning",
                                                            "mac_limit",
                                                            "mac_limit_action",
                                                            "mac_limit_notification",
                                                            "mac_limit_reached",
                                                            "mac_port_down_flush_enabled",
                                                            "mac_secure_action",
                                                            "mld_profile_name",
                                                            "mmrp_flood_optimization",
                                                            "multicast_storm_control_kb_ps",
                                                            "multicast_storm_control_pps",
                                                            "multicast_storm_control_rate_unit",
                                                            "split_horizon_group_id",
                                                            "unicast_storm_control_kb_ps",
                                                            "unicast_storm_control_pps",
                                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__setattr__(name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"

                                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                self.multicast = YLeaf(YType.boolean, "multicast")

                                                self.unicast = YLeaf(YType.boolean, "unicast")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bd_policer",
                                                                "broadcast",
                                                                "multicast",
                                                                "unicast") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bd_policer.is_set or
                                                    self.broadcast.is_set or
                                                    self.multicast.is_set or
                                                    self.unicast.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bd_policer.yfilter != YFilter.not_set or
                                                    self.broadcast.yfilter != YFilter.not_set or
                                                    self.multicast.yfilter != YFilter.not_set or
                                                    self.unicast.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "storm-control" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/base/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bd-policer"):
                                                    self.bd_policer = value
                                                    self.bd_policer.value_namespace = name_space
                                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast"):
                                                    self.broadcast = value
                                                    self.broadcast.value_namespace = name_space
                                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast"):
                                                    self.multicast = value
                                                    self.multicast.value_namespace = name_space
                                                    self.multicast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast"):
                                                    self.unicast = value
                                                    self.unicast.value_namespace = name_space
                                                    self.unicast.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.broadcast_storm_control_kb_ps.is_set or
                                                self.broadcast_storm_control_pps.is_set or
                                                self.broadcast_storm_control_rate_unit.is_set or
                                                self.dai_address_validation_mask.is_set or
                                                self.dhcpv4_profile_name.is_set or
                                                self.dhcpv4_snoop.is_set or
                                                self.flood_unknown_unicast_enabled.is_set or
                                                self.flood_uu_disabled_mac_limit_action.is_set or
                                                self.igm_pv4_disabled.is_set or
                                                self.igm_pv4_profile_name.is_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                                self.is_dai_addr_validate_ipv4_enabled.is_set or
                                                self.is_dai_addr_validate_source_mac_enabled.is_set or
                                                self.is_dai_enabled.is_set or
                                                self.is_dai_logging_enabled.is_set or
                                                self.is_ip_source_guard_enabled.is_set or
                                                self.is_ipsg_logging_enabled.is_set or
                                                self.is_mac_secure_accept_shutdown_enabled.is_set or
                                                self.is_mac_secure_enabled.is_set or
                                                self.is_mac_secure_logging_enabled.is_set or
                                                self.learn_disabled_mac_limit_action.is_set or
                                                self.mac_aging_mode.is_set or
                                                self.mac_aging_time.is_set or
                                                self.mac_flooding.is_set or
                                                self.mac_learning.is_set or
                                                self.mac_limit.is_set or
                                                self.mac_limit_action.is_set or
                                                self.mac_limit_notification.is_set or
                                                self.mac_limit_reached.is_set or
                                                self.mac_port_down_flush_enabled.is_set or
                                                self.mac_secure_action.is_set or
                                                self.mld_profile_name.is_set or
                                                self.mmrp_flood_optimization.is_set or
                                                self.multicast_storm_control_kb_ps.is_set or
                                                self.multicast_storm_control_pps.is_set or
                                                self.multicast_storm_control_rate_unit.is_set or
                                                self.split_horizon_group_id.is_set or
                                                self.unicast_storm_control_kb_ps.is_set or
                                                self.unicast_storm_control_pps.is_set or
                                                self.unicast_storm_control_rate_unit.is_set or
                                                (self.storm_control is not None and self.storm_control.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                                self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                                self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                                self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                                self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                                self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                                self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                                self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_aging_mode.yfilter != YFilter.not_set or
                                                self.mac_aging_time.yfilter != YFilter.not_set or
                                                self.mac_flooding.yfilter != YFilter.not_set or
                                                self.mac_learning.yfilter != YFilter.not_set or
                                                self.mac_limit.yfilter != YFilter.not_set or
                                                self.mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_limit_notification.yfilter != YFilter.not_set or
                                                self.mac_limit_reached.yfilter != YFilter.not_set or
                                                self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                                self.mac_secure_action.yfilter != YFilter.not_set or
                                                self.mld_profile_name.yfilter != YFilter.not_set or
                                                self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.split_horizon_group_id.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                (self.storm_control is not None and self.storm_control.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "base" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                            if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                            if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                            if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                            if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                            if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                            if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                            if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                            if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                            if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                            if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                            if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                            if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                            if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                            if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                            if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                            if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                            if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                            if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                            if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                            if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                            if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "storm-control"):
                                                if (self.storm_control is None):
                                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                                    self.storm_control.parent = self
                                                    self._children_name_map["storm_control"] = "storm-control"
                                                return self.storm_control

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "broadcast-storm-control-kb-ps"):
                                                self.broadcast_storm_control_kb_ps = value
                                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-pps"):
                                                self.broadcast_storm_control_pps = value
                                                self.broadcast_storm_control_pps.value_namespace = name_space
                                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-rate-unit"):
                                                self.broadcast_storm_control_rate_unit = value
                                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dai-address-validation-mask"):
                                                self.dai_address_validation_mask = value
                                                self.dai_address_validation_mask.value_namespace = name_space
                                                self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-profile-name"):
                                                self.dhcpv4_profile_name = value
                                                self.dhcpv4_profile_name.value_namespace = name_space
                                                self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-snoop"):
                                                self.dhcpv4_snoop = value
                                                self.dhcpv4_snoop.value_namespace = name_space
                                                self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-unknown-unicast-enabled"):
                                                self.flood_unknown_unicast_enabled = value
                                                self.flood_unknown_unicast_enabled.value_namespace = name_space
                                                self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-uu-disabled-mac-limit-action"):
                                                self.flood_uu_disabled_mac_limit_action = value
                                                self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                                self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-disabled"):
                                                self.igm_pv4_disabled = value
                                                self.igm_pv4_disabled.value_namespace = name_space
                                                self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-profile-name"):
                                                self.igm_pv4_profile_name = value
                                                self.igm_pv4_profile_name.value_namespace = name_space
                                                self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                                self.is_dai_addr_validate_destination_mac_enabled = value
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                                self.is_dai_addr_validate_ipv4_enabled = value
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                                self.is_dai_addr_validate_source_mac_enabled = value
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-enabled"):
                                                self.is_dai_enabled = value
                                                self.is_dai_enabled.value_namespace = name_space
                                                self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-logging-enabled"):
                                                self.is_dai_logging_enabled = value
                                                self.is_dai_logging_enabled.value_namespace = name_space
                                                self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ip-source-guard-enabled"):
                                                self.is_ip_source_guard_enabled = value
                                                self.is_ip_source_guard_enabled.value_namespace = name_space
                                                self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ipsg-logging-enabled"):
                                                self.is_ipsg_logging_enabled = value
                                                self.is_ipsg_logging_enabled.value_namespace = name_space
                                                self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                                self.is_mac_secure_accept_shutdown_enabled = value
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-enabled"):
                                                self.is_mac_secure_enabled = value
                                                self.is_mac_secure_enabled.value_namespace = name_space
                                                self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-logging-enabled"):
                                                self.is_mac_secure_logging_enabled = value
                                                self.is_mac_secure_logging_enabled.value_namespace = name_space
                                                self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "learn-disabled-mac-limit-action"):
                                                self.learn_disabled_mac_limit_action = value
                                                self.learn_disabled_mac_limit_action.value_namespace = name_space
                                                self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-mode"):
                                                self.mac_aging_mode = value
                                                self.mac_aging_mode.value_namespace = name_space
                                                self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-time"):
                                                self.mac_aging_time = value
                                                self.mac_aging_time.value_namespace = name_space
                                                self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-flooding"):
                                                self.mac_flooding = value
                                                self.mac_flooding.value_namespace = name_space
                                                self.mac_flooding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-learning"):
                                                self.mac_learning = value
                                                self.mac_learning.value_namespace = name_space
                                                self.mac_learning.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit"):
                                                self.mac_limit = value
                                                self.mac_limit.value_namespace = name_space
                                                self.mac_limit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-action"):
                                                self.mac_limit_action = value
                                                self.mac_limit_action.value_namespace = name_space
                                                self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-notification"):
                                                self.mac_limit_notification = value
                                                self.mac_limit_notification.value_namespace = name_space
                                                self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-reached"):
                                                self.mac_limit_reached = value
                                                self.mac_limit_reached.value_namespace = name_space
                                                self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-port-down-flush-enabled"):
                                                self.mac_port_down_flush_enabled = value
                                                self.mac_port_down_flush_enabled.value_namespace = name_space
                                                self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-secure-action"):
                                                self.mac_secure_action = value
                                                self.mac_secure_action.value_namespace = name_space
                                                self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mld-profile-name"):
                                                self.mld_profile_name = value
                                                self.mld_profile_name.value_namespace = name_space
                                                self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mmrp-flood-optimization"):
                                                self.mmrp_flood_optimization = value
                                                self.mmrp_flood_optimization.value_namespace = name_space
                                                self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-kb-ps"):
                                                self.multicast_storm_control_kb_ps = value
                                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-pps"):
                                                self.multicast_storm_control_pps = value
                                                self.multicast_storm_control_pps.value_namespace = name_space
                                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-rate-unit"):
                                                self.multicast_storm_control_rate_unit = value
                                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "split-horizon-group-id"):
                                                self.split_horizon_group_id = value
                                                self.split_horizon_group_id.value_namespace = name_space
                                                self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-kb-ps"):
                                                self.unicast_storm_control_kb_ps = value
                                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-pps"):
                                                self.unicast_storm_control_pps = value
                                                self.unicast_storm_control_pps.value_namespace = name_space
                                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-rate-unit"):
                                                self.unicast_storm_control_rate_unit = value
                                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dhcpv4_trust.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.base is not None and self.base.has_data()) or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dhcpv4_trust.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.base is not None and self.base.has_operation()) or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security-parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "base"):
                                            if (self.base is None):
                                                self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                                self.base.parent = self
                                                self._children_name_map["base"] = "base"
                                            return self.base

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-trust"):
                                            self.dhcpv4_trust = value
                                            self.dhcpv4_trust.value_namespace = name_space
                                            self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "edge-port"

                                        self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        self._children_yang_names.add("dispostion-stats")

                                        self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                        self._children_yang_names.add("impostion-stats")

                                        self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._children_yang_names.add("sequence-number")


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                            self._children_yang_names.add("broadcast")

                                            self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            self._children_yang_names.add("imposition-mtu-drop")

                                            self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                            self._children_yang_names.add("imposition-stat")

                                            self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            self._children_yang_names.add("impostion-tail-drop")

                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            self._children_yang_names.add("l2fsbi-drop")

                                            self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                            self._children_yang_names.add("multicast")

                                            self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._children_yang_names.add("unknown-unicast")


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class L2FsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2fsbi-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast is not None and self.broadcast.has_data()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                (self.multicast is not None and self.multicast.has_data()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast is not None and self.broadcast.has_operation()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                (self.multicast is not None and self.multicast.has_operation()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast"):
                                                if (self.broadcast is None):
                                                    self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                                    self.broadcast.parent = self
                                                    self._children_name_map["broadcast"] = "broadcast"
                                                return self.broadcast

                                            if (child_yang_name == "imposition-mtu-drop"):
                                                if (self.imposition_mtu_drop is None):
                                                    self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                    self.imposition_mtu_drop.parent = self
                                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                return self.imposition_mtu_drop

                                            if (child_yang_name == "imposition-stat"):
                                                if (self.imposition_stat is None):
                                                    self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                                    self.imposition_stat.parent = self
                                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                                return self.imposition_stat

                                            if (child_yang_name == "impostion-tail-drop"):
                                                if (self.impostion_tail_drop is None):
                                                    self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                                    self.impostion_tail_drop.parent = self
                                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                return self.impostion_tail_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "l2fsbi-drop"):
                                                if (self.l2fsbi_drop is None):
                                                    self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                                    self.l2fsbi_drop.parent = self
                                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                return self.l2fsbi_drop

                                            if (child_yang_name == "multicast"):
                                                if (self.multicast is None):
                                                    self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                                    self.multicast.parent = self
                                                    self._children_name_map["multicast"] = "multicast"
                                                return self.multicast

                                            if (child_yang_name == "unknown-unicast"):
                                                if (self.unknown_unicast is None):
                                                    self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                                    self.unknown_unicast.parent = self
                                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                return self.unknown_unicast

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            self._children_yang_names.add("broadcast-drop")

                                            self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                            self._children_yang_names.add("dai-drop")

                                            self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            self._children_yang_names.add("disposition-mtu-drop")

                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            self._children_yang_names.add("disposition-oo-o-drops")

                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            self._children_yang_names.add("disposition-p2mp-stats")

                                            self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                            self._children_yang_names.add("disposition-stat")

                                            self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            self._children_yang_names.add("disposition-tail-drop")

                                            self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            self._children_yang_names.add("ipsg-drop")

                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._children_yang_names.add("mac-move")

                                            self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                            self._children_yang_names.add("multicast-drop")

                                            self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                            self._children_yang_names.add("received-drops")

                                            self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                            self._children_yang_names.add("unicast-drop")


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "received-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dai-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipsg-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-oo-o-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionP2MpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-p2mp-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mac-move" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.mac_move is not None and self.mac_move.has_data()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                (self.received_drops is not None and self.received_drops.has_data()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.mac_move is not None and self.mac_move.has_operation()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                (self.received_drops is not None and self.received_drops.has_operation()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dispostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast-drop"):
                                                if (self.broadcast_drop is None):
                                                    self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                                    self.broadcast_drop.parent = self
                                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                return self.broadcast_drop

                                            if (child_yang_name == "dai-drop"):
                                                if (self.dai_drop is None):
                                                    self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                                    self.dai_drop.parent = self
                                                    self._children_name_map["dai_drop"] = "dai-drop"
                                                return self.dai_drop

                                            if (child_yang_name == "disposition-mtu-drop"):
                                                if (self.disposition_mtu_drop is None):
                                                    self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                                    self.disposition_mtu_drop.parent = self
                                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                return self.disposition_mtu_drop

                                            if (child_yang_name == "disposition-oo-o-drops"):
                                                if (self.disposition_oo_o_drops is None):
                                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                                    self.disposition_oo_o_drops.parent = self
                                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                return self.disposition_oo_o_drops

                                            if (child_yang_name == "disposition-p2mp-stats"):
                                                if (self.disposition_p2mp_stats is None):
                                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                                    self.disposition_p2mp_stats.parent = self
                                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                return self.disposition_p2mp_stats

                                            if (child_yang_name == "disposition-stat"):
                                                if (self.disposition_stat is None):
                                                    self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                                    self.disposition_stat.parent = self
                                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                                return self.disposition_stat

                                            if (child_yang_name == "disposition-tail-drop"):
                                                if (self.disposition_tail_drop is None):
                                                    self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                                    self.disposition_tail_drop.parent = self
                                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                return self.disposition_tail_drop

                                            if (child_yang_name == "ipsg-drop"):
                                                if (self.ipsg_drop is None):
                                                    self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                                    self.ipsg_drop.parent = self
                                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                return self.ipsg_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "mac-move"):
                                                if (self.mac_move is None):
                                                    self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                                    self.mac_move.parent = self
                                                    self._children_name_map["mac_move"] = "mac-move"
                                                return self.mac_move

                                            if (child_yang_name == "multicast-drop"):
                                                if (self.multicast_drop is None):
                                                    self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                                    self.multicast_drop.parent = self
                                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                                return self.multicast_drop

                                            if (child_yang_name == "received-drops"):
                                                if (self.received_drops is None):
                                                    self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                                    self.received_drops.parent = self
                                                    self._children_name_map["received_drops"] = "received-drops"
                                                return self.received_drops

                                            if (child_yang_name == "unicast-drop"):
                                                if (self.unicast_drop is None):
                                                    self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                                    self.unicast_drop.parent = self
                                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                                return self.unicast_drop

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"

                                            self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                            self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                            self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                            self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bypassed_inbound_sequence_packet",
                                                            "bypassed_out_sequence_packet",
                                                            "sequence_number_expected",
                                                            "sequence_number_sent") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bypassed_inbound_sequence_packet.is_set or
                                                self.bypassed_out_sequence_packet.is_set or
                                                self.sequence_number_expected.is_set or
                                                self.sequence_number_sent.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                self.sequence_number_expected.yfilter != YFilter.not_set or
                                                self.sequence_number_sent.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sequence-number" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                            if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                            if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                            if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bypassed-inbound-sequence-packet"):
                                                self.bypassed_inbound_sequence_packet = value
                                                self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bypassed-out-sequence-packet"):
                                                self.bypassed_out_sequence_packet = value
                                                self.bypassed_out_sequence_packet.value_namespace = name_space
                                                self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-expected"):
                                                self.sequence_number_expected = value
                                                self.sequence_number_expected.value_namespace = name_space
                                                self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-sent"):
                                                self.sequence_number_sent = value
                                                self.sequence_number_sent.value_namespace = name_space
                                                self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                            (self.sequence_number is not None and self.sequence_number.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                            (self.sequence_number is not None and self.sequence_number.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "statistics" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dispostion-stats"):
                                            if (self.dispostion_stats is None):
                                                self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                                self.dispostion_stats.parent = self
                                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            return self.dispostion_stats

                                        if (child_yang_name == "impostion-stats"):
                                            if (self.impostion_stats is None):
                                                self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                                self.impostion_stats.parent = self
                                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                            return self.impostion_stats

                                        if (child_yang_name == "sequence-number"):
                                            if (self.sequence_number is None):
                                                self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                                self.sequence_number.parent = self
                                                self._children_name_map["sequence_number"] = "sequence-number"
                                            return self.sequence_number

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class BmacMapping(Entity):
                                    """
                                    CMAC to BMAC Mapping
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__init__()

                                        self.yang_name = "bmac-mapping"
                                        self.yang_parent_name = "edge-port"

                                        self.address = YLeaf(YType.str, "address")

                                        self.bmac = YLeaf(YType.str, "bmac")

                                        self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("address",
                                                        "bmac",
                                                        "next_hop_ip") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.address.is_set or
                                            self.bmac.is_set or
                                            self.next_hop_ip.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.address.yfilter != YFilter.not_set or
                                            self.bmac.yfilter != YFilter.not_set or
                                            self.next_hop_ip.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bmac-mapping" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.address.get_name_leafdata())
                                        if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bmac.get_name_leafdata())
                                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "address"):
                                            self.address = value
                                            self.address.value_namespace = name_space
                                            self.address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bmac"):
                                            self.bmac = value
                                            self.bmac.value_namespace = name_space
                                            self.bmac.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop-ip"):
                                            self.next_hop_ip = value
                                            self.next_hop_ip.value_namespace = name_space
                                            self.next_hop_ip.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.bmac_mapping:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.edge_port_state.is_set or
                                        self.unknown_unicast_mac.is_set or
                                        self.unknown_unicast_mac_set.is_set or
                                        self.xconnect_id.is_set or
                                        (self.security_parameters is not None and self.security_parameters.has_data()) or
                                        (self.statistics is not None and self.statistics.has_data()))

                                def has_operation(self):
                                    for c in self.bmac_mapping:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.edge_port_state.yfilter != YFilter.not_set or
                                        self.unknown_unicast_mac.yfilter != YFilter.not_set or
                                        self.unknown_unicast_mac_set.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                        (self.statistics is not None and self.statistics.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "edge-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.edge_port_state.is_set or self.edge_port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.edge_port_state.get_name_leafdata())
                                    if (self.unknown_unicast_mac.is_set or self.unknown_unicast_mac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unknown_unicast_mac.get_name_leafdata())
                                    if (self.unknown_unicast_mac_set.is_set or self.unknown_unicast_mac_set.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unknown_unicast_mac_set.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "bmac-mapping"):
                                        for c in self.bmac_mapping:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.bmac_mapping.append(c)
                                        return c

                                    if (child_yang_name == "security-parameters"):
                                        if (self.security_parameters is None):
                                            self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                            self.security_parameters.parent = self
                                            self._children_name_map["security_parameters"] = "security-parameters"
                                        return self.security_parameters

                                    if (child_yang_name == "statistics"):
                                        if (self.statistics is None):
                                            self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                            self.statistics.parent = self
                                            self._children_name_map["statistics"] = "statistics"
                                        return self.statistics

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bmac-mapping" or name == "security-parameters" or name == "statistics" or name == "edge-port-state" or name == "unknown-unicast-mac" or name == "unknown-unicast-mac-set" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "edge-port-state"):
                                        self.edge_port_state = value
                                        self.edge_port_state.value_namespace = name_space
                                        self.edge_port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unknown-unicast-mac"):
                                        self.unknown_unicast_mac = value
                                        self.unknown_unicast_mac.value_namespace = name_space
                                        self.unknown_unicast_mac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unknown-unicast-mac-set"):
                                        self.unknown_unicast_mac_set = value
                                        self.unknown_unicast_mac_set.value_namespace = name_space
                                        self.unknown_unicast_mac_set.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.core_bridge_name.is_set or
                                    self.core_bridge_state.is_set or
                                    self.i_sid.is_set or
                                    self.mirp_lite_protocol.is_set or
                                    self.mirp_lite_status.is_set or
                                    (self.edge_port is not None and self.edge_port.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.core_bridge_name.yfilter != YFilter.not_set or
                                    self.core_bridge_state.yfilter != YFilter.not_set or
                                    self.i_sid.yfilter != YFilter.not_set or
                                    self.mirp_lite_protocol.yfilter != YFilter.not_set or
                                    self.mirp_lite_status.yfilter != YFilter.not_set or
                                    (self.edge_port is not None and self.edge_port.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb-edge" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.core_bridge_name.is_set or self.core_bridge_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_bridge_name.get_name_leafdata())
                                if (self.core_bridge_state.is_set or self.core_bridge_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_bridge_state.get_name_leafdata())
                                if (self.i_sid.is_set or self.i_sid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.i_sid.get_name_leafdata())
                                if (self.mirp_lite_protocol.is_set or self.mirp_lite_protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mirp_lite_protocol.get_name_leafdata())
                                if (self.mirp_lite_status.is_set or self.mirp_lite_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mirp_lite_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "edge-port"):
                                    if (self.edge_port is None):
                                        self.edge_port = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                        self.edge_port.parent = self
                                        self._children_name_map["edge_port"] = "edge-port"
                                    return self.edge_port

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "edge-port" or name == "core-bridge-name" or name == "core-bridge-state" or name == "i-sid" or name == "mirp-lite-protocol" or name == "mirp-lite-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "core-bridge-name"):
                                    self.core_bridge_name = value
                                    self.core_bridge_name.value_namespace = name_space
                                    self.core_bridge_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "core-bridge-state"):
                                    self.core_bridge_state = value
                                    self.core_bridge_state.value_namespace = name_space
                                    self.core_bridge_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "i-sid"):
                                    self.i_sid = value
                                    self.i_sid.value_namespace = name_space
                                    self.i_sid.value_namespace_prefix = name_space_prefix
                                if(value_path == "mirp-lite-protocol"):
                                    self.mirp_lite_protocol = value
                                    self.mirp_lite_protocol.value_namespace = name_space
                                    self.mirp_lite_protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "mirp-lite-status"):
                                    self.mirp_lite_status = value
                                    self.mirp_lite_status.value_namespace = name_space
                                    self.mirp_lite_status.value_namespace_prefix = name_space_prefix


                        class PbbCore(Entity):
                            """
                            PBB Core
                            
                            .. attribute:: core_port
                            
                            	PBB Core Port
                            	**type**\:   :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                            
                            .. attribute:: num_ass_edge
                            
                            	Number of Associated PBB Edges
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__init__()

                                self.yang_name = "pbb-core"
                                self.yang_parent_name = "pbb-parameters"

                                self.num_ass_edge = YLeaf(YType.uint32, "num-ass-edge")

                                self.core_port = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                self.core_port.parent = self
                                self._children_name_map["core_port"] = "core-port"
                                self._children_yang_names.add("core-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("num_ass_edge") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__setattr__(name, value)


                            class CorePort(Entity):
                                """
                                PBB Core Port
                                
                                .. attribute:: core_port_state
                                
                                	PBB Core Port State
                                	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                                
                                .. attribute:: vlan_id
                                
                                	Vlan ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__init__()

                                    self.yang_name = "core-port"
                                    self.yang_parent_name = "pbb-core"

                                    self.core_port_state = YLeaf(YType.enumeration, "core-port-state")

                                    self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                    self._children_yang_names.add("security-parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("core_port_state",
                                                    "vlan_id",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__setattr__(name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "core-port"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                        self._children_yang_names.add("base")

                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dhcpv4_trust",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__setattr__(name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"

                                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                            self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                            self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                            self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                            self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                            self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                            self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                            self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                            self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                            self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                            self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                            self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                            self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                            self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                            self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                            self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                            self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                            self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                            self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                            self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                            self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                            self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                            self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                            self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                            self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                            self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                            self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                            self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                            self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                            self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                            self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                            self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._children_yang_names.add("storm-control")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("broadcast_storm_control_kb_ps",
                                                            "broadcast_storm_control_pps",
                                                            "broadcast_storm_control_rate_unit",
                                                            "dai_address_validation_mask",
                                                            "dhcpv4_profile_name",
                                                            "dhcpv4_snoop",
                                                            "flood_unknown_unicast_enabled",
                                                            "flood_uu_disabled_mac_limit_action",
                                                            "igm_pv4_disabled",
                                                            "igm_pv4_profile_name",
                                                            "is_dai_addr_validate_destination_mac_enabled",
                                                            "is_dai_addr_validate_ipv4_enabled",
                                                            "is_dai_addr_validate_source_mac_enabled",
                                                            "is_dai_enabled",
                                                            "is_dai_logging_enabled",
                                                            "is_ip_source_guard_enabled",
                                                            "is_ipsg_logging_enabled",
                                                            "is_mac_secure_accept_shutdown_enabled",
                                                            "is_mac_secure_enabled",
                                                            "is_mac_secure_logging_enabled",
                                                            "learn_disabled_mac_limit_action",
                                                            "mac_aging_mode",
                                                            "mac_aging_time",
                                                            "mac_flooding",
                                                            "mac_learning",
                                                            "mac_limit",
                                                            "mac_limit_action",
                                                            "mac_limit_notification",
                                                            "mac_limit_reached",
                                                            "mac_port_down_flush_enabled",
                                                            "mac_secure_action",
                                                            "mld_profile_name",
                                                            "mmrp_flood_optimization",
                                                            "multicast_storm_control_kb_ps",
                                                            "multicast_storm_control_pps",
                                                            "multicast_storm_control_rate_unit",
                                                            "split_horizon_group_id",
                                                            "unicast_storm_control_kb_ps",
                                                            "unicast_storm_control_pps",
                                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__setattr__(name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"

                                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                self.multicast = YLeaf(YType.boolean, "multicast")

                                                self.unicast = YLeaf(YType.boolean, "unicast")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bd_policer",
                                                                "broadcast",
                                                                "multicast",
                                                                "unicast") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bd_policer.is_set or
                                                    self.broadcast.is_set or
                                                    self.multicast.is_set or
                                                    self.unicast.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bd_policer.yfilter != YFilter.not_set or
                                                    self.broadcast.yfilter != YFilter.not_set or
                                                    self.multicast.yfilter != YFilter.not_set or
                                                    self.unicast.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "storm-control" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/base/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bd-policer"):
                                                    self.bd_policer = value
                                                    self.bd_policer.value_namespace = name_space
                                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast"):
                                                    self.broadcast = value
                                                    self.broadcast.value_namespace = name_space
                                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast"):
                                                    self.multicast = value
                                                    self.multicast.value_namespace = name_space
                                                    self.multicast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast"):
                                                    self.unicast = value
                                                    self.unicast.value_namespace = name_space
                                                    self.unicast.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.broadcast_storm_control_kb_ps.is_set or
                                                self.broadcast_storm_control_pps.is_set or
                                                self.broadcast_storm_control_rate_unit.is_set or
                                                self.dai_address_validation_mask.is_set or
                                                self.dhcpv4_profile_name.is_set or
                                                self.dhcpv4_snoop.is_set or
                                                self.flood_unknown_unicast_enabled.is_set or
                                                self.flood_uu_disabled_mac_limit_action.is_set or
                                                self.igm_pv4_disabled.is_set or
                                                self.igm_pv4_profile_name.is_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                                self.is_dai_addr_validate_ipv4_enabled.is_set or
                                                self.is_dai_addr_validate_source_mac_enabled.is_set or
                                                self.is_dai_enabled.is_set or
                                                self.is_dai_logging_enabled.is_set or
                                                self.is_ip_source_guard_enabled.is_set or
                                                self.is_ipsg_logging_enabled.is_set or
                                                self.is_mac_secure_accept_shutdown_enabled.is_set or
                                                self.is_mac_secure_enabled.is_set or
                                                self.is_mac_secure_logging_enabled.is_set or
                                                self.learn_disabled_mac_limit_action.is_set or
                                                self.mac_aging_mode.is_set or
                                                self.mac_aging_time.is_set or
                                                self.mac_flooding.is_set or
                                                self.mac_learning.is_set or
                                                self.mac_limit.is_set or
                                                self.mac_limit_action.is_set or
                                                self.mac_limit_notification.is_set or
                                                self.mac_limit_reached.is_set or
                                                self.mac_port_down_flush_enabled.is_set or
                                                self.mac_secure_action.is_set or
                                                self.mld_profile_name.is_set or
                                                self.mmrp_flood_optimization.is_set or
                                                self.multicast_storm_control_kb_ps.is_set or
                                                self.multicast_storm_control_pps.is_set or
                                                self.multicast_storm_control_rate_unit.is_set or
                                                self.split_horizon_group_id.is_set or
                                                self.unicast_storm_control_kb_ps.is_set or
                                                self.unicast_storm_control_pps.is_set or
                                                self.unicast_storm_control_rate_unit.is_set or
                                                (self.storm_control is not None and self.storm_control.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                                self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                                self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                                self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                                self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                                self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                                self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                                self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_aging_mode.yfilter != YFilter.not_set or
                                                self.mac_aging_time.yfilter != YFilter.not_set or
                                                self.mac_flooding.yfilter != YFilter.not_set or
                                                self.mac_learning.yfilter != YFilter.not_set or
                                                self.mac_limit.yfilter != YFilter.not_set or
                                                self.mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_limit_notification.yfilter != YFilter.not_set or
                                                self.mac_limit_reached.yfilter != YFilter.not_set or
                                                self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                                self.mac_secure_action.yfilter != YFilter.not_set or
                                                self.mld_profile_name.yfilter != YFilter.not_set or
                                                self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.split_horizon_group_id.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                (self.storm_control is not None and self.storm_control.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "base" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                            if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                            if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                            if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                            if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                            if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                            if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                            if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                            if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                            if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                            if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                            if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                            if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                            if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                            if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                            if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                            if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                            if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                            if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                            if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                            if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                            if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "storm-control"):
                                                if (self.storm_control is None):
                                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                                    self.storm_control.parent = self
                                                    self._children_name_map["storm_control"] = "storm-control"
                                                return self.storm_control

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "broadcast-storm-control-kb-ps"):
                                                self.broadcast_storm_control_kb_ps = value
                                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-pps"):
                                                self.broadcast_storm_control_pps = value
                                                self.broadcast_storm_control_pps.value_namespace = name_space
                                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-rate-unit"):
                                                self.broadcast_storm_control_rate_unit = value
                                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dai-address-validation-mask"):
                                                self.dai_address_validation_mask = value
                                                self.dai_address_validation_mask.value_namespace = name_space
                                                self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-profile-name"):
                                                self.dhcpv4_profile_name = value
                                                self.dhcpv4_profile_name.value_namespace = name_space
                                                self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-snoop"):
                                                self.dhcpv4_snoop = value
                                                self.dhcpv4_snoop.value_namespace = name_space
                                                self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-unknown-unicast-enabled"):
                                                self.flood_unknown_unicast_enabled = value
                                                self.flood_unknown_unicast_enabled.value_namespace = name_space
                                                self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-uu-disabled-mac-limit-action"):
                                                self.flood_uu_disabled_mac_limit_action = value
                                                self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                                self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-disabled"):
                                                self.igm_pv4_disabled = value
                                                self.igm_pv4_disabled.value_namespace = name_space
                                                self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-profile-name"):
                                                self.igm_pv4_profile_name = value
                                                self.igm_pv4_profile_name.value_namespace = name_space
                                                self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                                self.is_dai_addr_validate_destination_mac_enabled = value
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                                self.is_dai_addr_validate_ipv4_enabled = value
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                                self.is_dai_addr_validate_source_mac_enabled = value
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-enabled"):
                                                self.is_dai_enabled = value
                                                self.is_dai_enabled.value_namespace = name_space
                                                self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-logging-enabled"):
                                                self.is_dai_logging_enabled = value
                                                self.is_dai_logging_enabled.value_namespace = name_space
                                                self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ip-source-guard-enabled"):
                                                self.is_ip_source_guard_enabled = value
                                                self.is_ip_source_guard_enabled.value_namespace = name_space
                                                self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ipsg-logging-enabled"):
                                                self.is_ipsg_logging_enabled = value
                                                self.is_ipsg_logging_enabled.value_namespace = name_space
                                                self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                                self.is_mac_secure_accept_shutdown_enabled = value
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-enabled"):
                                                self.is_mac_secure_enabled = value
                                                self.is_mac_secure_enabled.value_namespace = name_space
                                                self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-logging-enabled"):
                                                self.is_mac_secure_logging_enabled = value
                                                self.is_mac_secure_logging_enabled.value_namespace = name_space
                                                self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "learn-disabled-mac-limit-action"):
                                                self.learn_disabled_mac_limit_action = value
                                                self.learn_disabled_mac_limit_action.value_namespace = name_space
                                                self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-mode"):
                                                self.mac_aging_mode = value
                                                self.mac_aging_mode.value_namespace = name_space
                                                self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-time"):
                                                self.mac_aging_time = value
                                                self.mac_aging_time.value_namespace = name_space
                                                self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-flooding"):
                                                self.mac_flooding = value
                                                self.mac_flooding.value_namespace = name_space
                                                self.mac_flooding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-learning"):
                                                self.mac_learning = value
                                                self.mac_learning.value_namespace = name_space
                                                self.mac_learning.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit"):
                                                self.mac_limit = value
                                                self.mac_limit.value_namespace = name_space
                                                self.mac_limit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-action"):
                                                self.mac_limit_action = value
                                                self.mac_limit_action.value_namespace = name_space
                                                self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-notification"):
                                                self.mac_limit_notification = value
                                                self.mac_limit_notification.value_namespace = name_space
                                                self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-reached"):
                                                self.mac_limit_reached = value
                                                self.mac_limit_reached.value_namespace = name_space
                                                self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-port-down-flush-enabled"):
                                                self.mac_port_down_flush_enabled = value
                                                self.mac_port_down_flush_enabled.value_namespace = name_space
                                                self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-secure-action"):
                                                self.mac_secure_action = value
                                                self.mac_secure_action.value_namespace = name_space
                                                self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mld-profile-name"):
                                                self.mld_profile_name = value
                                                self.mld_profile_name.value_namespace = name_space
                                                self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mmrp-flood-optimization"):
                                                self.mmrp_flood_optimization = value
                                                self.mmrp_flood_optimization.value_namespace = name_space
                                                self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-kb-ps"):
                                                self.multicast_storm_control_kb_ps = value
                                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-pps"):
                                                self.multicast_storm_control_pps = value
                                                self.multicast_storm_control_pps.value_namespace = name_space
                                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-rate-unit"):
                                                self.multicast_storm_control_rate_unit = value
                                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "split-horizon-group-id"):
                                                self.split_horizon_group_id = value
                                                self.split_horizon_group_id.value_namespace = name_space
                                                self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-kb-ps"):
                                                self.unicast_storm_control_kb_ps = value
                                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-pps"):
                                                self.unicast_storm_control_pps = value
                                                self.unicast_storm_control_pps.value_namespace = name_space
                                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-rate-unit"):
                                                self.unicast_storm_control_rate_unit = value
                                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dhcpv4_trust.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.base is not None and self.base.has_data()) or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dhcpv4_trust.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.base is not None and self.base.has_operation()) or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security-parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "base"):
                                            if (self.base is None):
                                                self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                                self.base.parent = self
                                                self._children_name_map["base"] = "base"
                                            return self.base

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-trust"):
                                            self.dhcpv4_trust = value
                                            self.dhcpv4_trust.value_namespace = name_space
                                            self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.core_port_state.is_set or
                                        self.vlan_id.is_set or
                                        self.xconnect_id.is_set or
                                        (self.security_parameters is not None and self.security_parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.core_port_state.yfilter != YFilter.not_set or
                                        self.vlan_id.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.security_parameters is not None and self.security_parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "core-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.core_port_state.is_set or self.core_port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.core_port_state.get_name_leafdata())
                                    if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_id.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "security-parameters"):
                                        if (self.security_parameters is None):
                                            self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                            self.security_parameters.parent = self
                                            self._children_name_map["security_parameters"] = "security-parameters"
                                        return self.security_parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "security-parameters" or name == "core-port-state" or name == "vlan-id" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "core-port-state"):
                                        self.core_port_state = value
                                        self.core_port_state.value_namespace = name_space
                                        self.core_port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-id"):
                                        self.vlan_id = value
                                        self.vlan_id.value_namespace = name_space
                                        self.vlan_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.num_ass_edge.is_set or
                                    (self.core_port is not None and self.core_port.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.num_ass_edge.yfilter != YFilter.not_set or
                                    (self.core_port is not None and self.core_port.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb-core" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.num_ass_edge.is_set or self.num_ass_edge.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ass_edge.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "core-port"):
                                    if (self.core_port is None):
                                        self.core_port = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                        self.core_port.parent = self
                                        self._children_name_map["core_port"] = "core-port"
                                    return self.core_port

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "core-port" or name == "num-ass-edge"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "num-ass-edge"):
                                    self.num_ass_edge = value
                                    self.num_ass_edge.value_namespace = name_space
                                    self.num_ass_edge.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.type.is_set or
                                (self.pbb_core is not None and self.pbb_core.has_data()) or
                                (self.pbb_edge is not None and self.pbb_edge.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.type.yfilter != YFilter.not_set or
                                (self.pbb_core is not None and self.pbb_core.has_operation()) or
                                (self.pbb_edge is not None and self.pbb_edge.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pbb-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "pbb-core"):
                                if (self.pbb_core is None):
                                    self.pbb_core = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                                    self.pbb_core.parent = self
                                    self._children_name_map["pbb_core"] = "pbb-core"
                                return self.pbb_core

                            if (child_yang_name == "pbb-edge"):
                                if (self.pbb_edge is None):
                                    self.pbb_edge = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                                    self.pbb_edge.parent = self
                                    self._children_name_map["pbb_edge"] = "pbb-edge"
                                return self.pbb_edge

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "pbb-core" or name == "pbb-edge" or name == "type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "type"):
                                self.type = value
                                self.type.value_namespace = name_space
                                self.type.value_namespace_prefix = name_space_prefix


                    class EvpnParameters(Entity):
                        """
                        EVPN parameters
                        
                        .. attribute:: evi
                        
                        	E\-VPN id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_port
                        
                        	EVPN Port
                        	**type**\:   :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__init__()

                            self.yang_name = "evpn-parameters"
                            self.yang_parent_name = "bridge-domain-info"

                            self.evi = YLeaf(YType.uint32, "evi")

                            self.evpn_port = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                            self.evpn_port.parent = self
                            self._children_name_map["evpn_port"] = "evpn-port"
                            self._children_yang_names.add("evpn-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("evi") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__setattr__(name, value)


                        class EvpnPort(Entity):
                            """
                            EVPN Port
                            
                            .. attribute:: evpn_port_state
                            
                            	EVPN Port State
                            	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__init__()

                                self.yang_name = "evpn-port"
                                self.yang_parent_name = "evpn-parameters"

                                self.evpn_port_state = YLeaf(YType.enumeration, "evpn-port-state")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                                self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("evpn_port_state",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__setattr__(name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "evpn-port"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/base/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "evpn-port"

                                    self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.evpn_port_state.is_set or
                                    self.xconnect_id.is_set or
                                    (self.security_parameters is not None and self.security_parameters.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.evpn_port_state.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn-port" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.evpn_port_state.is_set or self.evpn_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_port_state.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "security-parameters" or name == "statistics" or name == "evpn-port-state" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "evpn-port-state"):
                                    self.evpn_port_state = value
                                    self.evpn_port_state.value_namespace = name_space
                                    self.evpn_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.evi.is_set or
                                (self.evpn_port is not None and self.evpn_port.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.evi.yfilter != YFilter.not_set or
                                (self.evpn_port is not None and self.evpn_port.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "evpn-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evi.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "evpn-port"):
                                if (self.evpn_port is None):
                                    self.evpn_port = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                                    self.evpn_port.parent = self
                                    self._children_name_map["evpn_port"] = "evpn-port"
                                return self.evpn_port

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "evpn-port" or name == "evi"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "evi"):
                                self.evi = value
                                self.evi.value_namespace = name_space
                                self.evi.value_namespace_prefix = name_space_prefix


                    class VniParameters(Entity):
                        """
                        VNI parameters
                        
                        .. attribute:: anycast_mcast_group_addr
                        
                        	Anycast Multicast Group Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: anycast_vtep_ip_addr
                        
                        	Anycast VTEP IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: multicast_group_addr
                        
                        	Multicast Group Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: overlay
                        
                        	NVE Overlay
                        	**type**\:  str
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                        
                        .. attribute:: source_ip_addr
                        
                        	Source IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                        
                        .. attribute:: udp_port
                        
                        	UDP Port
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vni
                        
                        	VNI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vni_encap_type
                        
                        	VNI Encapsulation Type
                        	**type**\:   :py:class:`L2VpnVniEncaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniEncaps>`
                        
                        .. attribute:: vni_mode
                        
                        	VNI Mode
                        	**type**\:   :py:class:`L2VpnVniMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniMode>`
                        
                        .. attribute:: vni_port_state
                        
                        	VNI Port State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: xconnect_id
                        
                        	Xconnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__init__()

                            self.yang_name = "vni-parameters"
                            self.yang_parent_name = "bridge-domain-info"

                            self.anycast_mcast_group_addr = YLeaf(YType.str, "anycast-mcast-group-addr")

                            self.anycast_vtep_ip_addr = YLeaf(YType.str, "anycast-vtep-ip-addr")

                            self.multicast_group_addr = YLeaf(YType.str, "multicast-group-addr")

                            self.overlay = YLeaf(YType.str, "overlay")

                            self.source_ip_addr = YLeaf(YType.str, "source-ip-addr")

                            self.udp_port = YLeaf(YType.uint32, "udp-port")

                            self.vni = YLeaf(YType.uint32, "vni")

                            self.vni_encap_type = YLeaf(YType.enumeration, "vni-encap-type")

                            self.vni_mode = YLeaf(YType.enumeration, "vni-mode")

                            self.vni_port_state = YLeaf(YType.enumeration, "vni-port-state")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                            self._children_yang_names.add("security-parameters")

                            self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                            self.static_mac = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("anycast_mcast_group_addr",
                                            "anycast_vtep_ip_addr",
                                            "multicast_group_addr",
                                            "overlay",
                                            "source_ip_addr",
                                            "udp_port",
                                            "vni",
                                            "vni_encap_type",
                                            "vni_mode",
                                            "vni_port_state",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__setattr__(name, value)


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "vni-parameters"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dhcpv4_trust",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                    self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                    self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                    self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                    self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                    self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                    self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                    self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                    self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                    self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                    self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                    self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                    self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                    self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                    self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                    self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                    self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                    self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                    self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                    self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                    self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                    self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                    self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                    self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                    self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                    self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                    self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                    self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                    self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                    self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dai_address_validation_mask",
                                                    "dhcpv4_profile_name",
                                                    "dhcpv4_snoop",
                                                    "flood_unknown_unicast_enabled",
                                                    "flood_uu_disabled_mac_limit_action",
                                                    "igm_pv4_disabled",
                                                    "igm_pv4_profile_name",
                                                    "is_dai_addr_validate_destination_mac_enabled",
                                                    "is_dai_addr_validate_ipv4_enabled",
                                                    "is_dai_addr_validate_source_mac_enabled",
                                                    "is_dai_enabled",
                                                    "is_dai_logging_enabled",
                                                    "is_ip_source_guard_enabled",
                                                    "is_ipsg_logging_enabled",
                                                    "is_mac_secure_accept_shutdown_enabled",
                                                    "is_mac_secure_enabled",
                                                    "is_mac_secure_logging_enabled",
                                                    "learn_disabled_mac_limit_action",
                                                    "mac_aging_mode",
                                                    "mac_aging_time",
                                                    "mac_flooding",
                                                    "mac_learning",
                                                    "mac_limit",
                                                    "mac_limit_action",
                                                    "mac_limit_notification",
                                                    "mac_limit_reached",
                                                    "mac_port_down_flush_enabled",
                                                    "mac_secure_action",
                                                    "mld_profile_name",
                                                    "mmrp_flood_optimization",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "split_horizon_group_id",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__setattr__(name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/base/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dai_address_validation_mask.is_set or
                                        self.dhcpv4_profile_name.is_set or
                                        self.dhcpv4_snoop.is_set or
                                        self.flood_unknown_unicast_enabled.is_set or
                                        self.flood_uu_disabled_mac_limit_action.is_set or
                                        self.igm_pv4_disabled.is_set or
                                        self.igm_pv4_profile_name.is_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                        self.is_dai_addr_validate_ipv4_enabled.is_set or
                                        self.is_dai_addr_validate_source_mac_enabled.is_set or
                                        self.is_dai_enabled.is_set or
                                        self.is_dai_logging_enabled.is_set or
                                        self.is_ip_source_guard_enabled.is_set or
                                        self.is_ipsg_logging_enabled.is_set or
                                        self.is_mac_secure_accept_shutdown_enabled.is_set or
                                        self.is_mac_secure_enabled.is_set or
                                        self.is_mac_secure_logging_enabled.is_set or
                                        self.learn_disabled_mac_limit_action.is_set or
                                        self.mac_aging_mode.is_set or
                                        self.mac_aging_time.is_set or
                                        self.mac_flooding.is_set or
                                        self.mac_learning.is_set or
                                        self.mac_limit.is_set or
                                        self.mac_limit_action.is_set or
                                        self.mac_limit_notification.is_set or
                                        self.mac_limit_reached.is_set or
                                        self.mac_port_down_flush_enabled.is_set or
                                        self.mac_secure_action.is_set or
                                        self.mld_profile_name.is_set or
                                        self.mmrp_flood_optimization.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.split_horizon_group_id.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                        self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                        self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                        self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                        self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                        self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                        self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                        self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_aging_mode.yfilter != YFilter.not_set or
                                        self.mac_aging_time.yfilter != YFilter.not_set or
                                        self.mac_flooding.yfilter != YFilter.not_set or
                                        self.mac_learning.yfilter != YFilter.not_set or
                                        self.mac_limit.yfilter != YFilter.not_set or
                                        self.mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_limit_notification.yfilter != YFilter.not_set or
                                        self.mac_limit_reached.yfilter != YFilter.not_set or
                                        self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                        self.mac_secure_action.yfilter != YFilter.not_set or
                                        self.mld_profile_name.yfilter != YFilter.not_set or
                                        self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.split_horizon_group_id.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                    if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                    if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                    if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                    if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                    if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                    if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                    if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                    if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                    if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                    if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                    if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                    if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                    if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                    if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                    if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                    if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                    if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                    if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                    if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                    if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                    if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dai-address-validation-mask"):
                                        self.dai_address_validation_mask = value
                                        self.dai_address_validation_mask.value_namespace = name_space
                                        self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-profile-name"):
                                        self.dhcpv4_profile_name = value
                                        self.dhcpv4_profile_name.value_namespace = name_space
                                        self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-snoop"):
                                        self.dhcpv4_snoop = value
                                        self.dhcpv4_snoop.value_namespace = name_space
                                        self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-unknown-unicast-enabled"):
                                        self.flood_unknown_unicast_enabled = value
                                        self.flood_unknown_unicast_enabled.value_namespace = name_space
                                        self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-uu-disabled-mac-limit-action"):
                                        self.flood_uu_disabled_mac_limit_action = value
                                        self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                        self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-disabled"):
                                        self.igm_pv4_disabled = value
                                        self.igm_pv4_disabled.value_namespace = name_space
                                        self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-profile-name"):
                                        self.igm_pv4_profile_name = value
                                        self.igm_pv4_profile_name.value_namespace = name_space
                                        self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                        self.is_dai_addr_validate_destination_mac_enabled = value
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                        self.is_dai_addr_validate_ipv4_enabled = value
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                        self.is_dai_addr_validate_source_mac_enabled = value
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-enabled"):
                                        self.is_dai_enabled = value
                                        self.is_dai_enabled.value_namespace = name_space
                                        self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-logging-enabled"):
                                        self.is_dai_logging_enabled = value
                                        self.is_dai_logging_enabled.value_namespace = name_space
                                        self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ip-source-guard-enabled"):
                                        self.is_ip_source_guard_enabled = value
                                        self.is_ip_source_guard_enabled.value_namespace = name_space
                                        self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ipsg-logging-enabled"):
                                        self.is_ipsg_logging_enabled = value
                                        self.is_ipsg_logging_enabled.value_namespace = name_space
                                        self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                        self.is_mac_secure_accept_shutdown_enabled = value
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-enabled"):
                                        self.is_mac_secure_enabled = value
                                        self.is_mac_secure_enabled.value_namespace = name_space
                                        self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-logging-enabled"):
                                        self.is_mac_secure_logging_enabled = value
                                        self.is_mac_secure_logging_enabled.value_namespace = name_space
                                        self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "learn-disabled-mac-limit-action"):
                                        self.learn_disabled_mac_limit_action = value
                                        self.learn_disabled_mac_limit_action.value_namespace = name_space
                                        self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-mode"):
                                        self.mac_aging_mode = value
                                        self.mac_aging_mode.value_namespace = name_space
                                        self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-time"):
                                        self.mac_aging_time = value
                                        self.mac_aging_time.value_namespace = name_space
                                        self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flooding"):
                                        self.mac_flooding = value
                                        self.mac_flooding.value_namespace = name_space
                                        self.mac_flooding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-learning"):
                                        self.mac_learning = value
                                        self.mac_learning.value_namespace = name_space
                                        self.mac_learning.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit"):
                                        self.mac_limit = value
                                        self.mac_limit.value_namespace = name_space
                                        self.mac_limit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-action"):
                                        self.mac_limit_action = value
                                        self.mac_limit_action.value_namespace = name_space
                                        self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-notification"):
                                        self.mac_limit_notification = value
                                        self.mac_limit_notification.value_namespace = name_space
                                        self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-reached"):
                                        self.mac_limit_reached = value
                                        self.mac_limit_reached.value_namespace = name_space
                                        self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-port-down-flush-enabled"):
                                        self.mac_port_down_flush_enabled = value
                                        self.mac_port_down_flush_enabled.value_namespace = name_space
                                        self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-secure-action"):
                                        self.mac_secure_action = value
                                        self.mac_secure_action.value_namespace = name_space
                                        self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mld-profile-name"):
                                        self.mld_profile_name = value
                                        self.mld_profile_name.value_namespace = name_space
                                        self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mmrp-flood-optimization"):
                                        self.mmrp_flood_optimization = value
                                        self.mmrp_flood_optimization.value_namespace = name_space
                                        self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "split-horizon-group-id"):
                                        self.split_horizon_group_id = value
                                        self.split_horizon_group_id.value_namespace = name_space
                                        self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dhcpv4_trust.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dhcpv4_trust.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-trust"):
                                    self.dhcpv4_trust = value
                                    self.dhcpv4_trust.value_namespace = name_space
                                    self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "vni-parameters"

                                self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "vni-parameters"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "static-mac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.static_mac:
                                if (c.has_data()):
                                    return True
                            return (
                                self.anycast_mcast_group_addr.is_set or
                                self.anycast_vtep_ip_addr.is_set or
                                self.multicast_group_addr.is_set or
                                self.overlay.is_set or
                                self.source_ip_addr.is_set or
                                self.udp_port.is_set or
                                self.vni.is_set or
                                self.vni_encap_type.is_set or
                                self.vni_mode.is_set or
                                self.vni_port_state.is_set or
                                self.xconnect_id.is_set or
                                (self.security_parameters is not None and self.security_parameters.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            for c in self.static_mac:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.anycast_mcast_group_addr.yfilter != YFilter.not_set or
                                self.anycast_vtep_ip_addr.yfilter != YFilter.not_set or
                                self.multicast_group_addr.yfilter != YFilter.not_set or
                                self.overlay.yfilter != YFilter.not_set or
                                self.source_ip_addr.yfilter != YFilter.not_set or
                                self.udp_port.yfilter != YFilter.not_set or
                                self.vni.yfilter != YFilter.not_set or
                                self.vni_encap_type.yfilter != YFilter.not_set or
                                self.vni_mode.yfilter != YFilter.not_set or
                                self.vni_port_state.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vni-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.anycast_mcast_group_addr.is_set or self.anycast_mcast_group_addr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_mcast_group_addr.get_name_leafdata())
                            if (self.anycast_vtep_ip_addr.is_set or self.anycast_vtep_ip_addr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_vtep_ip_addr.get_name_leafdata())
                            if (self.multicast_group_addr.is_set or self.multicast_group_addr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_group_addr.get_name_leafdata())
                            if (self.overlay.is_set or self.overlay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.overlay.get_name_leafdata())
                            if (self.source_ip_addr.is_set or self.source_ip_addr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_ip_addr.get_name_leafdata())
                            if (self.udp_port.is_set or self.udp_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.udp_port.get_name_leafdata())
                            if (self.vni.is_set or self.vni.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vni.get_name_leafdata())
                            if (self.vni_encap_type.is_set or self.vni_encap_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vni_encap_type.get_name_leafdata())
                            if (self.vni_mode.is_set or self.vni_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vni_mode.get_name_leafdata())
                            if (self.vni_port_state.is_set or self.vni_port_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vni_port_state.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "security-parameters"):
                                if (self.security_parameters is None):
                                    self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                return self.security_parameters

                            if (child_yang_name == "static-mac"):
                                for c in self.static_mac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.static_mac.append(c)
                                return c

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "security-parameters" or name == "static-mac" or name == "statistics" or name == "anycast-mcast-group-addr" or name == "anycast-vtep-ip-addr" or name == "multicast-group-addr" or name == "overlay" or name == "source-ip-addr" or name == "udp-port" or name == "vni" or name == "vni-encap-type" or name == "vni-mode" or name == "vni-port-state" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "anycast-mcast-group-addr"):
                                self.anycast_mcast_group_addr = value
                                self.anycast_mcast_group_addr.value_namespace = name_space
                                self.anycast_mcast_group_addr.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-vtep-ip-addr"):
                                self.anycast_vtep_ip_addr = value
                                self.anycast_vtep_ip_addr.value_namespace = name_space
                                self.anycast_vtep_ip_addr.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-group-addr"):
                                self.multicast_group_addr = value
                                self.multicast_group_addr.value_namespace = name_space
                                self.multicast_group_addr.value_namespace_prefix = name_space_prefix
                            if(value_path == "overlay"):
                                self.overlay = value
                                self.overlay.value_namespace = name_space
                                self.overlay.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-ip-addr"):
                                self.source_ip_addr = value
                                self.source_ip_addr.value_namespace = name_space
                                self.source_ip_addr.value_namespace_prefix = name_space_prefix
                            if(value_path == "udp-port"):
                                self.udp_port = value
                                self.udp_port.value_namespace = name_space
                                self.udp_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "vni"):
                                self.vni = value
                                self.vni.value_namespace = name_space
                                self.vni.value_namespace_prefix = name_space_prefix
                            if(value_path == "vni-encap-type"):
                                self.vni_encap_type = value
                                self.vni_encap_type.value_namespace = name_space
                                self.vni_encap_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "vni-mode"):
                                self.vni_mode = value
                                self.vni_mode.value_namespace = name_space
                                self.vni_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "vni-port-state"):
                                self.vni_port_state = value
                                self.vni_port_state.value_namespace = name_space
                                self.vni_port_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class Rd(Entity):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__init__()

                            self.yang_name = "rd"
                            self.yang_parent_name = "bridge-domain-info"

                            self.rd = YLeaf(YType.enumeration, "rd")

                            self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"
                            self._children_yang_names.add("auto")

                            self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                            self._children_yang_names.add("four-byte-as")

                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rd") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__setattr__(name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd"

                                self.auto_index = YLeaf(YType.uint16, "auto-index")

                                self.router_id = YLeaf(YType.str, "router-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("auto_index",
                                                "router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.auto_index.is_set or
                                    self.router_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.auto_index.yfilter != YFilter.not_set or
                                    self.router_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "auto" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_index.get_name_leafdata())
                                if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto-index" or name == "router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "auto-index"):
                                    self.auto_index = value
                                    self.auto_index.value_namespace = name_space
                                    self.auto_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-id"):
                                    self.router_id = value
                                    self.router_id.value_namespace = name_space
                                    self.router_id.value_namespace_prefix = name_space_prefix


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd"

                                self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_as",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_as.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_as.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "four-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-as" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-as"):
                                    self.four_byte_as = value
                                    self.four_byte_as.value_namespace = name_space
                                    self.four_byte_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.rd.is_set or
                                (self.auto is not None and self.auto.has_data()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rd.yfilter != YFilter.not_set or
                                (self.auto is not None and self.auto.has_operation()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rd" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rd.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "auto"):
                                if (self.auto is None):
                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                return self.auto

                            if (child_yang_name == "four-byte-as"):
                                if (self.four_byte_as is None):
                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                return self.four_byte_as

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rd"):
                                self.rd = value
                                self.rd.value_namespace = name_space
                                self.rd.value_namespace_prefix = name_space_prefix


                    class MacFilter(Entity):
                        """
                        MAC addresses for filtering
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__init__()

                            self.yang_name = "mac-filter"
                            self.yang_parent_name = "bridge-domain-info"

                            self.address = YLeaf(YType.str, "address")

                            self.bmac = YLeaf(YType.str, "bmac")

                            self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "bmac",
                                            "next_hop_ip") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.bmac.is_set or
                                self.next_hop_ip.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.bmac.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mac-filter" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bmac.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "bmac"):
                                self.bmac = value
                                self.bmac.value_namespace = name_space
                                self.bmac.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix


                    class BridgeVfi(Entity):
                        """
                        Virtual Forwarding Interfaces
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\:  bool
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\:  str
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:   :py:class:`L2VpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiState>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__init__()

                            self.yang_name = "bridge-vfi"
                            self.yang_parent_name = "bridge-domain-info"

                            self.access = YLeaf(YType.boolean, "access")

                            self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.vfi_name = YLeaf(YType.str, "vfi-name")

                            self.vfi_state = YLeaf(YType.enumeration, "vfi-state")

                            self.discovery_information = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self._children_name_map["discovery_information"] = "discovery-information"
                            self._children_yang_names.add("discovery-information")

                            self.p2mp_information = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("access",
                                            "number_pseudowires",
                                            "shutdown",
                                            "vfi_name",
                                            "vfi_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__setattr__(name, value)


                        class DiscoveryInformation(Entity):
                            """
                            Auto Discovery information
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\:  str
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\:  bool
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\:  bool
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\:  bool
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__init__()

                                self.yang_name = "discovery-information"
                                self.yang_parent_name = "bridge-vfi"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                                self.as_number = YLeaf(YType.uint32, "as-number")

                                self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                                self.l2vpn_router_id = YLeaf(YType.str, "l2vpn-router-id")

                                self.provisioned_ve_id = YLeaf(YType.uint32, "provisioned-ve-id")

                                self.service_connected = YLeaf(YType.boolean, "service-connected")

                                self.ve_id = YLeaf(YType.uint32, "ve-id")

                                self.ve_range = YLeaf(YType.uint16, "ve-range")

                                self.vpls_id_conflict = YLeaf(YType.boolean, "vpls-id-conflict")

                                self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                self.rd_value = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self._children_name_map["rd_value"] = "rd-value"
                                self._children_yang_names.add("rd-value")

                                self.vpls_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self._children_name_map["vpls_id"] = "vpls-id"
                                self._children_yang_names.add("vpls-id")

                                self.export_rt = YList(self)
                                self.import_rt = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_signalling_method",
                                                "as_number",
                                                "export_route_policy",
                                                "l2vpn_router_id",
                                                "provisioned_ve_id",
                                                "service_connected",
                                                "ve_id",
                                                "ve_range",
                                                "vpls_id_conflict",
                                                "vpn_added",
                                                "vpn_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__setattr__(name, value)


                            class RdValue(Entity):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__init__()

                                    self.yang_name = "rd-value"
                                    self.yang_parent_name = "discovery-information"

                                    self.rd = YLeaf(YType.enumeration, "rd")

                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rd") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "rd-value"

                                        self.auto_index = YLeaf(YType.uint16, "auto-index")

                                        self.router_id = YLeaf(YType.str, "router-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("auto_index",
                                                        "router_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.auto_index.is_set or
                                            self.router_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.auto_index.yfilter != YFilter.not_set or
                                            self.router_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.auto_index.get_name_leafdata())
                                        if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.router_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto-index" or name == "router-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "auto-index"):
                                            self.auto_index = value
                                            self.auto_index.value_namespace = name_space
                                            self.auto_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "router-id"):
                                            self.router_id = value
                                            self.router_id.value_namespace = name_space
                                            self.router_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "rd-value"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "rd-value"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "rd-value"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rd.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rd.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rd-value" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rd.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rd"):
                                        self.rd = value
                                        self.rd.value_namespace = name_space
                                        self.rd.value_namespace_prefix = name_space_prefix


                            class VplsId(Entity):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__init__()

                                    self.yang_name = "vpls-id"
                                    self.yang_parent_name = "discovery-information"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "vpls-id"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "vpls-id"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "vpls-id"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vpls-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class ImportRt(Entity):
                                """
                                List of import route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__init__()

                                    self.yang_name = "import-rt"
                                    self.yang_parent_name = "discovery-information"

                                    self.rt = YLeaf(YType.enumeration, "rt")

                                    self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._children_yang_names.add("es-import")

                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rt") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "import-rt"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "import-rt"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "import-rt"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "import-rt"

                                        self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                        self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("high_bytes",
                                                        "low_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.high_bytes.is_set or
                                            self.low_bytes.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.high_bytes.yfilter != YFilter.not_set or
                                            self.low_bytes.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-import" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                        if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "high-bytes" or name == "low-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "high-bytes"):
                                            self.high_bytes = value
                                            self.high_bytes.value_namespace = name_space
                                            self.high_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "low-bytes"):
                                            self.low_bytes = value
                                            self.low_bytes.value_namespace = name_space
                                            self.low_bytes.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rt.is_set or
                                        (self.es_import is not None and self.es_import.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rt.yfilter != YFilter.not_set or
                                        (self.es_import is not None and self.es_import.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "import-rt" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rt.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "es-import"):
                                        if (self.es_import is None):
                                            self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                            self.es_import.parent = self
                                            self._children_name_map["es_import"] = "es-import"
                                        return self.es_import

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rt"):
                                        self.rt = value
                                        self.rt.value_namespace = name_space
                                        self.rt.value_namespace_prefix = name_space_prefix


                            class ExportRt(Entity):
                                """
                                List of export route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__init__()

                                    self.yang_name = "export-rt"
                                    self.yang_parent_name = "discovery-information"

                                    self.rt = YLeaf(YType.enumeration, "rt")

                                    self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._children_yang_names.add("es-import")

                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rt") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "export-rt"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "export-rt"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "export-rt"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "export-rt"

                                        self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                        self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("high_bytes",
                                                        "low_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.high_bytes.is_set or
                                            self.low_bytes.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.high_bytes.yfilter != YFilter.not_set or
                                            self.low_bytes.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-import" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                        if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "high-bytes" or name == "low-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "high-bytes"):
                                            self.high_bytes = value
                                            self.high_bytes.value_namespace = name_space
                                            self.high_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "low-bytes"):
                                            self.low_bytes = value
                                            self.low_bytes.value_namespace = name_space
                                            self.low_bytes.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rt.is_set or
                                        (self.es_import is not None and self.es_import.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rt.yfilter != YFilter.not_set or
                                        (self.es_import is not None and self.es_import.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "export-rt" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rt.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "es-import"):
                                        if (self.es_import is None):
                                            self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                            self.es_import.parent = self
                                            self._children_name_map["es_import"] = "es-import"
                                        return self.es_import

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rt"):
                                        self.rt = value
                                        self.rt.value_namespace = name_space
                                        self.rt.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.export_rt:
                                    if (c.has_data()):
                                        return True
                                for c in self.import_rt:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.ad_method.is_set or
                                    self.ad_signalling_method.is_set or
                                    self.as_number.is_set or
                                    self.export_route_policy.is_set or
                                    self.l2vpn_router_id.is_set or
                                    self.provisioned_ve_id.is_set or
                                    self.service_connected.is_set or
                                    self.ve_id.is_set or
                                    self.ve_range.is_set or
                                    self.vpls_id_conflict.is_set or
                                    self.vpn_added.is_set or
                                    self.vpn_id.is_set or
                                    (self.rd_value is not None and self.rd_value.has_data()) or
                                    (self.vpls_id is not None and self.vpls_id.has_data()))

                            def has_operation(self):
                                for c in self.export_rt:
                                    if (c.has_operation()):
                                        return True
                                for c in self.import_rt:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_signalling_method.yfilter != YFilter.not_set or
                                    self.as_number.yfilter != YFilter.not_set or
                                    self.export_route_policy.yfilter != YFilter.not_set or
                                    self.l2vpn_router_id.yfilter != YFilter.not_set or
                                    self.provisioned_ve_id.yfilter != YFilter.not_set or
                                    self.service_connected.yfilter != YFilter.not_set or
                                    self.ve_id.yfilter != YFilter.not_set or
                                    self.ve_range.yfilter != YFilter.not_set or
                                    self.vpls_id_conflict.yfilter != YFilter.not_set or
                                    self.vpn_added.yfilter != YFilter.not_set or
                                    self.vpn_id.yfilter != YFilter.not_set or
                                    (self.rd_value is not None and self.rd_value.has_operation()) or
                                    (self.vpls_id is not None and self.vpls_id.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "discovery-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                                if (self.as_number.is_set or self.as_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_number.get_name_leafdata())
                                if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                                if (self.l2vpn_router_id.is_set or self.l2vpn_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l2vpn_router_id.get_name_leafdata())
                                if (self.provisioned_ve_id.is_set or self.provisioned_ve_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.provisioned_ve_id.get_name_leafdata())
                                if (self.service_connected.is_set or self.service_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_connected.get_name_leafdata())
                                if (self.ve_id.is_set or self.ve_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_id.get_name_leafdata())
                                if (self.ve_range.is_set or self.ve_range.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_range.get_name_leafdata())
                                if (self.vpls_id_conflict.is_set or self.vpls_id_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_conflict.get_name_leafdata())
                                if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpn_added.get_name_leafdata())
                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "export-rt"):
                                    for c in self.export_rt:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.export_rt.append(c)
                                    return c

                                if (child_yang_name == "import-rt"):
                                    for c in self.import_rt:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.import_rt.append(c)
                                    return c

                                if (child_yang_name == "rd-value"):
                                    if (self.rd_value is None):
                                        self.rd_value = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                        self.rd_value.parent = self
                                        self._children_name_map["rd_value"] = "rd-value"
                                    return self.rd_value

                                if (child_yang_name == "vpls-id"):
                                    if (self.vpls_id is None):
                                        self.vpls_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                        self.vpls_id.parent = self
                                        self._children_name_map["vpls_id"] = "vpls-id"
                                    return self.vpls_id

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "vpls-id" or name == "ad-method" or name == "ad-signalling-method" or name == "as-number" or name == "export-route-policy" or name == "l2vpn-router-id" or name == "provisioned-ve-id" or name == "service-connected" or name == "ve-id" or name == "ve-range" or name == "vpls-id-conflict" or name == "vpn-added" or name == "vpn-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-signalling-method"):
                                    self.ad_signalling_method = value
                                    self.ad_signalling_method.value_namespace = name_space
                                    self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-number"):
                                    self.as_number = value
                                    self.as_number.value_namespace = name_space
                                    self.as_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "export-route-policy"):
                                    self.export_route_policy = value
                                    self.export_route_policy.value_namespace = name_space
                                    self.export_route_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "l2vpn-router-id"):
                                    self.l2vpn_router_id = value
                                    self.l2vpn_router_id.value_namespace = name_space
                                    self.l2vpn_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "provisioned-ve-id"):
                                    self.provisioned_ve_id = value
                                    self.provisioned_ve_id.value_namespace = name_space
                                    self.provisioned_ve_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "service-connected"):
                                    self.service_connected = value
                                    self.service_connected.value_namespace = name_space
                                    self.service_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-id"):
                                    self.ve_id = value
                                    self.ve_id.value_namespace = name_space
                                    self.ve_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-range"):
                                    self.ve_range = value
                                    self.ve_range.value_namespace = name_space
                                    self.ve_range.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpls-id-conflict"):
                                    self.vpls_id_conflict = value
                                    self.vpls_id_conflict.value_namespace = name_space
                                    self.vpls_id_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpn-added"):
                                    self.vpn_added = value
                                    self.vpn_added.value_namespace = name_space
                                    self.vpn_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpn-id"):
                                    self.vpn_id = value
                                    self.vpn_id.value_namespace = name_space
                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                        class P2MpInformation(Entity):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\:  str
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:   :py:class:`L2VpnVfiP2MpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignaling>`
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:   :py:class:`L2VpnVfiP2MpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransport>`
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:   :py:class:`P2MpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportState>`
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__init__()

                                self.yang_name = "p2mp-information"
                                self.yang_parent_name = "bridge-vfi"

                                self.attribute_set_name = YLeaf(YType.str, "attribute-set-name")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.ptree_id = YLeaf(YType.uint32, "ptree-id")

                                self.signaling = YLeaf(YType.enumeration, "signaling")

                                self.transport = YLeaf(YType.enumeration, "transport")

                                self.transport_status = YLeaf(YType.enumeration, "transport-status")

                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("attribute_set_name",
                                                "local_label",
                                                "ptree_id",
                                                "signaling",
                                                "transport",
                                                "transport_status",
                                                "tunnel_interface") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.attribute_set_name.is_set or
                                    self.local_label.is_set or
                                    self.ptree_id.is_set or
                                    self.signaling.is_set or
                                    self.transport.is_set or
                                    self.transport_status.is_set or
                                    self.tunnel_interface.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.attribute_set_name.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.ptree_id.yfilter != YFilter.not_set or
                                    self.signaling.yfilter != YFilter.not_set or
                                    self.transport.yfilter != YFilter.not_set or
                                    self.transport_status.yfilter != YFilter.not_set or
                                    self.tunnel_interface.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.attribute_set_name.is_set or self.attribute_set_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attribute_set_name.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.ptree_id.is_set or self.ptree_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ptree_id.get_name_leafdata())
                                if (self.signaling.is_set or self.signaling.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signaling.get_name_leafdata())
                                if (self.transport.is_set or self.transport.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport.get_name_leafdata())
                                if (self.transport_status.is_set or self.transport_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_status.get_name_leafdata())
                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "attribute-set-name" or name == "local-label" or name == "ptree-id" or name == "signaling" or name == "transport" or name == "transport-status" or name == "tunnel-interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "attribute-set-name"):
                                    self.attribute_set_name = value
                                    self.attribute_set_name.value_namespace = name_space
                                    self.attribute_set_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ptree-id"):
                                    self.ptree_id = value
                                    self.ptree_id.value_namespace = name_space
                                    self.ptree_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "signaling"):
                                    self.signaling = value
                                    self.signaling.value_namespace = name_space
                                    self.signaling.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport"):
                                    self.transport = value
                                    self.transport.value_namespace = name_space
                                    self.transport.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-status"):
                                    self.transport_status = value
                                    self.transport_status.value_namespace = name_space
                                    self.transport_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-interface"):
                                    self.tunnel_interface = value
                                    self.tunnel_interface.value_namespace = name_space
                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.p2mp_information:
                                if (c.has_data()):
                                    return True
                            return (
                                self.access.is_set or
                                self.number_pseudowires.is_set or
                                self.shutdown.is_set or
                                self.vfi_name.is_set or
                                self.vfi_state.is_set or
                                (self.discovery_information is not None and self.discovery_information.has_data()))

                        def has_operation(self):
                            for c in self.p2mp_information:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.access.yfilter != YFilter.not_set or
                                self.number_pseudowires.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.vfi_name.yfilter != YFilter.not_set or
                                self.vfi_state.yfilter != YFilter.not_set or
                                (self.discovery_information is not None and self.discovery_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-vfi" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.access.is_set or self.access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.access.get_name_leafdata())
                            if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.vfi_name.is_set or self.vfi_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vfi_name.get_name_leafdata())
                            if (self.vfi_state.is_set or self.vfi_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vfi_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "discovery-information"):
                                if (self.discovery_information is None):
                                    self.discovery_information = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                                    self.discovery_information.parent = self
                                    self._children_name_map["discovery_information"] = "discovery-information"
                                return self.discovery_information

                            if (child_yang_name == "p2mp-information"):
                                for c in self.p2mp_information:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.p2mp_information.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "discovery-information" or name == "p2mp-information" or name == "access" or name == "number-pseudowires" or name == "shutdown" or name == "vfi-name" or name == "vfi-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "access"):
                                self.access = value
                                self.access.value_namespace = name_space
                                self.access.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pseudowires"):
                                self.number_pseudowires = value
                                self.number_pseudowires.value_namespace = name_space
                                self.number_pseudowires.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "vfi-name"):
                                self.vfi_name = value
                                self.vfi_name.value_namespace = name_space
                                self.vfi_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vfi-state"):
                                self.vfi_state = value
                                self.vfi_state.value_namespace = name_space
                                self.vfi_state.value_namespace_prefix = name_space_prefix


                    class BridgeAccessVfi(Entity):
                        """
                        Access Virtual Forwarding Interfaces
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\:  bool
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\:  str
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:   :py:class:`L2VpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiState>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__init__()

                            self.yang_name = "bridge-access-vfi"
                            self.yang_parent_name = "bridge-domain-info"

                            self.access = YLeaf(YType.boolean, "access")

                            self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.vfi_name = YLeaf(YType.str, "vfi-name")

                            self.vfi_state = YLeaf(YType.enumeration, "vfi-state")

                            self.discovery_information = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self._children_name_map["discovery_information"] = "discovery-information"
                            self._children_yang_names.add("discovery-information")

                            self.p2mp_information = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("access",
                                            "number_pseudowires",
                                            "shutdown",
                                            "vfi_name",
                                            "vfi_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__setattr__(name, value)


                        class DiscoveryInformation(Entity):
                            """
                            Auto Discovery information
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\:  str
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\:  bool
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\:  bool
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\:  bool
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__init__()

                                self.yang_name = "discovery-information"
                                self.yang_parent_name = "bridge-access-vfi"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                                self.as_number = YLeaf(YType.uint32, "as-number")

                                self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                                self.l2vpn_router_id = YLeaf(YType.str, "l2vpn-router-id")

                                self.provisioned_ve_id = YLeaf(YType.uint32, "provisioned-ve-id")

                                self.service_connected = YLeaf(YType.boolean, "service-connected")

                                self.ve_id = YLeaf(YType.uint32, "ve-id")

                                self.ve_range = YLeaf(YType.uint16, "ve-range")

                                self.vpls_id_conflict = YLeaf(YType.boolean, "vpls-id-conflict")

                                self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                self.rd_value = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self._children_name_map["rd_value"] = "rd-value"
                                self._children_yang_names.add("rd-value")

                                self.vpls_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self._children_name_map["vpls_id"] = "vpls-id"
                                self._children_yang_names.add("vpls-id")

                                self.export_rt = YList(self)
                                self.import_rt = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_signalling_method",
                                                "as_number",
                                                "export_route_policy",
                                                "l2vpn_router_id",
                                                "provisioned_ve_id",
                                                "service_connected",
                                                "ve_id",
                                                "ve_range",
                                                "vpls_id_conflict",
                                                "vpn_added",
                                                "vpn_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__setattr__(name, value)


                            class RdValue(Entity):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__init__()

                                    self.yang_name = "rd-value"
                                    self.yang_parent_name = "discovery-information"

                                    self.rd = YLeaf(YType.enumeration, "rd")

                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rd") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "rd-value"

                                        self.auto_index = YLeaf(YType.uint16, "auto-index")

                                        self.router_id = YLeaf(YType.str, "router-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("auto_index",
                                                        "router_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.auto_index.is_set or
                                            self.router_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.auto_index.yfilter != YFilter.not_set or
                                            self.router_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.auto_index.get_name_leafdata())
                                        if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.router_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto-index" or name == "router-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "auto-index"):
                                            self.auto_index = value
                                            self.auto_index.value_namespace = name_space
                                            self.auto_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "router-id"):
                                            self.router_id = value
                                            self.router_id.value_namespace = name_space
                                            self.router_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "rd-value"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "rd-value"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "rd-value"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rd.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rd.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rd-value" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rd.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rd"):
                                        self.rd = value
                                        self.rd.value_namespace = name_space
                                        self.rd.value_namespace_prefix = name_space_prefix


                            class VplsId(Entity):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__init__()

                                    self.yang_name = "vpls-id"
                                    self.yang_parent_name = "discovery-information"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "vpls-id"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "vpls-id"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "vpls-id"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vpls-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class ImportRt(Entity):
                                """
                                List of import route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__init__()

                                    self.yang_name = "import-rt"
                                    self.yang_parent_name = "discovery-information"

                                    self.rt = YLeaf(YType.enumeration, "rt")

                                    self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._children_yang_names.add("es-import")

                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rt") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "import-rt"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "import-rt"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "import-rt"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "import-rt"

                                        self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                        self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("high_bytes",
                                                        "low_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.high_bytes.is_set or
                                            self.low_bytes.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.high_bytes.yfilter != YFilter.not_set or
                                            self.low_bytes.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-import" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                        if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "high-bytes" or name == "low-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "high-bytes"):
                                            self.high_bytes = value
                                            self.high_bytes.value_namespace = name_space
                                            self.high_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "low-bytes"):
                                            self.low_bytes = value
                                            self.low_bytes.value_namespace = name_space
                                            self.low_bytes.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rt.is_set or
                                        (self.es_import is not None and self.es_import.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rt.yfilter != YFilter.not_set or
                                        (self.es_import is not None and self.es_import.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "import-rt" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rt.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "es-import"):
                                        if (self.es_import is None):
                                            self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                            self.es_import.parent = self
                                            self._children_name_map["es_import"] = "es-import"
                                        return self.es_import

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rt"):
                                        self.rt = value
                                        self.rt.value_namespace = name_space
                                        self.rt.value_namespace_prefix = name_space_prefix


                            class ExportRt(Entity):
                                """
                                List of export route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__init__()

                                    self.yang_name = "export-rt"
                                    self.yang_parent_name = "discovery-information"

                                    self.rt = YLeaf(YType.enumeration, "rt")

                                    self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._children_yang_names.add("es-import")

                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rt") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "export-rt"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "export-rt"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "export-rt"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "export-rt"

                                        self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                        self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("high_bytes",
                                                        "low_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.high_bytes.is_set or
                                            self.low_bytes.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.high_bytes.yfilter != YFilter.not_set or
                                            self.low_bytes.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-import" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                        if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "high-bytes" or name == "low-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "high-bytes"):
                                            self.high_bytes = value
                                            self.high_bytes.value_namespace = name_space
                                            self.high_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "low-bytes"):
                                            self.low_bytes = value
                                            self.low_bytes.value_namespace = name_space
                                            self.low_bytes.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rt.is_set or
                                        (self.es_import is not None and self.es_import.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rt.yfilter != YFilter.not_set or
                                        (self.es_import is not None and self.es_import.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "export-rt" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rt.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "es-import"):
                                        if (self.es_import is None):
                                            self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                            self.es_import.parent = self
                                            self._children_name_map["es_import"] = "es-import"
                                        return self.es_import

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rt"):
                                        self.rt = value
                                        self.rt.value_namespace = name_space
                                        self.rt.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.export_rt:
                                    if (c.has_data()):
                                        return True
                                for c in self.import_rt:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.ad_method.is_set or
                                    self.ad_signalling_method.is_set or
                                    self.as_number.is_set or
                                    self.export_route_policy.is_set or
                                    self.l2vpn_router_id.is_set or
                                    self.provisioned_ve_id.is_set or
                                    self.service_connected.is_set or
                                    self.ve_id.is_set or
                                    self.ve_range.is_set or
                                    self.vpls_id_conflict.is_set or
                                    self.vpn_added.is_set or
                                    self.vpn_id.is_set or
                                    (self.rd_value is not None and self.rd_value.has_data()) or
                                    (self.vpls_id is not None and self.vpls_id.has_data()))

                            def has_operation(self):
                                for c in self.export_rt:
                                    if (c.has_operation()):
                                        return True
                                for c in self.import_rt:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_signalling_method.yfilter != YFilter.not_set or
                                    self.as_number.yfilter != YFilter.not_set or
                                    self.export_route_policy.yfilter != YFilter.not_set or
                                    self.l2vpn_router_id.yfilter != YFilter.not_set or
                                    self.provisioned_ve_id.yfilter != YFilter.not_set or
                                    self.service_connected.yfilter != YFilter.not_set or
                                    self.ve_id.yfilter != YFilter.not_set or
                                    self.ve_range.yfilter != YFilter.not_set or
                                    self.vpls_id_conflict.yfilter != YFilter.not_set or
                                    self.vpn_added.yfilter != YFilter.not_set or
                                    self.vpn_id.yfilter != YFilter.not_set or
                                    (self.rd_value is not None and self.rd_value.has_operation()) or
                                    (self.vpls_id is not None and self.vpls_id.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "discovery-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                                if (self.as_number.is_set or self.as_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_number.get_name_leafdata())
                                if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                                if (self.l2vpn_router_id.is_set or self.l2vpn_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l2vpn_router_id.get_name_leafdata())
                                if (self.provisioned_ve_id.is_set or self.provisioned_ve_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.provisioned_ve_id.get_name_leafdata())
                                if (self.service_connected.is_set or self.service_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_connected.get_name_leafdata())
                                if (self.ve_id.is_set or self.ve_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_id.get_name_leafdata())
                                if (self.ve_range.is_set or self.ve_range.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_range.get_name_leafdata())
                                if (self.vpls_id_conflict.is_set or self.vpls_id_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_conflict.get_name_leafdata())
                                if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpn_added.get_name_leafdata())
                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "export-rt"):
                                    for c in self.export_rt:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.export_rt.append(c)
                                    return c

                                if (child_yang_name == "import-rt"):
                                    for c in self.import_rt:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.import_rt.append(c)
                                    return c

                                if (child_yang_name == "rd-value"):
                                    if (self.rd_value is None):
                                        self.rd_value = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                        self.rd_value.parent = self
                                        self._children_name_map["rd_value"] = "rd-value"
                                    return self.rd_value

                                if (child_yang_name == "vpls-id"):
                                    if (self.vpls_id is None):
                                        self.vpls_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                        self.vpls_id.parent = self
                                        self._children_name_map["vpls_id"] = "vpls-id"
                                    return self.vpls_id

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "vpls-id" or name == "ad-method" or name == "ad-signalling-method" or name == "as-number" or name == "export-route-policy" or name == "l2vpn-router-id" or name == "provisioned-ve-id" or name == "service-connected" or name == "ve-id" or name == "ve-range" or name == "vpls-id-conflict" or name == "vpn-added" or name == "vpn-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-signalling-method"):
                                    self.ad_signalling_method = value
                                    self.ad_signalling_method.value_namespace = name_space
                                    self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-number"):
                                    self.as_number = value
                                    self.as_number.value_namespace = name_space
                                    self.as_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "export-route-policy"):
                                    self.export_route_policy = value
                                    self.export_route_policy.value_namespace = name_space
                                    self.export_route_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "l2vpn-router-id"):
                                    self.l2vpn_router_id = value
                                    self.l2vpn_router_id.value_namespace = name_space
                                    self.l2vpn_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "provisioned-ve-id"):
                                    self.provisioned_ve_id = value
                                    self.provisioned_ve_id.value_namespace = name_space
                                    self.provisioned_ve_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "service-connected"):
                                    self.service_connected = value
                                    self.service_connected.value_namespace = name_space
                                    self.service_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-id"):
                                    self.ve_id = value
                                    self.ve_id.value_namespace = name_space
                                    self.ve_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-range"):
                                    self.ve_range = value
                                    self.ve_range.value_namespace = name_space
                                    self.ve_range.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpls-id-conflict"):
                                    self.vpls_id_conflict = value
                                    self.vpls_id_conflict.value_namespace = name_space
                                    self.vpls_id_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpn-added"):
                                    self.vpn_added = value
                                    self.vpn_added.value_namespace = name_space
                                    self.vpn_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpn-id"):
                                    self.vpn_id = value
                                    self.vpn_id.value_namespace = name_space
                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                        class P2MpInformation(Entity):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\:  str
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:   :py:class:`L2VpnVfiP2MpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignaling>`
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:   :py:class:`L2VpnVfiP2MpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransport>`
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:   :py:class:`P2MpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportState>`
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__init__()

                                self.yang_name = "p2mp-information"
                                self.yang_parent_name = "bridge-access-vfi"

                                self.attribute_set_name = YLeaf(YType.str, "attribute-set-name")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.ptree_id = YLeaf(YType.uint32, "ptree-id")

                                self.signaling = YLeaf(YType.enumeration, "signaling")

                                self.transport = YLeaf(YType.enumeration, "transport")

                                self.transport_status = YLeaf(YType.enumeration, "transport-status")

                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("attribute_set_name",
                                                "local_label",
                                                "ptree_id",
                                                "signaling",
                                                "transport",
                                                "transport_status",
                                                "tunnel_interface") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.attribute_set_name.is_set or
                                    self.local_label.is_set or
                                    self.ptree_id.is_set or
                                    self.signaling.is_set or
                                    self.transport.is_set or
                                    self.transport_status.is_set or
                                    self.tunnel_interface.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.attribute_set_name.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.ptree_id.yfilter != YFilter.not_set or
                                    self.signaling.yfilter != YFilter.not_set or
                                    self.transport.yfilter != YFilter.not_set or
                                    self.transport_status.yfilter != YFilter.not_set or
                                    self.tunnel_interface.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.attribute_set_name.is_set or self.attribute_set_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attribute_set_name.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.ptree_id.is_set or self.ptree_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ptree_id.get_name_leafdata())
                                if (self.signaling.is_set or self.signaling.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signaling.get_name_leafdata())
                                if (self.transport.is_set or self.transport.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport.get_name_leafdata())
                                if (self.transport_status.is_set or self.transport_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_status.get_name_leafdata())
                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "attribute-set-name" or name == "local-label" or name == "ptree-id" or name == "signaling" or name == "transport" or name == "transport-status" or name == "tunnel-interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "attribute-set-name"):
                                    self.attribute_set_name = value
                                    self.attribute_set_name.value_namespace = name_space
                                    self.attribute_set_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ptree-id"):
                                    self.ptree_id = value
                                    self.ptree_id.value_namespace = name_space
                                    self.ptree_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "signaling"):
                                    self.signaling = value
                                    self.signaling.value_namespace = name_space
                                    self.signaling.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport"):
                                    self.transport = value
                                    self.transport.value_namespace = name_space
                                    self.transport.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-status"):
                                    self.transport_status = value
                                    self.transport_status.value_namespace = name_space
                                    self.transport_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-interface"):
                                    self.tunnel_interface = value
                                    self.tunnel_interface.value_namespace = name_space
                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.p2mp_information:
                                if (c.has_data()):
                                    return True
                            return (
                                self.access.is_set or
                                self.number_pseudowires.is_set or
                                self.shutdown.is_set or
                                self.vfi_name.is_set or
                                self.vfi_state.is_set or
                                (self.discovery_information is not None and self.discovery_information.has_data()))

                        def has_operation(self):
                            for c in self.p2mp_information:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.access.yfilter != YFilter.not_set or
                                self.number_pseudowires.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.vfi_name.yfilter != YFilter.not_set or
                                self.vfi_state.yfilter != YFilter.not_set or
                                (self.discovery_information is not None and self.discovery_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-access-vfi" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.access.is_set or self.access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.access.get_name_leafdata())
                            if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.vfi_name.is_set or self.vfi_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vfi_name.get_name_leafdata())
                            if (self.vfi_state.is_set or self.vfi_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vfi_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "discovery-information"):
                                if (self.discovery_information is None):
                                    self.discovery_information = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                                    self.discovery_information.parent = self
                                    self._children_name_map["discovery_information"] = "discovery-information"
                                return self.discovery_information

                            if (child_yang_name == "p2mp-information"):
                                for c in self.p2mp_information:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.p2mp_information.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "discovery-information" or name == "p2mp-information" or name == "access" or name == "number-pseudowires" or name == "shutdown" or name == "vfi-name" or name == "vfi-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "access"):
                                self.access = value
                                self.access.value_namespace = name_space
                                self.access.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pseudowires"):
                                self.number_pseudowires = value
                                self.number_pseudowires.value_namespace = name_space
                                self.number_pseudowires.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "vfi-name"):
                                self.vfi_name = value
                                self.vfi_name.value_namespace = name_space
                                self.vfi_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vfi-state"):
                                self.vfi_state = value
                                self.vfi_state.value_namespace = name_space
                                self.vfi_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bridge_access_vfi:
                            if (c.has_data()):
                                return True
                        for c in self.bridge_vfi:
                            if (c.has_data()):
                                return True
                        for c in self.mac_filter:
                            if (c.has_data()):
                                return True
                        return (
                            self.acpwup.is_set or
                            self.as_.is_set or
                            self.bridge_coupled_state.is_set or
                            self.bridge_description.is_set or
                            self.bridge_domain_id.is_set or
                            self.bridge_internal_msti.is_set or
                            self.bridge_msti.is_set or
                            self.bridge_mtu.is_set or
                            self.bridge_name.is_set or
                            self.bridge_shg_id.is_set or
                            self.bridge_state.is_set or
                            self.bridge_type.is_set or
                            self.configured.is_set or
                            self.disposition_bytecount.is_set or
                            self.disposition_pkt_count.is_set or
                            self.evi.is_set or
                            self.flodd_group_id_down.is_set or
                            self.group_name.is_set or
                            self.imposition_byte_count.is_set or
                            self.imposition_pkt_count.is_set or
                            self.is_bridge_partially_programmed.is_set or
                            self.is_rd_configured.is_set or
                            self.last_time_status_changed.is_set or
                            self.load_balance.is_set or
                            self.mac_limit_down.is_set or
                            self.mac_withdraw.is_set or
                            self.mac_withdraw_access.is_set or
                            self.mac_withdraw_option.is_set or
                            self.mac_withdraw_relay.is_set or
                            self.num_vn_is.is_set or
                            self.num_vn_is_up.is_set or
                            self.number_a_cs.is_set or
                            self.number_a_cs_up.is_set or
                            self.number_access_vf_is.is_set or
                            self.number_p_ws_up.is_set or
                            self.number_pb_bs.is_set or
                            self.number_pb_bs_up.is_set or
                            self.number_pseudowires.is_set or
                            self.number_vf_is.is_set or
                            self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                            self.p2mp_enabled.is_set or
                            self.partially_programmed_a_cs.is_set or
                            self.partially_programmed_pseudowires.is_set or
                            self.shutdown.is_set or
                            self.standby_pseudowires.is_set or
                            self.time_created.is_set or
                            self.time_elapsed_creation.is_set or
                            self.time_elapsed_status_changed.is_set or
                            self.vine_fsm_state.is_set or
                            (self.evpn_parameters is not None and self.evpn_parameters.has_data()) or
                            (self.pbb_parameters is not None and self.pbb_parameters.has_data()) or
                            (self.rd is not None and self.rd.has_data()) or
                            (self.security_parameters is not None and self.security_parameters.has_data()) or
                            (self.vni_parameters is not None and self.vni_parameters.has_data()))

                    def has_operation(self):
                        for c in self.bridge_access_vfi:
                            if (c.has_operation()):
                                return True
                        for c in self.bridge_vfi:
                            if (c.has_operation()):
                                return True
                        for c in self.mac_filter:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.acpwup.yfilter != YFilter.not_set or
                            self.as_.yfilter != YFilter.not_set or
                            self.bridge_coupled_state.yfilter != YFilter.not_set or
                            self.bridge_description.yfilter != YFilter.not_set or
                            self.bridge_domain_id.yfilter != YFilter.not_set or
                            self.bridge_internal_msti.yfilter != YFilter.not_set or
                            self.bridge_msti.yfilter != YFilter.not_set or
                            self.bridge_mtu.yfilter != YFilter.not_set or
                            self.bridge_name.yfilter != YFilter.not_set or
                            self.bridge_shg_id.yfilter != YFilter.not_set or
                            self.bridge_state.yfilter != YFilter.not_set or
                            self.bridge_type.yfilter != YFilter.not_set or
                            self.configured.yfilter != YFilter.not_set or
                            self.disposition_bytecount.yfilter != YFilter.not_set or
                            self.disposition_pkt_count.yfilter != YFilter.not_set or
                            self.evi.yfilter != YFilter.not_set or
                            self.flodd_group_id_down.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.imposition_byte_count.yfilter != YFilter.not_set or
                            self.imposition_pkt_count.yfilter != YFilter.not_set or
                            self.is_bridge_partially_programmed.yfilter != YFilter.not_set or
                            self.is_rd_configured.yfilter != YFilter.not_set or
                            self.last_time_status_changed.yfilter != YFilter.not_set or
                            self.load_balance.yfilter != YFilter.not_set or
                            self.mac_limit_down.yfilter != YFilter.not_set or
                            self.mac_withdraw.yfilter != YFilter.not_set or
                            self.mac_withdraw_access.yfilter != YFilter.not_set or
                            self.mac_withdraw_option.yfilter != YFilter.not_set or
                            self.mac_withdraw_relay.yfilter != YFilter.not_set or
                            self.num_vn_is.yfilter != YFilter.not_set or
                            self.num_vn_is_up.yfilter != YFilter.not_set or
                            self.number_a_cs.yfilter != YFilter.not_set or
                            self.number_a_cs_up.yfilter != YFilter.not_set or
                            self.number_access_vf_is.yfilter != YFilter.not_set or
                            self.number_p_ws_up.yfilter != YFilter.not_set or
                            self.number_pb_bs.yfilter != YFilter.not_set or
                            self.number_pb_bs_up.yfilter != YFilter.not_set or
                            self.number_pseudowires.yfilter != YFilter.not_set or
                            self.number_vf_is.yfilter != YFilter.not_set or
                            self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                            self.p2mp_enabled.yfilter != YFilter.not_set or
                            self.partially_programmed_a_cs.yfilter != YFilter.not_set or
                            self.partially_programmed_pseudowires.yfilter != YFilter.not_set or
                            self.shutdown.yfilter != YFilter.not_set or
                            self.standby_pseudowires.yfilter != YFilter.not_set or
                            self.time_created.yfilter != YFilter.not_set or
                            self.time_elapsed_creation.yfilter != YFilter.not_set or
                            self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                            self.vine_fsm_state.yfilter != YFilter.not_set or
                            (self.evpn_parameters is not None and self.evpn_parameters.has_operation()) or
                            (self.pbb_parameters is not None and self.pbb_parameters.has_operation()) or
                            (self.rd is not None and self.rd.has_operation()) or
                            (self.security_parameters is not None and self.security_parameters.has_operation()) or
                            (self.vni_parameters is not None and self.vni_parameters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-domain-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.acpwup.is_set or self.acpwup.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.acpwup.get_name_leafdata())
                        if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.as_.get_name_leafdata())
                        if (self.bridge_coupled_state.is_set or self.bridge_coupled_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_coupled_state.get_name_leafdata())
                        if (self.bridge_description.is_set or self.bridge_description.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_description.get_name_leafdata())
                        if (self.bridge_domain_id.is_set or self.bridge_domain_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_id.get_name_leafdata())
                        if (self.bridge_internal_msti.is_set or self.bridge_internal_msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_internal_msti.get_name_leafdata())
                        if (self.bridge_msti.is_set or self.bridge_msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_msti.get_name_leafdata())
                        if (self.bridge_mtu.is_set or self.bridge_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_mtu.get_name_leafdata())
                        if (self.bridge_name.is_set or self.bridge_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_name.get_name_leafdata())
                        if (self.bridge_shg_id.is_set or self.bridge_shg_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_shg_id.get_name_leafdata())
                        if (self.bridge_state.is_set or self.bridge_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_state.get_name_leafdata())
                        if (self.bridge_type.is_set or self.bridge_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_type.get_name_leafdata())
                        if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured.get_name_leafdata())
                        if (self.disposition_bytecount.is_set or self.disposition_bytecount.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disposition_bytecount.get_name_leafdata())
                        if (self.disposition_pkt_count.is_set or self.disposition_pkt_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disposition_pkt_count.get_name_leafdata())
                        if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evi.get_name_leafdata())
                        if (self.flodd_group_id_down.is_set or self.flodd_group_id_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flodd_group_id_down.get_name_leafdata())
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.imposition_byte_count.is_set or self.imposition_byte_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.imposition_byte_count.get_name_leafdata())
                        if (self.imposition_pkt_count.is_set or self.imposition_pkt_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.imposition_pkt_count.get_name_leafdata())
                        if (self.is_bridge_partially_programmed.is_set or self.is_bridge_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bridge_partially_programmed.get_name_leafdata())
                        if (self.is_rd_configured.is_set or self.is_rd_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rd_configured.get_name_leafdata())
                        if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                        if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance.get_name_leafdata())
                        if (self.mac_limit_down.is_set or self.mac_limit_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_down.get_name_leafdata())
                        if (self.mac_withdraw.is_set or self.mac_withdraw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_withdraw.get_name_leafdata())
                        if (self.mac_withdraw_access.is_set or self.mac_withdraw_access.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_withdraw_access.get_name_leafdata())
                        if (self.mac_withdraw_option.is_set or self.mac_withdraw_option.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_withdraw_option.get_name_leafdata())
                        if (self.mac_withdraw_relay.is_set or self.mac_withdraw_relay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_withdraw_relay.get_name_leafdata())
                        if (self.num_vn_is.is_set or self.num_vn_is.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_vn_is.get_name_leafdata())
                        if (self.num_vn_is_up.is_set or self.num_vn_is_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_vn_is_up.get_name_leafdata())
                        if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                        if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                        if (self.number_access_vf_is.is_set or self.number_access_vf_is.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_access_vf_is.get_name_leafdata())
                        if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                        if (self.number_pb_bs.is_set or self.number_pb_bs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_pb_bs.get_name_leafdata())
                        if (self.number_pb_bs_up.is_set or self.number_pb_bs_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_pb_bs_up.get_name_leafdata())
                        if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                        if (self.number_vf_is.is_set or self.number_vf_is.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_vf_is.get_name_leafdata())
                        if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                        if (self.p2mp_enabled.is_set or self.p2mp_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.p2mp_enabled.get_name_leafdata())
                        if (self.partially_programmed_a_cs.is_set or self.partially_programmed_a_cs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.partially_programmed_a_cs.get_name_leafdata())
                        if (self.partially_programmed_pseudowires.is_set or self.partially_programmed_pseudowires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.partially_programmed_pseudowires.get_name_leafdata())
                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                        if (self.standby_pseudowires.is_set or self.standby_pseudowires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.standby_pseudowires.get_name_leafdata())
                        if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_created.get_name_leafdata())
                        if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                        if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                        if (self.vine_fsm_state.is_set or self.vine_fsm_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vine_fsm_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-access-vfi"):
                            for c in self.bridge_access_vfi:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bridge_access_vfi.append(c)
                            return c

                        if (child_yang_name == "bridge-vfi"):
                            for c in self.bridge_vfi:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bridge_vfi.append(c)
                            return c

                        if (child_yang_name == "evpn-parameters"):
                            if (self.evpn_parameters is None):
                                self.evpn_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                                self.evpn_parameters.parent = self
                                self._children_name_map["evpn_parameters"] = "evpn-parameters"
                            return self.evpn_parameters

                        if (child_yang_name == "mac-filter"):
                            for c in self.mac_filter:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mac_filter.append(c)
                            return c

                        if (child_yang_name == "pbb-parameters"):
                            if (self.pbb_parameters is None):
                                self.pbb_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                                self.pbb_parameters.parent = self
                                self._children_name_map["pbb_parameters"] = "pbb-parameters"
                            return self.pbb_parameters

                        if (child_yang_name == "rd"):
                            if (self.rd is None):
                                self.rd = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                                self.rd.parent = self
                                self._children_name_map["rd"] = "rd"
                            return self.rd

                        if (child_yang_name == "security-parameters"):
                            if (self.security_parameters is None):
                                self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                            return self.security_parameters

                        if (child_yang_name == "vni-parameters"):
                            if (self.vni_parameters is None):
                                self.vni_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                                self.vni_parameters.parent = self
                                self._children_name_map["vni_parameters"] = "vni-parameters"
                            return self.vni_parameters

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-access-vfi" or name == "bridge-vfi" or name == "evpn-parameters" or name == "mac-filter" or name == "pbb-parameters" or name == "rd" or name == "security-parameters" or name == "vni-parameters" or name == "acpwup" or name == "as" or name == "bridge-coupled-state" or name == "bridge-description" or name == "bridge-domain-id" or name == "bridge-internal-msti" or name == "bridge-msti" or name == "bridge-mtu" or name == "bridge-name" or name == "bridge-shg-id" or name == "bridge-state" or name == "bridge-type" or name == "configured" or name == "disposition-bytecount" or name == "disposition-pkt-count" or name == "evi" or name == "flodd-group-id-down" or name == "group-name" or name == "imposition-byte-count" or name == "imposition-pkt-count" or name == "is-bridge-partially-programmed" or name == "is-rd-configured" or name == "last-time-status-changed" or name == "load-balance" or name == "mac-limit-down" or name == "mac-withdraw" or name == "mac-withdraw-access" or name == "mac-withdraw-option" or name == "mac-withdraw-relay" or name == "num-vn-is" or name == "num-vn-is-up" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-access-vf-is" or name == "number-p-ws-up" or name == "number-pb-bs" or name == "number-pb-bs-up" or name == "number-pseudowires" or name == "number-vf-is" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "p2mp-enabled" or name == "partially-programmed-a-cs" or name == "partially-programmed-pseudowires" or name == "shutdown" or name == "standby-pseudowires" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "vine-fsm-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "acpwup"):
                            self.acpwup = value
                            self.acpwup.value_namespace = name_space
                            self.acpwup.value_namespace_prefix = name_space_prefix
                        if(value_path == "as"):
                            self.as_ = value
                            self.as_.value_namespace = name_space
                            self.as_.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-coupled-state"):
                            self.bridge_coupled_state = value
                            self.bridge_coupled_state.value_namespace = name_space
                            self.bridge_coupled_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-description"):
                            self.bridge_description = value
                            self.bridge_description.value_namespace = name_space
                            self.bridge_description.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-id"):
                            self.bridge_domain_id = value
                            self.bridge_domain_id.value_namespace = name_space
                            self.bridge_domain_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-internal-msti"):
                            self.bridge_internal_msti = value
                            self.bridge_internal_msti.value_namespace = name_space
                            self.bridge_internal_msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-msti"):
                            self.bridge_msti = value
                            self.bridge_msti.value_namespace = name_space
                            self.bridge_msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-mtu"):
                            self.bridge_mtu = value
                            self.bridge_mtu.value_namespace = name_space
                            self.bridge_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-name"):
                            self.bridge_name = value
                            self.bridge_name.value_namespace = name_space
                            self.bridge_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-shg-id"):
                            self.bridge_shg_id = value
                            self.bridge_shg_id.value_namespace = name_space
                            self.bridge_shg_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-state"):
                            self.bridge_state = value
                            self.bridge_state.value_namespace = name_space
                            self.bridge_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-type"):
                            self.bridge_type = value
                            self.bridge_type.value_namespace = name_space
                            self.bridge_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured"):
                            self.configured = value
                            self.configured.value_namespace = name_space
                            self.configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "disposition-bytecount"):
                            self.disposition_bytecount = value
                            self.disposition_bytecount.value_namespace = name_space
                            self.disposition_bytecount.value_namespace_prefix = name_space_prefix
                        if(value_path == "disposition-pkt-count"):
                            self.disposition_pkt_count = value
                            self.disposition_pkt_count.value_namespace = name_space
                            self.disposition_pkt_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "evi"):
                            self.evi = value
                            self.evi.value_namespace = name_space
                            self.evi.value_namespace_prefix = name_space_prefix
                        if(value_path == "flodd-group-id-down"):
                            self.flodd_group_id_down = value
                            self.flodd_group_id_down.value_namespace = name_space
                            self.flodd_group_id_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "imposition-byte-count"):
                            self.imposition_byte_count = value
                            self.imposition_byte_count.value_namespace = name_space
                            self.imposition_byte_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "imposition-pkt-count"):
                            self.imposition_pkt_count = value
                            self.imposition_pkt_count.value_namespace = name_space
                            self.imposition_pkt_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bridge-partially-programmed"):
                            self.is_bridge_partially_programmed = value
                            self.is_bridge_partially_programmed.value_namespace = name_space
                            self.is_bridge_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rd-configured"):
                            self.is_rd_configured = value
                            self.is_rd_configured.value_namespace = name_space
                            self.is_rd_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-changed"):
                            self.last_time_status_changed = value
                            self.last_time_status_changed.value_namespace = name_space
                            self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance"):
                            self.load_balance = value
                            self.load_balance.value_namespace = name_space
                            self.load_balance.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-down"):
                            self.mac_limit_down = value
                            self.mac_limit_down.value_namespace = name_space
                            self.mac_limit_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-withdraw"):
                            self.mac_withdraw = value
                            self.mac_withdraw.value_namespace = name_space
                            self.mac_withdraw.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-withdraw-access"):
                            self.mac_withdraw_access = value
                            self.mac_withdraw_access.value_namespace = name_space
                            self.mac_withdraw_access.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-withdraw-option"):
                            self.mac_withdraw_option = value
                            self.mac_withdraw_option.value_namespace = name_space
                            self.mac_withdraw_option.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-withdraw-relay"):
                            self.mac_withdraw_relay = value
                            self.mac_withdraw_relay.value_namespace = name_space
                            self.mac_withdraw_relay.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-vn-is"):
                            self.num_vn_is = value
                            self.num_vn_is.value_namespace = name_space
                            self.num_vn_is.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-vn-is-up"):
                            self.num_vn_is_up = value
                            self.num_vn_is_up.value_namespace = name_space
                            self.num_vn_is_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-a-cs"):
                            self.number_a_cs = value
                            self.number_a_cs.value_namespace = name_space
                            self.number_a_cs.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-a-cs-up"):
                            self.number_a_cs_up = value
                            self.number_a_cs_up.value_namespace = name_space
                            self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-access-vf-is"):
                            self.number_access_vf_is = value
                            self.number_access_vf_is.value_namespace = name_space
                            self.number_access_vf_is.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-p-ws-up"):
                            self.number_p_ws_up = value
                            self.number_p_ws_up.value_namespace = name_space
                            self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-pb-bs"):
                            self.number_pb_bs = value
                            self.number_pb_bs.value_namespace = name_space
                            self.number_pb_bs.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-pb-bs-up"):
                            self.number_pb_bs_up = value
                            self.number_pb_bs_up.value_namespace = name_space
                            self.number_pb_bs_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-pseudowires"):
                            self.number_pseudowires = value
                            self.number_pseudowires.value_namespace = name_space
                            self.number_pseudowires.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-vf-is"):
                            self.number_vf_is = value
                            self.number_vf_is.value_namespace = name_space
                            self.number_vf_is.value_namespace_prefix = name_space_prefix
                        if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                            self.nv_satellite_offload_ipv4_multicast_disabled = value
                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "p2mp-enabled"):
                            self.p2mp_enabled = value
                            self.p2mp_enabled.value_namespace = name_space
                            self.p2mp_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "partially-programmed-a-cs"):
                            self.partially_programmed_a_cs = value
                            self.partially_programmed_a_cs.value_namespace = name_space
                            self.partially_programmed_a_cs.value_namespace_prefix = name_space_prefix
                        if(value_path == "partially-programmed-pseudowires"):
                            self.partially_programmed_pseudowires = value
                            self.partially_programmed_pseudowires.value_namespace = name_space
                            self.partially_programmed_pseudowires.value_namespace_prefix = name_space_prefix
                        if(value_path == "shutdown"):
                            self.shutdown = value
                            self.shutdown.value_namespace = name_space
                            self.shutdown.value_namespace_prefix = name_space_prefix
                        if(value_path == "standby-pseudowires"):
                            self.standby_pseudowires = value
                            self.standby_pseudowires.value_namespace = name_space
                            self.standby_pseudowires.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-created"):
                            self.time_created = value
                            self.time_created.value_namespace = name_space
                            self.time_created.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-creation"):
                            self.time_elapsed_creation = value
                            self.time_elapsed_creation.value_namespace = name_space
                            self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-changed"):
                            self.time_elapsed_status_changed = value
                            self.time_elapsed_status_changed.value_namespace = name_space
                            self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "vine-fsm-state"):
                            self.vine_fsm_state = value
                            self.vine_fsm_state.value_namespace = name_space
                            self.vine_fsm_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bridge_domain_group_name.is_set or
                        self.bridge_domain_name.is_set or
                        (self.bridge_access_pws is not None and self.bridge_access_pws.has_data()) or
                        (self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table.has_data()) or
                        (self.bridge_acs is not None and self.bridge_acs.has_data()) or
                        (self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table.has_data()) or
                        (self.bridge_domain_info is not None and self.bridge_domain_info.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bridge_domain_group_name.yfilter != YFilter.not_set or
                        self.bridge_domain_name.yfilter != YFilter.not_set or
                        (self.bridge_access_pws is not None and self.bridge_access_pws.has_operation()) or
                        (self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table.has_operation()) or
                        (self.bridge_acs is not None and self.bridge_acs.has_operation()) or
                        (self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table.has_operation()) or
                        (self.bridge_domain_info is not None and self.bridge_domain_info.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bridge-domain" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bridge_domain_group_name.is_set or self.bridge_domain_group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_domain_group_name.get_name_leafdata())
                    if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bridge-access-pws"):
                        if (self.bridge_access_pws is None):
                            self.bridge_access_pws = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws()
                            self.bridge_access_pws.parent = self
                            self._children_name_map["bridge_access_pws"] = "bridge-access-pws"
                        return self.bridge_access_pws

                    if (child_yang_name == "bridge-access-vfi-table"):
                        if (self.bridge_access_vfi_table is None):
                            self.bridge_access_vfi_table = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                            self.bridge_access_vfi_table.parent = self
                            self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"
                        return self.bridge_access_vfi_table

                    if (child_yang_name == "bridge-acs"):
                        if (self.bridge_acs is None):
                            self.bridge_acs = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs()
                            self.bridge_acs.parent = self
                            self._children_name_map["bridge_acs"] = "bridge-acs"
                        return self.bridge_acs

                    if (child_yang_name == "bridge-core-vfi-table"):
                        if (self.bridge_core_vfi_table is None):
                            self.bridge_core_vfi_table = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                            self.bridge_core_vfi_table.parent = self
                            self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"
                        return self.bridge_core_vfi_table

                    if (child_yang_name == "bridge-domain-info"):
                        if (self.bridge_domain_info is None):
                            self.bridge_domain_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                            self.bridge_domain_info.parent = self
                            self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                        return self.bridge_domain_info

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bridge-access-pws" or name == "bridge-access-vfi-table" or name == "bridge-acs" or name == "bridge-core-vfi-table" or name == "bridge-domain-info" or name == "bridge-domain-group-name" or name == "bridge-domain-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bridge-domain-group-name"):
                        self.bridge_domain_group_name = value
                        self.bridge_domain_group_name.value_namespace = name_space
                        self.bridge_domain_group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-domain-name"):
                        self.bridge_domain_name = value
                        self.bridge_domain_name.value_namespace = name_space
                        self.bridge_domain_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.bridge_domain:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.bridge_domain:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bridge-domains" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bridge-domain"):
                    for c in self.bridge_domain:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.BridgeDomains.BridgeDomain()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.bridge_domain.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bridge-domain"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class DiscoverySummary(Entity):
            """
            Discovery summary information
            
            .. attribute:: bgp_current_node_id
            
            	BGP current node id
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: bgp_ipc_transport_mode
            
            	IPC Transport mode with BGP
            	**type**\:   :py:class:`L2VpnIpcTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIpcTransportMode>`
            
            .. attribute:: bgp_stateon_active_rp
            
            	BGP state on the active RP
            	**type**\:  bool
            
            .. attribute:: bgp_stateon_standby_rp
            
            	BGP state on standby RP
            	**type**\:  bool
            
            .. attribute:: number_bridge_domainvpns
            
            	Number of BDs registered
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_bridge_domain
            
            	Number of local Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_xconnect
            
            	Number of local Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2m_pxconnect_vpns
            
            	Number of XCs registered
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_bridge_domain
            
            	Number of NLRI
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_xconnect
            
            	Number of NLRI
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_bridge_domain
            
            	Number of Remote Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_xconnect
            
            	Number of Remote Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: vpls_registered
            
            	Is the VPLS service registered
            	**type**\:  bool
            
            .. attribute:: vpws_registered
            
            	Is the VPWS service registered
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.DiscoverySummary, self).__init__()

                self.yang_name = "discovery-summary"
                self.yang_parent_name = "standby"

                self.bgp_current_node_id = YLeaf(YType.str, "bgp-current-node-id")

                self.bgp_ipc_transport_mode = YLeaf(YType.enumeration, "bgp-ipc-transport-mode")

                self.bgp_stateon_active_rp = YLeaf(YType.boolean, "bgp-stateon-active-rp")

                self.bgp_stateon_standby_rp = YLeaf(YType.boolean, "bgp-stateon-standby-rp")

                self.number_bridge_domainvpns = YLeaf(YType.uint32, "number-bridge-domainvpns")

                self.number_local_edges_bridge_domain = YLeaf(YType.uint32, "number-local-edges-bridge-domain")

                self.number_local_edges_xconnect = YLeaf(YType.uint32, "number-local-edges-xconnect")

                self.number_mp2m_pxconnect_vpns = YLeaf(YType.uint32, "number-mp2m-pxconnect-vpns")

                self.number_nlri_bridge_domain = YLeaf(YType.uint32, "number-nlri-bridge-domain")

                self.number_nlri_xconnect = YLeaf(YType.uint32, "number-nlri-xconnect")

                self.number_remote_edges_bridge_domain = YLeaf(YType.uint32, "number-remote-edges-bridge-domain")

                self.number_remote_edges_xconnect = YLeaf(YType.uint32, "number-remote-edges-xconnect")

                self.vpls_registered = YLeaf(YType.boolean, "vpls-registered")

                self.vpws_registered = YLeaf(YType.boolean, "vpws-registered")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("bgp_current_node_id",
                                "bgp_ipc_transport_mode",
                                "bgp_stateon_active_rp",
                                "bgp_stateon_standby_rp",
                                "number_bridge_domainvpns",
                                "number_local_edges_bridge_domain",
                                "number_local_edges_xconnect",
                                "number_mp2m_pxconnect_vpns",
                                "number_nlri_bridge_domain",
                                "number_nlri_xconnect",
                                "number_remote_edges_bridge_domain",
                                "number_remote_edges_xconnect",
                                "vpls_registered",
                                "vpws_registered") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.DiscoverySummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.DiscoverySummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.bgp_current_node_id.is_set or
                    self.bgp_ipc_transport_mode.is_set or
                    self.bgp_stateon_active_rp.is_set or
                    self.bgp_stateon_standby_rp.is_set or
                    self.number_bridge_domainvpns.is_set or
                    self.number_local_edges_bridge_domain.is_set or
                    self.number_local_edges_xconnect.is_set or
                    self.number_mp2m_pxconnect_vpns.is_set or
                    self.number_nlri_bridge_domain.is_set or
                    self.number_nlri_xconnect.is_set or
                    self.number_remote_edges_bridge_domain.is_set or
                    self.number_remote_edges_xconnect.is_set or
                    self.vpls_registered.is_set or
                    self.vpws_registered.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.bgp_current_node_id.yfilter != YFilter.not_set or
                    self.bgp_ipc_transport_mode.yfilter != YFilter.not_set or
                    self.bgp_stateon_active_rp.yfilter != YFilter.not_set or
                    self.bgp_stateon_standby_rp.yfilter != YFilter.not_set or
                    self.number_bridge_domainvpns.yfilter != YFilter.not_set or
                    self.number_local_edges_bridge_domain.yfilter != YFilter.not_set or
                    self.number_local_edges_xconnect.yfilter != YFilter.not_set or
                    self.number_mp2m_pxconnect_vpns.yfilter != YFilter.not_set or
                    self.number_nlri_bridge_domain.yfilter != YFilter.not_set or
                    self.number_nlri_xconnect.yfilter != YFilter.not_set or
                    self.number_remote_edges_bridge_domain.yfilter != YFilter.not_set or
                    self.number_remote_edges_xconnect.yfilter != YFilter.not_set or
                    self.vpls_registered.yfilter != YFilter.not_set or
                    self.vpws_registered.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "discovery-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.bgp_current_node_id.is_set or self.bgp_current_node_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bgp_current_node_id.get_name_leafdata())
                if (self.bgp_ipc_transport_mode.is_set or self.bgp_ipc_transport_mode.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bgp_ipc_transport_mode.get_name_leafdata())
                if (self.bgp_stateon_active_rp.is_set or self.bgp_stateon_active_rp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bgp_stateon_active_rp.get_name_leafdata())
                if (self.bgp_stateon_standby_rp.is_set or self.bgp_stateon_standby_rp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bgp_stateon_standby_rp.get_name_leafdata())
                if (self.number_bridge_domainvpns.is_set or self.number_bridge_domainvpns.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_bridge_domainvpns.get_name_leafdata())
                if (self.number_local_edges_bridge_domain.is_set or self.number_local_edges_bridge_domain.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_local_edges_bridge_domain.get_name_leafdata())
                if (self.number_local_edges_xconnect.is_set or self.number_local_edges_xconnect.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_local_edges_xconnect.get_name_leafdata())
                if (self.number_mp2m_pxconnect_vpns.is_set or self.number_mp2m_pxconnect_vpns.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2m_pxconnect_vpns.get_name_leafdata())
                if (self.number_nlri_bridge_domain.is_set or self.number_nlri_bridge_domain.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_nlri_bridge_domain.get_name_leafdata())
                if (self.number_nlri_xconnect.is_set or self.number_nlri_xconnect.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_nlri_xconnect.get_name_leafdata())
                if (self.number_remote_edges_bridge_domain.is_set or self.number_remote_edges_bridge_domain.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_remote_edges_bridge_domain.get_name_leafdata())
                if (self.number_remote_edges_xconnect.is_set or self.number_remote_edges_xconnect.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_remote_edges_xconnect.get_name_leafdata())
                if (self.vpls_registered.is_set or self.vpls_registered.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vpls_registered.get_name_leafdata())
                if (self.vpws_registered.is_set or self.vpws_registered.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vpws_registered.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bgp-current-node-id" or name == "bgp-ipc-transport-mode" or name == "bgp-stateon-active-rp" or name == "bgp-stateon-standby-rp" or name == "number-bridge-domainvpns" or name == "number-local-edges-bridge-domain" or name == "number-local-edges-xconnect" or name == "number-mp2m-pxconnect-vpns" or name == "number-nlri-bridge-domain" or name == "number-nlri-xconnect" or name == "number-remote-edges-bridge-domain" or name == "number-remote-edges-xconnect" or name == "vpls-registered" or name == "vpws-registered"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "bgp-current-node-id"):
                    self.bgp_current_node_id = value
                    self.bgp_current_node_id.value_namespace = name_space
                    self.bgp_current_node_id.value_namespace_prefix = name_space_prefix
                if(value_path == "bgp-ipc-transport-mode"):
                    self.bgp_ipc_transport_mode = value
                    self.bgp_ipc_transport_mode.value_namespace = name_space
                    self.bgp_ipc_transport_mode.value_namespace_prefix = name_space_prefix
                if(value_path == "bgp-stateon-active-rp"):
                    self.bgp_stateon_active_rp = value
                    self.bgp_stateon_active_rp.value_namespace = name_space
                    self.bgp_stateon_active_rp.value_namespace_prefix = name_space_prefix
                if(value_path == "bgp-stateon-standby-rp"):
                    self.bgp_stateon_standby_rp = value
                    self.bgp_stateon_standby_rp.value_namespace = name_space
                    self.bgp_stateon_standby_rp.value_namespace_prefix = name_space_prefix
                if(value_path == "number-bridge-domainvpns"):
                    self.number_bridge_domainvpns = value
                    self.number_bridge_domainvpns.value_namespace = name_space
                    self.number_bridge_domainvpns.value_namespace_prefix = name_space_prefix
                if(value_path == "number-local-edges-bridge-domain"):
                    self.number_local_edges_bridge_domain = value
                    self.number_local_edges_bridge_domain.value_namespace = name_space
                    self.number_local_edges_bridge_domain.value_namespace_prefix = name_space_prefix
                if(value_path == "number-local-edges-xconnect"):
                    self.number_local_edges_xconnect = value
                    self.number_local_edges_xconnect.value_namespace = name_space
                    self.number_local_edges_xconnect.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2m-pxconnect-vpns"):
                    self.number_mp2m_pxconnect_vpns = value
                    self.number_mp2m_pxconnect_vpns.value_namespace = name_space
                    self.number_mp2m_pxconnect_vpns.value_namespace_prefix = name_space_prefix
                if(value_path == "number-nlri-bridge-domain"):
                    self.number_nlri_bridge_domain = value
                    self.number_nlri_bridge_domain.value_namespace = name_space
                    self.number_nlri_bridge_domain.value_namespace_prefix = name_space_prefix
                if(value_path == "number-nlri-xconnect"):
                    self.number_nlri_xconnect = value
                    self.number_nlri_xconnect.value_namespace = name_space
                    self.number_nlri_xconnect.value_namespace_prefix = name_space_prefix
                if(value_path == "number-remote-edges-bridge-domain"):
                    self.number_remote_edges_bridge_domain = value
                    self.number_remote_edges_bridge_domain.value_namespace = name_space
                    self.number_remote_edges_bridge_domain.value_namespace_prefix = name_space_prefix
                if(value_path == "number-remote-edges-xconnect"):
                    self.number_remote_edges_xconnect = value
                    self.number_remote_edges_xconnect.value_namespace = name_space
                    self.number_remote_edges_xconnect.value_namespace_prefix = name_space_prefix
                if(value_path == "vpls-registered"):
                    self.vpls_registered = value
                    self.vpls_registered.value_namespace = name_space
                    self.vpls_registered.value_namespace_prefix = name_space_prefix
                if(value_path == "vpws-registered"):
                    self.vpws_registered = value
                    self.vpws_registered.value_namespace = name_space
                    self.vpws_registered.value_namespace_prefix = name_space_prefix


        class G8032(Entity):
            """
            G8032 information
            
            .. attribute:: g8032_rings
            
            	G8032 Ring table
            	**type**\:   :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.G8032, self).__init__()

                self.yang_name = "g8032"
                self.yang_parent_name = "standby"

                self.g8032_rings = L2Vpnv2.Standby.G8032.G8032Rings()
                self.g8032_rings.parent = self
                self._children_name_map["g8032_rings"] = "g8032-rings"
                self._children_yang_names.add("g8032-rings")


            class G8032Rings(Entity):
                """
                G8032 Ring table
                
                .. attribute:: g8032_ring
                
                	G8032 Ring
                	**type**\: list of    :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.G8032.G8032Rings, self).__init__()

                    self.yang_name = "g8032-rings"
                    self.yang_parent_name = "g8032"

                    self.g8032_ring = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.G8032.G8032Rings, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.G8032.G8032Rings, self).__setattr__(name, value)


                class G8032Ring(Entity):
                    """
                    G8032 Ring
                    
                    .. attribute:: ring_name  <key>
                    
                    	Ring Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: g8032_ring_detail
                    
                    	G8032 Ring detailed information
                    	**type**\:   :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                    
                    .. attribute:: g8032_ring_instance_details
                    
                    	G8032 Ring Instance detail table
                    	**type**\:   :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                    
                    .. attribute:: g8032_ring_instance_summaries
                    
                    	G8032 Ring Instance summary table
                    	**type**\:   :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                    
                    .. attribute:: g8032_ring_summary
                    
                    	G8032 Ring summary information
                    	**type**\:   :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring, self).__init__()

                        self.yang_name = "g8032-ring"
                        self.yang_parent_name = "g8032-rings"

                        self.ring_name = YLeaf(YType.str, "ring-name")

                        self.g8032_ring_detail = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                        self.g8032_ring_detail.parent = self
                        self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"
                        self._children_yang_names.add("g8032-ring-detail")

                        self.g8032_ring_instance_details = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                        self.g8032_ring_instance_details.parent = self
                        self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                        self._children_yang_names.add("g8032-ring-instance-details")

                        self.g8032_ring_instance_summaries = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                        self.g8032_ring_instance_summaries.parent = self
                        self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"
                        self._children_yang_names.add("g8032-ring-instance-summaries")

                        self.g8032_ring_summary = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                        self.g8032_ring_summary.parent = self
                        self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"
                        self._children_yang_names.add("g8032-ring-summary")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ring_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring, self).__setattr__(name, value)


                    class G8032RingDetail(Entity):
                        """
                        G8032 Ring detailed information
                        
                        .. attribute:: excluded_vlan_id
                        
                        	Exclusion Vlan ids list 
                        	**type**\:  list of int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: is_open_ring
                        
                        	Flag open ring
                        	**type**\:  bool
                        
                        .. attribute:: is_provider_bridge
                        
                        	Operating mode Customer/Provider 
                        	**type**\:  bool
                        
                        .. attribute:: monitor0
                        
                        	Monitor port 0
                        	**type**\:  str
                        
                        .. attribute:: monitor1
                        
                        	Monitor port 1
                        	**type**\:  str
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\:  str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\:  str
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\:  str
                        
                        .. attribute:: tcn_propagation
                        
                        	Global TCN propagation
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__init__()

                            self.yang_name = "g8032-ring-detail"
                            self.yang_parent_name = "g8032-ring"

                            self.excluded_vlan_id = YLeafList(YType.uint16, "excluded-vlan-id")

                            self.is_open_ring = YLeaf(YType.boolean, "is-open-ring")

                            self.is_provider_bridge = YLeaf(YType.boolean, "is-provider-bridge")

                            self.monitor0 = YLeaf(YType.str, "monitor0")

                            self.monitor1 = YLeaf(YType.str, "monitor1")

                            self.port0 = YLeaf(YType.str, "port0")

                            self.port1 = YLeaf(YType.str, "port1")

                            self.ring_name = YLeaf(YType.str, "ring-name")

                            self.tcn_propagation = YLeaf(YType.boolean, "tcn-propagation")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("excluded_vlan_id",
                                            "is_open_ring",
                                            "is_provider_bridge",
                                            "monitor0",
                                            "monitor1",
                                            "port0",
                                            "port1",
                                            "ring_name",
                                            "tcn_propagation") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.excluded_vlan_id.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.is_open_ring.is_set or
                                self.is_provider_bridge.is_set or
                                self.monitor0.is_set or
                                self.monitor1.is_set or
                                self.port0.is_set or
                                self.port1.is_set or
                                self.ring_name.is_set or
                                self.tcn_propagation.is_set)

                        def has_operation(self):
                            for leaf in self.excluded_vlan_id.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.excluded_vlan_id.yfilter != YFilter.not_set or
                                self.is_open_ring.yfilter != YFilter.not_set or
                                self.is_provider_bridge.yfilter != YFilter.not_set or
                                self.monitor0.yfilter != YFilter.not_set or
                                self.monitor1.yfilter != YFilter.not_set or
                                self.port0.yfilter != YFilter.not_set or
                                self.port1.yfilter != YFilter.not_set or
                                self.ring_name.yfilter != YFilter.not_set or
                                self.tcn_propagation.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring-detail" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_open_ring.is_set or self.is_open_ring.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_open_ring.get_name_leafdata())
                            if (self.is_provider_bridge.is_set or self.is_provider_bridge.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_provider_bridge.get_name_leafdata())
                            if (self.monitor0.is_set or self.monitor0.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.monitor0.get_name_leafdata())
                            if (self.monitor1.is_set or self.monitor1.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.monitor1.get_name_leafdata())
                            if (self.port0.is_set or self.port0.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port0.get_name_leafdata())
                            if (self.port1.is_set or self.port1.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port1.get_name_leafdata())
                            if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ring_name.get_name_leafdata())
                            if (self.tcn_propagation.is_set or self.tcn_propagation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tcn_propagation.get_name_leafdata())

                            leaf_name_data.extend(self.excluded_vlan_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "excluded-vlan-id" or name == "is-open-ring" or name == "is-provider-bridge" or name == "monitor0" or name == "monitor1" or name == "port0" or name == "port1" or name == "ring-name" or name == "tcn-propagation"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "excluded-vlan-id"):
                                self.excluded_vlan_id.append(value)
                            if(value_path == "is-open-ring"):
                                self.is_open_ring = value
                                self.is_open_ring.value_namespace = name_space
                                self.is_open_ring.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-provider-bridge"):
                                self.is_provider_bridge = value
                                self.is_provider_bridge.value_namespace = name_space
                                self.is_provider_bridge.value_namespace_prefix = name_space_prefix
                            if(value_path == "monitor0"):
                                self.monitor0 = value
                                self.monitor0.value_namespace = name_space
                                self.monitor0.value_namespace_prefix = name_space_prefix
                            if(value_path == "monitor1"):
                                self.monitor1 = value
                                self.monitor1.value_namespace = name_space
                                self.monitor1.value_namespace_prefix = name_space_prefix
                            if(value_path == "port0"):
                                self.port0 = value
                                self.port0.value_namespace = name_space
                                self.port0.value_namespace_prefix = name_space_prefix
                            if(value_path == "port1"):
                                self.port1 = value
                                self.port1.value_namespace = name_space
                                self.port1.value_namespace_prefix = name_space_prefix
                            if(value_path == "ring-name"):
                                self.ring_name = value
                                self.ring_name.value_namespace = name_space
                                self.ring_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tcn-propagation"):
                                self.tcn_propagation = value
                                self.tcn_propagation.value_namespace = name_space
                                self.tcn_propagation.value_namespace_prefix = name_space_prefix


                    class G8032RingInstanceSummaries(Entity):
                        """
                        G8032 Ring Instance summary table
                        
                        .. attribute:: g8032_ring_instance_summary
                        
                        	G8032 Ring Instance summary information
                        	**type**\: list of    :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__init__()

                            self.yang_name = "g8032-ring-instance-summaries"
                            self.yang_parent_name = "g8032-ring"

                            self.g8032_ring_instance_summary = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__setattr__(name, value)


                        class G8032RingInstanceSummary(Entity):
                            """
                            G8032 Ring Instance summary information
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\:  bool
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\:  list of int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__init__()

                                self.yang_name = "g8032-ring-instance-summary"
                                self.yang_parent_name = "g8032-ring-instance-summaries"

                                self.instance = YLeaf(YType.int32, "instance")

                                self.aps_port0 = YLeaf(YType.str, "aps-port0")

                                self.aps_port1 = YLeaf(YType.str, "aps-port1")

                                self.config_state = YLeaf(YType.boolean, "config-state")

                                self.included_vlan_id = YLeafList(YType.uint16, "included-vlan-id")

                                self.ring_instance = YLeaf(YType.uint32, "ring-instance")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("instance",
                                                "aps_port0",
                                                "aps_port1",
                                                "config_state",
                                                "included_vlan_id",
                                                "ring_instance") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.included_vlan_id.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.instance.is_set or
                                    self.aps_port0.is_set or
                                    self.aps_port1.is_set or
                                    self.config_state.is_set or
                                    self.ring_instance.is_set)

                            def has_operation(self):
                                for leaf in self.included_vlan_id.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.instance.yfilter != YFilter.not_set or
                                    self.aps_port0.yfilter != YFilter.not_set or
                                    self.aps_port1.yfilter != YFilter.not_set or
                                    self.config_state.yfilter != YFilter.not_set or
                                    self.included_vlan_id.yfilter != YFilter.not_set or
                                    self.ring_instance.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g8032-ring-instance-summary" + "[instance='" + self.instance.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                if (self.aps_port0.is_set or self.aps_port0.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aps_port0.get_name_leafdata())
                                if (self.aps_port1.is_set or self.aps_port1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aps_port1.get_name_leafdata())
                                if (self.config_state.is_set or self.config_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.config_state.get_name_leafdata())
                                if (self.ring_instance.is_set or self.ring_instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_instance.get_name_leafdata())

                                leaf_name_data.extend(self.included_vlan_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "instance" or name == "aps-port0" or name == "aps-port1" or name == "config-state" or name == "included-vlan-id" or name == "ring-instance"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "instance"):
                                    self.instance = value
                                    self.instance.value_namespace = name_space
                                    self.instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "aps-port0"):
                                    self.aps_port0 = value
                                    self.aps_port0.value_namespace = name_space
                                    self.aps_port0.value_namespace_prefix = name_space_prefix
                                if(value_path == "aps-port1"):
                                    self.aps_port1 = value
                                    self.aps_port1.value_namespace = name_space
                                    self.aps_port1.value_namespace_prefix = name_space_prefix
                                if(value_path == "config-state"):
                                    self.config_state = value
                                    self.config_state.value_namespace = name_space
                                    self.config_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "included-vlan-id"):
                                    self.included_vlan_id.append(value)
                                if(value_path == "ring-instance"):
                                    self.ring_instance = value
                                    self.ring_instance.value_namespace = name_space
                                    self.ring_instance.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.g8032_ring_instance_summary:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.g8032_ring_instance_summary:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring-instance-summaries" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "g8032-ring-instance-summary"):
                                for c in self.g8032_ring_instance_summary:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.g8032_ring_instance_summary.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "g8032-ring-instance-summary"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class G8032RingSummary(Entity):
                        """
                        G8032 Ring summary information
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\:  str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\:  str
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__init__()

                            self.yang_name = "g8032-ring-summary"
                            self.yang_parent_name = "g8032-ring"

                            self.port0 = YLeaf(YType.str, "port0")

                            self.port1 = YLeaf(YType.str, "port1")

                            self.ring_name = YLeaf(YType.str, "ring-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("port0",
                                            "port1",
                                            "ring_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.port0.is_set or
                                self.port1.is_set or
                                self.ring_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.port0.yfilter != YFilter.not_set or
                                self.port1.yfilter != YFilter.not_set or
                                self.ring_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring-summary" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.port0.is_set or self.port0.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port0.get_name_leafdata())
                            if (self.port1.is_set or self.port1.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port1.get_name_leafdata())
                            if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ring_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "port0" or name == "port1" or name == "ring-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "port0"):
                                self.port0 = value
                                self.port0.value_namespace = name_space
                                self.port0.value_namespace_prefix = name_space_prefix
                            if(value_path == "port1"):
                                self.port1 = value
                                self.port1.value_namespace = name_space
                                self.port1.value_namespace_prefix = name_space_prefix
                            if(value_path == "ring-name"):
                                self.ring_name = value
                                self.ring_name.value_namespace = name_space
                                self.ring_name.value_namespace_prefix = name_space_prefix


                    class G8032RingInstanceDetails(Entity):
                        """
                        G8032 Ring Instance detail table
                        
                        .. attribute:: g8032_ring_instance_detail
                        
                        	G8032 Ring Instance detailed information
                        	**type**\: list of    :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__init__()

                            self.yang_name = "g8032-ring-instance-details"
                            self.yang_parent_name = "g8032-ring"

                            self.g8032_ring_instance_detail = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__setattr__(name, value)


                        class G8032RingInstanceDetail(Entity):
                            """
                            G8032 Ring Instance detailed information
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: aps_channel_level
                            
                            	APS channel level
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\:  bool
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\:  list of int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ring_description
                            
                            	Ring description
                            	**type**\:  str
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ring_profile
                            
                            	Ring Profile
                            	**type**\:  str
                            
                            .. attribute:: rpl
                            
                            	RPL
                            	**type**\:   :py:class:`L2VpnG8032Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032Rpl>`
                            
                            .. attribute:: unresolved_reason
                            
                            	Reason of unresolved state state
                            	**type**\:   :py:class:`L2VpnG8032UncfgReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032UncfgReason>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__init__()

                                self.yang_name = "g8032-ring-instance-detail"
                                self.yang_parent_name = "g8032-ring-instance-details"

                                self.instance = YLeaf(YType.int32, "instance")

                                self.aps_channel_level = YLeaf(YType.uint32, "aps-channel-level")

                                self.aps_port0 = YLeaf(YType.str, "aps-port0")

                                self.aps_port1 = YLeaf(YType.str, "aps-port1")

                                self.config_state = YLeaf(YType.boolean, "config-state")

                                self.included_vlan_id = YLeafList(YType.uint16, "included-vlan-id")

                                self.ring_description = YLeaf(YType.str, "ring-description")

                                self.ring_instance = YLeaf(YType.uint32, "ring-instance")

                                self.ring_profile = YLeaf(YType.str, "ring-profile")

                                self.rpl = YLeaf(YType.enumeration, "rpl")

                                self.unresolved_reason = YLeaf(YType.enumeration, "unresolved-reason")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("instance",
                                                "aps_channel_level",
                                                "aps_port0",
                                                "aps_port1",
                                                "config_state",
                                                "included_vlan_id",
                                                "ring_description",
                                                "ring_instance",
                                                "ring_profile",
                                                "rpl",
                                                "unresolved_reason") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.included_vlan_id.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.instance.is_set or
                                    self.aps_channel_level.is_set or
                                    self.aps_port0.is_set or
                                    self.aps_port1.is_set or
                                    self.config_state.is_set or
                                    self.ring_description.is_set or
                                    self.ring_instance.is_set or
                                    self.ring_profile.is_set or
                                    self.rpl.is_set or
                                    self.unresolved_reason.is_set)

                            def has_operation(self):
                                for leaf in self.included_vlan_id.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.instance.yfilter != YFilter.not_set or
                                    self.aps_channel_level.yfilter != YFilter.not_set or
                                    self.aps_port0.yfilter != YFilter.not_set or
                                    self.aps_port1.yfilter != YFilter.not_set or
                                    self.config_state.yfilter != YFilter.not_set or
                                    self.included_vlan_id.yfilter != YFilter.not_set or
                                    self.ring_description.yfilter != YFilter.not_set or
                                    self.ring_instance.yfilter != YFilter.not_set or
                                    self.ring_profile.yfilter != YFilter.not_set or
                                    self.rpl.yfilter != YFilter.not_set or
                                    self.unresolved_reason.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g8032-ring-instance-detail" + "[instance='" + self.instance.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                if (self.aps_channel_level.is_set or self.aps_channel_level.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aps_channel_level.get_name_leafdata())
                                if (self.aps_port0.is_set or self.aps_port0.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aps_port0.get_name_leafdata())
                                if (self.aps_port1.is_set or self.aps_port1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aps_port1.get_name_leafdata())
                                if (self.config_state.is_set or self.config_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.config_state.get_name_leafdata())
                                if (self.ring_description.is_set or self.ring_description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_description.get_name_leafdata())
                                if (self.ring_instance.is_set or self.ring_instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_instance.get_name_leafdata())
                                if (self.ring_profile.is_set or self.ring_profile.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_profile.get_name_leafdata())
                                if (self.rpl.is_set or self.rpl.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rpl.get_name_leafdata())
                                if (self.unresolved_reason.is_set or self.unresolved_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unresolved_reason.get_name_leafdata())

                                leaf_name_data.extend(self.included_vlan_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "instance" or name == "aps-channel-level" or name == "aps-port0" or name == "aps-port1" or name == "config-state" or name == "included-vlan-id" or name == "ring-description" or name == "ring-instance" or name == "ring-profile" or name == "rpl" or name == "unresolved-reason"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "instance"):
                                    self.instance = value
                                    self.instance.value_namespace = name_space
                                    self.instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "aps-channel-level"):
                                    self.aps_channel_level = value
                                    self.aps_channel_level.value_namespace = name_space
                                    self.aps_channel_level.value_namespace_prefix = name_space_prefix
                                if(value_path == "aps-port0"):
                                    self.aps_port0 = value
                                    self.aps_port0.value_namespace = name_space
                                    self.aps_port0.value_namespace_prefix = name_space_prefix
                                if(value_path == "aps-port1"):
                                    self.aps_port1 = value
                                    self.aps_port1.value_namespace = name_space
                                    self.aps_port1.value_namespace_prefix = name_space_prefix
                                if(value_path == "config-state"):
                                    self.config_state = value
                                    self.config_state.value_namespace = name_space
                                    self.config_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "included-vlan-id"):
                                    self.included_vlan_id.append(value)
                                if(value_path == "ring-description"):
                                    self.ring_description = value
                                    self.ring_description.value_namespace = name_space
                                    self.ring_description.value_namespace_prefix = name_space_prefix
                                if(value_path == "ring-instance"):
                                    self.ring_instance = value
                                    self.ring_instance.value_namespace = name_space
                                    self.ring_instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "ring-profile"):
                                    self.ring_profile = value
                                    self.ring_profile.value_namespace = name_space
                                    self.ring_profile.value_namespace_prefix = name_space_prefix
                                if(value_path == "rpl"):
                                    self.rpl = value
                                    self.rpl.value_namespace = name_space
                                    self.rpl.value_namespace_prefix = name_space_prefix
                                if(value_path == "unresolved-reason"):
                                    self.unresolved_reason = value
                                    self.unresolved_reason.value_namespace = name_space
                                    self.unresolved_reason.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.g8032_ring_instance_detail:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.g8032_ring_instance_detail:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring-instance-details" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "g8032-ring-instance-detail"):
                                for c in self.g8032_ring_instance_detail:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.g8032_ring_instance_detail.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "g8032-ring-instance-detail"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.ring_name.is_set or
                            (self.g8032_ring_detail is not None and self.g8032_ring_detail.has_data()) or
                            (self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details.has_data()) or
                            (self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries.has_data()) or
                            (self.g8032_ring_summary is not None and self.g8032_ring_summary.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ring_name.yfilter != YFilter.not_set or
                            (self.g8032_ring_detail is not None and self.g8032_ring_detail.has_operation()) or
                            (self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details.has_operation()) or
                            (self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries.has_operation()) or
                            (self.g8032_ring_summary is not None and self.g8032_ring_summary.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g8032-ring" + "[ring-name='" + self.ring_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/g8032/g8032-rings/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ring_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "g8032-ring-detail"):
                            if (self.g8032_ring_detail is None):
                                self.g8032_ring_detail = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                                self.g8032_ring_detail.parent = self
                                self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"
                            return self.g8032_ring_detail

                        if (child_yang_name == "g8032-ring-instance-details"):
                            if (self.g8032_ring_instance_details is None):
                                self.g8032_ring_instance_details = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                                self.g8032_ring_instance_details.parent = self
                                self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                            return self.g8032_ring_instance_details

                        if (child_yang_name == "g8032-ring-instance-summaries"):
                            if (self.g8032_ring_instance_summaries is None):
                                self.g8032_ring_instance_summaries = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                                self.g8032_ring_instance_summaries.parent = self
                                self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"
                            return self.g8032_ring_instance_summaries

                        if (child_yang_name == "g8032-ring-summary"):
                            if (self.g8032_ring_summary is None):
                                self.g8032_ring_summary = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                                self.g8032_ring_summary.parent = self
                                self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"
                            return self.g8032_ring_summary

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "g8032-ring-detail" or name == "g8032-ring-instance-details" or name == "g8032-ring-instance-summaries" or name == "g8032-ring-summary" or name == "ring-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ring-name"):
                            self.ring_name = value
                            self.ring_name.value_namespace = name_space
                            self.ring_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.g8032_ring:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.g8032_ring:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "g8032-rings" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/g8032/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g8032-ring"):
                        for c in self.g8032_ring:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.g8032_ring.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g8032-ring"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.g8032_rings is not None and self.g8032_rings.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.g8032_rings is not None and self.g8032_rings.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "g8032" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "g8032-rings"):
                    if (self.g8032_rings is None):
                        self.g8032_rings = L2Vpnv2.Standby.G8032.G8032Rings()
                        self.g8032_rings.parent = self
                        self._children_name_map["g8032_rings"] = "g8032-rings"
                    return self.g8032_rings

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "g8032-rings"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class PseudowireClasses(Entity):
            """
            List of pseudowire classes
            
            .. attribute:: pseudowire_class
            
            	Pseudowire class information
            	**type**\: list of    :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses.PseudowireClass>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.PseudowireClasses, self).__init__()

                self.yang_name = "pseudowire-classes"
                self.yang_parent_name = "standby"

                self.pseudowire_class = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.PseudowireClasses, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.PseudowireClasses, self).__setattr__(name, value)


            class PseudowireClass(Entity):
                """
                Pseudowire class information
                
                .. attribute:: pseudowire_class_name  <key>
                
                	Pseudowire Class Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: backup_mac_withdraw
                
                	TRUE if MAC withdraw message is sent
                	**type**\:  bool
                
                .. attribute:: control_word
                
                	Control word
                	**type**\:   :py:class:`L2VpnPwClassControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwClassControlWord>`
                
                .. attribute:: disable_delay
                
                	Disable Deley
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: disable_never
                
                	TRUE if backup is not automatically disabled
                	**type**\:  bool
                
                .. attribute:: encapsulation_info
                
                	Encapsulation specific pseudowire information
                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
                
                .. attribute:: is_flow_label_static
                
                	is flow label static
                	**type**\:  bool
                
                .. attribute:: load_balance
                
                	Load Balance Type
                	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                
                .. attribute:: local_source_address
                
                	Local source address
                	**type**\:   :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
                
                .. attribute:: preferred_path
                
                	MPLS Preferred Path
                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath>`
                
                .. attribute:: preferred_path_disable_fallback
                
                	PreferredPathDisableFallback
                	**type**\:  bool
                
                .. attribute:: protocol
                
                	Protocol
                	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                
                .. attribute:: pw_class_name
                
                	Pseudowire class name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: pw_flow_label_code17_disabled
                
                	Disable sending Code 17 TLV
                	**type**\:  bool
                
                .. attribute:: pw_flow_label_type_cfg
                
                	Configured pseudowire flow label type
                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                
                .. attribute:: resync_enabled
                
                	Resync if packets out of sequence
                	**type**\:  bool
                
                .. attribute:: resync_threshold
                
                	Number of Packets Out of Seqence to trigger resync
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sequencing_type
                
                	Sequencing Type
                	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                
                .. attribute:: tag_rewrite
                
                	Static tag rewrite
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: transport_mode
                
                	Transport mode
                	**type**\:   :py:class:`L2VpnTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTransportMode>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass, self).__init__()

                    self.yang_name = "pseudowire-class"
                    self.yang_parent_name = "pseudowire-classes"

                    self.pseudowire_class_name = YLeaf(YType.str, "pseudowire-class-name")

                    self.backup_mac_withdraw = YLeaf(YType.boolean, "backup-mac-withdraw")

                    self.control_word = YLeaf(YType.enumeration, "control-word")

                    self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                    self.disable_never = YLeaf(YType.boolean, "disable-never")

                    self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                    self.load_balance = YLeaf(YType.enumeration, "load-balance")

                    self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                    self.protocol = YLeaf(YType.enumeration, "protocol")

                    self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                    self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                    self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                    self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                    self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                    self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                    self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                    self.transport_mode = YLeaf(YType.enumeration, "transport-mode")

                    self.encapsulation_info = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                    self.encapsulation_info.parent = self
                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                    self._children_yang_names.add("encapsulation-info")

                    self.local_source_address = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                    self.local_source_address.parent = self
                    self._children_name_map["local_source_address"] = "local-source-address"
                    self._children_yang_names.add("local-source-address")

                    self.preferred_path = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath()
                    self.preferred_path.parent = self
                    self._children_name_map["preferred_path"] = "preferred-path"
                    self._children_yang_names.add("preferred-path")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("pseudowire_class_name",
                                    "backup_mac_withdraw",
                                    "control_word",
                                    "disable_delay",
                                    "disable_never",
                                    "is_flow_label_static",
                                    "load_balance",
                                    "preferred_path_disable_fallback",
                                    "protocol",
                                    "pw_class_name",
                                    "pw_flow_label_code17_disabled",
                                    "pw_flow_label_type_cfg",
                                    "resync_enabled",
                                    "resync_threshold",
                                    "sequencing_type",
                                    "tag_rewrite",
                                    "transport_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass, self).__setattr__(name, value)


                class EncapsulationInfo(Entity):
                    """
                    Encapsulation specific pseudowire information
                    
                    .. attribute:: encapsulation
                    
                    	Encapsulation
                    	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                    
                    .. attribute:: l2tpv3
                    
                    	l2tpv3
                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__init__()

                        self.yang_name = "encapsulation-info"
                        self.yang_parent_name = "pseudowire-class"

                        self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                        self.l2tpv3 = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                        self.l2tpv3.parent = self
                        self._children_name_map["l2tpv3"] = "l2tpv3"
                        self._children_yang_names.add("l2tpv3")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("encapsulation") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__setattr__(name, value)


                    class L2Tpv3(Entity):
                        """
                        l2tpv3
                        
                        .. attribute:: cookie_size
                        
                        	Cookie size\: 0, 4, or 8 bytes
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dont_fragment_bit
                        
                        	Don't Fragment Bit
                        	**type**\:  bool
                        
                        .. attribute:: ipv4_source_address
                        
                        	IPv4 source address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: l2tp_class_name
                        
                        	L2TPClassName
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        .. attribute:: path_mtu_enabled
                        
                        	Path MTU enabled
                        	**type**\:  bool
                        
                        .. attribute:: path_mtu_max_value
                        
                        	Path MTU Maximum allowable session MTU
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: tos
                        
                        	Type Of Service Value
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tos_mode
                        
                        	Type Of Service Mode
                        	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                        
                        .. attribute:: ttl
                        
                        	Time To Live value
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__init__()

                            self.yang_name = "l2tpv3"
                            self.yang_parent_name = "encapsulation-info"

                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                            self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                            self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                            self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                            self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                            self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                            self.tos = YLeaf(YType.uint8, "tos")

                            self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                            self.ttl = YLeaf(YType.uint8, "ttl")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("cookie_size",
                                            "dont_fragment_bit",
                                            "ipv4_source_address",
                                            "l2tp_class_name",
                                            "path_mtu_enabled",
                                            "path_mtu_max_value",
                                            "tos",
                                            "tos_mode",
                                            "ttl") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.cookie_size.is_set or
                                self.dont_fragment_bit.is_set or
                                self.ipv4_source_address.is_set or
                                self.l2tp_class_name.is_set or
                                self.path_mtu_enabled.is_set or
                                self.path_mtu_max_value.is_set or
                                self.tos.is_set or
                                self.tos_mode.is_set or
                                self.ttl.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.cookie_size.yfilter != YFilter.not_set or
                                self.dont_fragment_bit.yfilter != YFilter.not_set or
                                self.ipv4_source_address.yfilter != YFilter.not_set or
                                self.l2tp_class_name.yfilter != YFilter.not_set or
                                self.path_mtu_enabled.yfilter != YFilter.not_set or
                                self.path_mtu_max_value.yfilter != YFilter.not_set or
                                self.tos.yfilter != YFilter.not_set or
                                self.tos_mode.yfilter != YFilter.not_set or
                                self.ttl.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2tpv3" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                            if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                            if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                            if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                            if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                            if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                            if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tos.get_name_leafdata())
                            if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tos_mode.get_name_leafdata())
                            if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ttl.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "cookie-size" or name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "l2tp-class-name" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "tos" or name == "tos-mode" or name == "ttl"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "cookie-size"):
                                self.cookie_size = value
                                self.cookie_size.value_namespace = name_space
                                self.cookie_size.value_namespace_prefix = name_space_prefix
                            if(value_path == "dont-fragment-bit"):
                                self.dont_fragment_bit = value
                                self.dont_fragment_bit.value_namespace = name_space
                                self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-source-address"):
                                self.ipv4_source_address = value
                                self.ipv4_source_address.value_namespace = name_space
                                self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "l2tp-class-name"):
                                self.l2tp_class_name = value
                                self.l2tp_class_name.value_namespace = name_space
                                self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-mtu-enabled"):
                                self.path_mtu_enabled = value
                                self.path_mtu_enabled.value_namespace = name_space
                                self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-mtu-max-value"):
                                self.path_mtu_max_value = value
                                self.path_mtu_max_value.value_namespace = name_space
                                self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                            if(value_path == "tos"):
                                self.tos = value
                                self.tos.value_namespace = name_space
                                self.tos.value_namespace_prefix = name_space_prefix
                            if(value_path == "tos-mode"):
                                self.tos_mode = value
                                self.tos_mode.value_namespace = name_space
                                self.tos_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "ttl"):
                                self.ttl = value
                                self.ttl.value_namespace = name_space
                                self.ttl.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.encapsulation.is_set or
                            (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.encapsulation.yfilter != YFilter.not_set or
                            (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "encapsulation-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2tpv3"):
                            if (self.l2tpv3 is None):
                                self.l2tpv3 = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                            return self.l2tpv3

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2tpv3" or name == "encapsulation"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "encapsulation"):
                            self.encapsulation = value
                            self.encapsulation.value_namespace = name_space
                            self.encapsulation.value_namespace_prefix = name_space_prefix


                class PreferredPath(Entity):
                    """
                    MPLS Preferred Path
                    
                    .. attribute:: ip_tunnel_interface_number
                    
                    	IPTunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: next_hop_ip
                    
                    	NextHopIP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: option
                    
                    	Option
                    	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                    
                    .. attribute:: te_tunnel_interface_number
                    
                    	TETunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tp_tunnel_interface_number
                    
                    	TPTunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath, self).__init__()

                        self.yang_name = "preferred-path"
                        self.yang_parent_name = "pseudowire-class"

                        self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                        self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                        self.option = YLeaf(YType.enumeration, "option")

                        self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                        self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ip_tunnel_interface_number",
                                        "next_hop_ip",
                                        "option",
                                        "te_tunnel_interface_number",
                                        "tp_tunnel_interface_number") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ip_tunnel_interface_number.is_set or
                            self.next_hop_ip.is_set or
                            self.option.is_set or
                            self.te_tunnel_interface_number.is_set or
                            self.tp_tunnel_interface_number.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                            self.next_hop_ip.yfilter != YFilter.not_set or
                            self.option.yfilter != YFilter.not_set or
                            self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                            self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "preferred-path" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                        if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.option.get_name_leafdata())
                        if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                        if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ip-tunnel-interface-number"):
                            self.ip_tunnel_interface_number = value
                            self.ip_tunnel_interface_number.value_namespace = name_space
                            self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "next-hop-ip"):
                            self.next_hop_ip = value
                            self.next_hop_ip.value_namespace = name_space
                            self.next_hop_ip.value_namespace_prefix = name_space_prefix
                        if(value_path == "option"):
                            self.option = value
                            self.option.value_namespace = name_space
                            self.option.value_namespace_prefix = name_space_prefix
                        if(value_path == "te-tunnel-interface-number"):
                            self.te_tunnel_interface_number = value
                            self.te_tunnel_interface_number.value_namespace = name_space
                            self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "tp-tunnel-interface-number"):
                            self.tp_tunnel_interface_number = value
                            self.tp_tunnel_interface_number.value_namespace = name_space
                            self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                class LocalSourceAddress(Entity):
                    """
                    Local source address
                    
                    .. attribute:: address
                    
                    	Local source address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: configuration
                    
                    	Configuration
                    	**type**\:   :py:class:`L2VpnSrcAddressSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSrcAddressSet>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__init__()

                        self.yang_name = "local-source-address"
                        self.yang_parent_name = "pseudowire-class"

                        self.address = YLeaf(YType.str, "address")

                        self.configuration = YLeaf(YType.enumeration, "configuration")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "configuration") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.configuration.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.configuration.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "local-source-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.configuration.is_set or self.configuration.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "configuration"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration"):
                            self.configuration = value
                            self.configuration.value_namespace = name_space
                            self.configuration.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.pseudowire_class_name.is_set or
                        self.backup_mac_withdraw.is_set or
                        self.control_word.is_set or
                        self.disable_delay.is_set or
                        self.disable_never.is_set or
                        self.is_flow_label_static.is_set or
                        self.load_balance.is_set or
                        self.preferred_path_disable_fallback.is_set or
                        self.protocol.is_set or
                        self.pw_class_name.is_set or
                        self.pw_flow_label_code17_disabled.is_set or
                        self.pw_flow_label_type_cfg.is_set or
                        self.resync_enabled.is_set or
                        self.resync_threshold.is_set or
                        self.sequencing_type.is_set or
                        self.tag_rewrite.is_set or
                        self.transport_mode.is_set or
                        (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                        (self.local_source_address is not None and self.local_source_address.has_data()) or
                        (self.preferred_path is not None and self.preferred_path.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.pseudowire_class_name.yfilter != YFilter.not_set or
                        self.backup_mac_withdraw.yfilter != YFilter.not_set or
                        self.control_word.yfilter != YFilter.not_set or
                        self.disable_delay.yfilter != YFilter.not_set or
                        self.disable_never.yfilter != YFilter.not_set or
                        self.is_flow_label_static.yfilter != YFilter.not_set or
                        self.load_balance.yfilter != YFilter.not_set or
                        self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                        self.protocol.yfilter != YFilter.not_set or
                        self.pw_class_name.yfilter != YFilter.not_set or
                        self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                        self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                        self.resync_enabled.yfilter != YFilter.not_set or
                        self.resync_threshold.yfilter != YFilter.not_set or
                        self.sequencing_type.yfilter != YFilter.not_set or
                        self.tag_rewrite.yfilter != YFilter.not_set or
                        self.transport_mode.yfilter != YFilter.not_set or
                        (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                        (self.local_source_address is not None and self.local_source_address.has_operation()) or
                        (self.preferred_path is not None and self.preferred_path.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pseudowire-class" + "[pseudowire-class-name='" + self.pseudowire_class_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pseudowire-classes/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.pseudowire_class_name.is_set or self.pseudowire_class_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pseudowire_class_name.get_name_leafdata())
                    if (self.backup_mac_withdraw.is_set or self.backup_mac_withdraw.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.backup_mac_withdraw.get_name_leafdata())
                    if (self.control_word.is_set or self.control_word.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.control_word.get_name_leafdata())
                    if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disable_delay.get_name_leafdata())
                    if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disable_never.get_name_leafdata())
                    if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                    if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.load_balance.get_name_leafdata())
                    if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.protocol.get_name_leafdata())
                    if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                    if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                    if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                    if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                    if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                    if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                    if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                    if (self.transport_mode.is_set or self.transport_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.transport_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "encapsulation-info"):
                        if (self.encapsulation_info is None):
                            self.encapsulation_info = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                        return self.encapsulation_info

                    if (child_yang_name == "local-source-address"):
                        if (self.local_source_address is None):
                            self.local_source_address = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                            self.local_source_address.parent = self
                            self._children_name_map["local_source_address"] = "local-source-address"
                        return self.local_source_address

                    if (child_yang_name == "preferred-path"):
                        if (self.preferred_path is None):
                            self.preferred_path = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                        return self.preferred_path

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "encapsulation-info" or name == "local-source-address" or name == "preferred-path" or name == "pseudowire-class-name" or name == "backup-mac-withdraw" or name == "control-word" or name == "disable-delay" or name == "disable-never" or name == "is-flow-label-static" or name == "load-balance" or name == "preferred-path-disable-fallback" or name == "protocol" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type-cfg" or name == "resync-enabled" or name == "resync-threshold" or name == "sequencing-type" or name == "tag-rewrite" or name == "transport-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "pseudowire-class-name"):
                        self.pseudowire_class_name = value
                        self.pseudowire_class_name.value_namespace = name_space
                        self.pseudowire_class_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "backup-mac-withdraw"):
                        self.backup_mac_withdraw = value
                        self.backup_mac_withdraw.value_namespace = name_space
                        self.backup_mac_withdraw.value_namespace_prefix = name_space_prefix
                    if(value_path == "control-word"):
                        self.control_word = value
                        self.control_word.value_namespace = name_space
                        self.control_word.value_namespace_prefix = name_space_prefix
                    if(value_path == "disable-delay"):
                        self.disable_delay = value
                        self.disable_delay.value_namespace = name_space
                        self.disable_delay.value_namespace_prefix = name_space_prefix
                    if(value_path == "disable-never"):
                        self.disable_never = value
                        self.disable_never.value_namespace = name_space
                        self.disable_never.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-flow-label-static"):
                        self.is_flow_label_static = value
                        self.is_flow_label_static.value_namespace = name_space
                        self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                    if(value_path == "load-balance"):
                        self.load_balance = value
                        self.load_balance.value_namespace = name_space
                        self.load_balance.value_namespace_prefix = name_space_prefix
                    if(value_path == "preferred-path-disable-fallback"):
                        self.preferred_path_disable_fallback = value
                        self.preferred_path_disable_fallback.value_namespace = name_space
                        self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                    if(value_path == "protocol"):
                        self.protocol = value
                        self.protocol.value_namespace = name_space
                        self.protocol.value_namespace_prefix = name_space_prefix
                    if(value_path == "pw-class-name"):
                        self.pw_class_name = value
                        self.pw_class_name.value_namespace = name_space
                        self.pw_class_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "pw-flow-label-code17-disabled"):
                        self.pw_flow_label_code17_disabled = value
                        self.pw_flow_label_code17_disabled.value_namespace = name_space
                        self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "pw-flow-label-type-cfg"):
                        self.pw_flow_label_type_cfg = value
                        self.pw_flow_label_type_cfg.value_namespace = name_space
                        self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                    if(value_path == "resync-enabled"):
                        self.resync_enabled = value
                        self.resync_enabled.value_namespace = name_space
                        self.resync_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "resync-threshold"):
                        self.resync_threshold = value
                        self.resync_threshold.value_namespace = name_space
                        self.resync_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "sequencing-type"):
                        self.sequencing_type = value
                        self.sequencing_type.value_namespace = name_space
                        self.sequencing_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "tag-rewrite"):
                        self.tag_rewrite = value
                        self.tag_rewrite.value_namespace = name_space
                        self.tag_rewrite.value_namespace_prefix = name_space_prefix
                    if(value_path == "transport-mode"):
                        self.transport_mode = value
                        self.transport_mode.value_namespace = name_space
                        self.transport_mode.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.pseudowire_class:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.pseudowire_class:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "pseudowire-classes" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "pseudowire-class"):
                    for c in self.pseudowire_class:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.pseudowire_class.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "pseudowire-class"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class L2VpnCollaborators(Entity):
            """
            L2VPN collaborator information
            
            .. attribute:: collaborator_statistics
            
            	Collaborator Statistics
            	**type**\:   :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.L2VpnCollaborators, self).__init__()

                self.yang_name = "l2vpn-collaborators"
                self.yang_parent_name = "standby"

                self.collaborator_statistics = L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics()
                self.collaborator_statistics.parent = self
                self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
                self._children_yang_names.add("collaborator-statistics")


            class CollaboratorStatistics(Entity):
                """
                Collaborator Statistics
                
                .. attribute:: count
                
                	count
                	**type**\: list of    :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics.Count>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics, self).__init__()

                    self.yang_name = "collaborator-statistics"
                    self.yang_parent_name = "l2vpn-collaborators"

                    self.count = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics, self).__setattr__(name, value)


                class Count(Entity):
                    """
                    count
                    
                    .. attribute:: collaborator_name
                    
                    	Collaborator Name
                    	**type**\:  str
                    
                    .. attribute:: down
                    
                    	Down
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_up
                    
                    	Is up
                    	**type**\:  bool
                    
                    .. attribute:: up
                    
                    	Up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics.Count, self).__init__()

                        self.yang_name = "count"
                        self.yang_parent_name = "collaborator-statistics"

                        self.collaborator_name = YLeaf(YType.str, "collaborator-name")

                        self.down = YLeaf(YType.uint32, "down")

                        self.is_up = YLeaf(YType.boolean, "is-up")

                        self.up = YLeaf(YType.uint32, "up")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("collaborator_name",
                                        "down",
                                        "is_up",
                                        "up") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics.Count, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics.Count, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.collaborator_name.is_set or
                            self.down.is_set or
                            self.is_up.is_set or
                            self.up.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.collaborator_name.yfilter != YFilter.not_set or
                            self.down.yfilter != YFilter.not_set or
                            self.is_up.yfilter != YFilter.not_set or
                            self.up.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "count" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/l2vpn-collaborators/collaborator-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.collaborator_name.is_set or self.collaborator_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.collaborator_name.get_name_leafdata())
                        if (self.down.is_set or self.down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.down.get_name_leafdata())
                        if (self.is_up.is_set or self.is_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_up.get_name_leafdata())
                        if (self.up.is_set or self.up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.up.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "collaborator-name" or name == "down" or name == "is-up" or name == "up"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "collaborator-name"):
                            self.collaborator_name = value
                            self.collaborator_name.value_namespace = name_space
                            self.collaborator_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "down"):
                            self.down = value
                            self.down.value_namespace = name_space
                            self.down.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-up"):
                            self.is_up = value
                            self.is_up.value_namespace = name_space
                            self.is_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "up"):
                            self.up = value
                            self.up.value_namespace = name_space
                            self.up.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.count:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.count:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "collaborator-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/l2vpn-collaborators/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "count"):
                        for c in self.count:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics.Count()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.count.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.collaborator_statistics is not None and self.collaborator_statistics.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.collaborator_statistics is not None and self.collaborator_statistics.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "l2vpn-collaborators" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "collaborator-statistics"):
                    if (self.collaborator_statistics is None):
                        self.collaborator_statistics = L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics()
                        self.collaborator_statistics.parent = self
                        self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
                    return self.collaborator_statistics

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "collaborator-statistics"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Mvrp(Entity):
            """
            MVRP
            
            .. attribute:: mvrp_main_ports
            
            	MVRP Main Port Table
            	**type**\:   :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.Mvrp, self).__init__()

                self.yang_name = "mvrp"
                self.yang_parent_name = "standby"

                self.mvrp_main_ports = L2Vpnv2.Standby.Mvrp.MvrpMainPorts()
                self.mvrp_main_ports.parent = self
                self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
                self._children_yang_names.add("mvrp-main-ports")


            class MvrpMainPorts(Entity):
                """
                MVRP Main Port Table
                
                .. attribute:: mvrp_main_port
                
                	MVRP Main Port
                	**type**\: list of    :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts, self).__init__()

                    self.yang_name = "mvrp-main-ports"
                    self.yang_parent_name = "mvrp"

                    self.mvrp_main_port = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts, self).__setattr__(name, value)


                class MvrpMainPort(Entity):
                    """
                    MVRP Main Port
                    
                    .. attribute:: main_port_interface_name  <key>
                    
                    	Main Port interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mvrp_bridge_ports
                    
                    	MVRP Bridge Port Table
                    	**type**\:   :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                    
                    .. attribute:: mvrp_main_port_info
                    
                    	MVRP Main Port Information
                    	**type**\:   :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort, self).__init__()

                        self.yang_name = "mvrp-main-port"
                        self.yang_parent_name = "mvrp-main-ports"

                        self.main_port_interface_name = YLeaf(YType.str, "main-port-interface-name")

                        self.mvrp_bridge_ports = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                        self.mvrp_bridge_ports.parent = self
                        self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                        self._children_yang_names.add("mvrp-bridge-ports")

                        self.mvrp_main_port_info = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                        self.mvrp_main_port_info.parent = self
                        self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"
                        self._children_yang_names.add("mvrp-main-port-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("main_port_interface_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort, self).__setattr__(name, value)


                    class MvrpMainPortInfo(Entity):
                        """
                        MVRP Main Port Information
                        
                        .. attribute:: default_bridge_port
                        
                        	Trunk or default Bridge Port
                        	**type**\:   :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                        
                        .. attribute:: is_default_encap
                        
                        	Is default encap set
                        	**type**\:  bool
                        
                        .. attribute:: is_trunk
                        
                        	Is main port a trunk
                        	**type**\:  bool
                        
                        .. attribute:: main_port_interface_name
                        
                        	Main Port Interface name
                        	**type**\:  str
                        
                        .. attribute:: number_of_bridge_ports
                        
                        	Number of Bridge Ports
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__init__()

                            self.yang_name = "mvrp-main-port-info"
                            self.yang_parent_name = "mvrp-main-port"

                            self.is_default_encap = YLeaf(YType.boolean, "is-default-encap")

                            self.is_trunk = YLeaf(YType.boolean, "is-trunk")

                            self.main_port_interface_name = YLeaf(YType.str, "main-port-interface-name")

                            self.number_of_bridge_ports = YLeaf(YType.uint32, "number-of-bridge-ports")

                            self.default_bridge_port = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                            self.default_bridge_port.parent = self
                            self._children_name_map["default_bridge_port"] = "default-bridge-port"
                            self._children_yang_names.add("default-bridge-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("is_default_encap",
                                            "is_trunk",
                                            "main_port_interface_name",
                                            "number_of_bridge_ports") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__setattr__(name, value)


                        class DefaultBridgePort(Entity):
                            """
                            Trunk or default Bridge Port
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\:  str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__init__()

                                self.yang_name = "default-bridge-port"
                                self.yang_parent_name = "mvrp-main-port-info"

                                self.bridge_port_interface_name = YLeaf(YType.str, "bridge-port-interface-name")

                                self.bridge_port_xconnect_id = YLeaf(YType.uint32, "bridge-port-xconnect-id")

                                self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                                self.vlan_range = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bridge_port_interface_name",
                                                "bridge_port_xconnect_id",
                                                "mvrp_sequence_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__setattr__(name, value)


                            class VlanRange(Entity):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__init__()

                                    self.yang_name = "vlan-range"
                                    self.yang_parent_name = "default-bridge-port"

                                    self.lower = YLeaf(YType.uint16, "lower")

                                    self.upper = YLeaf(YType.uint16, "upper")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("lower",
                                                    "upper") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.lower.is_set or
                                        self.upper.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.lower.yfilter != YFilter.not_set or
                                        self.upper.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan-range" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lower" or name == "upper"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "lower"):
                                        self.lower = value
                                        self.lower.value_namespace = name_space
                                        self.lower.value_namespace_prefix = name_space_prefix
                                    if(value_path == "upper"):
                                        self.upper = value
                                        self.upper.value_namespace = name_space
                                        self.upper.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vlan_range:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.bridge_port_interface_name.is_set or
                                    self.bridge_port_xconnect_id.is_set or
                                    self.mvrp_sequence_number.is_set)

                            def has_operation(self):
                                for c in self.vlan_range:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bridge_port_interface_name.yfilter != YFilter.not_set or
                                    self.bridge_port_xconnect_id.yfilter != YFilter.not_set or
                                    self.mvrp_sequence_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "default-bridge-port" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bridge_port_interface_name.is_set or self.bridge_port_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_port_interface_name.get_name_leafdata())
                                if (self.bridge_port_xconnect_id.is_set or self.bridge_port_xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_port_xconnect_id.get_name_leafdata())
                                if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vlan-range"):
                                    for c in self.vlan_range:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vlan_range.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vlan-range" or name == "bridge-port-interface-name" or name == "bridge-port-xconnect-id" or name == "mvrp-sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bridge-port-interface-name"):
                                    self.bridge_port_interface_name = value
                                    self.bridge_port_interface_name.value_namespace = name_space
                                    self.bridge_port_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-port-xconnect-id"):
                                    self.bridge_port_xconnect_id = value
                                    self.bridge_port_xconnect_id.value_namespace = name_space
                                    self.bridge_port_xconnect_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvrp-sequence-number"):
                                    self.mvrp_sequence_number = value
                                    self.mvrp_sequence_number.value_namespace = name_space
                                    self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.is_default_encap.is_set or
                                self.is_trunk.is_set or
                                self.main_port_interface_name.is_set or
                                self.number_of_bridge_ports.is_set or
                                (self.default_bridge_port is not None and self.default_bridge_port.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.is_default_encap.yfilter != YFilter.not_set or
                                self.is_trunk.yfilter != YFilter.not_set or
                                self.main_port_interface_name.yfilter != YFilter.not_set or
                                self.number_of_bridge_ports.yfilter != YFilter.not_set or
                                (self.default_bridge_port is not None and self.default_bridge_port.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mvrp-main-port-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_default_encap.is_set or self.is_default_encap.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_default_encap.get_name_leafdata())
                            if (self.is_trunk.is_set or self.is_trunk.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_trunk.get_name_leafdata())
                            if (self.main_port_interface_name.is_set or self.main_port_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_port_interface_name.get_name_leafdata())
                            if (self.number_of_bridge_ports.is_set or self.number_of_bridge_ports.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_bridge_ports.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "default-bridge-port"):
                                if (self.default_bridge_port is None):
                                    self.default_bridge_port = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                                    self.default_bridge_port.parent = self
                                    self._children_name_map["default_bridge_port"] = "default-bridge-port"
                                return self.default_bridge_port

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "default-bridge-port" or name == "is-default-encap" or name == "is-trunk" or name == "main-port-interface-name" or name == "number-of-bridge-ports"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "is-default-encap"):
                                self.is_default_encap = value
                                self.is_default_encap.value_namespace = name_space
                                self.is_default_encap.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-trunk"):
                                self.is_trunk = value
                                self.is_trunk.value_namespace = name_space
                                self.is_trunk.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-port-interface-name"):
                                self.main_port_interface_name = value
                                self.main_port_interface_name.value_namespace = name_space
                                self.main_port_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-bridge-ports"):
                                self.number_of_bridge_ports = value
                                self.number_of_bridge_ports.value_namespace = name_space
                                self.number_of_bridge_ports.value_namespace_prefix = name_space_prefix


                    class MvrpBridgePorts(Entity):
                        """
                        MVRP Bridge Port Table
                        
                        .. attribute:: mvrp_bridge_port
                        
                        	MVRP Bridge Port Information
                        	**type**\: list of    :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__init__()

                            self.yang_name = "mvrp-bridge-ports"
                            self.yang_parent_name = "mvrp-main-port"

                            self.mvrp_bridge_port = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__setattr__(name, value)


                        class MvrpBridgePort(Entity):
                            """
                            MVRP Bridge Port Information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Bridge Port Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\:  str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__init__()

                                self.yang_name = "mvrp-bridge-port"
                                self.yang_parent_name = "mvrp-bridge-ports"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.bridge_port_interface_name = YLeaf(YType.str, "bridge-port-interface-name")

                                self.bridge_port_xconnect_id = YLeaf(YType.uint32, "bridge-port-xconnect-id")

                                self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                                self.vlan_range = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "bridge_port_interface_name",
                                                "bridge_port_xconnect_id",
                                                "mvrp_sequence_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__setattr__(name, value)


                            class VlanRange(Entity):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__init__()

                                    self.yang_name = "vlan-range"
                                    self.yang_parent_name = "mvrp-bridge-port"

                                    self.lower = YLeaf(YType.uint16, "lower")

                                    self.upper = YLeaf(YType.uint16, "upper")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("lower",
                                                    "upper") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.lower.is_set or
                                        self.upper.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.lower.yfilter != YFilter.not_set or
                                        self.upper.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan-range" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lower" or name == "upper"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "lower"):
                                        self.lower = value
                                        self.lower.value_namespace = name_space
                                        self.lower.value_namespace_prefix = name_space_prefix
                                    if(value_path == "upper"):
                                        self.upper = value
                                        self.upper.value_namespace = name_space
                                        self.upper.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vlan_range:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.bridge_port_interface_name.is_set or
                                    self.bridge_port_xconnect_id.is_set or
                                    self.mvrp_sequence_number.is_set)

                            def has_operation(self):
                                for c in self.vlan_range:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.bridge_port_interface_name.yfilter != YFilter.not_set or
                                    self.bridge_port_xconnect_id.yfilter != YFilter.not_set or
                                    self.mvrp_sequence_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mvrp-bridge-port" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.bridge_port_interface_name.is_set or self.bridge_port_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_port_interface_name.get_name_leafdata())
                                if (self.bridge_port_xconnect_id.is_set or self.bridge_port_xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_port_xconnect_id.get_name_leafdata())
                                if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vlan-range"):
                                    for c in self.vlan_range:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vlan_range.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vlan-range" or name == "interface-name" or name == "bridge-port-interface-name" or name == "bridge-port-xconnect-id" or name == "mvrp-sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-port-interface-name"):
                                    self.bridge_port_interface_name = value
                                    self.bridge_port_interface_name.value_namespace = name_space
                                    self.bridge_port_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-port-xconnect-id"):
                                    self.bridge_port_xconnect_id = value
                                    self.bridge_port_xconnect_id.value_namespace = name_space
                                    self.bridge_port_xconnect_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvrp-sequence-number"):
                                    self.mvrp_sequence_number = value
                                    self.mvrp_sequence_number.value_namespace = name_space
                                    self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.mvrp_bridge_port:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.mvrp_bridge_port:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mvrp-bridge-ports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mvrp-bridge-port"):
                                for c in self.mvrp_bridge_port:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.mvrp_bridge_port.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mvrp-bridge-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.main_port_interface_name.is_set or
                            (self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports.has_data()) or
                            (self.mvrp_main_port_info is not None and self.mvrp_main_port_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.main_port_interface_name.yfilter != YFilter.not_set or
                            (self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports.has_operation()) or
                            (self.mvrp_main_port_info is not None and self.mvrp_main_port_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mvrp-main-port" + "[main-port-interface-name='" + self.main_port_interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/mvrp/mvrp-main-ports/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.main_port_interface_name.is_set or self.main_port_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.main_port_interface_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mvrp-bridge-ports"):
                            if (self.mvrp_bridge_ports is None):
                                self.mvrp_bridge_ports = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                                self.mvrp_bridge_ports.parent = self
                                self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                            return self.mvrp_bridge_ports

                        if (child_yang_name == "mvrp-main-port-info"):
                            if (self.mvrp_main_port_info is None):
                                self.mvrp_main_port_info = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                                self.mvrp_main_port_info.parent = self
                                self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"
                            return self.mvrp_main_port_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mvrp-bridge-ports" or name == "mvrp-main-port-info" or name == "main-port-interface-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "main-port-interface-name"):
                            self.main_port_interface_name = value
                            self.main_port_interface_name.value_namespace = name_space
                            self.main_port_interface_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.mvrp_main_port:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.mvrp_main_port:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mvrp-main-ports" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/mvrp/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mvrp-main-port"):
                        for c in self.mvrp_main_port:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.mvrp_main_port.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mvrp-main-port"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.mvrp_main_ports is not None and self.mvrp_main_ports.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.mvrp_main_ports is not None and self.mvrp_main_ports.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mvrp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mvrp-main-ports"):
                    if (self.mvrp_main_ports is None):
                        self.mvrp_main_ports = L2Vpnv2.Standby.Mvrp.MvrpMainPorts()
                        self.mvrp_main_ports.parent = self
                        self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
                    return self.mvrp_main_ports

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mvrp-main-ports"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class GenericInterfaces(Entity):
            """
            L2VPN generic interface list Table
            
            .. attribute:: generic_interface
            
            	Generic Interface List information
            	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaces.GenericInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.GenericInterfaces, self).__init__()

                self.yang_name = "generic-interfaces"
                self.yang_parent_name = "standby"

                self.generic_interface = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.GenericInterfaces, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.GenericInterfaces, self).__setattr__(name, value)


            class GenericInterface(Entity):
                """
                Generic Interface List information
                
                .. attribute:: interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaces.GenericInterface.Interface>`
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_list_name_xr
                
                	Interface\-list name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: items
                
                	Number of items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.GenericInterfaces.GenericInterface, self).__init__()

                    self.yang_name = "generic-interface"
                    self.yang_parent_name = "generic-interfaces"

                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                    self.interface_list_name_xr = YLeaf(YType.str, "interface-list-name-xr")

                    self.items = YLeaf(YType.uint32, "items")

                    self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_list_name",
                                    "interface_list_id",
                                    "interface_list_name_xr",
                                    "items",
                                    "number_of_interfaces") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.GenericInterfaces.GenericInterface, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.GenericInterfaces.GenericInterface, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.GenericInterfaces.GenericInterface.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                        self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                        self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_fib_downloaded",
                                        "not_supported_replications",
                                        "pending_replications") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.is_fib_downloaded.is_set or
                            self.not_supported_replications.is_set or
                            self.pending_replications.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_fib_downloaded.yfilter != YFilter.not_set or
                            self.not_supported_replications.yfilter != YFilter.not_set or
                            self.pending_replications.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                        if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                        if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pending_replications.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-fib-downloaded"):
                            self.is_fib_downloaded = value
                            self.is_fib_downloaded.value_namespace = name_space
                            self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-replications"):
                            self.not_supported_replications = value
                            self.not_supported_replications.value_namespace = name_space
                            self.not_supported_replications.value_namespace_prefix = name_space_prefix
                        if(value_path == "pending-replications"):
                            self.pending_replications = value
                            self.pending_replications.value_namespace = name_space
                            self.pending_replications.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.interface_list_name.is_set or
                        self.interface_list_id.is_set or
                        self.interface_list_name_xr.is_set or
                        self.items.is_set or
                        self.number_of_interfaces.is_set)

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_list_name.yfilter != YFilter.not_set or
                        self.interface_list_id.yfilter != YFilter.not_set or
                        self.interface_list_name_xr.yfilter != YFilter.not_set or
                        self.items.yfilter != YFilter.not_set or
                        self.number_of_interfaces.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-interface" + "[interface-list-name='" + self.interface_list_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/generic-interfaces/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                    if (self.interface_list_name_xr.is_set or self.interface_list_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_name_xr.get_name_leafdata())
                    if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.items.get_name_leafdata())
                    if (self.number_of_interfaces.is_set or self.number_of_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_of_interfaces.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.GenericInterfaces.GenericInterface.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "interface-list-name" or name == "interface-list-id" or name == "interface-list-name-xr" or name == "items" or name == "number-of-interfaces"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-list-name"):
                        self.interface_list_name = value
                        self.interface_list_name.value_namespace = name_space
                        self.interface_list_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-list-id"):
                        self.interface_list_id = value
                        self.interface_list_id.value_namespace = name_space
                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-list-name-xr"):
                        self.interface_list_name_xr = value
                        self.interface_list_name_xr.value_namespace = name_space
                        self.interface_list_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "items"):
                        self.items = value
                        self.items.value_namespace = name_space
                        self.items.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-of-interfaces"):
                        self.number_of_interfaces = value
                        self.number_of_interfaces.value_namespace = name_space
                        self.number_of_interfaces.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.generic_interface:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.generic_interface:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "generic-interfaces" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "generic-interface"):
                    for c in self.generic_interface:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.GenericInterfaces.GenericInterface()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.generic_interface.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class MstpVlans(Entity):
            """
            L2VPN MSTP VLAN Table
            
            .. attribute:: mstp_vlan
            
            	L2VPN MSTP VLAN information
            	**type**\: list of    :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpVlans.MstpVlan>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.MstpVlans, self).__init__()

                self.yang_name = "mstp-vlans"
                self.yang_parent_name = "standby"

                self.mstp_vlan = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.MstpVlans, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.MstpVlans, self).__setattr__(name, value)


            class MstpVlan(Entity):
                """
                L2VPN MSTP VLAN information
                
                .. attribute:: vlan_id  <key>
                
                	vlan id
                	**type**\:  int
                
                	**range:** 0..4098
                
                .. attribute:: msti_id
                
                	MSTI id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_count
                
                	Port Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sub_interface
                
                	Sub interfaces
                	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpVlans.MstpVlan.SubInterface>`
                
                .. attribute:: vlan_id_xr
                
                	Vlan id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.MstpVlans.MstpVlan, self).__init__()

                    self.yang_name = "mstp-vlan"
                    self.yang_parent_name = "mstp-vlans"

                    self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                    self.msti_id = YLeaf(YType.uint32, "msti-id")

                    self.port_count = YLeaf(YType.uint32, "port-count")

                    self.vlan_id_xr = YLeaf(YType.uint32, "vlan-id-xr")

                    self.sub_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vlan_id",
                                    "msti_id",
                                    "port_count",
                                    "vlan_id_xr") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.MstpVlans.MstpVlan, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.MstpVlans.MstpVlan, self).__setattr__(name, value)


                class SubInterface(Entity):
                    """
                    Sub interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.MstpVlans.MstpVlan.SubInterface, self).__init__()

                        self.yang_name = "sub-interface"
                        self.yang_parent_name = "mstp-vlan"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.MstpVlans.MstpVlan.SubInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.MstpVlans.MstpVlan.SubInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return self.interface_name.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sub-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.sub_interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.vlan_id.is_set or
                        self.msti_id.is_set or
                        self.port_count.is_set or
                        self.vlan_id_xr.is_set)

                def has_operation(self):
                    for c in self.sub_interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vlan_id.yfilter != YFilter.not_set or
                        self.msti_id.yfilter != YFilter.not_set or
                        self.port_count.yfilter != YFilter.not_set or
                        self.vlan_id_xr.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mstp-vlan" + "[vlan-id='" + self.vlan_id.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/mstp-vlans/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vlan_id.get_name_leafdata())
                    if (self.msti_id.is_set or self.msti_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.msti_id.get_name_leafdata())
                    if (self.port_count.is_set or self.port_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.port_count.get_name_leafdata())
                    if (self.vlan_id_xr.is_set or self.vlan_id_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vlan_id_xr.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sub-interface"):
                        for c in self.sub_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.MstpVlans.MstpVlan.SubInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.sub_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sub-interface" or name == "vlan-id" or name == "msti-id" or name == "port-count" or name == "vlan-id-xr"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vlan-id"):
                        self.vlan_id = value
                        self.vlan_id.value_namespace = name_space
                        self.vlan_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "msti-id"):
                        self.msti_id = value
                        self.msti_id.value_namespace = name_space
                        self.msti_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "port-count"):
                        self.port_count = value
                        self.port_count.value_namespace = name_space
                        self.port_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "vlan-id-xr"):
                        self.vlan_id_xr = value
                        self.vlan_id_xr.value_namespace = name_space
                        self.vlan_id_xr.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.mstp_vlan:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.mstp_vlan:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mstp-vlans" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mstp-vlan"):
                    for c in self.mstp_vlan:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.MstpVlans.MstpVlan()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.mstp_vlan.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mstp-vlan"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class L2VpnPbbBsa(Entity):
            """
            L2VPN PBB Backbone Source MAC information
            
            .. attribute:: bmac_sa
            
            	BMAC SA
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: chassis_is_provisioned
            
            	Chassis MAC is configured
            	**type**\:  bool
            
            .. attribute:: chassis_mac
            
            	Chassis MAC
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: provisioned
            
            	BMAC SA configured
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.L2VpnPbbBsa, self).__init__()

                self.yang_name = "l2vpn-pbb-bsa"
                self.yang_parent_name = "standby"

                self.bmac_sa = YLeaf(YType.str, "bmac-sa")

                self.chassis_is_provisioned = YLeaf(YType.boolean, "chassis-is-provisioned")

                self.chassis_mac = YLeaf(YType.str, "chassis-mac")

                self.provisioned = YLeaf(YType.boolean, "provisioned")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("bmac_sa",
                                "chassis_is_provisioned",
                                "chassis_mac",
                                "provisioned") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.L2VpnPbbBsa, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.L2VpnPbbBsa, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.bmac_sa.is_set or
                    self.chassis_is_provisioned.is_set or
                    self.chassis_mac.is_set or
                    self.provisioned.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.bmac_sa.yfilter != YFilter.not_set or
                    self.chassis_is_provisioned.yfilter != YFilter.not_set or
                    self.chassis_mac.yfilter != YFilter.not_set or
                    self.provisioned.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "l2vpn-pbb-bsa" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.bmac_sa.is_set or self.bmac_sa.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bmac_sa.get_name_leafdata())
                if (self.chassis_is_provisioned.is_set or self.chassis_is_provisioned.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.chassis_is_provisioned.get_name_leafdata())
                if (self.chassis_mac.is_set or self.chassis_mac.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.chassis_mac.get_name_leafdata())
                if (self.provisioned.is_set or self.provisioned.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.provisioned.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bmac-sa" or name == "chassis-is-provisioned" or name == "chassis-mac" or name == "provisioned"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "bmac-sa"):
                    self.bmac_sa = value
                    self.bmac_sa.value_namespace = name_space
                    self.bmac_sa.value_namespace_prefix = name_space_prefix
                if(value_path == "chassis-is-provisioned"):
                    self.chassis_is_provisioned = value
                    self.chassis_is_provisioned.value_namespace = name_space
                    self.chassis_is_provisioned.value_namespace_prefix = name_space_prefix
                if(value_path == "chassis-mac"):
                    self.chassis_mac = value
                    self.chassis_mac.value_namespace = name_space
                    self.chassis_mac.value_namespace_prefix = name_space_prefix
                if(value_path == "provisioned"):
                    self.provisioned = value
                    self.provisioned.value_namespace = name_space
                    self.provisioned.value_namespace_prefix = name_space_prefix


        class FlexibleXconnectServices(Entity):
            """
            Flexible XConnect Service Table
            
            .. attribute:: flexible_xconnect_service
            
            	Flexible XConnect Service Information
            	**type**\: list of    :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.FlexibleXconnectServices, self).__init__()

                self.yang_name = "flexible-xconnect-services"
                self.yang_parent_name = "standby"

                self.flexible_xconnect_service = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.FlexibleXconnectServices, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.FlexibleXconnectServices, self).__setattr__(name, value)


            class FlexibleXconnectService(Entity):
                """
                Flexible XConnect Service Information
                
                .. attribute:: name  <key>
                
                	Flexible XConnect Service Name
                	**type**\:  str
                
                	**length:** 1..23
                
                .. attribute:: flexible_xconnect_service_acs
                
                	Flexible XConnect Service Attachment Circuit Table
                	**type**\:   :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
                
                .. attribute:: flexible_xconnect_service_info
                
                	Flexible XConnect Service Information
                	**type**\:   :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService, self).__init__()

                    self.yang_name = "flexible-xconnect-service"
                    self.yang_parent_name = "flexible-xconnect-services"

                    self.name = YLeaf(YType.str, "name")

                    self.flexible_xconnect_service_acs = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                    self.flexible_xconnect_service_acs.parent = self
                    self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"
                    self._children_yang_names.add("flexible-xconnect-service-acs")

                    self.flexible_xconnect_service_info = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                    self.flexible_xconnect_service_info.parent = self
                    self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                    self._children_yang_names.add("flexible-xconnect-service-info")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService, self).__setattr__(name, value)


                class FlexibleXconnectServiceAcs(Entity):
                    """
                    Flexible XConnect Service Attachment Circuit
                    Table
                    
                    .. attribute:: flexible_xconnect_service_ac
                    
                    	Flexible XConnect Service Attachment Circuit
                    	**type**\: list of    :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__init__()

                        self.yang_name = "flexible-xconnect-service-acs"
                        self.yang_parent_name = "flexible-xconnect-service"

                        self.flexible_xconnect_service_ac = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__setattr__(name, value)


                    class FlexibleXconnectServiceAc(Entity):
                        """
                        Flexible XConnect Service Attachment Circuit
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: attachment_circuit
                        
                        	Flexible XConnect Service Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__init__()

                            self.yang_name = "flexible-xconnect-service-ac"
                            self.yang_parent_name = "flexible-xconnect-service-acs"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.attachment_circuit = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            self._children_yang_names.add("attachment-circuit")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__setattr__(name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Flexible XConnect Service Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "flexible-xconnect-service-ac"

                                self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                                self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                                self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                                self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                                self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                                self.msti = YLeaf(YType.str, "msti")

                                self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.node_id = YLeaf(YType.str, "node-id")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.interface = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._children_yang_names.add("interface")

                                self.l2vpn_protection = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._children_yang_names.add("l2vpn-protection")

                                self.statistics = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bvi_mac_conflict",
                                                "bvi_no_port_up",
                                                "control_word_mismatched",
                                                "encapsulation_error",
                                                "encapsulation_mismatched",
                                                "evpn_internal_label",
                                                "interface_handle",
                                                "internal_ms_ti",
                                                "interworking",
                                                "is_ac_partially_programmed",
                                                "mac_limit_oper_down",
                                                "ms_ti_mismatch",
                                                "msti",
                                                "msti_mismatch_down",
                                                "mtu_mismatched",
                                                "node_id",
                                                "out_of_memory_state",
                                                "redundancy_group_id",
                                                "redundancy_group_state",
                                                "redundancy_object_id",
                                                "state",
                                                "tdm_media_mismatched",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__setattr__(name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.dispostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class L2VpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.protected_name = YLeaf(YType.str, "protected-name")

                                    self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                    self.protection_name = YLeaf(YType.str, "protection-name")

                                    self.protection_type = YLeaf(YType.enumeration, "protection-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "protected_name",
                                                    "protection_configured",
                                                    "protection_name",
                                                    "protection_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.protected_name.is_set or
                                        self.protection_configured.is_set or
                                        self.protection_name.is_set or
                                        self.protection_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.protected_name.yfilter != YFilter.not_set or
                                        self.protection_configured.yfilter != YFilter.not_set or
                                        self.protection_name.yfilter != YFilter.not_set or
                                        self.protection_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2vpn-protection" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protected_name.get_name_leafdata())
                                    if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                    if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_name.get_name_leafdata())
                                    if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protected-name"):
                                        self.protected_name = value
                                        self.protected_name.value_namespace = name_space
                                        self.protected_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-configured"):
                                        self.protection_configured = value
                                        self.protection_configured.value_namespace = name_space
                                        self.protection_configured.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-name"):
                                        self.protection_name = value
                                        self.protection_name.value_namespace = name_space
                                        self.protection_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-type"):
                                        self.protection_type = value
                                        self.protection_type.value_namespace = name_space
                                        self.protection_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bvi_mac_conflict.is_set or
                                    self.bvi_no_port_up.is_set or
                                    self.control_word_mismatched.is_set or
                                    self.encapsulation_error.is_set or
                                    self.encapsulation_mismatched.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.interface_handle.is_set or
                                    self.internal_ms_ti.is_set or
                                    self.interworking.is_set or
                                    self.is_ac_partially_programmed.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.ms_ti_mismatch.is_set or
                                    self.msti.is_set or
                                    self.msti_mismatch_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.node_id.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_group_state.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.state.is_set or
                                    self.tdm_media_mismatched.is_set or
                                    self.xconnect_id.is_set or
                                    (self.interface is not None and self.interface.has_data()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                    self.bvi_no_port_up.yfilter != YFilter.not_set or
                                    self.control_word_mismatched.yfilter != YFilter.not_set or
                                    self.encapsulation_error.yfilter != YFilter.not_set or
                                    self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.internal_ms_ti.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                    self.msti.yfilter != YFilter.not_set or
                                    self.msti_mismatch_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_group_state.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.interface is not None and self.interface.has_operation()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "attachment-circuit" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                                if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                                if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                                if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                                if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface"):
                                    if (self.interface is None):
                                        self.interface = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                        self.interface.parent = self
                                        self._children_name_map["interface"] = "interface"
                                    return self.interface

                                if (child_yang_name == "l2vpn-protection"):
                                    if (self.l2vpn_protection is None):
                                        self.l2vpn_protection = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                                        self.l2vpn_protection.parent = self
                                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    return self.l2vpn_protection

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bvi-mac-conflict"):
                                    self.bvi_mac_conflict = value
                                    self.bvi_mac_conflict.value_namespace = name_space
                                    self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-no-port-up"):
                                    self.bvi_no_port_up = value
                                    self.bvi_no_port_up.value_namespace = name_space
                                    self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-word-mismatched"):
                                    self.control_word_mismatched = value
                                    self.control_word_mismatched.value_namespace = name_space
                                    self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-error"):
                                    self.encapsulation_error = value
                                    self.encapsulation_error.value_namespace = name_space
                                    self.encapsulation_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-mismatched"):
                                    self.encapsulation_mismatched = value
                                    self.encapsulation_mismatched.value_namespace = name_space
                                    self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-ms-ti"):
                                    self.internal_ms_ti = value
                                    self.internal_ms_ti.value_namespace = name_space
                                    self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ac-partially-programmed"):
                                    self.is_ac_partially_programmed = value
                                    self.is_ac_partially_programmed.value_namespace = name_space
                                    self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ms-ti-mismatch"):
                                    self.ms_ti_mismatch = value
                                    self.ms_ti_mismatch.value_namespace = name_space
                                    self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti"):
                                    self.msti = value
                                    self.msti.value_namespace = name_space
                                    self.msti.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-mismatch-down"):
                                    self.msti_mismatch_down = value
                                    self.msti_mismatch_down.value_namespace = name_space
                                    self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-state"):
                                    self.redundancy_group_state = value
                                    self.redundancy_group_state.value_namespace = name_space
                                    self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "tdm-media-mismatched"):
                                    self.tdm_media_mismatched = value
                                    self.tdm_media_mismatched.value_namespace = name_space
                                    self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "flexible-xconnect-service-ac" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "attachment-circuit"):
                                if (self.attachment_circuit is None):
                                    self.attachment_circuit = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                                    self.attachment_circuit.parent = self
                                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                return self.attachment_circuit

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "attachment-circuit" or name == "interface-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.flexible_xconnect_service_ac:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.flexible_xconnect_service_ac:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flexible-xconnect-service-acs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "flexible-xconnect-service-ac"):
                            for c in self.flexible_xconnect_service_ac:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.flexible_xconnect_service_ac.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flexible-xconnect-service-ac"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class FlexibleXconnectServiceInfo(Entity):
                    """
                    Flexible XConnect Service Information
                    
                    .. attribute:: fxc_id
                    
                    	Flexible XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	Flexible XConnect Service Name
                    	**type**\:  str
                    
                    .. attribute:: num_p_ws
                    
                    	Number of Pseudowires in Pseudowire List
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: pseudowire
                    
                    	Flexible XConnect Service Pseudowire List
                    	**type**\: list of    :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                    
                    .. attribute:: state
                    
                    	State of the Flexible XConnect Service
                    	**type**\:   :py:class:`L2VpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcState>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__init__()

                        self.yang_name = "flexible-xconnect-service-info"
                        self.yang_parent_name = "flexible-xconnect-service"

                        self.fxc_id = YLeaf(YType.uint32, "fxc-id")

                        self.name = YLeaf(YType.str, "name")

                        self.num_p_ws = YLeaf(YType.uint8, "num-p-ws")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.pseudowire = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("fxc_id",
                                        "name",
                                        "num_p_ws",
                                        "state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__setattr__(name, value)


                    class Pseudowire(Entity):
                        """
                        Flexible XConnect Service Pseudowire List
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__init__()

                            self.yang_name = "pseudowire"
                            self.yang_parent_name = "flexible-xconnect-service-info"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudowire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudowire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudowire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudowire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudowire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudowire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudowire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudowire"

                                self.dispostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudowire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudowire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.pseudowire:
                            if (c.has_data()):
                                return True
                        return (
                            self.fxc_id.is_set or
                            self.name.is_set or
                            self.num_p_ws.is_set or
                            self.state.is_set)

                    def has_operation(self):
                        for c in self.pseudowire:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.fxc_id.yfilter != YFilter.not_set or
                            self.name.yfilter != YFilter.not_set or
                            self.num_p_ws.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flexible-xconnect-service-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.fxc_id.is_set or self.fxc_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fxc_id.get_name_leafdata())
                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.name.get_name_leafdata())
                        if (self.num_p_ws.is_set or self.num_p_ws.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_p_ws.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "pseudowire"):
                            for c in self.pseudowire:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.pseudowire.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "pseudowire" or name == "fxc-id" or name == "name" or name == "num-p-ws" or name == "state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "fxc-id"):
                            self.fxc_id = value
                            self.fxc_id.value_namespace = name_space
                            self.fxc_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "name"):
                            self.name = value
                            self.name.value_namespace = name_space
                            self.name.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-p-ws"):
                            self.num_p_ws = value
                            self.num_p_ws.value_namespace = name_space
                            self.num_p_ws.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs.has_data()) or
                        (self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs.has_operation()) or
                        (self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flexible-xconnect-service" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/flexible-xconnect-services/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "flexible-xconnect-service-acs"):
                        if (self.flexible_xconnect_service_acs is None):
                            self.flexible_xconnect_service_acs = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                            self.flexible_xconnect_service_acs.parent = self
                            self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"
                        return self.flexible_xconnect_service_acs

                    if (child_yang_name == "flexible-xconnect-service-info"):
                        if (self.flexible_xconnect_service_info is None):
                            self.flexible_xconnect_service_info = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                            self.flexible_xconnect_service_info.parent = self
                            self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                        return self.flexible_xconnect_service_info

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flexible-xconnect-service-acs" or name == "flexible-xconnect-service-info" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.flexible_xconnect_service:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.flexible_xconnect_service:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "flexible-xconnect-services" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "flexible-xconnect-service"):
                    for c in self.flexible_xconnect_service:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.flexible_xconnect_service.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "flexible-xconnect-service"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class XconnectBrief(Entity):
            """
            XConnect brief information
            
            .. attribute:: encapsulation_report_matrix
            
            	Encapsulation report counters matrix
            	**type**\: list of    :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix>`
            
            .. attribute:: encapsulation_total
            
            	Total summary
            	**type**\: list of    :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectBrief.EncapsulationTotal>`
            
            .. attribute:: main_total_down
            
            	Total Number of non\-active Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_unresolved
            
            	Total Number of unresolved Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_up
            
            	Total Number of active Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: memory_state
            
            	L2VPN memory state
            	**type**\:   :py:class:`L2VpnMemoryState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMemoryState>`
            
            .. attribute:: undefined_xc
            
            	Undefined xc including PW\-PW
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Standby.XconnectBrief, self).__init__()

                self.yang_name = "xconnect-brief"
                self.yang_parent_name = "standby"

                self.main_total_down = YLeaf(YType.uint32, "main-total-down")

                self.main_total_unresolved = YLeaf(YType.uint32, "main-total-unresolved")

                self.main_total_up = YLeaf(YType.uint32, "main-total-up")

                self.memory_state = YLeaf(YType.enumeration, "memory-state")

                self.undefined_xc = YLeaf(YType.uint32, "undefined-xc")

                self.encapsulation_report_matrix = YList(self)
                self.encapsulation_total = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("main_total_down",
                                "main_total_unresolved",
                                "main_total_up",
                                "memory_state",
                                "undefined_xc") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Standby.XconnectBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Standby.XconnectBrief, self).__setattr__(name, value)


            class EncapsulationReportMatrix(Entity):
                """
                Encapsulation report counters matrix
                
                .. attribute:: ac1
                
                	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
                	**type**\: list of    :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix, self).__init__()

                    self.yang_name = "encapsulation-report-matrix"
                    self.yang_parent_name = "xconnect-brief"

                    self.ac1 = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix, self).__setattr__(name, value)


                class Ac1(Entity):
                    """
                    Array of l2vpn\_xc\_brief\_first layer indexed by
                    the AC1 encapsulation type
                    
                    .. attribute:: ac2
                    
                    	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                    	**type**\: list of    :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__init__()

                        self.yang_name = "ac1"
                        self.yang_parent_name = "encapsulation-report-matrix"

                        self.ac2 = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__setattr__(name, value)


                    class Ac2(Entity):
                        """
                        Array of l2vpn\_xc\_brief\_line indexed by the AC2
                        encapsulation type plus one type for PW
                        
                        .. attribute:: ac1_encapsulation
                        
                        	AC1 encapsulation
                        	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                        
                        .. attribute:: ac2_encapsulation
                        
                        	AC2 encapsulation
                        	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                        
                        .. attribute:: down_count
                        
                        	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: psn_type
                        
                        	PSN Type
                        	**type**\:   :py:class:`L2VpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBriefPsn>`
                        
                        .. attribute:: unresolved_count
                        
                        	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: up_count
                        
                        	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__init__()

                            self.yang_name = "ac2"
                            self.yang_parent_name = "ac1"

                            self.ac1_encapsulation = YLeaf(YType.enumeration, "ac1-encapsulation")

                            self.ac2_encapsulation = YLeaf(YType.enumeration, "ac2-encapsulation")

                            self.down_count = YLeafList(YType.uint32, "down-count")

                            self.psn_type = YLeaf(YType.enumeration, "psn-type")

                            self.unresolved_count = YLeafList(YType.uint32, "unresolved-count")

                            self.up_count = YLeafList(YType.uint32, "up-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ac1_encapsulation",
                                            "ac2_encapsulation",
                                            "down_count",
                                            "psn_type",
                                            "unresolved_count",
                                            "up_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.down_count.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.unresolved_count.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.up_count.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.ac1_encapsulation.is_set or
                                self.ac2_encapsulation.is_set or
                                self.psn_type.is_set)

                        def has_operation(self):
                            for leaf in self.down_count.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.unresolved_count.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.up_count.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ac1_encapsulation.yfilter != YFilter.not_set or
                                self.ac2_encapsulation.yfilter != YFilter.not_set or
                                self.down_count.yfilter != YFilter.not_set or
                                self.psn_type.yfilter != YFilter.not_set or
                                self.unresolved_count.yfilter != YFilter.not_set or
                                self.up_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ac2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/encapsulation-report-matrix/ac1/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ac1_encapsulation.is_set or self.ac1_encapsulation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ac1_encapsulation.get_name_leafdata())
                            if (self.ac2_encapsulation.is_set or self.ac2_encapsulation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ac2_encapsulation.get_name_leafdata())
                            if (self.psn_type.is_set or self.psn_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.psn_type.get_name_leafdata())

                            leaf_name_data.extend(self.down_count.get_name_leafdata())

                            leaf_name_data.extend(self.unresolved_count.get_name_leafdata())

                            leaf_name_data.extend(self.up_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac1-encapsulation" or name == "ac2-encapsulation" or name == "down-count" or name == "psn-type" or name == "unresolved-count" or name == "up-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ac1-encapsulation"):
                                self.ac1_encapsulation = value
                                self.ac1_encapsulation.value_namespace = name_space
                                self.ac1_encapsulation.value_namespace_prefix = name_space_prefix
                            if(value_path == "ac2-encapsulation"):
                                self.ac2_encapsulation = value
                                self.ac2_encapsulation.value_namespace = name_space
                                self.ac2_encapsulation.value_namespace_prefix = name_space_prefix
                            if(value_path == "down-count"):
                                self.down_count.append(value)
                            if(value_path == "psn-type"):
                                self.psn_type = value
                                self.psn_type.value_namespace = name_space
                                self.psn_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "unresolved-count"):
                                self.unresolved_count.append(value)
                            if(value_path == "up-count"):
                                self.up_count.append(value)

                    def has_data(self):
                        for c in self.ac2:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ac2:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ac1" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/encapsulation-report-matrix/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ac2"):
                            for c in self.ac2:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ac2.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ac2"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    for c in self.ac1:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ac1:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "encapsulation-report-matrix" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ac1"):
                        for c in self.ac1:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ac1.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ac1"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class EncapsulationTotal(Entity):
                """
                Total summary
                
                .. attribute:: ac1_encapsulation
                
                	AC1 encapsulation
                	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                
                .. attribute:: ac2_encapsulation
                
                	AC2 encapsulation
                	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                
                .. attribute:: down_count
                
                	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: psn_type
                
                	PSN Type
                	**type**\:   :py:class:`L2VpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBriefPsn>`
                
                .. attribute:: unresolved_count
                
                	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Standby.XconnectBrief.EncapsulationTotal, self).__init__()

                    self.yang_name = "encapsulation-total"
                    self.yang_parent_name = "xconnect-brief"

                    self.ac1_encapsulation = YLeaf(YType.enumeration, "ac1-encapsulation")

                    self.ac2_encapsulation = YLeaf(YType.enumeration, "ac2-encapsulation")

                    self.down_count = YLeafList(YType.uint32, "down-count")

                    self.psn_type = YLeaf(YType.enumeration, "psn-type")

                    self.unresolved_count = YLeafList(YType.uint32, "unresolved-count")

                    self.up_count = YLeafList(YType.uint32, "up-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ac1_encapsulation",
                                    "ac2_encapsulation",
                                    "down_count",
                                    "psn_type",
                                    "unresolved_count",
                                    "up_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Standby.XconnectBrief.EncapsulationTotal, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Standby.XconnectBrief.EncapsulationTotal, self).__setattr__(name, value)

                def has_data(self):
                    for leaf in self.down_count.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.unresolved_count.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.up_count.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.ac1_encapsulation.is_set or
                        self.ac2_encapsulation.is_set or
                        self.psn_type.is_set)

                def has_operation(self):
                    for leaf in self.down_count.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.unresolved_count.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.up_count.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ac1_encapsulation.yfilter != YFilter.not_set or
                        self.ac2_encapsulation.yfilter != YFilter.not_set or
                        self.down_count.yfilter != YFilter.not_set or
                        self.psn_type.yfilter != YFilter.not_set or
                        self.unresolved_count.yfilter != YFilter.not_set or
                        self.up_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "encapsulation-total" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ac1_encapsulation.is_set or self.ac1_encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ac1_encapsulation.get_name_leafdata())
                    if (self.ac2_encapsulation.is_set or self.ac2_encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ac2_encapsulation.get_name_leafdata())
                    if (self.psn_type.is_set or self.psn_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.psn_type.get_name_leafdata())

                    leaf_name_data.extend(self.down_count.get_name_leafdata())

                    leaf_name_data.extend(self.unresolved_count.get_name_leafdata())

                    leaf_name_data.extend(self.up_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ac1-encapsulation" or name == "ac2-encapsulation" or name == "down-count" or name == "psn-type" or name == "unresolved-count" or name == "up-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ac1-encapsulation"):
                        self.ac1_encapsulation = value
                        self.ac1_encapsulation.value_namespace = name_space
                        self.ac1_encapsulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "ac2-encapsulation"):
                        self.ac2_encapsulation = value
                        self.ac2_encapsulation.value_namespace = name_space
                        self.ac2_encapsulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "down-count"):
                        self.down_count.append(value)
                    if(value_path == "psn-type"):
                        self.psn_type = value
                        self.psn_type.value_namespace = name_space
                        self.psn_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "unresolved-count"):
                        self.unresolved_count.append(value)
                    if(value_path == "up-count"):
                        self.up_count.append(value)

            def has_data(self):
                for c in self.encapsulation_report_matrix:
                    if (c.has_data()):
                        return True
                for c in self.encapsulation_total:
                    if (c.has_data()):
                        return True
                return (
                    self.main_total_down.is_set or
                    self.main_total_unresolved.is_set or
                    self.main_total_up.is_set or
                    self.memory_state.is_set or
                    self.undefined_xc.is_set)

            def has_operation(self):
                for c in self.encapsulation_report_matrix:
                    if (c.has_operation()):
                        return True
                for c in self.encapsulation_total:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.main_total_down.yfilter != YFilter.not_set or
                    self.main_total_unresolved.yfilter != YFilter.not_set or
                    self.main_total_up.yfilter != YFilter.not_set or
                    self.memory_state.yfilter != YFilter.not_set or
                    self.undefined_xc.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-brief" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.main_total_down.is_set or self.main_total_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.main_total_down.get_name_leafdata())
                if (self.main_total_unresolved.is_set or self.main_total_unresolved.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.main_total_unresolved.get_name_leafdata())
                if (self.main_total_up.is_set or self.main_total_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.main_total_up.get_name_leafdata())
                if (self.memory_state.is_set or self.memory_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.memory_state.get_name_leafdata())
                if (self.undefined_xc.is_set or self.undefined_xc.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.undefined_xc.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "encapsulation-report-matrix"):
                    for c in self.encapsulation_report_matrix:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.encapsulation_report_matrix.append(c)
                    return c

                if (child_yang_name == "encapsulation-total"):
                    for c in self.encapsulation_total:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Standby.XconnectBrief.EncapsulationTotal()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.encapsulation_total.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "encapsulation-report-matrix" or name == "encapsulation-total" or name == "main-total-down" or name == "main-total-unresolved" or name == "main-total-up" or name == "memory-state" or name == "undefined-xc"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "main-total-down"):
                    self.main_total_down = value
                    self.main_total_down.value_namespace = name_space
                    self.main_total_down.value_namespace_prefix = name_space_prefix
                if(value_path == "main-total-unresolved"):
                    self.main_total_unresolved = value
                    self.main_total_unresolved.value_namespace = name_space
                    self.main_total_unresolved.value_namespace_prefix = name_space_prefix
                if(value_path == "main-total-up"):
                    self.main_total_up = value
                    self.main_total_up.value_namespace = name_space
                    self.main_total_up.value_namespace_prefix = name_space_prefix
                if(value_path == "memory-state"):
                    self.memory_state = value
                    self.memory_state.value_namespace = name_space
                    self.memory_state.value_namespace_prefix = name_space_prefix
                if(value_path == "undefined-xc"):
                    self.undefined_xc = value
                    self.undefined_xc.value_namespace = name_space
                    self.undefined_xc.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                (self.bridge_domains is not None and self.bridge_domains.has_data()) or
                (self.bridge_summary is not None and self.bridge_summary.has_data()) or
                (self.discoveries is not None and self.discoveries.has_data()) or
                (self.discovery_summary is not None and self.discovery_summary.has_data()) or
                (self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary.has_data()) or
                (self.flexible_xconnect_services is not None and self.flexible_xconnect_services.has_data()) or
                (self.g8032 is not None and self.g8032.has_data()) or
                (self.generic_interface_list_details is not None and self.generic_interface_list_details.has_data()) or
                (self.generic_interfaces is not None and self.generic_interfaces.has_data()) or
                (self.global_settings is not None and self.global_settings.has_data()) or
                (self.iccp_sm is not None and self.iccp_sm.has_data()) or
                (self.indexes is not None and self.indexes.has_data()) or
                (self.l2vpn_collaborators is not None and self.l2vpn_collaborators.has_data()) or
                (self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa.has_data()) or
                (self.l2vpn_resource_state is not None and self.l2vpn_resource_state.has_data()) or
                (self.main_interfaces is not None and self.main_interfaces.has_data()) or
                (self.mstp_ports is not None and self.mstp_ports.has_data()) or
                (self.mstp_vlans is not None and self.mstp_vlans.has_data()) or
                (self.mvrp is not None and self.mvrp.has_data()) or
                (self.nsr is not None and self.nsr.has_data()) or
                (self.proc_fsm is not None and self.proc_fsm.has_data()) or
                (self.pseudowire_classes is not None and self.pseudowire_classes.has_data()) or
                (self.pwr is not None and self.pwr.has_data()) or
                (self.xconnect_brief is not None and self.xconnect_brief.has_data()) or
                (self.xconnect_groups is not None and self.xconnect_groups.has_data()) or
                (self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces.has_data()) or
                (self.xconnect_mp2mps is not None and self.xconnect_mp2mps.has_data()) or
                (self.xconnect_summary is not None and self.xconnect_summary.has_data()) or
                (self.xconnects is not None and self.xconnects.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.bridge_domains is not None and self.bridge_domains.has_operation()) or
                (self.bridge_summary is not None and self.bridge_summary.has_operation()) or
                (self.discoveries is not None and self.discoveries.has_operation()) or
                (self.discovery_summary is not None and self.discovery_summary.has_operation()) or
                (self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary.has_operation()) or
                (self.flexible_xconnect_services is not None and self.flexible_xconnect_services.has_operation()) or
                (self.g8032 is not None and self.g8032.has_operation()) or
                (self.generic_interface_list_details is not None and self.generic_interface_list_details.has_operation()) or
                (self.generic_interfaces is not None and self.generic_interfaces.has_operation()) or
                (self.global_settings is not None and self.global_settings.has_operation()) or
                (self.iccp_sm is not None and self.iccp_sm.has_operation()) or
                (self.indexes is not None and self.indexes.has_operation()) or
                (self.l2vpn_collaborators is not None and self.l2vpn_collaborators.has_operation()) or
                (self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa.has_operation()) or
                (self.l2vpn_resource_state is not None and self.l2vpn_resource_state.has_operation()) or
                (self.main_interfaces is not None and self.main_interfaces.has_operation()) or
                (self.mstp_ports is not None and self.mstp_ports.has_operation()) or
                (self.mstp_vlans is not None and self.mstp_vlans.has_operation()) or
                (self.mvrp is not None and self.mvrp.has_operation()) or
                (self.nsr is not None and self.nsr.has_operation()) or
                (self.proc_fsm is not None and self.proc_fsm.has_operation()) or
                (self.pseudowire_classes is not None and self.pseudowire_classes.has_operation()) or
                (self.pwr is not None and self.pwr.has_operation()) or
                (self.xconnect_brief is not None and self.xconnect_brief.has_operation()) or
                (self.xconnect_groups is not None and self.xconnect_groups.has_operation()) or
                (self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces.has_operation()) or
                (self.xconnect_mp2mps is not None and self.xconnect_mp2mps.has_operation()) or
                (self.xconnect_summary is not None and self.xconnect_summary.has_operation()) or
                (self.xconnects is not None and self.xconnects.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "standby" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "bridge-domains"):
                if (self.bridge_domains is None):
                    self.bridge_domains = L2Vpnv2.Standby.BridgeDomains()
                    self.bridge_domains.parent = self
                    self._children_name_map["bridge_domains"] = "bridge-domains"
                return self.bridge_domains

            if (child_yang_name == "bridge-summary"):
                if (self.bridge_summary is None):
                    self.bridge_summary = L2Vpnv2.Standby.BridgeSummary()
                    self.bridge_summary.parent = self
                    self._children_name_map["bridge_summary"] = "bridge-summary"
                return self.bridge_summary

            if (child_yang_name == "discoveries"):
                if (self.discoveries is None):
                    self.discoveries = L2Vpnv2.Standby.Discoveries()
                    self.discoveries.parent = self
                    self._children_name_map["discoveries"] = "discoveries"
                return self.discoveries

            if (child_yang_name == "discovery-summary"):
                if (self.discovery_summary is None):
                    self.discovery_summary = L2Vpnv2.Standby.DiscoverySummary()
                    self.discovery_summary.parent = self
                    self._children_name_map["discovery_summary"] = "discovery-summary"
                return self.discovery_summary

            if (child_yang_name == "flexible-xconnect-service-summary"):
                if (self.flexible_xconnect_service_summary is None):
                    self.flexible_xconnect_service_summary = L2Vpnv2.Standby.FlexibleXconnectServiceSummary()
                    self.flexible_xconnect_service_summary.parent = self
                    self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"
                return self.flexible_xconnect_service_summary

            if (child_yang_name == "flexible-xconnect-services"):
                if (self.flexible_xconnect_services is None):
                    self.flexible_xconnect_services = L2Vpnv2.Standby.FlexibleXconnectServices()
                    self.flexible_xconnect_services.parent = self
                    self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"
                return self.flexible_xconnect_services

            if (child_yang_name == "g8032"):
                if (self.g8032 is None):
                    self.g8032 = L2Vpnv2.Standby.G8032()
                    self.g8032.parent = self
                    self._children_name_map["g8032"] = "g8032"
                return self.g8032

            if (child_yang_name == "generic-interface-list-details"):
                if (self.generic_interface_list_details is None):
                    self.generic_interface_list_details = L2Vpnv2.Standby.GenericInterfaceListDetails()
                    self.generic_interface_list_details.parent = self
                    self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"
                return self.generic_interface_list_details

            if (child_yang_name == "generic-interfaces"):
                if (self.generic_interfaces is None):
                    self.generic_interfaces = L2Vpnv2.Standby.GenericInterfaces()
                    self.generic_interfaces.parent = self
                    self._children_name_map["generic_interfaces"] = "generic-interfaces"
                return self.generic_interfaces

            if (child_yang_name == "global-settings"):
                if (self.global_settings is None):
                    self.global_settings = L2Vpnv2.Standby.GlobalSettings()
                    self.global_settings.parent = self
                    self._children_name_map["global_settings"] = "global-settings"
                return self.global_settings

            if (child_yang_name == "iccp-sm"):
                if (self.iccp_sm is None):
                    self.iccp_sm = L2Vpnv2.Standby.IccpSm()
                    self.iccp_sm.parent = self
                    self._children_name_map["iccp_sm"] = "iccp-sm"
                return self.iccp_sm

            if (child_yang_name == "indexes"):
                if (self.indexes is None):
                    self.indexes = L2Vpnv2.Standby.Indexes()
                    self.indexes.parent = self
                    self._children_name_map["indexes"] = "indexes"
                return self.indexes

            if (child_yang_name == "l2vpn-collaborators"):
                if (self.l2vpn_collaborators is None):
                    self.l2vpn_collaborators = L2Vpnv2.Standby.L2VpnCollaborators()
                    self.l2vpn_collaborators.parent = self
                    self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"
                return self.l2vpn_collaborators

            if (child_yang_name == "l2vpn-pbb-bsa"):
                if (self.l2vpn_pbb_bsa is None):
                    self.l2vpn_pbb_bsa = L2Vpnv2.Standby.L2VpnPbbBsa()
                    self.l2vpn_pbb_bsa.parent = self
                    self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"
                return self.l2vpn_pbb_bsa

            if (child_yang_name == "l2vpn-resource-state"):
                if (self.l2vpn_resource_state is None):
                    self.l2vpn_resource_state = L2Vpnv2.Standby.L2VpnResourceState()
                    self.l2vpn_resource_state.parent = self
                    self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"
                return self.l2vpn_resource_state

            if (child_yang_name == "main-interfaces"):
                if (self.main_interfaces is None):
                    self.main_interfaces = L2Vpnv2.Standby.MainInterfaces()
                    self.main_interfaces.parent = self
                    self._children_name_map["main_interfaces"] = "main-interfaces"
                return self.main_interfaces

            if (child_yang_name == "mstp-ports"):
                if (self.mstp_ports is None):
                    self.mstp_ports = L2Vpnv2.Standby.MstpPorts()
                    self.mstp_ports.parent = self
                    self._children_name_map["mstp_ports"] = "mstp-ports"
                return self.mstp_ports

            if (child_yang_name == "mstp-vlans"):
                if (self.mstp_vlans is None):
                    self.mstp_vlans = L2Vpnv2.Standby.MstpVlans()
                    self.mstp_vlans.parent = self
                    self._children_name_map["mstp_vlans"] = "mstp-vlans"
                return self.mstp_vlans

            if (child_yang_name == "mvrp"):
                if (self.mvrp is None):
                    self.mvrp = L2Vpnv2.Standby.Mvrp()
                    self.mvrp.parent = self
                    self._children_name_map["mvrp"] = "mvrp"
                return self.mvrp

            if (child_yang_name == "nsr"):
                if (self.nsr is None):
                    self.nsr = L2Vpnv2.Standby.Nsr()
                    self.nsr.parent = self
                    self._children_name_map["nsr"] = "nsr"
                return self.nsr

            if (child_yang_name == "proc-fsm"):
                if (self.proc_fsm is None):
                    self.proc_fsm = L2Vpnv2.Standby.ProcFsm()
                    self.proc_fsm.parent = self
                    self._children_name_map["proc_fsm"] = "proc-fsm"
                return self.proc_fsm

            if (child_yang_name == "pseudowire-classes"):
                if (self.pseudowire_classes is None):
                    self.pseudowire_classes = L2Vpnv2.Standby.PseudowireClasses()
                    self.pseudowire_classes.parent = self
                    self._children_name_map["pseudowire_classes"] = "pseudowire-classes"
                return self.pseudowire_classes

            if (child_yang_name == "pwr"):
                if (self.pwr is None):
                    self.pwr = L2Vpnv2.Standby.Pwr()
                    self.pwr.parent = self
                    self._children_name_map["pwr"] = "pwr"
                return self.pwr

            if (child_yang_name == "xconnect-brief"):
                if (self.xconnect_brief is None):
                    self.xconnect_brief = L2Vpnv2.Standby.XconnectBrief()
                    self.xconnect_brief.parent = self
                    self._children_name_map["xconnect_brief"] = "xconnect-brief"
                return self.xconnect_brief

            if (child_yang_name == "xconnect-groups"):
                if (self.xconnect_groups is None):
                    self.xconnect_groups = L2Vpnv2.Standby.XconnectGroups()
                    self.xconnect_groups.parent = self
                    self._children_name_map["xconnect_groups"] = "xconnect-groups"
                return self.xconnect_groups

            if (child_yang_name == "xconnect-mp2mp-ce2ces"):
                if (self.xconnect_mp2mp_ce2ces is None):
                    self.xconnect_mp2mp_ce2ces = L2Vpnv2.Standby.XconnectMp2MpCe2Ces()
                    self.xconnect_mp2mp_ce2ces.parent = self
                    self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"
                return self.xconnect_mp2mp_ce2ces

            if (child_yang_name == "xconnect-mp2mps"):
                if (self.xconnect_mp2mps is None):
                    self.xconnect_mp2mps = L2Vpnv2.Standby.XconnectMp2Mps()
                    self.xconnect_mp2mps.parent = self
                    self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"
                return self.xconnect_mp2mps

            if (child_yang_name == "xconnect-summary"):
                if (self.xconnect_summary is None):
                    self.xconnect_summary = L2Vpnv2.Standby.XconnectSummary()
                    self.xconnect_summary.parent = self
                    self._children_name_map["xconnect_summary"] = "xconnect-summary"
                return self.xconnect_summary

            if (child_yang_name == "xconnects"):
                if (self.xconnects is None):
                    self.xconnects = L2Vpnv2.Standby.Xconnects()
                    self.xconnects.parent = self
                    self._children_name_map["xconnects"] = "xconnects"
                return self.xconnects

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bridge-domains" or name == "bridge-summary" or name == "discoveries" or name == "discovery-summary" or name == "flexible-xconnect-service-summary" or name == "flexible-xconnect-services" or name == "g8032" or name == "generic-interface-list-details" or name == "generic-interfaces" or name == "global-settings" or name == "iccp-sm" or name == "indexes" or name == "l2vpn-collaborators" or name == "l2vpn-pbb-bsa" or name == "l2vpn-resource-state" or name == "main-interfaces" or name == "mstp-ports" or name == "mstp-vlans" or name == "mvrp" or name == "nsr" or name == "proc-fsm" or name == "pseudowire-classes" or name == "pwr" or name == "xconnect-brief" or name == "xconnect-groups" or name == "xconnect-mp2mp-ce2ces" or name == "xconnect-mp2mps" or name == "xconnect-summary" or name == "xconnects"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Active(Entity):
        """
        Active L2VPN operational data
        
        .. attribute:: bridge_domains
        
        	VPLS Bridge Domain Information
        	**type**\:   :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains>`
        
        .. attribute:: bridge_summary
        
        	Bridge Domain summary information
        	**type**\:   :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeSummary>`
        
        .. attribute:: discoveries
        
        	Discovery Table
        	**type**\:   :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries>`
        
        .. attribute:: discovery_summary
        
        	Discovery summary information
        	**type**\:   :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.DiscoverySummary>`
        
        .. attribute:: flexible_xconnect_service_summary
        
        	Flexible XConnect Service summary information
        	**type**\:   :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServiceSummary>`
        
        .. attribute:: flexible_xconnect_services
        
        	Flexible XConnect Service Table
        	**type**\:   :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices>`
        
        .. attribute:: g8032
        
        	G8032 information
        	**type**\:   :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032>`
        
        .. attribute:: generic_interface_list_details
        
        	L2VPN generic interface list Detail Table
        	**type**\:   :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails>`
        
        .. attribute:: generic_interfaces
        
        	L2VPN generic interface list Table
        	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaces>`
        
        .. attribute:: global_settings
        
        	L2VPN global settings
        	**type**\:   :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GlobalSettings>`
        
        .. attribute:: iccp_sm
        
        	ICCP\-based Service Multi\-homing operational data
        	**type**\:   :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm>`
        
        .. attribute:: indexes
        
        	ID Manager Index Table
        	**type**\:   :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Indexes>`
        
        .. attribute:: l2vpn_collaborators
        
        	L2VPN collaborator information
        	**type**\:   :py:class:`L2VpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.L2VpnCollaborators>`
        
        .. attribute:: l2vpn_pbb_bsa
        
        	L2VPN PBB Backbone Source MAC information
        	**type**\:   :py:class:`L2VpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.L2VpnPbbBsa>`
        
        .. attribute:: l2vpn_resource_state
        
        	L2VPN resource state information
        	**type**\:   :py:class:`L2VpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.L2VpnResourceState>`
        
        .. attribute:: main_interfaces
        
        	Main Interface
        	**type**\:   :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces>`
        
        .. attribute:: mstp_ports
        
        	L2VPN MSTP Port Table
        	**type**\:   :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpPorts>`
        
        .. attribute:: mstp_vlans
        
        	L2VPN MSTP VLAN Table
        	**type**\:   :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpVlans>`
        
        .. attribute:: mvrp
        
        	MVRP
        	**type**\:   :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp>`
        
        .. attribute:: nsr
        
        	L2VPN NSR information
        	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr>`
        
        .. attribute:: proc_fsm
        
        	L2VPN Process FSM information
        	**type**\:   :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm>`
        
        .. attribute:: pseudowire_classes
        
        	List of pseudowire classes
        	**type**\:   :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses>`
        
        .. attribute:: pwr
        
        	Pseudowire Routing Table
        	**type**\:   :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr>`
        
        .. attribute:: xconnect_brief
        
        	XConnect brief information
        	**type**\:   :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectBrief>`
        
        .. attribute:: xconnect_groups
        
        	XConnect group Table
        	**type**\:   :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectGroups>`
        
        .. attribute:: xconnect_mp2mp_ce2ces
        
        	XConnect MP2MP CE2CE Table
        	**type**\:   :py:class:`XconnectMp2MpCe2Ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2MpCe2Ces>`
        
        .. attribute:: xconnect_mp2mps
        
        	XConnect MP2MP Table
        	**type**\:   :py:class:`XconnectMp2Mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps>`
        
        .. attribute:: xconnect_summary
        
        	XConnect summary information
        	**type**\:   :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectSummary>`
        
        .. attribute:: xconnects
        
        	XConnect Table
        	**type**\:   :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpnv2.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "l2vpnv2"

            self.bridge_domains = L2Vpnv2.Active.BridgeDomains()
            self.bridge_domains.parent = self
            self._children_name_map["bridge_domains"] = "bridge-domains"
            self._children_yang_names.add("bridge-domains")

            self.bridge_summary = L2Vpnv2.Active.BridgeSummary()
            self.bridge_summary.parent = self
            self._children_name_map["bridge_summary"] = "bridge-summary"
            self._children_yang_names.add("bridge-summary")

            self.discoveries = L2Vpnv2.Active.Discoveries()
            self.discoveries.parent = self
            self._children_name_map["discoveries"] = "discoveries"
            self._children_yang_names.add("discoveries")

            self.discovery_summary = L2Vpnv2.Active.DiscoverySummary()
            self.discovery_summary.parent = self
            self._children_name_map["discovery_summary"] = "discovery-summary"
            self._children_yang_names.add("discovery-summary")

            self.flexible_xconnect_service_summary = L2Vpnv2.Active.FlexibleXconnectServiceSummary()
            self.flexible_xconnect_service_summary.parent = self
            self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"
            self._children_yang_names.add("flexible-xconnect-service-summary")

            self.flexible_xconnect_services = L2Vpnv2.Active.FlexibleXconnectServices()
            self.flexible_xconnect_services.parent = self
            self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"
            self._children_yang_names.add("flexible-xconnect-services")

            self.g8032 = L2Vpnv2.Active.G8032()
            self.g8032.parent = self
            self._children_name_map["g8032"] = "g8032"
            self._children_yang_names.add("g8032")

            self.generic_interface_list_details = L2Vpnv2.Active.GenericInterfaceListDetails()
            self.generic_interface_list_details.parent = self
            self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"
            self._children_yang_names.add("generic-interface-list-details")

            self.generic_interfaces = L2Vpnv2.Active.GenericInterfaces()
            self.generic_interfaces.parent = self
            self._children_name_map["generic_interfaces"] = "generic-interfaces"
            self._children_yang_names.add("generic-interfaces")

            self.global_settings = L2Vpnv2.Active.GlobalSettings()
            self.global_settings.parent = self
            self._children_name_map["global_settings"] = "global-settings"
            self._children_yang_names.add("global-settings")

            self.iccp_sm = L2Vpnv2.Active.IccpSm()
            self.iccp_sm.parent = self
            self._children_name_map["iccp_sm"] = "iccp-sm"
            self._children_yang_names.add("iccp-sm")

            self.indexes = L2Vpnv2.Active.Indexes()
            self.indexes.parent = self
            self._children_name_map["indexes"] = "indexes"
            self._children_yang_names.add("indexes")

            self.l2vpn_collaborators = L2Vpnv2.Active.L2VpnCollaborators()
            self.l2vpn_collaborators.parent = self
            self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"
            self._children_yang_names.add("l2vpn-collaborators")

            self.l2vpn_pbb_bsa = L2Vpnv2.Active.L2VpnPbbBsa()
            self.l2vpn_pbb_bsa.parent = self
            self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"
            self._children_yang_names.add("l2vpn-pbb-bsa")

            self.l2vpn_resource_state = L2Vpnv2.Active.L2VpnResourceState()
            self.l2vpn_resource_state.parent = self
            self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"
            self._children_yang_names.add("l2vpn-resource-state")

            self.main_interfaces = L2Vpnv2.Active.MainInterfaces()
            self.main_interfaces.parent = self
            self._children_name_map["main_interfaces"] = "main-interfaces"
            self._children_yang_names.add("main-interfaces")

            self.mstp_ports = L2Vpnv2.Active.MstpPorts()
            self.mstp_ports.parent = self
            self._children_name_map["mstp_ports"] = "mstp-ports"
            self._children_yang_names.add("mstp-ports")

            self.mstp_vlans = L2Vpnv2.Active.MstpVlans()
            self.mstp_vlans.parent = self
            self._children_name_map["mstp_vlans"] = "mstp-vlans"
            self._children_yang_names.add("mstp-vlans")

            self.mvrp = L2Vpnv2.Active.Mvrp()
            self.mvrp.parent = self
            self._children_name_map["mvrp"] = "mvrp"
            self._children_yang_names.add("mvrp")

            self.nsr = L2Vpnv2.Active.Nsr()
            self.nsr.parent = self
            self._children_name_map["nsr"] = "nsr"
            self._children_yang_names.add("nsr")

            self.proc_fsm = L2Vpnv2.Active.ProcFsm()
            self.proc_fsm.parent = self
            self._children_name_map["proc_fsm"] = "proc-fsm"
            self._children_yang_names.add("proc-fsm")

            self.pseudowire_classes = L2Vpnv2.Active.PseudowireClasses()
            self.pseudowire_classes.parent = self
            self._children_name_map["pseudowire_classes"] = "pseudowire-classes"
            self._children_yang_names.add("pseudowire-classes")

            self.pwr = L2Vpnv2.Active.Pwr()
            self.pwr.parent = self
            self._children_name_map["pwr"] = "pwr"
            self._children_yang_names.add("pwr")

            self.xconnect_brief = L2Vpnv2.Active.XconnectBrief()
            self.xconnect_brief.parent = self
            self._children_name_map["xconnect_brief"] = "xconnect-brief"
            self._children_yang_names.add("xconnect-brief")

            self.xconnect_groups = L2Vpnv2.Active.XconnectGroups()
            self.xconnect_groups.parent = self
            self._children_name_map["xconnect_groups"] = "xconnect-groups"
            self._children_yang_names.add("xconnect-groups")

            self.xconnect_mp2mp_ce2ces = L2Vpnv2.Active.XconnectMp2MpCe2Ces()
            self.xconnect_mp2mp_ce2ces.parent = self
            self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"
            self._children_yang_names.add("xconnect-mp2mp-ce2ces")

            self.xconnect_mp2mps = L2Vpnv2.Active.XconnectMp2Mps()
            self.xconnect_mp2mps.parent = self
            self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"
            self._children_yang_names.add("xconnect-mp2mps")

            self.xconnect_summary = L2Vpnv2.Active.XconnectSummary()
            self.xconnect_summary.parent = self
            self._children_name_map["xconnect_summary"] = "xconnect-summary"
            self._children_yang_names.add("xconnect-summary")

            self.xconnects = L2Vpnv2.Active.Xconnects()
            self.xconnects.parent = self
            self._children_name_map["xconnects"] = "xconnects"
            self._children_yang_names.add("xconnects")


        class Discoveries(Entity):
            """
            Discovery Table
            
            .. attribute:: discovery
            
            	VPLS Discovery information
            	**type**\: list of    :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.Discoveries, self).__init__()

                self.yang_name = "discoveries"
                self.yang_parent_name = "active"

                self.discovery = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.Discoveries, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.Discoveries, self).__setattr__(name, value)


            class Discovery(Entity):
                """
                VPLS Discovery information
                
                .. attribute:: group_name
                
                	Group Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: is_service_connected
                
                	Is the service connected
                	**type**\:  bool
                
                .. attribute:: mtu_mismatch_ignore
                
                	Ignore MTU Mismatch
                	**type**\:  bool
                
                .. attribute:: number_vpn
                
                	Number of vpns
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: service_name
                
                	Service type
                	**type**\:   :py:class:`L2VpnService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnService>`
                
                .. attribute:: service_name_xr
                
                	Service Type
                	**type**\:  str
                
                .. attribute:: signalling_info
                
                	Info about signalling protocol
                	**type**\:   :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo>`
                
                .. attribute:: vpn_id
                
                	VPN id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_name
                
                	VPN Name
                	**type**\:  str
                
                	**length:** 1..27
                
                .. attribute:: vpn_name_xr
                
                	VPN instance name
                	**type**\:  str
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Discoveries.Discovery, self).__init__()

                    self.yang_name = "discovery"
                    self.yang_parent_name = "discoveries"

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                    self.is_service_connected = YLeaf(YType.boolean, "is-service-connected")

                    self.mtu_mismatch_ignore = YLeaf(YType.boolean, "mtu-mismatch-ignore")

                    self.number_vpn = YLeaf(YType.uint32, "number-vpn")

                    self.service_name = YLeaf(YType.enumeration, "service-name")

                    self.service_name_xr = YLeaf(YType.str, "service-name-xr")

                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                    self.vpn_name = YLeaf(YType.str, "vpn-name")

                    self.vpn_name_xr = YLeaf(YType.str, "vpn-name-xr")

                    self.signalling_info = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo()
                    self.signalling_info.parent = self
                    self._children_name_map["signalling_info"] = "signalling-info"
                    self._children_yang_names.add("signalling-info")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_name",
                                    "group_name_xr",
                                    "is_service_connected",
                                    "mtu_mismatch_ignore",
                                    "number_vpn",
                                    "service_name",
                                    "service_name_xr",
                                    "vpn_id",
                                    "vpn_name",
                                    "vpn_name_xr") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Discoveries.Discovery, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Discoveries.Discovery, self).__setattr__(name, value)


                class SignallingInfo(Entity):
                    """
                    Info about signalling protocol
                    
                    .. attribute:: ad_signalling_method
                    
                    	ADSignallingMethod
                    	**type**\:   :py:class:`L2VpnAdSigMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdSigMethod>`
                    
                    .. attribute:: bgp_sig_info
                    
                    	bgp sig info
                    	**type**\:   :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                    
                    .. attribute:: ldp_sig_info
                    
                    	ldp sig info
                    	**type**\:   :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo, self).__init__()

                        self.yang_name = "signalling-info"
                        self.yang_parent_name = "discovery"

                        self.ad_signalling_method = YLeaf(YType.enumeration, "ad-signalling-method")

                        self.bgp_sig_info = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                        self.bgp_sig_info.parent = self
                        self._children_name_map["bgp_sig_info"] = "bgp-sig-info"
                        self._children_yang_names.add("bgp-sig-info")

                        self.ldp_sig_info = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                        self.ldp_sig_info.parent = self
                        self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                        self._children_yang_names.add("ldp-sig-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ad_signalling_method") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo, self).__setattr__(name, value)


                    class BgpSigInfo(Entity):
                        """
                        bgp sig info
                        
                        .. attribute:: edge
                        
                        	List of edge ids
                        	**type**\: list of    :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                        
                        .. attribute:: number_edges
                        
                        	Number of Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redge
                        
                        	List of edge ids
                        	**type**\: list of    :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__init__()

                            self.yang_name = "bgp-sig-info"
                            self.yang_parent_name = "signalling-info"

                            self.number_edges = YLeaf(YType.uint32, "number-edges")

                            self.number_remote_edges = YLeaf(YType.uint32, "number-remote-edges")

                            self.edge = YList(self)
                            self.redge = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("number_edges",
                                            "number_remote_edges") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__setattr__(name, value)


                        class Edge(Entity):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__init__()

                                self.yang_name = "edge"
                                self.yang_parent_name = "bgp-sig-info"

                                self.edge_id = YLeaf(YType.uint32, "edge-id")

                                self.label_count = YLeaf(YType.uint32, "label-count")

                                self.label_block = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("edge_id",
                                                "label_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__setattr__(name, value)


                            class LabelBlock(Entity):
                                """
                                List of label blocks
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:   :py:class:`L2VpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErr>`
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\:  list of int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__init__()

                                    self.yang_name = "label-block"
                                    self.yang_parent_name = "edge"

                                    self.block_offset = YLeaf(YType.uint32, "block-offset")

                                    self.block_size = YLeaf(YType.uint32, "block-size")

                                    self.label_base = YLeaf(YType.uint32, "label-base")

                                    self.label_error = YLeaf(YType.enumeration, "label-error")

                                    self.label_time_created = YLeaf(YType.uint32, "label-time-created")

                                    self.local_edge_id = YLeaf(YType.uint32, "local-edge-id")

                                    self.next_hop = YLeaf(YType.str, "next-hop")

                                    self.status_vector = YLeafList(YType.uint8, "status-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("block_offset",
                                                    "block_size",
                                                    "label_base",
                                                    "label_error",
                                                    "label_time_created",
                                                    "local_edge_id",
                                                    "next_hop",
                                                    "status_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__setattr__(name, value)

                                def has_data(self):
                                    for leaf in self.status_vector.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.block_offset.is_set or
                                        self.block_size.is_set or
                                        self.label_base.is_set or
                                        self.label_error.is_set or
                                        self.label_time_created.is_set or
                                        self.local_edge_id.is_set or
                                        self.next_hop.is_set)

                                def has_operation(self):
                                    for leaf in self.status_vector.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.block_offset.yfilter != YFilter.not_set or
                                        self.block_size.yfilter != YFilter.not_set or
                                        self.label_base.yfilter != YFilter.not_set or
                                        self.label_error.yfilter != YFilter.not_set or
                                        self.label_time_created.yfilter != YFilter.not_set or
                                        self.local_edge_id.yfilter != YFilter.not_set or
                                        self.next_hop.yfilter != YFilter.not_set or
                                        self.status_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "label-block" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/bgp-sig-info/edge/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.block_offset.is_set or self.block_offset.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.block_offset.get_name_leafdata())
                                    if (self.block_size.is_set or self.block_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.block_size.get_name_leafdata())
                                    if (self.label_base.is_set or self.label_base.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_base.get_name_leafdata())
                                    if (self.label_error.is_set or self.label_error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_error.get_name_leafdata())
                                    if (self.label_time_created.is_set or self.label_time_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_time_created.get_name_leafdata())
                                    if (self.local_edge_id.is_set or self.local_edge_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_edge_id.get_name_leafdata())
                                    if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop.get_name_leafdata())

                                    leaf_name_data.extend(self.status_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "block-offset" or name == "block-size" or name == "label-base" or name == "label-error" or name == "label-time-created" or name == "local-edge-id" or name == "next-hop" or name == "status-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "block-offset"):
                                        self.block_offset = value
                                        self.block_offset.value_namespace = name_space
                                        self.block_offset.value_namespace_prefix = name_space_prefix
                                    if(value_path == "block-size"):
                                        self.block_size = value
                                        self.block_size.value_namespace = name_space
                                        self.block_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-base"):
                                        self.label_base = value
                                        self.label_base.value_namespace = name_space
                                        self.label_base.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-error"):
                                        self.label_error = value
                                        self.label_error.value_namespace = name_space
                                        self.label_error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-time-created"):
                                        self.label_time_created = value
                                        self.label_time_created.value_namespace = name_space
                                        self.label_time_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-edge-id"):
                                        self.local_edge_id = value
                                        self.local_edge_id.value_namespace = name_space
                                        self.local_edge_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop"):
                                        self.next_hop = value
                                        self.next_hop.value_namespace = name_space
                                        self.next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "status-vector"):
                                        self.status_vector.append(value)

                            def has_data(self):
                                for c in self.label_block:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.edge_id.is_set or
                                    self.label_count.is_set)

                            def has_operation(self):
                                for c in self.label_block:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.edge_id.yfilter != YFilter.not_set or
                                    self.label_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "edge" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/bgp-sig-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.edge_id.is_set or self.edge_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.edge_id.get_name_leafdata())
                                if (self.label_count.is_set or self.label_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "label-block"):
                                    for c in self.label_block:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.label_block.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "label-block" or name == "edge-id" or name == "label-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "edge-id"):
                                    self.edge_id = value
                                    self.edge_id.value_namespace = name_space
                                    self.edge_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "label-count"):
                                    self.label_count = value
                                    self.label_count.value_namespace = name_space
                                    self.label_count.value_namespace_prefix = name_space_prefix


                        class Redge(Entity):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__init__()

                                self.yang_name = "redge"
                                self.yang_parent_name = "bgp-sig-info"

                                self.edge_id = YLeaf(YType.uint32, "edge-id")

                                self.label_count = YLeaf(YType.uint32, "label-count")

                                self.label_block = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("edge_id",
                                                "label_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__setattr__(name, value)


                            class LabelBlock(Entity):
                                """
                                List of label blocks
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:   :py:class:`L2VpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErr>`
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\:  list of int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__init__()

                                    self.yang_name = "label-block"
                                    self.yang_parent_name = "redge"

                                    self.block_offset = YLeaf(YType.uint32, "block-offset")

                                    self.block_size = YLeaf(YType.uint32, "block-size")

                                    self.label_base = YLeaf(YType.uint32, "label-base")

                                    self.label_error = YLeaf(YType.enumeration, "label-error")

                                    self.label_time_created = YLeaf(YType.uint32, "label-time-created")

                                    self.local_edge_id = YLeaf(YType.uint32, "local-edge-id")

                                    self.next_hop = YLeaf(YType.str, "next-hop")

                                    self.status_vector = YLeafList(YType.uint8, "status-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("block_offset",
                                                    "block_size",
                                                    "label_base",
                                                    "label_error",
                                                    "label_time_created",
                                                    "local_edge_id",
                                                    "next_hop",
                                                    "status_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__setattr__(name, value)

                                def has_data(self):
                                    for leaf in self.status_vector.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.block_offset.is_set or
                                        self.block_size.is_set or
                                        self.label_base.is_set or
                                        self.label_error.is_set or
                                        self.label_time_created.is_set or
                                        self.local_edge_id.is_set or
                                        self.next_hop.is_set)

                                def has_operation(self):
                                    for leaf in self.status_vector.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.block_offset.yfilter != YFilter.not_set or
                                        self.block_size.yfilter != YFilter.not_set or
                                        self.label_base.yfilter != YFilter.not_set or
                                        self.label_error.yfilter != YFilter.not_set or
                                        self.label_time_created.yfilter != YFilter.not_set or
                                        self.local_edge_id.yfilter != YFilter.not_set or
                                        self.next_hop.yfilter != YFilter.not_set or
                                        self.status_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "label-block" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/bgp-sig-info/redge/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.block_offset.is_set or self.block_offset.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.block_offset.get_name_leafdata())
                                    if (self.block_size.is_set or self.block_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.block_size.get_name_leafdata())
                                    if (self.label_base.is_set or self.label_base.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_base.get_name_leafdata())
                                    if (self.label_error.is_set or self.label_error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_error.get_name_leafdata())
                                    if (self.label_time_created.is_set or self.label_time_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_time_created.get_name_leafdata())
                                    if (self.local_edge_id.is_set or self.local_edge_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_edge_id.get_name_leafdata())
                                    if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop.get_name_leafdata())

                                    leaf_name_data.extend(self.status_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "block-offset" or name == "block-size" or name == "label-base" or name == "label-error" or name == "label-time-created" or name == "local-edge-id" or name == "next-hop" or name == "status-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "block-offset"):
                                        self.block_offset = value
                                        self.block_offset.value_namespace = name_space
                                        self.block_offset.value_namespace_prefix = name_space_prefix
                                    if(value_path == "block-size"):
                                        self.block_size = value
                                        self.block_size.value_namespace = name_space
                                        self.block_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-base"):
                                        self.label_base = value
                                        self.label_base.value_namespace = name_space
                                        self.label_base.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-error"):
                                        self.label_error = value
                                        self.label_error.value_namespace = name_space
                                        self.label_error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-time-created"):
                                        self.label_time_created = value
                                        self.label_time_created.value_namespace = name_space
                                        self.label_time_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-edge-id"):
                                        self.local_edge_id = value
                                        self.local_edge_id.value_namespace = name_space
                                        self.local_edge_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop"):
                                        self.next_hop = value
                                        self.next_hop.value_namespace = name_space
                                        self.next_hop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "status-vector"):
                                        self.status_vector.append(value)

                            def has_data(self):
                                for c in self.label_block:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.edge_id.is_set or
                                    self.label_count.is_set)

                            def has_operation(self):
                                for c in self.label_block:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.edge_id.yfilter != YFilter.not_set or
                                    self.label_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redge" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/bgp-sig-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.edge_id.is_set or self.edge_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.edge_id.get_name_leafdata())
                                if (self.label_count.is_set or self.label_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "label-block"):
                                    for c in self.label_block:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.label_block.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "label-block" or name == "edge-id" or name == "label-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "edge-id"):
                                    self.edge_id = value
                                    self.edge_id.value_namespace = name_space
                                    self.edge_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "label-count"):
                                    self.label_count = value
                                    self.label_count.value_namespace = name_space
                                    self.label_count.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.edge:
                                if (c.has_data()):
                                    return True
                            for c in self.redge:
                                if (c.has_data()):
                                    return True
                            return (
                                self.number_edges.is_set or
                                self.number_remote_edges.is_set)

                        def has_operation(self):
                            for c in self.edge:
                                if (c.has_operation()):
                                    return True
                            for c in self.redge:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.number_edges.yfilter != YFilter.not_set or
                                self.number_remote_edges.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bgp-sig-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.number_edges.is_set or self.number_edges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_edges.get_name_leafdata())
                            if (self.number_remote_edges.is_set or self.number_remote_edges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_remote_edges.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "edge"):
                                for c in self.edge:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.edge.append(c)
                                return c

                            if (child_yang_name == "redge"):
                                for c in self.redge:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.redge.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "edge" or name == "redge" or name == "number-edges" or name == "number-remote-edges"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "number-edges"):
                                self.number_edges = value
                                self.number_edges.value_namespace = name_space
                                self.number_edges.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-remote-edges"):
                                self.number_remote_edges = value
                                self.number_remote_edges.value_namespace = name_space
                                self.number_remote_edges.value_namespace_prefix = name_space_prefix


                    class LdpSigInfo(Entity):
                        """
                        ldp sig info
                        
                        .. attribute:: local_l2_router_id
                        
                        	Local L2VPN Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_vpls_id
                        
                        	Local VPLS\-ID
                        	**type**\:   :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_nlri
                        
                        	List of NLRIs
                        	**type**\: list of    :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__init__()

                            self.yang_name = "ldp-sig-info"
                            self.yang_parent_name = "signalling-info"

                            self.local_l2_router_id = YLeaf(YType.str, "local-l2-router-id")

                            self.number_remote_edges = YLeaf(YType.uint32, "number-remote-edges")

                            self.local_vpls_id = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                            self.local_vpls_id.parent = self
                            self._children_name_map["local_vpls_id"] = "local-vpls-id"
                            self._children_yang_names.add("local-vpls-id")

                            self.remote_nlri = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("local_l2_router_id",
                                            "number_remote_edges") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__setattr__(name, value)


                        class LocalVplsId(Entity):
                            """
                            Local VPLS\-ID
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                            
                            .. attribute:: vpls_id_type
                            
                            	VPLS ID TYPE
                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__init__()

                                self.yang_name = "local-vpls-id"
                                self.yang_parent_name = "ldp-sig-info"

                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                self.auto = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                                self._children_yang_names.add("auto")

                                self.two_byte_as = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("vpls_id_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__setattr__(name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: asn
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpn_id
                                
                                	VPN ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "local-vpls-id"

                                    self.asn = YLeaf(YType.uint16, "asn")

                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("asn",
                                                    "vpn_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.asn.is_set or
                                        self.vpn_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.asn.yfilter != YFilter.not_set or
                                        self.vpn_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "auto" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "asn" or name == "vpn-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "asn"):
                                        self.asn = value
                                        self.asn.value_namespace = name_space
                                        self.asn.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpn-id"):
                                        self.vpn_id = value
                                        self.vpn_id.value_namespace = name_space
                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "local-vpls-id"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "local-vpls-id"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.vpls_id_type.is_set or
                                    (self.auto is not None and self.auto.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                    (self.auto is not None and self.auto.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-vpls-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/ldp-sig-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "auto"):
                                    if (self.auto is None):
                                        self.auto = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                    return self.auto

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "vpls-id-type"):
                                    self.vpls_id_type = value
                                    self.vpls_id_type.value_namespace = name_space
                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                        class RemoteNlri(Entity):
                            """
                            List of NLRIs
                            
                            .. attribute:: local_address
                            
                            	Local BGP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nlri_time_created
                            
                            	NLRI creation time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote BGP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_l2_router_id
                            
                            	Remote L2VPN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__init__()

                                self.yang_name = "remote-nlri"
                                self.yang_parent_name = "ldp-sig-info"

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.nlri_time_created = YLeaf(YType.uint32, "nlri-time-created")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                                self.remote_l2_router_id = YLeaf(YType.str, "remote-l2-router-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_address",
                                                "nlri_time_created",
                                                "remote_address",
                                                "remote_l2_router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_address.is_set or
                                    self.nlri_time_created.is_set or
                                    self.remote_address.is_set or
                                    self.remote_l2_router_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.nlri_time_created.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set or
                                    self.remote_l2_router_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-nlri" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/ldp-sig-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.nlri_time_created.is_set or self.nlri_time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nlri_time_created.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())
                                if (self.remote_l2_router_id.is_set or self.remote_l2_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_l2_router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-address" or name == "nlri-time-created" or name == "remote-address" or name == "remote-l2-router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "nlri-time-created"):
                                    self.nlri_time_created = value
                                    self.nlri_time_created.value_namespace = name_space
                                    self.nlri_time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-l2-router-id"):
                                    self.remote_l2_router_id = value
                                    self.remote_l2_router_id.value_namespace = name_space
                                    self.remote_l2_router_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.remote_nlri:
                                if (c.has_data()):
                                    return True
                            return (
                                self.local_l2_router_id.is_set or
                                self.number_remote_edges.is_set or
                                (self.local_vpls_id is not None and self.local_vpls_id.has_data()))

                        def has_operation(self):
                            for c in self.remote_nlri:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.local_l2_router_id.yfilter != YFilter.not_set or
                                self.number_remote_edges.yfilter != YFilter.not_set or
                                (self.local_vpls_id is not None and self.local_vpls_id.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ldp-sig-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.local_l2_router_id.is_set or self.local_l2_router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_l2_router_id.get_name_leafdata())
                            if (self.number_remote_edges.is_set or self.number_remote_edges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_remote_edges.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "local-vpls-id"):
                                if (self.local_vpls_id is None):
                                    self.local_vpls_id = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                                    self.local_vpls_id.parent = self
                                    self._children_name_map["local_vpls_id"] = "local-vpls-id"
                                return self.local_vpls_id

                            if (child_yang_name == "remote-nlri"):
                                for c in self.remote_nlri:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.remote_nlri.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-vpls-id" or name == "remote-nlri" or name == "local-l2-router-id" or name == "number-remote-edges"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "local-l2-router-id"):
                                self.local_l2_router_id = value
                                self.local_l2_router_id.value_namespace = name_space
                                self.local_l2_router_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-remote-edges"):
                                self.number_remote_edges = value
                                self.number_remote_edges.value_namespace = name_space
                                self.number_remote_edges.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ad_signalling_method.is_set or
                            (self.bgp_sig_info is not None and self.bgp_sig_info.has_data()) or
                            (self.ldp_sig_info is not None and self.ldp_sig_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ad_signalling_method.yfilter != YFilter.not_set or
                            (self.bgp_sig_info is not None and self.bgp_sig_info.has_operation()) or
                            (self.ldp_sig_info is not None and self.ldp_sig_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "signalling-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bgp-sig-info"):
                            if (self.bgp_sig_info is None):
                                self.bgp_sig_info = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                                self.bgp_sig_info.parent = self
                                self._children_name_map["bgp_sig_info"] = "bgp-sig-info"
                            return self.bgp_sig_info

                        if (child_yang_name == "ldp-sig-info"):
                            if (self.ldp_sig_info is None):
                                self.ldp_sig_info = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                                self.ldp_sig_info.parent = self
                                self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                            return self.ldp_sig_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bgp-sig-info" or name == "ldp-sig-info" or name == "ad-signalling-method"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ad-signalling-method"):
                            self.ad_signalling_method = value
                            self.ad_signalling_method.value_namespace = name_space
                            self.ad_signalling_method.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.group_name.is_set or
                        self.group_name_xr.is_set or
                        self.is_service_connected.is_set or
                        self.mtu_mismatch_ignore.is_set or
                        self.number_vpn.is_set or
                        self.service_name.is_set or
                        self.service_name_xr.is_set or
                        self.vpn_id.is_set or
                        self.vpn_name.is_set or
                        self.vpn_name_xr.is_set or
                        (self.signalling_info is not None and self.signalling_info.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.group_name_xr.yfilter != YFilter.not_set or
                        self.is_service_connected.yfilter != YFilter.not_set or
                        self.mtu_mismatch_ignore.yfilter != YFilter.not_set or
                        self.number_vpn.yfilter != YFilter.not_set or
                        self.service_name.yfilter != YFilter.not_set or
                        self.service_name_xr.yfilter != YFilter.not_set or
                        self.vpn_id.yfilter != YFilter.not_set or
                        self.vpn_name.yfilter != YFilter.not_set or
                        self.vpn_name_xr.yfilter != YFilter.not_set or
                        (self.signalling_info is not None and self.signalling_info.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "discovery" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                    if (self.is_service_connected.is_set or self.is_service_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_service_connected.get_name_leafdata())
                    if (self.mtu_mismatch_ignore.is_set or self.mtu_mismatch_ignore.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mtu_mismatch_ignore.get_name_leafdata())
                    if (self.number_vpn.is_set or self.number_vpn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_vpn.get_name_leafdata())
                    if (self.service_name.is_set or self.service_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.service_name.get_name_leafdata())
                    if (self.service_name_xr.is_set or self.service_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.service_name_xr.get_name_leafdata())
                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_id.get_name_leafdata())
                    if (self.vpn_name.is_set or self.vpn_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_name.get_name_leafdata())
                    if (self.vpn_name_xr.is_set or self.vpn_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_name_xr.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "signalling-info"):
                        if (self.signalling_info is None):
                            self.signalling_info = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo()
                            self.signalling_info.parent = self
                            self._children_name_map["signalling_info"] = "signalling-info"
                        return self.signalling_info

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "signalling-info" or name == "group-name" or name == "group-name-xr" or name == "is-service-connected" or name == "mtu-mismatch-ignore" or name == "number-vpn" or name == "service-name" or name == "service-name-xr" or name == "vpn-id" or name == "vpn-name" or name == "vpn-name-xr"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name-xr"):
                        self.group_name_xr = value
                        self.group_name_xr.value_namespace = name_space
                        self.group_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-service-connected"):
                        self.is_service_connected = value
                        self.is_service_connected.value_namespace = name_space
                        self.is_service_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "mtu-mismatch-ignore"):
                        self.mtu_mismatch_ignore = value
                        self.mtu_mismatch_ignore.value_namespace = name_space
                        self.mtu_mismatch_ignore.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-vpn"):
                        self.number_vpn = value
                        self.number_vpn.value_namespace = name_space
                        self.number_vpn.value_namespace_prefix = name_space_prefix
                    if(value_path == "service-name"):
                        self.service_name = value
                        self.service_name.value_namespace = name_space
                        self.service_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "service-name-xr"):
                        self.service_name_xr = value
                        self.service_name_xr.value_namespace = name_space
                        self.service_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-id"):
                        self.vpn_id = value
                        self.vpn_id.value_namespace = name_space
                        self.vpn_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-name"):
                        self.vpn_name = value
                        self.vpn_name.value_namespace = name_space
                        self.vpn_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-name-xr"):
                        self.vpn_name_xr = value
                        self.vpn_name_xr.value_namespace = name_space
                        self.vpn_name_xr.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.discovery:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.discovery:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "discoveries" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "discovery"):
                    for c in self.discovery:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.Discoveries.Discovery()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.discovery.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "discovery"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class FlexibleXconnectServiceSummary(Entity):
            """
            Flexible XConnect Service summary information
            
            .. attribute:: number_fxc
            
            	Number of flexible xconnect services
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_down
            
            	Number of flexible xconnect services whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_up
            
            	Number of flexible xconnect services whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.FlexibleXconnectServiceSummary, self).__init__()

                self.yang_name = "flexible-xconnect-service-summary"
                self.yang_parent_name = "active"

                self.number_fxc = YLeaf(YType.uint32, "number-fxc")

                self.number_fxc_down = YLeaf(YType.uint32, "number-fxc-down")

                self.number_fxc_up = YLeaf(YType.uint32, "number-fxc-up")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("number_fxc",
                                "number_fxc_down",
                                "number_fxc_up") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.FlexibleXconnectServiceSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.FlexibleXconnectServiceSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.number_fxc.is_set or
                    self.number_fxc_down.is_set or
                    self.number_fxc_up.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.number_fxc.yfilter != YFilter.not_set or
                    self.number_fxc_down.yfilter != YFilter.not_set or
                    self.number_fxc_up.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "flexible-xconnect-service-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.number_fxc.is_set or self.number_fxc.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_fxc.get_name_leafdata())
                if (self.number_fxc_down.is_set or self.number_fxc_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_fxc_down.get_name_leafdata())
                if (self.number_fxc_up.is_set or self.number_fxc_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_fxc_up.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "number-fxc" or name == "number-fxc-down" or name == "number-fxc-up"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "number-fxc"):
                    self.number_fxc = value
                    self.number_fxc.value_namespace = name_space
                    self.number_fxc.value_namespace_prefix = name_space_prefix
                if(value_path == "number-fxc-down"):
                    self.number_fxc_down = value
                    self.number_fxc_down.value_namespace = name_space
                    self.number_fxc_down.value_namespace_prefix = name_space_prefix
                if(value_path == "number-fxc-up"):
                    self.number_fxc_up = value
                    self.number_fxc_up.value_namespace = name_space
                    self.number_fxc_up.value_namespace_prefix = name_space_prefix


        class MainInterfaces(Entity):
            """
            Main Interface
            
            .. attribute:: main_interface
            
            	Main Interface Table
            	**type**\: list of    :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.MainInterfaces, self).__init__()

                self.yang_name = "main-interfaces"
                self.yang_parent_name = "active"

                self.main_interface = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.MainInterfaces, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.MainInterfaces, self).__setattr__(name, value)


            class MainInterface(Entity):
                """
                Main Interface Table
                
                .. attribute:: interface_name  <key>
                
                	Main interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: main_interface_info
                
                	Main Interface info
                	**type**\:   :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo>`
                
                .. attribute:: main_interface_instances
                
                	Main Interface Instance table
                	**type**\:   :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.MainInterfaces.MainInterface, self).__init__()

                    self.yang_name = "main-interface"
                    self.yang_parent_name = "main-interfaces"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.main_interface_info = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo()
                    self.main_interface_info.parent = self
                    self._children_name_map["main_interface_info"] = "main-interface-info"
                    self._children_yang_names.add("main-interface-info")

                    self.main_interface_instances = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances()
                    self.main_interface_instances.parent = self
                    self._children_name_map["main_interface_instances"] = "main-interface-instances"
                    self._children_yang_names.add("main-interface-instances")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.MainInterfaces.MainInterface, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.MainInterfaces.MainInterface, self).__setattr__(name, value)


                class MainInterfaceInstances(Entity):
                    """
                    Main Interface Instance table
                    
                    .. attribute:: main_interface_instance
                    
                    	Main Interface Instance
                    	**type**\: list of    :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances, self).__init__()

                        self.yang_name = "main-interface-instances"
                        self.yang_parent_name = "main-interface"

                        self.main_interface_instance = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances, self).__setattr__(name, value)


                    class MainInterfaceInstance(Entity):
                        """
                        Main Interface Instance
                        
                        .. attribute:: instance  <key>
                        
                        	Instance
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: main_interface_instance_bridge_ports
                        
                        	Main Interface Instance Bridge Port table
                        	**type**\:   :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                        
                        .. attribute:: main_interface_instance_info
                        
                        	Main Interface Instance info
                        	**type**\:   :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__init__()

                            self.yang_name = "main-interface-instance"
                            self.yang_parent_name = "main-interface-instances"

                            self.instance = YLeaf(YType.int32, "instance")

                            self.main_interface_instance_bridge_ports = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                            self.main_interface_instance_bridge_ports.parent = self
                            self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                            self._children_yang_names.add("main-interface-instance-bridge-ports")

                            self.main_interface_instance_info = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                            self.main_interface_instance_info.parent = self
                            self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"
                            self._children_yang_names.add("main-interface-instance-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("instance") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__setattr__(name, value)


                        class MainInterfaceInstanceInfo(Entity):
                            """
                            Main Interface Instance info
                            
                            .. attribute:: configured_instance
                            
                            	Configured Instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flush_count
                            
                            	Flush count 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_flags
                            
                            	Instance Flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_id
                            
                            	Instance ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_state
                            
                            	Instance State
                            	**type**\:   :py:class:`L2VpnMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfInstanceState>`
                            
                            .. attribute:: interface_count
                            
                            	Interface count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__init__()

                                self.yang_name = "main-interface-instance-info"
                                self.yang_parent_name = "main-interface-instance"

                                self.configured_instance = YLeaf(YType.uint32, "configured-instance")

                                self.flush_count = YLeaf(YType.uint32, "flush-count")

                                self.instance_flags = YLeaf(YType.uint32, "instance-flags")

                                self.instance_id = YLeaf(YType.uint32, "instance-id")

                                self.instance_state = YLeaf(YType.enumeration, "instance-state")

                                self.interface_count = YLeaf(YType.uint32, "interface-count")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configured_instance",
                                                "flush_count",
                                                "instance_flags",
                                                "instance_id",
                                                "instance_state",
                                                "interface_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.configured_instance.is_set or
                                    self.flush_count.is_set or
                                    self.instance_flags.is_set or
                                    self.instance_id.is_set or
                                    self.instance_state.is_set or
                                    self.interface_count.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configured_instance.yfilter != YFilter.not_set or
                                    self.flush_count.yfilter != YFilter.not_set or
                                    self.instance_flags.yfilter != YFilter.not_set or
                                    self.instance_id.yfilter != YFilter.not_set or
                                    self.instance_state.yfilter != YFilter.not_set or
                                    self.interface_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "main-interface-instance-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configured_instance.is_set or self.configured_instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_instance.get_name_leafdata())
                                if (self.flush_count.is_set or self.flush_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flush_count.get_name_leafdata())
                                if (self.instance_flags.is_set or self.instance_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance_flags.get_name_leafdata())
                                if (self.instance_id.is_set or self.instance_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance_id.get_name_leafdata())
                                if (self.instance_state.is_set or self.instance_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance_state.get_name_leafdata())
                                if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "configured-instance" or name == "flush-count" or name == "instance-flags" or name == "instance-id" or name == "instance-state" or name == "interface-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configured-instance"):
                                    self.configured_instance = value
                                    self.configured_instance.value_namespace = name_space
                                    self.configured_instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "flush-count"):
                                    self.flush_count = value
                                    self.flush_count.value_namespace = name_space
                                    self.flush_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "instance-flags"):
                                    self.instance_flags = value
                                    self.instance_flags.value_namespace = name_space
                                    self.instance_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "instance-id"):
                                    self.instance_id = value
                                    self.instance_id.value_namespace = name_space
                                    self.instance_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "instance-state"):
                                    self.instance_state = value
                                    self.instance_state.value_namespace = name_space
                                    self.instance_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-count"):
                                    self.interface_count = value
                                    self.interface_count.value_namespace = name_space
                                    self.interface_count.value_namespace_prefix = name_space_prefix


                        class MainInterfaceInstanceBridgePorts(Entity):
                            """
                            Main Interface Instance Bridge Port table
                            
                            .. attribute:: main_interface_instance_bridge_port
                            
                            	Main Interface Bridge Port info
                            	**type**\: list of    :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__init__()

                                self.yang_name = "main-interface-instance-bridge-ports"
                                self.yang_parent_name = "main-interface-instance"

                                self.main_interface_instance_bridge_port = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__setattr__(name, value)


                            class MainInterfaceInstanceBridgePort(Entity):
                                """
                                Main Interface Bridge Port info
                                
                                .. attribute:: bridge_port  <key>
                                
                                	Bridge Port
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: bridge_port_xr
                                
                                	Bridge port ifhandle
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: instance_id
                                
                                	Instance ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__init__()

                                    self.yang_name = "main-interface-instance-bridge-port"
                                    self.yang_parent_name = "main-interface-instance-bridge-ports"

                                    self.bridge_port = YLeaf(YType.str, "bridge-port")

                                    self.bridge_port_xr = YLeaf(YType.str, "bridge-port-xr")

                                    self.instance_id = YLeaf(YType.uint32, "instance-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bridge_port",
                                                    "bridge_port_xr",
                                                    "instance_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bridge_port.is_set or
                                        self.bridge_port_xr.is_set or
                                        self.instance_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bridge_port.yfilter != YFilter.not_set or
                                        self.bridge_port_xr.yfilter != YFilter.not_set or
                                        self.instance_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "main-interface-instance-bridge-port" + "[bridge-port='" + self.bridge_port.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bridge_port.is_set or self.bridge_port.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port.get_name_leafdata())
                                    if (self.bridge_port_xr.is_set or self.bridge_port_xr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_xr.get_name_leafdata())
                                    if (self.instance_id.is_set or self.instance_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bridge-port" or name == "bridge-port-xr" or name == "instance-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bridge-port"):
                                        self.bridge_port = value
                                        self.bridge_port.value_namespace = name_space
                                        self.bridge_port.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bridge-port-xr"):
                                        self.bridge_port_xr = value
                                        self.bridge_port_xr.value_namespace = name_space
                                        self.bridge_port_xr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-id"):
                                        self.instance_id = value
                                        self.instance_id.value_namespace = name_space
                                        self.instance_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.main_interface_instance_bridge_port:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.main_interface_instance_bridge_port:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "main-interface-instance-bridge-ports" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "main-interface-instance-bridge-port"):
                                    for c in self.main_interface_instance_bridge_port:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.main_interface_instance_bridge_port.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "main-interface-instance-bridge-port"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.instance.is_set or
                                (self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports.has_data()) or
                                (self.main_interface_instance_info is not None and self.main_interface_instance_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.instance.yfilter != YFilter.not_set or
                                (self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports.has_operation()) or
                                (self.main_interface_instance_info is not None and self.main_interface_instance_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "main-interface-instance" + "[instance='" + self.instance.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.instance.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "main-interface-instance-bridge-ports"):
                                if (self.main_interface_instance_bridge_ports is None):
                                    self.main_interface_instance_bridge_ports = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                                    self.main_interface_instance_bridge_ports.parent = self
                                    self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                                return self.main_interface_instance_bridge_ports

                            if (child_yang_name == "main-interface-instance-info"):
                                if (self.main_interface_instance_info is None):
                                    self.main_interface_instance_info = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                                    self.main_interface_instance_info.parent = self
                                    self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"
                                return self.main_interface_instance_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "main-interface-instance-bridge-ports" or name == "main-interface-instance-info" or name == "instance"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "instance"):
                                self.instance = value
                                self.instance.value_namespace = name_space
                                self.instance.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.main_interface_instance:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.main_interface_instance:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "main-interface-instances" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "main-interface-instance"):
                            for c in self.main_interface_instance:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.main_interface_instance.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "main-interface-instance"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MainInterfaceInfo(Entity):
                    """
                    Main Interface info
                    
                    .. attribute:: interface_count
                    
                    	Sub Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: main_interface_handle
                    
                    	Main Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: protected
                    
                    	Protected
                    	**type**\:   :py:class:`L2VpnMainIfProtectected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfProtectected>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo, self).__init__()

                        self.yang_name = "main-interface-info"
                        self.yang_parent_name = "main-interface"

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                        self.main_interface_handle = YLeaf(YType.str, "main-interface-handle")

                        self.protected = YLeaf(YType.enumeration, "protected")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_count",
                                        "main_interface_handle",
                                        "protected") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_count.is_set or
                            self.main_interface_handle.is_set or
                            self.protected.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set or
                            self.main_interface_handle.yfilter != YFilter.not_set or
                            self.protected.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "main-interface-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())
                        if (self.main_interface_handle.is_set or self.main_interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.main_interface_handle.get_name_leafdata())
                        if (self.protected.is_set or self.protected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protected.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-count" or name == "main-interface-handle" or name == "protected"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "main-interface-handle"):
                            self.main_interface_handle = value
                            self.main_interface_handle.value_namespace = name_space
                            self.main_interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "protected"):
                            self.protected = value
                            self.protected.value_namespace = name_space
                            self.protected.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        (self.main_interface_info is not None and self.main_interface_info.has_data()) or
                        (self.main_interface_instances is not None and self.main_interface_instances.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        (self.main_interface_info is not None and self.main_interface_info.has_operation()) or
                        (self.main_interface_instances is not None and self.main_interface_instances.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "main-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/main-interfaces/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "main-interface-info"):
                        if (self.main_interface_info is None):
                            self.main_interface_info = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo()
                            self.main_interface_info.parent = self
                            self._children_name_map["main_interface_info"] = "main-interface-info"
                        return self.main_interface_info

                    if (child_yang_name == "main-interface-instances"):
                        if (self.main_interface_instances is None):
                            self.main_interface_instances = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances()
                            self.main_interface_instances.parent = self
                            self._children_name_map["main_interface_instances"] = "main-interface-instances"
                        return self.main_interface_instances

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "main-interface-info" or name == "main-interface-instances" or name == "interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.main_interface:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.main_interface:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "main-interfaces" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "main-interface"):
                    for c in self.main_interface:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.MainInterfaces.MainInterface()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.main_interface.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "main-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class IccpSm(Entity):
            """
            ICCP\-based Service Multi\-homing operational data
            
            .. attribute:: iccp_groups
            
            	ICCP Group Table
            	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups>`
            
            .. attribute:: iccp_sm_summary
            
            	ICCP\-based Service Multi\-homing database summary
            	**type**\:   :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpSmSummary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.IccpSm, self).__init__()

                self.yang_name = "iccp-sm"
                self.yang_parent_name = "active"

                self.iccp_groups = L2Vpnv2.Active.IccpSm.IccpGroups()
                self.iccp_groups.parent = self
                self._children_name_map["iccp_groups"] = "iccp-groups"
                self._children_yang_names.add("iccp-groups")

                self.iccp_sm_summary = L2Vpnv2.Active.IccpSm.IccpSmSummary()
                self.iccp_sm_summary.parent = self
                self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"
                self._children_yang_names.add("iccp-sm-summary")


            class IccpSmSummary(Entity):
                """
                ICCP\-based Service Multi\-homing database
                summary
                
                .. attribute:: connected_groups
                
                	Number of Connected Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: connecting_groups
                
                	Number of Connecting Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: failed_ports
                
                	Number of Failed Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groups
                
                	Total Number of Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: operational_ports
                
                	Number of Operational Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ports
                
                	Total Number of Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: provisioned_groups
                
                	Number of Provisioned Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reverting_ports
                
                	Number of Reverting Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronized_groups
                
                	Number of Synchronized Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronizing_groups
                
                	Number of Synchronizing Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unconfigured_ports
                
                	Number of Unconfigured Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_ports
                
                	Number of Unknown Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_groups
                
                	Number of Unresolved Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsynchronized_ports
                
                	Number of Unsynchronized Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.IccpSm.IccpSmSummary, self).__init__()

                    self.yang_name = "iccp-sm-summary"
                    self.yang_parent_name = "iccp-sm"

                    self.connected_groups = YLeaf(YType.uint32, "connected-groups")

                    self.connecting_groups = YLeaf(YType.uint32, "connecting-groups")

                    self.failed_ports = YLeaf(YType.uint32, "failed-ports")

                    self.groups = YLeaf(YType.uint32, "groups")

                    self.operational_ports = YLeaf(YType.uint32, "operational-ports")

                    self.ports = YLeaf(YType.uint32, "ports")

                    self.provisioned_groups = YLeaf(YType.uint32, "provisioned-groups")

                    self.reverting_ports = YLeaf(YType.uint32, "reverting-ports")

                    self.synchronized_groups = YLeaf(YType.uint32, "synchronized-groups")

                    self.synchronizing_groups = YLeaf(YType.uint32, "synchronizing-groups")

                    self.unconfigured_ports = YLeaf(YType.uint32, "unconfigured-ports")

                    self.unknown_ports = YLeaf(YType.uint32, "unknown-ports")

                    self.unresolved_groups = YLeaf(YType.uint32, "unresolved-groups")

                    self.unsynchronized_ports = YLeaf(YType.uint32, "unsynchronized-ports")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("connected_groups",
                                    "connecting_groups",
                                    "failed_ports",
                                    "groups",
                                    "operational_ports",
                                    "ports",
                                    "provisioned_groups",
                                    "reverting_ports",
                                    "synchronized_groups",
                                    "synchronizing_groups",
                                    "unconfigured_ports",
                                    "unknown_ports",
                                    "unresolved_groups",
                                    "unsynchronized_ports") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.IccpSm.IccpSmSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.IccpSm.IccpSmSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.connected_groups.is_set or
                        self.connecting_groups.is_set or
                        self.failed_ports.is_set or
                        self.groups.is_set or
                        self.operational_ports.is_set or
                        self.ports.is_set or
                        self.provisioned_groups.is_set or
                        self.reverting_ports.is_set or
                        self.synchronized_groups.is_set or
                        self.synchronizing_groups.is_set or
                        self.unconfigured_ports.is_set or
                        self.unknown_ports.is_set or
                        self.unresolved_groups.is_set or
                        self.unsynchronized_ports.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.connected_groups.yfilter != YFilter.not_set or
                        self.connecting_groups.yfilter != YFilter.not_set or
                        self.failed_ports.yfilter != YFilter.not_set or
                        self.groups.yfilter != YFilter.not_set or
                        self.operational_ports.yfilter != YFilter.not_set or
                        self.ports.yfilter != YFilter.not_set or
                        self.provisioned_groups.yfilter != YFilter.not_set or
                        self.reverting_ports.yfilter != YFilter.not_set or
                        self.synchronized_groups.yfilter != YFilter.not_set or
                        self.synchronizing_groups.yfilter != YFilter.not_set or
                        self.unconfigured_ports.yfilter != YFilter.not_set or
                        self.unknown_ports.yfilter != YFilter.not_set or
                        self.unresolved_groups.yfilter != YFilter.not_set or
                        self.unsynchronized_ports.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "iccp-sm-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/iccp-sm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.connected_groups.is_set or self.connected_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.connected_groups.get_name_leafdata())
                    if (self.connecting_groups.is_set or self.connecting_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.connecting_groups.get_name_leafdata())
                    if (self.failed_ports.is_set or self.failed_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.failed_ports.get_name_leafdata())
                    if (self.groups.is_set or self.groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.groups.get_name_leafdata())
                    if (self.operational_ports.is_set or self.operational_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.operational_ports.get_name_leafdata())
                    if (self.ports.is_set or self.ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ports.get_name_leafdata())
                    if (self.provisioned_groups.is_set or self.provisioned_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.provisioned_groups.get_name_leafdata())
                    if (self.reverting_ports.is_set or self.reverting_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reverting_ports.get_name_leafdata())
                    if (self.synchronized_groups.is_set or self.synchronized_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.synchronized_groups.get_name_leafdata())
                    if (self.synchronizing_groups.is_set or self.synchronizing_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.synchronizing_groups.get_name_leafdata())
                    if (self.unconfigured_ports.is_set or self.unconfigured_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unconfigured_ports.get_name_leafdata())
                    if (self.unknown_ports.is_set or self.unknown_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unknown_ports.get_name_leafdata())
                    if (self.unresolved_groups.is_set or self.unresolved_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unresolved_groups.get_name_leafdata())
                    if (self.unsynchronized_ports.is_set or self.unsynchronized_ports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unsynchronized_ports.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "connected-groups" or name == "connecting-groups" or name == "failed-ports" or name == "groups" or name == "operational-ports" or name == "ports" or name == "provisioned-groups" or name == "reverting-ports" or name == "synchronized-groups" or name == "synchronizing-groups" or name == "unconfigured-ports" or name == "unknown-ports" or name == "unresolved-groups" or name == "unsynchronized-ports"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "connected-groups"):
                        self.connected_groups = value
                        self.connected_groups.value_namespace = name_space
                        self.connected_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "connecting-groups"):
                        self.connecting_groups = value
                        self.connecting_groups.value_namespace = name_space
                        self.connecting_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "failed-ports"):
                        self.failed_ports = value
                        self.failed_ports.value_namespace = name_space
                        self.failed_ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "groups"):
                        self.groups = value
                        self.groups.value_namespace = name_space
                        self.groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "operational-ports"):
                        self.operational_ports = value
                        self.operational_ports.value_namespace = name_space
                        self.operational_ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "ports"):
                        self.ports = value
                        self.ports.value_namespace = name_space
                        self.ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "provisioned-groups"):
                        self.provisioned_groups = value
                        self.provisioned_groups.value_namespace = name_space
                        self.provisioned_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "reverting-ports"):
                        self.reverting_ports = value
                        self.reverting_ports.value_namespace = name_space
                        self.reverting_ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "synchronized-groups"):
                        self.synchronized_groups = value
                        self.synchronized_groups.value_namespace = name_space
                        self.synchronized_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "synchronizing-groups"):
                        self.synchronizing_groups = value
                        self.synchronizing_groups.value_namespace = name_space
                        self.synchronizing_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "unconfigured-ports"):
                        self.unconfigured_ports = value
                        self.unconfigured_ports.value_namespace = name_space
                        self.unconfigured_ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "unknown-ports"):
                        self.unknown_ports = value
                        self.unknown_ports.value_namespace = name_space
                        self.unknown_ports.value_namespace_prefix = name_space_prefix
                    if(value_path == "unresolved-groups"):
                        self.unresolved_groups = value
                        self.unresolved_groups.value_namespace = name_space
                        self.unresolved_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "unsynchronized-ports"):
                        self.unsynchronized_ports = value
                        self.unsynchronized_ports.value_namespace = name_space
                        self.unsynchronized_ports.value_namespace_prefix = name_space_prefix


            class IccpGroups(Entity):
                """
                ICCP Group Table
                
                .. attribute:: iccp_group
                
                	ICCP Group
                	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.IccpSm.IccpGroups, self).__init__()

                    self.yang_name = "iccp-groups"
                    self.yang_parent_name = "iccp-sm"

                    self.iccp_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.IccpSm.IccpGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.IccpSm.IccpGroups, self).__setattr__(name, value)


                class IccpGroup(Entity):
                    """
                    ICCP Group
                    
                    .. attribute:: group_id  <key>
                    
                    	Group ID
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: iccp_group_info
                    
                    	ICCP Group Information
                    	**type**\:   :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                    
                    .. attribute:: iccp_ports
                    
                    	ICCP Port Table
                    	**type**\:   :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup, self).__init__()

                        self.yang_name = "iccp-group"
                        self.yang_parent_name = "iccp-groups"

                        self.group_id = YLeaf(YType.uint32, "group-id")

                        self.iccp_group_info = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                        self.iccp_group_info.parent = self
                        self._children_name_map["iccp_group_info"] = "iccp-group-info"
                        self._children_yang_names.add("iccp-group-info")

                        self.iccp_ports = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                        self.iccp_ports.parent = self
                        self._children_name_map["iccp_ports"] = "iccp-ports"
                        self._children_yang_names.add("iccp-ports")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup, self).__setattr__(name, value)


                    class IccpGroupInfo(Entity):
                        """
                        ICCP Group Information
                        
                        .. attribute:: group_id
                        
                        	Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: iccp_member_up
                        
                        	ICCP Member Up
                        	**type**\:  bool
                        
                        .. attribute:: iccp_transport_up
                        
                        	ICCP Transport Up
                        	**type**\:  bool
                        
                        .. attribute:: local_node_id
                        
                        	Local Node ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ports
                        
                        	List of ports in the group
                        	**type**\: list of    :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                        
                        .. attribute:: remote_node_id
                        
                        	Remote Node ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`IccpSmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmState>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__init__()

                            self.yang_name = "iccp-group-info"
                            self.yang_parent_name = "iccp-group"

                            self.group_id = YLeaf(YType.uint32, "group-id")

                            self.iccp_member_up = YLeaf(YType.boolean, "iccp-member-up")

                            self.iccp_transport_up = YLeaf(YType.boolean, "iccp-transport-up")

                            self.local_node_id = YLeaf(YType.uint8, "local-node-id")

                            self.remote_node_id = YLeaf(YType.uint8, "remote-node-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.ports = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_id",
                                            "iccp_member_up",
                                            "iccp_transport_up",
                                            "local_node_id",
                                            "remote_node_id",
                                            "state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__setattr__(name, value)


                        class Ports(Entity):
                            """
                            List of ports in the group
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\:  bool
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__init__()

                                self.yang_name = "ports"
                                self.yang_parent_name = "iccp-group-info"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.mac_flush_tcn = YLeaf(YType.boolean, "mac-flush-tcn")

                                self.local_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                self.local_port.parent = self
                                self._children_name_map["local_port"] = "local-port"
                                self._children_yang_names.add("local-port")

                                self.remote_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                self.remote_port.parent = self
                                self._children_name_map["remote_port"] = "remote-port"
                                self._children_yang_names.add("remote-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "mac_flush_tcn") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__setattr__(name, value)


                            class LocalPort(Entity):
                                """
                                Local port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__init__()

                                    self.yang_name = "local-port"
                                    self.yang_parent_name = "ports"

                                    self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                    self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                    self.port_state = YLeaf(YType.enumeration, "port-state")

                                    self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                    self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                    self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                    self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fsm_state",
                                                    "port_fail_code",
                                                    "port_state",
                                                    "reversion_time",
                                                    "reversion_time_remaining",
                                                    "vlan_state",
                                                    "vlan_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.fsm_state.is_set or
                                        self.port_fail_code.is_set or
                                        self.port_state.is_set or
                                        self.reversion_time.is_set or
                                        self.reversion_time_remaining.is_set or
                                        self.vlan_state.is_set or
                                        self.vlan_vector.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fsm_state.yfilter != YFilter.not_set or
                                        self.port_fail_code.yfilter != YFilter.not_set or
                                        self.port_state.yfilter != YFilter.not_set or
                                        self.reversion_time.yfilter != YFilter.not_set or
                                        self.reversion_time_remaining.yfilter != YFilter.not_set or
                                        self.vlan_state.yfilter != YFilter.not_set or
                                        self.vlan_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                    if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                    if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_state.get_name_leafdata())
                                    if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                    if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                    if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                    if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fsm-state"):
                                        self.fsm_state = value
                                        self.fsm_state.value_namespace = name_space
                                        self.fsm_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-fail-code"):
                                        self.port_fail_code = value
                                        self.port_fail_code.value_namespace = name_space
                                        self.port_fail_code.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-state"):
                                        self.port_state = value
                                        self.port_state.value_namespace = name_space
                                        self.port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time"):
                                        self.reversion_time = value
                                        self.reversion_time.value_namespace = name_space
                                        self.reversion_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time-remaining"):
                                        self.reversion_time_remaining = value
                                        self.reversion_time_remaining.value_namespace = name_space
                                        self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-state"):
                                        self.vlan_state = value
                                        self.vlan_state.value_namespace = name_space
                                        self.vlan_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-vector"):
                                        self.vlan_vector = value
                                        self.vlan_vector.value_namespace = name_space
                                        self.vlan_vector.value_namespace_prefix = name_space_prefix


                            class RemotePort(Entity):
                                """
                                Remote port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__init__()

                                    self.yang_name = "remote-port"
                                    self.yang_parent_name = "ports"

                                    self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                    self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                    self.port_state = YLeaf(YType.enumeration, "port-state")

                                    self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                    self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                    self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                    self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fsm_state",
                                                    "port_fail_code",
                                                    "port_state",
                                                    "reversion_time",
                                                    "reversion_time_remaining",
                                                    "vlan_state",
                                                    "vlan_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.fsm_state.is_set or
                                        self.port_fail_code.is_set or
                                        self.port_state.is_set or
                                        self.reversion_time.is_set or
                                        self.reversion_time_remaining.is_set or
                                        self.vlan_state.is_set or
                                        self.vlan_vector.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fsm_state.yfilter != YFilter.not_set or
                                        self.port_fail_code.yfilter != YFilter.not_set or
                                        self.port_state.yfilter != YFilter.not_set or
                                        self.reversion_time.yfilter != YFilter.not_set or
                                        self.reversion_time_remaining.yfilter != YFilter.not_set or
                                        self.vlan_state.yfilter != YFilter.not_set or
                                        self.vlan_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                    if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                    if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_state.get_name_leafdata())
                                    if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                    if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                    if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                    if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fsm-state"):
                                        self.fsm_state = value
                                        self.fsm_state.value_namespace = name_space
                                        self.fsm_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-fail-code"):
                                        self.port_fail_code = value
                                        self.port_fail_code.value_namespace = name_space
                                        self.port_fail_code.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-state"):
                                        self.port_state = value
                                        self.port_state.value_namespace = name_space
                                        self.port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time"):
                                        self.reversion_time = value
                                        self.reversion_time.value_namespace = name_space
                                        self.reversion_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time-remaining"):
                                        self.reversion_time_remaining = value
                                        self.reversion_time_remaining.value_namespace = name_space
                                        self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-state"):
                                        self.vlan_state = value
                                        self.vlan_state.value_namespace = name_space
                                        self.vlan_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-vector"):
                                        self.vlan_vector = value
                                        self.vlan_vector.value_namespace = name_space
                                        self.vlan_vector.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.interface_name.is_set or
                                    self.mac_flush_tcn.is_set or
                                    (self.local_port is not None and self.local_port.has_data()) or
                                    (self.remote_port is not None and self.remote_port.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.mac_flush_tcn.yfilter != YFilter.not_set or
                                    (self.local_port is not None and self.local_port.has_operation()) or
                                    (self.remote_port is not None and self.remote_port.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ports" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.mac_flush_tcn.is_set or self.mac_flush_tcn.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_flush_tcn.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-port"):
                                    if (self.local_port is None):
                                        self.local_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                        self.local_port.parent = self
                                        self._children_name_map["local_port"] = "local-port"
                                    return self.local_port

                                if (child_yang_name == "remote-port"):
                                    if (self.remote_port is None):
                                        self.remote_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                        self.remote_port.parent = self
                                        self._children_name_map["remote_port"] = "remote-port"
                                    return self.remote_port

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-port" or name == "remote-port" or name == "interface-name" or name == "mac-flush-tcn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-flush-tcn"):
                                    self.mac_flush_tcn = value
                                    self.mac_flush_tcn.value_namespace = name_space
                                    self.mac_flush_tcn.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ports:
                                if (c.has_data()):
                                    return True
                            return (
                                self.group_id.is_set or
                                self.iccp_member_up.is_set or
                                self.iccp_transport_up.is_set or
                                self.local_node_id.is_set or
                                self.remote_node_id.is_set or
                                self.state.is_set)

                        def has_operation(self):
                            for c in self.ports:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_id.yfilter != YFilter.not_set or
                                self.iccp_member_up.yfilter != YFilter.not_set or
                                self.iccp_transport_up.yfilter != YFilter.not_set or
                                self.local_node_id.yfilter != YFilter.not_set or
                                self.remote_node_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_id.get_name_leafdata())
                            if (self.iccp_member_up.is_set or self.iccp_member_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_member_up.get_name_leafdata())
                            if (self.iccp_transport_up.is_set or self.iccp_transport_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_transport_up.get_name_leafdata())
                            if (self.local_node_id.is_set or self.local_node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_node_id.get_name_leafdata())
                            if (self.remote_node_id.is_set or self.remote_node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_node_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ports"):
                                for c in self.ports:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ports.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ports" or name == "group-id" or name == "iccp-member-up" or name == "iccp-transport-up" or name == "local-node-id" or name == "remote-node-id" or name == "state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-id"):
                                self.group_id = value
                                self.group_id.value_namespace = name_space
                                self.group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-member-up"):
                                self.iccp_member_up = value
                                self.iccp_member_up.value_namespace = name_space
                                self.iccp_member_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-transport-up"):
                                self.iccp_transport_up = value
                                self.iccp_transport_up.value_namespace = name_space
                                self.iccp_transport_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-node-id"):
                                self.local_node_id = value
                                self.local_node_id.value_namespace = name_space
                                self.local_node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-node-id"):
                                self.remote_node_id = value
                                self.remote_node_id.value_namespace = name_space
                                self.remote_node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix


                    class IccpPorts(Entity):
                        """
                        ICCP Port Table
                        
                        .. attribute:: iccp_port
                        
                        	ICCP Port
                        	**type**\: list of    :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__init__()

                            self.yang_name = "iccp-ports"
                            self.yang_parent_name = "iccp-group"

                            self.iccp_port = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__setattr__(name, value)


                        class IccpPort(Entity):
                            """
                            ICCP Port
                            
                            .. attribute:: interface  <key>
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\:  bool
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__init__()

                                self.yang_name = "iccp-port"
                                self.yang_parent_name = "iccp-ports"

                                self.interface = YLeaf(YType.str, "interface")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.mac_flush_tcn = YLeaf(YType.boolean, "mac-flush-tcn")

                                self.local_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                self.local_port.parent = self
                                self._children_name_map["local_port"] = "local-port"
                                self._children_yang_names.add("local-port")

                                self.remote_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                self.remote_port.parent = self
                                self._children_name_map["remote_port"] = "remote-port"
                                self._children_yang_names.add("remote-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface",
                                                "interface_name",
                                                "mac_flush_tcn") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__setattr__(name, value)


                            class LocalPort(Entity):
                                """
                                Local port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__init__()

                                    self.yang_name = "local-port"
                                    self.yang_parent_name = "iccp-port"

                                    self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                    self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                    self.port_state = YLeaf(YType.enumeration, "port-state")

                                    self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                    self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                    self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                    self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fsm_state",
                                                    "port_fail_code",
                                                    "port_state",
                                                    "reversion_time",
                                                    "reversion_time_remaining",
                                                    "vlan_state",
                                                    "vlan_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.fsm_state.is_set or
                                        self.port_fail_code.is_set or
                                        self.port_state.is_set or
                                        self.reversion_time.is_set or
                                        self.reversion_time_remaining.is_set or
                                        self.vlan_state.is_set or
                                        self.vlan_vector.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fsm_state.yfilter != YFilter.not_set or
                                        self.port_fail_code.yfilter != YFilter.not_set or
                                        self.port_state.yfilter != YFilter.not_set or
                                        self.reversion_time.yfilter != YFilter.not_set or
                                        self.reversion_time_remaining.yfilter != YFilter.not_set or
                                        self.vlan_state.yfilter != YFilter.not_set or
                                        self.vlan_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                    if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                    if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_state.get_name_leafdata())
                                    if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                    if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                    if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                    if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fsm-state"):
                                        self.fsm_state = value
                                        self.fsm_state.value_namespace = name_space
                                        self.fsm_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-fail-code"):
                                        self.port_fail_code = value
                                        self.port_fail_code.value_namespace = name_space
                                        self.port_fail_code.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-state"):
                                        self.port_state = value
                                        self.port_state.value_namespace = name_space
                                        self.port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time"):
                                        self.reversion_time = value
                                        self.reversion_time.value_namespace = name_space
                                        self.reversion_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time-remaining"):
                                        self.reversion_time_remaining = value
                                        self.reversion_time_remaining.value_namespace = name_space
                                        self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-state"):
                                        self.vlan_state = value
                                        self.vlan_state.value_namespace = name_space
                                        self.vlan_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-vector"):
                                        self.vlan_vector = value
                                        self.vlan_vector.value_namespace = name_space
                                        self.vlan_vector.value_namespace_prefix = name_space_prefix


                            class RemotePort(Entity):
                                """
                                Remote port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__init__()

                                    self.yang_name = "remote-port"
                                    self.yang_parent_name = "iccp-port"

                                    self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                    self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                    self.port_state = YLeaf(YType.enumeration, "port-state")

                                    self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                    self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                    self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                    self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fsm_state",
                                                    "port_fail_code",
                                                    "port_state",
                                                    "reversion_time",
                                                    "reversion_time_remaining",
                                                    "vlan_state",
                                                    "vlan_vector") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.fsm_state.is_set or
                                        self.port_fail_code.is_set or
                                        self.port_state.is_set or
                                        self.reversion_time.is_set or
                                        self.reversion_time_remaining.is_set or
                                        self.vlan_state.is_set or
                                        self.vlan_vector.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fsm_state.yfilter != YFilter.not_set or
                                        self.port_fail_code.yfilter != YFilter.not_set or
                                        self.port_state.yfilter != YFilter.not_set or
                                        self.reversion_time.yfilter != YFilter.not_set or
                                        self.reversion_time_remaining.yfilter != YFilter.not_set or
                                        self.vlan_state.yfilter != YFilter.not_set or
                                        self.vlan_vector.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                    if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                    if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_state.get_name_leafdata())
                                    if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                    if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                    if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                    if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fsm-state"):
                                        self.fsm_state = value
                                        self.fsm_state.value_namespace = name_space
                                        self.fsm_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-fail-code"):
                                        self.port_fail_code = value
                                        self.port_fail_code.value_namespace = name_space
                                        self.port_fail_code.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-state"):
                                        self.port_state = value
                                        self.port_state.value_namespace = name_space
                                        self.port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time"):
                                        self.reversion_time = value
                                        self.reversion_time.value_namespace = name_space
                                        self.reversion_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "reversion-time-remaining"):
                                        self.reversion_time_remaining = value
                                        self.reversion_time_remaining.value_namespace = name_space
                                        self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-state"):
                                        self.vlan_state = value
                                        self.vlan_state.value_namespace = name_space
                                        self.vlan_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-vector"):
                                        self.vlan_vector = value
                                        self.vlan_vector.value_namespace = name_space
                                        self.vlan_vector.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.interface.is_set or
                                    self.interface_name.is_set or
                                    self.mac_flush_tcn.is_set or
                                    (self.local_port is not None and self.local_port.has_data()) or
                                    (self.remote_port is not None and self.remote_port.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.mac_flush_tcn.yfilter != YFilter.not_set or
                                    (self.local_port is not None and self.local_port.has_operation()) or
                                    (self.remote_port is not None and self.remote_port.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-port" + "[interface='" + self.interface.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.mac_flush_tcn.is_set or self.mac_flush_tcn.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_flush_tcn.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-port"):
                                    if (self.local_port is None):
                                        self.local_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                        self.local_port.parent = self
                                        self._children_name_map["local_port"] = "local-port"
                                    return self.local_port

                                if (child_yang_name == "remote-port"):
                                    if (self.remote_port is None):
                                        self.remote_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                        self.remote_port.parent = self
                                        self._children_name_map["remote_port"] = "remote-port"
                                    return self.remote_port

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-port" or name == "remote-port" or name == "interface" or name == "interface-name" or name == "mac-flush-tcn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface"):
                                    self.interface = value
                                    self.interface.value_namespace = name_space
                                    self.interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-flush-tcn"):
                                    self.mac_flush_tcn = value
                                    self.mac_flush_tcn.value_namespace = name_space
                                    self.mac_flush_tcn.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.iccp_port:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.iccp_port:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-ports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "iccp-port"):
                                for c in self.iccp_port:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.iccp_port.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "iccp-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.group_id.is_set or
                            (self.iccp_group_info is not None and self.iccp_group_info.has_data()) or
                            (self.iccp_ports is not None and self.iccp_ports.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_id.yfilter != YFilter.not_set or
                            (self.iccp_group_info is not None and self.iccp_group_info.has_operation()) or
                            (self.iccp_ports is not None and self.iccp_ports.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-group" + "[group-id='" + self.group_id.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/iccp-sm/iccp-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-group-info"):
                            if (self.iccp_group_info is None):
                                self.iccp_group_info = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                                self.iccp_group_info.parent = self
                                self._children_name_map["iccp_group_info"] = "iccp-group-info"
                            return self.iccp_group_info

                        if (child_yang_name == "iccp-ports"):
                            if (self.iccp_ports is None):
                                self.iccp_ports = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                                self.iccp_ports.parent = self
                                self._children_name_map["iccp_ports"] = "iccp-ports"
                            return self.iccp_ports

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-group-info" or name == "iccp-ports" or name == "group-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-id"):
                            self.group_id = value
                            self.group_id.value_namespace = name_space
                            self.group_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.iccp_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.iccp_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "iccp-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/iccp-sm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "iccp-group"):
                        for c in self.iccp_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.iccp_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.iccp_groups is not None and self.iccp_groups.has_data()) or
                    (self.iccp_sm_summary is not None and self.iccp_sm_summary.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.iccp_groups is not None and self.iccp_groups.has_operation()) or
                    (self.iccp_sm_summary is not None and self.iccp_sm_summary.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "iccp-sm" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "iccp-groups"):
                    if (self.iccp_groups is None):
                        self.iccp_groups = L2Vpnv2.Active.IccpSm.IccpGroups()
                        self.iccp_groups.parent = self
                        self._children_name_map["iccp_groups"] = "iccp-groups"
                    return self.iccp_groups

                if (child_yang_name == "iccp-sm-summary"):
                    if (self.iccp_sm_summary is None):
                        self.iccp_sm_summary = L2Vpnv2.Active.IccpSm.IccpSmSummary()
                        self.iccp_sm_summary.parent = self
                        self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"
                    return self.iccp_sm_summary

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "iccp-groups" or name == "iccp-sm-summary"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class BridgeSummary(Entity):
            """
            Bridge Domain summary information
            
            .. attribute:: num_vn_is
            
            	Number of VNIs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_down
            
            	Number of VNIs down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_unresolved
            
            	Number of VNIs unresolved
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_up
            
            	Number of VNIs up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs
            
            	Number of attachment circuits
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs_up
            
            	Number of attachment circuits whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains
            
            	Number of bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_shut
            
            	Number of bridge\-domains admin disabled
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_up
            
            	Number of bridge\-domains up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_default_bridge_doamins
            
            	Number of default bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp
            
            	Number of P2MPs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_down
            
            	Number of P2MPs whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_up
            
            	Number of P2MPs whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p_ws_up
            
            	Number of pseudowires whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_core
            
            	Number of PBB Core
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_edge
            
            	Number of PBB Edge
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pseudowires
            
            	Number of pseudowires
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_a_cs
            
            	Number of partially programmed attachment circuits
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_bridges
            
            	Number of partially programmed bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_pseudowires
            
            	Number of partially programmed pseudowires
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_pseudowires
            
            	Number of pseudowires whose state is standby
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.BridgeSummary, self).__init__()

                self.yang_name = "bridge-summary"
                self.yang_parent_name = "active"

                self.num_vn_is = YLeaf(YType.uint32, "num-vn-is")

                self.num_vn_is_down = YLeaf(YType.uint32, "num-vn-is-down")

                self.num_vn_is_unresolved = YLeaf(YType.uint32, "num-vn-is-unresolved")

                self.num_vn_is_up = YLeaf(YType.uint32, "num-vn-is-up")

                self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                self.number_bridge_domains = YLeaf(YType.uint32, "number-bridge-domains")

                self.number_bridge_domains_shut = YLeaf(YType.uint32, "number-bridge-domains-shut")

                self.number_bridge_domains_up = YLeaf(YType.uint32, "number-bridge-domains-up")

                self.number_default_bridge_doamins = YLeaf(YType.uint32, "number-default-bridge-doamins")

                self.number_groups = YLeaf(YType.uint32, "number-groups")

                self.number_p2mp = YLeaf(YType.uint32, "number-p2mp")

                self.number_p2mp_down = YLeaf(YType.uint32, "number-p2mp-down")

                self.number_p2mp_up = YLeaf(YType.uint32, "number-p2mp-up")

                self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                self.number_pbb_core = YLeaf(YType.uint32, "number-pbb-core")

                self.number_pbb_edge = YLeaf(YType.uint32, "number-pbb-edge")

                self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                self.partially_programmed_a_cs = YLeaf(YType.uint32, "partially-programmed-a-cs")

                self.partially_programmed_bridges = YLeaf(YType.uint32, "partially-programmed-bridges")

                self.partially_programmed_pseudowires = YLeaf(YType.uint32, "partially-programmed-pseudowires")

                self.standby_pseudowires = YLeaf(YType.uint32, "standby-pseudowires")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("num_vn_is",
                                "num_vn_is_down",
                                "num_vn_is_unresolved",
                                "num_vn_is_up",
                                "number_a_cs",
                                "number_a_cs_up",
                                "number_bridge_domains",
                                "number_bridge_domains_shut",
                                "number_bridge_domains_up",
                                "number_default_bridge_doamins",
                                "number_groups",
                                "number_p2mp",
                                "number_p2mp_down",
                                "number_p2mp_up",
                                "number_p_ws_up",
                                "number_pbb_core",
                                "number_pbb_edge",
                                "number_pseudowires",
                                "out_of_memory_state",
                                "partially_programmed_a_cs",
                                "partially_programmed_bridges",
                                "partially_programmed_pseudowires",
                                "standby_pseudowires") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.BridgeSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.BridgeSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.num_vn_is.is_set or
                    self.num_vn_is_down.is_set or
                    self.num_vn_is_unresolved.is_set or
                    self.num_vn_is_up.is_set or
                    self.number_a_cs.is_set or
                    self.number_a_cs_up.is_set or
                    self.number_bridge_domains.is_set or
                    self.number_bridge_domains_shut.is_set or
                    self.number_bridge_domains_up.is_set or
                    self.number_default_bridge_doamins.is_set or
                    self.number_groups.is_set or
                    self.number_p2mp.is_set or
                    self.number_p2mp_down.is_set or
                    self.number_p2mp_up.is_set or
                    self.number_p_ws_up.is_set or
                    self.number_pbb_core.is_set or
                    self.number_pbb_edge.is_set or
                    self.number_pseudowires.is_set or
                    self.out_of_memory_state.is_set or
                    self.partially_programmed_a_cs.is_set or
                    self.partially_programmed_bridges.is_set or
                    self.partially_programmed_pseudowires.is_set or
                    self.standby_pseudowires.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.num_vn_is.yfilter != YFilter.not_set or
                    self.num_vn_is_down.yfilter != YFilter.not_set or
                    self.num_vn_is_unresolved.yfilter != YFilter.not_set or
                    self.num_vn_is_up.yfilter != YFilter.not_set or
                    self.number_a_cs.yfilter != YFilter.not_set or
                    self.number_a_cs_up.yfilter != YFilter.not_set or
                    self.number_bridge_domains.yfilter != YFilter.not_set or
                    self.number_bridge_domains_shut.yfilter != YFilter.not_set or
                    self.number_bridge_domains_up.yfilter != YFilter.not_set or
                    self.number_default_bridge_doamins.yfilter != YFilter.not_set or
                    self.number_groups.yfilter != YFilter.not_set or
                    self.number_p2mp.yfilter != YFilter.not_set or
                    self.number_p2mp_down.yfilter != YFilter.not_set or
                    self.number_p2mp_up.yfilter != YFilter.not_set or
                    self.number_p_ws_up.yfilter != YFilter.not_set or
                    self.number_pbb_core.yfilter != YFilter.not_set or
                    self.number_pbb_edge.yfilter != YFilter.not_set or
                    self.number_pseudowires.yfilter != YFilter.not_set or
                    self.out_of_memory_state.yfilter != YFilter.not_set or
                    self.partially_programmed_a_cs.yfilter != YFilter.not_set or
                    self.partially_programmed_bridges.yfilter != YFilter.not_set or
                    self.partially_programmed_pseudowires.yfilter != YFilter.not_set or
                    self.standby_pseudowires.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bridge-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.num_vn_is.is_set or self.num_vn_is.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.num_vn_is.get_name_leafdata())
                if (self.num_vn_is_down.is_set or self.num_vn_is_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.num_vn_is_down.get_name_leafdata())
                if (self.num_vn_is_unresolved.is_set or self.num_vn_is_unresolved.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.num_vn_is_unresolved.get_name_leafdata())
                if (self.num_vn_is_up.is_set or self.num_vn_is_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.num_vn_is_up.get_name_leafdata())
                if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                if (self.number_bridge_domains.is_set or self.number_bridge_domains.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_bridge_domains.get_name_leafdata())
                if (self.number_bridge_domains_shut.is_set or self.number_bridge_domains_shut.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_bridge_domains_shut.get_name_leafdata())
                if (self.number_bridge_domains_up.is_set or self.number_bridge_domains_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_bridge_domains_up.get_name_leafdata())
                if (self.number_default_bridge_doamins.is_set or self.number_default_bridge_doamins.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_default_bridge_doamins.get_name_leafdata())
                if (self.number_groups.is_set or self.number_groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_groups.get_name_leafdata())
                if (self.number_p2mp.is_set or self.number_p2mp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_p2mp.get_name_leafdata())
                if (self.number_p2mp_down.is_set or self.number_p2mp_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_p2mp_down.get_name_leafdata())
                if (self.number_p2mp_up.is_set or self.number_p2mp_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_p2mp_up.get_name_leafdata())
                if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                if (self.number_pbb_core.is_set or self.number_pbb_core.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_pbb_core.get_name_leafdata())
                if (self.number_pbb_edge.is_set or self.number_pbb_edge.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_pbb_edge.get_name_leafdata())
                if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                if (self.partially_programmed_a_cs.is_set or self.partially_programmed_a_cs.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.partially_programmed_a_cs.get_name_leafdata())
                if (self.partially_programmed_bridges.is_set or self.partially_programmed_bridges.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.partially_programmed_bridges.get_name_leafdata())
                if (self.partially_programmed_pseudowires.is_set or self.partially_programmed_pseudowires.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.partially_programmed_pseudowires.get_name_leafdata())
                if (self.standby_pseudowires.is_set or self.standby_pseudowires.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.standby_pseudowires.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "num-vn-is" or name == "num-vn-is-down" or name == "num-vn-is-unresolved" or name == "num-vn-is-up" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-bridge-domains" or name == "number-bridge-domains-shut" or name == "number-bridge-domains-up" or name == "number-default-bridge-doamins" or name == "number-groups" or name == "number-p2mp" or name == "number-p2mp-down" or name == "number-p2mp-up" or name == "number-p-ws-up" or name == "number-pbb-core" or name == "number-pbb-edge" or name == "number-pseudowires" or name == "out-of-memory-state" or name == "partially-programmed-a-cs" or name == "partially-programmed-bridges" or name == "partially-programmed-pseudowires" or name == "standby-pseudowires"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "num-vn-is"):
                    self.num_vn_is = value
                    self.num_vn_is.value_namespace = name_space
                    self.num_vn_is.value_namespace_prefix = name_space_prefix
                if(value_path == "num-vn-is-down"):
                    self.num_vn_is_down = value
                    self.num_vn_is_down.value_namespace = name_space
                    self.num_vn_is_down.value_namespace_prefix = name_space_prefix
                if(value_path == "num-vn-is-unresolved"):
                    self.num_vn_is_unresolved = value
                    self.num_vn_is_unresolved.value_namespace = name_space
                    self.num_vn_is_unresolved.value_namespace_prefix = name_space_prefix
                if(value_path == "num-vn-is-up"):
                    self.num_vn_is_up = value
                    self.num_vn_is_up.value_namespace = name_space
                    self.num_vn_is_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-a-cs"):
                    self.number_a_cs = value
                    self.number_a_cs.value_namespace = name_space
                    self.number_a_cs.value_namespace_prefix = name_space_prefix
                if(value_path == "number-a-cs-up"):
                    self.number_a_cs_up = value
                    self.number_a_cs_up.value_namespace = name_space
                    self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-bridge-domains"):
                    self.number_bridge_domains = value
                    self.number_bridge_domains.value_namespace = name_space
                    self.number_bridge_domains.value_namespace_prefix = name_space_prefix
                if(value_path == "number-bridge-domains-shut"):
                    self.number_bridge_domains_shut = value
                    self.number_bridge_domains_shut.value_namespace = name_space
                    self.number_bridge_domains_shut.value_namespace_prefix = name_space_prefix
                if(value_path == "number-bridge-domains-up"):
                    self.number_bridge_domains_up = value
                    self.number_bridge_domains_up.value_namespace = name_space
                    self.number_bridge_domains_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-default-bridge-doamins"):
                    self.number_default_bridge_doamins = value
                    self.number_default_bridge_doamins.value_namespace = name_space
                    self.number_default_bridge_doamins.value_namespace_prefix = name_space_prefix
                if(value_path == "number-groups"):
                    self.number_groups = value
                    self.number_groups.value_namespace = name_space
                    self.number_groups.value_namespace_prefix = name_space_prefix
                if(value_path == "number-p2mp"):
                    self.number_p2mp = value
                    self.number_p2mp.value_namespace = name_space
                    self.number_p2mp.value_namespace_prefix = name_space_prefix
                if(value_path == "number-p2mp-down"):
                    self.number_p2mp_down = value
                    self.number_p2mp_down.value_namespace = name_space
                    self.number_p2mp_down.value_namespace_prefix = name_space_prefix
                if(value_path == "number-p2mp-up"):
                    self.number_p2mp_up = value
                    self.number_p2mp_up.value_namespace = name_space
                    self.number_p2mp_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-p-ws-up"):
                    self.number_p_ws_up = value
                    self.number_p_ws_up.value_namespace = name_space
                    self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-pbb-core"):
                    self.number_pbb_core = value
                    self.number_pbb_core.value_namespace = name_space
                    self.number_pbb_core.value_namespace_prefix = name_space_prefix
                if(value_path == "number-pbb-edge"):
                    self.number_pbb_edge = value
                    self.number_pbb_edge.value_namespace = name_space
                    self.number_pbb_edge.value_namespace_prefix = name_space_prefix
                if(value_path == "number-pseudowires"):
                    self.number_pseudowires = value
                    self.number_pseudowires.value_namespace = name_space
                    self.number_pseudowires.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-memory-state"):
                    self.out_of_memory_state = value
                    self.out_of_memory_state.value_namespace = name_space
                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                if(value_path == "partially-programmed-a-cs"):
                    self.partially_programmed_a_cs = value
                    self.partially_programmed_a_cs.value_namespace = name_space
                    self.partially_programmed_a_cs.value_namespace_prefix = name_space_prefix
                if(value_path == "partially-programmed-bridges"):
                    self.partially_programmed_bridges = value
                    self.partially_programmed_bridges.value_namespace = name_space
                    self.partially_programmed_bridges.value_namespace_prefix = name_space_prefix
                if(value_path == "partially-programmed-pseudowires"):
                    self.partially_programmed_pseudowires = value
                    self.partially_programmed_pseudowires.value_namespace = name_space
                    self.partially_programmed_pseudowires.value_namespace_prefix = name_space_prefix
                if(value_path == "standby-pseudowires"):
                    self.standby_pseudowires = value
                    self.standby_pseudowires.value_namespace = name_space
                    self.standby_pseudowires.value_namespace_prefix = name_space_prefix


        class Nsr(Entity):
            """
            L2VPN NSR information
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.EventHistory>`
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.FailoverStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.IssuStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.NsrStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.ReportCard>`
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\:  bool
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.XidInfo>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.Nsr, self).__init__()

                self.yang_name = "nsr"
                self.yang_parent_name = "active"

                self.process_role = YLeaf(YType.uint8, "process-role")

                self.process_state = YLeaf(YType.uint8, "process-state")

                self.state_transition_time = YLeafList(YType.uint32, "state-transition-time")

                self.sw_install_in_progress = YLeaf(YType.boolean, "sw-install-in-progress")

                self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                self.failover_status = L2Vpnv2.Active.Nsr.FailoverStatus()
                self.failover_status.parent = self
                self._children_name_map["failover_status"] = "failover-status"
                self._children_yang_names.add("failover-status")

                self.issu_status = L2Vpnv2.Active.Nsr.IssuStatus()
                self.issu_status.parent = self
                self._children_name_map["issu_status"] = "issu-status"
                self._children_yang_names.add("issu-status")

                self.nsr_status = L2Vpnv2.Active.Nsr.NsrStatus()
                self.nsr_status.parent = self
                self._children_name_map["nsr_status"] = "nsr-status"
                self._children_yang_names.add("nsr-status")

                self.event_history = YList(self)
                self.report_card = YList(self)
                self.xid_info = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("process_role",
                                "process_state",
                                "state_transition_time",
                                "sw_install_in_progress",
                                "sync_flags") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.Nsr, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.Nsr, self).__setattr__(name, value)


            class FailoverStatus(Entity):
                """
                L2VPN failover status
                
                .. attribute:: master_time
                
                	Master time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Nsr.FailoverStatus, self).__init__()

                    self.yang_name = "failover-status"
                    self.yang_parent_name = "nsr"

                    self.master_time = YLeaf(YType.uint32, "master-time")

                    self.start_time = YLeaf(YType.uint32, "start-time")

                    self.triggered_time = YLeaf(YType.uint32, "triggered-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("master_time",
                                    "start_time",
                                    "triggered_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Nsr.FailoverStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Nsr.FailoverStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.master_time.is_set or
                        self.start_time.is_set or
                        self.triggered_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.master_time.yfilter != YFilter.not_set or
                        self.start_time.yfilter != YFilter.not_set or
                        self.triggered_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "failover-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.master_time.is_set or self.master_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.master_time.get_name_leafdata())
                    if (self.start_time.is_set or self.start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.start_time.get_name_leafdata())
                    if (self.triggered_time.is_set or self.triggered_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.triggered_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "master-time" or name == "start-time" or name == "triggered-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "master-time"):
                        self.master_time = value
                        self.master_time.value_namespace = name_space
                        self.master_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "start-time"):
                        self.start_time = value
                        self.start_time.value_namespace = name_space
                        self.start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "triggered-time"):
                        self.triggered_time = value
                        self.triggered_time.value_namespace = name_space
                        self.triggered_time.value_namespace_prefix = name_space_prefix


            class NsrStatus(Entity):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Nsr.NsrStatus, self).__init__()

                    self.yang_name = "nsr-status"
                    self.yang_parent_name = "nsr"

                    self.role = YLeaf(YType.enumeration, "role")

                    self.idt_status = L2Vpnv2.Active.Nsr.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"
                    self._children_yang_names.add("idt-status")

                    self.previ_ous_idt_status = L2Vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._children_yang_names.add("previ-ous-idt-status")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("role") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Nsr.NsrStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Nsr.NsrStatus, self).__setattr__(name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Nsr.NsrStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "nsr-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Nsr.NsrStatus.IdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Nsr.NsrStatus.IdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/nsr-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "nsr-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "previ-ous-idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/nsr-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.role.is_set or
                        (self.idt_status is not None and self.idt_status.has_data()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.role.yfilter != YFilter.not_set or
                        (self.idt_status is not None and self.idt_status.has_operation()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "idt-status"):
                        if (self.idt_status is None):
                            self.idt_status = L2Vpnv2.Active.Nsr.NsrStatus.IdtStatus()
                            self.idt_status.parent = self
                            self._children_name_map["idt_status"] = "idt-status"
                        return self.idt_status

                    if (child_yang_name == "previ-ous-idt-status"):
                        if (self.previ_ous_idt_status is None):
                            self.previ_ous_idt_status = L2Vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus()
                            self.previ_ous_idt_status.parent = self
                            self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        return self.previ_ous_idt_status

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "role"):
                        self.role = value
                        self.role.value_namespace = name_space
                        self.role.value_namespace_prefix = name_space_prefix


            class IssuStatus(Entity):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Nsr.IssuStatus, self).__init__()

                    self.yang_name = "issu-status"
                    self.yang_parent_name = "nsr"

                    self.role = YLeaf(YType.enumeration, "role")

                    self.idt_status = L2Vpnv2.Active.Nsr.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"
                    self._children_yang_names.add("idt-status")

                    self.previ_ous_idt_status = L2Vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._children_yang_names.add("previ-ous-idt-status")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("role") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Nsr.IssuStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Nsr.IssuStatus, self).__setattr__(name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Nsr.IssuStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "issu-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Nsr.IssuStatus.IdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Nsr.IssuStatus.IdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/issu-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "issu-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "previ-ous-idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/issu-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.role.is_set or
                        (self.idt_status is not None and self.idt_status.has_data()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.role.yfilter != YFilter.not_set or
                        (self.idt_status is not None and self.idt_status.has_operation()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "issu-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "idt-status"):
                        if (self.idt_status is None):
                            self.idt_status = L2Vpnv2.Active.Nsr.IssuStatus.IdtStatus()
                            self.idt_status.parent = self
                            self._children_name_map["idt_status"] = "idt-status"
                        return self.idt_status

                    if (child_yang_name == "previ-ous-idt-status"):
                        if (self.previ_ous_idt_status is None):
                            self.previ_ous_idt_status = L2Vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus()
                            self.previ_ous_idt_status.parent = self
                            self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        return self.previ_ous_idt_status

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "role"):
                        self.role = value
                        self.role.value_namespace = name_space
                        self.role.value_namespace_prefix = name_space_prefix


            class XidInfo(Entity):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Nsr.XidInfo, self).__init__()

                    self.yang_name = "xid-info"
                    self.yang_parent_name = "nsr"

                    self.app_type = YLeaf(YType.enumeration, "app-type")

                    self.sent_ids = YLeaf(YType.uint32, "sent-ids")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("app_type",
                                    "sent_ids") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Nsr.XidInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Nsr.XidInfo, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.app_type.is_set or
                        self.sent_ids.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.app_type.yfilter != YFilter.not_set or
                        self.sent_ids.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xid-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.app_type.is_set or self.app_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.app_type.get_name_leafdata())
                    if (self.sent_ids.is_set or self.sent_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sent_ids.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "app-type" or name == "sent-ids"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "app-type"):
                        self.app_type = value
                        self.app_type.value_namespace = name_space
                        self.app_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "sent-ids"):
                        self.sent_ids = value
                        self.sent_ids.value_namespace = name_space
                        self.sent_ids.value_namespace_prefix = name_space_prefix


            class ReportCard(Entity):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\:  bool
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\:  bool
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\:  bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Nsr.ReportCard, self).__init__()

                    self.yang_name = "report-card"
                    self.yang_parent_name = "nsr"

                    self.collaborator_idt_done = YLeaf(YType.boolean, "collaborator-idt-done")

                    self.collaborator_is_connected = YLeaf(YType.boolean, "collaborator-is-connected")

                    self.collaborator_skipped = YLeaf(YType.boolean, "collaborator-skipped")

                    self.connection_change_time = YLeaf(YType.uint32, "connection-change-time")

                    self.idt_time = YLeaf(YType.uint32, "idt-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("collaborator_idt_done",
                                    "collaborator_is_connected",
                                    "collaborator_skipped",
                                    "connection_change_time",
                                    "idt_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Nsr.ReportCard, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Nsr.ReportCard, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.collaborator_idt_done.is_set or
                        self.collaborator_is_connected.is_set or
                        self.collaborator_skipped.is_set or
                        self.connection_change_time.is_set or
                        self.idt_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.collaborator_idt_done.yfilter != YFilter.not_set or
                        self.collaborator_is_connected.yfilter != YFilter.not_set or
                        self.collaborator_skipped.yfilter != YFilter.not_set or
                        self.connection_change_time.yfilter != YFilter.not_set or
                        self.idt_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "report-card" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.collaborator_idt_done.is_set or self.collaborator_idt_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_idt_done.get_name_leafdata())
                    if (self.collaborator_is_connected.is_set or self.collaborator_is_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_is_connected.get_name_leafdata())
                    if (self.collaborator_skipped.is_set or self.collaborator_skipped.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_skipped.get_name_leafdata())
                    if (self.connection_change_time.is_set or self.connection_change_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.connection_change_time.get_name_leafdata())
                    if (self.idt_time.is_set or self.idt_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "collaborator-idt-done" or name == "collaborator-is-connected" or name == "collaborator-skipped" or name == "connection-change-time" or name == "idt-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "collaborator-idt-done"):
                        self.collaborator_idt_done = value
                        self.collaborator_idt_done.value_namespace = name_space
                        self.collaborator_idt_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "collaborator-is-connected"):
                        self.collaborator_is_connected = value
                        self.collaborator_is_connected.value_namespace = name_space
                        self.collaborator_is_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "collaborator-skipped"):
                        self.collaborator_skipped = value
                        self.collaborator_skipped.value_namespace = name_space
                        self.collaborator_skipped.value_namespace_prefix = name_space_prefix
                    if(value_path == "connection-change-time"):
                        self.connection_change_time = value
                        self.connection_change_time.value_namespace = name_space
                        self.connection_change_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-time"):
                        self.idt_time = value
                        self.idt_time.value_namespace = name_space
                        self.idt_time.value_namespace_prefix = name_space_prefix


            class EventHistory(Entity):
                """
                L2VPN Process event history
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: new_state
                
                	New state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: process_event
                
                	Process event
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Nsr.EventHistory, self).__init__()

                    self.yang_name = "event-history"
                    self.yang_parent_name = "nsr"

                    self.event_timestamp = YLeaf(YType.uint32, "event-timestamp")

                    self.new_state = YLeaf(YType.uint8, "new-state")

                    self.previous_state = YLeaf(YType.uint8, "previous-state")

                    self.process_collaborator = YLeaf(YType.uint16, "process-collaborator")

                    self.process_event = YLeaf(YType.uint16, "process-event")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("event_timestamp",
                                    "new_state",
                                    "previous_state",
                                    "process_collaborator",
                                    "process_event") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Nsr.EventHistory, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Nsr.EventHistory, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.event_timestamp.is_set or
                        self.new_state.is_set or
                        self.previous_state.is_set or
                        self.process_collaborator.is_set or
                        self.process_event.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.event_timestamp.yfilter != YFilter.not_set or
                        self.new_state.yfilter != YFilter.not_set or
                        self.previous_state.yfilter != YFilter.not_set or
                        self.process_collaborator.yfilter != YFilter.not_set or
                        self.process_event.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "event-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.event_timestamp.is_set or self.event_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.event_timestamp.get_name_leafdata())
                    if (self.new_state.is_set or self.new_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.new_state.get_name_leafdata())
                    if (self.previous_state.is_set or self.previous_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.previous_state.get_name_leafdata())
                    if (self.process_collaborator.is_set or self.process_collaborator.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_collaborator.get_name_leafdata())
                    if (self.process_event.is_set or self.process_event.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_event.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "event-timestamp" or name == "new-state" or name == "previous-state" or name == "process-collaborator" or name == "process-event"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "event-timestamp"):
                        self.event_timestamp = value
                        self.event_timestamp.value_namespace = name_space
                        self.event_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "new-state"):
                        self.new_state = value
                        self.new_state.value_namespace = name_space
                        self.new_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "previous-state"):
                        self.previous_state = value
                        self.previous_state.value_namespace = name_space
                        self.previous_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-collaborator"):
                        self.process_collaborator = value
                        self.process_collaborator.value_namespace = name_space
                        self.process_collaborator.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-event"):
                        self.process_event = value
                        self.process_event.value_namespace = name_space
                        self.process_event.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.event_history:
                    if (c.has_data()):
                        return True
                for c in self.report_card:
                    if (c.has_data()):
                        return True
                for c in self.xid_info:
                    if (c.has_data()):
                        return True
                for leaf in self.state_transition_time.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                return (
                    self.process_role.is_set or
                    self.process_state.is_set or
                    self.sw_install_in_progress.is_set or
                    self.sync_flags.is_set or
                    (self.failover_status is not None and self.failover_status.has_data()) or
                    (self.issu_status is not None and self.issu_status.has_data()) or
                    (self.nsr_status is not None and self.nsr_status.has_data()))

            def has_operation(self):
                for c in self.event_history:
                    if (c.has_operation()):
                        return True
                for c in self.report_card:
                    if (c.has_operation()):
                        return True
                for c in self.xid_info:
                    if (c.has_operation()):
                        return True
                for leaf in self.state_transition_time.getYLeafs():
                    if (leaf.is_set):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.process_role.yfilter != YFilter.not_set or
                    self.process_state.yfilter != YFilter.not_set or
                    self.state_transition_time.yfilter != YFilter.not_set or
                    self.sw_install_in_progress.yfilter != YFilter.not_set or
                    self.sync_flags.yfilter != YFilter.not_set or
                    (self.failover_status is not None and self.failover_status.has_operation()) or
                    (self.issu_status is not None and self.issu_status.has_operation()) or
                    (self.nsr_status is not None and self.nsr_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "nsr" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.process_role.is_set or self.process_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_role.get_name_leafdata())
                if (self.process_state.is_set or self.process_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_state.get_name_leafdata())
                if (self.sw_install_in_progress.is_set or self.sw_install_in_progress.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sw_install_in_progress.get_name_leafdata())
                if (self.sync_flags.is_set or self.sync_flags.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sync_flags.get_name_leafdata())

                leaf_name_data.extend(self.state_transition_time.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "event-history"):
                    for c in self.event_history:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.Nsr.EventHistory()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.event_history.append(c)
                    return c

                if (child_yang_name == "failover-status"):
                    if (self.failover_status is None):
                        self.failover_status = L2Vpnv2.Active.Nsr.FailoverStatus()
                        self.failover_status.parent = self
                        self._children_name_map["failover_status"] = "failover-status"
                    return self.failover_status

                if (child_yang_name == "issu-status"):
                    if (self.issu_status is None):
                        self.issu_status = L2Vpnv2.Active.Nsr.IssuStatus()
                        self.issu_status.parent = self
                        self._children_name_map["issu_status"] = "issu-status"
                    return self.issu_status

                if (child_yang_name == "nsr-status"):
                    if (self.nsr_status is None):
                        self.nsr_status = L2Vpnv2.Active.Nsr.NsrStatus()
                        self.nsr_status.parent = self
                        self._children_name_map["nsr_status"] = "nsr-status"
                    return self.nsr_status

                if (child_yang_name == "report-card"):
                    for c in self.report_card:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.Nsr.ReportCard()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.report_card.append(c)
                    return c

                if (child_yang_name == "xid-info"):
                    for c in self.xid_info:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.Nsr.XidInfo()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xid_info.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "event-history" or name == "failover-status" or name == "issu-status" or name == "nsr-status" or name == "report-card" or name == "xid-info" or name == "process-role" or name == "process-state" or name == "state-transition-time" or name == "sw-install-in-progress" or name == "sync-flags"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "process-role"):
                    self.process_role = value
                    self.process_role.value_namespace = name_space
                    self.process_role.value_namespace_prefix = name_space_prefix
                if(value_path == "process-state"):
                    self.process_state = value
                    self.process_state.value_namespace = name_space
                    self.process_state.value_namespace_prefix = name_space_prefix
                if(value_path == "state-transition-time"):
                    self.state_transition_time.append(value)
                if(value_path == "sw-install-in-progress"):
                    self.sw_install_in_progress = value
                    self.sw_install_in_progress.value_namespace = name_space
                    self.sw_install_in_progress.value_namespace_prefix = name_space_prefix
                if(value_path == "sync-flags"):
                    self.sync_flags = value
                    self.sync_flags.value_namespace = name_space
                    self.sync_flags.value_namespace_prefix = name_space_prefix


        class GlobalSettings(Entity):
            """
            L2VPN global settings
            
            .. attribute:: going_active
            
            	transitioning to Active functional role
            	**type**\:  bool
            
            .. attribute:: ha_role
            
            	Node redundancy role
            	**type**\:  str
            
            .. attribute:: issu_role
            
            	Node ISSU role
            	**type**\:  str
            
            .. attribute:: logging_bd_enabled
            
            	Logging BD state changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_df_election_enabled
            
            	Logging EVPN Designated Forwarder changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_nsr_enabled
            
            	Logging NSR state changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_pw_enabled
            
            	Logging PW enabled
            	**type**\:  bool
            
            .. attribute:: logging_vfi_enabled
            
            	Logging VFI state changes enabled
            	**type**\:  bool
            
            .. attribute:: process_fsm
            
            	Current L2VPN FSM role
            	**type**\:  str
            
            .. attribute:: pw_grouping_enabled
            
            	PW Grouping enabled
            	**type**\:  bool
            
            .. attribute:: pw_oam_refresh_transmit_time
            
            	PW OAM refresh transmit (seconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: pw_status_enabled
            
            	PW Status enabled
            	**type**\:  bool
            
            .. attribute:: tcn_propagation_enabled
            
            	TCN propagation enabled
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.GlobalSettings, self).__init__()

                self.yang_name = "global-settings"
                self.yang_parent_name = "active"

                self.going_active = YLeaf(YType.boolean, "going-active")

                self.ha_role = YLeaf(YType.str, "ha-role")

                self.issu_role = YLeaf(YType.str, "issu-role")

                self.logging_bd_enabled = YLeaf(YType.boolean, "logging-bd-enabled")

                self.logging_df_election_enabled = YLeaf(YType.boolean, "logging-df-election-enabled")

                self.logging_nsr_enabled = YLeaf(YType.boolean, "logging-nsr-enabled")

                self.logging_pw_enabled = YLeaf(YType.boolean, "logging-pw-enabled")

                self.logging_vfi_enabled = YLeaf(YType.boolean, "logging-vfi-enabled")

                self.process_fsm = YLeaf(YType.str, "process-fsm")

                self.pw_grouping_enabled = YLeaf(YType.boolean, "pw-grouping-enabled")

                self.pw_oam_refresh_transmit_time = YLeaf(YType.uint32, "pw-oam-refresh-transmit-time")

                self.pw_status_enabled = YLeaf(YType.boolean, "pw-status-enabled")

                self.tcn_propagation_enabled = YLeaf(YType.boolean, "tcn-propagation-enabled")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("going_active",
                                "ha_role",
                                "issu_role",
                                "logging_bd_enabled",
                                "logging_df_election_enabled",
                                "logging_nsr_enabled",
                                "logging_pw_enabled",
                                "logging_vfi_enabled",
                                "process_fsm",
                                "pw_grouping_enabled",
                                "pw_oam_refresh_transmit_time",
                                "pw_status_enabled",
                                "tcn_propagation_enabled") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.GlobalSettings, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.GlobalSettings, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.going_active.is_set or
                    self.ha_role.is_set or
                    self.issu_role.is_set or
                    self.logging_bd_enabled.is_set or
                    self.logging_df_election_enabled.is_set or
                    self.logging_nsr_enabled.is_set or
                    self.logging_pw_enabled.is_set or
                    self.logging_vfi_enabled.is_set or
                    self.process_fsm.is_set or
                    self.pw_grouping_enabled.is_set or
                    self.pw_oam_refresh_transmit_time.is_set or
                    self.pw_status_enabled.is_set or
                    self.tcn_propagation_enabled.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.going_active.yfilter != YFilter.not_set or
                    self.ha_role.yfilter != YFilter.not_set or
                    self.issu_role.yfilter != YFilter.not_set or
                    self.logging_bd_enabled.yfilter != YFilter.not_set or
                    self.logging_df_election_enabled.yfilter != YFilter.not_set or
                    self.logging_nsr_enabled.yfilter != YFilter.not_set or
                    self.logging_pw_enabled.yfilter != YFilter.not_set or
                    self.logging_vfi_enabled.yfilter != YFilter.not_set or
                    self.process_fsm.yfilter != YFilter.not_set or
                    self.pw_grouping_enabled.yfilter != YFilter.not_set or
                    self.pw_oam_refresh_transmit_time.yfilter != YFilter.not_set or
                    self.pw_status_enabled.yfilter != YFilter.not_set or
                    self.tcn_propagation_enabled.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "global-settings" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.going_active.is_set or self.going_active.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.going_active.get_name_leafdata())
                if (self.ha_role.is_set or self.ha_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ha_role.get_name_leafdata())
                if (self.issu_role.is_set or self.issu_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.issu_role.get_name_leafdata())
                if (self.logging_bd_enabled.is_set or self.logging_bd_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.logging_bd_enabled.get_name_leafdata())
                if (self.logging_df_election_enabled.is_set or self.logging_df_election_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.logging_df_election_enabled.get_name_leafdata())
                if (self.logging_nsr_enabled.is_set or self.logging_nsr_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.logging_nsr_enabled.get_name_leafdata())
                if (self.logging_pw_enabled.is_set or self.logging_pw_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.logging_pw_enabled.get_name_leafdata())
                if (self.logging_vfi_enabled.is_set or self.logging_vfi_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.logging_vfi_enabled.get_name_leafdata())
                if (self.process_fsm.is_set or self.process_fsm.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_fsm.get_name_leafdata())
                if (self.pw_grouping_enabled.is_set or self.pw_grouping_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pw_grouping_enabled.get_name_leafdata())
                if (self.pw_oam_refresh_transmit_time.is_set or self.pw_oam_refresh_transmit_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pw_oam_refresh_transmit_time.get_name_leafdata())
                if (self.pw_status_enabled.is_set or self.pw_status_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pw_status_enabled.get_name_leafdata())
                if (self.tcn_propagation_enabled.is_set or self.tcn_propagation_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.tcn_propagation_enabled.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "going-active" or name == "ha-role" or name == "issu-role" or name == "logging-bd-enabled" or name == "logging-df-election-enabled" or name == "logging-nsr-enabled" or name == "logging-pw-enabled" or name == "logging-vfi-enabled" or name == "process-fsm" or name == "pw-grouping-enabled" or name == "pw-oam-refresh-transmit-time" or name == "pw-status-enabled" or name == "tcn-propagation-enabled"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "going-active"):
                    self.going_active = value
                    self.going_active.value_namespace = name_space
                    self.going_active.value_namespace_prefix = name_space_prefix
                if(value_path == "ha-role"):
                    self.ha_role = value
                    self.ha_role.value_namespace = name_space
                    self.ha_role.value_namespace_prefix = name_space_prefix
                if(value_path == "issu-role"):
                    self.issu_role = value
                    self.issu_role.value_namespace = name_space
                    self.issu_role.value_namespace_prefix = name_space_prefix
                if(value_path == "logging-bd-enabled"):
                    self.logging_bd_enabled = value
                    self.logging_bd_enabled.value_namespace = name_space
                    self.logging_bd_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "logging-df-election-enabled"):
                    self.logging_df_election_enabled = value
                    self.logging_df_election_enabled.value_namespace = name_space
                    self.logging_df_election_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "logging-nsr-enabled"):
                    self.logging_nsr_enabled = value
                    self.logging_nsr_enabled.value_namespace = name_space
                    self.logging_nsr_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "logging-pw-enabled"):
                    self.logging_pw_enabled = value
                    self.logging_pw_enabled.value_namespace = name_space
                    self.logging_pw_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "logging-vfi-enabled"):
                    self.logging_vfi_enabled = value
                    self.logging_vfi_enabled.value_namespace = name_space
                    self.logging_vfi_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "process-fsm"):
                    self.process_fsm = value
                    self.process_fsm.value_namespace = name_space
                    self.process_fsm.value_namespace_prefix = name_space_prefix
                if(value_path == "pw-grouping-enabled"):
                    self.pw_grouping_enabled = value
                    self.pw_grouping_enabled.value_namespace = name_space
                    self.pw_grouping_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "pw-oam-refresh-transmit-time"):
                    self.pw_oam_refresh_transmit_time = value
                    self.pw_oam_refresh_transmit_time.value_namespace = name_space
                    self.pw_oam_refresh_transmit_time.value_namespace_prefix = name_space_prefix
                if(value_path == "pw-status-enabled"):
                    self.pw_status_enabled = value
                    self.pw_status_enabled.value_namespace = name_space
                    self.pw_status_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "tcn-propagation-enabled"):
                    self.tcn_propagation_enabled = value
                    self.tcn_propagation_enabled.value_namespace = name_space
                    self.tcn_propagation_enabled.value_namespace_prefix = name_space_prefix


        class Pwr(Entity):
            """
            Pseudowire Routing Table
            
            .. attribute:: summary
            
            	L2VPN Pseudowire Routing Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.Pwr, self).__init__()

                self.yang_name = "pwr"
                self.yang_parent_name = "active"

                self.summary = L2Vpnv2.Active.Pwr.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")


            class Summary(Entity):
                """
                L2VPN Pseudowire Routing Summary
                
                .. attribute:: bgp_as
                
                	BGP AS number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_router_id
                
                	BGP Router ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: cfg_global_id
                
                	Configured Global ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: cfg_router_id
                
                	Configured Router ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: l2vpn_has_bgp_eod
                
                	L2VPN got BGP EOD
                	**type**\:  bool
                
                .. attribute:: rd_auto
                
                	Automatic Route Distingtuisher
                	**type**\:   :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdAuto>`
                
                .. attribute:: rd_configured
                
                	Configured Route Distinguisher
                	**type**\:   :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdConfigured>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Pwr.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "pwr"

                    self.bgp_as = YLeaf(YType.uint32, "bgp-as")

                    self.bgp_router_id = YLeaf(YType.str, "bgp-router-id")

                    self.cfg_global_id = YLeaf(YType.uint32, "cfg-global-id")

                    self.cfg_router_id = YLeaf(YType.str, "cfg-router-id")

                    self.l2vpn_has_bgp_eod = YLeaf(YType.boolean, "l2vpn-has-bgp-eod")

                    self.rd_auto = L2Vpnv2.Active.Pwr.Summary.RdAuto()
                    self.rd_auto.parent = self
                    self._children_name_map["rd_auto"] = "rd-auto"
                    self._children_yang_names.add("rd-auto")

                    self.rd_configured = L2Vpnv2.Active.Pwr.Summary.RdConfigured()
                    self.rd_configured.parent = self
                    self._children_name_map["rd_configured"] = "rd-configured"
                    self._children_yang_names.add("rd-configured")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bgp_as",
                                    "bgp_router_id",
                                    "cfg_global_id",
                                    "cfg_router_id",
                                    "l2vpn_has_bgp_eod") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Pwr.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Pwr.Summary, self).__setattr__(name, value)


                class RdAuto(Entity):
                    """
                    Automatic Route Distingtuisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdAuto.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdAuto.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Pwr.Summary.RdAuto, self).__init__()

                        self.yang_name = "rd-auto"
                        self.yang_parent_name = "summary"

                        self.rd = YLeaf(YType.enumeration, "rd")

                        self.auto = L2Vpnv2.Active.Pwr.Summary.RdAuto.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"
                        self._children_yang_names.add("auto")

                        self.four_byte_as = L2Vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"
                        self._children_yang_names.add("four-byte-as")

                        self.two_byte_as = L2Vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"
                        self._children_yang_names.add("two-byte-as")

                        self.v4_addr = L2Vpnv2.Active.Pwr.Summary.RdAuto.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._children_yang_names.add("v4-addr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("rd") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Pwr.Summary.RdAuto, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Pwr.Summary.RdAuto, self).__setattr__(name, value)


                    class Auto(Entity):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Pwr.Summary.RdAuto.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "rd-auto"

                            self.auto_index = YLeaf(YType.uint16, "auto-index")

                            self.router_id = YLeaf(YType.str, "router-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("auto_index",
                                            "router_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Pwr.Summary.RdAuto.Auto, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Pwr.Summary.RdAuto.Auto, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.auto_index.is_set or
                                self.router_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.auto_index.yfilter != YFilter.not_set or
                                self.router_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "auto" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-auto/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_index.get_name_leafdata())
                            if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto-index" or name == "router-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "auto-index"):
                                self.auto_index = value
                                self.auto_index.value_namespace = name_space
                                self.auto_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-id"):
                                self.router_id = value
                                self.router_id.value_namespace = name_space
                                self.router_id.value_namespace_prefix = name_space_prefix


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "rd-auto"

                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_index",
                                            "two_byte_as") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_index.is_set or
                                self.two_byte_as.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_index.yfilter != YFilter.not_set or
                                self.two_byte_as.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "two-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-auto/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-index" or name == "two-byte-as"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-index"):
                                self.four_byte_index = value
                                self.four_byte_index.value_namespace = name_space
                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-as"):
                                self.two_byte_as = value
                                self.two_byte_as.value_namespace = name_space
                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "rd-auto"

                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_as",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_as.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_as.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "four-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-auto/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-as" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-as"):
                                self.four_byte_as = value
                                self.four_byte_as.value_namespace = name_space
                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Pwr.Summary.RdAuto.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "rd-auto"

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ipv4_address",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Pwr.Summary.RdAuto.V4Addr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Pwr.Summary.RdAuto.V4Addr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ipv4_address.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "v4-addr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-auto/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4-address" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.rd.is_set or
                            (self.auto is not None and self.auto.has_data()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                            (self.v4_addr is not None and self.v4_addr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.rd.yfilter != YFilter.not_set or
                            (self.auto is not None and self.auto.has_operation()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rd-auto" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rd.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "auto"):
                            if (self.auto is None):
                                self.auto = L2Vpnv2.Active.Pwr.Summary.RdAuto.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                            return self.auto

                        if (child_yang_name == "four-byte-as"):
                            if (self.four_byte_as is None):
                                self.four_byte_as = L2Vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                            return self.four_byte_as

                        if (child_yang_name == "two-byte-as"):
                            if (self.two_byte_as is None):
                                self.two_byte_as = L2Vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                            return self.two_byte_as

                        if (child_yang_name == "v4-addr"):
                            if (self.v4_addr is None):
                                self.v4_addr = L2Vpnv2.Active.Pwr.Summary.RdAuto.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                            return self.v4_addr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "rd"):
                            self.rd = value
                            self.rd.value_namespace = name_space
                            self.rd.value_namespace_prefix = name_space_prefix


                class RdConfigured(Entity):
                    """
                    Configured Route Distinguisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdConfigured.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Pwr.Summary.RdConfigured, self).__init__()

                        self.yang_name = "rd-configured"
                        self.yang_parent_name = "summary"

                        self.rd = YLeaf(YType.enumeration, "rd")

                        self.auto = L2Vpnv2.Active.Pwr.Summary.RdConfigured.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"
                        self._children_yang_names.add("auto")

                        self.four_byte_as = L2Vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"
                        self._children_yang_names.add("four-byte-as")

                        self.two_byte_as = L2Vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"
                        self._children_yang_names.add("two-byte-as")

                        self.v4_addr = L2Vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._children_yang_names.add("v4-addr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("rd") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Pwr.Summary.RdConfigured, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Pwr.Summary.RdConfigured, self).__setattr__(name, value)


                    class Auto(Entity):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "rd-configured"

                            self.auto_index = YLeaf(YType.uint16, "auto-index")

                            self.router_id = YLeaf(YType.str, "router-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("auto_index",
                                            "router_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.Auto, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.Auto, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.auto_index.is_set or
                                self.router_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.auto_index.yfilter != YFilter.not_set or
                                self.router_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "auto" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-configured/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_index.get_name_leafdata())
                            if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto-index" or name == "router-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "auto-index"):
                                self.auto_index = value
                                self.auto_index.value_namespace = name_space
                                self.auto_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-id"):
                                self.router_id = value
                                self.router_id.value_namespace = name_space
                                self.router_id.value_namespace_prefix = name_space_prefix


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "rd-configured"

                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_index",
                                            "two_byte_as") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_index.is_set or
                                self.two_byte_as.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_index.yfilter != YFilter.not_set or
                                self.two_byte_as.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "two-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-configured/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-index" or name == "two-byte-as"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-index"):
                                self.four_byte_index = value
                                self.four_byte_index.value_namespace = name_space
                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-as"):
                                self.two_byte_as = value
                                self.two_byte_as.value_namespace = name_space
                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "rd-configured"

                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_as",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_as.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_as.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "four-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-configured/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-as" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-as"):
                                self.four_byte_as = value
                                self.four_byte_as.value_namespace = name_space
                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "rd-configured"

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ipv4_address",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ipv4_address.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "v4-addr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-configured/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4-address" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.rd.is_set or
                            (self.auto is not None and self.auto.has_data()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                            (self.v4_addr is not None and self.v4_addr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.rd.yfilter != YFilter.not_set or
                            (self.auto is not None and self.auto.has_operation()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rd-configured" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rd.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "auto"):
                            if (self.auto is None):
                                self.auto = L2Vpnv2.Active.Pwr.Summary.RdConfigured.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                            return self.auto

                        if (child_yang_name == "four-byte-as"):
                            if (self.four_byte_as is None):
                                self.four_byte_as = L2Vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                            return self.four_byte_as

                        if (child_yang_name == "two-byte-as"):
                            if (self.two_byte_as is None):
                                self.two_byte_as = L2Vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                            return self.two_byte_as

                        if (child_yang_name == "v4-addr"):
                            if (self.v4_addr is None):
                                self.v4_addr = L2Vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                            return self.v4_addr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "rd"):
                            self.rd = value
                            self.rd.value_namespace = name_space
                            self.rd.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bgp_as.is_set or
                        self.bgp_router_id.is_set or
                        self.cfg_global_id.is_set or
                        self.cfg_router_id.is_set or
                        self.l2vpn_has_bgp_eod.is_set or
                        (self.rd_auto is not None and self.rd_auto.has_data()) or
                        (self.rd_configured is not None and self.rd_configured.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bgp_as.yfilter != YFilter.not_set or
                        self.bgp_router_id.yfilter != YFilter.not_set or
                        self.cfg_global_id.yfilter != YFilter.not_set or
                        self.cfg_router_id.yfilter != YFilter.not_set or
                        self.l2vpn_has_bgp_eod.yfilter != YFilter.not_set or
                        (self.rd_auto is not None and self.rd_auto.has_operation()) or
                        (self.rd_configured is not None and self.rd_configured.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bgp_as.is_set or self.bgp_as.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_as.get_name_leafdata())
                    if (self.bgp_router_id.is_set or self.bgp_router_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_router_id.get_name_leafdata())
                    if (self.cfg_global_id.is_set or self.cfg_global_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cfg_global_id.get_name_leafdata())
                    if (self.cfg_router_id.is_set or self.cfg_router_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cfg_router_id.get_name_leafdata())
                    if (self.l2vpn_has_bgp_eod.is_set or self.l2vpn_has_bgp_eod.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.l2vpn_has_bgp_eod.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rd-auto"):
                        if (self.rd_auto is None):
                            self.rd_auto = L2Vpnv2.Active.Pwr.Summary.RdAuto()
                            self.rd_auto.parent = self
                            self._children_name_map["rd_auto"] = "rd-auto"
                        return self.rd_auto

                    if (child_yang_name == "rd-configured"):
                        if (self.rd_configured is None):
                            self.rd_configured = L2Vpnv2.Active.Pwr.Summary.RdConfigured()
                            self.rd_configured.parent = self
                            self._children_name_map["rd_configured"] = "rd-configured"
                        return self.rd_configured

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rd-auto" or name == "rd-configured" or name == "bgp-as" or name == "bgp-router-id" or name == "cfg-global-id" or name == "cfg-router-id" or name == "l2vpn-has-bgp-eod"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bgp-as"):
                        self.bgp_as = value
                        self.bgp_as.value_namespace = name_space
                        self.bgp_as.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-router-id"):
                        self.bgp_router_id = value
                        self.bgp_router_id.value_namespace = name_space
                        self.bgp_router_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "cfg-global-id"):
                        self.cfg_global_id = value
                        self.cfg_global_id.value_namespace = name_space
                        self.cfg_global_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "cfg-router-id"):
                        self.cfg_router_id = value
                        self.cfg_router_id.value_namespace = name_space
                        self.cfg_router_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "l2vpn-has-bgp-eod"):
                        self.l2vpn_has_bgp_eod = value
                        self.l2vpn_has_bgp_eod.value_namespace = name_space
                        self.l2vpn_has_bgp_eod.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.summary is not None and self.summary.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.summary is not None and self.summary.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "pwr" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = L2Vpnv2.Active.Pwr.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "summary"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class XconnectMp2MpCe2Ces(Entity):
            """
            XConnect MP2MP CE2CE Table
            
            .. attribute:: xconnect_mp2mp_ce2ce
            
            	XConnect MP2MP CE2CE information
            	**type**\: list of    :py:class:`XconnectMp2MpCe2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.XconnectMp2MpCe2Ces, self).__init__()

                self.yang_name = "xconnect-mp2mp-ce2ces"
                self.yang_parent_name = "active"

                self.xconnect_mp2mp_ce2ce = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.XconnectMp2MpCe2Ces, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.XconnectMp2MpCe2Ces, self).__setattr__(name, value)


            class XconnectMp2MpCe2Ce(Entity):
                """
                XConnect MP2MP CE2CE information
                
                .. attribute:: ce_added
                
                	CE2CE Advertised
                	**type**\:  bool
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: local_ceid
                
                	Local CE ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: local_customer_edge_id
                
                	Local CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\:  str
                
                	**length:** 1..26
                
                .. attribute:: remote_ceid
                
                	Remote CE ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: remote_customer_edge_id
                
                	Remote CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__init__()

                    self.yang_name = "xconnect-mp2mp-ce2ce"
                    self.yang_parent_name = "xconnect-mp2mp-ce2ces"

                    self.ce_added = YLeaf(YType.boolean, "ce-added")

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                    self.local_customer_edge_id = YLeaf(YType.uint16, "local-customer-edge-id")

                    self.mp2_mp_name = YLeaf(YType.str, "mp2-mp-name")

                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                    self.remote_customer_edge_id = YLeaf(YType.uint16, "remote-customer-edge-id")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ce_added",
                                    "group_name",
                                    "local_ceid",
                                    "local_customer_edge_id",
                                    "mp2_mp_name",
                                    "remote_ceid",
                                    "remote_customer_edge_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ce_added.is_set or
                        self.group_name.is_set or
                        self.local_ceid.is_set or
                        self.local_customer_edge_id.is_set or
                        self.mp2_mp_name.is_set or
                        self.remote_ceid.is_set or
                        self.remote_customer_edge_id.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ce_added.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.local_ceid.yfilter != YFilter.not_set or
                        self.local_customer_edge_id.yfilter != YFilter.not_set or
                        self.mp2_mp_name.yfilter != YFilter.not_set or
                        self.remote_ceid.yfilter != YFilter.not_set or
                        self.remote_customer_edge_id.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-mp2mp-ce2ce" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mp-ce2ces/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ce_added.is_set or self.ce_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ce_added.get_name_leafdata())
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                    if (self.local_customer_edge_id.is_set or self.local_customer_edge_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_customer_edge_id.get_name_leafdata())
                    if (self.mp2_mp_name.is_set or self.mp2_mp_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mp2_mp_name.get_name_leafdata())
                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                    if (self.remote_customer_edge_id.is_set or self.remote_customer_edge_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote_customer_edge_id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ce-added" or name == "group-name" or name == "local-ceid" or name == "local-customer-edge-id" or name == "mp2-mp-name" or name == "remote-ceid" or name == "remote-customer-edge-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ce-added"):
                        self.ce_added = value
                        self.ce_added.value_namespace = name_space
                        self.ce_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-ceid"):
                        self.local_ceid = value
                        self.local_ceid.value_namespace = name_space
                        self.local_ceid.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-customer-edge-id"):
                        self.local_customer_edge_id = value
                        self.local_customer_edge_id.value_namespace = name_space
                        self.local_customer_edge_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "mp2-mp-name"):
                        self.mp2_mp_name = value
                        self.mp2_mp_name.value_namespace = name_space
                        self.mp2_mp_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote-ceid"):
                        self.remote_ceid = value
                        self.remote_ceid.value_namespace = name_space
                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote-customer-edge-id"):
                        self.remote_customer_edge_id = value
                        self.remote_customer_edge_id.value_namespace = name_space
                        self.remote_customer_edge_id.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.xconnect_mp2mp_ce2ce:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.xconnect_mp2mp_ce2ce:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-mp2mp-ce2ces" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "xconnect-mp2mp-ce2ce"):
                    for c in self.xconnect_mp2mp_ce2ce:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xconnect_mp2mp_ce2ce.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "xconnect-mp2mp-ce2ce"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Xconnects(Entity):
            """
            XConnect Table
            
            .. attribute:: xconnect
            
            	XConnect information
            	**type**\: list of    :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.Xconnects, self).__init__()

                self.yang_name = "xconnects"
                self.yang_parent_name = "active"

                self.xconnect = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.Xconnects, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.Xconnects, self).__setattr__(name, value)


            class Xconnect(Entity):
                """
                XConnect information
                
                .. attribute:: backup
                
                	LCR backup
                	**type**\:   :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup>`
                
                .. attribute:: backup_segment
                
                	Backup Segment
                	**type**\: list of    :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment>`
                
                .. attribute:: ce2ce
                
                	CE2CE
                	**type**\:   :py:class:`Ce2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Ce2Ce>`
                
                .. attribute:: description
                
                	P2P Description
                	**type**\:  str
                
                .. attribute:: diag_mask
                
                	Mask indicating what if anything is missing before the XC can be provisioned
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: interworking
                
                	Interworking type
                	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                
                .. attribute:: is_mp2mp
                
                	xconnect is mp2mp
                	**type**\:  bool
                
                .. attribute:: number_of_backup_p_ws
                
                	Number of backups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: segment1
                
                	Segment 1
                	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1>`
                
                .. attribute:: segment2
                
                	Segment 2
                	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2>`
                
                .. attribute:: state
                
                	State of the xconnect
                	**type**\:   :py:class:`L2VpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcState>`
                
                .. attribute:: xconnect_name
                
                	XConnect Name
                	**type**\:  str
                
                	**length:** 1..38
                
                .. attribute:: xconnect_name_xr
                
                	XConnect name
                	**type**\:  str
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Xconnects.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "xconnects"

                    self.description = YLeaf(YType.str, "description")

                    self.diag_mask = YLeaf(YType.uint32, "diag-mask")

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                    self.interworking = YLeaf(YType.enumeration, "interworking")

                    self.is_mp2mp = YLeaf(YType.boolean, "is-mp2mp")

                    self.number_of_backup_p_ws = YLeaf(YType.uint32, "number-of-backup-p-ws")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.xconnect_name = YLeaf(YType.str, "xconnect-name")

                    self.xconnect_name_xr = YLeaf(YType.str, "xconnect-name-xr")

                    self.backup = L2Vpnv2.Active.Xconnects.Xconnect.Backup()
                    self.backup.parent = self
                    self._children_name_map["backup"] = "backup"
                    self._children_yang_names.add("backup")

                    self.ce2ce = L2Vpnv2.Active.Xconnects.Xconnect.Ce2Ce()
                    self.ce2ce.parent = self
                    self._children_name_map["ce2ce"] = "ce2ce"
                    self._children_yang_names.add("ce2ce")

                    self.segment1 = L2Vpnv2.Active.Xconnects.Xconnect.Segment1()
                    self.segment1.parent = self
                    self._children_name_map["segment1"] = "segment1"
                    self._children_yang_names.add("segment1")

                    self.segment2 = L2Vpnv2.Active.Xconnects.Xconnect.Segment2()
                    self.segment2.parent = self
                    self._children_name_map["segment2"] = "segment2"
                    self._children_yang_names.add("segment2")

                    self.backup_segment = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("description",
                                    "diag_mask",
                                    "group_name",
                                    "group_name_xr",
                                    "interworking",
                                    "is_mp2mp",
                                    "number_of_backup_p_ws",
                                    "state",
                                    "xconnect_name",
                                    "xconnect_name_xr") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Xconnects.Xconnect, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Xconnects.Xconnect, self).__setattr__(name, value)


                class Backup(Entity):
                    """
                    LCR backup
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup, self).__init__()

                        self.yang_name = "backup"
                        self.yang_parent_name = "xconnect"

                        self.segment_type = YLeaf(YType.enumeration, "segment-type")

                        self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        self._children_yang_names.add("attachment-circuit")

                        self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._children_yang_names.add("pseudo-wire")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("segment_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup, self).__setattr__(name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "backup"

                            self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                            self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                            self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                            self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                            self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                            self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                            self.msti = YLeaf(YType.str, "msti")

                            self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                            self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.interface = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")

                            self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._children_yang_names.add("l2vpn-protection")

                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_mac_conflict",
                                            "bvi_no_port_up",
                                            "control_word_mismatched",
                                            "encapsulation_error",
                                            "encapsulation_mismatched",
                                            "evpn_internal_label",
                                            "interface_handle",
                                            "internal_ms_ti",
                                            "interworking",
                                            "is_ac_partially_programmed",
                                            "mac_limit_oper_down",
                                            "ms_ti_mismatch",
                                            "msti",
                                            "msti_mismatch_down",
                                            "mtu_mismatched",
                                            "node_id",
                                            "out_of_memory_state",
                                            "redundancy_group_id",
                                            "redundancy_group_state",
                                            "redundancy_object_id",
                                            "state",
                                            "tdm_media_mismatched",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"

                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2VpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"

                                self.active = YLeaf(YType.boolean, "active")

                                self.protected_name = YLeaf(YType.str, "protected-name")

                                self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                self.protection_name = YLeaf(YType.str, "protection-name")

                                self.protection_type = YLeaf(YType.enumeration, "protection-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active",
                                                "protected_name",
                                                "protection_configured",
                                                "protection_name",
                                                "protection_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.active.is_set or
                                    self.protected_name.is_set or
                                    self.protection_configured.is_set or
                                    self.protection_name.is_set or
                                    self.protection_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.protected_name.yfilter != YFilter.not_set or
                                    self.protection_configured.yfilter != YFilter.not_set or
                                    self.protection_name.yfilter != YFilter.not_set or
                                    self.protection_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2vpn-protection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_name.get_name_leafdata())
                                if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_name.get_name_leafdata())
                                if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-name"):
                                    self.protected_name = value
                                    self.protected_name.value_namespace = name_space
                                    self.protected_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-configured"):
                                    self.protection_configured = value
                                    self.protection_configured.value_namespace = name_space
                                    self.protection_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-name"):
                                    self.protection_name = value
                                    self.protection_name.value_namespace = name_space
                                    self.protection_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-type"):
                                    self.protection_type = value
                                    self.protection_type.value_namespace = name_space
                                    self.protection_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bvi_mac_conflict.is_set or
                                self.bvi_no_port_up.is_set or
                                self.control_word_mismatched.is_set or
                                self.encapsulation_error.is_set or
                                self.encapsulation_mismatched.is_set or
                                self.evpn_internal_label.is_set or
                                self.interface_handle.is_set or
                                self.internal_ms_ti.is_set or
                                self.interworking.is_set or
                                self.is_ac_partially_programmed.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.ms_ti_mismatch.is_set or
                                self.msti.is_set or
                                self.msti_mismatch_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.node_id.is_set or
                                self.out_of_memory_state.is_set or
                                self.redundancy_group_id.is_set or
                                self.redundancy_group_state.is_set or
                                self.redundancy_object_id.is_set or
                                self.state.is_set or
                                self.tdm_media_mismatched.is_set or
                                self.xconnect_id.is_set or
                                (self.interface is not None and self.interface.has_data()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                self.bvi_no_port_up.yfilter != YFilter.not_set or
                                self.control_word_mismatched.yfilter != YFilter.not_set or
                                self.encapsulation_error.yfilter != YFilter.not_set or
                                self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                self.evpn_internal_label.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.internal_ms_ti.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                self.msti.yfilter != YFilter.not_set or
                                self.msti_mismatch_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.redundancy_group_id.yfilter != YFilter.not_set or
                                self.redundancy_group_state.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.interface is not None and self.interface.has_operation()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment-circuit" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                            if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                            if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                            if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                            if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                            if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                            if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti.get_name_leafdata())
                            if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                            if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                if (self.interface is None):
                                    self.interface = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                return self.interface

                            if (child_yang_name == "l2vpn-protection"):
                                if (self.l2vpn_protection is None):
                                    self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                return self.l2vpn_protection

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-mac-conflict"):
                                self.bvi_mac_conflict = value
                                self.bvi_mac_conflict.value_namespace = name_space
                                self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-no-port-up"):
                                self.bvi_no_port_up = value
                                self.bvi_no_port_up.value_namespace = name_space
                                self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-word-mismatched"):
                                self.control_word_mismatched = value
                                self.control_word_mismatched.value_namespace = name_space
                                self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-error"):
                                self.encapsulation_error = value
                                self.encapsulation_error.value_namespace = name_space
                                self.encapsulation_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-mismatched"):
                                self.encapsulation_mismatched = value
                                self.encapsulation_mismatched.value_namespace = name_space
                                self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-internal-label"):
                                self.evpn_internal_label = value
                                self.evpn_internal_label.value_namespace = name_space
                                self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-ms-ti"):
                                self.internal_ms_ti = value
                                self.internal_ms_ti.value_namespace = name_space
                                self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ac-partially-programmed"):
                                self.is_ac_partially_programmed = value
                                self.is_ac_partially_programmed.value_namespace = name_space
                                self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ms-ti-mismatch"):
                                self.ms_ti_mismatch = value
                                self.ms_ti_mismatch.value_namespace = name_space
                                self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti"):
                                self.msti = value
                                self.msti.value_namespace = name_space
                                self.msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-mismatch-down"):
                                self.msti_mismatch_down = value
                                self.msti_mismatch_down.value_namespace = name_space
                                self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-id"):
                                self.redundancy_group_id = value
                                self.redundancy_group_id.value_namespace = name_space
                                self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-state"):
                                self.redundancy_group_state = value
                                self.redundancy_group_state.value_namespace = name_space
                                self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "tdm-media-mismatched"):
                                self.tdm_media_mismatched = value
                                self.tdm_media_mismatched.value_namespace = name_space
                                self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "backup"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"

                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudo-wire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.segment_type.is_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.segment_type.yfilter != YFilter.not_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "backup" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment-circuit"):
                            if (self.attachment_circuit is None):
                                self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            return self.attachment_circuit

                        if (child_yang_name == "pseudo-wire"):
                            if (self.pseudo_wire is None):
                                self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire()
                                self.pseudo_wire.parent = self
                                self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            return self.pseudo_wire

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "segment-type"):
                            self.segment_type = value
                            self.segment_type.value_namespace = name_space
                            self.segment_type.value_namespace_prefix = name_space_prefix


                class Segment1(Entity):
                    """
                    Segment 1
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1, self).__init__()

                        self.yang_name = "segment1"
                        self.yang_parent_name = "xconnect"

                        self.segment_type = YLeaf(YType.enumeration, "segment-type")

                        self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        self._children_yang_names.add("attachment-circuit")

                        self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._children_yang_names.add("pseudo-wire")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("segment_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1, self).__setattr__(name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "segment1"

                            self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                            self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                            self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                            self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                            self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                            self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                            self.msti = YLeaf(YType.str, "msti")

                            self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                            self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")

                            self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._children_yang_names.add("l2vpn-protection")

                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_mac_conflict",
                                            "bvi_no_port_up",
                                            "control_word_mismatched",
                                            "encapsulation_error",
                                            "encapsulation_mismatched",
                                            "evpn_internal_label",
                                            "interface_handle",
                                            "internal_ms_ti",
                                            "interworking",
                                            "is_ac_partially_programmed",
                                            "mac_limit_oper_down",
                                            "ms_ti_mismatch",
                                            "msti",
                                            "msti_mismatch_down",
                                            "mtu_mismatched",
                                            "node_id",
                                            "out_of_memory_state",
                                            "redundancy_group_id",
                                            "redundancy_group_state",
                                            "redundancy_object_id",
                                            "state",
                                            "tdm_media_mismatched",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"

                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2VpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"

                                self.active = YLeaf(YType.boolean, "active")

                                self.protected_name = YLeaf(YType.str, "protected-name")

                                self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                self.protection_name = YLeaf(YType.str, "protection-name")

                                self.protection_type = YLeaf(YType.enumeration, "protection-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active",
                                                "protected_name",
                                                "protection_configured",
                                                "protection_name",
                                                "protection_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.active.is_set or
                                    self.protected_name.is_set or
                                    self.protection_configured.is_set or
                                    self.protection_name.is_set or
                                    self.protection_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.protected_name.yfilter != YFilter.not_set or
                                    self.protection_configured.yfilter != YFilter.not_set or
                                    self.protection_name.yfilter != YFilter.not_set or
                                    self.protection_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2vpn-protection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_name.get_name_leafdata())
                                if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_name.get_name_leafdata())
                                if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-name"):
                                    self.protected_name = value
                                    self.protected_name.value_namespace = name_space
                                    self.protected_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-configured"):
                                    self.protection_configured = value
                                    self.protection_configured.value_namespace = name_space
                                    self.protection_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-name"):
                                    self.protection_name = value
                                    self.protection_name.value_namespace = name_space
                                    self.protection_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-type"):
                                    self.protection_type = value
                                    self.protection_type.value_namespace = name_space
                                    self.protection_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bvi_mac_conflict.is_set or
                                self.bvi_no_port_up.is_set or
                                self.control_word_mismatched.is_set or
                                self.encapsulation_error.is_set or
                                self.encapsulation_mismatched.is_set or
                                self.evpn_internal_label.is_set or
                                self.interface_handle.is_set or
                                self.internal_ms_ti.is_set or
                                self.interworking.is_set or
                                self.is_ac_partially_programmed.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.ms_ti_mismatch.is_set or
                                self.msti.is_set or
                                self.msti_mismatch_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.node_id.is_set or
                                self.out_of_memory_state.is_set or
                                self.redundancy_group_id.is_set or
                                self.redundancy_group_state.is_set or
                                self.redundancy_object_id.is_set or
                                self.state.is_set or
                                self.tdm_media_mismatched.is_set or
                                self.xconnect_id.is_set or
                                (self.interface is not None and self.interface.has_data()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                self.bvi_no_port_up.yfilter != YFilter.not_set or
                                self.control_word_mismatched.yfilter != YFilter.not_set or
                                self.encapsulation_error.yfilter != YFilter.not_set or
                                self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                self.evpn_internal_label.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.internal_ms_ti.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                self.msti.yfilter != YFilter.not_set or
                                self.msti_mismatch_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.redundancy_group_id.yfilter != YFilter.not_set or
                                self.redundancy_group_state.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.interface is not None and self.interface.has_operation()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment-circuit" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                            if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                            if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                            if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                            if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                            if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                            if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti.get_name_leafdata())
                            if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                            if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                if (self.interface is None):
                                    self.interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                return self.interface

                            if (child_yang_name == "l2vpn-protection"):
                                if (self.l2vpn_protection is None):
                                    self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                return self.l2vpn_protection

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-mac-conflict"):
                                self.bvi_mac_conflict = value
                                self.bvi_mac_conflict.value_namespace = name_space
                                self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-no-port-up"):
                                self.bvi_no_port_up = value
                                self.bvi_no_port_up.value_namespace = name_space
                                self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-word-mismatched"):
                                self.control_word_mismatched = value
                                self.control_word_mismatched.value_namespace = name_space
                                self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-error"):
                                self.encapsulation_error = value
                                self.encapsulation_error.value_namespace = name_space
                                self.encapsulation_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-mismatched"):
                                self.encapsulation_mismatched = value
                                self.encapsulation_mismatched.value_namespace = name_space
                                self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-internal-label"):
                                self.evpn_internal_label = value
                                self.evpn_internal_label.value_namespace = name_space
                                self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-ms-ti"):
                                self.internal_ms_ti = value
                                self.internal_ms_ti.value_namespace = name_space
                                self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ac-partially-programmed"):
                                self.is_ac_partially_programmed = value
                                self.is_ac_partially_programmed.value_namespace = name_space
                                self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ms-ti-mismatch"):
                                self.ms_ti_mismatch = value
                                self.ms_ti_mismatch.value_namespace = name_space
                                self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti"):
                                self.msti = value
                                self.msti.value_namespace = name_space
                                self.msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-mismatch-down"):
                                self.msti_mismatch_down = value
                                self.msti_mismatch_down.value_namespace = name_space
                                self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-id"):
                                self.redundancy_group_id = value
                                self.redundancy_group_id.value_namespace = name_space
                                self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-state"):
                                self.redundancy_group_state = value
                                self.redundancy_group_state.value_namespace = name_space
                                self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "tdm-media-mismatched"):
                                self.tdm_media_mismatched = value
                                self.tdm_media_mismatched.value_namespace = name_space
                                self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "segment1"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"

                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudo-wire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.segment_type.is_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.segment_type.yfilter != YFilter.not_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "segment1" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment-circuit"):
                            if (self.attachment_circuit is None):
                                self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            return self.attachment_circuit

                        if (child_yang_name == "pseudo-wire"):
                            if (self.pseudo_wire is None):
                                self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire()
                                self.pseudo_wire.parent = self
                                self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            return self.pseudo_wire

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "segment-type"):
                            self.segment_type = value
                            self.segment_type.value_namespace = name_space
                            self.segment_type.value_namespace_prefix = name_space_prefix


                class Segment2(Entity):
                    """
                    Segment 2
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2, self).__init__()

                        self.yang_name = "segment2"
                        self.yang_parent_name = "xconnect"

                        self.segment_type = YLeaf(YType.enumeration, "segment-type")

                        self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        self._children_yang_names.add("attachment-circuit")

                        self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._children_yang_names.add("pseudo-wire")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("segment_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2, self).__setattr__(name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "segment2"

                            self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                            self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                            self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                            self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                            self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                            self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                            self.msti = YLeaf(YType.str, "msti")

                            self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                            self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")

                            self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._children_yang_names.add("l2vpn-protection")

                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_mac_conflict",
                                            "bvi_no_port_up",
                                            "control_word_mismatched",
                                            "encapsulation_error",
                                            "encapsulation_mismatched",
                                            "evpn_internal_label",
                                            "interface_handle",
                                            "internal_ms_ti",
                                            "interworking",
                                            "is_ac_partially_programmed",
                                            "mac_limit_oper_down",
                                            "ms_ti_mismatch",
                                            "msti",
                                            "msti_mismatch_down",
                                            "mtu_mismatched",
                                            "node_id",
                                            "out_of_memory_state",
                                            "redundancy_group_id",
                                            "redundancy_group_state",
                                            "redundancy_object_id",
                                            "state",
                                            "tdm_media_mismatched",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"

                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2VpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"

                                self.active = YLeaf(YType.boolean, "active")

                                self.protected_name = YLeaf(YType.str, "protected-name")

                                self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                self.protection_name = YLeaf(YType.str, "protection-name")

                                self.protection_type = YLeaf(YType.enumeration, "protection-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active",
                                                "protected_name",
                                                "protection_configured",
                                                "protection_name",
                                                "protection_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.active.is_set or
                                    self.protected_name.is_set or
                                    self.protection_configured.is_set or
                                    self.protection_name.is_set or
                                    self.protection_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.protected_name.yfilter != YFilter.not_set or
                                    self.protection_configured.yfilter != YFilter.not_set or
                                    self.protection_name.yfilter != YFilter.not_set or
                                    self.protection_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2vpn-protection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_name.get_name_leafdata())
                                if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_name.get_name_leafdata())
                                if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-name"):
                                    self.protected_name = value
                                    self.protected_name.value_namespace = name_space
                                    self.protected_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-configured"):
                                    self.protection_configured = value
                                    self.protection_configured.value_namespace = name_space
                                    self.protection_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-name"):
                                    self.protection_name = value
                                    self.protection_name.value_namespace = name_space
                                    self.protection_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-type"):
                                    self.protection_type = value
                                    self.protection_type.value_namespace = name_space
                                    self.protection_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bvi_mac_conflict.is_set or
                                self.bvi_no_port_up.is_set or
                                self.control_word_mismatched.is_set or
                                self.encapsulation_error.is_set or
                                self.encapsulation_mismatched.is_set or
                                self.evpn_internal_label.is_set or
                                self.interface_handle.is_set or
                                self.internal_ms_ti.is_set or
                                self.interworking.is_set or
                                self.is_ac_partially_programmed.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.ms_ti_mismatch.is_set or
                                self.msti.is_set or
                                self.msti_mismatch_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.node_id.is_set or
                                self.out_of_memory_state.is_set or
                                self.redundancy_group_id.is_set or
                                self.redundancy_group_state.is_set or
                                self.redundancy_object_id.is_set or
                                self.state.is_set or
                                self.tdm_media_mismatched.is_set or
                                self.xconnect_id.is_set or
                                (self.interface is not None and self.interface.has_data()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                self.bvi_no_port_up.yfilter != YFilter.not_set or
                                self.control_word_mismatched.yfilter != YFilter.not_set or
                                self.encapsulation_error.yfilter != YFilter.not_set or
                                self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                self.evpn_internal_label.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.internal_ms_ti.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                self.msti.yfilter != YFilter.not_set or
                                self.msti_mismatch_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.redundancy_group_id.yfilter != YFilter.not_set or
                                self.redundancy_group_state.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.interface is not None and self.interface.has_operation()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment-circuit" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                            if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                            if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                            if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                            if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                            if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                            if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti.get_name_leafdata())
                            if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                            if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                if (self.interface is None):
                                    self.interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                return self.interface

                            if (child_yang_name == "l2vpn-protection"):
                                if (self.l2vpn_protection is None):
                                    self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                return self.l2vpn_protection

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-mac-conflict"):
                                self.bvi_mac_conflict = value
                                self.bvi_mac_conflict.value_namespace = name_space
                                self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-no-port-up"):
                                self.bvi_no_port_up = value
                                self.bvi_no_port_up.value_namespace = name_space
                                self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-word-mismatched"):
                                self.control_word_mismatched = value
                                self.control_word_mismatched.value_namespace = name_space
                                self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-error"):
                                self.encapsulation_error = value
                                self.encapsulation_error.value_namespace = name_space
                                self.encapsulation_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-mismatched"):
                                self.encapsulation_mismatched = value
                                self.encapsulation_mismatched.value_namespace = name_space
                                self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-internal-label"):
                                self.evpn_internal_label = value
                                self.evpn_internal_label.value_namespace = name_space
                                self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-ms-ti"):
                                self.internal_ms_ti = value
                                self.internal_ms_ti.value_namespace = name_space
                                self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ac-partially-programmed"):
                                self.is_ac_partially_programmed = value
                                self.is_ac_partially_programmed.value_namespace = name_space
                                self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ms-ti-mismatch"):
                                self.ms_ti_mismatch = value
                                self.ms_ti_mismatch.value_namespace = name_space
                                self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti"):
                                self.msti = value
                                self.msti.value_namespace = name_space
                                self.msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-mismatch-down"):
                                self.msti_mismatch_down = value
                                self.msti_mismatch_down.value_namespace = name_space
                                self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-id"):
                                self.redundancy_group_id = value
                                self.redundancy_group_id.value_namespace = name_space
                                self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-state"):
                                self.redundancy_group_state = value
                                self.redundancy_group_state.value_namespace = name_space
                                self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "tdm-media-mismatched"):
                                self.tdm_media_mismatched = value
                                self.tdm_media_mismatched.value_namespace = name_space
                                self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "segment2"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"

                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudo-wire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.segment_type.is_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.segment_type.yfilter != YFilter.not_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "segment2" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment-circuit"):
                            if (self.attachment_circuit is None):
                                self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            return self.attachment_circuit

                        if (child_yang_name == "pseudo-wire"):
                            if (self.pseudo_wire is None):
                                self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire()
                                self.pseudo_wire.parent = self
                                self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            return self.pseudo_wire

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "segment-type"):
                            self.segment_type = value
                            self.segment_type.value_namespace = name_space
                            self.segment_type.value_namespace_prefix = name_space_prefix


                class Ce2Ce(Entity):
                    """
                    CE2CE
                    
                    .. attribute:: ce_added
                    
                    	CE2CE Advertised
                    	**type**\:  bool
                    
                    .. attribute:: local_customer_edge_id
                    
                    	Local CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: remote_customer_edge_id
                    
                    	Remote CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Xconnects.Xconnect.Ce2Ce, self).__init__()

                        self.yang_name = "ce2ce"
                        self.yang_parent_name = "xconnect"

                        self.ce_added = YLeaf(YType.boolean, "ce-added")

                        self.local_customer_edge_id = YLeaf(YType.uint16, "local-customer-edge-id")

                        self.remote_customer_edge_id = YLeaf(YType.uint16, "remote-customer-edge-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ce_added",
                                        "local_customer_edge_id",
                                        "remote_customer_edge_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.Ce2Ce, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Xconnects.Xconnect.Ce2Ce, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ce_added.is_set or
                            self.local_customer_edge_id.is_set or
                            self.remote_customer_edge_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ce_added.yfilter != YFilter.not_set or
                            self.local_customer_edge_id.yfilter != YFilter.not_set or
                            self.remote_customer_edge_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ce2ce" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ce_added.is_set or self.ce_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ce_added.get_name_leafdata())
                        if (self.local_customer_edge_id.is_set or self.local_customer_edge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_customer_edge_id.get_name_leafdata())
                        if (self.remote_customer_edge_id.is_set or self.remote_customer_edge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_customer_edge_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ce-added" or name == "local-customer-edge-id" or name == "remote-customer-edge-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ce-added"):
                            self.ce_added = value
                            self.ce_added.value_namespace = name_space
                            self.ce_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-customer-edge-id"):
                            self.local_customer_edge_id = value
                            self.local_customer_edge_id.value_namespace = name_space
                            self.local_customer_edge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-customer-edge-id"):
                            self.remote_customer_edge_id = value
                            self.remote_customer_edge_id.value_namespace = name_space
                            self.remote_customer_edge_id.value_namespace_prefix = name_space_prefix


                class BackupSegment(Entity):
                    """
                    Backup Segment
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment, self).__init__()

                        self.yang_name = "backup-segment"
                        self.yang_parent_name = "xconnect"

                        self.segment_type = YLeaf(YType.enumeration, "segment-type")

                        self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        self._children_yang_names.add("attachment-circuit")

                        self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._children_yang_names.add("pseudo-wire")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("segment_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment, self).__setattr__(name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "backup-segment"

                            self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                            self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                            self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                            self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                            self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                            self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                            self.msti = YLeaf(YType.str, "msti")

                            self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                            self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.interface = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")

                            self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._children_yang_names.add("l2vpn-protection")

                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_mac_conflict",
                                            "bvi_no_port_up",
                                            "control_word_mismatched",
                                            "encapsulation_error",
                                            "encapsulation_mismatched",
                                            "evpn_internal_label",
                                            "interface_handle",
                                            "internal_ms_ti",
                                            "interworking",
                                            "is_ac_partially_programmed",
                                            "mac_limit_oper_down",
                                            "ms_ti_mismatch",
                                            "msti",
                                            "msti_mismatch_down",
                                            "mtu_mismatched",
                                            "node_id",
                                            "out_of_memory_state",
                                            "redundancy_group_id",
                                            "redundancy_group_state",
                                            "redundancy_object_id",
                                            "state",
                                            "tdm_media_mismatched",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"

                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2VpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"

                                self.active = YLeaf(YType.boolean, "active")

                                self.protected_name = YLeaf(YType.str, "protected-name")

                                self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                self.protection_name = YLeaf(YType.str, "protection-name")

                                self.protection_type = YLeaf(YType.enumeration, "protection-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active",
                                                "protected_name",
                                                "protection_configured",
                                                "protection_name",
                                                "protection_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.active.is_set or
                                    self.protected_name.is_set or
                                    self.protection_configured.is_set or
                                    self.protection_name.is_set or
                                    self.protection_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.protected_name.yfilter != YFilter.not_set or
                                    self.protection_configured.yfilter != YFilter.not_set or
                                    self.protection_name.yfilter != YFilter.not_set or
                                    self.protection_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2vpn-protection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_name.get_name_leafdata())
                                if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_name.get_name_leafdata())
                                if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-name"):
                                    self.protected_name = value
                                    self.protected_name.value_namespace = name_space
                                    self.protected_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-configured"):
                                    self.protection_configured = value
                                    self.protection_configured.value_namespace = name_space
                                    self.protection_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-name"):
                                    self.protection_name = value
                                    self.protection_name.value_namespace = name_space
                                    self.protection_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-type"):
                                    self.protection_type = value
                                    self.protection_type.value_namespace = name_space
                                    self.protection_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bvi_mac_conflict.is_set or
                                self.bvi_no_port_up.is_set or
                                self.control_word_mismatched.is_set or
                                self.encapsulation_error.is_set or
                                self.encapsulation_mismatched.is_set or
                                self.evpn_internal_label.is_set or
                                self.interface_handle.is_set or
                                self.internal_ms_ti.is_set or
                                self.interworking.is_set or
                                self.is_ac_partially_programmed.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.ms_ti_mismatch.is_set or
                                self.msti.is_set or
                                self.msti_mismatch_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.node_id.is_set or
                                self.out_of_memory_state.is_set or
                                self.redundancy_group_id.is_set or
                                self.redundancy_group_state.is_set or
                                self.redundancy_object_id.is_set or
                                self.state.is_set or
                                self.tdm_media_mismatched.is_set or
                                self.xconnect_id.is_set or
                                (self.interface is not None and self.interface.has_data()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                self.bvi_no_port_up.yfilter != YFilter.not_set or
                                self.control_word_mismatched.yfilter != YFilter.not_set or
                                self.encapsulation_error.yfilter != YFilter.not_set or
                                self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                self.evpn_internal_label.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.internal_ms_ti.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                self.msti.yfilter != YFilter.not_set or
                                self.msti_mismatch_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.redundancy_group_id.yfilter != YFilter.not_set or
                                self.redundancy_group_state.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.interface is not None and self.interface.has_operation()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment-circuit" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                            if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                            if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                            if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                            if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                            if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                            if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti.get_name_leafdata())
                            if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                            if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                if (self.interface is None):
                                    self.interface = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                return self.interface

                            if (child_yang_name == "l2vpn-protection"):
                                if (self.l2vpn_protection is None):
                                    self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                return self.l2vpn_protection

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-mac-conflict"):
                                self.bvi_mac_conflict = value
                                self.bvi_mac_conflict.value_namespace = name_space
                                self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-no-port-up"):
                                self.bvi_no_port_up = value
                                self.bvi_no_port_up.value_namespace = name_space
                                self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-word-mismatched"):
                                self.control_word_mismatched = value
                                self.control_word_mismatched.value_namespace = name_space
                                self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-error"):
                                self.encapsulation_error = value
                                self.encapsulation_error.value_namespace = name_space
                                self.encapsulation_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-mismatched"):
                                self.encapsulation_mismatched = value
                                self.encapsulation_mismatched.value_namespace = name_space
                                self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-internal-label"):
                                self.evpn_internal_label = value
                                self.evpn_internal_label.value_namespace = name_space
                                self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-ms-ti"):
                                self.internal_ms_ti = value
                                self.internal_ms_ti.value_namespace = name_space
                                self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ac-partially-programmed"):
                                self.is_ac_partially_programmed = value
                                self.is_ac_partially_programmed.value_namespace = name_space
                                self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ms-ti-mismatch"):
                                self.ms_ti_mismatch = value
                                self.ms_ti_mismatch.value_namespace = name_space
                                self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti"):
                                self.msti = value
                                self.msti.value_namespace = name_space
                                self.msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-mismatch-down"):
                                self.msti_mismatch_down = value
                                self.msti_mismatch_down.value_namespace = name_space
                                self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-id"):
                                self.redundancy_group_id = value
                                self.redundancy_group_id.value_namespace = name_space
                                self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-state"):
                                self.redundancy_group_state = value
                                self.redundancy_group_state.value_namespace = name_space
                                self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "tdm-media-mismatched"):
                                self.tdm_media_mismatched = value
                                self.tdm_media_mismatched.value_namespace = name_space
                                self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "backup-segment"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"

                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudo-wire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.segment_type.is_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.segment_type.yfilter != YFilter.not_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                            (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "backup-segment" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment-circuit"):
                            if (self.attachment_circuit is None):
                                self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            return self.attachment_circuit

                        if (child_yang_name == "pseudo-wire"):
                            if (self.pseudo_wire is None):
                                self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire()
                                self.pseudo_wire.parent = self
                                self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            return self.pseudo_wire

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "segment-type"):
                            self.segment_type = value
                            self.segment_type.value_namespace = name_space
                            self.segment_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.backup_segment:
                        if (c.has_data()):
                            return True
                    return (
                        self.description.is_set or
                        self.diag_mask.is_set or
                        self.group_name.is_set or
                        self.group_name_xr.is_set or
                        self.interworking.is_set or
                        self.is_mp2mp.is_set or
                        self.number_of_backup_p_ws.is_set or
                        self.state.is_set or
                        self.xconnect_name.is_set or
                        self.xconnect_name_xr.is_set or
                        (self.backup is not None and self.backup.has_data()) or
                        (self.ce2ce is not None and self.ce2ce.has_data()) or
                        (self.segment1 is not None and self.segment1.has_data()) or
                        (self.segment2 is not None and self.segment2.has_data()))

                def has_operation(self):
                    for c in self.backup_segment:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.description.yfilter != YFilter.not_set or
                        self.diag_mask.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.group_name_xr.yfilter != YFilter.not_set or
                        self.interworking.yfilter != YFilter.not_set or
                        self.is_mp2mp.yfilter != YFilter.not_set or
                        self.number_of_backup_p_ws.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set or
                        self.xconnect_name.yfilter != YFilter.not_set or
                        self.xconnect_name_xr.yfilter != YFilter.not_set or
                        (self.backup is not None and self.backup.has_operation()) or
                        (self.ce2ce is not None and self.ce2ce.has_operation()) or
                        (self.segment1 is not None and self.segment1.has_operation()) or
                        (self.segment2 is not None and self.segment2.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.description.get_name_leafdata())
                    if (self.diag_mask.is_set or self.diag_mask.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.diag_mask.get_name_leafdata())
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                    if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interworking.get_name_leafdata())
                    if (self.is_mp2mp.is_set or self.is_mp2mp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mp2mp.get_name_leafdata())
                    if (self.number_of_backup_p_ws.is_set or self.number_of_backup_p_ws.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_of_backup_p_ws.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())
                    if (self.xconnect_name.is_set or self.xconnect_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.xconnect_name.get_name_leafdata())
                    if (self.xconnect_name_xr.is_set or self.xconnect_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.xconnect_name_xr.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "backup"):
                        if (self.backup is None):
                            self.backup = L2Vpnv2.Active.Xconnects.Xconnect.Backup()
                            self.backup.parent = self
                            self._children_name_map["backup"] = "backup"
                        return self.backup

                    if (child_yang_name == "backup-segment"):
                        for c in self.backup_segment:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.backup_segment.append(c)
                        return c

                    if (child_yang_name == "ce2ce"):
                        if (self.ce2ce is None):
                            self.ce2ce = L2Vpnv2.Active.Xconnects.Xconnect.Ce2Ce()
                            self.ce2ce.parent = self
                            self._children_name_map["ce2ce"] = "ce2ce"
                        return self.ce2ce

                    if (child_yang_name == "segment1"):
                        if (self.segment1 is None):
                            self.segment1 = L2Vpnv2.Active.Xconnects.Xconnect.Segment1()
                            self.segment1.parent = self
                            self._children_name_map["segment1"] = "segment1"
                        return self.segment1

                    if (child_yang_name == "segment2"):
                        if (self.segment2 is None):
                            self.segment2 = L2Vpnv2.Active.Xconnects.Xconnect.Segment2()
                            self.segment2.parent = self
                            self._children_name_map["segment2"] = "segment2"
                        return self.segment2

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "backup" or name == "backup-segment" or name == "ce2ce" or name == "segment1" or name == "segment2" or name == "description" or name == "diag-mask" or name == "group-name" or name == "group-name-xr" or name == "interworking" or name == "is-mp2mp" or name == "number-of-backup-p-ws" or name == "state" or name == "xconnect-name" or name == "xconnect-name-xr"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "description"):
                        self.description = value
                        self.description.value_namespace = name_space
                        self.description.value_namespace_prefix = name_space_prefix
                    if(value_path == "diag-mask"):
                        self.diag_mask = value
                        self.diag_mask.value_namespace = name_space
                        self.diag_mask.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name-xr"):
                        self.group_name_xr = value
                        self.group_name_xr.value_namespace = name_space
                        self.group_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "interworking"):
                        self.interworking = value
                        self.interworking.value_namespace = name_space
                        self.interworking.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mp2mp"):
                        self.is_mp2mp = value
                        self.is_mp2mp.value_namespace = name_space
                        self.is_mp2mp.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-of-backup-p-ws"):
                        self.number_of_backup_p_ws = value
                        self.number_of_backup_p_ws.value_namespace = name_space
                        self.number_of_backup_p_ws.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix
                    if(value_path == "xconnect-name"):
                        self.xconnect_name = value
                        self.xconnect_name.value_namespace = name_space
                        self.xconnect_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "xconnect-name-xr"):
                        self.xconnect_name_xr = value
                        self.xconnect_name_xr.value_namespace = name_space
                        self.xconnect_name_xr.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.xconnect:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.xconnect:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnects" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "xconnect"):
                    for c in self.xconnect:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.Xconnects.Xconnect()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xconnect.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "xconnect"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class XconnectGroups(Entity):
            """
            XConnect group Table
            
            .. attribute:: xconnect_group
            
            	XConnect group information
            	**type**\: list of    :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectGroups.XconnectGroup>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.XconnectGroups, self).__init__()

                self.yang_name = "xconnect-groups"
                self.yang_parent_name = "active"

                self.xconnect_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.XconnectGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.XconnectGroups, self).__setattr__(name, value)


            class XconnectGroup(Entity):
                """
                XConnect group information
                
                .. attribute:: group_name  <key>
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: number_xconnects
                
                	Number of xconnects
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.XconnectGroups.XconnectGroup, self).__init__()

                    self.yang_name = "xconnect-group"
                    self.yang_parent_name = "xconnect-groups"

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                    self.number_xconnects = YLeaf(YType.uint32, "number-xconnects")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_name",
                                    "group_name_xr",
                                    "number_xconnects") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.XconnectGroups.XconnectGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.XconnectGroups.XconnectGroup, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.group_name.is_set or
                        self.group_name_xr.is_set or
                        self.number_xconnects.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.group_name_xr.yfilter != YFilter.not_set or
                        self.number_xconnects.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-group" + "[group-name='" + self.group_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                    if (self.number_xconnects.is_set or self.number_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-name" or name == "group-name-xr" or name == "number-xconnects"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name-xr"):
                        self.group_name_xr = value
                        self.group_name_xr.value_namespace = name_space
                        self.group_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects"):
                        self.number_xconnects = value
                        self.number_xconnects.value_namespace = name_space
                        self.number_xconnects.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.xconnect_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.xconnect_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "xconnect-group"):
                    for c in self.xconnect_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.XconnectGroups.XconnectGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xconnect_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "xconnect-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class XconnectMp2Mps(Entity):
            """
            XConnect MP2MP Table
            
            .. attribute:: xconnect_mp2mp
            
            	XConnect MP2MP information
            	**type**\: list of    :py:class:`XconnectMp2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.XconnectMp2Mps, self).__init__()

                self.yang_name = "xconnect-mp2mps"
                self.yang_parent_name = "active"

                self.xconnect_mp2mp = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.XconnectMp2Mps, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.XconnectMp2Mps, self).__setattr__(name, value)


            class XconnectMp2Mp(Entity):
                """
                XConnect MP2MP information
                
                .. attribute:: discovery
                
                	l2vpn xc auto discovery info
                	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery>`
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: l2_encapsulation
                
                	L2 Encapsulation
                	**type**\:   :py:class:`L2VpnBagAdEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagAdEncap>`
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\:  str
                
                	**length:** 1..26
                
                .. attribute:: mp2mp_name
                
                	MP2MP name
                	**type**\:  str
                
                .. attribute:: mp2mpid
                
                	Identification Number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_id
                
                	Vpn ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_mtu
                
                	VPN MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: xconnect_shutdown
                
                	Administratively disabled
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp, self).__init__()

                    self.yang_name = "xconnect-mp2mp"
                    self.yang_parent_name = "xconnect-mp2mps"

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                    self.l2_encapsulation = YLeaf(YType.enumeration, "l2-encapsulation")

                    self.mp2_mp_name = YLeaf(YType.str, "mp2-mp-name")

                    self.mp2mp_name = YLeaf(YType.str, "mp2mp-name")

                    self.mp2mpid = YLeaf(YType.uint32, "mp2mpid")

                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                    self.vpn_mtu = YLeaf(YType.uint32, "vpn-mtu")

                    self.xconnect_shutdown = YLeaf(YType.boolean, "xconnect-shutdown")

                    self.discovery = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                    self.discovery.parent = self
                    self._children_name_map["discovery"] = "discovery"
                    self._children_yang_names.add("discovery")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_name",
                                    "group_name_xr",
                                    "l2_encapsulation",
                                    "mp2_mp_name",
                                    "mp2mp_name",
                                    "mp2mpid",
                                    "vpn_id",
                                    "vpn_mtu",
                                    "xconnect_shutdown") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp, self).__setattr__(name, value)


                class Discovery(Entity):
                    """
                    l2vpn xc auto discovery info
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery Method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_service_connected
                    
                    	Service Connected
                    	**type**\:  bool
                    
                    .. attribute:: ad_signalling_method
                    
                    	Signaling Protocol
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ce_range
                    
                    	CE Range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: export_route_policy
                    
                    	Export Route Policy
                    	**type**\:  str
                    
                    .. attribute:: export_rt
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt>`
                    
                    .. attribute:: import_rt
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt>`
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2c_es
                    
                    	Number of ce2ce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2ce_advertised
                    
                    	Number of ce2ce Advertised
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rd_value
                    
                    	Route Distinguisher
                    	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue>`
                    
                    .. attribute:: vpn_added
                    
                    	VPN Added
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__init__()

                        self.yang_name = "discovery"
                        self.yang_parent_name = "xconnect-mp2mp"

                        self.ad_method = YLeaf(YType.uint32, "ad-method")

                        self.ad_service_connected = YLeaf(YType.boolean, "ad-service-connected")

                        self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                        self.ce_range = YLeaf(YType.uint16, "ce-range")

                        self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                        self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                        self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                        self.number_ce2c_es = YLeaf(YType.uint32, "number-ce2c-es")

                        self.number_ce2ce_advertised = YLeaf(YType.uint32, "number-ce2ce-advertised")

                        self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                        self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                        self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                        self.rd_value = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                        self.rd_value.parent = self
                        self._children_name_map["rd_value"] = "rd-value"
                        self._children_yang_names.add("rd-value")

                        self.export_rt = YList(self)
                        self.import_rt = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ad_method",
                                        "ad_service_connected",
                                        "ad_signalling_method",
                                        "ce_range",
                                        "export_route_policy",
                                        "number_a_cs",
                                        "number_a_cs_up",
                                        "number_ce2c_es",
                                        "number_ce2ce_advertised",
                                        "number_p_ws_up",
                                        "number_pseudowires",
                                        "vpn_added") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__setattr__(name, value)


                    class RdValue(Entity):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__init__()

                            self.yang_name = "rd-value"
                            self.yang_parent_name = "discovery"

                            self.rd = YLeaf(YType.enumeration, "rd")

                            self.auto = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"
                            self._children_yang_names.add("auto")

                            self.four_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                            self._children_yang_names.add("four-byte-as")

                            self.two_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rd") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__setattr__(name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd-value"

                                self.auto_index = YLeaf(YType.uint16, "auto-index")

                                self.router_id = YLeaf(YType.str, "router-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("auto_index",
                                                "router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.auto_index.is_set or
                                    self.router_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.auto_index.yfilter != YFilter.not_set or
                                    self.router_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "auto" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_index.get_name_leafdata())
                                if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto-index" or name == "router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "auto-index"):
                                    self.auto_index = value
                                    self.auto_index.value_namespace = name_space
                                    self.auto_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-id"):
                                    self.router_id = value
                                    self.router_id.value_namespace = name_space
                                    self.router_id.value_namespace_prefix = name_space_prefix


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd-value"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd-value"

                                self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_as",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_as.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_as.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "four-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-as" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-as"):
                                    self.four_byte_as = value
                                    self.four_byte_as.value_namespace = name_space
                                    self.four_byte_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd-value"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.rd.is_set or
                                (self.auto is not None and self.auto.has_data()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rd.yfilter != YFilter.not_set or
                                (self.auto is not None and self.auto.has_operation()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rd-value" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rd.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "auto"):
                                if (self.auto is None):
                                    self.auto = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                return self.auto

                            if (child_yang_name == "four-byte-as"):
                                if (self.four_byte_as is None):
                                    self.four_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                return self.four_byte_as

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rd"):
                                self.rd = value
                                self.rd.value_namespace = name_space
                                self.rd.value_namespace_prefix = name_space_prefix


                    class ImportRt(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__init__()

                            self.yang_name = "import-rt"
                            self.yang_parent_name = "discovery"

                            self.rt = YLeaf(YType.enumeration, "rt")

                            self.es_import = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                            self.es_import.parent = self
                            self._children_name_map["es_import"] = "es-import"
                            self._children_yang_names.add("es-import")

                            self.four_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                            self._children_yang_names.add("four-byte-as")

                            self.two_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rt") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__setattr__(name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "import-rt"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "import-rt"

                                self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_as",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_as.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_as.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "four-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-as" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-as"):
                                    self.four_byte_as = value
                                    self.four_byte_as.value_namespace = name_space
                                    self.four_byte_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "import-rt"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class EsImport(Entity):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__init__()

                                self.yang_name = "es-import"
                                self.yang_parent_name = "import-rt"

                                self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("high_bytes",
                                                "low_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.high_bytes.is_set or
                                    self.low_bytes.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.high_bytes.yfilter != YFilter.not_set or
                                    self.low_bytes.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "es-import" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "high-bytes" or name == "low-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "high-bytes"):
                                    self.high_bytes = value
                                    self.high_bytes.value_namespace = name_space
                                    self.high_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "low-bytes"):
                                    self.low_bytes = value
                                    self.low_bytes.value_namespace = name_space
                                    self.low_bytes.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.rt.is_set or
                                (self.es_import is not None and self.es_import.has_data()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rt.yfilter != YFilter.not_set or
                                (self.es_import is not None and self.es_import.has_operation()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "import-rt" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rt.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "es-import"):
                                if (self.es_import is None):
                                    self.es_import = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                return self.es_import

                            if (child_yang_name == "four-byte-as"):
                                if (self.four_byte_as is None):
                                    self.four_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                return self.four_byte_as

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rt"):
                                self.rt = value
                                self.rt.value_namespace = name_space
                                self.rt.value_namespace_prefix = name_space_prefix


                    class ExportRt(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__init__()

                            self.yang_name = "export-rt"
                            self.yang_parent_name = "discovery"

                            self.rt = YLeaf(YType.enumeration, "rt")

                            self.es_import = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                            self.es_import.parent = self
                            self._children_name_map["es_import"] = "es-import"
                            self._children_yang_names.add("es-import")

                            self.four_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                            self._children_yang_names.add("four-byte-as")

                            self.two_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rt") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__setattr__(name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "export-rt"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "export-rt"

                                self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_as",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_as.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_as.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "four-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-as" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-as"):
                                    self.four_byte_as = value
                                    self.four_byte_as.value_namespace = name_space
                                    self.four_byte_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "export-rt"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class EsImport(Entity):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__init__()

                                self.yang_name = "es-import"
                                self.yang_parent_name = "export-rt"

                                self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("high_bytes",
                                                "low_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.high_bytes.is_set or
                                    self.low_bytes.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.high_bytes.yfilter != YFilter.not_set or
                                    self.low_bytes.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "es-import" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "high-bytes" or name == "low-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "high-bytes"):
                                    self.high_bytes = value
                                    self.high_bytes.value_namespace = name_space
                                    self.high_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "low-bytes"):
                                    self.low_bytes = value
                                    self.low_bytes.value_namespace = name_space
                                    self.low_bytes.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.rt.is_set or
                                (self.es_import is not None and self.es_import.has_data()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rt.yfilter != YFilter.not_set or
                                (self.es_import is not None and self.es_import.has_operation()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "export-rt" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rt.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "es-import"):
                                if (self.es_import is None):
                                    self.es_import = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                return self.es_import

                            if (child_yang_name == "four-byte-as"):
                                if (self.four_byte_as is None):
                                    self.four_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                return self.four_byte_as

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rt"):
                                self.rt = value
                                self.rt.value_namespace = name_space
                                self.rt.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.export_rt:
                            if (c.has_data()):
                                return True
                        for c in self.import_rt:
                            if (c.has_data()):
                                return True
                        return (
                            self.ad_method.is_set or
                            self.ad_service_connected.is_set or
                            self.ad_signalling_method.is_set or
                            self.ce_range.is_set or
                            self.export_route_policy.is_set or
                            self.number_a_cs.is_set or
                            self.number_a_cs_up.is_set or
                            self.number_ce2c_es.is_set or
                            self.number_ce2ce_advertised.is_set or
                            self.number_p_ws_up.is_set or
                            self.number_pseudowires.is_set or
                            self.vpn_added.is_set or
                            (self.rd_value is not None and self.rd_value.has_data()))

                    def has_operation(self):
                        for c in self.export_rt:
                            if (c.has_operation()):
                                return True
                        for c in self.import_rt:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ad_method.yfilter != YFilter.not_set or
                            self.ad_service_connected.yfilter != YFilter.not_set or
                            self.ad_signalling_method.yfilter != YFilter.not_set or
                            self.ce_range.yfilter != YFilter.not_set or
                            self.export_route_policy.yfilter != YFilter.not_set or
                            self.number_a_cs.yfilter != YFilter.not_set or
                            self.number_a_cs_up.yfilter != YFilter.not_set or
                            self.number_ce2c_es.yfilter != YFilter.not_set or
                            self.number_ce2ce_advertised.yfilter != YFilter.not_set or
                            self.number_p_ws_up.yfilter != YFilter.not_set or
                            self.number_pseudowires.yfilter != YFilter.not_set or
                            self.vpn_added.yfilter != YFilter.not_set or
                            (self.rd_value is not None and self.rd_value.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "discovery" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_method.get_name_leafdata())
                        if (self.ad_service_connected.is_set or self.ad_service_connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_service_connected.get_name_leafdata())
                        if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                        if (self.ce_range.is_set or self.ce_range.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ce_range.get_name_leafdata())
                        if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                        if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                        if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                        if (self.number_ce2c_es.is_set or self.number_ce2c_es.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_ce2c_es.get_name_leafdata())
                        if (self.number_ce2ce_advertised.is_set or self.number_ce2ce_advertised.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_ce2ce_advertised.get_name_leafdata())
                        if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                        if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                        if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_added.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "export-rt"):
                            for c in self.export_rt:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.export_rt.append(c)
                            return c

                        if (child_yang_name == "import-rt"):
                            for c in self.import_rt:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.import_rt.append(c)
                            return c

                        if (child_yang_name == "rd-value"):
                            if (self.rd_value is None):
                                self.rd_value = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                                self.rd_value.parent = self
                                self._children_name_map["rd_value"] = "rd-value"
                            return self.rd_value

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "ad-method" or name == "ad-service-connected" or name == "ad-signalling-method" or name == "ce-range" or name == "export-route-policy" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-ce2c-es" or name == "number-ce2ce-advertised" or name == "number-p-ws-up" or name == "number-pseudowires" or name == "vpn-added"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ad-method"):
                            self.ad_method = value
                            self.ad_method.value_namespace = name_space
                            self.ad_method.value_namespace_prefix = name_space_prefix
                        if(value_path == "ad-service-connected"):
                            self.ad_service_connected = value
                            self.ad_service_connected.value_namespace = name_space
                            self.ad_service_connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "ad-signalling-method"):
                            self.ad_signalling_method = value
                            self.ad_signalling_method.value_namespace = name_space
                            self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                        if(value_path == "ce-range"):
                            self.ce_range = value
                            self.ce_range.value_namespace = name_space
                            self.ce_range.value_namespace_prefix = name_space_prefix
                        if(value_path == "export-route-policy"):
                            self.export_route_policy = value
                            self.export_route_policy.value_namespace = name_space
                            self.export_route_policy.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-a-cs"):
                            self.number_a_cs = value
                            self.number_a_cs.value_namespace = name_space
                            self.number_a_cs.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-a-cs-up"):
                            self.number_a_cs_up = value
                            self.number_a_cs_up.value_namespace = name_space
                            self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-ce2c-es"):
                            self.number_ce2c_es = value
                            self.number_ce2c_es.value_namespace = name_space
                            self.number_ce2c_es.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-ce2ce-advertised"):
                            self.number_ce2ce_advertised = value
                            self.number_ce2ce_advertised.value_namespace = name_space
                            self.number_ce2ce_advertised.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-p-ws-up"):
                            self.number_p_ws_up = value
                            self.number_p_ws_up.value_namespace = name_space
                            self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-pseudowires"):
                            self.number_pseudowires = value
                            self.number_pseudowires.value_namespace = name_space
                            self.number_pseudowires.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-added"):
                            self.vpn_added = value
                            self.vpn_added.value_namespace = name_space
                            self.vpn_added.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.group_name.is_set or
                        self.group_name_xr.is_set or
                        self.l2_encapsulation.is_set or
                        self.mp2_mp_name.is_set or
                        self.mp2mp_name.is_set or
                        self.mp2mpid.is_set or
                        self.vpn_id.is_set or
                        self.vpn_mtu.is_set or
                        self.xconnect_shutdown.is_set or
                        (self.discovery is not None and self.discovery.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.group_name_xr.yfilter != YFilter.not_set or
                        self.l2_encapsulation.yfilter != YFilter.not_set or
                        self.mp2_mp_name.yfilter != YFilter.not_set or
                        self.mp2mp_name.yfilter != YFilter.not_set or
                        self.mp2mpid.yfilter != YFilter.not_set or
                        self.vpn_id.yfilter != YFilter.not_set or
                        self.vpn_mtu.yfilter != YFilter.not_set or
                        self.xconnect_shutdown.yfilter != YFilter.not_set or
                        (self.discovery is not None and self.discovery.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-mp2mp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                    if (self.l2_encapsulation.is_set or self.l2_encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.l2_encapsulation.get_name_leafdata())
                    if (self.mp2_mp_name.is_set or self.mp2_mp_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mp2_mp_name.get_name_leafdata())
                    if (self.mp2mp_name.is_set or self.mp2mp_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mp2mp_name.get_name_leafdata())
                    if (self.mp2mpid.is_set or self.mp2mpid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mp2mpid.get_name_leafdata())
                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_id.get_name_leafdata())
                    if (self.vpn_mtu.is_set or self.vpn_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_mtu.get_name_leafdata())
                    if (self.xconnect_shutdown.is_set or self.xconnect_shutdown.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.xconnect_shutdown.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "discovery"):
                        if (self.discovery is None):
                            self.discovery = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                            self.discovery.parent = self
                            self._children_name_map["discovery"] = "discovery"
                        return self.discovery

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "discovery" or name == "group-name" or name == "group-name-xr" or name == "l2-encapsulation" or name == "mp2-mp-name" or name == "mp2mp-name" or name == "mp2mpid" or name == "vpn-id" or name == "vpn-mtu" or name == "xconnect-shutdown"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name-xr"):
                        self.group_name_xr = value
                        self.group_name_xr.value_namespace = name_space
                        self.group_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "l2-encapsulation"):
                        self.l2_encapsulation = value
                        self.l2_encapsulation.value_namespace = name_space
                        self.l2_encapsulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mp2-mp-name"):
                        self.mp2_mp_name = value
                        self.mp2_mp_name.value_namespace = name_space
                        self.mp2_mp_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mp2mp-name"):
                        self.mp2mp_name = value
                        self.mp2mp_name.value_namespace = name_space
                        self.mp2mp_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mp2mpid"):
                        self.mp2mpid = value
                        self.mp2mpid.value_namespace = name_space
                        self.mp2mpid.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-id"):
                        self.vpn_id = value
                        self.vpn_id.value_namespace = name_space
                        self.vpn_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-mtu"):
                        self.vpn_mtu = value
                        self.vpn_mtu.value_namespace = name_space
                        self.vpn_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "xconnect-shutdown"):
                        self.xconnect_shutdown = value
                        self.xconnect_shutdown.value_namespace = name_space
                        self.xconnect_shutdown.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.xconnect_mp2mp:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.xconnect_mp2mp:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-mp2mps" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "xconnect-mp2mp"):
                    for c in self.xconnect_mp2mp:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xconnect_mp2mp.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "xconnect-mp2mp"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Indexes(Entity):
            """
            ID Manager Index Table
            
            .. attribute:: index
            
            	ID Manager Index Pool
            	**type**\: list of    :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Indexes.Index>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.Indexes, self).__init__()

                self.yang_name = "indexes"
                self.yang_parent_name = "active"

                self.index = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.Indexes, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.Indexes, self).__setattr__(name, value)


            class Index(Entity):
                """
                ID Manager Index Pool
                
                .. attribute:: pool_id  <key>
                
                	Pool ID
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                .. attribute:: allocated_ids
                
                	Number of IDs allocated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: application_type
                
                	Application Type
                	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
                
                .. attribute:: max_num_id_mgr
                
                	Maximum number of pool extensions
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_id_mgr_in_use
                
                	ID mgr instances in use
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pool_id_xr
                
                	Pool Id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pool_size
                
                	Pool size
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: zombied_ids
                
                	Number of IDs allocated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Indexes.Index, self).__init__()

                    self.yang_name = "index"
                    self.yang_parent_name = "indexes"

                    self.pool_id = YLeaf(YType.str, "pool-id")

                    self.allocated_ids = YLeaf(YType.uint32, "allocated-ids")

                    self.application_type = YLeaf(YType.enumeration, "application-type")

                    self.max_num_id_mgr = YLeaf(YType.uint32, "max-num-id-mgr")

                    self.num_id_mgr_in_use = YLeaf(YType.uint32, "num-id-mgr-in-use")

                    self.pool_id_xr = YLeaf(YType.uint32, "pool-id-xr")

                    self.pool_size = YLeaf(YType.uint32, "pool-size")

                    self.zombied_ids = YLeaf(YType.uint32, "zombied-ids")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("pool_id",
                                    "allocated_ids",
                                    "application_type",
                                    "max_num_id_mgr",
                                    "num_id_mgr_in_use",
                                    "pool_id_xr",
                                    "pool_size",
                                    "zombied_ids") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Indexes.Index, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Indexes.Index, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.pool_id.is_set or
                        self.allocated_ids.is_set or
                        self.application_type.is_set or
                        self.max_num_id_mgr.is_set or
                        self.num_id_mgr_in_use.is_set or
                        self.pool_id_xr.is_set or
                        self.pool_size.is_set or
                        self.zombied_ids.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.pool_id.yfilter != YFilter.not_set or
                        self.allocated_ids.yfilter != YFilter.not_set or
                        self.application_type.yfilter != YFilter.not_set or
                        self.max_num_id_mgr.yfilter != YFilter.not_set or
                        self.num_id_mgr_in_use.yfilter != YFilter.not_set or
                        self.pool_id_xr.yfilter != YFilter.not_set or
                        self.pool_size.yfilter != YFilter.not_set or
                        self.zombied_ids.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "index" + "[pool-id='" + self.pool_id.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/indexes/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.pool_id.is_set or self.pool_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pool_id.get_name_leafdata())
                    if (self.allocated_ids.is_set or self.allocated_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allocated_ids.get_name_leafdata())
                    if (self.application_type.is_set or self.application_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.application_type.get_name_leafdata())
                    if (self.max_num_id_mgr.is_set or self.max_num_id_mgr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.max_num_id_mgr.get_name_leafdata())
                    if (self.num_id_mgr_in_use.is_set or self.num_id_mgr_in_use.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.num_id_mgr_in_use.get_name_leafdata())
                    if (self.pool_id_xr.is_set or self.pool_id_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pool_id_xr.get_name_leafdata())
                    if (self.pool_size.is_set or self.pool_size.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pool_size.get_name_leafdata())
                    if (self.zombied_ids.is_set or self.zombied_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.zombied_ids.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pool-id" or name == "allocated-ids" or name == "application-type" or name == "max-num-id-mgr" or name == "num-id-mgr-in-use" or name == "pool-id-xr" or name == "pool-size" or name == "zombied-ids"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "pool-id"):
                        self.pool_id = value
                        self.pool_id.value_namespace = name_space
                        self.pool_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "allocated-ids"):
                        self.allocated_ids = value
                        self.allocated_ids.value_namespace = name_space
                        self.allocated_ids.value_namespace_prefix = name_space_prefix
                    if(value_path == "application-type"):
                        self.application_type = value
                        self.application_type.value_namespace = name_space
                        self.application_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "max-num-id-mgr"):
                        self.max_num_id_mgr = value
                        self.max_num_id_mgr.value_namespace = name_space
                        self.max_num_id_mgr.value_namespace_prefix = name_space_prefix
                    if(value_path == "num-id-mgr-in-use"):
                        self.num_id_mgr_in_use = value
                        self.num_id_mgr_in_use.value_namespace = name_space
                        self.num_id_mgr_in_use.value_namespace_prefix = name_space_prefix
                    if(value_path == "pool-id-xr"):
                        self.pool_id_xr = value
                        self.pool_id_xr.value_namespace = name_space
                        self.pool_id_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "pool-size"):
                        self.pool_size = value
                        self.pool_size.value_namespace = name_space
                        self.pool_size.value_namespace_prefix = name_space_prefix
                    if(value_path == "zombied-ids"):
                        self.zombied_ids = value
                        self.zombied_ids.value_namespace = name_space
                        self.zombied_ids.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.index:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.index:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "indexes" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "index"):
                    for c in self.index:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.Indexes.Index()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.index.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "index"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class XconnectSummary(Entity):
            """
            XConnect summary information
            
            .. attribute:: admin_down_backup_interface_xconnects
            
            	Number of XCs with backup interface in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_backup_xconnects
            
            	Number of XCs with backup PW in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_interface_xconnects
            
            	Number of XCs with backup interface in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_xconnects
            
            	Number of XCs with backup PW in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2_ceconnections
            
            	Number of Ce2Ce connections
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_advertized
            
            	Number of CE2CE connections that have been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_not_advertized
            
            	Number of CE2CE connections that have not been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects
            
            	Number of mp2mp xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_advertised
            
            	Number of Mp2mp XCs that have been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_down
            
            	Number of Mp2mp XCs that have ben admined down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_up
            
            	Number of Mp2mp XCs that have been admined up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnectss_not_advertised
            
            	Number of Mp2mp XCs that have not been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects
            
            	Number of xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_administratively_down
            
            	Number of xconnects with segments in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup
            
            	Number of XCs currently using backup PW (UP state)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup_interface
            
            	Number of XCs currently using backup interface (UP state)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_down
            
            	Number of xconnects whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_locally_switched
            
            	Number of locally switched xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
            
            	Number of xconnects of type attachment circuit to pseudowire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
            
            	Number of xconnects of type monitor session to pseudowire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
            
            	Number of xconnects of type PseudoWire To PseudoWire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_unresolved
            
            	Number of xconnects whose state is unresolved
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_up
            
            	Numxber of xconnects whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_interface
            
            	Number of XCs configured with backup interface
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_pw
            
            	Number of XCs configured with backup PW
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_xconnects
            
            	Number of cross\-connects partially programmed
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_interface_xconnects
            
            	Number of XCs with backup interface in standby state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_xconnects
            
            	Number of XCs with backup PW in standby state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_ready_backup_xconnects
            
            	Number of XCs with backup PW in standby ready state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_interface_xconnects
            
            	Number of XCs with backup interface in unresolved state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_xconnects
            
            	Number of XCs with backup PW in unresolved state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.XconnectSummary, self).__init__()

                self.yang_name = "xconnect-summary"
                self.yang_parent_name = "active"

                self.admin_down_backup_interface_xconnects = YLeaf(YType.uint32, "admin-down-backup-interface-xconnects")

                self.admin_down_backup_xconnects = YLeaf(YType.uint32, "admin-down-backup-xconnects")

                self.down_backup_interface_xconnects = YLeaf(YType.uint32, "down-backup-interface-xconnects")

                self.down_backup_xconnects = YLeaf(YType.uint32, "down-backup-xconnects")

                self.number_ce2_ceconnections = YLeaf(YType.uint32, "number-ce2-ceconnections")

                self.number_ce2ce_advertized = YLeaf(YType.uint32, "number-ce2ce-advertized")

                self.number_ce2ce_not_advertized = YLeaf(YType.uint32, "number-ce2ce-not-advertized")

                self.number_groups = YLeaf(YType.uint32, "number-groups")

                self.number_mp2mp_xconnects = YLeaf(YType.uint32, "number-mp2mp-xconnects")

                self.number_mp2mp_xconnects_advertised = YLeaf(YType.uint32, "number-mp2mp-xconnects-advertised")

                self.number_mp2mp_xconnects_down = YLeaf(YType.uint32, "number-mp2mp-xconnects-down")

                self.number_mp2mp_xconnects_up = YLeaf(YType.uint32, "number-mp2mp-xconnects-up")

                self.number_mp2mp_xconnectss_not_advertised = YLeaf(YType.uint32, "number-mp2mp-xconnectss-not-advertised")

                self.number_xconnects = YLeaf(YType.uint32, "number-xconnects")

                self.number_xconnects_administratively_down = YLeaf(YType.uint32, "number-xconnects-administratively-down")

                self.number_xconnects_currently_using_backup = YLeaf(YType.uint32, "number-xconnects-currently-using-backup")

                self.number_xconnects_currently_using_backup_interface = YLeaf(YType.uint32, "number-xconnects-currently-using-backup-interface")

                self.number_xconnects_down = YLeaf(YType.uint32, "number-xconnects-down")

                self.number_xconnects_locally_switched = YLeaf(YType.uint32, "number-xconnects-locally-switched")

                self.number_xconnects_type_attachment_circuit_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-attachment-circuit-to-pseudo-wire")

                self.number_xconnects_type_monitor_session_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-monitor-session-to-pseudo-wire")

                self.number_xconnects_type_pseudo_wire_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-pseudo-wire-to-pseudo-wire")

                self.number_xconnects_unresolved = YLeaf(YType.uint32, "number-xconnects-unresolved")

                self.number_xconnects_up = YLeaf(YType.uint32, "number-xconnects-up")

                self.number_xconnects_with_backup_interface = YLeaf(YType.uint32, "number-xconnects-with-backup-interface")

                self.number_xconnects_with_backup_pw = YLeaf(YType.uint32, "number-xconnects-with-backup-pw")

                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                self.partially_programmed_xconnects = YLeaf(YType.uint32, "partially-programmed-xconnects")

                self.standby_backup_interface_xconnects = YLeaf(YType.uint32, "standby-backup-interface-xconnects")

                self.standby_backup_xconnects = YLeaf(YType.uint32, "standby-backup-xconnects")

                self.standby_ready_backup_xconnects = YLeaf(YType.uint32, "standby-ready-backup-xconnects")

                self.unresolved_backup_interface_xconnects = YLeaf(YType.uint32, "unresolved-backup-interface-xconnects")

                self.unresolved_backup_xconnects = YLeaf(YType.uint32, "unresolved-backup-xconnects")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("admin_down_backup_interface_xconnects",
                                "admin_down_backup_xconnects",
                                "down_backup_interface_xconnects",
                                "down_backup_xconnects",
                                "number_ce2_ceconnections",
                                "number_ce2ce_advertized",
                                "number_ce2ce_not_advertized",
                                "number_groups",
                                "number_mp2mp_xconnects",
                                "number_mp2mp_xconnects_advertised",
                                "number_mp2mp_xconnects_down",
                                "number_mp2mp_xconnects_up",
                                "number_mp2mp_xconnectss_not_advertised",
                                "number_xconnects",
                                "number_xconnects_administratively_down",
                                "number_xconnects_currently_using_backup",
                                "number_xconnects_currently_using_backup_interface",
                                "number_xconnects_down",
                                "number_xconnects_locally_switched",
                                "number_xconnects_type_attachment_circuit_to_pseudo_wire",
                                "number_xconnects_type_monitor_session_to_pseudo_wire",
                                "number_xconnects_type_pseudo_wire_to_pseudo_wire",
                                "number_xconnects_unresolved",
                                "number_xconnects_up",
                                "number_xconnects_with_backup_interface",
                                "number_xconnects_with_backup_pw",
                                "out_of_memory_state",
                                "partially_programmed_xconnects",
                                "standby_backup_interface_xconnects",
                                "standby_backup_xconnects",
                                "standby_ready_backup_xconnects",
                                "unresolved_backup_interface_xconnects",
                                "unresolved_backup_xconnects") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.XconnectSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.XconnectSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.admin_down_backup_interface_xconnects.is_set or
                    self.admin_down_backup_xconnects.is_set or
                    self.down_backup_interface_xconnects.is_set or
                    self.down_backup_xconnects.is_set or
                    self.number_ce2_ceconnections.is_set or
                    self.number_ce2ce_advertized.is_set or
                    self.number_ce2ce_not_advertized.is_set or
                    self.number_groups.is_set or
                    self.number_mp2mp_xconnects.is_set or
                    self.number_mp2mp_xconnects_advertised.is_set or
                    self.number_mp2mp_xconnects_down.is_set or
                    self.number_mp2mp_xconnects_up.is_set or
                    self.number_mp2mp_xconnectss_not_advertised.is_set or
                    self.number_xconnects.is_set or
                    self.number_xconnects_administratively_down.is_set or
                    self.number_xconnects_currently_using_backup.is_set or
                    self.number_xconnects_currently_using_backup_interface.is_set or
                    self.number_xconnects_down.is_set or
                    self.number_xconnects_locally_switched.is_set or
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire.is_set or
                    self.number_xconnects_type_monitor_session_to_pseudo_wire.is_set or
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire.is_set or
                    self.number_xconnects_unresolved.is_set or
                    self.number_xconnects_up.is_set or
                    self.number_xconnects_with_backup_interface.is_set or
                    self.number_xconnects_with_backup_pw.is_set or
                    self.out_of_memory_state.is_set or
                    self.partially_programmed_xconnects.is_set or
                    self.standby_backup_interface_xconnects.is_set or
                    self.standby_backup_xconnects.is_set or
                    self.standby_ready_backup_xconnects.is_set or
                    self.unresolved_backup_interface_xconnects.is_set or
                    self.unresolved_backup_xconnects.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.admin_down_backup_interface_xconnects.yfilter != YFilter.not_set or
                    self.admin_down_backup_xconnects.yfilter != YFilter.not_set or
                    self.down_backup_interface_xconnects.yfilter != YFilter.not_set or
                    self.down_backup_xconnects.yfilter != YFilter.not_set or
                    self.number_ce2_ceconnections.yfilter != YFilter.not_set or
                    self.number_ce2ce_advertized.yfilter != YFilter.not_set or
                    self.number_ce2ce_not_advertized.yfilter != YFilter.not_set or
                    self.number_groups.yfilter != YFilter.not_set or
                    self.number_mp2mp_xconnects.yfilter != YFilter.not_set or
                    self.number_mp2mp_xconnects_advertised.yfilter != YFilter.not_set or
                    self.number_mp2mp_xconnects_down.yfilter != YFilter.not_set or
                    self.number_mp2mp_xconnects_up.yfilter != YFilter.not_set or
                    self.number_mp2mp_xconnectss_not_advertised.yfilter != YFilter.not_set or
                    self.number_xconnects.yfilter != YFilter.not_set or
                    self.number_xconnects_administratively_down.yfilter != YFilter.not_set or
                    self.number_xconnects_currently_using_backup.yfilter != YFilter.not_set or
                    self.number_xconnects_currently_using_backup_interface.yfilter != YFilter.not_set or
                    self.number_xconnects_down.yfilter != YFilter.not_set or
                    self.number_xconnects_locally_switched.yfilter != YFilter.not_set or
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire.yfilter != YFilter.not_set or
                    self.number_xconnects_type_monitor_session_to_pseudo_wire.yfilter != YFilter.not_set or
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire.yfilter != YFilter.not_set or
                    self.number_xconnects_unresolved.yfilter != YFilter.not_set or
                    self.number_xconnects_up.yfilter != YFilter.not_set or
                    self.number_xconnects_with_backup_interface.yfilter != YFilter.not_set or
                    self.number_xconnects_with_backup_pw.yfilter != YFilter.not_set or
                    self.out_of_memory_state.yfilter != YFilter.not_set or
                    self.partially_programmed_xconnects.yfilter != YFilter.not_set or
                    self.standby_backup_interface_xconnects.yfilter != YFilter.not_set or
                    self.standby_backup_xconnects.yfilter != YFilter.not_set or
                    self.standby_ready_backup_xconnects.yfilter != YFilter.not_set or
                    self.unresolved_backup_interface_xconnects.yfilter != YFilter.not_set or
                    self.unresolved_backup_xconnects.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.admin_down_backup_interface_xconnects.is_set or self.admin_down_backup_interface_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.admin_down_backup_interface_xconnects.get_name_leafdata())
                if (self.admin_down_backup_xconnects.is_set or self.admin_down_backup_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.admin_down_backup_xconnects.get_name_leafdata())
                if (self.down_backup_interface_xconnects.is_set or self.down_backup_interface_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.down_backup_interface_xconnects.get_name_leafdata())
                if (self.down_backup_xconnects.is_set or self.down_backup_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.down_backup_xconnects.get_name_leafdata())
                if (self.number_ce2_ceconnections.is_set or self.number_ce2_ceconnections.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_ce2_ceconnections.get_name_leafdata())
                if (self.number_ce2ce_advertized.is_set or self.number_ce2ce_advertized.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_ce2ce_advertized.get_name_leafdata())
                if (self.number_ce2ce_not_advertized.is_set or self.number_ce2ce_not_advertized.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_ce2ce_not_advertized.get_name_leafdata())
                if (self.number_groups.is_set or self.number_groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_groups.get_name_leafdata())
                if (self.number_mp2mp_xconnects.is_set or self.number_mp2mp_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2mp_xconnects.get_name_leafdata())
                if (self.number_mp2mp_xconnects_advertised.is_set or self.number_mp2mp_xconnects_advertised.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2mp_xconnects_advertised.get_name_leafdata())
                if (self.number_mp2mp_xconnects_down.is_set or self.number_mp2mp_xconnects_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2mp_xconnects_down.get_name_leafdata())
                if (self.number_mp2mp_xconnects_up.is_set or self.number_mp2mp_xconnects_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2mp_xconnects_up.get_name_leafdata())
                if (self.number_mp2mp_xconnectss_not_advertised.is_set or self.number_mp2mp_xconnectss_not_advertised.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2mp_xconnectss_not_advertised.get_name_leafdata())
                if (self.number_xconnects.is_set or self.number_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects.get_name_leafdata())
                if (self.number_xconnects_administratively_down.is_set or self.number_xconnects_administratively_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_administratively_down.get_name_leafdata())
                if (self.number_xconnects_currently_using_backup.is_set or self.number_xconnects_currently_using_backup.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_currently_using_backup.get_name_leafdata())
                if (self.number_xconnects_currently_using_backup_interface.is_set or self.number_xconnects_currently_using_backup_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_currently_using_backup_interface.get_name_leafdata())
                if (self.number_xconnects_down.is_set or self.number_xconnects_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_down.get_name_leafdata())
                if (self.number_xconnects_locally_switched.is_set or self.number_xconnects_locally_switched.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_locally_switched.get_name_leafdata())
                if (self.number_xconnects_type_attachment_circuit_to_pseudo_wire.is_set or self.number_xconnects_type_attachment_circuit_to_pseudo_wire.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_type_attachment_circuit_to_pseudo_wire.get_name_leafdata())
                if (self.number_xconnects_type_monitor_session_to_pseudo_wire.is_set or self.number_xconnects_type_monitor_session_to_pseudo_wire.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_type_monitor_session_to_pseudo_wire.get_name_leafdata())
                if (self.number_xconnects_type_pseudo_wire_to_pseudo_wire.is_set or self.number_xconnects_type_pseudo_wire_to_pseudo_wire.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_type_pseudo_wire_to_pseudo_wire.get_name_leafdata())
                if (self.number_xconnects_unresolved.is_set or self.number_xconnects_unresolved.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_unresolved.get_name_leafdata())
                if (self.number_xconnects_up.is_set or self.number_xconnects_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_up.get_name_leafdata())
                if (self.number_xconnects_with_backup_interface.is_set or self.number_xconnects_with_backup_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_with_backup_interface.get_name_leafdata())
                if (self.number_xconnects_with_backup_pw.is_set or self.number_xconnects_with_backup_pw.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects_with_backup_pw.get_name_leafdata())
                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                if (self.partially_programmed_xconnects.is_set or self.partially_programmed_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.partially_programmed_xconnects.get_name_leafdata())
                if (self.standby_backup_interface_xconnects.is_set or self.standby_backup_interface_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.standby_backup_interface_xconnects.get_name_leafdata())
                if (self.standby_backup_xconnects.is_set or self.standby_backup_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.standby_backup_xconnects.get_name_leafdata())
                if (self.standby_ready_backup_xconnects.is_set or self.standby_ready_backup_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.standby_ready_backup_xconnects.get_name_leafdata())
                if (self.unresolved_backup_interface_xconnects.is_set or self.unresolved_backup_interface_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unresolved_backup_interface_xconnects.get_name_leafdata())
                if (self.unresolved_backup_xconnects.is_set or self.unresolved_backup_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unresolved_backup_xconnects.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "admin-down-backup-interface-xconnects" or name == "admin-down-backup-xconnects" or name == "down-backup-interface-xconnects" or name == "down-backup-xconnects" or name == "number-ce2-ceconnections" or name == "number-ce2ce-advertized" or name == "number-ce2ce-not-advertized" or name == "number-groups" or name == "number-mp2mp-xconnects" or name == "number-mp2mp-xconnects-advertised" or name == "number-mp2mp-xconnects-down" or name == "number-mp2mp-xconnects-up" or name == "number-mp2mp-xconnectss-not-advertised" or name == "number-xconnects" or name == "number-xconnects-administratively-down" or name == "number-xconnects-currently-using-backup" or name == "number-xconnects-currently-using-backup-interface" or name == "number-xconnects-down" or name == "number-xconnects-locally-switched" or name == "number-xconnects-type-attachment-circuit-to-pseudo-wire" or name == "number-xconnects-type-monitor-session-to-pseudo-wire" or name == "number-xconnects-type-pseudo-wire-to-pseudo-wire" or name == "number-xconnects-unresolved" or name == "number-xconnects-up" or name == "number-xconnects-with-backup-interface" or name == "number-xconnects-with-backup-pw" or name == "out-of-memory-state" or name == "partially-programmed-xconnects" or name == "standby-backup-interface-xconnects" or name == "standby-backup-xconnects" or name == "standby-ready-backup-xconnects" or name == "unresolved-backup-interface-xconnects" or name == "unresolved-backup-xconnects"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "admin-down-backup-interface-xconnects"):
                    self.admin_down_backup_interface_xconnects = value
                    self.admin_down_backup_interface_xconnects.value_namespace = name_space
                    self.admin_down_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "admin-down-backup-xconnects"):
                    self.admin_down_backup_xconnects = value
                    self.admin_down_backup_xconnects.value_namespace = name_space
                    self.admin_down_backup_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "down-backup-interface-xconnects"):
                    self.down_backup_interface_xconnects = value
                    self.down_backup_interface_xconnects.value_namespace = name_space
                    self.down_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "down-backup-xconnects"):
                    self.down_backup_xconnects = value
                    self.down_backup_xconnects.value_namespace = name_space
                    self.down_backup_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "number-ce2-ceconnections"):
                    self.number_ce2_ceconnections = value
                    self.number_ce2_ceconnections.value_namespace = name_space
                    self.number_ce2_ceconnections.value_namespace_prefix = name_space_prefix
                if(value_path == "number-ce2ce-advertized"):
                    self.number_ce2ce_advertized = value
                    self.number_ce2ce_advertized.value_namespace = name_space
                    self.number_ce2ce_advertized.value_namespace_prefix = name_space_prefix
                if(value_path == "number-ce2ce-not-advertized"):
                    self.number_ce2ce_not_advertized = value
                    self.number_ce2ce_not_advertized.value_namespace = name_space
                    self.number_ce2ce_not_advertized.value_namespace_prefix = name_space_prefix
                if(value_path == "number-groups"):
                    self.number_groups = value
                    self.number_groups.value_namespace = name_space
                    self.number_groups.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2mp-xconnects"):
                    self.number_mp2mp_xconnects = value
                    self.number_mp2mp_xconnects.value_namespace = name_space
                    self.number_mp2mp_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2mp-xconnects-advertised"):
                    self.number_mp2mp_xconnects_advertised = value
                    self.number_mp2mp_xconnects_advertised.value_namespace = name_space
                    self.number_mp2mp_xconnects_advertised.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2mp-xconnects-down"):
                    self.number_mp2mp_xconnects_down = value
                    self.number_mp2mp_xconnects_down.value_namespace = name_space
                    self.number_mp2mp_xconnects_down.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2mp-xconnects-up"):
                    self.number_mp2mp_xconnects_up = value
                    self.number_mp2mp_xconnects_up.value_namespace = name_space
                    self.number_mp2mp_xconnects_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2mp-xconnectss-not-advertised"):
                    self.number_mp2mp_xconnectss_not_advertised = value
                    self.number_mp2mp_xconnectss_not_advertised.value_namespace = name_space
                    self.number_mp2mp_xconnectss_not_advertised.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects"):
                    self.number_xconnects = value
                    self.number_xconnects.value_namespace = name_space
                    self.number_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-administratively-down"):
                    self.number_xconnects_administratively_down = value
                    self.number_xconnects_administratively_down.value_namespace = name_space
                    self.number_xconnects_administratively_down.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-currently-using-backup"):
                    self.number_xconnects_currently_using_backup = value
                    self.number_xconnects_currently_using_backup.value_namespace = name_space
                    self.number_xconnects_currently_using_backup.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-currently-using-backup-interface"):
                    self.number_xconnects_currently_using_backup_interface = value
                    self.number_xconnects_currently_using_backup_interface.value_namespace = name_space
                    self.number_xconnects_currently_using_backup_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-down"):
                    self.number_xconnects_down = value
                    self.number_xconnects_down.value_namespace = name_space
                    self.number_xconnects_down.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-locally-switched"):
                    self.number_xconnects_locally_switched = value
                    self.number_xconnects_locally_switched.value_namespace = name_space
                    self.number_xconnects_locally_switched.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-type-attachment-circuit-to-pseudo-wire"):
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire = value
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire.value_namespace = name_space
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-type-monitor-session-to-pseudo-wire"):
                    self.number_xconnects_type_monitor_session_to_pseudo_wire = value
                    self.number_xconnects_type_monitor_session_to_pseudo_wire.value_namespace = name_space
                    self.number_xconnects_type_monitor_session_to_pseudo_wire.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-type-pseudo-wire-to-pseudo-wire"):
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire = value
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire.value_namespace = name_space
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-unresolved"):
                    self.number_xconnects_unresolved = value
                    self.number_xconnects_unresolved.value_namespace = name_space
                    self.number_xconnects_unresolved.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-up"):
                    self.number_xconnects_up = value
                    self.number_xconnects_up.value_namespace = name_space
                    self.number_xconnects_up.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-with-backup-interface"):
                    self.number_xconnects_with_backup_interface = value
                    self.number_xconnects_with_backup_interface.value_namespace = name_space
                    self.number_xconnects_with_backup_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects-with-backup-pw"):
                    self.number_xconnects_with_backup_pw = value
                    self.number_xconnects_with_backup_pw.value_namespace = name_space
                    self.number_xconnects_with_backup_pw.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-memory-state"):
                    self.out_of_memory_state = value
                    self.out_of_memory_state.value_namespace = name_space
                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                if(value_path == "partially-programmed-xconnects"):
                    self.partially_programmed_xconnects = value
                    self.partially_programmed_xconnects.value_namespace = name_space
                    self.partially_programmed_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "standby-backup-interface-xconnects"):
                    self.standby_backup_interface_xconnects = value
                    self.standby_backup_interface_xconnects.value_namespace = name_space
                    self.standby_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "standby-backup-xconnects"):
                    self.standby_backup_xconnects = value
                    self.standby_backup_xconnects.value_namespace = name_space
                    self.standby_backup_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "standby-ready-backup-xconnects"):
                    self.standby_ready_backup_xconnects = value
                    self.standby_ready_backup_xconnects.value_namespace = name_space
                    self.standby_ready_backup_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "unresolved-backup-interface-xconnects"):
                    self.unresolved_backup_interface_xconnects = value
                    self.unresolved_backup_interface_xconnects.value_namespace = name_space
                    self.unresolved_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                if(value_path == "unresolved-backup-xconnects"):
                    self.unresolved_backup_xconnects = value
                    self.unresolved_backup_xconnects.value_namespace = name_space
                    self.unresolved_backup_xconnects.value_namespace_prefix = name_space_prefix


        class ProcFsm(Entity):
            """
            L2VPN Process FSM information
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.EventHistory>`
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.FailoverStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.IssuStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.NsrStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.ReportCard>`
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\:  bool
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.XidInfo>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.ProcFsm, self).__init__()

                self.yang_name = "proc-fsm"
                self.yang_parent_name = "active"

                self.process_role = YLeaf(YType.uint8, "process-role")

                self.process_state = YLeaf(YType.uint8, "process-state")

                self.state_transition_time = YLeafList(YType.uint32, "state-transition-time")

                self.sw_install_in_progress = YLeaf(YType.boolean, "sw-install-in-progress")

                self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                self.failover_status = L2Vpnv2.Active.ProcFsm.FailoverStatus()
                self.failover_status.parent = self
                self._children_name_map["failover_status"] = "failover-status"
                self._children_yang_names.add("failover-status")

                self.issu_status = L2Vpnv2.Active.ProcFsm.IssuStatus()
                self.issu_status.parent = self
                self._children_name_map["issu_status"] = "issu-status"
                self._children_yang_names.add("issu-status")

                self.nsr_status = L2Vpnv2.Active.ProcFsm.NsrStatus()
                self.nsr_status.parent = self
                self._children_name_map["nsr_status"] = "nsr-status"
                self._children_yang_names.add("nsr-status")

                self.event_history = YList(self)
                self.report_card = YList(self)
                self.xid_info = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("process_role",
                                "process_state",
                                "state_transition_time",
                                "sw_install_in_progress",
                                "sync_flags") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.ProcFsm, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.ProcFsm, self).__setattr__(name, value)


            class FailoverStatus(Entity):
                """
                L2VPN failover status
                
                .. attribute:: master_time
                
                	Master time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.ProcFsm.FailoverStatus, self).__init__()

                    self.yang_name = "failover-status"
                    self.yang_parent_name = "proc-fsm"

                    self.master_time = YLeaf(YType.uint32, "master-time")

                    self.start_time = YLeaf(YType.uint32, "start-time")

                    self.triggered_time = YLeaf(YType.uint32, "triggered-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("master_time",
                                    "start_time",
                                    "triggered_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.ProcFsm.FailoverStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.ProcFsm.FailoverStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.master_time.is_set or
                        self.start_time.is_set or
                        self.triggered_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.master_time.yfilter != YFilter.not_set or
                        self.start_time.yfilter != YFilter.not_set or
                        self.triggered_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "failover-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.master_time.is_set or self.master_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.master_time.get_name_leafdata())
                    if (self.start_time.is_set or self.start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.start_time.get_name_leafdata())
                    if (self.triggered_time.is_set or self.triggered_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.triggered_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "master-time" or name == "start-time" or name == "triggered-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "master-time"):
                        self.master_time = value
                        self.master_time.value_namespace = name_space
                        self.master_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "start-time"):
                        self.start_time = value
                        self.start_time.value_namespace = name_space
                        self.start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "triggered-time"):
                        self.triggered_time = value
                        self.triggered_time.value_namespace = name_space
                        self.triggered_time.value_namespace_prefix = name_space_prefix


            class NsrStatus(Entity):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.ProcFsm.NsrStatus, self).__init__()

                    self.yang_name = "nsr-status"
                    self.yang_parent_name = "proc-fsm"

                    self.role = YLeaf(YType.enumeration, "role")

                    self.idt_status = L2Vpnv2.Active.ProcFsm.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"
                    self._children_yang_names.add("idt-status")

                    self.previ_ous_idt_status = L2Vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._children_yang_names.add("previ-ous-idt-status")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("role") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.ProcFsm.NsrStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.ProcFsm.NsrStatus, self).__setattr__(name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.ProcFsm.NsrStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "nsr-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.ProcFsm.NsrStatus.IdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.ProcFsm.NsrStatus.IdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/nsr-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "nsr-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "previ-ous-idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/nsr-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.role.is_set or
                        (self.idt_status is not None and self.idt_status.has_data()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.role.yfilter != YFilter.not_set or
                        (self.idt_status is not None and self.idt_status.has_operation()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "idt-status"):
                        if (self.idt_status is None):
                            self.idt_status = L2Vpnv2.Active.ProcFsm.NsrStatus.IdtStatus()
                            self.idt_status.parent = self
                            self._children_name_map["idt_status"] = "idt-status"
                        return self.idt_status

                    if (child_yang_name == "previ-ous-idt-status"):
                        if (self.previ_ous_idt_status is None):
                            self.previ_ous_idt_status = L2Vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus()
                            self.previ_ous_idt_status.parent = self
                            self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        return self.previ_ous_idt_status

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "role"):
                        self.role = value
                        self.role.value_namespace = name_space
                        self.role.value_namespace_prefix = name_space_prefix


            class IssuStatus(Entity):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.ProcFsm.IssuStatus, self).__init__()

                    self.yang_name = "issu-status"
                    self.yang_parent_name = "proc-fsm"

                    self.role = YLeaf(YType.enumeration, "role")

                    self.idt_status = L2Vpnv2.Active.ProcFsm.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"
                    self._children_yang_names.add("idt-status")

                    self.previ_ous_idt_status = L2Vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._children_yang_names.add("previ-ous-idt-status")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("role") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.ProcFsm.IssuStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.ProcFsm.IssuStatus, self).__setattr__(name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.ProcFsm.IssuStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "issu-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.ProcFsm.IssuStatus.IdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.ProcFsm.IssuStatus.IdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/issu-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "issu-status"

                        self.declare_time = YLeaf(YType.uint32, "declare-time")

                        self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                        self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                        self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                        self.sync_status = YLeaf(YType.enumeration, "sync-status")

                        self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("declare_time",
                                        "idt_end_time",
                                        "idt_start_time",
                                        "not_ready_reason",
                                        "sync_status",
                                        "withdraw_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.declare_time.is_set or
                            self.idt_end_time.is_set or
                            self.idt_start_time.is_set or
                            self.not_ready_reason.is_set or
                            self.sync_status.is_set or
                            self.withdraw_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.declare_time.yfilter != YFilter.not_set or
                            self.idt_end_time.yfilter != YFilter.not_set or
                            self.idt_start_time.yfilter != YFilter.not_set or
                            self.not_ready_reason.yfilter != YFilter.not_set or
                            self.sync_status.yfilter != YFilter.not_set or
                            self.withdraw_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "previ-ous-idt-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/issu-status/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.declare_time.get_name_leafdata())
                        if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                        if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                        if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                        if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sync_status.get_name_leafdata())
                        if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "declare-time"):
                            self.declare_time = value
                            self.declare_time.value_namespace = name_space
                            self.declare_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-end-time"):
                            self.idt_end_time = value
                            self.idt_end_time.value_namespace = name_space
                            self.idt_end_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-start-time"):
                            self.idt_start_time = value
                            self.idt_start_time.value_namespace = name_space
                            self.idt_start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-ready-reason"):
                            self.not_ready_reason = value
                            self.not_ready_reason.value_namespace = name_space
                            self.not_ready_reason.value_namespace_prefix = name_space_prefix
                        if(value_path == "sync-status"):
                            self.sync_status = value
                            self.sync_status.value_namespace = name_space
                            self.sync_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "withdraw-time"):
                            self.withdraw_time = value
                            self.withdraw_time.value_namespace = name_space
                            self.withdraw_time.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.role.is_set or
                        (self.idt_status is not None and self.idt_status.has_data()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.role.yfilter != YFilter.not_set or
                        (self.idt_status is not None and self.idt_status.has_operation()) or
                        (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "issu-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "idt-status"):
                        if (self.idt_status is None):
                            self.idt_status = L2Vpnv2.Active.ProcFsm.IssuStatus.IdtStatus()
                            self.idt_status.parent = self
                            self._children_name_map["idt_status"] = "idt-status"
                        return self.idt_status

                    if (child_yang_name == "previ-ous-idt-status"):
                        if (self.previ_ous_idt_status is None):
                            self.previ_ous_idt_status = L2Vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus()
                            self.previ_ous_idt_status.parent = self
                            self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        return self.previ_ous_idt_status

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "role"):
                        self.role = value
                        self.role.value_namespace = name_space
                        self.role.value_namespace_prefix = name_space_prefix


            class XidInfo(Entity):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.ProcFsm.XidInfo, self).__init__()

                    self.yang_name = "xid-info"
                    self.yang_parent_name = "proc-fsm"

                    self.app_type = YLeaf(YType.enumeration, "app-type")

                    self.sent_ids = YLeaf(YType.uint32, "sent-ids")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("app_type",
                                    "sent_ids") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.ProcFsm.XidInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.ProcFsm.XidInfo, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.app_type.is_set or
                        self.sent_ids.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.app_type.yfilter != YFilter.not_set or
                        self.sent_ids.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xid-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.app_type.is_set or self.app_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.app_type.get_name_leafdata())
                    if (self.sent_ids.is_set or self.sent_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sent_ids.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "app-type" or name == "sent-ids"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "app-type"):
                        self.app_type = value
                        self.app_type.value_namespace = name_space
                        self.app_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "sent-ids"):
                        self.sent_ids = value
                        self.sent_ids.value_namespace = name_space
                        self.sent_ids.value_namespace_prefix = name_space_prefix


            class ReportCard(Entity):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\:  bool
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\:  bool
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\:  bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.ProcFsm.ReportCard, self).__init__()

                    self.yang_name = "report-card"
                    self.yang_parent_name = "proc-fsm"

                    self.collaborator_idt_done = YLeaf(YType.boolean, "collaborator-idt-done")

                    self.collaborator_is_connected = YLeaf(YType.boolean, "collaborator-is-connected")

                    self.collaborator_skipped = YLeaf(YType.boolean, "collaborator-skipped")

                    self.connection_change_time = YLeaf(YType.uint32, "connection-change-time")

                    self.idt_time = YLeaf(YType.uint32, "idt-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("collaborator_idt_done",
                                    "collaborator_is_connected",
                                    "collaborator_skipped",
                                    "connection_change_time",
                                    "idt_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.ProcFsm.ReportCard, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.ProcFsm.ReportCard, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.collaborator_idt_done.is_set or
                        self.collaborator_is_connected.is_set or
                        self.collaborator_skipped.is_set or
                        self.connection_change_time.is_set or
                        self.idt_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.collaborator_idt_done.yfilter != YFilter.not_set or
                        self.collaborator_is_connected.yfilter != YFilter.not_set or
                        self.collaborator_skipped.yfilter != YFilter.not_set or
                        self.connection_change_time.yfilter != YFilter.not_set or
                        self.idt_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "report-card" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.collaborator_idt_done.is_set or self.collaborator_idt_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_idt_done.get_name_leafdata())
                    if (self.collaborator_is_connected.is_set or self.collaborator_is_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_is_connected.get_name_leafdata())
                    if (self.collaborator_skipped.is_set or self.collaborator_skipped.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_skipped.get_name_leafdata())
                    if (self.connection_change_time.is_set or self.connection_change_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.connection_change_time.get_name_leafdata())
                    if (self.idt_time.is_set or self.idt_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "collaborator-idt-done" or name == "collaborator-is-connected" or name == "collaborator-skipped" or name == "connection-change-time" or name == "idt-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "collaborator-idt-done"):
                        self.collaborator_idt_done = value
                        self.collaborator_idt_done.value_namespace = name_space
                        self.collaborator_idt_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "collaborator-is-connected"):
                        self.collaborator_is_connected = value
                        self.collaborator_is_connected.value_namespace = name_space
                        self.collaborator_is_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "collaborator-skipped"):
                        self.collaborator_skipped = value
                        self.collaborator_skipped.value_namespace = name_space
                        self.collaborator_skipped.value_namespace_prefix = name_space_prefix
                    if(value_path == "connection-change-time"):
                        self.connection_change_time = value
                        self.connection_change_time.value_namespace = name_space
                        self.connection_change_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-time"):
                        self.idt_time = value
                        self.idt_time.value_namespace = name_space
                        self.idt_time.value_namespace_prefix = name_space_prefix


            class EventHistory(Entity):
                """
                L2VPN Process event history
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: new_state
                
                	New state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: process_event
                
                	Process event
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.ProcFsm.EventHistory, self).__init__()

                    self.yang_name = "event-history"
                    self.yang_parent_name = "proc-fsm"

                    self.event_timestamp = YLeaf(YType.uint32, "event-timestamp")

                    self.new_state = YLeaf(YType.uint8, "new-state")

                    self.previous_state = YLeaf(YType.uint8, "previous-state")

                    self.process_collaborator = YLeaf(YType.uint16, "process-collaborator")

                    self.process_event = YLeaf(YType.uint16, "process-event")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("event_timestamp",
                                    "new_state",
                                    "previous_state",
                                    "process_collaborator",
                                    "process_event") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.ProcFsm.EventHistory, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.ProcFsm.EventHistory, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.event_timestamp.is_set or
                        self.new_state.is_set or
                        self.previous_state.is_set or
                        self.process_collaborator.is_set or
                        self.process_event.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.event_timestamp.yfilter != YFilter.not_set or
                        self.new_state.yfilter != YFilter.not_set or
                        self.previous_state.yfilter != YFilter.not_set or
                        self.process_collaborator.yfilter != YFilter.not_set or
                        self.process_event.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "event-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.event_timestamp.is_set or self.event_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.event_timestamp.get_name_leafdata())
                    if (self.new_state.is_set or self.new_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.new_state.get_name_leafdata())
                    if (self.previous_state.is_set or self.previous_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.previous_state.get_name_leafdata())
                    if (self.process_collaborator.is_set or self.process_collaborator.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_collaborator.get_name_leafdata())
                    if (self.process_event.is_set or self.process_event.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_event.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "event-timestamp" or name == "new-state" or name == "previous-state" or name == "process-collaborator" or name == "process-event"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "event-timestamp"):
                        self.event_timestamp = value
                        self.event_timestamp.value_namespace = name_space
                        self.event_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "new-state"):
                        self.new_state = value
                        self.new_state.value_namespace = name_space
                        self.new_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "previous-state"):
                        self.previous_state = value
                        self.previous_state.value_namespace = name_space
                        self.previous_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-collaborator"):
                        self.process_collaborator = value
                        self.process_collaborator.value_namespace = name_space
                        self.process_collaborator.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-event"):
                        self.process_event = value
                        self.process_event.value_namespace = name_space
                        self.process_event.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.event_history:
                    if (c.has_data()):
                        return True
                for c in self.report_card:
                    if (c.has_data()):
                        return True
                for c in self.xid_info:
                    if (c.has_data()):
                        return True
                for leaf in self.state_transition_time.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                return (
                    self.process_role.is_set or
                    self.process_state.is_set or
                    self.sw_install_in_progress.is_set or
                    self.sync_flags.is_set or
                    (self.failover_status is not None and self.failover_status.has_data()) or
                    (self.issu_status is not None and self.issu_status.has_data()) or
                    (self.nsr_status is not None and self.nsr_status.has_data()))

            def has_operation(self):
                for c in self.event_history:
                    if (c.has_operation()):
                        return True
                for c in self.report_card:
                    if (c.has_operation()):
                        return True
                for c in self.xid_info:
                    if (c.has_operation()):
                        return True
                for leaf in self.state_transition_time.getYLeafs():
                    if (leaf.is_set):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.process_role.yfilter != YFilter.not_set or
                    self.process_state.yfilter != YFilter.not_set or
                    self.state_transition_time.yfilter != YFilter.not_set or
                    self.sw_install_in_progress.yfilter != YFilter.not_set or
                    self.sync_flags.yfilter != YFilter.not_set or
                    (self.failover_status is not None and self.failover_status.has_operation()) or
                    (self.issu_status is not None and self.issu_status.has_operation()) or
                    (self.nsr_status is not None and self.nsr_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "proc-fsm" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.process_role.is_set or self.process_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_role.get_name_leafdata())
                if (self.process_state.is_set or self.process_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_state.get_name_leafdata())
                if (self.sw_install_in_progress.is_set or self.sw_install_in_progress.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sw_install_in_progress.get_name_leafdata())
                if (self.sync_flags.is_set or self.sync_flags.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sync_flags.get_name_leafdata())

                leaf_name_data.extend(self.state_transition_time.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "event-history"):
                    for c in self.event_history:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.ProcFsm.EventHistory()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.event_history.append(c)
                    return c

                if (child_yang_name == "failover-status"):
                    if (self.failover_status is None):
                        self.failover_status = L2Vpnv2.Active.ProcFsm.FailoverStatus()
                        self.failover_status.parent = self
                        self._children_name_map["failover_status"] = "failover-status"
                    return self.failover_status

                if (child_yang_name == "issu-status"):
                    if (self.issu_status is None):
                        self.issu_status = L2Vpnv2.Active.ProcFsm.IssuStatus()
                        self.issu_status.parent = self
                        self._children_name_map["issu_status"] = "issu-status"
                    return self.issu_status

                if (child_yang_name == "nsr-status"):
                    if (self.nsr_status is None):
                        self.nsr_status = L2Vpnv2.Active.ProcFsm.NsrStatus()
                        self.nsr_status.parent = self
                        self._children_name_map["nsr_status"] = "nsr-status"
                    return self.nsr_status

                if (child_yang_name == "report-card"):
                    for c in self.report_card:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.ProcFsm.ReportCard()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.report_card.append(c)
                    return c

                if (child_yang_name == "xid-info"):
                    for c in self.xid_info:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.ProcFsm.XidInfo()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.xid_info.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "event-history" or name == "failover-status" or name == "issu-status" or name == "nsr-status" or name == "report-card" or name == "xid-info" or name == "process-role" or name == "process-state" or name == "state-transition-time" or name == "sw-install-in-progress" or name == "sync-flags"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "process-role"):
                    self.process_role = value
                    self.process_role.value_namespace = name_space
                    self.process_role.value_namespace_prefix = name_space_prefix
                if(value_path == "process-state"):
                    self.process_state = value
                    self.process_state.value_namespace = name_space
                    self.process_state.value_namespace_prefix = name_space_prefix
                if(value_path == "state-transition-time"):
                    self.state_transition_time.append(value)
                if(value_path == "sw-install-in-progress"):
                    self.sw_install_in_progress = value
                    self.sw_install_in_progress.value_namespace = name_space
                    self.sw_install_in_progress.value_namespace_prefix = name_space_prefix
                if(value_path == "sync-flags"):
                    self.sync_flags = value
                    self.sync_flags.value_namespace = name_space
                    self.sync_flags.value_namespace_prefix = name_space_prefix


        class MstpPorts(Entity):
            """
            L2VPN MSTP Port Table
            
            .. attribute:: mstp_port
            
            	MSTP Port information
            	**type**\: list of    :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpPorts.MstpPort>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.MstpPorts, self).__init__()

                self.yang_name = "mstp-ports"
                self.yang_parent_name = "active"

                self.mstp_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.MstpPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.MstpPorts, self).__setattr__(name, value)


            class MstpPort(Entity):
                """
                MSTP Port information
                
                .. attribute:: interface  <key>
                
                	Interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\:  str
                
                .. attribute:: msti_entry
                
                	MSTI
                	**type**\: list of    :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry>`
                
                .. attribute:: mstp_interface_handle
                
                	Interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: protected
                
                	Protected
                	**type**\:  bool
                
                .. attribute:: reference_count
                
                	Reference Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.MstpPorts.MstpPort, self).__init__()

                    self.yang_name = "mstp-port"
                    self.yang_parent_name = "mstp-ports"

                    self.interface = YLeaf(YType.str, "interface")

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.mstp_interface_handle = YLeaf(YType.str, "mstp-interface-handle")

                    self.protected = YLeaf(YType.boolean, "protected")

                    self.reference_count = YLeaf(YType.uint32, "reference-count")

                    self.msti_entry = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface",
                                    "interface_name",
                                    "mstp_interface_handle",
                                    "protected",
                                    "reference_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.MstpPorts.MstpPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.MstpPorts.MstpPort, self).__setattr__(name, value)


                class MstiEntry(Entity):
                    """
                    MSTI
                    
                    .. attribute:: ack_count
                    
                    	Ack count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_count
                    
                    	BD count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_entry
                    
                    	BD entries
                    	**type**\: list of    :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                    
                    .. attribute:: cfg_ms_ti
                    
                    	 Configured MSTi
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: flush_count
                    
                    	Flush count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_flags
                    
                    	Msti Flags
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_state
                    
                    	Msti State
                    	**type**\:   :py:class:`L2VpnMstiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMstiState>`
                    
                    .. attribute:: nack_count
                    
                    	Nack count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rcv_count
                    
                    	Receive count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry, self).__init__()

                        self.yang_name = "msti-entry"
                        self.yang_parent_name = "mstp-port"

                        self.ack_count = YLeaf(YType.uint32, "ack-count")

                        self.bd_count = YLeaf(YType.uint32, "bd-count")

                        self.cfg_ms_ti = YLeaf(YType.uint32, "cfg-ms-ti")

                        self.flush_count = YLeaf(YType.uint32, "flush-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                        self.msti_flags = YLeaf(YType.uint32, "msti-flags")

                        self.msti_state = YLeaf(YType.enumeration, "msti-state")

                        self.nack_count = YLeaf(YType.uint32, "nack-count")

                        self.rcv_count = YLeaf(YType.uint32, "rcv-count")

                        self.bd_entry = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ack_count",
                                        "bd_count",
                                        "cfg_ms_ti",
                                        "flush_count",
                                        "interface_count",
                                        "msti_flags",
                                        "msti_state",
                                        "nack_count",
                                        "rcv_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry, self).__setattr__(name, value)


                    class BdEntry(Entity):
                        """
                        BD entries
                        
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bdif_count
                        
                        	BD Intf Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__init__()

                            self.yang_name = "bd-entry"
                            self.yang_parent_name = "msti-entry"

                            self.bdid = YLeaf(YType.uint32, "bdid")

                            self.bdif_count = YLeaf(YType.uint32, "bdif-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bdid",
                                            "bdif_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bdid.is_set or
                                self.bdif_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bdid.yfilter != YFilter.not_set or
                                self.bdif_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bd-entry" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bdid.is_set or self.bdid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bdid.get_name_leafdata())
                            if (self.bdif_count.is_set or self.bdif_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bdif_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bdid" or name == "bdif-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bdid"):
                                self.bdid = value
                                self.bdid.value_namespace = name_space
                                self.bdid.value_namespace_prefix = name_space_prefix
                            if(value_path == "bdif-count"):
                                self.bdif_count = value
                                self.bdif_count.value_namespace = name_space
                                self.bdif_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bd_entry:
                            if (c.has_data()):
                                return True
                        return (
                            self.ack_count.is_set or
                            self.bd_count.is_set or
                            self.cfg_ms_ti.is_set or
                            self.flush_count.is_set or
                            self.interface_count.is_set or
                            self.msti_flags.is_set or
                            self.msti_state.is_set or
                            self.nack_count.is_set or
                            self.rcv_count.is_set)

                    def has_operation(self):
                        for c in self.bd_entry:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ack_count.yfilter != YFilter.not_set or
                            self.bd_count.yfilter != YFilter.not_set or
                            self.cfg_ms_ti.yfilter != YFilter.not_set or
                            self.flush_count.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set or
                            self.msti_flags.yfilter != YFilter.not_set or
                            self.msti_state.yfilter != YFilter.not_set or
                            self.nack_count.yfilter != YFilter.not_set or
                            self.rcv_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "msti-entry" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ack_count.is_set or self.ack_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ack_count.get_name_leafdata())
                        if (self.bd_count.is_set or self.bd_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bd_count.get_name_leafdata())
                        if (self.cfg_ms_ti.is_set or self.cfg_ms_ti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cfg_ms_ti.get_name_leafdata())
                        if (self.flush_count.is_set or self.flush_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flush_count.get_name_leafdata())
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())
                        if (self.msti_flags.is_set or self.msti_flags.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_flags.get_name_leafdata())
                        if (self.msti_state.is_set or self.msti_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_state.get_name_leafdata())
                        if (self.nack_count.is_set or self.nack_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nack_count.get_name_leafdata())
                        if (self.rcv_count.is_set or self.rcv_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rcv_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bd-entry"):
                            for c in self.bd_entry:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bd_entry.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bd-entry" or name == "ack-count" or name == "bd-count" or name == "cfg-ms-ti" or name == "flush-count" or name == "interface-count" or name == "msti-flags" or name == "msti-state" or name == "nack-count" or name == "rcv-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ack-count"):
                            self.ack_count = value
                            self.ack_count.value_namespace = name_space
                            self.ack_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bd-count"):
                            self.bd_count = value
                            self.bd_count.value_namespace = name_space
                            self.bd_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "cfg-ms-ti"):
                            self.cfg_ms_ti = value
                            self.cfg_ms_ti.value_namespace = name_space
                            self.cfg_ms_ti.value_namespace_prefix = name_space_prefix
                        if(value_path == "flush-count"):
                            self.flush_count = value
                            self.flush_count.value_namespace = name_space
                            self.flush_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-flags"):
                            self.msti_flags = value
                            self.msti_flags.value_namespace = name_space
                            self.msti_flags.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-state"):
                            self.msti_state = value
                            self.msti_state.value_namespace = name_space
                            self.msti_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "nack-count"):
                            self.nack_count = value
                            self.nack_count.value_namespace = name_space
                            self.nack_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "rcv-count"):
                            self.rcv_count = value
                            self.rcv_count.value_namespace = name_space
                            self.rcv_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.msti_entry:
                        if (c.has_data()):
                            return True
                    return (
                        self.interface.is_set or
                        self.interface_name.is_set or
                        self.mstp_interface_handle.is_set or
                        self.protected.is_set or
                        self.reference_count.is_set)

                def has_operation(self):
                    for c in self.msti_entry:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.mstp_interface_handle.yfilter != YFilter.not_set or
                        self.protected.yfilter != YFilter.not_set or
                        self.reference_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mstp-port" + "[interface='" + self.interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/mstp-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface.get_name_leafdata())
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.mstp_interface_handle.is_set or self.mstp_interface_handle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mstp_interface_handle.get_name_leafdata())
                    if (self.protected.is_set or self.protected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.protected.get_name_leafdata())
                    if (self.reference_count.is_set or self.reference_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reference_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "msti-entry"):
                        for c in self.msti_entry:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.msti_entry.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "msti-entry" or name == "interface" or name == "interface-name" or name == "mstp-interface-handle" or name == "protected" or name == "reference-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface"):
                        self.interface = value
                        self.interface.value_namespace = name_space
                        self.interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mstp-interface-handle"):
                        self.mstp_interface_handle = value
                        self.mstp_interface_handle.value_namespace = name_space
                        self.mstp_interface_handle.value_namespace_prefix = name_space_prefix
                    if(value_path == "protected"):
                        self.protected = value
                        self.protected.value_namespace = name_space
                        self.protected.value_namespace_prefix = name_space_prefix
                    if(value_path == "reference-count"):
                        self.reference_count = value
                        self.reference_count.value_namespace = name_space
                        self.reference_count.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.mstp_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.mstp_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mstp-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mstp-port"):
                    for c in self.mstp_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.MstpPorts.MstpPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.mstp_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mstp-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class GenericInterfaceListDetails(Entity):
            """
            L2VPN generic interface list Detail Table
            
            .. attribute:: generic_interface_list_detail
            
            	Generic Interface List detail information
            	**type**\: list of    :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.GenericInterfaceListDetails, self).__init__()

                self.yang_name = "generic-interface-list-details"
                self.yang_parent_name = "active"

                self.generic_interface_list_detail = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.GenericInterfaceListDetails, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.GenericInterfaceListDetails, self).__setattr__(name, value)


            class GenericInterfaceListDetail(Entity):
                """
                Generic Interface List detail information
                
                .. attribute:: interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\:  bool
                
                .. attribute:: items
                
                	Number of items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: psedowire_ether_items
                
                	Number PW Ether Items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pseudowire_ether_range
                
                	PW\-Ether ranges
                	**type**\: list of    :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
                
                .. attribute:: pseudowire_iw_items
                
                	Number PW IW Items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pseudowire_iw_range
                
                	PW\-IW ranges
                	**type**\: list of    :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
                
                .. attribute:: summary
                
                	Summary information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__init__()

                    self.yang_name = "generic-interface-list-detail"
                    self.yang_parent_name = "generic-interface-list-details"

                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                    self.is_provisioned = YLeaf(YType.boolean, "is-provisioned")

                    self.items = YLeaf(YType.uint32, "items")

                    self.psedowire_ether_items = YLeaf(YType.uint32, "psedowire-ether-items")

                    self.pseudowire_iw_items = YLeaf(YType.uint32, "pseudowire-iw-items")

                    self.summary = L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.interface = YList(self)
                    self.pseudowire_ether_range = YList(self)
                    self.pseudowire_iw_range = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_list_name",
                                    "is_provisioned",
                                    "items",
                                    "psedowire_ether_items",
                                    "pseudowire_iw_items") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__setattr__(name, value)


                class Summary(Entity):
                    """
                    Summary information
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_list_name_xr
                    
                    	Interface\-list name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_interfaces
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "generic-interface-list-detail"

                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                        self.interface_list_name_xr = YLeaf(YType.str, "interface-list-name-xr")

                        self.items = YLeaf(YType.uint32, "items")

                        self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_list_id",
                                        "interface_list_name_xr",
                                        "items",
                                        "number_of_interfaces") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                            self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                            self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "is_fib_downloaded",
                                            "not_supported_replications",
                                            "pending_replications") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.is_fib_downloaded.is_set or
                                self.not_supported_replications.is_set or
                                self.pending_replications.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_fib_downloaded.yfilter != YFilter.not_set or
                                self.not_supported_replications.yfilter != YFilter.not_set or
                                self.pending_replications.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                            if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                            if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pending_replications.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-fib-downloaded"):
                                self.is_fib_downloaded = value
                                self.is_fib_downloaded.value_namespace = name_space
                                self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-replications"):
                                self.not_supported_replications = value
                                self.not_supported_replications.value_namespace = name_space
                                self.not_supported_replications.value_namespace_prefix = name_space_prefix
                            if(value_path == "pending-replications"):
                                self.pending_replications = value
                                self.pending_replications.value_namespace = name_space
                                self.pending_replications.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_list_id.is_set or
                            self.interface_list_name_xr.is_set or
                            self.items.is_set or
                            self.number_of_interfaces.is_set)

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_list_id.yfilter != YFilter.not_set or
                            self.interface_list_name_xr.yfilter != YFilter.not_set or
                            self.items.yfilter != YFilter.not_set or
                            self.number_of_interfaces.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                        if (self.interface_list_name_xr.is_set or self.interface_list_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_list_name_xr.get_name_leafdata())
                        if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.items.get_name_leafdata())
                        if (self.number_of_interfaces.is_set or self.number_of_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_interfaces.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name-xr" or name == "items" or name == "number-of-interfaces"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-list-id"):
                            self.interface_list_id = value
                            self.interface_list_id.value_namespace = name_space
                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-list-name-xr"):
                            self.interface_list_name_xr = value
                            self.interface_list_name_xr.value_namespace = name_space
                            self.interface_list_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "items"):
                            self.items = value
                            self.items.value_namespace = name_space
                            self.items.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-interfaces"):
                            self.number_of_interfaces = value
                            self.number_of_interfaces.value_namespace = name_space
                            self.number_of_interfaces.value_namespace_prefix = name_space_prefix


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface-list-detail"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                        self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                        self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_fib_downloaded",
                                        "not_supported_replications",
                                        "pending_replications") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.is_fib_downloaded.is_set or
                            self.not_supported_replications.is_set or
                            self.pending_replications.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_fib_downloaded.yfilter != YFilter.not_set or
                            self.not_supported_replications.yfilter != YFilter.not_set or
                            self.pending_replications.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                        if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                        if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pending_replications.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-fib-downloaded"):
                            self.is_fib_downloaded = value
                            self.is_fib_downloaded.value_namespace = name_space
                            self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-replications"):
                            self.not_supported_replications = value
                            self.not_supported_replications.value_namespace = name_space
                            self.not_supported_replications.value_namespace_prefix = name_space_prefix
                        if(value_path == "pending-replications"):
                            self.pending_replications = value
                            self.pending_replications.value_namespace = name_space
                            self.pending_replications.value_namespace_prefix = name_space_prefix


                class PseudowireEtherRange(Entity):
                    """
                    PW\-Ether ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__init__()

                        self.yang_name = "pseudowire-ether-range"
                        self.yang_parent_name = "generic-interface-list-detail"

                        self.lower = YLeaf(YType.uint16, "lower")

                        self.upper = YLeaf(YType.uint16, "upper")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("lower",
                                        "upper") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.lower.is_set or
                            self.upper.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.lower.yfilter != YFilter.not_set or
                            self.upper.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pseudowire-ether-range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lower.get_name_leafdata())
                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.upper.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "lower" or name == "upper"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "lower"):
                            self.lower = value
                            self.lower.value_namespace = name_space
                            self.lower.value_namespace_prefix = name_space_prefix
                        if(value_path == "upper"):
                            self.upper = value
                            self.upper.value_namespace = name_space
                            self.upper.value_namespace_prefix = name_space_prefix


                class PseudowireIwRange(Entity):
                    """
                    PW\-IW ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__init__()

                        self.yang_name = "pseudowire-iw-range"
                        self.yang_parent_name = "generic-interface-list-detail"

                        self.lower = YLeaf(YType.uint16, "lower")

                        self.upper = YLeaf(YType.uint16, "upper")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("lower",
                                        "upper") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.lower.is_set or
                            self.upper.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.lower.yfilter != YFilter.not_set or
                            self.upper.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pseudowire-iw-range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lower.get_name_leafdata())
                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.upper.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "lower" or name == "upper"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "lower"):
                            self.lower = value
                            self.lower.value_namespace = name_space
                            self.lower.value_namespace_prefix = name_space_prefix
                        if(value_path == "upper"):
                            self.upper = value
                            self.upper.value_namespace = name_space
                            self.upper.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    for c in self.pseudowire_ether_range:
                        if (c.has_data()):
                            return True
                    for c in self.pseudowire_iw_range:
                        if (c.has_data()):
                            return True
                    return (
                        self.interface_list_name.is_set or
                        self.is_provisioned.is_set or
                        self.items.is_set or
                        self.psedowire_ether_items.is_set or
                        self.pseudowire_iw_items.is_set or
                        (self.summary is not None and self.summary.has_data()))

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    for c in self.pseudowire_ether_range:
                        if (c.has_operation()):
                            return True
                    for c in self.pseudowire_iw_range:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_list_name.yfilter != YFilter.not_set or
                        self.is_provisioned.yfilter != YFilter.not_set or
                        self.items.yfilter != YFilter.not_set or
                        self.psedowire_ether_items.yfilter != YFilter.not_set or
                        self.pseudowire_iw_items.yfilter != YFilter.not_set or
                        (self.summary is not None and self.summary.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-interface-list-detail" + "[interface-list-name='" + self.interface_list_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/generic-interface-list-details/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                    if (self.is_provisioned.is_set or self.is_provisioned.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_provisioned.get_name_leafdata())
                    if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.items.get_name_leafdata())
                    if (self.psedowire_ether_items.is_set or self.psedowire_ether_items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.psedowire_ether_items.get_name_leafdata())
                    if (self.pseudowire_iw_items.is_set or self.pseudowire_iw_items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pseudowire_iw_items.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    if (child_yang_name == "pseudowire-ether-range"):
                        for c in self.pseudowire_ether_range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.pseudowire_ether_range.append(c)
                        return c

                    if (child_yang_name == "pseudowire-iw-range"):
                        for c in self.pseudowire_iw_range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.pseudowire_iw_range.append(c)
                        return c

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "pseudowire-ether-range" or name == "pseudowire-iw-range" or name == "summary" or name == "interface-list-name" or name == "is-provisioned" or name == "items" or name == "psedowire-ether-items" or name == "pseudowire-iw-items"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-list-name"):
                        self.interface_list_name = value
                        self.interface_list_name.value_namespace = name_space
                        self.interface_list_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-provisioned"):
                        self.is_provisioned = value
                        self.is_provisioned.value_namespace = name_space
                        self.is_provisioned.value_namespace_prefix = name_space_prefix
                    if(value_path == "items"):
                        self.items = value
                        self.items.value_namespace = name_space
                        self.items.value_namespace_prefix = name_space_prefix
                    if(value_path == "psedowire-ether-items"):
                        self.psedowire_ether_items = value
                        self.psedowire_ether_items.value_namespace = name_space
                        self.psedowire_ether_items.value_namespace_prefix = name_space_prefix
                    if(value_path == "pseudowire-iw-items"):
                        self.pseudowire_iw_items = value
                        self.pseudowire_iw_items.value_namespace = name_space
                        self.pseudowire_iw_items.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.generic_interface_list_detail:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.generic_interface_list_detail:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "generic-interface-list-details" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "generic-interface-list-detail"):
                    for c in self.generic_interface_list_detail:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.generic_interface_list_detail.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-interface-list-detail"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class L2VpnResourceState(Entity):
            """
            L2VPN resource state information
            
            .. attribute:: resource_out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.L2VpnResourceState, self).__init__()

                self.yang_name = "l2vpn-resource-state"
                self.yang_parent_name = "active"

                self.resource_out_of_memory_state = YLeaf(YType.uint32, "resource-out-of-memory-state")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("resource_out_of_memory_state") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.L2VpnResourceState, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.L2VpnResourceState, self).__setattr__(name, value)

            def has_data(self):
                return self.resource_out_of_memory_state.is_set

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.resource_out_of_memory_state.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "l2vpn-resource-state" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.resource_out_of_memory_state.is_set or self.resource_out_of_memory_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.resource_out_of_memory_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "resource-out-of-memory-state"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "resource-out-of-memory-state"):
                    self.resource_out_of_memory_state = value
                    self.resource_out_of_memory_state.value_namespace = name_space
                    self.resource_out_of_memory_state.value_namespace_prefix = name_space_prefix


        class BridgeDomains(Entity):
            """
            VPLS Bridge Domain Information
            
            .. attribute:: bridge_domain
            
            	VPLS Bridge Domain Information
            	**type**\: list of    :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.BridgeDomains, self).__init__()

                self.yang_name = "bridge-domains"
                self.yang_parent_name = "active"

                self.bridge_domain = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.BridgeDomains, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.BridgeDomains, self).__setattr__(name, value)


            class BridgeDomain(Entity):
                """
                VPLS Bridge Domain Information
                
                .. attribute:: bridge_access_pws
                
                	VPLS Bridge Domain Access Pseudowire Table
                	**type**\:   :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws>`
                
                .. attribute:: bridge_access_vfi_table
                
                	Bridge Domain Access VFI Table
                	**type**\:   :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
                
                .. attribute:: bridge_acs
                
                	VPLS Bridge Domain Attachment Circuit Table
                	**type**\:   :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs>`
                
                .. attribute:: bridge_core_vfi_table
                
                	Bridge Domain Core VFI Table
                	**type**\:   :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
                
                .. attribute:: bridge_domain_group_name
                
                	Bridge Domain Group Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: bridge_domain_info
                
                	VPLS Bridge Domain Information
                	**type**\:   :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
                
                .. attribute:: bridge_domain_name
                
                	Bridge Domain Name
                	**type**\:  str
                
                	**length:** 1..27
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain, self).__init__()

                    self.yang_name = "bridge-domain"
                    self.yang_parent_name = "bridge-domains"

                    self.bridge_domain_group_name = YLeaf(YType.str, "bridge-domain-group-name")

                    self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                    self.bridge_access_pws = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws()
                    self.bridge_access_pws.parent = self
                    self._children_name_map["bridge_access_pws"] = "bridge-access-pws"
                    self._children_yang_names.add("bridge-access-pws")

                    self.bridge_access_vfi_table = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                    self.bridge_access_vfi_table.parent = self
                    self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"
                    self._children_yang_names.add("bridge-access-vfi-table")

                    self.bridge_acs = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs()
                    self.bridge_acs.parent = self
                    self._children_name_map["bridge_acs"] = "bridge-acs"
                    self._children_yang_names.add("bridge-acs")

                    self.bridge_core_vfi_table = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                    self.bridge_core_vfi_table.parent = self
                    self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"
                    self._children_yang_names.add("bridge-core-vfi-table")

                    self.bridge_domain_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                    self.bridge_domain_info.parent = self
                    self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                    self._children_yang_names.add("bridge-domain-info")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bridge_domain_group_name",
                                    "bridge_domain_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain, self).__setattr__(name, value)


                class BridgeAccessVfiTable(Entity):
                    """
                    Bridge Domain Access VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable, self).__init__()

                        self.yang_name = "bridge-access-vfi-table"
                        self.yang_parent_name = "bridge-domain"

                        self.bridge_pws = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                        self.bridge_pws.parent = self
                        self._children_name_map["bridge_pws"] = "bridge-pws"
                        self._children_yang_names.add("bridge-pws")


                    class BridgePws(Entity):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	VPLS Bridge Domain Pseudowire
                        	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__init__()

                            self.yang_name = "bridge-pws"
                            self.yang_parent_name = "bridge-access-vfi-table"

                            self.bridge_pw = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__setattr__(name, value)


                        class BridgePw(Entity):
                            """
                            VPLS Bridge Domain Pseudowire
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:   :py:class:`L2Vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnpw>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__init__()

                                self.yang_name = "bridge-pw"
                                self.yang_parent_name = "bridge-pws"

                                self.is_access = YLeaf(YType.boolean, "is-access")

                                self.neighbor = YLeaf(YType.str, "neighbor")

                                self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                                self.pw_type = YLeaf(YType.enumeration, "pw-type")

                                self.ve_id_vpls_id_0_3 = YLeaf(YType.uint32, "ve-id-vpls-id-0-3")

                                self.vpls_id_4_7 = YLeaf(YType.uint32, "vpls-id-4-7")

                                self.pseudowire = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"
                                self._children_yang_names.add("pseudowire")

                                self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                                self.static_mac = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_access",
                                                "neighbor",
                                                "pseudowire_id",
                                                "pw_type",
                                                "ve_id_vpls_id_0_3",
                                                "vpls_id_4_7") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)


                            class Pseudowire(Entity):
                                """
                                Pseudowire
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\:  bool
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\:  bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\:  bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\:  bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\:  bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\:  bool
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\:  bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\:  bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\:  bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\:  bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\:  bool
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_evpnvpws_type
                                
                                	is EVPN VPWS
                                	**type**\:  bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\:  bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\:  bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\:  bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\:  bool
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\:  bool
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\:  bool
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\:  bool
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\:  bool
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\:  bool
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\:  bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\:  bool
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\:  bool
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\:  bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\:  bool
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\:  bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\:  bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\:  bool
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\:  str
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                    self.yang_name = "pseudowire"
                                    self.yang_parent_name = "bridge-pw"

                                    self.ad_method = YLeaf(YType.uint32, "ad-method")

                                    self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                    self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                    self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                    self.backup_active = YLeaf(YType.boolean, "backup-active")

                                    self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                    self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                    self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                    self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                    self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                    self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                    self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                    self.disable_never = YLeaf(YType.boolean, "disable-never")

                                    self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                    self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                    self.forward_class = YLeaf(YType.uint8, "forward-class")

                                    self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                    self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                    self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                    self.interworking = YLeaf(YType.enumeration, "interworking")

                                    self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                    self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                    self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                    self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                    self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                    self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                    self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                    self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                    self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                    self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                    self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                    self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                    self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                    self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                    self.local_source_address = YLeaf(YType.str, "local-source-address")

                                    self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                    self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                    self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                    self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                    self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                    self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                    self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                    self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                    self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                    self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                    self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                    self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                    self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                    self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                    self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                    self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                    self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                    self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                    self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                    self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                    self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                    self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                    self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                    self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                    self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                    self.required_bw = YLeaf(YType.uint32, "required-bw")

                                    self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                    self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                    self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                    self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                    self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                    self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                    self.time_created = YLeaf(YType.str, "time-created")

                                    self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                    self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                    self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                    self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.encapsulation_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    self._children_yang_names.add("encapsulation-info")

                                    self.local_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                    self._children_yang_names.add("local-interface")

                                    self.local_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                    self._children_yang_names.add("local-signalling")

                                    self.p2mp_pw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    self._children_yang_names.add("p2mp-pw")

                                    self.peer_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                    self._children_yang_names.add("peer-id")

                                    self.preferred_path = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                    self._children_yang_names.add("preferred-path")

                                    self.remote_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                    self._children_yang_names.add("remote-interface")

                                    self.remote_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                    self._children_yang_names.add("remote-signalling")

                                    self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._children_yang_names.add("statistics")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ad_method",
                                                    "ad_remote_down",
                                                    "admited_bw",
                                                    "auto_discovery",
                                                    "backup_active",
                                                    "backup_force_active",
                                                    "backup_pw",
                                                    "bitrate_mismatched",
                                                    "bridge_pw_type_mismatch",
                                                    "cas_mismatched",
                                                    "diff_ts_mismatched",
                                                    "disable_delay",
                                                    "disable_never",
                                                    "evpn_src_acid",
                                                    "fe_ctype",
                                                    "forward_class",
                                                    "freq_mismatched",
                                                    "illegal_control_word",
                                                    "imposed_vlan_id",
                                                    "interworking",
                                                    "ipv6_local_source_address",
                                                    "is_evpnvpws_type",
                                                    "is_flow_label_static",
                                                    "is_multi_segment_pseudowire",
                                                    "is_partially_programmed",
                                                    "is_pwr_type",
                                                    "is_vfi",
                                                    "last_time_status_changed",
                                                    "last_time_status_down",
                                                    "ldp_label_advertise_failed",
                                                    "load_balance",
                                                    "local_control_word",
                                                    "local_label_failed",
                                                    "local_pseudo_wire_type",
                                                    "local_source_address",
                                                    "mac_limit_oper_down",
                                                    "mtu_mismatched",
                                                    "not_supported_qinq",
                                                    "num_ma_cwithdraw_msg_received",
                                                    "number_ma_cwithdraw_message_sent",
                                                    "out_of_memory_state",
                                                    "payload_bytes_mismatched",
                                                    "payload_type_mismatched",
                                                    "preferred_path_disable_fallback",
                                                    "primary_peer_id",
                                                    "primary_pseudo_wire_id",
                                                    "primary_pw",
                                                    "protocol",
                                                    "pseudo_wire_id",
                                                    "pseudo_wire_state",
                                                    "pseudo_wire_type_mismatched",
                                                    "pw_class_name",
                                                    "pw_flow_label_code17_disabled",
                                                    "pw_flow_label_type",
                                                    "pw_flow_label_type_cfg",
                                                    "pw_redundancy_initial_delay",
                                                    "pw_redundancy_one_way",
                                                    "pw_status_use",
                                                    "pwlsd_rewrite_failed",
                                                    "remote_control_word",
                                                    "remote_label_failed",
                                                    "remote_pseudo_wire_type",
                                                    "required_bw",
                                                    "resync_enabled",
                                                    "resync_threshold",
                                                    "rtp_mismatched",
                                                    "sequencing_type",
                                                    "shutdown",
                                                    "sig_pkts_mismatched",
                                                    "ssrc_mismatched",
                                                    "state",
                                                    "table_policy_name",
                                                    "tag_rewrite",
                                                    "time_created",
                                                    "time_elapsed_creation",
                                                    "time_elapsed_status_changed",
                                                    "time_elapsed_status_down",
                                                    "transport_lsp_down",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)


                                class PeerId(Entity):
                                    """
                                    Peer
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                        self.yang_name = "peer-id"
                                        self.yang_parent_name = "pseudowire"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                        self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                        self.type = YLeaf(YType.enumeration, "type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "ipv4_peer_id",
                                                        "ipv6_peer_id",
                                                        "type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.ipv4_peer_id.is_set or
                                            self.ipv6_peer_id.is_set or
                                            self.type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.ipv4_peer_id.yfilter != YFilter.not_set or
                                            self.ipv6_peer_id.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "peer-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                        if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-peer-id"):
                                            self.ipv4_peer_id = value
                                            self.ipv4_peer_id.value_namespace = name_space
                                            self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-peer-id"):
                                            self.ipv6_peer_id = value
                                            self.ipv6_peer_id.value_namespace = name_space
                                            self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix


                                class EncapsulationInfo(Entity):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                        self.yang_name = "encapsulation-info"
                                        self.yang_parent_name = "pseudowire"

                                        self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                        self.atom = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                        self._children_yang_names.add("atom")

                                        self.l2tpv3 = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                        self._children_yang_names.add("l2tpv3")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                    class Atom(Entity):
                                        """
                                        atom
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                            self.yang_name = "atom"
                                            self.yang_parent_name = "encapsulation-info"

                                            self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                            self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                            self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                            self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                            self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                            self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                            self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                            self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                            self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                            self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                            self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                            self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                            self.local_veid = YLeaf(YType.uint32, "local-veid")

                                            self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                            self.rem_saii = YLeaf(YType.str, "rem-saii")

                                            self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                            self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                            self.rem_taii = YLeaf(YType.str, "rem-taii")

                                            self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                            self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                            self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                            self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                            self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                            self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                                            self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                            self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                            self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                            self.saii = YLeaf(YType.str, "saii")

                                            self.source_address = YLeaf(YType.str, "source-address")

                                            self.taii = YLeaf(YType.str, "taii")

                                            self.local_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                            self._children_yang_names.add("local-agi")

                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            self._children_yang_names.add("multi-segment-pseudowire-stats")

                                            self.remote_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                            self._children_yang_names.add("remote-agi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("is_pseudowire_headend",
                                                            "is_sai_itype2",
                                                            "is_tai_itype2",
                                                            "ldp_label_advertisment_failed",
                                                            "local_c_ctype",
                                                            "local_ceid",
                                                            "local_cv_type",
                                                            "local_group_id",
                                                            "local_label",
                                                            "local_ldp_id",
                                                            "local_saii_gbl_id",
                                                            "local_saiiac_id",
                                                            "local_taii_gbl_id",
                                                            "local_taiiac_id",
                                                            "local_veid",
                                                            "lsd_rewrite_failed",
                                                            "rem_saii",
                                                            "rem_saii_gbl_id",
                                                            "rem_saiiac_id",
                                                            "rem_taii",
                                                            "rem_taii_gbl_id",
                                                            "rem_taiiac_id",
                                                            "remote_c_ctype",
                                                            "remote_ceid",
                                                            "remote_cv_type",
                                                            "remote_group_id",
                                                            "remote_label",
                                                            "remote_ldp_id",
                                                            "remote_source_address",
                                                            "remote_veid",
                                                            "saii",
                                                            "source_address",
                                                            "taii") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                        class LocalAgi(Entity):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                self.yang_name = "local-agi"
                                                self.yang_parent_name = "atom"

                                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                                self._children_yang_names.add("auto")

                                                self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                                self._children_yang_names.add("two-byte-as")

                                                self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._children_yang_names.add("v4-addr")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vpls_id_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "local-agi"

                                                    self.asn = YLeaf(YType.uint16, "asn")

                                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("asn",
                                                                    "vpn_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.asn.is_set or
                                                        self.vpn_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.asn.yfilter != YFilter.not_set or
                                                        self.vpn_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "auto" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "asn" or name == "vpn-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "asn"):
                                                        self.asn = value
                                                        self.asn.value_namespace = name_space
                                                        self.asn.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpn-id"):
                                                        self.vpn_id = value
                                                        self.vpn_id.value_namespace = name_space
                                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "local-agi"

                                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("four_byte_index",
                                                                    "two_byte_as") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.four_byte_index.is_set or
                                                        self.two_byte_as.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.four_byte_index.yfilter != YFilter.not_set or
                                                        self.two_byte_as.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "two-byte-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "four-byte-index"):
                                                        self.four_byte_index = value
                                                        self.four_byte_index.value_namespace = name_space
                                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-as"):
                                                        self.two_byte_as = value
                                                        self.two_byte_as.value_namespace = name_space
                                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "local-agi"

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ipv4_address",
                                                                    "two_byte_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ipv4_address.is_set or
                                                        self.two_byte_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ipv4_address.yfilter != YFilter.not_set or
                                                        self.two_byte_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "v4-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ipv4-address"):
                                                        self.ipv4_address = value
                                                        self.ipv4_address.value_namespace = name_space
                                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-index"):
                                                        self.two_byte_index = value
                                                        self.two_byte_index.value_namespace = name_space
                                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.vpls_id_type.is_set or
                                                    (self.auto is not None and self.auto.has_data()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                                    (self.auto is not None and self.auto.has_operation()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "local-agi" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "auto"):
                                                    if (self.auto is None):
                                                        self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                        self.auto.parent = self
                                                        self._children_name_map["auto"] = "auto"
                                                    return self.auto

                                                if (child_yang_name == "two-byte-as"):
                                                    if (self.two_byte_as is None):
                                                        self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                        self.two_byte_as.parent = self
                                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    return self.two_byte_as

                                                if (child_yang_name == "v4-addr"):
                                                    if (self.v4_addr is None):
                                                        self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                        self.v4_addr.parent = self
                                                        self._children_name_map["v4_addr"] = "v4-addr"
                                                    return self.v4_addr

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vpls-id-type"):
                                                    self.vpls_id_type = value
                                                    self.vpls_id_type.value_namespace = name_space
                                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                        class RemoteAgi(Entity):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                self.yang_name = "remote-agi"
                                                self.yang_parent_name = "atom"

                                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                                self._children_yang_names.add("auto")

                                                self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                                self._children_yang_names.add("two-byte-as")

                                                self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._children_yang_names.add("v4-addr")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vpls_id_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.asn = YLeaf(YType.uint16, "asn")

                                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("asn",
                                                                    "vpn_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.asn.is_set or
                                                        self.vpn_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.asn.yfilter != YFilter.not_set or
                                                        self.vpn_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "auto" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "asn" or name == "vpn-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "asn"):
                                                        self.asn = value
                                                        self.asn.value_namespace = name_space
                                                        self.asn.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpn-id"):
                                                        self.vpn_id = value
                                                        self.vpn_id.value_namespace = name_space
                                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("four_byte_index",
                                                                    "two_byte_as") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.four_byte_index.is_set or
                                                        self.two_byte_as.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.four_byte_index.yfilter != YFilter.not_set or
                                                        self.two_byte_as.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "two-byte-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "four-byte-index"):
                                                        self.four_byte_index = value
                                                        self.four_byte_index.value_namespace = name_space
                                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-as"):
                                                        self.two_byte_as = value
                                                        self.two_byte_as.value_namespace = name_space
                                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ipv4_address",
                                                                    "two_byte_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ipv4_address.is_set or
                                                        self.two_byte_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ipv4_address.yfilter != YFilter.not_set or
                                                        self.two_byte_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "v4-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ipv4-address"):
                                                        self.ipv4_address = value
                                                        self.ipv4_address.value_namespace = name_space
                                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-index"):
                                                        self.two_byte_index = value
                                                        self.two_byte_index.value_namespace = name_space
                                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.vpls_id_type.is_set or
                                                    (self.auto is not None and self.auto.has_data()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                                    (self.auto is not None and self.auto.has_operation()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-agi" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "auto"):
                                                    if (self.auto is None):
                                                        self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                        self.auto.parent = self
                                                        self._children_name_map["auto"] = "auto"
                                                    return self.auto

                                                if (child_yang_name == "two-byte-as"):
                                                    if (self.two_byte_as is None):
                                                        self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                        self.two_byte_as.parent = self
                                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    return self.two_byte_as

                                                if (child_yang_name == "v4-addr"):
                                                    if (self.v4_addr is None):
                                                        self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                        self.v4_addr.parent = self
                                                        self._children_name_map["v4_addr"] = "v4-addr"
                                                    return self.v4_addr

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vpls-id-type"):
                                                    self.vpls_id_type = value
                                                    self.vpls_id_type.value_namespace = name_space
                                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                        class MultiSegmentPseudowireStats(Entity):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                self.yang_name = "multi-segment-pseudowire-stats"
                                                self.yang_parent_name = "atom"

                                                self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                                self.received_packets = YLeaf(YType.uint64, "received-packets")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("received_bytes",
                                                                "received_packets") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.received_bytes.is_set or
                                                    self.received_packets.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.received_bytes.yfilter != YFilter.not_set or
                                                    self.received_packets.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                                if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.received_packets.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "received-bytes" or name == "received-packets"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "received-bytes"):
                                                    self.received_bytes = value
                                                    self.received_bytes.value_namespace = name_space
                                                    self.received_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "received-packets"):
                                                    self.received_packets = value
                                                    self.received_packets.value_namespace = name_space
                                                    self.received_packets.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.is_pseudowire_headend.is_set or
                                                self.is_sai_itype2.is_set or
                                                self.is_tai_itype2.is_set or
                                                self.ldp_label_advertisment_failed.is_set or
                                                self.local_c_ctype.is_set or
                                                self.local_ceid.is_set or
                                                self.local_cv_type.is_set or
                                                self.local_group_id.is_set or
                                                self.local_label.is_set or
                                                self.local_ldp_id.is_set or
                                                self.local_saii_gbl_id.is_set or
                                                self.local_saiiac_id.is_set or
                                                self.local_taii_gbl_id.is_set or
                                                self.local_taiiac_id.is_set or
                                                self.local_veid.is_set or
                                                self.lsd_rewrite_failed.is_set or
                                                self.rem_saii.is_set or
                                                self.rem_saii_gbl_id.is_set or
                                                self.rem_saiiac_id.is_set or
                                                self.rem_taii.is_set or
                                                self.rem_taii_gbl_id.is_set or
                                                self.rem_taiiac_id.is_set or
                                                self.remote_c_ctype.is_set or
                                                self.remote_ceid.is_set or
                                                self.remote_cv_type.is_set or
                                                self.remote_group_id.is_set or
                                                self.remote_label.is_set or
                                                self.remote_ldp_id.is_set or
                                                self.remote_source_address.is_set or
                                                self.remote_veid.is_set or
                                                self.saii.is_set or
                                                self.source_address.is_set or
                                                self.taii.is_set or
                                                (self.local_agi is not None and self.local_agi.has_data()) or
                                                (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                                (self.remote_agi is not None and self.remote_agi.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                                self.is_sai_itype2.yfilter != YFilter.not_set or
                                                self.is_tai_itype2.yfilter != YFilter.not_set or
                                                self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                                self.local_c_ctype.yfilter != YFilter.not_set or
                                                self.local_ceid.yfilter != YFilter.not_set or
                                                self.local_cv_type.yfilter != YFilter.not_set or
                                                self.local_group_id.yfilter != YFilter.not_set or
                                                self.local_label.yfilter != YFilter.not_set or
                                                self.local_ldp_id.yfilter != YFilter.not_set or
                                                self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                                self.local_saiiac_id.yfilter != YFilter.not_set or
                                                self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                                self.local_taiiac_id.yfilter != YFilter.not_set or
                                                self.local_veid.yfilter != YFilter.not_set or
                                                self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                                self.rem_saii.yfilter != YFilter.not_set or
                                                self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                                self.rem_saiiac_id.yfilter != YFilter.not_set or
                                                self.rem_taii.yfilter != YFilter.not_set or
                                                self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                                self.rem_taiiac_id.yfilter != YFilter.not_set or
                                                self.remote_c_ctype.yfilter != YFilter.not_set or
                                                self.remote_ceid.yfilter != YFilter.not_set or
                                                self.remote_cv_type.yfilter != YFilter.not_set or
                                                self.remote_group_id.yfilter != YFilter.not_set or
                                                self.remote_label.yfilter != YFilter.not_set or
                                                self.remote_ldp_id.yfilter != YFilter.not_set or
                                                self.remote_source_address.yfilter != YFilter.not_set or
                                                self.remote_veid.yfilter != YFilter.not_set or
                                                self.saii.yfilter != YFilter.not_set or
                                                self.source_address.yfilter != YFilter.not_set or
                                                self.taii.yfilter != YFilter.not_set or
                                                (self.local_agi is not None and self.local_agi.has_operation()) or
                                                (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                                (self.remote_agi is not None and self.remote_agi.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atom" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                            if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                            if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                            if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                            if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                            if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                            if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                            if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_label.get_name_leafdata())
                                            if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                            if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                            if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                            if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                            if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                            if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_veid.get_name_leafdata())
                                            if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                            if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                            if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                            if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                            if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                            if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                            if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                            if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                            if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                            if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                            if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                                            if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                            if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                            if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                            if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.saii.get_name_leafdata())
                                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.source_address.get_name_leafdata())
                                            if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.taii.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "local-agi"):
                                                if (self.local_agi is None):
                                                    self.local_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                    self.local_agi.parent = self
                                                    self._children_name_map["local_agi"] = "local-agi"
                                                return self.local_agi

                                            if (child_yang_name == "multi-segment-pseudowire-stats"):
                                                if (self.multi_segment_pseudowire_stats is None):
                                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                    self.multi_segment_pseudowire_stats.parent = self
                                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                return self.multi_segment_pseudowire_stats

                                            if (child_yang_name == "remote-agi"):
                                                if (self.remote_agi is None):
                                                    self.remote_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                    self.remote_agi.parent = self
                                                    self._children_name_map["remote_agi"] = "remote-agi"
                                                return self.remote_agi

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "is-pseudowire-headend"):
                                                self.is_pseudowire_headend = value
                                                self.is_pseudowire_headend.value_namespace = name_space
                                                self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-sai-itype2"):
                                                self.is_sai_itype2 = value
                                                self.is_sai_itype2.value_namespace = name_space
                                                self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-tai-itype2"):
                                                self.is_tai_itype2 = value
                                                self.is_tai_itype2.value_namespace = name_space
                                                self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ldp-label-advertisment-failed"):
                                                self.ldp_label_advertisment_failed = value
                                                self.ldp_label_advertisment_failed.value_namespace = name_space
                                                self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-c-ctype"):
                                                self.local_c_ctype = value
                                                self.local_c_ctype.value_namespace = name_space
                                                self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ceid"):
                                                self.local_ceid = value
                                                self.local_ceid.value_namespace = name_space
                                                self.local_ceid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cv-type"):
                                                self.local_cv_type = value
                                                self.local_cv_type.value_namespace = name_space
                                                self.local_cv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-group-id"):
                                                self.local_group_id = value
                                                self.local_group_id.value_namespace = name_space
                                                self.local_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-label"):
                                                self.local_label = value
                                                self.local_label.value_namespace = name_space
                                                self.local_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ldp-id"):
                                                self.local_ldp_id = value
                                                self.local_ldp_id.value_namespace = name_space
                                                self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-saii-gbl-id"):
                                                self.local_saii_gbl_id = value
                                                self.local_saii_gbl_id.value_namespace = name_space
                                                self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-saiiac-id"):
                                                self.local_saiiac_id = value
                                                self.local_saiiac_id.value_namespace = name_space
                                                self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-taii-gbl-id"):
                                                self.local_taii_gbl_id = value
                                                self.local_taii_gbl_id.value_namespace = name_space
                                                self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-taiiac-id"):
                                                self.local_taiiac_id = value
                                                self.local_taiiac_id.value_namespace = name_space
                                                self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-veid"):
                                                self.local_veid = value
                                                self.local_veid.value_namespace = name_space
                                                self.local_veid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsd-rewrite-failed"):
                                                self.lsd_rewrite_failed = value
                                                self.lsd_rewrite_failed.value_namespace = name_space
                                                self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saii"):
                                                self.rem_saii = value
                                                self.rem_saii.value_namespace = name_space
                                                self.rem_saii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saii-gbl-id"):
                                                self.rem_saii_gbl_id = value
                                                self.rem_saii_gbl_id.value_namespace = name_space
                                                self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saiiac-id"):
                                                self.rem_saiiac_id = value
                                                self.rem_saiiac_id.value_namespace = name_space
                                                self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taii"):
                                                self.rem_taii = value
                                                self.rem_taii.value_namespace = name_space
                                                self.rem_taii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taii-gbl-id"):
                                                self.rem_taii_gbl_id = value
                                                self.rem_taii_gbl_id.value_namespace = name_space
                                                self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taiiac-id"):
                                                self.rem_taiiac_id = value
                                                self.rem_taiiac_id.value_namespace = name_space
                                                self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-c-ctype"):
                                                self.remote_c_ctype = value
                                                self.remote_c_ctype.value_namespace = name_space
                                                self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ceid"):
                                                self.remote_ceid = value
                                                self.remote_ceid.value_namespace = name_space
                                                self.remote_ceid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cv-type"):
                                                self.remote_cv_type = value
                                                self.remote_cv_type.value_namespace = name_space
                                                self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-group-id"):
                                                self.remote_group_id = value
                                                self.remote_group_id.value_namespace = name_space
                                                self.remote_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-label"):
                                                self.remote_label = value
                                                self.remote_label.value_namespace = name_space
                                                self.remote_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ldp-id"):
                                                self.remote_ldp_id = value
                                                self.remote_ldp_id.value_namespace = name_space
                                                self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-source-address"):
                                                self.remote_source_address = value
                                                self.remote_source_address.value_namespace = name_space
                                                self.remote_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-veid"):
                                                self.remote_veid = value
                                                self.remote_veid.value_namespace = name_space
                                                self.remote_veid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "saii"):
                                                self.saii = value
                                                self.saii.value_namespace = name_space
                                                self.saii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "source-address"):
                                                self.source_address = value
                                                self.source_address.value_namespace = name_space
                                                self.source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "taii"):
                                                self.taii = value
                                                self.taii.value_namespace = name_space
                                                self.taii.value_namespace_prefix = name_space_prefix


                                    class L2Tpv3(Entity):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\:  bool
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\:  str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                            self.yang_name = "l2tpv3"
                                            self.yang_parent_name = "encapsulation-info"

                                            self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                            self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                            self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                            self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                            self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                            self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                            self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                            self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                            self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                            self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                            self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                            self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                            self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                            self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                            self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                            self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                            self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                            self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                            self.tos = YLeaf(YType.uint8, "tos")

                                            self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                            self.ttl = YLeaf(YType.uint8, "ttl")

                                            self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dont_fragment_bit",
                                                            "ipv4_source_address",
                                                            "ipv6_source_address",
                                                            "l2tp_class_name",
                                                            "local_cookie_high_value",
                                                            "local_cookie_low_value",
                                                            "local_cookie_size",
                                                            "local_secondary_cookie_high_value",
                                                            "local_secondary_cookie_low_value",
                                                            "local_secondary_cookie_size",
                                                            "local_session_id",
                                                            "path_mtu_enabled",
                                                            "path_mtu_max_value",
                                                            "remote_circuit_status_up",
                                                            "remote_cookie_high_value",
                                                            "remote_cookie_low_value",
                                                            "remote_cookie_size",
                                                            "remote_session_id",
                                                            "tos",
                                                            "tos_mode",
                                                            "ttl",
                                                            "tunnel_state") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dont_fragment_bit.is_set or
                                                self.ipv4_source_address.is_set or
                                                self.ipv6_source_address.is_set or
                                                self.l2tp_class_name.is_set or
                                                self.local_cookie_high_value.is_set or
                                                self.local_cookie_low_value.is_set or
                                                self.local_cookie_size.is_set or
                                                self.local_secondary_cookie_high_value.is_set or
                                                self.local_secondary_cookie_low_value.is_set or
                                                self.local_secondary_cookie_size.is_set or
                                                self.local_session_id.is_set or
                                                self.path_mtu_enabled.is_set or
                                                self.path_mtu_max_value.is_set or
                                                self.remote_circuit_status_up.is_set or
                                                self.remote_cookie_high_value.is_set or
                                                self.remote_cookie_low_value.is_set or
                                                self.remote_cookie_size.is_set or
                                                self.remote_session_id.is_set or
                                                self.tos.is_set or
                                                self.tos_mode.is_set or
                                                self.ttl.is_set or
                                                self.tunnel_state.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dont_fragment_bit.yfilter != YFilter.not_set or
                                                self.ipv4_source_address.yfilter != YFilter.not_set or
                                                self.ipv6_source_address.yfilter != YFilter.not_set or
                                                self.l2tp_class_name.yfilter != YFilter.not_set or
                                                self.local_cookie_high_value.yfilter != YFilter.not_set or
                                                self.local_cookie_low_value.yfilter != YFilter.not_set or
                                                self.local_cookie_size.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.local_session_id.yfilter != YFilter.not_set or
                                                self.path_mtu_enabled.yfilter != YFilter.not_set or
                                                self.path_mtu_max_value.yfilter != YFilter.not_set or
                                                self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                                self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                                self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                                self.remote_cookie_size.yfilter != YFilter.not_set or
                                                self.remote_session_id.yfilter != YFilter.not_set or
                                                self.tos.yfilter != YFilter.not_set or
                                                self.tos_mode.yfilter != YFilter.not_set or
                                                self.ttl.yfilter != YFilter.not_set or
                                                self.tunnel_state.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2tpv3" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                            if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                            if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                            if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                            if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                            if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                            if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                            if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                            if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                            if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                            if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                            if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                            if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                            if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                            if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                            if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                            if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                            if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                            if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos.get_name_leafdata())
                                            if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                            if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ttl.get_name_leafdata())
                                            if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dont-fragment-bit"):
                                                self.dont_fragment_bit = value
                                                self.dont_fragment_bit.value_namespace = name_space
                                                self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-source-address"):
                                                self.ipv4_source_address = value
                                                self.ipv4_source_address.value_namespace = name_space
                                                self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-source-address"):
                                                self.ipv6_source_address = value
                                                self.ipv6_source_address.value_namespace = name_space
                                                self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "l2tp-class-name"):
                                                self.l2tp_class_name = value
                                                self.l2tp_class_name.value_namespace = name_space
                                                self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-high-value"):
                                                self.local_cookie_high_value = value
                                                self.local_cookie_high_value.value_namespace = name_space
                                                self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-low-value"):
                                                self.local_cookie_low_value = value
                                                self.local_cookie_low_value.value_namespace = name_space
                                                self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-size"):
                                                self.local_cookie_size = value
                                                self.local_cookie_size.value_namespace = name_space
                                                self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-high-value"):
                                                self.local_secondary_cookie_high_value = value
                                                self.local_secondary_cookie_high_value.value_namespace = name_space
                                                self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-low-value"):
                                                self.local_secondary_cookie_low_value = value
                                                self.local_secondary_cookie_low_value.value_namespace = name_space
                                                self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-size"):
                                                self.local_secondary_cookie_size = value
                                                self.local_secondary_cookie_size.value_namespace = name_space
                                                self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-session-id"):
                                                self.local_session_id = value
                                                self.local_session_id.value_namespace = name_space
                                                self.local_session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "path-mtu-enabled"):
                                                self.path_mtu_enabled = value
                                                self.path_mtu_enabled.value_namespace = name_space
                                                self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "path-mtu-max-value"):
                                                self.path_mtu_max_value = value
                                                self.path_mtu_max_value.value_namespace = name_space
                                                self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-circuit-status-up"):
                                                self.remote_circuit_status_up = value
                                                self.remote_circuit_status_up.value_namespace = name_space
                                                self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-high-value"):
                                                self.remote_cookie_high_value = value
                                                self.remote_cookie_high_value.value_namespace = name_space
                                                self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-low-value"):
                                                self.remote_cookie_low_value = value
                                                self.remote_cookie_low_value.value_namespace = name_space
                                                self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-size"):
                                                self.remote_cookie_size = value
                                                self.remote_cookie_size.value_namespace = name_space
                                                self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-session-id"):
                                                self.remote_session_id = value
                                                self.remote_session_id.value_namespace = name_space
                                                self.remote_session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos"):
                                                self.tos = value
                                                self.tos.value_namespace = name_space
                                                self.tos.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos-mode"):
                                                self.tos_mode = value
                                                self.tos_mode.value_namespace = name_space
                                                self.tos_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ttl"):
                                                self.ttl = value
                                                self.ttl.value_namespace = name_space
                                                self.ttl.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-state"):
                                                self.tunnel_state = value
                                                self.tunnel_state.value_namespace = name_space
                                                self.tunnel_state.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.encapsulation.is_set or
                                            (self.atom is not None and self.atom.has_data()) or
                                            (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation.yfilter != YFilter.not_set or
                                            (self.atom is not None and self.atom.has_operation()) or
                                            (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "encapsulation-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atom"):
                                            if (self.atom is None):
                                                self.atom = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                                self.atom.parent = self
                                                self._children_name_map["atom"] = "atom"
                                            return self.atom

                                        if (child_yang_name == "l2tpv3"):
                                            if (self.l2tpv3 is None):
                                                self.l2tpv3 = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                                self.l2tpv3.parent = self
                                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                            return self.l2tpv3

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation"):
                                            self.encapsulation = value
                                            self.encapsulation.value_namespace = name_space
                                            self.encapsulation.value_namespace_prefix = name_space_prefix


                                class LocalInterface(Entity):
                                    """
                                    Local interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                        self.yang_name = "local-interface"
                                        self.yang_parent_name = "pseudowire"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "local-interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class RemoteInterface(Entity):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                        self.yang_name = "remote-interface"
                                        self.yang_parent_name = "pseudowire"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "remote-interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class PreferredPath(Entity):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                        self.yang_name = "preferred-path"
                                        self.yang_parent_name = "pseudowire"

                                        self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                        self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                        self.option = YLeaf(YType.enumeration, "option")

                                        self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                        self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ip_tunnel_interface_number",
                                                        "next_hop_ip",
                                                        "option",
                                                        "te_tunnel_interface_number",
                                                        "tp_tunnel_interface_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ip_tunnel_interface_number.is_set or
                                            self.next_hop_ip.is_set or
                                            self.option.is_set or
                                            self.te_tunnel_interface_number.is_set or
                                            self.tp_tunnel_interface_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                            self.next_hop_ip.yfilter != YFilter.not_set or
                                            self.option.yfilter != YFilter.not_set or
                                            self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                            self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "preferred-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                        if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.option.get_name_leafdata())
                                        if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                        if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ip-tunnel-interface-number"):
                                            self.ip_tunnel_interface_number = value
                                            self.ip_tunnel_interface_number.value_namespace = name_space
                                            self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop-ip"):
                                            self.next_hop_ip = value
                                            self.next_hop_ip.value_namespace = name_space
                                            self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                        if(value_path == "option"):
                                            self.option = value
                                            self.option.value_namespace = name_space
                                            self.option.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-tunnel-interface-number"):
                                            self.te_tunnel_interface_number = value
                                            self.te_tunnel_interface_number.value_namespace = name_space
                                            self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tp-tunnel-interface-number"):
                                            self.tp_tunnel_interface_number = value
                                            self.tp_tunnel_interface_number.value_namespace = name_space
                                            self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                                class LocalSignalling(Entity):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                        self.yang_name = "local-signalling"
                                        self.yang_parent_name = "pseudowire"

                                        self.pw_status = YLeaf(YType.uint32, "pw-status")

                                        self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                        self._children_yang_names.add("status-tlv")

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "local-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "status-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "local-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.pw_status.is_set or
                                            (self.status_tlv is not None and self.status_tlv.has_data()))

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_status.yfilter != YFilter.not_set or
                                            (self.status_tlv is not None and self.status_tlv.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-signalling" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "status-tlv"):
                                            if (self.status_tlv is None):
                                                self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                                self.status_tlv.parent = self
                                                self._children_name_map["status_tlv"] = "status-tlv"
                                            return self.status_tlv

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-status"):
                                            self.pw_status = value
                                            self.pw_status.value_namespace = name_space
                                            self.pw_status.value_namespace_prefix = name_space_prefix


                                class RemoteSignalling(Entity):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                        self.yang_name = "remote-signalling"
                                        self.yang_parent_name = "pseudowire"

                                        self.pw_status = YLeaf(YType.uint32, "pw-status")

                                        self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                        self._children_yang_names.add("status-tlv")

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "remote-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "status-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "remote-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.pw_status.is_set or
                                            (self.status_tlv is not None and self.status_tlv.has_data()))

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_status.yfilter != YFilter.not_set or
                                            (self.status_tlv is not None and self.status_tlv.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-signalling" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "status-tlv"):
                                            if (self.status_tlv is None):
                                                self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                                self.status_tlv.parent = self
                                                self._children_name_map["status_tlv"] = "status-tlv"
                                            return self.status_tlv

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-status"):
                                            self.pw_status = value
                                            self.pw_status.value_namespace = name_space
                                            self.pw_status.value_namespace_prefix = name_space_prefix


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "pseudowire"

                                        self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        self._children_yang_names.add("dispostion-stats")

                                        self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                        self._children_yang_names.add("impostion-stats")

                                        self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._children_yang_names.add("sequence-number")


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                            self._children_yang_names.add("broadcast")

                                            self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            self._children_yang_names.add("imposition-mtu-drop")

                                            self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                            self._children_yang_names.add("imposition-stat")

                                            self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            self._children_yang_names.add("impostion-tail-drop")

                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            self._children_yang_names.add("l2fsbi-drop")

                                            self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                            self._children_yang_names.add("multicast")

                                            self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._children_yang_names.add("unknown-unicast")


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class L2FsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2fsbi-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast is not None and self.broadcast.has_data()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                (self.multicast is not None and self.multicast.has_data()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast is not None and self.broadcast.has_operation()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                (self.multicast is not None and self.multicast.has_operation()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast"):
                                                if (self.broadcast is None):
                                                    self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                    self.broadcast.parent = self
                                                    self._children_name_map["broadcast"] = "broadcast"
                                                return self.broadcast

                                            if (child_yang_name == "imposition-mtu-drop"):
                                                if (self.imposition_mtu_drop is None):
                                                    self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                    self.imposition_mtu_drop.parent = self
                                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                return self.imposition_mtu_drop

                                            if (child_yang_name == "imposition-stat"):
                                                if (self.imposition_stat is None):
                                                    self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                    self.imposition_stat.parent = self
                                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                                return self.imposition_stat

                                            if (child_yang_name == "impostion-tail-drop"):
                                                if (self.impostion_tail_drop is None):
                                                    self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                    self.impostion_tail_drop.parent = self
                                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                return self.impostion_tail_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "l2fsbi-drop"):
                                                if (self.l2fsbi_drop is None):
                                                    self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                    self.l2fsbi_drop.parent = self
                                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                return self.l2fsbi_drop

                                            if (child_yang_name == "multicast"):
                                                if (self.multicast is None):
                                                    self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                    self.multicast.parent = self
                                                    self._children_name_map["multicast"] = "multicast"
                                                return self.multicast

                                            if (child_yang_name == "unknown-unicast"):
                                                if (self.unknown_unicast is None):
                                                    self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                    self.unknown_unicast.parent = self
                                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                return self.unknown_unicast

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            self._children_yang_names.add("broadcast-drop")

                                            self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                            self._children_yang_names.add("dai-drop")

                                            self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            self._children_yang_names.add("disposition-mtu-drop")

                                            self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            self._children_yang_names.add("disposition-oo-o-drops")

                                            self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            self._children_yang_names.add("disposition-p2mp-stats")

                                            self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                            self._children_yang_names.add("disposition-stat")

                                            self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            self._children_yang_names.add("disposition-tail-drop")

                                            self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            self._children_yang_names.add("ipsg-drop")

                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._children_yang_names.add("mac-move")

                                            self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                            self._children_yang_names.add("multicast-drop")

                                            self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                            self._children_yang_names.add("received-drops")

                                            self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                            self._children_yang_names.add("unicast-drop")


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "received-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dai-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipsg-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-oo-o-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionP2MpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-p2mp-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mac-move" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.mac_move is not None and self.mac_move.has_data()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                (self.received_drops is not None and self.received_drops.has_data()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.mac_move is not None and self.mac_move.has_operation()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                (self.received_drops is not None and self.received_drops.has_operation()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dispostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast-drop"):
                                                if (self.broadcast_drop is None):
                                                    self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                    self.broadcast_drop.parent = self
                                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                return self.broadcast_drop

                                            if (child_yang_name == "dai-drop"):
                                                if (self.dai_drop is None):
                                                    self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                    self.dai_drop.parent = self
                                                    self._children_name_map["dai_drop"] = "dai-drop"
                                                return self.dai_drop

                                            if (child_yang_name == "disposition-mtu-drop"):
                                                if (self.disposition_mtu_drop is None):
                                                    self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                    self.disposition_mtu_drop.parent = self
                                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                return self.disposition_mtu_drop

                                            if (child_yang_name == "disposition-oo-o-drops"):
                                                if (self.disposition_oo_o_drops is None):
                                                    self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                    self.disposition_oo_o_drops.parent = self
                                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                return self.disposition_oo_o_drops

                                            if (child_yang_name == "disposition-p2mp-stats"):
                                                if (self.disposition_p2mp_stats is None):
                                                    self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                    self.disposition_p2mp_stats.parent = self
                                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                return self.disposition_p2mp_stats

                                            if (child_yang_name == "disposition-stat"):
                                                if (self.disposition_stat is None):
                                                    self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                    self.disposition_stat.parent = self
                                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                                return self.disposition_stat

                                            if (child_yang_name == "disposition-tail-drop"):
                                                if (self.disposition_tail_drop is None):
                                                    self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                    self.disposition_tail_drop.parent = self
                                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                return self.disposition_tail_drop

                                            if (child_yang_name == "ipsg-drop"):
                                                if (self.ipsg_drop is None):
                                                    self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                    self.ipsg_drop.parent = self
                                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                return self.ipsg_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "mac-move"):
                                                if (self.mac_move is None):
                                                    self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                    self.mac_move.parent = self
                                                    self._children_name_map["mac_move"] = "mac-move"
                                                return self.mac_move

                                            if (child_yang_name == "multicast-drop"):
                                                if (self.multicast_drop is None):
                                                    self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                    self.multicast_drop.parent = self
                                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                                return self.multicast_drop

                                            if (child_yang_name == "received-drops"):
                                                if (self.received_drops is None):
                                                    self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                    self.received_drops.parent = self
                                                    self._children_name_map["received_drops"] = "received-drops"
                                                return self.received_drops

                                            if (child_yang_name == "unicast-drop"):
                                                if (self.unicast_drop is None):
                                                    self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                    self.unicast_drop.parent = self
                                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                                return self.unicast_drop

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"

                                            self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                            self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                            self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                            self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bypassed_inbound_sequence_packet",
                                                            "bypassed_out_sequence_packet",
                                                            "sequence_number_expected",
                                                            "sequence_number_sent") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bypassed_inbound_sequence_packet.is_set or
                                                self.bypassed_out_sequence_packet.is_set or
                                                self.sequence_number_expected.is_set or
                                                self.sequence_number_sent.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                self.sequence_number_expected.yfilter != YFilter.not_set or
                                                self.sequence_number_sent.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sequence-number" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                            if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                            if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                            if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bypassed-inbound-sequence-packet"):
                                                self.bypassed_inbound_sequence_packet = value
                                                self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bypassed-out-sequence-packet"):
                                                self.bypassed_out_sequence_packet = value
                                                self.bypassed_out_sequence_packet.value_namespace = name_space
                                                self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-expected"):
                                                self.sequence_number_expected = value
                                                self.sequence_number_expected.value_namespace = name_space
                                                self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-sent"):
                                                self.sequence_number_sent = value
                                                self.sequence_number_sent.value_namespace = name_space
                                                self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                            (self.sequence_number is not None and self.sequence_number.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                            (self.sequence_number is not None and self.sequence_number.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "statistics" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dispostion-stats"):
                                            if (self.dispostion_stats is None):
                                                self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                                self.dispostion_stats.parent = self
                                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            return self.dispostion_stats

                                        if (child_yang_name == "impostion-stats"):
                                            if (self.impostion_stats is None):
                                                self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                                self.impostion_stats.parent = self
                                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                            return self.impostion_stats

                                        if (child_yang_name == "sequence-number"):
                                            if (self.sequence_number is None):
                                                self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                                self.sequence_number.parent = self
                                                self._children_name_map["sequence_number"] = "sequence-number"
                                            return self.sequence_number

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class P2MpPw(Entity):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__init__()

                                        self.yang_name = "p2mp-pw"
                                        self.yang_parent_name = "pseudowire"

                                        self.local_available = YLeaf(YType.boolean, "local-available")

                                        self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                        self.local_flags = YLeaf(YType.uint8, "local-flags")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                        self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                        self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                        self.remote_available = YLeaf(YType.boolean, "remote-available")

                                        self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                        self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                        self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                        self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_available",
                                                        "local_extended_tunnel_id",
                                                        "local_flags",
                                                        "local_label",
                                                        "local_p2mp_id",
                                                        "local_ptree_type",
                                                        "local_tunnel_id",
                                                        "remote_available",
                                                        "remote_extended_tunnel_id",
                                                        "remote_flags",
                                                        "remote_label",
                                                        "remote_p2mp_id",
                                                        "remote_ptree_type",
                                                        "remote_tunnel_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_available.is_set or
                                            self.local_extended_tunnel_id.is_set or
                                            self.local_flags.is_set or
                                            self.local_label.is_set or
                                            self.local_p2mp_id.is_set or
                                            self.local_ptree_type.is_set or
                                            self.local_tunnel_id.is_set or
                                            self.remote_available.is_set or
                                            self.remote_extended_tunnel_id.is_set or
                                            self.remote_flags.is_set or
                                            self.remote_label.is_set or
                                            self.remote_p2mp_id.is_set or
                                            self.remote_ptree_type.is_set or
                                            self.remote_tunnel_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_available.yfilter != YFilter.not_set or
                                            self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                            self.local_flags.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_p2mp_id.yfilter != YFilter.not_set or
                                            self.local_ptree_type.yfilter != YFilter.not_set or
                                            self.local_tunnel_id.yfilter != YFilter.not_set or
                                            self.remote_available.yfilter != YFilter.not_set or
                                            self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                            self.remote_flags.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_p2mp_id.yfilter != YFilter.not_set or
                                            self.remote_ptree_type.yfilter != YFilter.not_set or
                                            self.remote_tunnel_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "p2mp-pw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_available.get_name_leafdata())
                                        if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                        if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_flags.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                        if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                        if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                        if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_available.get_name_leafdata())
                                        if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                        if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                        if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                        if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-available"):
                                            self.local_available = value
                                            self.local_available.value_namespace = name_space
                                            self.local_available.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-extended-tunnel-id"):
                                            self.local_extended_tunnel_id = value
                                            self.local_extended_tunnel_id.value_namespace = name_space
                                            self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-flags"):
                                            self.local_flags = value
                                            self.local_flags.value_namespace = name_space
                                            self.local_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-p2mp-id"):
                                            self.local_p2mp_id = value
                                            self.local_p2mp_id.value_namespace = name_space
                                            self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ptree-type"):
                                            self.local_ptree_type = value
                                            self.local_ptree_type.value_namespace = name_space
                                            self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-tunnel-id"):
                                            self.local_tunnel_id = value
                                            self.local_tunnel_id.value_namespace = name_space
                                            self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-available"):
                                            self.remote_available = value
                                            self.remote_available.value_namespace = name_space
                                            self.remote_available.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-extended-tunnel-id"):
                                            self.remote_extended_tunnel_id = value
                                            self.remote_extended_tunnel_id.value_namespace = name_space
                                            self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-flags"):
                                            self.remote_flags = value
                                            self.remote_flags.value_namespace = name_space
                                            self.remote_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-p2mp-id"):
                                            self.remote_p2mp_id = value
                                            self.remote_p2mp_id.value_namespace = name_space
                                            self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ptree-type"):
                                            self.remote_ptree_type = value
                                            self.remote_ptree_type.value_namespace = name_space
                                            self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-tunnel-id"):
                                            self.remote_tunnel_id = value
                                            self.remote_tunnel_id.value_namespace = name_space
                                            self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.ad_method.is_set or
                                        self.ad_remote_down.is_set or
                                        self.admited_bw.is_set or
                                        self.auto_discovery.is_set or
                                        self.backup_active.is_set or
                                        self.backup_force_active.is_set or
                                        self.backup_pw.is_set or
                                        self.bitrate_mismatched.is_set or
                                        self.bridge_pw_type_mismatch.is_set or
                                        self.cas_mismatched.is_set or
                                        self.diff_ts_mismatched.is_set or
                                        self.disable_delay.is_set or
                                        self.disable_never.is_set or
                                        self.evpn_src_acid.is_set or
                                        self.fe_ctype.is_set or
                                        self.forward_class.is_set or
                                        self.freq_mismatched.is_set or
                                        self.illegal_control_word.is_set or
                                        self.imposed_vlan_id.is_set or
                                        self.interworking.is_set or
                                        self.ipv6_local_source_address.is_set or
                                        self.is_evpnvpws_type.is_set or
                                        self.is_flow_label_static.is_set or
                                        self.is_multi_segment_pseudowire.is_set or
                                        self.is_partially_programmed.is_set or
                                        self.is_pwr_type.is_set or
                                        self.is_vfi.is_set or
                                        self.last_time_status_changed.is_set or
                                        self.last_time_status_down.is_set or
                                        self.ldp_label_advertise_failed.is_set or
                                        self.load_balance.is_set or
                                        self.local_control_word.is_set or
                                        self.local_label_failed.is_set or
                                        self.local_pseudo_wire_type.is_set or
                                        self.local_source_address.is_set or
                                        self.mac_limit_oper_down.is_set or
                                        self.mtu_mismatched.is_set or
                                        self.not_supported_qinq.is_set or
                                        self.num_ma_cwithdraw_msg_received.is_set or
                                        self.number_ma_cwithdraw_message_sent.is_set or
                                        self.out_of_memory_state.is_set or
                                        self.payload_bytes_mismatched.is_set or
                                        self.payload_type_mismatched.is_set or
                                        self.preferred_path_disable_fallback.is_set or
                                        self.primary_peer_id.is_set or
                                        self.primary_pseudo_wire_id.is_set or
                                        self.primary_pw.is_set or
                                        self.protocol.is_set or
                                        self.pseudo_wire_id.is_set or
                                        self.pseudo_wire_state.is_set or
                                        self.pseudo_wire_type_mismatched.is_set or
                                        self.pw_class_name.is_set or
                                        self.pw_flow_label_code17_disabled.is_set or
                                        self.pw_flow_label_type.is_set or
                                        self.pw_flow_label_type_cfg.is_set or
                                        self.pw_redundancy_initial_delay.is_set or
                                        self.pw_redundancy_one_way.is_set or
                                        self.pw_status_use.is_set or
                                        self.pwlsd_rewrite_failed.is_set or
                                        self.remote_control_word.is_set or
                                        self.remote_label_failed.is_set or
                                        self.remote_pseudo_wire_type.is_set or
                                        self.required_bw.is_set or
                                        self.resync_enabled.is_set or
                                        self.resync_threshold.is_set or
                                        self.rtp_mismatched.is_set or
                                        self.sequencing_type.is_set or
                                        self.shutdown.is_set or
                                        self.sig_pkts_mismatched.is_set or
                                        self.ssrc_mismatched.is_set or
                                        self.state.is_set or
                                        self.table_policy_name.is_set or
                                        self.tag_rewrite.is_set or
                                        self.time_created.is_set or
                                        self.time_elapsed_creation.is_set or
                                        self.time_elapsed_status_changed.is_set or
                                        self.time_elapsed_status_down.is_set or
                                        self.transport_lsp_down.is_set or
                                        self.xconnect_id.is_set or
                                        (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                        (self.local_interface is not None and self.local_interface.has_data()) or
                                        (self.local_signalling is not None and self.local_signalling.has_data()) or
                                        (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                        (self.peer_id is not None and self.peer_id.has_data()) or
                                        (self.preferred_path is not None and self.preferred_path.has_data()) or
                                        (self.remote_interface is not None and self.remote_interface.has_data()) or
                                        (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                        (self.statistics is not None and self.statistics.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ad_method.yfilter != YFilter.not_set or
                                        self.ad_remote_down.yfilter != YFilter.not_set or
                                        self.admited_bw.yfilter != YFilter.not_set or
                                        self.auto_discovery.yfilter != YFilter.not_set or
                                        self.backup_active.yfilter != YFilter.not_set or
                                        self.backup_force_active.yfilter != YFilter.not_set or
                                        self.backup_pw.yfilter != YFilter.not_set or
                                        self.bitrate_mismatched.yfilter != YFilter.not_set or
                                        self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                        self.cas_mismatched.yfilter != YFilter.not_set or
                                        self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                        self.disable_delay.yfilter != YFilter.not_set or
                                        self.disable_never.yfilter != YFilter.not_set or
                                        self.evpn_src_acid.yfilter != YFilter.not_set or
                                        self.fe_ctype.yfilter != YFilter.not_set or
                                        self.forward_class.yfilter != YFilter.not_set or
                                        self.freq_mismatched.yfilter != YFilter.not_set or
                                        self.illegal_control_word.yfilter != YFilter.not_set or
                                        self.imposed_vlan_id.yfilter != YFilter.not_set or
                                        self.interworking.yfilter != YFilter.not_set or
                                        self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                        self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                        self.is_flow_label_static.yfilter != YFilter.not_set or
                                        self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                        self.is_partially_programmed.yfilter != YFilter.not_set or
                                        self.is_pwr_type.yfilter != YFilter.not_set or
                                        self.is_vfi.yfilter != YFilter.not_set or
                                        self.last_time_status_changed.yfilter != YFilter.not_set or
                                        self.last_time_status_down.yfilter != YFilter.not_set or
                                        self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                        self.load_balance.yfilter != YFilter.not_set or
                                        self.local_control_word.yfilter != YFilter.not_set or
                                        self.local_label_failed.yfilter != YFilter.not_set or
                                        self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                        self.local_source_address.yfilter != YFilter.not_set or
                                        self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                        self.mtu_mismatched.yfilter != YFilter.not_set or
                                        self.not_supported_qinq.yfilter != YFilter.not_set or
                                        self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                        self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                        self.out_of_memory_state.yfilter != YFilter.not_set or
                                        self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                        self.payload_type_mismatched.yfilter != YFilter.not_set or
                                        self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                        self.primary_peer_id.yfilter != YFilter.not_set or
                                        self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.primary_pw.yfilter != YFilter.not_set or
                                        self.protocol.yfilter != YFilter.not_set or
                                        self.pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.pseudo_wire_state.yfilter != YFilter.not_set or
                                        self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                        self.pw_class_name.yfilter != YFilter.not_set or
                                        self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                        self.pw_flow_label_type.yfilter != YFilter.not_set or
                                        self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                        self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                        self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                        self.pw_status_use.yfilter != YFilter.not_set or
                                        self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.remote_control_word.yfilter != YFilter.not_set or
                                        self.remote_label_failed.yfilter != YFilter.not_set or
                                        self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                        self.required_bw.yfilter != YFilter.not_set or
                                        self.resync_enabled.yfilter != YFilter.not_set or
                                        self.resync_threshold.yfilter != YFilter.not_set or
                                        self.rtp_mismatched.yfilter != YFilter.not_set or
                                        self.sequencing_type.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                        self.ssrc_mismatched.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.table_policy_name.yfilter != YFilter.not_set or
                                        self.tag_rewrite.yfilter != YFilter.not_set or
                                        self.time_created.yfilter != YFilter.not_set or
                                        self.time_elapsed_creation.yfilter != YFilter.not_set or
                                        self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                        self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                        self.transport_lsp_down.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                        (self.local_interface is not None and self.local_interface.has_operation()) or
                                        (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                        (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                        (self.peer_id is not None and self.peer_id.has_operation()) or
                                        (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                        (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                        (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                        (self.statistics is not None and self.statistics.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_method.get_name_leafdata())
                                    if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                    if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                    if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                    if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_active.get_name_leafdata())
                                    if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                    if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                    if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                    if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                    if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                    if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                    if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                    if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_never.get_name_leafdata())
                                    if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                    if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                    if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.forward_class.get_name_leafdata())
                                    if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                    if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                    if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                    if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interworking.get_name_leafdata())
                                    if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                    if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                    if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                    if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                    if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                    if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                    if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                    if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                    if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                    if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                    if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.load_balance.get_name_leafdata())
                                    if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                    if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                    if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                    if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                    if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                    if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                    if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                    if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                    if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                    if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                    if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                    if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                    if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                    if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                    if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                    if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol.get_name_leafdata())
                                    if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                    if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                    if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                    if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                    if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                    if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                    if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                    if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                    if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                    if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                    if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                    if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                    if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                    if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                    if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.required_bw.get_name_leafdata())
                                    if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                    if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                    if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                    if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                    if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                    if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                    if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_created.get_name_leafdata())
                                    if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                    if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                    if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                    if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "encapsulation-info"):
                                        if (self.encapsulation_info is None):
                                            self.encapsulation_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                            self.encapsulation_info.parent = self
                                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                        return self.encapsulation_info

                                    if (child_yang_name == "local-interface"):
                                        if (self.local_interface is None):
                                            self.local_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                            self.local_interface.parent = self
                                            self._children_name_map["local_interface"] = "local-interface"
                                        return self.local_interface

                                    if (child_yang_name == "local-signalling"):
                                        if (self.local_signalling is None):
                                            self.local_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                            self.local_signalling.parent = self
                                            self._children_name_map["local_signalling"] = "local-signalling"
                                        return self.local_signalling

                                    if (child_yang_name == "p2mp-pw"):
                                        if (self.p2mp_pw is None):
                                            self.p2mp_pw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                            self.p2mp_pw.parent = self
                                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                        return self.p2mp_pw

                                    if (child_yang_name == "peer-id"):
                                        if (self.peer_id is None):
                                            self.peer_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                            self.peer_id.parent = self
                                            self._children_name_map["peer_id"] = "peer-id"
                                        return self.peer_id

                                    if (child_yang_name == "preferred-path"):
                                        if (self.preferred_path is None):
                                            self.preferred_path = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                            self.preferred_path.parent = self
                                            self._children_name_map["preferred_path"] = "preferred-path"
                                        return self.preferred_path

                                    if (child_yang_name == "remote-interface"):
                                        if (self.remote_interface is None):
                                            self.remote_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                            self.remote_interface.parent = self
                                            self._children_name_map["remote_interface"] = "remote-interface"
                                        return self.remote_interface

                                    if (child_yang_name == "remote-signalling"):
                                        if (self.remote_signalling is None):
                                            self.remote_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                            self.remote_signalling.parent = self
                                            self._children_name_map["remote_signalling"] = "remote-signalling"
                                        return self.remote_signalling

                                    if (child_yang_name == "statistics"):
                                        if (self.statistics is None):
                                            self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                            self.statistics.parent = self
                                            self._children_name_map["statistics"] = "statistics"
                                        return self.statistics

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ad-method"):
                                        self.ad_method = value
                                        self.ad_method.value_namespace = name_space
                                        self.ad_method.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ad-remote-down"):
                                        self.ad_remote_down = value
                                        self.ad_remote_down.value_namespace = name_space
                                        self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "admited-bw"):
                                        self.admited_bw = value
                                        self.admited_bw.value_namespace = name_space
                                        self.admited_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "auto-discovery"):
                                        self.auto_discovery = value
                                        self.auto_discovery.value_namespace = name_space
                                        self.auto_discovery.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-active"):
                                        self.backup_active = value
                                        self.backup_active.value_namespace = name_space
                                        self.backup_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-force-active"):
                                        self.backup_force_active = value
                                        self.backup_force_active.value_namespace = name_space
                                        self.backup_force_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pw"):
                                        self.backup_pw = value
                                        self.backup_pw.value_namespace = name_space
                                        self.backup_pw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bitrate-mismatched"):
                                        self.bitrate_mismatched = value
                                        self.bitrate_mismatched.value_namespace = name_space
                                        self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bridge-pw-type-mismatch"):
                                        self.bridge_pw_type_mismatch = value
                                        self.bridge_pw_type_mismatch.value_namespace = name_space
                                        self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cas-mismatched"):
                                        self.cas_mismatched = value
                                        self.cas_mismatched.value_namespace = name_space
                                        self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "diff-ts-mismatched"):
                                        self.diff_ts_mismatched = value
                                        self.diff_ts_mismatched.value_namespace = name_space
                                        self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-delay"):
                                        self.disable_delay = value
                                        self.disable_delay.value_namespace = name_space
                                        self.disable_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-never"):
                                        self.disable_never = value
                                        self.disable_never.value_namespace = name_space
                                        self.disable_never.value_namespace_prefix = name_space_prefix
                                    if(value_path == "evpn-src-acid"):
                                        self.evpn_src_acid = value
                                        self.evpn_src_acid.value_namespace = name_space
                                        self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fe-ctype"):
                                        self.fe_ctype = value
                                        self.fe_ctype.value_namespace = name_space
                                        self.fe_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "forward-class"):
                                        self.forward_class = value
                                        self.forward_class.value_namespace = name_space
                                        self.forward_class.value_namespace_prefix = name_space_prefix
                                    if(value_path == "freq-mismatched"):
                                        self.freq_mismatched = value
                                        self.freq_mismatched.value_namespace = name_space
                                        self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "illegal-control-word"):
                                        self.illegal_control_word = value
                                        self.illegal_control_word.value_namespace = name_space
                                        self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "imposed-vlan-id"):
                                        self.imposed_vlan_id = value
                                        self.imposed_vlan_id.value_namespace = name_space
                                        self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interworking"):
                                        self.interworking = value
                                        self.interworking.value_namespace = name_space
                                        self.interworking.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-local-source-address"):
                                        self.ipv6_local_source_address = value
                                        self.ipv6_local_source_address.value_namespace = name_space
                                        self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-evpnvpws-type"):
                                        self.is_evpnvpws_type = value
                                        self.is_evpnvpws_type.value_namespace = name_space
                                        self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-flow-label-static"):
                                        self.is_flow_label_static = value
                                        self.is_flow_label_static.value_namespace = name_space
                                        self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-multi-segment-pseudowire"):
                                        self.is_multi_segment_pseudowire = value
                                        self.is_multi_segment_pseudowire.value_namespace = name_space
                                        self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-partially-programmed"):
                                        self.is_partially_programmed = value
                                        self.is_partially_programmed.value_namespace = name_space
                                        self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-pwr-type"):
                                        self.is_pwr_type = value
                                        self.is_pwr_type.value_namespace = name_space
                                        self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-vfi"):
                                        self.is_vfi = value
                                        self.is_vfi.value_namespace = name_space
                                        self.is_vfi.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-time-status-changed"):
                                        self.last_time_status_changed = value
                                        self.last_time_status_changed.value_namespace = name_space
                                        self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-time-status-down"):
                                        self.last_time_status_down = value
                                        self.last_time_status_down.value_namespace = name_space
                                        self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertise-failed"):
                                        self.ldp_label_advertise_failed = value
                                        self.ldp_label_advertise_failed.value_namespace = name_space
                                        self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "load-balance"):
                                        self.load_balance = value
                                        self.load_balance.value_namespace = name_space
                                        self.load_balance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-control-word"):
                                        self.local_control_word = value
                                        self.local_control_word.value_namespace = name_space
                                        self.local_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label-failed"):
                                        self.local_label_failed = value
                                        self.local_label_failed.value_namespace = name_space
                                        self.local_label_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-pseudo-wire-type"):
                                        self.local_pseudo_wire_type = value
                                        self.local_pseudo_wire_type.value_namespace = name_space
                                        self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-source-address"):
                                        self.local_source_address = value
                                        self.local_source_address.value_namespace = name_space
                                        self.local_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-oper-down"):
                                        self.mac_limit_oper_down = value
                                        self.mac_limit_oper_down.value_namespace = name_space
                                        self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-mismatched"):
                                        self.mtu_mismatched = value
                                        self.mtu_mismatched.value_namespace = name_space
                                        self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "not-supported-qinq"):
                                        self.not_supported_qinq = value
                                        self.not_supported_qinq.value_namespace = name_space
                                        self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                    if(value_path == "num-ma-cwithdraw-msg-received"):
                                        self.num_ma_cwithdraw_msg_received = value
                                        self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                        self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                    if(value_path == "number-ma-cwithdraw-message-sent"):
                                        self.number_ma_cwithdraw_message_sent = value
                                        self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                        self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                    if(value_path == "out-of-memory-state"):
                                        self.out_of_memory_state = value
                                        self.out_of_memory_state.value_namespace = name_space
                                        self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes-mismatched"):
                                        self.payload_bytes_mismatched = value
                                        self.payload_bytes_mismatched.value_namespace = name_space
                                        self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-type-mismatched"):
                                        self.payload_type_mismatched = value
                                        self.payload_type_mismatched.value_namespace = name_space
                                        self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "preferred-path-disable-fallback"):
                                        self.preferred_path_disable_fallback = value
                                        self.preferred_path_disable_fallback.value_namespace = name_space
                                        self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-peer-id"):
                                        self.primary_peer_id = value
                                        self.primary_peer_id.value_namespace = name_space
                                        self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-pseudo-wire-id"):
                                        self.primary_pseudo_wire_id = value
                                        self.primary_pseudo_wire_id.value_namespace = name_space
                                        self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-pw"):
                                        self.primary_pw = value
                                        self.primary_pw.value_namespace = name_space
                                        self.primary_pw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol"):
                                        self.protocol = value
                                        self.protocol.value_namespace = name_space
                                        self.protocol.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-id"):
                                        self.pseudo_wire_id = value
                                        self.pseudo_wire_id.value_namespace = name_space
                                        self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-state"):
                                        self.pseudo_wire_state = value
                                        self.pseudo_wire_state.value_namespace = name_space
                                        self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-type-mismatched"):
                                        self.pseudo_wire_type_mismatched = value
                                        self.pseudo_wire_type_mismatched.value_namespace = name_space
                                        self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-class-name"):
                                        self.pw_class_name = value
                                        self.pw_class_name.value_namespace = name_space
                                        self.pw_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-code17-disabled"):
                                        self.pw_flow_label_code17_disabled = value
                                        self.pw_flow_label_code17_disabled.value_namespace = name_space
                                        self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-type"):
                                        self.pw_flow_label_type = value
                                        self.pw_flow_label_type.value_namespace = name_space
                                        self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-type-cfg"):
                                        self.pw_flow_label_type_cfg = value
                                        self.pw_flow_label_type_cfg.value_namespace = name_space
                                        self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-redundancy-initial-delay"):
                                        self.pw_redundancy_initial_delay = value
                                        self.pw_redundancy_initial_delay.value_namespace = name_space
                                        self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-redundancy-one-way"):
                                        self.pw_redundancy_one_way = value
                                        self.pw_redundancy_one_way.value_namespace = name_space
                                        self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-status-use"):
                                        self.pw_status_use = value
                                        self.pw_status_use.value_namespace = name_space
                                        self.pw_status_use.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pwlsd-rewrite-failed"):
                                        self.pwlsd_rewrite_failed = value
                                        self.pwlsd_rewrite_failed.value_namespace = name_space
                                        self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-control-word"):
                                        self.remote_control_word = value
                                        self.remote_control_word.value_namespace = name_space
                                        self.remote_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label-failed"):
                                        self.remote_label_failed = value
                                        self.remote_label_failed.value_namespace = name_space
                                        self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-pseudo-wire-type"):
                                        self.remote_pseudo_wire_type = value
                                        self.remote_pseudo_wire_type.value_namespace = name_space
                                        self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "required-bw"):
                                        self.required_bw = value
                                        self.required_bw.value_namespace = name_space
                                        self.required_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resync-enabled"):
                                        self.resync_enabled = value
                                        self.resync_enabled.value_namespace = name_space
                                        self.resync_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resync-threshold"):
                                        self.resync_threshold = value
                                        self.resync_threshold.value_namespace = name_space
                                        self.resync_threshold.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rtp-mismatched"):
                                        self.rtp_mismatched = value
                                        self.rtp_mismatched.value_namespace = name_space
                                        self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequencing-type"):
                                        self.sequencing_type = value
                                        self.sequencing_type.value_namespace = name_space
                                        self.sequencing_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sig-pkts-mismatched"):
                                        self.sig_pkts_mismatched = value
                                        self.sig_pkts_mismatched.value_namespace = name_space
                                        self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ssrc-mismatched"):
                                        self.ssrc_mismatched = value
                                        self.ssrc_mismatched.value_namespace = name_space
                                        self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "table-policy-name"):
                                        self.table_policy_name = value
                                        self.table_policy_name.value_namespace = name_space
                                        self.table_policy_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tag-rewrite"):
                                        self.tag_rewrite = value
                                        self.tag_rewrite.value_namespace = name_space
                                        self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-created"):
                                        self.time_created = value
                                        self.time_created.value_namespace = name_space
                                        self.time_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-creation"):
                                        self.time_elapsed_creation = value
                                        self.time_elapsed_creation.value_namespace = name_space
                                        self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-status-changed"):
                                        self.time_elapsed_status_changed = value
                                        self.time_elapsed_status_changed.value_namespace = name_space
                                        self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-status-down"):
                                        self.time_elapsed_status_down = value
                                        self.time_elapsed_status_down.value_namespace = name_space
                                        self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transport-lsp-down"):
                                        self.transport_lsp_down = value
                                        self.transport_lsp_down.value_namespace = name_space
                                        self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-pw"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/base/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-pw"

                                    self.address = YLeaf(YType.str, "address")

                                    self.bmac = YLeaf(YType.str, "bmac")

                                    self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "bmac",
                                                    "next_hop_ip") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.bmac.is_set or
                                        self.next_hop_ip.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.bmac.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "static-mac" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bmac.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bmac"):
                                        self.bmac = value
                                        self.bmac.value_namespace = name_space
                                        self.bmac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.static_mac:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.is_access.is_set or
                                    self.neighbor.is_set or
                                    self.pseudowire_id.is_set or
                                    self.pw_type.is_set or
                                    self.ve_id_vpls_id_0_3.is_set or
                                    self.vpls_id_4_7.is_set or
                                    (self.pseudowire is not None and self.pseudowire.has_data()) or
                                    (self.security_parameters is not None and self.security_parameters.has_data()))

                            def has_operation(self):
                                for c in self.static_mac:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_access.yfilter != YFilter.not_set or
                                    self.neighbor.yfilter != YFilter.not_set or
                                    self.pseudowire_id.yfilter != YFilter.not_set or
                                    self.pw_type.yfilter != YFilter.not_set or
                                    self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set or
                                    self.vpls_id_4_7.yfilter != YFilter.not_set or
                                    (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bridge-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_access.get_name_leafdata())
                                if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor.get_name_leafdata())
                                if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudowire_id.get_name_leafdata())
                                if (self.pw_type.is_set or self.pw_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_type.get_name_leafdata())
                                if (self.ve_id_vpls_id_0_3.is_set or self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_id_vpls_id_0_3.get_name_leafdata())
                                if (self.vpls_id_4_7.is_set or self.vpls_id_4_7.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_4_7.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "pseudowire"):
                                    if (self.pseudowire is None):
                                        self.pseudowire = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                        self.pseudowire.parent = self
                                        self._children_name_map["pseudowire"] = "pseudowire"
                                    return self.pseudowire

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                if (child_yang_name == "static-mac"):
                                    for c in self.static_mac:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.static_mac.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id" or name == "pw-type" or name == "ve-id-vpls-id-0-3" or name == "vpls-id-4-7"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-access"):
                                    self.is_access = value
                                    self.is_access.value_namespace = name_space
                                    self.is_access.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor"):
                                    self.neighbor = value
                                    self.neighbor.value_namespace = name_space
                                    self.neighbor.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudowire-id"):
                                    self.pseudowire_id = value
                                    self.pseudowire_id.value_namespace = name_space
                                    self.pseudowire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-type"):
                                    self.pw_type = value
                                    self.pw_type.value_namespace = name_space
                                    self.pw_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-id-vpls-id-0-3"):
                                    self.ve_id_vpls_id_0_3 = value
                                    self.ve_id_vpls_id_0_3.value_namespace = name_space
                                    self.ve_id_vpls_id_0_3.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpls-id-4-7"):
                                    self.vpls_id_4_7 = value
                                    self.vpls_id_4_7.value_namespace = name_space
                                    self.vpls_id_4_7.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bridge_pw:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bridge_pw:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-pws" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bridge-pw"):
                                for c in self.bridge_pw:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bridge_pw.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-pw"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (self.bridge_pws is not None and self.bridge_pws.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bridge_pws is not None and self.bridge_pws.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-access-vfi-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-pws"):
                            if (self.bridge_pws is None):
                                self.bridge_pws = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                                self.bridge_pws.parent = self
                                self._children_name_map["bridge_pws"] = "bridge-pws"
                            return self.bridge_pws

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-pws"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BridgeCoreVfiTable(Entity):
                    """
                    Bridge Domain Core VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable, self).__init__()

                        self.yang_name = "bridge-core-vfi-table"
                        self.yang_parent_name = "bridge-domain"

                        self.bridge_pws = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                        self.bridge_pws.parent = self
                        self._children_name_map["bridge_pws"] = "bridge-pws"
                        self._children_yang_names.add("bridge-pws")


                    class BridgePws(Entity):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	VPLS Bridge Domain Pseudowire
                        	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__init__()

                            self.yang_name = "bridge-pws"
                            self.yang_parent_name = "bridge-core-vfi-table"

                            self.bridge_pw = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__setattr__(name, value)


                        class BridgePw(Entity):
                            """
                            VPLS Bridge Domain Pseudowire
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:   :py:class:`L2Vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnpw>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__init__()

                                self.yang_name = "bridge-pw"
                                self.yang_parent_name = "bridge-pws"

                                self.is_access = YLeaf(YType.boolean, "is-access")

                                self.neighbor = YLeaf(YType.str, "neighbor")

                                self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                                self.pw_type = YLeaf(YType.enumeration, "pw-type")

                                self.ve_id_vpls_id_0_3 = YLeaf(YType.uint32, "ve-id-vpls-id-0-3")

                                self.vpls_id_4_7 = YLeaf(YType.uint32, "vpls-id-4-7")

                                self.pseudowire = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"
                                self._children_yang_names.add("pseudowire")

                                self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                                self.static_mac = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_access",
                                                "neighbor",
                                                "pseudowire_id",
                                                "pw_type",
                                                "ve_id_vpls_id_0_3",
                                                "vpls_id_4_7") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)


                            class Pseudowire(Entity):
                                """
                                Pseudowire
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\:  bool
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\:  bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\:  bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\:  bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\:  bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\:  bool
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\:  bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\:  bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\:  bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\:  bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\:  bool
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_evpnvpws_type
                                
                                	is EVPN VPWS
                                	**type**\:  bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\:  bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\:  bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\:  bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\:  bool
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\:  bool
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\:  bool
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\:  bool
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\:  bool
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\:  bool
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\:  bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\:  bool
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\:  bool
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\:  bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\:  bool
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\:  bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\:  bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\:  bool
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\:  str
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                    self.yang_name = "pseudowire"
                                    self.yang_parent_name = "bridge-pw"

                                    self.ad_method = YLeaf(YType.uint32, "ad-method")

                                    self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                    self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                    self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                    self.backup_active = YLeaf(YType.boolean, "backup-active")

                                    self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                    self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                    self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                    self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                    self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                    self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                    self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                    self.disable_never = YLeaf(YType.boolean, "disable-never")

                                    self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                    self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                    self.forward_class = YLeaf(YType.uint8, "forward-class")

                                    self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                    self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                    self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                    self.interworking = YLeaf(YType.enumeration, "interworking")

                                    self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                    self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                    self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                    self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                    self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                    self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                    self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                    self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                    self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                    self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                    self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                    self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                    self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                    self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                    self.local_source_address = YLeaf(YType.str, "local-source-address")

                                    self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                    self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                    self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                    self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                    self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                    self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                    self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                    self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                    self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                    self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                    self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                    self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                    self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                    self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                    self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                    self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                    self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                    self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                    self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                    self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                    self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                    self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                    self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                    self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                    self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                    self.required_bw = YLeaf(YType.uint32, "required-bw")

                                    self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                    self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                    self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                    self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                    self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                    self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                    self.time_created = YLeaf(YType.str, "time-created")

                                    self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                    self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                    self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                    self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.encapsulation_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    self._children_yang_names.add("encapsulation-info")

                                    self.local_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                    self._children_yang_names.add("local-interface")

                                    self.local_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                    self._children_yang_names.add("local-signalling")

                                    self.p2mp_pw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    self._children_yang_names.add("p2mp-pw")

                                    self.peer_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                    self._children_yang_names.add("peer-id")

                                    self.preferred_path = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                    self._children_yang_names.add("preferred-path")

                                    self.remote_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                    self._children_yang_names.add("remote-interface")

                                    self.remote_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                    self._children_yang_names.add("remote-signalling")

                                    self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._children_yang_names.add("statistics")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ad_method",
                                                    "ad_remote_down",
                                                    "admited_bw",
                                                    "auto_discovery",
                                                    "backup_active",
                                                    "backup_force_active",
                                                    "backup_pw",
                                                    "bitrate_mismatched",
                                                    "bridge_pw_type_mismatch",
                                                    "cas_mismatched",
                                                    "diff_ts_mismatched",
                                                    "disable_delay",
                                                    "disable_never",
                                                    "evpn_src_acid",
                                                    "fe_ctype",
                                                    "forward_class",
                                                    "freq_mismatched",
                                                    "illegal_control_word",
                                                    "imposed_vlan_id",
                                                    "interworking",
                                                    "ipv6_local_source_address",
                                                    "is_evpnvpws_type",
                                                    "is_flow_label_static",
                                                    "is_multi_segment_pseudowire",
                                                    "is_partially_programmed",
                                                    "is_pwr_type",
                                                    "is_vfi",
                                                    "last_time_status_changed",
                                                    "last_time_status_down",
                                                    "ldp_label_advertise_failed",
                                                    "load_balance",
                                                    "local_control_word",
                                                    "local_label_failed",
                                                    "local_pseudo_wire_type",
                                                    "local_source_address",
                                                    "mac_limit_oper_down",
                                                    "mtu_mismatched",
                                                    "not_supported_qinq",
                                                    "num_ma_cwithdraw_msg_received",
                                                    "number_ma_cwithdraw_message_sent",
                                                    "out_of_memory_state",
                                                    "payload_bytes_mismatched",
                                                    "payload_type_mismatched",
                                                    "preferred_path_disable_fallback",
                                                    "primary_peer_id",
                                                    "primary_pseudo_wire_id",
                                                    "primary_pw",
                                                    "protocol",
                                                    "pseudo_wire_id",
                                                    "pseudo_wire_state",
                                                    "pseudo_wire_type_mismatched",
                                                    "pw_class_name",
                                                    "pw_flow_label_code17_disabled",
                                                    "pw_flow_label_type",
                                                    "pw_flow_label_type_cfg",
                                                    "pw_redundancy_initial_delay",
                                                    "pw_redundancy_one_way",
                                                    "pw_status_use",
                                                    "pwlsd_rewrite_failed",
                                                    "remote_control_word",
                                                    "remote_label_failed",
                                                    "remote_pseudo_wire_type",
                                                    "required_bw",
                                                    "resync_enabled",
                                                    "resync_threshold",
                                                    "rtp_mismatched",
                                                    "sequencing_type",
                                                    "shutdown",
                                                    "sig_pkts_mismatched",
                                                    "ssrc_mismatched",
                                                    "state",
                                                    "table_policy_name",
                                                    "tag_rewrite",
                                                    "time_created",
                                                    "time_elapsed_creation",
                                                    "time_elapsed_status_changed",
                                                    "time_elapsed_status_down",
                                                    "transport_lsp_down",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)


                                class PeerId(Entity):
                                    """
                                    Peer
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                        self.yang_name = "peer-id"
                                        self.yang_parent_name = "pseudowire"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                        self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                        self.type = YLeaf(YType.enumeration, "type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "ipv4_peer_id",
                                                        "ipv6_peer_id",
                                                        "type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.ipv4_peer_id.is_set or
                                            self.ipv6_peer_id.is_set or
                                            self.type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.ipv4_peer_id.yfilter != YFilter.not_set or
                                            self.ipv6_peer_id.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "peer-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                        if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-peer-id"):
                                            self.ipv4_peer_id = value
                                            self.ipv4_peer_id.value_namespace = name_space
                                            self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-peer-id"):
                                            self.ipv6_peer_id = value
                                            self.ipv6_peer_id.value_namespace = name_space
                                            self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix


                                class EncapsulationInfo(Entity):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                        self.yang_name = "encapsulation-info"
                                        self.yang_parent_name = "pseudowire"

                                        self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                        self.atom = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                        self._children_yang_names.add("atom")

                                        self.l2tpv3 = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                        self._children_yang_names.add("l2tpv3")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                    class Atom(Entity):
                                        """
                                        atom
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                            self.yang_name = "atom"
                                            self.yang_parent_name = "encapsulation-info"

                                            self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                            self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                            self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                            self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                            self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                            self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                            self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                            self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                            self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                            self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                            self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                            self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                            self.local_veid = YLeaf(YType.uint32, "local-veid")

                                            self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                            self.rem_saii = YLeaf(YType.str, "rem-saii")

                                            self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                            self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                            self.rem_taii = YLeaf(YType.str, "rem-taii")

                                            self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                            self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                            self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                            self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                            self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                            self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                                            self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                            self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                            self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                            self.saii = YLeaf(YType.str, "saii")

                                            self.source_address = YLeaf(YType.str, "source-address")

                                            self.taii = YLeaf(YType.str, "taii")

                                            self.local_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                            self._children_yang_names.add("local-agi")

                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            self._children_yang_names.add("multi-segment-pseudowire-stats")

                                            self.remote_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                            self._children_yang_names.add("remote-agi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("is_pseudowire_headend",
                                                            "is_sai_itype2",
                                                            "is_tai_itype2",
                                                            "ldp_label_advertisment_failed",
                                                            "local_c_ctype",
                                                            "local_ceid",
                                                            "local_cv_type",
                                                            "local_group_id",
                                                            "local_label",
                                                            "local_ldp_id",
                                                            "local_saii_gbl_id",
                                                            "local_saiiac_id",
                                                            "local_taii_gbl_id",
                                                            "local_taiiac_id",
                                                            "local_veid",
                                                            "lsd_rewrite_failed",
                                                            "rem_saii",
                                                            "rem_saii_gbl_id",
                                                            "rem_saiiac_id",
                                                            "rem_taii",
                                                            "rem_taii_gbl_id",
                                                            "rem_taiiac_id",
                                                            "remote_c_ctype",
                                                            "remote_ceid",
                                                            "remote_cv_type",
                                                            "remote_group_id",
                                                            "remote_label",
                                                            "remote_ldp_id",
                                                            "remote_source_address",
                                                            "remote_veid",
                                                            "saii",
                                                            "source_address",
                                                            "taii") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                        class LocalAgi(Entity):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                self.yang_name = "local-agi"
                                                self.yang_parent_name = "atom"

                                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                                self._children_yang_names.add("auto")

                                                self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                                self._children_yang_names.add("two-byte-as")

                                                self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._children_yang_names.add("v4-addr")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vpls_id_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "local-agi"

                                                    self.asn = YLeaf(YType.uint16, "asn")

                                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("asn",
                                                                    "vpn_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.asn.is_set or
                                                        self.vpn_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.asn.yfilter != YFilter.not_set or
                                                        self.vpn_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "auto" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "asn" or name == "vpn-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "asn"):
                                                        self.asn = value
                                                        self.asn.value_namespace = name_space
                                                        self.asn.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpn-id"):
                                                        self.vpn_id = value
                                                        self.vpn_id.value_namespace = name_space
                                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "local-agi"

                                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("four_byte_index",
                                                                    "two_byte_as") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.four_byte_index.is_set or
                                                        self.two_byte_as.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.four_byte_index.yfilter != YFilter.not_set or
                                                        self.two_byte_as.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "two-byte-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "four-byte-index"):
                                                        self.four_byte_index = value
                                                        self.four_byte_index.value_namespace = name_space
                                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-as"):
                                                        self.two_byte_as = value
                                                        self.two_byte_as.value_namespace = name_space
                                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "local-agi"

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ipv4_address",
                                                                    "two_byte_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ipv4_address.is_set or
                                                        self.two_byte_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ipv4_address.yfilter != YFilter.not_set or
                                                        self.two_byte_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "v4-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ipv4-address"):
                                                        self.ipv4_address = value
                                                        self.ipv4_address.value_namespace = name_space
                                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-index"):
                                                        self.two_byte_index = value
                                                        self.two_byte_index.value_namespace = name_space
                                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.vpls_id_type.is_set or
                                                    (self.auto is not None and self.auto.has_data()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                                    (self.auto is not None and self.auto.has_operation()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "local-agi" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "auto"):
                                                    if (self.auto is None):
                                                        self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                        self.auto.parent = self
                                                        self._children_name_map["auto"] = "auto"
                                                    return self.auto

                                                if (child_yang_name == "two-byte-as"):
                                                    if (self.two_byte_as is None):
                                                        self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                        self.two_byte_as.parent = self
                                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    return self.two_byte_as

                                                if (child_yang_name == "v4-addr"):
                                                    if (self.v4_addr is None):
                                                        self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                        self.v4_addr.parent = self
                                                        self._children_name_map["v4_addr"] = "v4-addr"
                                                    return self.v4_addr

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vpls-id-type"):
                                                    self.vpls_id_type = value
                                                    self.vpls_id_type.value_namespace = name_space
                                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                        class RemoteAgi(Entity):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                self.yang_name = "remote-agi"
                                                self.yang_parent_name = "atom"

                                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                                self._children_yang_names.add("auto")

                                                self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                                self._children_yang_names.add("two-byte-as")

                                                self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._children_yang_names.add("v4-addr")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vpls_id_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.asn = YLeaf(YType.uint16, "asn")

                                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("asn",
                                                                    "vpn_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.asn.is_set or
                                                        self.vpn_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.asn.yfilter != YFilter.not_set or
                                                        self.vpn_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "auto" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "asn" or name == "vpn-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "asn"):
                                                        self.asn = value
                                                        self.asn.value_namespace = name_space
                                                        self.asn.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpn-id"):
                                                        self.vpn_id = value
                                                        self.vpn_id.value_namespace = name_space
                                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("four_byte_index",
                                                                    "two_byte_as") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.four_byte_index.is_set or
                                                        self.two_byte_as.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.four_byte_index.yfilter != YFilter.not_set or
                                                        self.two_byte_as.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "two-byte-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "four-byte-index"):
                                                        self.four_byte_index = value
                                                        self.four_byte_index.value_namespace = name_space
                                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-as"):
                                                        self.two_byte_as = value
                                                        self.two_byte_as.value_namespace = name_space
                                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ipv4_address",
                                                                    "two_byte_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ipv4_address.is_set or
                                                        self.two_byte_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ipv4_address.yfilter != YFilter.not_set or
                                                        self.two_byte_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "v4-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ipv4-address"):
                                                        self.ipv4_address = value
                                                        self.ipv4_address.value_namespace = name_space
                                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-index"):
                                                        self.two_byte_index = value
                                                        self.two_byte_index.value_namespace = name_space
                                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.vpls_id_type.is_set or
                                                    (self.auto is not None and self.auto.has_data()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                                    (self.auto is not None and self.auto.has_operation()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-agi" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "auto"):
                                                    if (self.auto is None):
                                                        self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                        self.auto.parent = self
                                                        self._children_name_map["auto"] = "auto"
                                                    return self.auto

                                                if (child_yang_name == "two-byte-as"):
                                                    if (self.two_byte_as is None):
                                                        self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                        self.two_byte_as.parent = self
                                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    return self.two_byte_as

                                                if (child_yang_name == "v4-addr"):
                                                    if (self.v4_addr is None):
                                                        self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                        self.v4_addr.parent = self
                                                        self._children_name_map["v4_addr"] = "v4-addr"
                                                    return self.v4_addr

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vpls-id-type"):
                                                    self.vpls_id_type = value
                                                    self.vpls_id_type.value_namespace = name_space
                                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                        class MultiSegmentPseudowireStats(Entity):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                self.yang_name = "multi-segment-pseudowire-stats"
                                                self.yang_parent_name = "atom"

                                                self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                                self.received_packets = YLeaf(YType.uint64, "received-packets")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("received_bytes",
                                                                "received_packets") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.received_bytes.is_set or
                                                    self.received_packets.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.received_bytes.yfilter != YFilter.not_set or
                                                    self.received_packets.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                                if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.received_packets.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "received-bytes" or name == "received-packets"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "received-bytes"):
                                                    self.received_bytes = value
                                                    self.received_bytes.value_namespace = name_space
                                                    self.received_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "received-packets"):
                                                    self.received_packets = value
                                                    self.received_packets.value_namespace = name_space
                                                    self.received_packets.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.is_pseudowire_headend.is_set or
                                                self.is_sai_itype2.is_set or
                                                self.is_tai_itype2.is_set or
                                                self.ldp_label_advertisment_failed.is_set or
                                                self.local_c_ctype.is_set or
                                                self.local_ceid.is_set or
                                                self.local_cv_type.is_set or
                                                self.local_group_id.is_set or
                                                self.local_label.is_set or
                                                self.local_ldp_id.is_set or
                                                self.local_saii_gbl_id.is_set or
                                                self.local_saiiac_id.is_set or
                                                self.local_taii_gbl_id.is_set or
                                                self.local_taiiac_id.is_set or
                                                self.local_veid.is_set or
                                                self.lsd_rewrite_failed.is_set or
                                                self.rem_saii.is_set or
                                                self.rem_saii_gbl_id.is_set or
                                                self.rem_saiiac_id.is_set or
                                                self.rem_taii.is_set or
                                                self.rem_taii_gbl_id.is_set or
                                                self.rem_taiiac_id.is_set or
                                                self.remote_c_ctype.is_set or
                                                self.remote_ceid.is_set or
                                                self.remote_cv_type.is_set or
                                                self.remote_group_id.is_set or
                                                self.remote_label.is_set or
                                                self.remote_ldp_id.is_set or
                                                self.remote_source_address.is_set or
                                                self.remote_veid.is_set or
                                                self.saii.is_set or
                                                self.source_address.is_set or
                                                self.taii.is_set or
                                                (self.local_agi is not None and self.local_agi.has_data()) or
                                                (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                                (self.remote_agi is not None and self.remote_agi.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                                self.is_sai_itype2.yfilter != YFilter.not_set or
                                                self.is_tai_itype2.yfilter != YFilter.not_set or
                                                self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                                self.local_c_ctype.yfilter != YFilter.not_set or
                                                self.local_ceid.yfilter != YFilter.not_set or
                                                self.local_cv_type.yfilter != YFilter.not_set or
                                                self.local_group_id.yfilter != YFilter.not_set or
                                                self.local_label.yfilter != YFilter.not_set or
                                                self.local_ldp_id.yfilter != YFilter.not_set or
                                                self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                                self.local_saiiac_id.yfilter != YFilter.not_set or
                                                self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                                self.local_taiiac_id.yfilter != YFilter.not_set or
                                                self.local_veid.yfilter != YFilter.not_set or
                                                self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                                self.rem_saii.yfilter != YFilter.not_set or
                                                self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                                self.rem_saiiac_id.yfilter != YFilter.not_set or
                                                self.rem_taii.yfilter != YFilter.not_set or
                                                self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                                self.rem_taiiac_id.yfilter != YFilter.not_set or
                                                self.remote_c_ctype.yfilter != YFilter.not_set or
                                                self.remote_ceid.yfilter != YFilter.not_set or
                                                self.remote_cv_type.yfilter != YFilter.not_set or
                                                self.remote_group_id.yfilter != YFilter.not_set or
                                                self.remote_label.yfilter != YFilter.not_set or
                                                self.remote_ldp_id.yfilter != YFilter.not_set or
                                                self.remote_source_address.yfilter != YFilter.not_set or
                                                self.remote_veid.yfilter != YFilter.not_set or
                                                self.saii.yfilter != YFilter.not_set or
                                                self.source_address.yfilter != YFilter.not_set or
                                                self.taii.yfilter != YFilter.not_set or
                                                (self.local_agi is not None and self.local_agi.has_operation()) or
                                                (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                                (self.remote_agi is not None and self.remote_agi.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atom" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                            if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                            if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                            if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                            if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                            if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                            if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                            if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_label.get_name_leafdata())
                                            if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                            if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                            if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                            if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                            if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                            if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_veid.get_name_leafdata())
                                            if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                            if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                            if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                            if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                            if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                            if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                            if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                            if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                            if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                            if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                            if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                                            if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                            if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                            if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                            if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.saii.get_name_leafdata())
                                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.source_address.get_name_leafdata())
                                            if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.taii.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "local-agi"):
                                                if (self.local_agi is None):
                                                    self.local_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                    self.local_agi.parent = self
                                                    self._children_name_map["local_agi"] = "local-agi"
                                                return self.local_agi

                                            if (child_yang_name == "multi-segment-pseudowire-stats"):
                                                if (self.multi_segment_pseudowire_stats is None):
                                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                    self.multi_segment_pseudowire_stats.parent = self
                                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                return self.multi_segment_pseudowire_stats

                                            if (child_yang_name == "remote-agi"):
                                                if (self.remote_agi is None):
                                                    self.remote_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                    self.remote_agi.parent = self
                                                    self._children_name_map["remote_agi"] = "remote-agi"
                                                return self.remote_agi

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "is-pseudowire-headend"):
                                                self.is_pseudowire_headend = value
                                                self.is_pseudowire_headend.value_namespace = name_space
                                                self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-sai-itype2"):
                                                self.is_sai_itype2 = value
                                                self.is_sai_itype2.value_namespace = name_space
                                                self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-tai-itype2"):
                                                self.is_tai_itype2 = value
                                                self.is_tai_itype2.value_namespace = name_space
                                                self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ldp-label-advertisment-failed"):
                                                self.ldp_label_advertisment_failed = value
                                                self.ldp_label_advertisment_failed.value_namespace = name_space
                                                self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-c-ctype"):
                                                self.local_c_ctype = value
                                                self.local_c_ctype.value_namespace = name_space
                                                self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ceid"):
                                                self.local_ceid = value
                                                self.local_ceid.value_namespace = name_space
                                                self.local_ceid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cv-type"):
                                                self.local_cv_type = value
                                                self.local_cv_type.value_namespace = name_space
                                                self.local_cv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-group-id"):
                                                self.local_group_id = value
                                                self.local_group_id.value_namespace = name_space
                                                self.local_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-label"):
                                                self.local_label = value
                                                self.local_label.value_namespace = name_space
                                                self.local_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ldp-id"):
                                                self.local_ldp_id = value
                                                self.local_ldp_id.value_namespace = name_space
                                                self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-saii-gbl-id"):
                                                self.local_saii_gbl_id = value
                                                self.local_saii_gbl_id.value_namespace = name_space
                                                self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-saiiac-id"):
                                                self.local_saiiac_id = value
                                                self.local_saiiac_id.value_namespace = name_space
                                                self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-taii-gbl-id"):
                                                self.local_taii_gbl_id = value
                                                self.local_taii_gbl_id.value_namespace = name_space
                                                self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-taiiac-id"):
                                                self.local_taiiac_id = value
                                                self.local_taiiac_id.value_namespace = name_space
                                                self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-veid"):
                                                self.local_veid = value
                                                self.local_veid.value_namespace = name_space
                                                self.local_veid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsd-rewrite-failed"):
                                                self.lsd_rewrite_failed = value
                                                self.lsd_rewrite_failed.value_namespace = name_space
                                                self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saii"):
                                                self.rem_saii = value
                                                self.rem_saii.value_namespace = name_space
                                                self.rem_saii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saii-gbl-id"):
                                                self.rem_saii_gbl_id = value
                                                self.rem_saii_gbl_id.value_namespace = name_space
                                                self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saiiac-id"):
                                                self.rem_saiiac_id = value
                                                self.rem_saiiac_id.value_namespace = name_space
                                                self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taii"):
                                                self.rem_taii = value
                                                self.rem_taii.value_namespace = name_space
                                                self.rem_taii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taii-gbl-id"):
                                                self.rem_taii_gbl_id = value
                                                self.rem_taii_gbl_id.value_namespace = name_space
                                                self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taiiac-id"):
                                                self.rem_taiiac_id = value
                                                self.rem_taiiac_id.value_namespace = name_space
                                                self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-c-ctype"):
                                                self.remote_c_ctype = value
                                                self.remote_c_ctype.value_namespace = name_space
                                                self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ceid"):
                                                self.remote_ceid = value
                                                self.remote_ceid.value_namespace = name_space
                                                self.remote_ceid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cv-type"):
                                                self.remote_cv_type = value
                                                self.remote_cv_type.value_namespace = name_space
                                                self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-group-id"):
                                                self.remote_group_id = value
                                                self.remote_group_id.value_namespace = name_space
                                                self.remote_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-label"):
                                                self.remote_label = value
                                                self.remote_label.value_namespace = name_space
                                                self.remote_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ldp-id"):
                                                self.remote_ldp_id = value
                                                self.remote_ldp_id.value_namespace = name_space
                                                self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-source-address"):
                                                self.remote_source_address = value
                                                self.remote_source_address.value_namespace = name_space
                                                self.remote_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-veid"):
                                                self.remote_veid = value
                                                self.remote_veid.value_namespace = name_space
                                                self.remote_veid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "saii"):
                                                self.saii = value
                                                self.saii.value_namespace = name_space
                                                self.saii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "source-address"):
                                                self.source_address = value
                                                self.source_address.value_namespace = name_space
                                                self.source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "taii"):
                                                self.taii = value
                                                self.taii.value_namespace = name_space
                                                self.taii.value_namespace_prefix = name_space_prefix


                                    class L2Tpv3(Entity):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\:  bool
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\:  str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                            self.yang_name = "l2tpv3"
                                            self.yang_parent_name = "encapsulation-info"

                                            self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                            self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                            self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                            self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                            self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                            self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                            self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                            self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                            self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                            self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                            self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                            self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                            self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                            self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                            self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                            self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                            self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                            self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                            self.tos = YLeaf(YType.uint8, "tos")

                                            self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                            self.ttl = YLeaf(YType.uint8, "ttl")

                                            self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dont_fragment_bit",
                                                            "ipv4_source_address",
                                                            "ipv6_source_address",
                                                            "l2tp_class_name",
                                                            "local_cookie_high_value",
                                                            "local_cookie_low_value",
                                                            "local_cookie_size",
                                                            "local_secondary_cookie_high_value",
                                                            "local_secondary_cookie_low_value",
                                                            "local_secondary_cookie_size",
                                                            "local_session_id",
                                                            "path_mtu_enabled",
                                                            "path_mtu_max_value",
                                                            "remote_circuit_status_up",
                                                            "remote_cookie_high_value",
                                                            "remote_cookie_low_value",
                                                            "remote_cookie_size",
                                                            "remote_session_id",
                                                            "tos",
                                                            "tos_mode",
                                                            "ttl",
                                                            "tunnel_state") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dont_fragment_bit.is_set or
                                                self.ipv4_source_address.is_set or
                                                self.ipv6_source_address.is_set or
                                                self.l2tp_class_name.is_set or
                                                self.local_cookie_high_value.is_set or
                                                self.local_cookie_low_value.is_set or
                                                self.local_cookie_size.is_set or
                                                self.local_secondary_cookie_high_value.is_set or
                                                self.local_secondary_cookie_low_value.is_set or
                                                self.local_secondary_cookie_size.is_set or
                                                self.local_session_id.is_set or
                                                self.path_mtu_enabled.is_set or
                                                self.path_mtu_max_value.is_set or
                                                self.remote_circuit_status_up.is_set or
                                                self.remote_cookie_high_value.is_set or
                                                self.remote_cookie_low_value.is_set or
                                                self.remote_cookie_size.is_set or
                                                self.remote_session_id.is_set or
                                                self.tos.is_set or
                                                self.tos_mode.is_set or
                                                self.ttl.is_set or
                                                self.tunnel_state.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dont_fragment_bit.yfilter != YFilter.not_set or
                                                self.ipv4_source_address.yfilter != YFilter.not_set or
                                                self.ipv6_source_address.yfilter != YFilter.not_set or
                                                self.l2tp_class_name.yfilter != YFilter.not_set or
                                                self.local_cookie_high_value.yfilter != YFilter.not_set or
                                                self.local_cookie_low_value.yfilter != YFilter.not_set or
                                                self.local_cookie_size.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.local_session_id.yfilter != YFilter.not_set or
                                                self.path_mtu_enabled.yfilter != YFilter.not_set or
                                                self.path_mtu_max_value.yfilter != YFilter.not_set or
                                                self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                                self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                                self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                                self.remote_cookie_size.yfilter != YFilter.not_set or
                                                self.remote_session_id.yfilter != YFilter.not_set or
                                                self.tos.yfilter != YFilter.not_set or
                                                self.tos_mode.yfilter != YFilter.not_set or
                                                self.ttl.yfilter != YFilter.not_set or
                                                self.tunnel_state.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2tpv3" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                            if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                            if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                            if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                            if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                            if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                            if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                            if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                            if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                            if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                            if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                            if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                            if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                            if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                            if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                            if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                            if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                            if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                            if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos.get_name_leafdata())
                                            if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                            if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ttl.get_name_leafdata())
                                            if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dont-fragment-bit"):
                                                self.dont_fragment_bit = value
                                                self.dont_fragment_bit.value_namespace = name_space
                                                self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-source-address"):
                                                self.ipv4_source_address = value
                                                self.ipv4_source_address.value_namespace = name_space
                                                self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-source-address"):
                                                self.ipv6_source_address = value
                                                self.ipv6_source_address.value_namespace = name_space
                                                self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "l2tp-class-name"):
                                                self.l2tp_class_name = value
                                                self.l2tp_class_name.value_namespace = name_space
                                                self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-high-value"):
                                                self.local_cookie_high_value = value
                                                self.local_cookie_high_value.value_namespace = name_space
                                                self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-low-value"):
                                                self.local_cookie_low_value = value
                                                self.local_cookie_low_value.value_namespace = name_space
                                                self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-size"):
                                                self.local_cookie_size = value
                                                self.local_cookie_size.value_namespace = name_space
                                                self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-high-value"):
                                                self.local_secondary_cookie_high_value = value
                                                self.local_secondary_cookie_high_value.value_namespace = name_space
                                                self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-low-value"):
                                                self.local_secondary_cookie_low_value = value
                                                self.local_secondary_cookie_low_value.value_namespace = name_space
                                                self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-size"):
                                                self.local_secondary_cookie_size = value
                                                self.local_secondary_cookie_size.value_namespace = name_space
                                                self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-session-id"):
                                                self.local_session_id = value
                                                self.local_session_id.value_namespace = name_space
                                                self.local_session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "path-mtu-enabled"):
                                                self.path_mtu_enabled = value
                                                self.path_mtu_enabled.value_namespace = name_space
                                                self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "path-mtu-max-value"):
                                                self.path_mtu_max_value = value
                                                self.path_mtu_max_value.value_namespace = name_space
                                                self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-circuit-status-up"):
                                                self.remote_circuit_status_up = value
                                                self.remote_circuit_status_up.value_namespace = name_space
                                                self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-high-value"):
                                                self.remote_cookie_high_value = value
                                                self.remote_cookie_high_value.value_namespace = name_space
                                                self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-low-value"):
                                                self.remote_cookie_low_value = value
                                                self.remote_cookie_low_value.value_namespace = name_space
                                                self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-size"):
                                                self.remote_cookie_size = value
                                                self.remote_cookie_size.value_namespace = name_space
                                                self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-session-id"):
                                                self.remote_session_id = value
                                                self.remote_session_id.value_namespace = name_space
                                                self.remote_session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos"):
                                                self.tos = value
                                                self.tos.value_namespace = name_space
                                                self.tos.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos-mode"):
                                                self.tos_mode = value
                                                self.tos_mode.value_namespace = name_space
                                                self.tos_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ttl"):
                                                self.ttl = value
                                                self.ttl.value_namespace = name_space
                                                self.ttl.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-state"):
                                                self.tunnel_state = value
                                                self.tunnel_state.value_namespace = name_space
                                                self.tunnel_state.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.encapsulation.is_set or
                                            (self.atom is not None and self.atom.has_data()) or
                                            (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation.yfilter != YFilter.not_set or
                                            (self.atom is not None and self.atom.has_operation()) or
                                            (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "encapsulation-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atom"):
                                            if (self.atom is None):
                                                self.atom = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                                self.atom.parent = self
                                                self._children_name_map["atom"] = "atom"
                                            return self.atom

                                        if (child_yang_name == "l2tpv3"):
                                            if (self.l2tpv3 is None):
                                                self.l2tpv3 = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                                self.l2tpv3.parent = self
                                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                            return self.l2tpv3

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation"):
                                            self.encapsulation = value
                                            self.encapsulation.value_namespace = name_space
                                            self.encapsulation.value_namespace_prefix = name_space_prefix


                                class LocalInterface(Entity):
                                    """
                                    Local interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                        self.yang_name = "local-interface"
                                        self.yang_parent_name = "pseudowire"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "local-interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class RemoteInterface(Entity):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                        self.yang_name = "remote-interface"
                                        self.yang_parent_name = "pseudowire"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "remote-interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class PreferredPath(Entity):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                        self.yang_name = "preferred-path"
                                        self.yang_parent_name = "pseudowire"

                                        self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                        self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                        self.option = YLeaf(YType.enumeration, "option")

                                        self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                        self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ip_tunnel_interface_number",
                                                        "next_hop_ip",
                                                        "option",
                                                        "te_tunnel_interface_number",
                                                        "tp_tunnel_interface_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ip_tunnel_interface_number.is_set or
                                            self.next_hop_ip.is_set or
                                            self.option.is_set or
                                            self.te_tunnel_interface_number.is_set or
                                            self.tp_tunnel_interface_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                            self.next_hop_ip.yfilter != YFilter.not_set or
                                            self.option.yfilter != YFilter.not_set or
                                            self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                            self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "preferred-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                        if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.option.get_name_leafdata())
                                        if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                        if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ip-tunnel-interface-number"):
                                            self.ip_tunnel_interface_number = value
                                            self.ip_tunnel_interface_number.value_namespace = name_space
                                            self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop-ip"):
                                            self.next_hop_ip = value
                                            self.next_hop_ip.value_namespace = name_space
                                            self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                        if(value_path == "option"):
                                            self.option = value
                                            self.option.value_namespace = name_space
                                            self.option.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-tunnel-interface-number"):
                                            self.te_tunnel_interface_number = value
                                            self.te_tunnel_interface_number.value_namespace = name_space
                                            self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tp-tunnel-interface-number"):
                                            self.tp_tunnel_interface_number = value
                                            self.tp_tunnel_interface_number.value_namespace = name_space
                                            self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                                class LocalSignalling(Entity):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                        self.yang_name = "local-signalling"
                                        self.yang_parent_name = "pseudowire"

                                        self.pw_status = YLeaf(YType.uint32, "pw-status")

                                        self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                        self._children_yang_names.add("status-tlv")

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "local-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "status-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "local-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.pw_status.is_set or
                                            (self.status_tlv is not None and self.status_tlv.has_data()))

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_status.yfilter != YFilter.not_set or
                                            (self.status_tlv is not None and self.status_tlv.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-signalling" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "status-tlv"):
                                            if (self.status_tlv is None):
                                                self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                                self.status_tlv.parent = self
                                                self._children_name_map["status_tlv"] = "status-tlv"
                                            return self.status_tlv

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-status"):
                                            self.pw_status = value
                                            self.pw_status.value_namespace = name_space
                                            self.pw_status.value_namespace_prefix = name_space_prefix


                                class RemoteSignalling(Entity):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                        self.yang_name = "remote-signalling"
                                        self.yang_parent_name = "pseudowire"

                                        self.pw_status = YLeaf(YType.uint32, "pw-status")

                                        self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                        self._children_yang_names.add("status-tlv")

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "remote-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "status-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "remote-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.pw_status.is_set or
                                            (self.status_tlv is not None and self.status_tlv.has_data()))

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_status.yfilter != YFilter.not_set or
                                            (self.status_tlv is not None and self.status_tlv.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-signalling" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "status-tlv"):
                                            if (self.status_tlv is None):
                                                self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                                self.status_tlv.parent = self
                                                self._children_name_map["status_tlv"] = "status-tlv"
                                            return self.status_tlv

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-status"):
                                            self.pw_status = value
                                            self.pw_status.value_namespace = name_space
                                            self.pw_status.value_namespace_prefix = name_space_prefix


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "pseudowire"

                                        self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        self._children_yang_names.add("dispostion-stats")

                                        self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                        self._children_yang_names.add("impostion-stats")

                                        self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._children_yang_names.add("sequence-number")


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                            self._children_yang_names.add("broadcast")

                                            self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            self._children_yang_names.add("imposition-mtu-drop")

                                            self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                            self._children_yang_names.add("imposition-stat")

                                            self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            self._children_yang_names.add("impostion-tail-drop")

                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            self._children_yang_names.add("l2fsbi-drop")

                                            self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                            self._children_yang_names.add("multicast")

                                            self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._children_yang_names.add("unknown-unicast")


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class L2FsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2fsbi-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast is not None and self.broadcast.has_data()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                (self.multicast is not None and self.multicast.has_data()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast is not None and self.broadcast.has_operation()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                (self.multicast is not None and self.multicast.has_operation()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast"):
                                                if (self.broadcast is None):
                                                    self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                    self.broadcast.parent = self
                                                    self._children_name_map["broadcast"] = "broadcast"
                                                return self.broadcast

                                            if (child_yang_name == "imposition-mtu-drop"):
                                                if (self.imposition_mtu_drop is None):
                                                    self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                    self.imposition_mtu_drop.parent = self
                                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                return self.imposition_mtu_drop

                                            if (child_yang_name == "imposition-stat"):
                                                if (self.imposition_stat is None):
                                                    self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                    self.imposition_stat.parent = self
                                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                                return self.imposition_stat

                                            if (child_yang_name == "impostion-tail-drop"):
                                                if (self.impostion_tail_drop is None):
                                                    self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                    self.impostion_tail_drop.parent = self
                                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                return self.impostion_tail_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "l2fsbi-drop"):
                                                if (self.l2fsbi_drop is None):
                                                    self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                    self.l2fsbi_drop.parent = self
                                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                return self.l2fsbi_drop

                                            if (child_yang_name == "multicast"):
                                                if (self.multicast is None):
                                                    self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                    self.multicast.parent = self
                                                    self._children_name_map["multicast"] = "multicast"
                                                return self.multicast

                                            if (child_yang_name == "unknown-unicast"):
                                                if (self.unknown_unicast is None):
                                                    self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                    self.unknown_unicast.parent = self
                                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                return self.unknown_unicast

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            self._children_yang_names.add("broadcast-drop")

                                            self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                            self._children_yang_names.add("dai-drop")

                                            self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            self._children_yang_names.add("disposition-mtu-drop")

                                            self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            self._children_yang_names.add("disposition-oo-o-drops")

                                            self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            self._children_yang_names.add("disposition-p2mp-stats")

                                            self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                            self._children_yang_names.add("disposition-stat")

                                            self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            self._children_yang_names.add("disposition-tail-drop")

                                            self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            self._children_yang_names.add("ipsg-drop")

                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._children_yang_names.add("mac-move")

                                            self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                            self._children_yang_names.add("multicast-drop")

                                            self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                            self._children_yang_names.add("received-drops")

                                            self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                            self._children_yang_names.add("unicast-drop")


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "received-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dai-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipsg-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-oo-o-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionP2MpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-p2mp-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mac-move" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.mac_move is not None and self.mac_move.has_data()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                (self.received_drops is not None and self.received_drops.has_data()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.mac_move is not None and self.mac_move.has_operation()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                (self.received_drops is not None and self.received_drops.has_operation()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dispostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast-drop"):
                                                if (self.broadcast_drop is None):
                                                    self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                    self.broadcast_drop.parent = self
                                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                return self.broadcast_drop

                                            if (child_yang_name == "dai-drop"):
                                                if (self.dai_drop is None):
                                                    self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                    self.dai_drop.parent = self
                                                    self._children_name_map["dai_drop"] = "dai-drop"
                                                return self.dai_drop

                                            if (child_yang_name == "disposition-mtu-drop"):
                                                if (self.disposition_mtu_drop is None):
                                                    self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                    self.disposition_mtu_drop.parent = self
                                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                return self.disposition_mtu_drop

                                            if (child_yang_name == "disposition-oo-o-drops"):
                                                if (self.disposition_oo_o_drops is None):
                                                    self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                    self.disposition_oo_o_drops.parent = self
                                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                return self.disposition_oo_o_drops

                                            if (child_yang_name == "disposition-p2mp-stats"):
                                                if (self.disposition_p2mp_stats is None):
                                                    self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                    self.disposition_p2mp_stats.parent = self
                                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                return self.disposition_p2mp_stats

                                            if (child_yang_name == "disposition-stat"):
                                                if (self.disposition_stat is None):
                                                    self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                    self.disposition_stat.parent = self
                                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                                return self.disposition_stat

                                            if (child_yang_name == "disposition-tail-drop"):
                                                if (self.disposition_tail_drop is None):
                                                    self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                    self.disposition_tail_drop.parent = self
                                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                return self.disposition_tail_drop

                                            if (child_yang_name == "ipsg-drop"):
                                                if (self.ipsg_drop is None):
                                                    self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                    self.ipsg_drop.parent = self
                                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                return self.ipsg_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "mac-move"):
                                                if (self.mac_move is None):
                                                    self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                    self.mac_move.parent = self
                                                    self._children_name_map["mac_move"] = "mac-move"
                                                return self.mac_move

                                            if (child_yang_name == "multicast-drop"):
                                                if (self.multicast_drop is None):
                                                    self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                    self.multicast_drop.parent = self
                                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                                return self.multicast_drop

                                            if (child_yang_name == "received-drops"):
                                                if (self.received_drops is None):
                                                    self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                    self.received_drops.parent = self
                                                    self._children_name_map["received_drops"] = "received-drops"
                                                return self.received_drops

                                            if (child_yang_name == "unicast-drop"):
                                                if (self.unicast_drop is None):
                                                    self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                    self.unicast_drop.parent = self
                                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                                return self.unicast_drop

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"

                                            self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                            self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                            self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                            self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bypassed_inbound_sequence_packet",
                                                            "bypassed_out_sequence_packet",
                                                            "sequence_number_expected",
                                                            "sequence_number_sent") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bypassed_inbound_sequence_packet.is_set or
                                                self.bypassed_out_sequence_packet.is_set or
                                                self.sequence_number_expected.is_set or
                                                self.sequence_number_sent.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                self.sequence_number_expected.yfilter != YFilter.not_set or
                                                self.sequence_number_sent.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sequence-number" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                            if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                            if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                            if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bypassed-inbound-sequence-packet"):
                                                self.bypassed_inbound_sequence_packet = value
                                                self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bypassed-out-sequence-packet"):
                                                self.bypassed_out_sequence_packet = value
                                                self.bypassed_out_sequence_packet.value_namespace = name_space
                                                self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-expected"):
                                                self.sequence_number_expected = value
                                                self.sequence_number_expected.value_namespace = name_space
                                                self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-sent"):
                                                self.sequence_number_sent = value
                                                self.sequence_number_sent.value_namespace = name_space
                                                self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                            (self.sequence_number is not None and self.sequence_number.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                            (self.sequence_number is not None and self.sequence_number.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "statistics" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dispostion-stats"):
                                            if (self.dispostion_stats is None):
                                                self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                                self.dispostion_stats.parent = self
                                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            return self.dispostion_stats

                                        if (child_yang_name == "impostion-stats"):
                                            if (self.impostion_stats is None):
                                                self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                                self.impostion_stats.parent = self
                                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                            return self.impostion_stats

                                        if (child_yang_name == "sequence-number"):
                                            if (self.sequence_number is None):
                                                self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                                self.sequence_number.parent = self
                                                self._children_name_map["sequence_number"] = "sequence-number"
                                            return self.sequence_number

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class P2MpPw(Entity):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__init__()

                                        self.yang_name = "p2mp-pw"
                                        self.yang_parent_name = "pseudowire"

                                        self.local_available = YLeaf(YType.boolean, "local-available")

                                        self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                        self.local_flags = YLeaf(YType.uint8, "local-flags")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                        self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                        self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                        self.remote_available = YLeaf(YType.boolean, "remote-available")

                                        self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                        self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                        self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                        self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_available",
                                                        "local_extended_tunnel_id",
                                                        "local_flags",
                                                        "local_label",
                                                        "local_p2mp_id",
                                                        "local_ptree_type",
                                                        "local_tunnel_id",
                                                        "remote_available",
                                                        "remote_extended_tunnel_id",
                                                        "remote_flags",
                                                        "remote_label",
                                                        "remote_p2mp_id",
                                                        "remote_ptree_type",
                                                        "remote_tunnel_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_available.is_set or
                                            self.local_extended_tunnel_id.is_set or
                                            self.local_flags.is_set or
                                            self.local_label.is_set or
                                            self.local_p2mp_id.is_set or
                                            self.local_ptree_type.is_set or
                                            self.local_tunnel_id.is_set or
                                            self.remote_available.is_set or
                                            self.remote_extended_tunnel_id.is_set or
                                            self.remote_flags.is_set or
                                            self.remote_label.is_set or
                                            self.remote_p2mp_id.is_set or
                                            self.remote_ptree_type.is_set or
                                            self.remote_tunnel_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_available.yfilter != YFilter.not_set or
                                            self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                            self.local_flags.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_p2mp_id.yfilter != YFilter.not_set or
                                            self.local_ptree_type.yfilter != YFilter.not_set or
                                            self.local_tunnel_id.yfilter != YFilter.not_set or
                                            self.remote_available.yfilter != YFilter.not_set or
                                            self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                            self.remote_flags.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_p2mp_id.yfilter != YFilter.not_set or
                                            self.remote_ptree_type.yfilter != YFilter.not_set or
                                            self.remote_tunnel_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "p2mp-pw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_available.get_name_leafdata())
                                        if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                        if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_flags.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                        if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                        if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                        if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_available.get_name_leafdata())
                                        if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                        if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                        if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                        if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-available"):
                                            self.local_available = value
                                            self.local_available.value_namespace = name_space
                                            self.local_available.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-extended-tunnel-id"):
                                            self.local_extended_tunnel_id = value
                                            self.local_extended_tunnel_id.value_namespace = name_space
                                            self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-flags"):
                                            self.local_flags = value
                                            self.local_flags.value_namespace = name_space
                                            self.local_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-p2mp-id"):
                                            self.local_p2mp_id = value
                                            self.local_p2mp_id.value_namespace = name_space
                                            self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ptree-type"):
                                            self.local_ptree_type = value
                                            self.local_ptree_type.value_namespace = name_space
                                            self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-tunnel-id"):
                                            self.local_tunnel_id = value
                                            self.local_tunnel_id.value_namespace = name_space
                                            self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-available"):
                                            self.remote_available = value
                                            self.remote_available.value_namespace = name_space
                                            self.remote_available.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-extended-tunnel-id"):
                                            self.remote_extended_tunnel_id = value
                                            self.remote_extended_tunnel_id.value_namespace = name_space
                                            self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-flags"):
                                            self.remote_flags = value
                                            self.remote_flags.value_namespace = name_space
                                            self.remote_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-p2mp-id"):
                                            self.remote_p2mp_id = value
                                            self.remote_p2mp_id.value_namespace = name_space
                                            self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ptree-type"):
                                            self.remote_ptree_type = value
                                            self.remote_ptree_type.value_namespace = name_space
                                            self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-tunnel-id"):
                                            self.remote_tunnel_id = value
                                            self.remote_tunnel_id.value_namespace = name_space
                                            self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.ad_method.is_set or
                                        self.ad_remote_down.is_set or
                                        self.admited_bw.is_set or
                                        self.auto_discovery.is_set or
                                        self.backup_active.is_set or
                                        self.backup_force_active.is_set or
                                        self.backup_pw.is_set or
                                        self.bitrate_mismatched.is_set or
                                        self.bridge_pw_type_mismatch.is_set or
                                        self.cas_mismatched.is_set or
                                        self.diff_ts_mismatched.is_set or
                                        self.disable_delay.is_set or
                                        self.disable_never.is_set or
                                        self.evpn_src_acid.is_set or
                                        self.fe_ctype.is_set or
                                        self.forward_class.is_set or
                                        self.freq_mismatched.is_set or
                                        self.illegal_control_word.is_set or
                                        self.imposed_vlan_id.is_set or
                                        self.interworking.is_set or
                                        self.ipv6_local_source_address.is_set or
                                        self.is_evpnvpws_type.is_set or
                                        self.is_flow_label_static.is_set or
                                        self.is_multi_segment_pseudowire.is_set or
                                        self.is_partially_programmed.is_set or
                                        self.is_pwr_type.is_set or
                                        self.is_vfi.is_set or
                                        self.last_time_status_changed.is_set or
                                        self.last_time_status_down.is_set or
                                        self.ldp_label_advertise_failed.is_set or
                                        self.load_balance.is_set or
                                        self.local_control_word.is_set or
                                        self.local_label_failed.is_set or
                                        self.local_pseudo_wire_type.is_set or
                                        self.local_source_address.is_set or
                                        self.mac_limit_oper_down.is_set or
                                        self.mtu_mismatched.is_set or
                                        self.not_supported_qinq.is_set or
                                        self.num_ma_cwithdraw_msg_received.is_set or
                                        self.number_ma_cwithdraw_message_sent.is_set or
                                        self.out_of_memory_state.is_set or
                                        self.payload_bytes_mismatched.is_set or
                                        self.payload_type_mismatched.is_set or
                                        self.preferred_path_disable_fallback.is_set or
                                        self.primary_peer_id.is_set or
                                        self.primary_pseudo_wire_id.is_set or
                                        self.primary_pw.is_set or
                                        self.protocol.is_set or
                                        self.pseudo_wire_id.is_set or
                                        self.pseudo_wire_state.is_set or
                                        self.pseudo_wire_type_mismatched.is_set or
                                        self.pw_class_name.is_set or
                                        self.pw_flow_label_code17_disabled.is_set or
                                        self.pw_flow_label_type.is_set or
                                        self.pw_flow_label_type_cfg.is_set or
                                        self.pw_redundancy_initial_delay.is_set or
                                        self.pw_redundancy_one_way.is_set or
                                        self.pw_status_use.is_set or
                                        self.pwlsd_rewrite_failed.is_set or
                                        self.remote_control_word.is_set or
                                        self.remote_label_failed.is_set or
                                        self.remote_pseudo_wire_type.is_set or
                                        self.required_bw.is_set or
                                        self.resync_enabled.is_set or
                                        self.resync_threshold.is_set or
                                        self.rtp_mismatched.is_set or
                                        self.sequencing_type.is_set or
                                        self.shutdown.is_set or
                                        self.sig_pkts_mismatched.is_set or
                                        self.ssrc_mismatched.is_set or
                                        self.state.is_set or
                                        self.table_policy_name.is_set or
                                        self.tag_rewrite.is_set or
                                        self.time_created.is_set or
                                        self.time_elapsed_creation.is_set or
                                        self.time_elapsed_status_changed.is_set or
                                        self.time_elapsed_status_down.is_set or
                                        self.transport_lsp_down.is_set or
                                        self.xconnect_id.is_set or
                                        (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                        (self.local_interface is not None and self.local_interface.has_data()) or
                                        (self.local_signalling is not None and self.local_signalling.has_data()) or
                                        (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                        (self.peer_id is not None and self.peer_id.has_data()) or
                                        (self.preferred_path is not None and self.preferred_path.has_data()) or
                                        (self.remote_interface is not None and self.remote_interface.has_data()) or
                                        (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                        (self.statistics is not None and self.statistics.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ad_method.yfilter != YFilter.not_set or
                                        self.ad_remote_down.yfilter != YFilter.not_set or
                                        self.admited_bw.yfilter != YFilter.not_set or
                                        self.auto_discovery.yfilter != YFilter.not_set or
                                        self.backup_active.yfilter != YFilter.not_set or
                                        self.backup_force_active.yfilter != YFilter.not_set or
                                        self.backup_pw.yfilter != YFilter.not_set or
                                        self.bitrate_mismatched.yfilter != YFilter.not_set or
                                        self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                        self.cas_mismatched.yfilter != YFilter.not_set or
                                        self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                        self.disable_delay.yfilter != YFilter.not_set or
                                        self.disable_never.yfilter != YFilter.not_set or
                                        self.evpn_src_acid.yfilter != YFilter.not_set or
                                        self.fe_ctype.yfilter != YFilter.not_set or
                                        self.forward_class.yfilter != YFilter.not_set or
                                        self.freq_mismatched.yfilter != YFilter.not_set or
                                        self.illegal_control_word.yfilter != YFilter.not_set or
                                        self.imposed_vlan_id.yfilter != YFilter.not_set or
                                        self.interworking.yfilter != YFilter.not_set or
                                        self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                        self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                        self.is_flow_label_static.yfilter != YFilter.not_set or
                                        self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                        self.is_partially_programmed.yfilter != YFilter.not_set or
                                        self.is_pwr_type.yfilter != YFilter.not_set or
                                        self.is_vfi.yfilter != YFilter.not_set or
                                        self.last_time_status_changed.yfilter != YFilter.not_set or
                                        self.last_time_status_down.yfilter != YFilter.not_set or
                                        self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                        self.load_balance.yfilter != YFilter.not_set or
                                        self.local_control_word.yfilter != YFilter.not_set or
                                        self.local_label_failed.yfilter != YFilter.not_set or
                                        self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                        self.local_source_address.yfilter != YFilter.not_set or
                                        self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                        self.mtu_mismatched.yfilter != YFilter.not_set or
                                        self.not_supported_qinq.yfilter != YFilter.not_set or
                                        self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                        self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                        self.out_of_memory_state.yfilter != YFilter.not_set or
                                        self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                        self.payload_type_mismatched.yfilter != YFilter.not_set or
                                        self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                        self.primary_peer_id.yfilter != YFilter.not_set or
                                        self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.primary_pw.yfilter != YFilter.not_set or
                                        self.protocol.yfilter != YFilter.not_set or
                                        self.pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.pseudo_wire_state.yfilter != YFilter.not_set or
                                        self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                        self.pw_class_name.yfilter != YFilter.not_set or
                                        self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                        self.pw_flow_label_type.yfilter != YFilter.not_set or
                                        self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                        self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                        self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                        self.pw_status_use.yfilter != YFilter.not_set or
                                        self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.remote_control_word.yfilter != YFilter.not_set or
                                        self.remote_label_failed.yfilter != YFilter.not_set or
                                        self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                        self.required_bw.yfilter != YFilter.not_set or
                                        self.resync_enabled.yfilter != YFilter.not_set or
                                        self.resync_threshold.yfilter != YFilter.not_set or
                                        self.rtp_mismatched.yfilter != YFilter.not_set or
                                        self.sequencing_type.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                        self.ssrc_mismatched.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.table_policy_name.yfilter != YFilter.not_set or
                                        self.tag_rewrite.yfilter != YFilter.not_set or
                                        self.time_created.yfilter != YFilter.not_set or
                                        self.time_elapsed_creation.yfilter != YFilter.not_set or
                                        self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                        self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                        self.transport_lsp_down.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                        (self.local_interface is not None and self.local_interface.has_operation()) or
                                        (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                        (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                        (self.peer_id is not None and self.peer_id.has_operation()) or
                                        (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                        (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                        (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                        (self.statistics is not None and self.statistics.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_method.get_name_leafdata())
                                    if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                    if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                    if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                    if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_active.get_name_leafdata())
                                    if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                    if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                    if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                    if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                    if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                    if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                    if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                    if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_never.get_name_leafdata())
                                    if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                    if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                    if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.forward_class.get_name_leafdata())
                                    if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                    if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                    if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                    if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interworking.get_name_leafdata())
                                    if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                    if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                    if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                    if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                    if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                    if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                    if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                    if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                    if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                    if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                    if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.load_balance.get_name_leafdata())
                                    if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                    if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                    if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                    if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                    if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                    if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                    if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                    if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                    if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                    if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                    if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                    if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                    if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                    if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                    if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                    if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol.get_name_leafdata())
                                    if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                    if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                    if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                    if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                    if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                    if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                    if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                    if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                    if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                    if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                    if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                    if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                    if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                    if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                    if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.required_bw.get_name_leafdata())
                                    if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                    if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                    if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                    if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                    if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                    if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                    if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_created.get_name_leafdata())
                                    if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                    if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                    if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                    if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "encapsulation-info"):
                                        if (self.encapsulation_info is None):
                                            self.encapsulation_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                            self.encapsulation_info.parent = self
                                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                        return self.encapsulation_info

                                    if (child_yang_name == "local-interface"):
                                        if (self.local_interface is None):
                                            self.local_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                            self.local_interface.parent = self
                                            self._children_name_map["local_interface"] = "local-interface"
                                        return self.local_interface

                                    if (child_yang_name == "local-signalling"):
                                        if (self.local_signalling is None):
                                            self.local_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                            self.local_signalling.parent = self
                                            self._children_name_map["local_signalling"] = "local-signalling"
                                        return self.local_signalling

                                    if (child_yang_name == "p2mp-pw"):
                                        if (self.p2mp_pw is None):
                                            self.p2mp_pw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                            self.p2mp_pw.parent = self
                                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                        return self.p2mp_pw

                                    if (child_yang_name == "peer-id"):
                                        if (self.peer_id is None):
                                            self.peer_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                            self.peer_id.parent = self
                                            self._children_name_map["peer_id"] = "peer-id"
                                        return self.peer_id

                                    if (child_yang_name == "preferred-path"):
                                        if (self.preferred_path is None):
                                            self.preferred_path = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                            self.preferred_path.parent = self
                                            self._children_name_map["preferred_path"] = "preferred-path"
                                        return self.preferred_path

                                    if (child_yang_name == "remote-interface"):
                                        if (self.remote_interface is None):
                                            self.remote_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                            self.remote_interface.parent = self
                                            self._children_name_map["remote_interface"] = "remote-interface"
                                        return self.remote_interface

                                    if (child_yang_name == "remote-signalling"):
                                        if (self.remote_signalling is None):
                                            self.remote_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                            self.remote_signalling.parent = self
                                            self._children_name_map["remote_signalling"] = "remote-signalling"
                                        return self.remote_signalling

                                    if (child_yang_name == "statistics"):
                                        if (self.statistics is None):
                                            self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                            self.statistics.parent = self
                                            self._children_name_map["statistics"] = "statistics"
                                        return self.statistics

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ad-method"):
                                        self.ad_method = value
                                        self.ad_method.value_namespace = name_space
                                        self.ad_method.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ad-remote-down"):
                                        self.ad_remote_down = value
                                        self.ad_remote_down.value_namespace = name_space
                                        self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "admited-bw"):
                                        self.admited_bw = value
                                        self.admited_bw.value_namespace = name_space
                                        self.admited_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "auto-discovery"):
                                        self.auto_discovery = value
                                        self.auto_discovery.value_namespace = name_space
                                        self.auto_discovery.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-active"):
                                        self.backup_active = value
                                        self.backup_active.value_namespace = name_space
                                        self.backup_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-force-active"):
                                        self.backup_force_active = value
                                        self.backup_force_active.value_namespace = name_space
                                        self.backup_force_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pw"):
                                        self.backup_pw = value
                                        self.backup_pw.value_namespace = name_space
                                        self.backup_pw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bitrate-mismatched"):
                                        self.bitrate_mismatched = value
                                        self.bitrate_mismatched.value_namespace = name_space
                                        self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bridge-pw-type-mismatch"):
                                        self.bridge_pw_type_mismatch = value
                                        self.bridge_pw_type_mismatch.value_namespace = name_space
                                        self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cas-mismatched"):
                                        self.cas_mismatched = value
                                        self.cas_mismatched.value_namespace = name_space
                                        self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "diff-ts-mismatched"):
                                        self.diff_ts_mismatched = value
                                        self.diff_ts_mismatched.value_namespace = name_space
                                        self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-delay"):
                                        self.disable_delay = value
                                        self.disable_delay.value_namespace = name_space
                                        self.disable_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-never"):
                                        self.disable_never = value
                                        self.disable_never.value_namespace = name_space
                                        self.disable_never.value_namespace_prefix = name_space_prefix
                                    if(value_path == "evpn-src-acid"):
                                        self.evpn_src_acid = value
                                        self.evpn_src_acid.value_namespace = name_space
                                        self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fe-ctype"):
                                        self.fe_ctype = value
                                        self.fe_ctype.value_namespace = name_space
                                        self.fe_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "forward-class"):
                                        self.forward_class = value
                                        self.forward_class.value_namespace = name_space
                                        self.forward_class.value_namespace_prefix = name_space_prefix
                                    if(value_path == "freq-mismatched"):
                                        self.freq_mismatched = value
                                        self.freq_mismatched.value_namespace = name_space
                                        self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "illegal-control-word"):
                                        self.illegal_control_word = value
                                        self.illegal_control_word.value_namespace = name_space
                                        self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "imposed-vlan-id"):
                                        self.imposed_vlan_id = value
                                        self.imposed_vlan_id.value_namespace = name_space
                                        self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interworking"):
                                        self.interworking = value
                                        self.interworking.value_namespace = name_space
                                        self.interworking.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-local-source-address"):
                                        self.ipv6_local_source_address = value
                                        self.ipv6_local_source_address.value_namespace = name_space
                                        self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-evpnvpws-type"):
                                        self.is_evpnvpws_type = value
                                        self.is_evpnvpws_type.value_namespace = name_space
                                        self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-flow-label-static"):
                                        self.is_flow_label_static = value
                                        self.is_flow_label_static.value_namespace = name_space
                                        self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-multi-segment-pseudowire"):
                                        self.is_multi_segment_pseudowire = value
                                        self.is_multi_segment_pseudowire.value_namespace = name_space
                                        self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-partially-programmed"):
                                        self.is_partially_programmed = value
                                        self.is_partially_programmed.value_namespace = name_space
                                        self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-pwr-type"):
                                        self.is_pwr_type = value
                                        self.is_pwr_type.value_namespace = name_space
                                        self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-vfi"):
                                        self.is_vfi = value
                                        self.is_vfi.value_namespace = name_space
                                        self.is_vfi.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-time-status-changed"):
                                        self.last_time_status_changed = value
                                        self.last_time_status_changed.value_namespace = name_space
                                        self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-time-status-down"):
                                        self.last_time_status_down = value
                                        self.last_time_status_down.value_namespace = name_space
                                        self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertise-failed"):
                                        self.ldp_label_advertise_failed = value
                                        self.ldp_label_advertise_failed.value_namespace = name_space
                                        self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "load-balance"):
                                        self.load_balance = value
                                        self.load_balance.value_namespace = name_space
                                        self.load_balance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-control-word"):
                                        self.local_control_word = value
                                        self.local_control_word.value_namespace = name_space
                                        self.local_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label-failed"):
                                        self.local_label_failed = value
                                        self.local_label_failed.value_namespace = name_space
                                        self.local_label_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-pseudo-wire-type"):
                                        self.local_pseudo_wire_type = value
                                        self.local_pseudo_wire_type.value_namespace = name_space
                                        self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-source-address"):
                                        self.local_source_address = value
                                        self.local_source_address.value_namespace = name_space
                                        self.local_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-oper-down"):
                                        self.mac_limit_oper_down = value
                                        self.mac_limit_oper_down.value_namespace = name_space
                                        self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-mismatched"):
                                        self.mtu_mismatched = value
                                        self.mtu_mismatched.value_namespace = name_space
                                        self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "not-supported-qinq"):
                                        self.not_supported_qinq = value
                                        self.not_supported_qinq.value_namespace = name_space
                                        self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                    if(value_path == "num-ma-cwithdraw-msg-received"):
                                        self.num_ma_cwithdraw_msg_received = value
                                        self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                        self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                    if(value_path == "number-ma-cwithdraw-message-sent"):
                                        self.number_ma_cwithdraw_message_sent = value
                                        self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                        self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                    if(value_path == "out-of-memory-state"):
                                        self.out_of_memory_state = value
                                        self.out_of_memory_state.value_namespace = name_space
                                        self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes-mismatched"):
                                        self.payload_bytes_mismatched = value
                                        self.payload_bytes_mismatched.value_namespace = name_space
                                        self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-type-mismatched"):
                                        self.payload_type_mismatched = value
                                        self.payload_type_mismatched.value_namespace = name_space
                                        self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "preferred-path-disable-fallback"):
                                        self.preferred_path_disable_fallback = value
                                        self.preferred_path_disable_fallback.value_namespace = name_space
                                        self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-peer-id"):
                                        self.primary_peer_id = value
                                        self.primary_peer_id.value_namespace = name_space
                                        self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-pseudo-wire-id"):
                                        self.primary_pseudo_wire_id = value
                                        self.primary_pseudo_wire_id.value_namespace = name_space
                                        self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-pw"):
                                        self.primary_pw = value
                                        self.primary_pw.value_namespace = name_space
                                        self.primary_pw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol"):
                                        self.protocol = value
                                        self.protocol.value_namespace = name_space
                                        self.protocol.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-id"):
                                        self.pseudo_wire_id = value
                                        self.pseudo_wire_id.value_namespace = name_space
                                        self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-state"):
                                        self.pseudo_wire_state = value
                                        self.pseudo_wire_state.value_namespace = name_space
                                        self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-type-mismatched"):
                                        self.pseudo_wire_type_mismatched = value
                                        self.pseudo_wire_type_mismatched.value_namespace = name_space
                                        self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-class-name"):
                                        self.pw_class_name = value
                                        self.pw_class_name.value_namespace = name_space
                                        self.pw_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-code17-disabled"):
                                        self.pw_flow_label_code17_disabled = value
                                        self.pw_flow_label_code17_disabled.value_namespace = name_space
                                        self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-type"):
                                        self.pw_flow_label_type = value
                                        self.pw_flow_label_type.value_namespace = name_space
                                        self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-type-cfg"):
                                        self.pw_flow_label_type_cfg = value
                                        self.pw_flow_label_type_cfg.value_namespace = name_space
                                        self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-redundancy-initial-delay"):
                                        self.pw_redundancy_initial_delay = value
                                        self.pw_redundancy_initial_delay.value_namespace = name_space
                                        self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-redundancy-one-way"):
                                        self.pw_redundancy_one_way = value
                                        self.pw_redundancy_one_way.value_namespace = name_space
                                        self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-status-use"):
                                        self.pw_status_use = value
                                        self.pw_status_use.value_namespace = name_space
                                        self.pw_status_use.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pwlsd-rewrite-failed"):
                                        self.pwlsd_rewrite_failed = value
                                        self.pwlsd_rewrite_failed.value_namespace = name_space
                                        self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-control-word"):
                                        self.remote_control_word = value
                                        self.remote_control_word.value_namespace = name_space
                                        self.remote_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label-failed"):
                                        self.remote_label_failed = value
                                        self.remote_label_failed.value_namespace = name_space
                                        self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-pseudo-wire-type"):
                                        self.remote_pseudo_wire_type = value
                                        self.remote_pseudo_wire_type.value_namespace = name_space
                                        self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "required-bw"):
                                        self.required_bw = value
                                        self.required_bw.value_namespace = name_space
                                        self.required_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resync-enabled"):
                                        self.resync_enabled = value
                                        self.resync_enabled.value_namespace = name_space
                                        self.resync_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resync-threshold"):
                                        self.resync_threshold = value
                                        self.resync_threshold.value_namespace = name_space
                                        self.resync_threshold.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rtp-mismatched"):
                                        self.rtp_mismatched = value
                                        self.rtp_mismatched.value_namespace = name_space
                                        self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequencing-type"):
                                        self.sequencing_type = value
                                        self.sequencing_type.value_namespace = name_space
                                        self.sequencing_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sig-pkts-mismatched"):
                                        self.sig_pkts_mismatched = value
                                        self.sig_pkts_mismatched.value_namespace = name_space
                                        self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ssrc-mismatched"):
                                        self.ssrc_mismatched = value
                                        self.ssrc_mismatched.value_namespace = name_space
                                        self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "table-policy-name"):
                                        self.table_policy_name = value
                                        self.table_policy_name.value_namespace = name_space
                                        self.table_policy_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tag-rewrite"):
                                        self.tag_rewrite = value
                                        self.tag_rewrite.value_namespace = name_space
                                        self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-created"):
                                        self.time_created = value
                                        self.time_created.value_namespace = name_space
                                        self.time_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-creation"):
                                        self.time_elapsed_creation = value
                                        self.time_elapsed_creation.value_namespace = name_space
                                        self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-status-changed"):
                                        self.time_elapsed_status_changed = value
                                        self.time_elapsed_status_changed.value_namespace = name_space
                                        self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-status-down"):
                                        self.time_elapsed_status_down = value
                                        self.time_elapsed_status_down.value_namespace = name_space
                                        self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transport-lsp-down"):
                                        self.transport_lsp_down = value
                                        self.transport_lsp_down.value_namespace = name_space
                                        self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-pw"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/base/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-pw"

                                    self.address = YLeaf(YType.str, "address")

                                    self.bmac = YLeaf(YType.str, "bmac")

                                    self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "bmac",
                                                    "next_hop_ip") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.bmac.is_set or
                                        self.next_hop_ip.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.bmac.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "static-mac" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bmac.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bmac"):
                                        self.bmac = value
                                        self.bmac.value_namespace = name_space
                                        self.bmac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.static_mac:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.is_access.is_set or
                                    self.neighbor.is_set or
                                    self.pseudowire_id.is_set or
                                    self.pw_type.is_set or
                                    self.ve_id_vpls_id_0_3.is_set or
                                    self.vpls_id_4_7.is_set or
                                    (self.pseudowire is not None and self.pseudowire.has_data()) or
                                    (self.security_parameters is not None and self.security_parameters.has_data()))

                            def has_operation(self):
                                for c in self.static_mac:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_access.yfilter != YFilter.not_set or
                                    self.neighbor.yfilter != YFilter.not_set or
                                    self.pseudowire_id.yfilter != YFilter.not_set or
                                    self.pw_type.yfilter != YFilter.not_set or
                                    self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set or
                                    self.vpls_id_4_7.yfilter != YFilter.not_set or
                                    (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bridge-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_access.get_name_leafdata())
                                if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor.get_name_leafdata())
                                if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudowire_id.get_name_leafdata())
                                if (self.pw_type.is_set or self.pw_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_type.get_name_leafdata())
                                if (self.ve_id_vpls_id_0_3.is_set or self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_id_vpls_id_0_3.get_name_leafdata())
                                if (self.vpls_id_4_7.is_set or self.vpls_id_4_7.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_4_7.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "pseudowire"):
                                    if (self.pseudowire is None):
                                        self.pseudowire = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                        self.pseudowire.parent = self
                                        self._children_name_map["pseudowire"] = "pseudowire"
                                    return self.pseudowire

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                if (child_yang_name == "static-mac"):
                                    for c in self.static_mac:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.static_mac.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id" or name == "pw-type" or name == "ve-id-vpls-id-0-3" or name == "vpls-id-4-7"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-access"):
                                    self.is_access = value
                                    self.is_access.value_namespace = name_space
                                    self.is_access.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor"):
                                    self.neighbor = value
                                    self.neighbor.value_namespace = name_space
                                    self.neighbor.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudowire-id"):
                                    self.pseudowire_id = value
                                    self.pseudowire_id.value_namespace = name_space
                                    self.pseudowire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-type"):
                                    self.pw_type = value
                                    self.pw_type.value_namespace = name_space
                                    self.pw_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-id-vpls-id-0-3"):
                                    self.ve_id_vpls_id_0_3 = value
                                    self.ve_id_vpls_id_0_3.value_namespace = name_space
                                    self.ve_id_vpls_id_0_3.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpls-id-4-7"):
                                    self.vpls_id_4_7 = value
                                    self.vpls_id_4_7.value_namespace = name_space
                                    self.vpls_id_4_7.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bridge_pw:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bridge_pw:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-pws" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bridge-pw"):
                                for c in self.bridge_pw:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bridge_pw.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-pw"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (self.bridge_pws is not None and self.bridge_pws.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bridge_pws is not None and self.bridge_pws.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-core-vfi-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-pws"):
                            if (self.bridge_pws is None):
                                self.bridge_pws = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                                self.bridge_pws.parent = self
                                self._children_name_map["bridge_pws"] = "bridge-pws"
                            return self.bridge_pws

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-pws"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BridgeAcs(Entity):
                    """
                    VPLS Bridge Domain Attachment Circuit Table
                    
                    .. attribute:: bridge_ac
                    
                    	VPLS Bridge Domain Attachment Circuit
                    	**type**\: list of    :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs, self).__init__()

                        self.yang_name = "bridge-acs"
                        self.yang_parent_name = "bridge-domain"

                        self.bridge_ac = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs, self).__setattr__(name, value)


                    class BridgeAc(Entity):
                        """
                        VPLS Bridge Domain Attachment Circuit
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                        
                        .. attribute:: bvi_mac_index
                        
                        	MyMac Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bvimac
                        
                        	BVI MAC addresses
                        	**type**\: list of    :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__init__()

                            self.yang_name = "bridge-ac"
                            self.yang_parent_name = "bridge-acs"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.bvi_mac_index = YLeaf(YType.uint16, "bvi-mac-index")

                            self.attachment_circuit = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            self._children_yang_names.add("attachment-circuit")

                            self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                            self._children_yang_names.add("security-parameters")

                            self.bvimac = YList(self)
                            self.static_mac = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "bvi_mac_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__setattr__(name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "bridge-ac"

                                self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                                self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                                self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                                self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                                self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                                self.msti = YLeaf(YType.str, "msti")

                                self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.node_id = YLeaf(YType.str, "node-id")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._children_yang_names.add("interface")

                                self.l2vpn_protection = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._children_yang_names.add("l2vpn-protection")

                                self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bvi_mac_conflict",
                                                "bvi_no_port_up",
                                                "control_word_mismatched",
                                                "encapsulation_error",
                                                "encapsulation_mismatched",
                                                "evpn_internal_label",
                                                "interface_handle",
                                                "internal_ms_ti",
                                                "interworking",
                                                "is_ac_partially_programmed",
                                                "mac_limit_oper_down",
                                                "ms_ti_mismatch",
                                                "msti",
                                                "msti_mismatch_down",
                                                "mtu_mismatched",
                                                "node_id",
                                                "out_of_memory_state",
                                                "redundancy_group_id",
                                                "redundancy_group_state",
                                                "redundancy_object_id",
                                                "state",
                                                "tdm_media_mismatched",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__setattr__(name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class L2VpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.protected_name = YLeaf(YType.str, "protected-name")

                                    self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                    self.protection_name = YLeaf(YType.str, "protection-name")

                                    self.protection_type = YLeaf(YType.enumeration, "protection-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "protected_name",
                                                    "protection_configured",
                                                    "protection_name",
                                                    "protection_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.protected_name.is_set or
                                        self.protection_configured.is_set or
                                        self.protection_name.is_set or
                                        self.protection_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.protected_name.yfilter != YFilter.not_set or
                                        self.protection_configured.yfilter != YFilter.not_set or
                                        self.protection_name.yfilter != YFilter.not_set or
                                        self.protection_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2vpn-protection" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protected_name.get_name_leafdata())
                                    if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                    if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_name.get_name_leafdata())
                                    if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protected-name"):
                                        self.protected_name = value
                                        self.protected_name.value_namespace = name_space
                                        self.protected_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-configured"):
                                        self.protection_configured = value
                                        self.protection_configured.value_namespace = name_space
                                        self.protection_configured.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-name"):
                                        self.protection_name = value
                                        self.protection_name.value_namespace = name_space
                                        self.protection_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-type"):
                                        self.protection_type = value
                                        self.protection_type.value_namespace = name_space
                                        self.protection_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bvi_mac_conflict.is_set or
                                    self.bvi_no_port_up.is_set or
                                    self.control_word_mismatched.is_set or
                                    self.encapsulation_error.is_set or
                                    self.encapsulation_mismatched.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.interface_handle.is_set or
                                    self.internal_ms_ti.is_set or
                                    self.interworking.is_set or
                                    self.is_ac_partially_programmed.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.ms_ti_mismatch.is_set or
                                    self.msti.is_set or
                                    self.msti_mismatch_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.node_id.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_group_state.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.state.is_set or
                                    self.tdm_media_mismatched.is_set or
                                    self.xconnect_id.is_set or
                                    (self.interface is not None and self.interface.has_data()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                    self.bvi_no_port_up.yfilter != YFilter.not_set or
                                    self.control_word_mismatched.yfilter != YFilter.not_set or
                                    self.encapsulation_error.yfilter != YFilter.not_set or
                                    self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.internal_ms_ti.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                    self.msti.yfilter != YFilter.not_set or
                                    self.msti_mismatch_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_group_state.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.interface is not None and self.interface.has_operation()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "attachment-circuit" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                                if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                                if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                                if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                                if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface"):
                                    if (self.interface is None):
                                        self.interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                        self.interface.parent = self
                                        self._children_name_map["interface"] = "interface"
                                    return self.interface

                                if (child_yang_name == "l2vpn-protection"):
                                    if (self.l2vpn_protection is None):
                                        self.l2vpn_protection = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                                        self.l2vpn_protection.parent = self
                                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    return self.l2vpn_protection

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bvi-mac-conflict"):
                                    self.bvi_mac_conflict = value
                                    self.bvi_mac_conflict.value_namespace = name_space
                                    self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-no-port-up"):
                                    self.bvi_no_port_up = value
                                    self.bvi_no_port_up.value_namespace = name_space
                                    self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-word-mismatched"):
                                    self.control_word_mismatched = value
                                    self.control_word_mismatched.value_namespace = name_space
                                    self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-error"):
                                    self.encapsulation_error = value
                                    self.encapsulation_error.value_namespace = name_space
                                    self.encapsulation_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-mismatched"):
                                    self.encapsulation_mismatched = value
                                    self.encapsulation_mismatched.value_namespace = name_space
                                    self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-ms-ti"):
                                    self.internal_ms_ti = value
                                    self.internal_ms_ti.value_namespace = name_space
                                    self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ac-partially-programmed"):
                                    self.is_ac_partially_programmed = value
                                    self.is_ac_partially_programmed.value_namespace = name_space
                                    self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ms-ti-mismatch"):
                                    self.ms_ti_mismatch = value
                                    self.ms_ti_mismatch.value_namespace = name_space
                                    self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti"):
                                    self.msti = value
                                    self.msti.value_namespace = name_space
                                    self.msti.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-mismatch-down"):
                                    self.msti_mismatch_down = value
                                    self.msti_mismatch_down.value_namespace = name_space
                                    self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-state"):
                                    self.redundancy_group_state = value
                                    self.redundancy_group_state.value_namespace = name_space
                                    self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "tdm-media-mismatched"):
                                    self.tdm_media_mismatched = value
                                    self.tdm_media_mismatched.value_namespace = name_space
                                    self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-ac"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dhcpv4_trust",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                    self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                    self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                    self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                    self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                    self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                    self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                    self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                    self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                    self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                    self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                    self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                    self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                    self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                    self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                    self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                    self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                    self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                    self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                    self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                    self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                    self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                    self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                    self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                    self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                    self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                    self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                    self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                    self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                    self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dai_address_validation_mask",
                                                    "dhcpv4_profile_name",
                                                    "dhcpv4_snoop",
                                                    "flood_unknown_unicast_enabled",
                                                    "flood_uu_disabled_mac_limit_action",
                                                    "igm_pv4_disabled",
                                                    "igm_pv4_profile_name",
                                                    "is_dai_addr_validate_destination_mac_enabled",
                                                    "is_dai_addr_validate_ipv4_enabled",
                                                    "is_dai_addr_validate_source_mac_enabled",
                                                    "is_dai_enabled",
                                                    "is_dai_logging_enabled",
                                                    "is_ip_source_guard_enabled",
                                                    "is_ipsg_logging_enabled",
                                                    "is_mac_secure_accept_shutdown_enabled",
                                                    "is_mac_secure_enabled",
                                                    "is_mac_secure_logging_enabled",
                                                    "learn_disabled_mac_limit_action",
                                                    "mac_aging_mode",
                                                    "mac_aging_time",
                                                    "mac_flooding",
                                                    "mac_learning",
                                                    "mac_limit",
                                                    "mac_limit_action",
                                                    "mac_limit_notification",
                                                    "mac_limit_reached",
                                                    "mac_port_down_flush_enabled",
                                                    "mac_secure_action",
                                                    "mld_profile_name",
                                                    "mmrp_flood_optimization",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "split_horizon_group_id",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__setattr__(name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dai_address_validation_mask.is_set or
                                        self.dhcpv4_profile_name.is_set or
                                        self.dhcpv4_snoop.is_set or
                                        self.flood_unknown_unicast_enabled.is_set or
                                        self.flood_uu_disabled_mac_limit_action.is_set or
                                        self.igm_pv4_disabled.is_set or
                                        self.igm_pv4_profile_name.is_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                        self.is_dai_addr_validate_ipv4_enabled.is_set or
                                        self.is_dai_addr_validate_source_mac_enabled.is_set or
                                        self.is_dai_enabled.is_set or
                                        self.is_dai_logging_enabled.is_set or
                                        self.is_ip_source_guard_enabled.is_set or
                                        self.is_ipsg_logging_enabled.is_set or
                                        self.is_mac_secure_accept_shutdown_enabled.is_set or
                                        self.is_mac_secure_enabled.is_set or
                                        self.is_mac_secure_logging_enabled.is_set or
                                        self.learn_disabled_mac_limit_action.is_set or
                                        self.mac_aging_mode.is_set or
                                        self.mac_aging_time.is_set or
                                        self.mac_flooding.is_set or
                                        self.mac_learning.is_set or
                                        self.mac_limit.is_set or
                                        self.mac_limit_action.is_set or
                                        self.mac_limit_notification.is_set or
                                        self.mac_limit_reached.is_set or
                                        self.mac_port_down_flush_enabled.is_set or
                                        self.mac_secure_action.is_set or
                                        self.mld_profile_name.is_set or
                                        self.mmrp_flood_optimization.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.split_horizon_group_id.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                        self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                        self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                        self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                        self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                        self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                        self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                        self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_aging_mode.yfilter != YFilter.not_set or
                                        self.mac_aging_time.yfilter != YFilter.not_set or
                                        self.mac_flooding.yfilter != YFilter.not_set or
                                        self.mac_learning.yfilter != YFilter.not_set or
                                        self.mac_limit.yfilter != YFilter.not_set or
                                        self.mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_limit_notification.yfilter != YFilter.not_set or
                                        self.mac_limit_reached.yfilter != YFilter.not_set or
                                        self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                        self.mac_secure_action.yfilter != YFilter.not_set or
                                        self.mld_profile_name.yfilter != YFilter.not_set or
                                        self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.split_horizon_group_id.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                    if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                    if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                    if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                    if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                    if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                    if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                    if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                    if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                    if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                    if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                    if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                    if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                    if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                    if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                    if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                    if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                    if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                    if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                    if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                    if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                    if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dai-address-validation-mask"):
                                        self.dai_address_validation_mask = value
                                        self.dai_address_validation_mask.value_namespace = name_space
                                        self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-profile-name"):
                                        self.dhcpv4_profile_name = value
                                        self.dhcpv4_profile_name.value_namespace = name_space
                                        self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-snoop"):
                                        self.dhcpv4_snoop = value
                                        self.dhcpv4_snoop.value_namespace = name_space
                                        self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-unknown-unicast-enabled"):
                                        self.flood_unknown_unicast_enabled = value
                                        self.flood_unknown_unicast_enabled.value_namespace = name_space
                                        self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-uu-disabled-mac-limit-action"):
                                        self.flood_uu_disabled_mac_limit_action = value
                                        self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                        self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-disabled"):
                                        self.igm_pv4_disabled = value
                                        self.igm_pv4_disabled.value_namespace = name_space
                                        self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-profile-name"):
                                        self.igm_pv4_profile_name = value
                                        self.igm_pv4_profile_name.value_namespace = name_space
                                        self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                        self.is_dai_addr_validate_destination_mac_enabled = value
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                        self.is_dai_addr_validate_ipv4_enabled = value
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                        self.is_dai_addr_validate_source_mac_enabled = value
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-enabled"):
                                        self.is_dai_enabled = value
                                        self.is_dai_enabled.value_namespace = name_space
                                        self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-logging-enabled"):
                                        self.is_dai_logging_enabled = value
                                        self.is_dai_logging_enabled.value_namespace = name_space
                                        self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ip-source-guard-enabled"):
                                        self.is_ip_source_guard_enabled = value
                                        self.is_ip_source_guard_enabled.value_namespace = name_space
                                        self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ipsg-logging-enabled"):
                                        self.is_ipsg_logging_enabled = value
                                        self.is_ipsg_logging_enabled.value_namespace = name_space
                                        self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                        self.is_mac_secure_accept_shutdown_enabled = value
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-enabled"):
                                        self.is_mac_secure_enabled = value
                                        self.is_mac_secure_enabled.value_namespace = name_space
                                        self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-logging-enabled"):
                                        self.is_mac_secure_logging_enabled = value
                                        self.is_mac_secure_logging_enabled.value_namespace = name_space
                                        self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "learn-disabled-mac-limit-action"):
                                        self.learn_disabled_mac_limit_action = value
                                        self.learn_disabled_mac_limit_action.value_namespace = name_space
                                        self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-mode"):
                                        self.mac_aging_mode = value
                                        self.mac_aging_mode.value_namespace = name_space
                                        self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-time"):
                                        self.mac_aging_time = value
                                        self.mac_aging_time.value_namespace = name_space
                                        self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flooding"):
                                        self.mac_flooding = value
                                        self.mac_flooding.value_namespace = name_space
                                        self.mac_flooding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-learning"):
                                        self.mac_learning = value
                                        self.mac_learning.value_namespace = name_space
                                        self.mac_learning.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit"):
                                        self.mac_limit = value
                                        self.mac_limit.value_namespace = name_space
                                        self.mac_limit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-action"):
                                        self.mac_limit_action = value
                                        self.mac_limit_action.value_namespace = name_space
                                        self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-notification"):
                                        self.mac_limit_notification = value
                                        self.mac_limit_notification.value_namespace = name_space
                                        self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-reached"):
                                        self.mac_limit_reached = value
                                        self.mac_limit_reached.value_namespace = name_space
                                        self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-port-down-flush-enabled"):
                                        self.mac_port_down_flush_enabled = value
                                        self.mac_port_down_flush_enabled.value_namespace = name_space
                                        self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-secure-action"):
                                        self.mac_secure_action = value
                                        self.mac_secure_action.value_namespace = name_space
                                        self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mld-profile-name"):
                                        self.mld_profile_name = value
                                        self.mld_profile_name.value_namespace = name_space
                                        self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mmrp-flood-optimization"):
                                        self.mmrp_flood_optimization = value
                                        self.mmrp_flood_optimization.value_namespace = name_space
                                        self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "split-horizon-group-id"):
                                        self.split_horizon_group_id = value
                                        self.split_horizon_group_id.value_namespace = name_space
                                        self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dhcpv4_trust.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dhcpv4_trust.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-trust"):
                                    self.dhcpv4_trust = value
                                    self.dhcpv4_trust.value_namespace = name_space
                                    self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "bridge-ac"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "static-mac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix


                        class Bvimac(Entity):
                            """
                            BVI MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__init__()

                                self.yang_name = "bvimac"
                                self.yang_parent_name = "bridge-ac"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bvimac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bvimac:
                                if (c.has_data()):
                                    return True
                            for c in self.static_mac:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.bvi_mac_index.is_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                                (self.security_parameters is not None and self.security_parameters.has_data()))

                        def has_operation(self):
                            for c in self.bvimac:
                                if (c.has_operation()):
                                    return True
                            for c in self.static_mac:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.bvi_mac_index.yfilter != YFilter.not_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                                (self.security_parameters is not None and self.security_parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-ac" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-acs/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.bvi_mac_index.is_set or self.bvi_mac_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "attachment-circuit"):
                                if (self.attachment_circuit is None):
                                    self.attachment_circuit = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                                    self.attachment_circuit.parent = self
                                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                return self.attachment_circuit

                            if (child_yang_name == "bvimac"):
                                for c in self.bvimac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bvimac.append(c)
                                return c

                            if (child_yang_name == "security-parameters"):
                                if (self.security_parameters is None):
                                    self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                return self.security_parameters

                            if (child_yang_name == "static-mac"):
                                for c in self.static_mac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.static_mac.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "attachment-circuit" or name == "bvimac" or name == "security-parameters" or name == "static-mac" or name == "interface-name" or name == "bvi-mac-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-mac-index"):
                                self.bvi_mac_index = value
                                self.bvi_mac_index.value_namespace = name_space
                                self.bvi_mac_index.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bridge_ac:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bridge_ac:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-acs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-ac"):
                            for c in self.bridge_ac:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bridge_ac.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-ac"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BridgeAccessPws(Entity):
                    """
                    VPLS Bridge Domain Access Pseudowire Table
                    
                    .. attribute:: bridge_access_pw
                    
                    	VPLS Bridge Domain Access Pseudowire
                    	**type**\: list of    :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__init__()

                        self.yang_name = "bridge-access-pws"
                        self.yang_parent_name = "bridge-domain"

                        self.bridge_access_pw = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__setattr__(name, value)


                    class BridgeAccessPw(Entity):
                        """
                        VPLS Bridge Domain Access Pseudowire
                        
                        .. attribute:: is_access
                        
                        	Is Access PW
                        	**type**\:  bool
                        
                        .. attribute:: neighbor
                        
                        	Neighbor IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                        
                        .. attribute:: pseudowire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__init__()

                            self.yang_name = "bridge-access-pw"
                            self.yang_parent_name = "bridge-access-pws"

                            self.is_access = YLeaf(YType.boolean, "is-access")

                            self.neighbor = YLeaf(YType.str, "neighbor")

                            self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                            self.pseudowire = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                            self.pseudowire.parent = self
                            self._children_name_map["pseudowire"] = "pseudowire"
                            self._children_yang_names.add("pseudowire")

                            self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                            self._children_yang_names.add("security-parameters")

                            self.static_mac = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("is_access",
                                            "neighbor",
                                            "pseudowire_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__setattr__(name, value)


                        class Pseudowire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__init__()

                                self.yang_name = "pseudowire"
                                self.yang_parent_name = "bridge-access-pw"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                self.backup_active = YLeaf(YType.boolean, "backup-active")

                                self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                self.disable_never = YLeaf(YType.boolean, "disable-never")

                                self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                self.local_source_address = YLeaf(YType.str, "local-source-address")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                self.required_bw = YLeaf(YType.uint32, "required-bw")

                                self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                self.time_created = YLeaf(YType.str, "time-created")

                                self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.encapsulation_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                self._children_yang_names.add("encapsulation-info")

                                self.local_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                                self._children_yang_names.add("local-interface")

                                self.local_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                                self._children_yang_names.add("local-signalling")

                                self.p2mp_pw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._children_yang_names.add("p2mp-pw")

                                self.peer_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                                self._children_yang_names.add("peer-id")

                                self.preferred_path = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                                self._children_yang_names.add("preferred-path")

                                self.remote_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                                self._children_yang_names.add("remote-interface")

                                self.remote_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                self._children_yang_names.add("remote-signalling")

                                self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_remote_down",
                                                "admited_bw",
                                                "auto_discovery",
                                                "backup_active",
                                                "backup_force_active",
                                                "backup_pw",
                                                "bitrate_mismatched",
                                                "bridge_pw_type_mismatch",
                                                "cas_mismatched",
                                                "diff_ts_mismatched",
                                                "disable_delay",
                                                "disable_never",
                                                "evpn_src_acid",
                                                "fe_ctype",
                                                "forward_class",
                                                "freq_mismatched",
                                                "illegal_control_word",
                                                "imposed_vlan_id",
                                                "interworking",
                                                "ipv6_local_source_address",
                                                "is_evpnvpws_type",
                                                "is_flow_label_static",
                                                "is_multi_segment_pseudowire",
                                                "is_partially_programmed",
                                                "is_pwr_type",
                                                "is_vfi",
                                                "last_time_status_changed",
                                                "last_time_status_down",
                                                "ldp_label_advertise_failed",
                                                "load_balance",
                                                "local_control_word",
                                                "local_label_failed",
                                                "local_pseudo_wire_type",
                                                "local_source_address",
                                                "mac_limit_oper_down",
                                                "mtu_mismatched",
                                                "not_supported_qinq",
                                                "num_ma_cwithdraw_msg_received",
                                                "number_ma_cwithdraw_message_sent",
                                                "out_of_memory_state",
                                                "payload_bytes_mismatched",
                                                "payload_type_mismatched",
                                                "preferred_path_disable_fallback",
                                                "primary_peer_id",
                                                "primary_pseudo_wire_id",
                                                "primary_pw",
                                                "protocol",
                                                "pseudo_wire_id",
                                                "pseudo_wire_state",
                                                "pseudo_wire_type_mismatched",
                                                "pw_class_name",
                                                "pw_flow_label_code17_disabled",
                                                "pw_flow_label_type",
                                                "pw_flow_label_type_cfg",
                                                "pw_redundancy_initial_delay",
                                                "pw_redundancy_one_way",
                                                "pw_status_use",
                                                "pwlsd_rewrite_failed",
                                                "remote_control_word",
                                                "remote_label_failed",
                                                "remote_pseudo_wire_type",
                                                "required_bw",
                                                "resync_enabled",
                                                "resync_threshold",
                                                "rtp_mismatched",
                                                "sequencing_type",
                                                "shutdown",
                                                "sig_pkts_mismatched",
                                                "ssrc_mismatched",
                                                "state",
                                                "table_policy_name",
                                                "tag_rewrite",
                                                "time_created",
                                                "time_elapsed_creation",
                                                "time_elapsed_status_changed",
                                                "time_elapsed_status_down",
                                                "transport_lsp_down",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__setattr__(name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudowire"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                    self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                    self.type = YLeaf(YType.enumeration, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "ipv4_peer_id",
                                                    "ipv6_peer_id",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.ipv4_peer_id.is_set or
                                        self.ipv6_peer_id.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.ipv4_peer_id.yfilter != YFilter.not_set or
                                        self.ipv6_peer_id.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "peer-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                    if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-peer-id"):
                                        self.ipv4_peer_id = value
                                        self.ipv4_peer_id.value_namespace = name_space
                                        self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-peer-id"):
                                        self.ipv6_peer_id = value
                                        self.ipv6_peer_id.value_namespace = name_space
                                        self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudowire"

                                    self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                    self.atom = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                    self.l2tpv3 = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._children_yang_names.add("l2tpv3")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                        self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                        self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                        self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                        self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                        self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                        self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                        self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                        self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                        self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                        self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                        self.local_veid = YLeaf(YType.uint32, "local-veid")

                                        self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                        self.rem_saii = YLeaf(YType.str, "rem-saii")

                                        self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                        self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                        self.rem_taii = YLeaf(YType.str, "rem-taii")

                                        self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                        self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                        self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                        self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                        self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                        self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                        self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                        self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                        self.saii = YLeaf(YType.str, "saii")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.taii = YLeaf(YType.str, "taii")

                                        self.local_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                        self._children_yang_names.add("local-agi")

                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._children_yang_names.add("multi-segment-pseudowire-stats")

                                        self.remote_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                        self._children_yang_names.add("remote-agi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_pseudowire_headend",
                                                        "is_sai_itype2",
                                                        "is_tai_itype2",
                                                        "ldp_label_advertisment_failed",
                                                        "local_c_ctype",
                                                        "local_ceid",
                                                        "local_cv_type",
                                                        "local_group_id",
                                                        "local_label",
                                                        "local_ldp_id",
                                                        "local_saii_gbl_id",
                                                        "local_saiiac_id",
                                                        "local_taii_gbl_id",
                                                        "local_taiiac_id",
                                                        "local_veid",
                                                        "lsd_rewrite_failed",
                                                        "rem_saii",
                                                        "rem_saii_gbl_id",
                                                        "rem_saiiac_id",
                                                        "rem_taii",
                                                        "rem_taii_gbl_id",
                                                        "rem_taiiac_id",
                                                        "remote_c_ctype",
                                                        "remote_ceid",
                                                        "remote_cv_type",
                                                        "remote_group_id",
                                                        "remote_label",
                                                        "remote_ldp_id",
                                                        "remote_source_address",
                                                        "remote_veid",
                                                        "saii",
                                                        "source_address",
                                                        "taii") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"

                                            self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                            self.received_packets = YLeaf(YType.uint64, "received-packets")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("received_bytes",
                                                            "received_packets") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.received_bytes.is_set or
                                                self.received_packets.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.received_bytes.yfilter != YFilter.not_set or
                                                self.received_packets.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                            if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_packets.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "received-bytes" or name == "received-packets"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "received-bytes"):
                                                self.received_bytes = value
                                                self.received_bytes.value_namespace = name_space
                                                self.received_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "received-packets"):
                                                self.received_packets = value
                                                self.received_packets.value_namespace = name_space
                                                self.received_packets.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_pseudowire_headend.is_set or
                                            self.is_sai_itype2.is_set or
                                            self.is_tai_itype2.is_set or
                                            self.ldp_label_advertisment_failed.is_set or
                                            self.local_c_ctype.is_set or
                                            self.local_ceid.is_set or
                                            self.local_cv_type.is_set or
                                            self.local_group_id.is_set or
                                            self.local_label.is_set or
                                            self.local_ldp_id.is_set or
                                            self.local_saii_gbl_id.is_set or
                                            self.local_saiiac_id.is_set or
                                            self.local_taii_gbl_id.is_set or
                                            self.local_taiiac_id.is_set or
                                            self.local_veid.is_set or
                                            self.lsd_rewrite_failed.is_set or
                                            self.rem_saii.is_set or
                                            self.rem_saii_gbl_id.is_set or
                                            self.rem_saiiac_id.is_set or
                                            self.rem_taii.is_set or
                                            self.rem_taii_gbl_id.is_set or
                                            self.rem_taiiac_id.is_set or
                                            self.remote_c_ctype.is_set or
                                            self.remote_ceid.is_set or
                                            self.remote_cv_type.is_set or
                                            self.remote_group_id.is_set or
                                            self.remote_label.is_set or
                                            self.remote_ldp_id.is_set or
                                            self.remote_source_address.is_set or
                                            self.remote_veid.is_set or
                                            self.saii.is_set or
                                            self.source_address.is_set or
                                            self.taii.is_set or
                                            (self.local_agi is not None and self.local_agi.has_data()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                            (self.remote_agi is not None and self.remote_agi.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                            self.is_sai_itype2.yfilter != YFilter.not_set or
                                            self.is_tai_itype2.yfilter != YFilter.not_set or
                                            self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                            self.local_c_ctype.yfilter != YFilter.not_set or
                                            self.local_ceid.yfilter != YFilter.not_set or
                                            self.local_cv_type.yfilter != YFilter.not_set or
                                            self.local_group_id.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_ldp_id.yfilter != YFilter.not_set or
                                            self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_saiiac_id.yfilter != YFilter.not_set or
                                            self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_taiiac_id.yfilter != YFilter.not_set or
                                            self.local_veid.yfilter != YFilter.not_set or
                                            self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.rem_saii.yfilter != YFilter.not_set or
                                            self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_saiiac_id.yfilter != YFilter.not_set or
                                            self.rem_taii.yfilter != YFilter.not_set or
                                            self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_taiiac_id.yfilter != YFilter.not_set or
                                            self.remote_c_ctype.yfilter != YFilter.not_set or
                                            self.remote_ceid.yfilter != YFilter.not_set or
                                            self.remote_cv_type.yfilter != YFilter.not_set or
                                            self.remote_group_id.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_ldp_id.yfilter != YFilter.not_set or
                                            self.remote_source_address.yfilter != YFilter.not_set or
                                            self.remote_veid.yfilter != YFilter.not_set or
                                            self.saii.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.taii.yfilter != YFilter.not_set or
                                            (self.local_agi is not None and self.local_agi.has_operation()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                            (self.remote_agi is not None and self.remote_agi.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                        if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                        if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                        if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                        if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                        if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                        if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                        if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                        if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                        if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                        if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                        if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                        if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_veid.get_name_leafdata())
                                        if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                        if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                        if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                        if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                        if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                        if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                        if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                        if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                        if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                        if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                        if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                        if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                        if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                        if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saii.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.taii.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local-agi"):
                                            if (self.local_agi is None):
                                                self.local_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                            return self.local_agi

                                        if (child_yang_name == "multi-segment-pseudowire-stats"):
                                            if (self.multi_segment_pseudowire_stats is None):
                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            return self.multi_segment_pseudowire_stats

                                        if (child_yang_name == "remote-agi"):
                                            if (self.remote_agi is None):
                                                self.remote_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                            return self.remote_agi

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-pseudowire-headend"):
                                            self.is_pseudowire_headend = value
                                            self.is_pseudowire_headend.value_namespace = name_space
                                            self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-sai-itype2"):
                                            self.is_sai_itype2 = value
                                            self.is_sai_itype2.value_namespace = name_space
                                            self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-tai-itype2"):
                                            self.is_tai_itype2 = value
                                            self.is_tai_itype2.value_namespace = name_space
                                            self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertisment-failed"):
                                            self.ldp_label_advertisment_failed = value
                                            self.ldp_label_advertisment_failed.value_namespace = name_space
                                            self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-c-ctype"):
                                            self.local_c_ctype = value
                                            self.local_c_ctype.value_namespace = name_space
                                            self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ceid"):
                                            self.local_ceid = value
                                            self.local_ceid.value_namespace = name_space
                                            self.local_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cv-type"):
                                            self.local_cv_type = value
                                            self.local_cv_type.value_namespace = name_space
                                            self.local_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-group-id"):
                                            self.local_group_id = value
                                            self.local_group_id.value_namespace = name_space
                                            self.local_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ldp-id"):
                                            self.local_ldp_id = value
                                            self.local_ldp_id.value_namespace = name_space
                                            self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saii-gbl-id"):
                                            self.local_saii_gbl_id = value
                                            self.local_saii_gbl_id.value_namespace = name_space
                                            self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saiiac-id"):
                                            self.local_saiiac_id = value
                                            self.local_saiiac_id.value_namespace = name_space
                                            self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taii-gbl-id"):
                                            self.local_taii_gbl_id = value
                                            self.local_taii_gbl_id.value_namespace = name_space
                                            self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taiiac-id"):
                                            self.local_taiiac_id = value
                                            self.local_taiiac_id.value_namespace = name_space
                                            self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-veid"):
                                            self.local_veid = value
                                            self.local_veid.value_namespace = name_space
                                            self.local_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsd-rewrite-failed"):
                                            self.lsd_rewrite_failed = value
                                            self.lsd_rewrite_failed.value_namespace = name_space
                                            self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii"):
                                            self.rem_saii = value
                                            self.rem_saii.value_namespace = name_space
                                            self.rem_saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii-gbl-id"):
                                            self.rem_saii_gbl_id = value
                                            self.rem_saii_gbl_id.value_namespace = name_space
                                            self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saiiac-id"):
                                            self.rem_saiiac_id = value
                                            self.rem_saiiac_id.value_namespace = name_space
                                            self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii"):
                                            self.rem_taii = value
                                            self.rem_taii.value_namespace = name_space
                                            self.rem_taii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii-gbl-id"):
                                            self.rem_taii_gbl_id = value
                                            self.rem_taii_gbl_id.value_namespace = name_space
                                            self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taiiac-id"):
                                            self.rem_taiiac_id = value
                                            self.rem_taiiac_id.value_namespace = name_space
                                            self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-c-ctype"):
                                            self.remote_c_ctype = value
                                            self.remote_c_ctype.value_namespace = name_space
                                            self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ceid"):
                                            self.remote_ceid = value
                                            self.remote_ceid.value_namespace = name_space
                                            self.remote_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cv-type"):
                                            self.remote_cv_type = value
                                            self.remote_cv_type.value_namespace = name_space
                                            self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-group-id"):
                                            self.remote_group_id = value
                                            self.remote_group_id.value_namespace = name_space
                                            self.remote_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ldp-id"):
                                            self.remote_ldp_id = value
                                            self.remote_ldp_id.value_namespace = name_space
                                            self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-source-address"):
                                            self.remote_source_address = value
                                            self.remote_source_address.value_namespace = name_space
                                            self.remote_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-veid"):
                                            self.remote_veid = value
                                            self.remote_veid.value_namespace = name_space
                                            self.remote_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saii"):
                                            self.saii = value
                                            self.saii.value_namespace = name_space
                                            self.saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "taii"):
                                            self.taii = value
                                            self.taii.value_namespace = name_space
                                            self.taii.value_namespace_prefix = name_space_prefix


                                class L2Tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                        self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                        self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                        self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                        self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                        self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                        self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                        self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                        self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                        self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                        self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                        self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                        self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                        self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                        self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                        self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                        self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                        self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                        self.tos = YLeaf(YType.uint8, "tos")

                                        self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dont_fragment_bit",
                                                        "ipv4_source_address",
                                                        "ipv6_source_address",
                                                        "l2tp_class_name",
                                                        "local_cookie_high_value",
                                                        "local_cookie_low_value",
                                                        "local_cookie_size",
                                                        "local_secondary_cookie_high_value",
                                                        "local_secondary_cookie_low_value",
                                                        "local_secondary_cookie_size",
                                                        "local_session_id",
                                                        "path_mtu_enabled",
                                                        "path_mtu_max_value",
                                                        "remote_circuit_status_up",
                                                        "remote_cookie_high_value",
                                                        "remote_cookie_low_value",
                                                        "remote_cookie_size",
                                                        "remote_session_id",
                                                        "tos",
                                                        "tos_mode",
                                                        "ttl",
                                                        "tunnel_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dont_fragment_bit.is_set or
                                            self.ipv4_source_address.is_set or
                                            self.ipv6_source_address.is_set or
                                            self.l2tp_class_name.is_set or
                                            self.local_cookie_high_value.is_set or
                                            self.local_cookie_low_value.is_set or
                                            self.local_cookie_size.is_set or
                                            self.local_secondary_cookie_high_value.is_set or
                                            self.local_secondary_cookie_low_value.is_set or
                                            self.local_secondary_cookie_size.is_set or
                                            self.local_session_id.is_set or
                                            self.path_mtu_enabled.is_set or
                                            self.path_mtu_max_value.is_set or
                                            self.remote_circuit_status_up.is_set or
                                            self.remote_cookie_high_value.is_set or
                                            self.remote_cookie_low_value.is_set or
                                            self.remote_cookie_size.is_set or
                                            self.remote_session_id.is_set or
                                            self.tos.is_set or
                                            self.tos_mode.is_set or
                                            self.ttl.is_set or
                                            self.tunnel_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dont_fragment_bit.yfilter != YFilter.not_set or
                                            self.ipv4_source_address.yfilter != YFilter.not_set or
                                            self.ipv6_source_address.yfilter != YFilter.not_set or
                                            self.l2tp_class_name.yfilter != YFilter.not_set or
                                            self.local_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_cookie_size.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                            self.local_session_id.yfilter != YFilter.not_set or
                                            self.path_mtu_enabled.yfilter != YFilter.not_set or
                                            self.path_mtu_max_value.yfilter != YFilter.not_set or
                                            self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                            self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_size.yfilter != YFilter.not_set or
                                            self.remote_session_id.yfilter != YFilter.not_set or
                                            self.tos.yfilter != YFilter.not_set or
                                            self.tos_mode.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.tunnel_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv3" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                        if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                        if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                        if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                        if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                        if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                        if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                        if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                        if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                        if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                        if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                        if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                        if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                        if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                        if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                        if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                        if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos.get_name_leafdata())
                                        if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dont-fragment-bit"):
                                            self.dont_fragment_bit = value
                                            self.dont_fragment_bit.value_namespace = name_space
                                            self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-source-address"):
                                            self.ipv4_source_address = value
                                            self.ipv4_source_address.value_namespace = name_space
                                            self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-source-address"):
                                            self.ipv6_source_address = value
                                            self.ipv6_source_address.value_namespace = name_space
                                            self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l2tp-class-name"):
                                            self.l2tp_class_name = value
                                            self.l2tp_class_name.value_namespace = name_space
                                            self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-high-value"):
                                            self.local_cookie_high_value = value
                                            self.local_cookie_high_value.value_namespace = name_space
                                            self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-low-value"):
                                            self.local_cookie_low_value = value
                                            self.local_cookie_low_value.value_namespace = name_space
                                            self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-size"):
                                            self.local_cookie_size = value
                                            self.local_cookie_size.value_namespace = name_space
                                            self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-high-value"):
                                            self.local_secondary_cookie_high_value = value
                                            self.local_secondary_cookie_high_value.value_namespace = name_space
                                            self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-low-value"):
                                            self.local_secondary_cookie_low_value = value
                                            self.local_secondary_cookie_low_value.value_namespace = name_space
                                            self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-size"):
                                            self.local_secondary_cookie_size = value
                                            self.local_secondary_cookie_size.value_namespace = name_space
                                            self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-session-id"):
                                            self.local_session_id = value
                                            self.local_session_id.value_namespace = name_space
                                            self.local_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-enabled"):
                                            self.path_mtu_enabled = value
                                            self.path_mtu_enabled.value_namespace = name_space
                                            self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-max-value"):
                                            self.path_mtu_max_value = value
                                            self.path_mtu_max_value.value_namespace = name_space
                                            self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-circuit-status-up"):
                                            self.remote_circuit_status_up = value
                                            self.remote_circuit_status_up.value_namespace = name_space
                                            self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-high-value"):
                                            self.remote_cookie_high_value = value
                                            self.remote_cookie_high_value.value_namespace = name_space
                                            self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-low-value"):
                                            self.remote_cookie_low_value = value
                                            self.remote_cookie_low_value.value_namespace = name_space
                                            self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-size"):
                                            self.remote_cookie_size = value
                                            self.remote_cookie_size.value_namespace = name_space
                                            self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-session-id"):
                                            self.remote_session_id = value
                                            self.remote_session_id.value_namespace = name_space
                                            self.remote_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos"):
                                            self.tos = value
                                            self.tos.value_namespace = name_space
                                            self.tos.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-mode"):
                                            self.tos_mode = value
                                            self.tos_mode.value_namespace = name_space
                                            self.tos_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tunnel-state"):
                                            self.tunnel_state = value
                                            self.tunnel_state.value_namespace = name_space
                                            self.tunnel_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.encapsulation.is_set or
                                        (self.atom is not None and self.atom.has_data()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "encapsulation-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    if (child_yang_name == "l2tpv3"):
                                        if (self.l2tpv3 is None):
                                            self.l2tpv3 = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                        return self.l2tpv3

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation"):
                                        self.encapsulation = value
                                        self.encapsulation.value_namespace = name_space
                                        self.encapsulation.value_namespace_prefix = name_space_prefix


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudowire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudowire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudowire"

                                    self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                    self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                    self.option = YLeaf(YType.enumeration, "option")

                                    self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                    self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ip_tunnel_interface_number",
                                                    "next_hop_ip",
                                                    "option",
                                                    "te_tunnel_interface_number",
                                                    "tp_tunnel_interface_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ip_tunnel_interface_number.is_set or
                                        self.next_hop_ip.is_set or
                                        self.option.is_set or
                                        self.te_tunnel_interface_number.is_set or
                                        self.tp_tunnel_interface_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set or
                                        self.option.yfilter != YFilter.not_set or
                                        self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "preferred-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                    if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.option.get_name_leafdata())
                                    if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                    if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ip-tunnel-interface-number"):
                                        self.ip_tunnel_interface_number = value
                                        self.ip_tunnel_interface_number.value_namespace = name_space
                                        self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                    if(value_path == "option"):
                                        self.option = value
                                        self.option.value_namespace = name_space
                                        self.option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-tunnel-interface-number"):
                                        self.te_tunnel_interface_number = value
                                        self.te_tunnel_interface_number.value_namespace = name_space
                                        self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tp-tunnel-interface-number"):
                                        self.tp_tunnel_interface_number = value
                                        self.tp_tunnel_interface_number.value_namespace = name_space
                                        self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudowire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudowire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudowire"

                                    self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class P2MpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudowire"

                                    self.local_available = YLeaf(YType.boolean, "local-available")

                                    self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                    self.local_flags = YLeaf(YType.uint8, "local-flags")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                    self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                    self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                    self.remote_available = YLeaf(YType.boolean, "remote-available")

                                    self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                    self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                    self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                    self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_available",
                                                    "local_extended_tunnel_id",
                                                    "local_flags",
                                                    "local_label",
                                                    "local_p2mp_id",
                                                    "local_ptree_type",
                                                    "local_tunnel_id",
                                                    "remote_available",
                                                    "remote_extended_tunnel_id",
                                                    "remote_flags",
                                                    "remote_label",
                                                    "remote_p2mp_id",
                                                    "remote_ptree_type",
                                                    "remote_tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_available.is_set or
                                        self.local_extended_tunnel_id.is_set or
                                        self.local_flags.is_set or
                                        self.local_label.is_set or
                                        self.local_p2mp_id.is_set or
                                        self.local_ptree_type.is_set or
                                        self.local_tunnel_id.is_set or
                                        self.remote_available.is_set or
                                        self.remote_extended_tunnel_id.is_set or
                                        self.remote_flags.is_set or
                                        self.remote_label.is_set or
                                        self.remote_p2mp_id.is_set or
                                        self.remote_ptree_type.is_set or
                                        self.remote_tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_available.yfilter != YFilter.not_set or
                                        self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.local_flags.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_p2mp_id.yfilter != YFilter.not_set or
                                        self.local_ptree_type.yfilter != YFilter.not_set or
                                        self.local_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_available.yfilter != YFilter.not_set or
                                        self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_flags.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_p2mp_id.yfilter != YFilter.not_set or
                                        self.remote_ptree_type.yfilter != YFilter.not_set or
                                        self.remote_tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_available.get_name_leafdata())
                                    if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                    if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_flags.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                    if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                    if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                    if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_available.get_name_leafdata())
                                    if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                    if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                    if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                    if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-available"):
                                        self.local_available = value
                                        self.local_available.value_namespace = name_space
                                        self.local_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-extended-tunnel-id"):
                                        self.local_extended_tunnel_id = value
                                        self.local_extended_tunnel_id.value_namespace = name_space
                                        self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-flags"):
                                        self.local_flags = value
                                        self.local_flags.value_namespace = name_space
                                        self.local_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-p2mp-id"):
                                        self.local_p2mp_id = value
                                        self.local_p2mp_id.value_namespace = name_space
                                        self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ptree-type"):
                                        self.local_ptree_type = value
                                        self.local_ptree_type.value_namespace = name_space
                                        self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-tunnel-id"):
                                        self.local_tunnel_id = value
                                        self.local_tunnel_id.value_namespace = name_space
                                        self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-available"):
                                        self.remote_available = value
                                        self.remote_available.value_namespace = name_space
                                        self.remote_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-extended-tunnel-id"):
                                        self.remote_extended_tunnel_id = value
                                        self.remote_extended_tunnel_id.value_namespace = name_space
                                        self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-flags"):
                                        self.remote_flags = value
                                        self.remote_flags.value_namespace = name_space
                                        self.remote_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-p2mp-id"):
                                        self.remote_p2mp_id = value
                                        self.remote_p2mp_id.value_namespace = name_space
                                        self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ptree-type"):
                                        self.remote_ptree_type = value
                                        self.remote_ptree_type.value_namespace = name_space
                                        self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-tunnel-id"):
                                        self.remote_tunnel_id = value
                                        self.remote_tunnel_id.value_namespace = name_space
                                        self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ad_method.is_set or
                                    self.ad_remote_down.is_set or
                                    self.admited_bw.is_set or
                                    self.auto_discovery.is_set or
                                    self.backup_active.is_set or
                                    self.backup_force_active.is_set or
                                    self.backup_pw.is_set or
                                    self.bitrate_mismatched.is_set or
                                    self.bridge_pw_type_mismatch.is_set or
                                    self.cas_mismatched.is_set or
                                    self.diff_ts_mismatched.is_set or
                                    self.disable_delay.is_set or
                                    self.disable_never.is_set or
                                    self.evpn_src_acid.is_set or
                                    self.fe_ctype.is_set or
                                    self.forward_class.is_set or
                                    self.freq_mismatched.is_set or
                                    self.illegal_control_word.is_set or
                                    self.imposed_vlan_id.is_set or
                                    self.interworking.is_set or
                                    self.ipv6_local_source_address.is_set or
                                    self.is_evpnvpws_type.is_set or
                                    self.is_flow_label_static.is_set or
                                    self.is_multi_segment_pseudowire.is_set or
                                    self.is_partially_programmed.is_set or
                                    self.is_pwr_type.is_set or
                                    self.is_vfi.is_set or
                                    self.last_time_status_changed.is_set or
                                    self.last_time_status_down.is_set or
                                    self.ldp_label_advertise_failed.is_set or
                                    self.load_balance.is_set or
                                    self.local_control_word.is_set or
                                    self.local_label_failed.is_set or
                                    self.local_pseudo_wire_type.is_set or
                                    self.local_source_address.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.not_supported_qinq.is_set or
                                    self.num_ma_cwithdraw_msg_received.is_set or
                                    self.number_ma_cwithdraw_message_sent.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.payload_bytes_mismatched.is_set or
                                    self.payload_type_mismatched.is_set or
                                    self.preferred_path_disable_fallback.is_set or
                                    self.primary_peer_id.is_set or
                                    self.primary_pseudo_wire_id.is_set or
                                    self.primary_pw.is_set or
                                    self.protocol.is_set or
                                    self.pseudo_wire_id.is_set or
                                    self.pseudo_wire_state.is_set or
                                    self.pseudo_wire_type_mismatched.is_set or
                                    self.pw_class_name.is_set or
                                    self.pw_flow_label_code17_disabled.is_set or
                                    self.pw_flow_label_type.is_set or
                                    self.pw_flow_label_type_cfg.is_set or
                                    self.pw_redundancy_initial_delay.is_set or
                                    self.pw_redundancy_one_way.is_set or
                                    self.pw_status_use.is_set or
                                    self.pwlsd_rewrite_failed.is_set or
                                    self.remote_control_word.is_set or
                                    self.remote_label_failed.is_set or
                                    self.remote_pseudo_wire_type.is_set or
                                    self.required_bw.is_set or
                                    self.resync_enabled.is_set or
                                    self.resync_threshold.is_set or
                                    self.rtp_mismatched.is_set or
                                    self.sequencing_type.is_set or
                                    self.shutdown.is_set or
                                    self.sig_pkts_mismatched.is_set or
                                    self.ssrc_mismatched.is_set or
                                    self.state.is_set or
                                    self.table_policy_name.is_set or
                                    self.tag_rewrite.is_set or
                                    self.time_created.is_set or
                                    self.time_elapsed_creation.is_set or
                                    self.time_elapsed_status_changed.is_set or
                                    self.time_elapsed_status_down.is_set or
                                    self.transport_lsp_down.is_set or
                                    self.xconnect_id.is_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                    (self.local_interface is not None and self.local_interface.has_data()) or
                                    (self.local_signalling is not None and self.local_signalling.has_data()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                    (self.peer_id is not None and self.peer_id.has_data()) or
                                    (self.preferred_path is not None and self.preferred_path.has_data()) or
                                    (self.remote_interface is not None and self.remote_interface.has_data()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_remote_down.yfilter != YFilter.not_set or
                                    self.admited_bw.yfilter != YFilter.not_set or
                                    self.auto_discovery.yfilter != YFilter.not_set or
                                    self.backup_active.yfilter != YFilter.not_set or
                                    self.backup_force_active.yfilter != YFilter.not_set or
                                    self.backup_pw.yfilter != YFilter.not_set or
                                    self.bitrate_mismatched.yfilter != YFilter.not_set or
                                    self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                    self.cas_mismatched.yfilter != YFilter.not_set or
                                    self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                    self.disable_delay.yfilter != YFilter.not_set or
                                    self.disable_never.yfilter != YFilter.not_set or
                                    self.evpn_src_acid.yfilter != YFilter.not_set or
                                    self.fe_ctype.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.freq_mismatched.yfilter != YFilter.not_set or
                                    self.illegal_control_word.yfilter != YFilter.not_set or
                                    self.imposed_vlan_id.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                    self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                    self.is_flow_label_static.yfilter != YFilter.not_set or
                                    self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                    self.is_partially_programmed.yfilter != YFilter.not_set or
                                    self.is_pwr_type.yfilter != YFilter.not_set or
                                    self.is_vfi.yfilter != YFilter.not_set or
                                    self.last_time_status_changed.yfilter != YFilter.not_set or
                                    self.last_time_status_down.yfilter != YFilter.not_set or
                                    self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                    self.load_balance.yfilter != YFilter.not_set or
                                    self.local_control_word.yfilter != YFilter.not_set or
                                    self.local_label_failed.yfilter != YFilter.not_set or
                                    self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.local_source_address.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.not_supported_qinq.yfilter != YFilter.not_set or
                                    self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                    self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                    self.payload_type_mismatched.yfilter != YFilter.not_set or
                                    self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                    self.primary_peer_id.yfilter != YFilter.not_set or
                                    self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.primary_pw.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.pseudo_wire_state.yfilter != YFilter.not_set or
                                    self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                    self.pw_class_name.yfilter != YFilter.not_set or
                                    self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                    self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                    self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                    self.pw_status_use.yfilter != YFilter.not_set or
                                    self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.remote_control_word.yfilter != YFilter.not_set or
                                    self.remote_label_failed.yfilter != YFilter.not_set or
                                    self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.required_bw.yfilter != YFilter.not_set or
                                    self.resync_enabled.yfilter != YFilter.not_set or
                                    self.resync_threshold.yfilter != YFilter.not_set or
                                    self.rtp_mismatched.yfilter != YFilter.not_set or
                                    self.sequencing_type.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                    self.ssrc_mismatched.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.table_policy_name.yfilter != YFilter.not_set or
                                    self.tag_rewrite.yfilter != YFilter.not_set or
                                    self.time_created.yfilter != YFilter.not_set or
                                    self.time_elapsed_creation.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                    self.transport_lsp_down.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                    (self.local_interface is not None and self.local_interface.has_operation()) or
                                    (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                    (self.peer_id is not None and self.peer_id.has_operation()) or
                                    (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                    (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pseudowire" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_active.get_name_leafdata())
                                if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_never.get_name_leafdata())
                                if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance.get_name_leafdata())
                                if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())
                                if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.required_bw.get_name_leafdata())
                                if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_created.get_name_leafdata())
                                if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "encapsulation-info"):
                                    if (self.encapsulation_info is None):
                                        self.encapsulation_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    return self.encapsulation_info

                                if (child_yang_name == "local-interface"):
                                    if (self.local_interface is None):
                                        self.local_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                    return self.local_interface

                                if (child_yang_name == "local-signalling"):
                                    if (self.local_signalling is None):
                                        self.local_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                    return self.local_signalling

                                if (child_yang_name == "p2mp-pw"):
                                    if (self.p2mp_pw is None):
                                        self.p2mp_pw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    return self.p2mp_pw

                                if (child_yang_name == "peer-id"):
                                    if (self.peer_id is None):
                                        self.peer_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                    return self.peer_id

                                if (child_yang_name == "preferred-path"):
                                    if (self.preferred_path is None):
                                        self.preferred_path = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                    return self.preferred_path

                                if (child_yang_name == "remote-interface"):
                                    if (self.remote_interface is None):
                                        self.remote_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                    return self.remote_interface

                                if (child_yang_name == "remote-signalling"):
                                    if (self.remote_signalling is None):
                                        self.remote_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                    return self.remote_signalling

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-remote-down"):
                                    self.ad_remote_down = value
                                    self.ad_remote_down.value_namespace = name_space
                                    self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "admited-bw"):
                                    self.admited_bw = value
                                    self.admited_bw.value_namespace = name_space
                                    self.admited_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "auto-discovery"):
                                    self.auto_discovery = value
                                    self.auto_discovery.value_namespace = name_space
                                    self.auto_discovery.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-active"):
                                    self.backup_active = value
                                    self.backup_active.value_namespace = name_space
                                    self.backup_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-force-active"):
                                    self.backup_force_active = value
                                    self.backup_force_active.value_namespace = name_space
                                    self.backup_force_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-pw"):
                                    self.backup_pw = value
                                    self.backup_pw.value_namespace = name_space
                                    self.backup_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "bitrate-mismatched"):
                                    self.bitrate_mismatched = value
                                    self.bitrate_mismatched.value_namespace = name_space
                                    self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-pw-type-mismatch"):
                                    self.bridge_pw_type_mismatch = value
                                    self.bridge_pw_type_mismatch.value_namespace = name_space
                                    self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "cas-mismatched"):
                                    self.cas_mismatched = value
                                    self.cas_mismatched.value_namespace = name_space
                                    self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "diff-ts-mismatched"):
                                    self.diff_ts_mismatched = value
                                    self.diff_ts_mismatched.value_namespace = name_space
                                    self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-delay"):
                                    self.disable_delay = value
                                    self.disable_delay.value_namespace = name_space
                                    self.disable_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-never"):
                                    self.disable_never = value
                                    self.disable_never.value_namespace = name_space
                                    self.disable_never.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-src-acid"):
                                    self.evpn_src_acid = value
                                    self.evpn_src_acid.value_namespace = name_space
                                    self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                if(value_path == "fe-ctype"):
                                    self.fe_ctype = value
                                    self.fe_ctype.value_namespace = name_space
                                    self.fe_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "freq-mismatched"):
                                    self.freq_mismatched = value
                                    self.freq_mismatched.value_namespace = name_space
                                    self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-control-word"):
                                    self.illegal_control_word = value
                                    self.illegal_control_word.value_namespace = name_space
                                    self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "imposed-vlan-id"):
                                    self.imposed_vlan_id = value
                                    self.imposed_vlan_id.value_namespace = name_space
                                    self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-local-source-address"):
                                    self.ipv6_local_source_address = value
                                    self.ipv6_local_source_address.value_namespace = name_space
                                    self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpnvpws-type"):
                                    self.is_evpnvpws_type = value
                                    self.is_evpnvpws_type.value_namespace = name_space
                                    self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-flow-label-static"):
                                    self.is_flow_label_static = value
                                    self.is_flow_label_static.value_namespace = name_space
                                    self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-multi-segment-pseudowire"):
                                    self.is_multi_segment_pseudowire = value
                                    self.is_multi_segment_pseudowire.value_namespace = name_space
                                    self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-partially-programmed"):
                                    self.is_partially_programmed = value
                                    self.is_partially_programmed.value_namespace = name_space
                                    self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pwr-type"):
                                    self.is_pwr_type = value
                                    self.is_pwr_type.value_namespace = name_space
                                    self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vfi"):
                                    self.is_vfi = value
                                    self.is_vfi.value_namespace = name_space
                                    self.is_vfi.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-changed"):
                                    self.last_time_status_changed = value
                                    self.last_time_status_changed.value_namespace = name_space
                                    self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-down"):
                                    self.last_time_status_down = value
                                    self.last_time_status_down.value_namespace = name_space
                                    self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertise-failed"):
                                    self.ldp_label_advertise_failed = value
                                    self.ldp_label_advertise_failed.value_namespace = name_space
                                    self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance"):
                                    self.load_balance = value
                                    self.load_balance.value_namespace = name_space
                                    self.load_balance.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-control-word"):
                                    self.local_control_word = value
                                    self.local_control_word.value_namespace = name_space
                                    self.local_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label-failed"):
                                    self.local_label_failed = value
                                    self.local_label_failed.value_namespace = name_space
                                    self.local_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-pseudo-wire-type"):
                                    self.local_pseudo_wire_type = value
                                    self.local_pseudo_wire_type.value_namespace = name_space
                                    self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-source-address"):
                                    self.local_source_address = value
                                    self.local_source_address.value_namespace = name_space
                                    self.local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-supported-qinq"):
                                    self.not_supported_qinq = value
                                    self.not_supported_qinq.value_namespace = name_space
                                    self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                if(value_path == "num-ma-cwithdraw-msg-received"):
                                    self.num_ma_cwithdraw_msg_received = value
                                    self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                    self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-ma-cwithdraw-message-sent"):
                                    self.number_ma_cwithdraw_message_sent = value
                                    self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                    self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes-mismatched"):
                                    self.payload_bytes_mismatched = value
                                    self.payload_bytes_mismatched.value_namespace = name_space
                                    self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-type-mismatched"):
                                    self.payload_type_mismatched = value
                                    self.payload_type_mismatched.value_namespace = name_space
                                    self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "preferred-path-disable-fallback"):
                                    self.preferred_path_disable_fallback = value
                                    self.preferred_path_disable_fallback.value_namespace = name_space
                                    self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-peer-id"):
                                    self.primary_peer_id = value
                                    self.primary_peer_id.value_namespace = name_space
                                    self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pseudo-wire-id"):
                                    self.primary_pseudo_wire_id = value
                                    self.primary_pseudo_wire_id.value_namespace = name_space
                                    self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pw"):
                                    self.primary_pw = value
                                    self.primary_pw.value_namespace = name_space
                                    self.primary_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id"):
                                    self.pseudo_wire_id = value
                                    self.pseudo_wire_id.value_namespace = name_space
                                    self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-state"):
                                    self.pseudo_wire_state = value
                                    self.pseudo_wire_state.value_namespace = name_space
                                    self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-type-mismatched"):
                                    self.pseudo_wire_type_mismatched = value
                                    self.pseudo_wire_type_mismatched.value_namespace = name_space
                                    self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-class-name"):
                                    self.pw_class_name = value
                                    self.pw_class_name.value_namespace = name_space
                                    self.pw_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-code17-disabled"):
                                    self.pw_flow_label_code17_disabled = value
                                    self.pw_flow_label_code17_disabled.value_namespace = name_space
                                    self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type"):
                                    self.pw_flow_label_type = value
                                    self.pw_flow_label_type.value_namespace = name_space
                                    self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type-cfg"):
                                    self.pw_flow_label_type_cfg = value
                                    self.pw_flow_label_type_cfg.value_namespace = name_space
                                    self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-initial-delay"):
                                    self.pw_redundancy_initial_delay = value
                                    self.pw_redundancy_initial_delay.value_namespace = name_space
                                    self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-one-way"):
                                    self.pw_redundancy_one_way = value
                                    self.pw_redundancy_one_way.value_namespace = name_space
                                    self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-status-use"):
                                    self.pw_status_use = value
                                    self.pw_status_use.value_namespace = name_space
                                    self.pw_status_use.value_namespace_prefix = name_space_prefix
                                if(value_path == "pwlsd-rewrite-failed"):
                                    self.pwlsd_rewrite_failed = value
                                    self.pwlsd_rewrite_failed.value_namespace = name_space
                                    self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-control-word"):
                                    self.remote_control_word = value
                                    self.remote_control_word.value_namespace = name_space
                                    self.remote_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label-failed"):
                                    self.remote_label_failed = value
                                    self.remote_label_failed.value_namespace = name_space
                                    self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-pseudo-wire-type"):
                                    self.remote_pseudo_wire_type = value
                                    self.remote_pseudo_wire_type.value_namespace = name_space
                                    self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "required-bw"):
                                    self.required_bw = value
                                    self.required_bw.value_namespace = name_space
                                    self.required_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-enabled"):
                                    self.resync_enabled = value
                                    self.resync_enabled.value_namespace = name_space
                                    self.resync_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-threshold"):
                                    self.resync_threshold = value
                                    self.resync_threshold.value_namespace = name_space
                                    self.resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "rtp-mismatched"):
                                    self.rtp_mismatched = value
                                    self.rtp_mismatched.value_namespace = name_space
                                    self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequencing-type"):
                                    self.sequencing_type = value
                                    self.sequencing_type.value_namespace = name_space
                                    self.sequencing_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "sig-pkts-mismatched"):
                                    self.sig_pkts_mismatched = value
                                    self.sig_pkts_mismatched.value_namespace = name_space
                                    self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "ssrc-mismatched"):
                                    self.ssrc_mismatched = value
                                    self.ssrc_mismatched.value_namespace = name_space
                                    self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-policy-name"):
                                    self.table_policy_name = value
                                    self.table_policy_name.value_namespace = name_space
                                    self.table_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag-rewrite"):
                                    self.tag_rewrite = value
                                    self.tag_rewrite.value_namespace = name_space
                                    self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-created"):
                                    self.time_created = value
                                    self.time_created.value_namespace = name_space
                                    self.time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-creation"):
                                    self.time_elapsed_creation = value
                                    self.time_elapsed_creation.value_namespace = name_space
                                    self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-changed"):
                                    self.time_elapsed_status_changed = value
                                    self.time_elapsed_status_changed.value_namespace = name_space
                                    self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-down"):
                                    self.time_elapsed_status_down = value
                                    self.time_elapsed_status_down.value_namespace = name_space
                                    self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-lsp-down"):
                                    self.transport_lsp_down = value
                                    self.transport_lsp_down.value_namespace = name_space
                                    self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-access-pw"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dhcpv4_trust",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                    self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                    self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                    self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                    self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                    self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                    self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                    self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                    self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                    self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                    self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                    self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                    self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                    self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                    self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                    self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                    self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                    self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                    self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                    self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                    self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                    self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                    self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                    self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                    self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                    self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                    self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                    self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                    self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                    self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dai_address_validation_mask",
                                                    "dhcpv4_profile_name",
                                                    "dhcpv4_snoop",
                                                    "flood_unknown_unicast_enabled",
                                                    "flood_uu_disabled_mac_limit_action",
                                                    "igm_pv4_disabled",
                                                    "igm_pv4_profile_name",
                                                    "is_dai_addr_validate_destination_mac_enabled",
                                                    "is_dai_addr_validate_ipv4_enabled",
                                                    "is_dai_addr_validate_source_mac_enabled",
                                                    "is_dai_enabled",
                                                    "is_dai_logging_enabled",
                                                    "is_ip_source_guard_enabled",
                                                    "is_ipsg_logging_enabled",
                                                    "is_mac_secure_accept_shutdown_enabled",
                                                    "is_mac_secure_enabled",
                                                    "is_mac_secure_logging_enabled",
                                                    "learn_disabled_mac_limit_action",
                                                    "mac_aging_mode",
                                                    "mac_aging_time",
                                                    "mac_flooding",
                                                    "mac_learning",
                                                    "mac_limit",
                                                    "mac_limit_action",
                                                    "mac_limit_notification",
                                                    "mac_limit_reached",
                                                    "mac_port_down_flush_enabled",
                                                    "mac_secure_action",
                                                    "mld_profile_name",
                                                    "mmrp_flood_optimization",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "split_horizon_group_id",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__setattr__(name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/base/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dai_address_validation_mask.is_set or
                                        self.dhcpv4_profile_name.is_set or
                                        self.dhcpv4_snoop.is_set or
                                        self.flood_unknown_unicast_enabled.is_set or
                                        self.flood_uu_disabled_mac_limit_action.is_set or
                                        self.igm_pv4_disabled.is_set or
                                        self.igm_pv4_profile_name.is_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                        self.is_dai_addr_validate_ipv4_enabled.is_set or
                                        self.is_dai_addr_validate_source_mac_enabled.is_set or
                                        self.is_dai_enabled.is_set or
                                        self.is_dai_logging_enabled.is_set or
                                        self.is_ip_source_guard_enabled.is_set or
                                        self.is_ipsg_logging_enabled.is_set or
                                        self.is_mac_secure_accept_shutdown_enabled.is_set or
                                        self.is_mac_secure_enabled.is_set or
                                        self.is_mac_secure_logging_enabled.is_set or
                                        self.learn_disabled_mac_limit_action.is_set or
                                        self.mac_aging_mode.is_set or
                                        self.mac_aging_time.is_set or
                                        self.mac_flooding.is_set or
                                        self.mac_learning.is_set or
                                        self.mac_limit.is_set or
                                        self.mac_limit_action.is_set or
                                        self.mac_limit_notification.is_set or
                                        self.mac_limit_reached.is_set or
                                        self.mac_port_down_flush_enabled.is_set or
                                        self.mac_secure_action.is_set or
                                        self.mld_profile_name.is_set or
                                        self.mmrp_flood_optimization.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.split_horizon_group_id.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                        self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                        self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                        self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                        self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                        self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                        self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                        self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_aging_mode.yfilter != YFilter.not_set or
                                        self.mac_aging_time.yfilter != YFilter.not_set or
                                        self.mac_flooding.yfilter != YFilter.not_set or
                                        self.mac_learning.yfilter != YFilter.not_set or
                                        self.mac_limit.yfilter != YFilter.not_set or
                                        self.mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_limit_notification.yfilter != YFilter.not_set or
                                        self.mac_limit_reached.yfilter != YFilter.not_set or
                                        self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                        self.mac_secure_action.yfilter != YFilter.not_set or
                                        self.mld_profile_name.yfilter != YFilter.not_set or
                                        self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.split_horizon_group_id.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                    if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                    if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                    if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                    if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                    if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                    if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                    if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                    if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                    if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                    if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                    if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                    if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                    if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                    if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                    if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                    if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                    if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                    if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                    if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                    if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                    if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dai-address-validation-mask"):
                                        self.dai_address_validation_mask = value
                                        self.dai_address_validation_mask.value_namespace = name_space
                                        self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-profile-name"):
                                        self.dhcpv4_profile_name = value
                                        self.dhcpv4_profile_name.value_namespace = name_space
                                        self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-snoop"):
                                        self.dhcpv4_snoop = value
                                        self.dhcpv4_snoop.value_namespace = name_space
                                        self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-unknown-unicast-enabled"):
                                        self.flood_unknown_unicast_enabled = value
                                        self.flood_unknown_unicast_enabled.value_namespace = name_space
                                        self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-uu-disabled-mac-limit-action"):
                                        self.flood_uu_disabled_mac_limit_action = value
                                        self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                        self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-disabled"):
                                        self.igm_pv4_disabled = value
                                        self.igm_pv4_disabled.value_namespace = name_space
                                        self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-profile-name"):
                                        self.igm_pv4_profile_name = value
                                        self.igm_pv4_profile_name.value_namespace = name_space
                                        self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                        self.is_dai_addr_validate_destination_mac_enabled = value
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                        self.is_dai_addr_validate_ipv4_enabled = value
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                        self.is_dai_addr_validate_source_mac_enabled = value
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-enabled"):
                                        self.is_dai_enabled = value
                                        self.is_dai_enabled.value_namespace = name_space
                                        self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-logging-enabled"):
                                        self.is_dai_logging_enabled = value
                                        self.is_dai_logging_enabled.value_namespace = name_space
                                        self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ip-source-guard-enabled"):
                                        self.is_ip_source_guard_enabled = value
                                        self.is_ip_source_guard_enabled.value_namespace = name_space
                                        self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ipsg-logging-enabled"):
                                        self.is_ipsg_logging_enabled = value
                                        self.is_ipsg_logging_enabled.value_namespace = name_space
                                        self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                        self.is_mac_secure_accept_shutdown_enabled = value
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-enabled"):
                                        self.is_mac_secure_enabled = value
                                        self.is_mac_secure_enabled.value_namespace = name_space
                                        self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-logging-enabled"):
                                        self.is_mac_secure_logging_enabled = value
                                        self.is_mac_secure_logging_enabled.value_namespace = name_space
                                        self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "learn-disabled-mac-limit-action"):
                                        self.learn_disabled_mac_limit_action = value
                                        self.learn_disabled_mac_limit_action.value_namespace = name_space
                                        self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-mode"):
                                        self.mac_aging_mode = value
                                        self.mac_aging_mode.value_namespace = name_space
                                        self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-time"):
                                        self.mac_aging_time = value
                                        self.mac_aging_time.value_namespace = name_space
                                        self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flooding"):
                                        self.mac_flooding = value
                                        self.mac_flooding.value_namespace = name_space
                                        self.mac_flooding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-learning"):
                                        self.mac_learning = value
                                        self.mac_learning.value_namespace = name_space
                                        self.mac_learning.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit"):
                                        self.mac_limit = value
                                        self.mac_limit.value_namespace = name_space
                                        self.mac_limit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-action"):
                                        self.mac_limit_action = value
                                        self.mac_limit_action.value_namespace = name_space
                                        self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-notification"):
                                        self.mac_limit_notification = value
                                        self.mac_limit_notification.value_namespace = name_space
                                        self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-reached"):
                                        self.mac_limit_reached = value
                                        self.mac_limit_reached.value_namespace = name_space
                                        self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-port-down-flush-enabled"):
                                        self.mac_port_down_flush_enabled = value
                                        self.mac_port_down_flush_enabled.value_namespace = name_space
                                        self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-secure-action"):
                                        self.mac_secure_action = value
                                        self.mac_secure_action.value_namespace = name_space
                                        self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mld-profile-name"):
                                        self.mld_profile_name = value
                                        self.mld_profile_name.value_namespace = name_space
                                        self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mmrp-flood-optimization"):
                                        self.mmrp_flood_optimization = value
                                        self.mmrp_flood_optimization.value_namespace = name_space
                                        self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "split-horizon-group-id"):
                                        self.split_horizon_group_id = value
                                        self.split_horizon_group_id.value_namespace = name_space
                                        self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dhcpv4_trust.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dhcpv4_trust.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-trust"):
                                    self.dhcpv4_trust = value
                                    self.dhcpv4_trust.value_namespace = name_space
                                    self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "bridge-access-pw"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "static-mac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.static_mac:
                                if (c.has_data()):
                                    return True
                            return (
                                self.is_access.is_set or
                                self.neighbor.is_set or
                                self.pseudowire_id.is_set or
                                (self.pseudowire is not None and self.pseudowire.has_data()) or
                                (self.security_parameters is not None and self.security_parameters.has_data()))

                        def has_operation(self):
                            for c in self.static_mac:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.is_access.yfilter != YFilter.not_set or
                                self.neighbor.yfilter != YFilter.not_set or
                                self.pseudowire_id.yfilter != YFilter.not_set or
                                (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                (self.security_parameters is not None and self.security_parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-access-pw" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_access.get_name_leafdata())
                            if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor.get_name_leafdata())
                            if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudowire_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "pseudowire"):
                                if (self.pseudowire is None):
                                    self.pseudowire = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                                    self.pseudowire.parent = self
                                    self._children_name_map["pseudowire"] = "pseudowire"
                                return self.pseudowire

                            if (child_yang_name == "security-parameters"):
                                if (self.security_parameters is None):
                                    self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                return self.security_parameters

                            if (child_yang_name == "static-mac"):
                                for c in self.static_mac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.static_mac.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "is-access"):
                                self.is_access = value
                                self.is_access.value_namespace = name_space
                                self.is_access.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor"):
                                self.neighbor = value
                                self.neighbor.value_namespace = name_space
                                self.neighbor.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudowire-id"):
                                self.pseudowire_id = value
                                self.pseudowire_id.value_namespace = name_space
                                self.pseudowire_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bridge_access_pw:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bridge_access_pw:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-access-pws" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-access-pw"):
                            for c in self.bridge_access_pw:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bridge_access_pw.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-access-pw"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BridgeDomainInfo(Entity):
                    """
                    VPLS Bridge Domain Information
                    
                    .. attribute:: acpwup
                    
                    	Number of bridge ports (AC,PW) which are up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: as_
                    
                    	BGP AS number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_access_vfi
                    
                    	Access Virtual Forwarding Interfaces
                    	**type**\: list of    :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                    
                    .. attribute:: bridge_coupled_state
                    
                    	Bridge\-domain coupled state
                    	**type**\:   :py:class:`L2VpnBridgeCoupledState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeCoupledState>`
                    
                    .. attribute:: bridge_description
                    
                    	Human\-readable bridge\-domain description
                    	**type**\:  str
                    
                    .. attribute:: bridge_domain_id
                    
                    	Identification number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_internal_msti
                    
                    	Bridge\-domain internal msti
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_msti
                    
                    	Bridge\-domain msti
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_mtu
                    
                    	Maximum transmission unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_name
                    
                    	Bridge\-domain name
                    	**type**\:  str
                    
                    .. attribute:: bridge_shg_id
                    
                    	Bridge\-domain shgid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_state
                    
                    	Bridge\-domain state
                    	**type**\:   :py:class:`L2VpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeState>`
                    
                    .. attribute:: bridge_type
                    
                    	Bridge\-domain type
                    	**type**\:   :py:class:`L2VpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridge>`
                    
                    .. attribute:: bridge_vfi
                    
                    	Virtual Forwarding Interfaces
                    	**type**\: list of    :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                    
                    .. attribute:: configured
                    
                    	Bridge\-domain is configured
                    	**type**\:  bool
                    
                    .. attribute:: disposition_bytecount
                    
                    	EVPN Disposition Byte Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: disposition_pkt_count
                    
                    	EVPN Disposition Packet Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: evi
                    
                    	E\-VPN id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_parameters
                    
                    	EVPN parameters
                    	**type**\:   :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                    
                    .. attribute:: flodd_group_id_down
                    
                    	Oper down because no FGID
                    	**type**\:  bool
                    
                    .. attribute:: group_name
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: imposition_byte_count
                    
                    	EVPN Imposition Byte Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: imposition_pkt_count
                    
                    	EVPN Imposition Packet Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: is_bridge_partially_programmed
                    
                    	Bridge is partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_rd_configured
                    
                    	Config or Auto
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the bridge domain status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                    
                    .. attribute:: mac_filter
                    
                    	MAC addresses for filtering
                    	**type**\: list of    :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                    
                    .. attribute:: mac_limit_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw
                    
                    	MAC withdraw enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw_access
                    
                    	MAC Access PW withdraw enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw_option
                    
                    	Event on which MAC withdraw is sent
                    	**type**\:   :py:class:`L2VpnBagMacWithdrawOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacWithdrawOption>`
                    
                    .. attribute:: mac_withdraw_relay
                    
                    	MAC Access PW withdraw relaying from access to access enabled
                    	**type**\:  bool
                    
                    .. attribute:: num_vn_is
                    
                    	Number of VNIs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: num_vn_is_up
                    
                    	Number of VNIs up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_access_vf_is
                    
                    	Number of Access VFIs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pb_bs
                    
                    	Number of pbbs
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_pb_bs_up
                    
                    	Number of pbbs up
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_vf_is
                    
                    	Number of virtual forwarding interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                    
                    	nV Satellite Offload IPv4 Multicast Disabled
                    	**type**\:  bool
                    
                    .. attribute:: p2mp_enabled
                    
                    	P2MP Enabled on this Bridge Domain
                    	**type**\:  bool
                    
                    .. attribute:: partially_programmed_a_cs
                    
                    	Number of attachment circuits partially programmed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partially_programmed_pseudowires
                    
                    	Number of pseudowires partially programmed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_parameters
                    
                    	PBB parameters
                    	**type**\:   :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                    
                    .. attribute:: rd
                    
                    	Route Distinguisher
                    	**type**\:   :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                    
                    .. attribute:: security_parameters
                    
                    	Security parameters
                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                    
                    .. attribute:: shutdown
                    
                    	Administratively disabled
                    	**type**\:  bool
                    
                    .. attribute:: standby_pseudowires
                    
                    	Number of pseudowires standby
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_created
                    
                    	Time when the bridge domain was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: vine_fsm_state
                    
                    	VNI, IRB, Native\-Evpn state
                    	**type**\:  str
                    
                    .. attribute:: vni_parameters
                    
                    	VNI parameters
                    	**type**\:   :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__init__()

                        self.yang_name = "bridge-domain-info"
                        self.yang_parent_name = "bridge-domain"

                        self.acpwup = YLeaf(YType.uint32, "acpwup")

                        self.as_ = YLeaf(YType.uint32, "as")

                        self.bridge_coupled_state = YLeaf(YType.enumeration, "bridge-coupled-state")

                        self.bridge_description = YLeaf(YType.str, "bridge-description")

                        self.bridge_domain_id = YLeaf(YType.uint32, "bridge-domain-id")

                        self.bridge_internal_msti = YLeaf(YType.uint32, "bridge-internal-msti")

                        self.bridge_msti = YLeaf(YType.uint32, "bridge-msti")

                        self.bridge_mtu = YLeaf(YType.uint32, "bridge-mtu")

                        self.bridge_name = YLeaf(YType.str, "bridge-name")

                        self.bridge_shg_id = YLeaf(YType.uint32, "bridge-shg-id")

                        self.bridge_state = YLeaf(YType.enumeration, "bridge-state")

                        self.bridge_type = YLeaf(YType.enumeration, "bridge-type")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.disposition_bytecount = YLeaf(YType.uint64, "disposition-bytecount")

                        self.disposition_pkt_count = YLeaf(YType.uint64, "disposition-pkt-count")

                        self.evi = YLeaf(YType.uint32, "evi")

                        self.flodd_group_id_down = YLeaf(YType.boolean, "flodd-group-id-down")

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.imposition_byte_count = YLeaf(YType.uint64, "imposition-byte-count")

                        self.imposition_pkt_count = YLeaf(YType.uint64, "imposition-pkt-count")

                        self.is_bridge_partially_programmed = YLeaf(YType.boolean, "is-bridge-partially-programmed")

                        self.is_rd_configured = YLeaf(YType.boolean, "is-rd-configured")

                        self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                        self.load_balance = YLeaf(YType.enumeration, "load-balance")

                        self.mac_limit_down = YLeaf(YType.boolean, "mac-limit-down")

                        self.mac_withdraw = YLeaf(YType.boolean, "mac-withdraw")

                        self.mac_withdraw_access = YLeaf(YType.boolean, "mac-withdraw-access")

                        self.mac_withdraw_option = YLeaf(YType.enumeration, "mac-withdraw-option")

                        self.mac_withdraw_relay = YLeaf(YType.boolean, "mac-withdraw-relay")

                        self.num_vn_is = YLeaf(YType.uint32, "num-vn-is")

                        self.num_vn_is_up = YLeaf(YType.uint32, "num-vn-is-up")

                        self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                        self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                        self.number_access_vf_is = YLeaf(YType.uint32, "number-access-vf-is")

                        self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                        self.number_pb_bs = YLeaf(YType.uint8, "number-pb-bs")

                        self.number_pb_bs_up = YLeaf(YType.uint8, "number-pb-bs-up")

                        self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                        self.number_vf_is = YLeaf(YType.uint32, "number-vf-is")

                        self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                        self.p2mp_enabled = YLeaf(YType.boolean, "p2mp-enabled")

                        self.partially_programmed_a_cs = YLeaf(YType.uint32, "partially-programmed-a-cs")

                        self.partially_programmed_pseudowires = YLeaf(YType.uint32, "partially-programmed-pseudowires")

                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                        self.standby_pseudowires = YLeaf(YType.uint32, "standby-pseudowires")

                        self.time_created = YLeaf(YType.str, "time-created")

                        self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                        self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                        self.vine_fsm_state = YLeaf(YType.str, "vine-fsm-state")

                        self.evpn_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                        self.evpn_parameters.parent = self
                        self._children_name_map["evpn_parameters"] = "evpn-parameters"
                        self._children_yang_names.add("evpn-parameters")

                        self.pbb_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                        self.pbb_parameters.parent = self
                        self._children_name_map["pbb_parameters"] = "pbb-parameters"
                        self._children_yang_names.add("pbb-parameters")

                        self.rd = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                        self.rd.parent = self
                        self._children_name_map["rd"] = "rd"
                        self._children_yang_names.add("rd")

                        self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                        self.security_parameters.parent = self
                        self._children_name_map["security_parameters"] = "security-parameters"
                        self._children_yang_names.add("security-parameters")

                        self.vni_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                        self.vni_parameters.parent = self
                        self._children_name_map["vni_parameters"] = "vni-parameters"
                        self._children_yang_names.add("vni-parameters")

                        self.bridge_access_vfi = YList(self)
                        self.bridge_vfi = YList(self)
                        self.mac_filter = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("acpwup",
                                        "as_",
                                        "bridge_coupled_state",
                                        "bridge_description",
                                        "bridge_domain_id",
                                        "bridge_internal_msti",
                                        "bridge_msti",
                                        "bridge_mtu",
                                        "bridge_name",
                                        "bridge_shg_id",
                                        "bridge_state",
                                        "bridge_type",
                                        "configured",
                                        "disposition_bytecount",
                                        "disposition_pkt_count",
                                        "evi",
                                        "flodd_group_id_down",
                                        "group_name",
                                        "imposition_byte_count",
                                        "imposition_pkt_count",
                                        "is_bridge_partially_programmed",
                                        "is_rd_configured",
                                        "last_time_status_changed",
                                        "load_balance",
                                        "mac_limit_down",
                                        "mac_withdraw",
                                        "mac_withdraw_access",
                                        "mac_withdraw_option",
                                        "mac_withdraw_relay",
                                        "num_vn_is",
                                        "num_vn_is_up",
                                        "number_a_cs",
                                        "number_a_cs_up",
                                        "number_access_vf_is",
                                        "number_p_ws_up",
                                        "number_pb_bs",
                                        "number_pb_bs_up",
                                        "number_pseudowires",
                                        "number_vf_is",
                                        "nv_satellite_offload_ipv4_multicast_disabled",
                                        "p2mp_enabled",
                                        "partially_programmed_a_cs",
                                        "partially_programmed_pseudowires",
                                        "shutdown",
                                        "standby_pseudowires",
                                        "time_created",
                                        "time_elapsed_creation",
                                        "time_elapsed_status_changed",
                                        "vine_fsm_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__setattr__(name, value)


                    class SecurityParameters(Entity):
                        """
                        Security parameters
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        .. attribute:: dai_address_validation_mask
                        
                        	DAI Address Validation mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dhcpv4_profile_name
                        
                        	DHCPv4 Profile Name
                        	**type**\:  str
                        
                        .. attribute:: dhcpv4_snoop
                        
                        	DHCPv4 Snoop Status
                        	**type**\:  bool
                        
                        .. attribute:: flood_unknown_unicast_enabled
                        
                        	Flooding unknown unicast enabled
                        	**type**\:  bool
                        
                        .. attribute:: flood_uu_disabled_mac_limit_action
                        
                        	Flooding of unknown\-unicast disabled due to MAC limit action
                        	**type**\:  bool
                        
                        .. attribute:: igm_pv4_disabled
                        
                        	IGMPv4 Disabled
                        	**type**\:  bool
                        
                        .. attribute:: igm_pv4_profile_name
                        
                        	IGMPv4 Profile Name
                        	**type**\:  str
                        
                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                        
                        	Is DAI Dstination MAC Address Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                        
                        	Is DAI IPv4 Addr Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                        
                        	Is DAI Source MAC Address Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_enabled
                        
                        	Is Dynamic ARP Inspection Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_logging_enabled
                        
                        	Is DAI Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_source_guard_enabled
                        
                        	Is IP Source Guard Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_ipsg_logging_enabled
                        
                        	Is IP Source Guard Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                        
                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_enabled
                        
                        	Is MAC Secure Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_logging_enabled
                        
                        	Is MAC Secure Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: learn_disabled_mac_limit_action
                        
                        	Learning disabled due to MAC limit action
                        	**type**\:  bool
                        
                        .. attribute:: mac_aging_mode
                        
                        	MAC Aging Mode
                        	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                        
                        .. attribute:: mac_aging_time
                        
                        	MAC aging time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: mac_flooding
                        
                        	MAC flooding enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_learning
                        
                        	MAC learning enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_limit
                        
                        	MAC address limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_limit_action
                        
                        	MAC limit action
                        	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                        
                        .. attribute:: mac_limit_notification
                        
                        	MAC limit notification
                        	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                        
                        .. attribute:: mac_limit_reached
                        
                        	MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mac_port_down_flush_enabled
                        
                        	MAC Flush when port goes down
                        	**type**\:  bool
                        
                        .. attribute:: mac_secure_action
                        
                        	MAC Secure Action
                        	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                        
                        .. attribute:: mld_profile_name
                        
                        	MLD Profile Name
                        	**type**\:  str
                        
                        .. attribute:: mmrp_flood_optimization
                        
                        	MMRP Flood Optimization Status
                        	**type**\:  bool
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        .. attribute:: split_horizon_group_id
                        
                        	Split Horizon Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__init__()

                            self.yang_name = "security-parameters"
                            self.yang_parent_name = "bridge-domain-info"

                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                            self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                            self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                            self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                            self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                            self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                            self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                            self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                            self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                            self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                            self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                            self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                            self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                            self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                            self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                            self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                            self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                            self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                            self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                            self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                            self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                            self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                            self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                            self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                            self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                            self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                            self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                            self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                            self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                            self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                            self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                            self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self._children_name_map["storm_control"] = "storm-control"
                            self._children_yang_names.add("storm-control")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("broadcast_storm_control_kb_ps",
                                            "broadcast_storm_control_pps",
                                            "broadcast_storm_control_rate_unit",
                                            "dai_address_validation_mask",
                                            "dhcpv4_profile_name",
                                            "dhcpv4_snoop",
                                            "flood_unknown_unicast_enabled",
                                            "flood_uu_disabled_mac_limit_action",
                                            "igm_pv4_disabled",
                                            "igm_pv4_profile_name",
                                            "is_dai_addr_validate_destination_mac_enabled",
                                            "is_dai_addr_validate_ipv4_enabled",
                                            "is_dai_addr_validate_source_mac_enabled",
                                            "is_dai_enabled",
                                            "is_dai_logging_enabled",
                                            "is_ip_source_guard_enabled",
                                            "is_ipsg_logging_enabled",
                                            "is_mac_secure_accept_shutdown_enabled",
                                            "is_mac_secure_enabled",
                                            "is_mac_secure_logging_enabled",
                                            "learn_disabled_mac_limit_action",
                                            "mac_aging_mode",
                                            "mac_aging_time",
                                            "mac_flooding",
                                            "mac_learning",
                                            "mac_limit",
                                            "mac_limit_action",
                                            "mac_limit_notification",
                                            "mac_limit_reached",
                                            "mac_port_down_flush_enabled",
                                            "mac_secure_action",
                                            "mld_profile_name",
                                            "mmrp_flood_optimization",
                                            "multicast_storm_control_kb_ps",
                                            "multicast_storm_control_pps",
                                            "multicast_storm_control_rate_unit",
                                            "split_horizon_group_id",
                                            "unicast_storm_control_kb_ps",
                                            "unicast_storm_control_pps",
                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__setattr__(name, value)


                        class StormControl(Entity):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\:  bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__init__()

                                self.yang_name = "storm-control"
                                self.yang_parent_name = "security-parameters"

                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                self.multicast = YLeaf(YType.boolean, "multicast")

                                self.unicast = YLeaf(YType.boolean, "unicast")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bd_policer",
                                                "broadcast",
                                                "multicast",
                                                "unicast") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bd_policer.is_set or
                                    self.broadcast.is_set or
                                    self.multicast.is_set or
                                    self.unicast.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bd_policer.yfilter != YFilter.not_set or
                                    self.broadcast.yfilter != YFilter.not_set or
                                    self.multicast.yfilter != YFilter.not_set or
                                    self.unicast.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "storm-control" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/security-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bd-policer"):
                                    self.bd_policer = value
                                    self.bd_policer.value_namespace = name_space
                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast"):
                                    self.broadcast = value
                                    self.broadcast.value_namespace = name_space
                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast"):
                                    self.multicast = value
                                    self.multicast.value_namespace = name_space
                                    self.multicast.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast"):
                                    self.unicast = value
                                    self.unicast.value_namespace = name_space
                                    self.unicast.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.broadcast_storm_control_kb_ps.is_set or
                                self.broadcast_storm_control_pps.is_set or
                                self.broadcast_storm_control_rate_unit.is_set or
                                self.dai_address_validation_mask.is_set or
                                self.dhcpv4_profile_name.is_set or
                                self.dhcpv4_snoop.is_set or
                                self.flood_unknown_unicast_enabled.is_set or
                                self.flood_uu_disabled_mac_limit_action.is_set or
                                self.igm_pv4_disabled.is_set or
                                self.igm_pv4_profile_name.is_set or
                                self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                self.is_dai_addr_validate_ipv4_enabled.is_set or
                                self.is_dai_addr_validate_source_mac_enabled.is_set or
                                self.is_dai_enabled.is_set or
                                self.is_dai_logging_enabled.is_set or
                                self.is_ip_source_guard_enabled.is_set or
                                self.is_ipsg_logging_enabled.is_set or
                                self.is_mac_secure_accept_shutdown_enabled.is_set or
                                self.is_mac_secure_enabled.is_set or
                                self.is_mac_secure_logging_enabled.is_set or
                                self.learn_disabled_mac_limit_action.is_set or
                                self.mac_aging_mode.is_set or
                                self.mac_aging_time.is_set or
                                self.mac_flooding.is_set or
                                self.mac_learning.is_set or
                                self.mac_limit.is_set or
                                self.mac_limit_action.is_set or
                                self.mac_limit_notification.is_set or
                                self.mac_limit_reached.is_set or
                                self.mac_port_down_flush_enabled.is_set or
                                self.mac_secure_action.is_set or
                                self.mld_profile_name.is_set or
                                self.mmrp_flood_optimization.is_set or
                                self.multicast_storm_control_kb_ps.is_set or
                                self.multicast_storm_control_pps.is_set or
                                self.multicast_storm_control_rate_unit.is_set or
                                self.split_horizon_group_id.is_set or
                                self.unicast_storm_control_kb_ps.is_set or
                                self.unicast_storm_control_pps.is_set or
                                self.unicast_storm_control_rate_unit.is_set or
                                (self.storm_control is not None and self.storm_control.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                self.is_dai_enabled.yfilter != YFilter.not_set or
                                self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                self.mac_aging_mode.yfilter != YFilter.not_set or
                                self.mac_aging_time.yfilter != YFilter.not_set or
                                self.mac_flooding.yfilter != YFilter.not_set or
                                self.mac_learning.yfilter != YFilter.not_set or
                                self.mac_limit.yfilter != YFilter.not_set or
                                self.mac_limit_action.yfilter != YFilter.not_set or
                                self.mac_limit_notification.yfilter != YFilter.not_set or
                                self.mac_limit_reached.yfilter != YFilter.not_set or
                                self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                self.mac_secure_action.yfilter != YFilter.not_set or
                                self.mld_profile_name.yfilter != YFilter.not_set or
                                self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                self.split_horizon_group_id.yfilter != YFilter.not_set or
                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                (self.storm_control is not None and self.storm_control.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "security-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                            if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                            if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                            if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                            if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                            if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                            if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                            if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                            if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                            if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                            if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                            if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                            if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                            if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                            if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                            if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                            if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                            if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                            if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                            if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                            if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                            if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                            if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_learning.get_name_leafdata())
                            if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit.get_name_leafdata())
                            if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                            if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                            if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                            if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                            if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                            if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                            if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                            if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "storm-control"):
                                if (self.storm_control is None):
                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                return self.storm_control

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "broadcast-storm-control-kb-ps"):
                                self.broadcast_storm_control_kb_ps = value
                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-pps"):
                                self.broadcast_storm_control_pps = value
                                self.broadcast_storm_control_pps.value_namespace = name_space
                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-rate-unit"):
                                self.broadcast_storm_control_rate_unit = value
                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "dai-address-validation-mask"):
                                self.dai_address_validation_mask = value
                                self.dai_address_validation_mask.value_namespace = name_space
                                self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "dhcpv4-profile-name"):
                                self.dhcpv4_profile_name = value
                                self.dhcpv4_profile_name.value_namespace = name_space
                                self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "dhcpv4-snoop"):
                                self.dhcpv4_snoop = value
                                self.dhcpv4_snoop.value_namespace = name_space
                                self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                            if(value_path == "flood-unknown-unicast-enabled"):
                                self.flood_unknown_unicast_enabled = value
                                self.flood_unknown_unicast_enabled.value_namespace = name_space
                                self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "flood-uu-disabled-mac-limit-action"):
                                self.flood_uu_disabled_mac_limit_action = value
                                self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                            if(value_path == "igm-pv4-disabled"):
                                self.igm_pv4_disabled = value
                                self.igm_pv4_disabled.value_namespace = name_space
                                self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "igm-pv4-profile-name"):
                                self.igm_pv4_profile_name = value
                                self.igm_pv4_profile_name.value_namespace = name_space
                                self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                self.is_dai_addr_validate_destination_mac_enabled = value
                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                self.is_dai_addr_validate_ipv4_enabled = value
                                self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                self.is_dai_addr_validate_source_mac_enabled = value
                                self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dai-enabled"):
                                self.is_dai_enabled = value
                                self.is_dai_enabled.value_namespace = name_space
                                self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dai-logging-enabled"):
                                self.is_dai_logging_enabled = value
                                self.is_dai_logging_enabled.value_namespace = name_space
                                self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-source-guard-enabled"):
                                self.is_ip_source_guard_enabled = value
                                self.is_ip_source_guard_enabled.value_namespace = name_space
                                self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ipsg-logging-enabled"):
                                self.is_ipsg_logging_enabled = value
                                self.is_ipsg_logging_enabled.value_namespace = name_space
                                self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                self.is_mac_secure_accept_shutdown_enabled = value
                                self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-mac-secure-enabled"):
                                self.is_mac_secure_enabled = value
                                self.is_mac_secure_enabled.value_namespace = name_space
                                self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-mac-secure-logging-enabled"):
                                self.is_mac_secure_logging_enabled = value
                                self.is_mac_secure_logging_enabled.value_namespace = name_space
                                self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "learn-disabled-mac-limit-action"):
                                self.learn_disabled_mac_limit_action = value
                                self.learn_disabled_mac_limit_action.value_namespace = name_space
                                self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-aging-mode"):
                                self.mac_aging_mode = value
                                self.mac_aging_mode.value_namespace = name_space
                                self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-aging-time"):
                                self.mac_aging_time = value
                                self.mac_aging_time.value_namespace = name_space
                                self.mac_aging_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-flooding"):
                                self.mac_flooding = value
                                self.mac_flooding.value_namespace = name_space
                                self.mac_flooding.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-learning"):
                                self.mac_learning = value
                                self.mac_learning.value_namespace = name_space
                                self.mac_learning.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit"):
                                self.mac_limit = value
                                self.mac_limit.value_namespace = name_space
                                self.mac_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-action"):
                                self.mac_limit_action = value
                                self.mac_limit_action.value_namespace = name_space
                                self.mac_limit_action.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-notification"):
                                self.mac_limit_notification = value
                                self.mac_limit_notification.value_namespace = name_space
                                self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-reached"):
                                self.mac_limit_reached = value
                                self.mac_limit_reached.value_namespace = name_space
                                self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-port-down-flush-enabled"):
                                self.mac_port_down_flush_enabled = value
                                self.mac_port_down_flush_enabled.value_namespace = name_space
                                self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-secure-action"):
                                self.mac_secure_action = value
                                self.mac_secure_action.value_namespace = name_space
                                self.mac_secure_action.value_namespace_prefix = name_space_prefix
                            if(value_path == "mld-profile-name"):
                                self.mld_profile_name = value
                                self.mld_profile_name.value_namespace = name_space
                                self.mld_profile_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "mmrp-flood-optimization"):
                                self.mmrp_flood_optimization = value
                                self.mmrp_flood_optimization.value_namespace = name_space
                                self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-kb-ps"):
                                self.multicast_storm_control_kb_ps = value
                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-pps"):
                                self.multicast_storm_control_pps = value
                                self.multicast_storm_control_pps.value_namespace = name_space
                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-rate-unit"):
                                self.multicast_storm_control_rate_unit = value
                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "split-horizon-group-id"):
                                self.split_horizon_group_id = value
                                self.split_horizon_group_id.value_namespace = name_space
                                self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-kb-ps"):
                                self.unicast_storm_control_kb_ps = value
                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-pps"):
                                self.unicast_storm_control_pps = value
                                self.unicast_storm_control_pps.value_namespace = name_space
                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-rate-unit"):
                                self.unicast_storm_control_rate_unit = value
                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                    class PbbParameters(Entity):
                        """
                        PBB parameters
                        
                        .. attribute:: pbb_core
                        
                        	PBB Core
                        	**type**\:   :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                        
                        .. attribute:: pbb_edge
                        
                        	PBB Edge
                        	**type**\:   :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                        
                        .. attribute:: type
                        
                        	Type
                        	**type**\:   :py:class:`L2VpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__init__()

                            self.yang_name = "pbb-parameters"
                            self.yang_parent_name = "bridge-domain-info"

                            self.type = YLeaf(YType.enumeration, "type")

                            self.pbb_core = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                            self.pbb_core.parent = self
                            self._children_name_map["pbb_core"] = "pbb-core"
                            self._children_yang_names.add("pbb-core")

                            self.pbb_edge = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                            self.pbb_edge.parent = self
                            self._children_name_map["pbb_edge"] = "pbb-edge"
                            self._children_yang_names.add("pbb-edge")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__setattr__(name, value)


                        class PbbEdge(Entity):
                            """
                            PBB Edge
                            
                            .. attribute:: core_bridge_name
                            
                            	Core Bridge Domain Name
                            	**type**\:  str
                            
                            .. attribute:: core_bridge_state
                            
                            	Core Bridge State
                            	**type**\:   :py:class:`L2VpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeState>`
                            
                            .. attribute:: edge_port
                            
                            	PBB Edge Port
                            	**type**\:   :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                            
                            .. attribute:: i_sid
                            
                            	SID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mirp_lite_protocol
                            
                            	MIRP\-lite protocol info
                            	**type**\:   :py:class:`L2VpnMirpLiteProtocolInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteProtocolInfo>`
                            
                            .. attribute:: mirp_lite_status
                            
                            	MIRP\-lite Status
                            	**type**\:   :py:class:`L2VpnMirpLiteStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteStatus>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__init__()

                                self.yang_name = "pbb-edge"
                                self.yang_parent_name = "pbb-parameters"

                                self.core_bridge_name = YLeaf(YType.str, "core-bridge-name")

                                self.core_bridge_state = YLeaf(YType.enumeration, "core-bridge-state")

                                self.i_sid = YLeaf(YType.uint32, "i-sid")

                                self.mirp_lite_protocol = YLeaf(YType.enumeration, "mirp-lite-protocol")

                                self.mirp_lite_status = YLeaf(YType.enumeration, "mirp-lite-status")

                                self.edge_port = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                self.edge_port.parent = self
                                self._children_name_map["edge_port"] = "edge-port"
                                self._children_yang_names.add("edge-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("core_bridge_name",
                                                "core_bridge_state",
                                                "i_sid",
                                                "mirp_lite_protocol",
                                                "mirp_lite_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__setattr__(name, value)


                            class EdgePort(Entity):
                                """
                                PBB Edge Port
                                
                                .. attribute:: bmac_mapping
                                
                                	CMAC to BMAC Mapping
                                	**type**\: list of    :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                                
                                .. attribute:: edge_port_state
                                
                                	PBB Edge Port State
                                	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                                
                                .. attribute:: unknown_unicast_mac
                                
                                	Unknown Unicast MAC
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: unknown_unicast_mac_set
                                
                                	Unknown Unicast MAC Configured
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__init__()

                                    self.yang_name = "edge-port"
                                    self.yang_parent_name = "pbb-edge"

                                    self.edge_port_state = YLeaf(YType.enumeration, "edge-port-state")

                                    self.unknown_unicast_mac = YLeaf(YType.str, "unknown-unicast-mac")

                                    self.unknown_unicast_mac_set = YLeaf(YType.boolean, "unknown-unicast-mac-set")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                    self._children_yang_names.add("security-parameters")

                                    self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._children_yang_names.add("statistics")

                                    self.bmac_mapping = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("edge_port_state",
                                                    "unknown_unicast_mac",
                                                    "unknown_unicast_mac_set",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__setattr__(name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "edge-port"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                        self._children_yang_names.add("base")

                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dhcpv4_trust",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__setattr__(name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"

                                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                            self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                            self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                            self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                            self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                            self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                            self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                            self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                            self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                            self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                            self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                            self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                            self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                            self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                            self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                            self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                            self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                            self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                            self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                            self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                            self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                            self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                            self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                            self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                            self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                            self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                            self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                            self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                            self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                            self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                            self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                            self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._children_yang_names.add("storm-control")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("broadcast_storm_control_kb_ps",
                                                            "broadcast_storm_control_pps",
                                                            "broadcast_storm_control_rate_unit",
                                                            "dai_address_validation_mask",
                                                            "dhcpv4_profile_name",
                                                            "dhcpv4_snoop",
                                                            "flood_unknown_unicast_enabled",
                                                            "flood_uu_disabled_mac_limit_action",
                                                            "igm_pv4_disabled",
                                                            "igm_pv4_profile_name",
                                                            "is_dai_addr_validate_destination_mac_enabled",
                                                            "is_dai_addr_validate_ipv4_enabled",
                                                            "is_dai_addr_validate_source_mac_enabled",
                                                            "is_dai_enabled",
                                                            "is_dai_logging_enabled",
                                                            "is_ip_source_guard_enabled",
                                                            "is_ipsg_logging_enabled",
                                                            "is_mac_secure_accept_shutdown_enabled",
                                                            "is_mac_secure_enabled",
                                                            "is_mac_secure_logging_enabled",
                                                            "learn_disabled_mac_limit_action",
                                                            "mac_aging_mode",
                                                            "mac_aging_time",
                                                            "mac_flooding",
                                                            "mac_learning",
                                                            "mac_limit",
                                                            "mac_limit_action",
                                                            "mac_limit_notification",
                                                            "mac_limit_reached",
                                                            "mac_port_down_flush_enabled",
                                                            "mac_secure_action",
                                                            "mld_profile_name",
                                                            "mmrp_flood_optimization",
                                                            "multicast_storm_control_kb_ps",
                                                            "multicast_storm_control_pps",
                                                            "multicast_storm_control_rate_unit",
                                                            "split_horizon_group_id",
                                                            "unicast_storm_control_kb_ps",
                                                            "unicast_storm_control_pps",
                                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__setattr__(name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"

                                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                self.multicast = YLeaf(YType.boolean, "multicast")

                                                self.unicast = YLeaf(YType.boolean, "unicast")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bd_policer",
                                                                "broadcast",
                                                                "multicast",
                                                                "unicast") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bd_policer.is_set or
                                                    self.broadcast.is_set or
                                                    self.multicast.is_set or
                                                    self.unicast.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bd_policer.yfilter != YFilter.not_set or
                                                    self.broadcast.yfilter != YFilter.not_set or
                                                    self.multicast.yfilter != YFilter.not_set or
                                                    self.unicast.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "storm-control" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/base/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bd-policer"):
                                                    self.bd_policer = value
                                                    self.bd_policer.value_namespace = name_space
                                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast"):
                                                    self.broadcast = value
                                                    self.broadcast.value_namespace = name_space
                                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast"):
                                                    self.multicast = value
                                                    self.multicast.value_namespace = name_space
                                                    self.multicast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast"):
                                                    self.unicast = value
                                                    self.unicast.value_namespace = name_space
                                                    self.unicast.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.broadcast_storm_control_kb_ps.is_set or
                                                self.broadcast_storm_control_pps.is_set or
                                                self.broadcast_storm_control_rate_unit.is_set or
                                                self.dai_address_validation_mask.is_set or
                                                self.dhcpv4_profile_name.is_set or
                                                self.dhcpv4_snoop.is_set or
                                                self.flood_unknown_unicast_enabled.is_set or
                                                self.flood_uu_disabled_mac_limit_action.is_set or
                                                self.igm_pv4_disabled.is_set or
                                                self.igm_pv4_profile_name.is_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                                self.is_dai_addr_validate_ipv4_enabled.is_set or
                                                self.is_dai_addr_validate_source_mac_enabled.is_set or
                                                self.is_dai_enabled.is_set or
                                                self.is_dai_logging_enabled.is_set or
                                                self.is_ip_source_guard_enabled.is_set or
                                                self.is_ipsg_logging_enabled.is_set or
                                                self.is_mac_secure_accept_shutdown_enabled.is_set or
                                                self.is_mac_secure_enabled.is_set or
                                                self.is_mac_secure_logging_enabled.is_set or
                                                self.learn_disabled_mac_limit_action.is_set or
                                                self.mac_aging_mode.is_set or
                                                self.mac_aging_time.is_set or
                                                self.mac_flooding.is_set or
                                                self.mac_learning.is_set or
                                                self.mac_limit.is_set or
                                                self.mac_limit_action.is_set or
                                                self.mac_limit_notification.is_set or
                                                self.mac_limit_reached.is_set or
                                                self.mac_port_down_flush_enabled.is_set or
                                                self.mac_secure_action.is_set or
                                                self.mld_profile_name.is_set or
                                                self.mmrp_flood_optimization.is_set or
                                                self.multicast_storm_control_kb_ps.is_set or
                                                self.multicast_storm_control_pps.is_set or
                                                self.multicast_storm_control_rate_unit.is_set or
                                                self.split_horizon_group_id.is_set or
                                                self.unicast_storm_control_kb_ps.is_set or
                                                self.unicast_storm_control_pps.is_set or
                                                self.unicast_storm_control_rate_unit.is_set or
                                                (self.storm_control is not None and self.storm_control.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                                self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                                self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                                self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                                self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                                self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                                self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                                self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_aging_mode.yfilter != YFilter.not_set or
                                                self.mac_aging_time.yfilter != YFilter.not_set or
                                                self.mac_flooding.yfilter != YFilter.not_set or
                                                self.mac_learning.yfilter != YFilter.not_set or
                                                self.mac_limit.yfilter != YFilter.not_set or
                                                self.mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_limit_notification.yfilter != YFilter.not_set or
                                                self.mac_limit_reached.yfilter != YFilter.not_set or
                                                self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                                self.mac_secure_action.yfilter != YFilter.not_set or
                                                self.mld_profile_name.yfilter != YFilter.not_set or
                                                self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.split_horizon_group_id.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                (self.storm_control is not None and self.storm_control.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "base" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                            if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                            if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                            if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                            if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                            if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                            if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                            if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                            if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                            if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                            if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                            if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                            if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                            if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                            if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                            if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                            if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                            if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                            if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                            if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                            if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                            if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "storm-control"):
                                                if (self.storm_control is None):
                                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                                    self.storm_control.parent = self
                                                    self._children_name_map["storm_control"] = "storm-control"
                                                return self.storm_control

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "broadcast-storm-control-kb-ps"):
                                                self.broadcast_storm_control_kb_ps = value
                                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-pps"):
                                                self.broadcast_storm_control_pps = value
                                                self.broadcast_storm_control_pps.value_namespace = name_space
                                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-rate-unit"):
                                                self.broadcast_storm_control_rate_unit = value
                                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dai-address-validation-mask"):
                                                self.dai_address_validation_mask = value
                                                self.dai_address_validation_mask.value_namespace = name_space
                                                self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-profile-name"):
                                                self.dhcpv4_profile_name = value
                                                self.dhcpv4_profile_name.value_namespace = name_space
                                                self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-snoop"):
                                                self.dhcpv4_snoop = value
                                                self.dhcpv4_snoop.value_namespace = name_space
                                                self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-unknown-unicast-enabled"):
                                                self.flood_unknown_unicast_enabled = value
                                                self.flood_unknown_unicast_enabled.value_namespace = name_space
                                                self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-uu-disabled-mac-limit-action"):
                                                self.flood_uu_disabled_mac_limit_action = value
                                                self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                                self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-disabled"):
                                                self.igm_pv4_disabled = value
                                                self.igm_pv4_disabled.value_namespace = name_space
                                                self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-profile-name"):
                                                self.igm_pv4_profile_name = value
                                                self.igm_pv4_profile_name.value_namespace = name_space
                                                self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                                self.is_dai_addr_validate_destination_mac_enabled = value
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                                self.is_dai_addr_validate_ipv4_enabled = value
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                                self.is_dai_addr_validate_source_mac_enabled = value
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-enabled"):
                                                self.is_dai_enabled = value
                                                self.is_dai_enabled.value_namespace = name_space
                                                self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-logging-enabled"):
                                                self.is_dai_logging_enabled = value
                                                self.is_dai_logging_enabled.value_namespace = name_space
                                                self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ip-source-guard-enabled"):
                                                self.is_ip_source_guard_enabled = value
                                                self.is_ip_source_guard_enabled.value_namespace = name_space
                                                self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ipsg-logging-enabled"):
                                                self.is_ipsg_logging_enabled = value
                                                self.is_ipsg_logging_enabled.value_namespace = name_space
                                                self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                                self.is_mac_secure_accept_shutdown_enabled = value
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-enabled"):
                                                self.is_mac_secure_enabled = value
                                                self.is_mac_secure_enabled.value_namespace = name_space
                                                self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-logging-enabled"):
                                                self.is_mac_secure_logging_enabled = value
                                                self.is_mac_secure_logging_enabled.value_namespace = name_space
                                                self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "learn-disabled-mac-limit-action"):
                                                self.learn_disabled_mac_limit_action = value
                                                self.learn_disabled_mac_limit_action.value_namespace = name_space
                                                self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-mode"):
                                                self.mac_aging_mode = value
                                                self.mac_aging_mode.value_namespace = name_space
                                                self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-time"):
                                                self.mac_aging_time = value
                                                self.mac_aging_time.value_namespace = name_space
                                                self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-flooding"):
                                                self.mac_flooding = value
                                                self.mac_flooding.value_namespace = name_space
                                                self.mac_flooding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-learning"):
                                                self.mac_learning = value
                                                self.mac_learning.value_namespace = name_space
                                                self.mac_learning.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit"):
                                                self.mac_limit = value
                                                self.mac_limit.value_namespace = name_space
                                                self.mac_limit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-action"):
                                                self.mac_limit_action = value
                                                self.mac_limit_action.value_namespace = name_space
                                                self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-notification"):
                                                self.mac_limit_notification = value
                                                self.mac_limit_notification.value_namespace = name_space
                                                self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-reached"):
                                                self.mac_limit_reached = value
                                                self.mac_limit_reached.value_namespace = name_space
                                                self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-port-down-flush-enabled"):
                                                self.mac_port_down_flush_enabled = value
                                                self.mac_port_down_flush_enabled.value_namespace = name_space
                                                self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-secure-action"):
                                                self.mac_secure_action = value
                                                self.mac_secure_action.value_namespace = name_space
                                                self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mld-profile-name"):
                                                self.mld_profile_name = value
                                                self.mld_profile_name.value_namespace = name_space
                                                self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mmrp-flood-optimization"):
                                                self.mmrp_flood_optimization = value
                                                self.mmrp_flood_optimization.value_namespace = name_space
                                                self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-kb-ps"):
                                                self.multicast_storm_control_kb_ps = value
                                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-pps"):
                                                self.multicast_storm_control_pps = value
                                                self.multicast_storm_control_pps.value_namespace = name_space
                                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-rate-unit"):
                                                self.multicast_storm_control_rate_unit = value
                                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "split-horizon-group-id"):
                                                self.split_horizon_group_id = value
                                                self.split_horizon_group_id.value_namespace = name_space
                                                self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-kb-ps"):
                                                self.unicast_storm_control_kb_ps = value
                                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-pps"):
                                                self.unicast_storm_control_pps = value
                                                self.unicast_storm_control_pps.value_namespace = name_space
                                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-rate-unit"):
                                                self.unicast_storm_control_rate_unit = value
                                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dhcpv4_trust.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.base is not None and self.base.has_data()) or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dhcpv4_trust.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.base is not None and self.base.has_operation()) or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security-parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "base"):
                                            if (self.base is None):
                                                self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                                self.base.parent = self
                                                self._children_name_map["base"] = "base"
                                            return self.base

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-trust"):
                                            self.dhcpv4_trust = value
                                            self.dhcpv4_trust.value_namespace = name_space
                                            self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "edge-port"

                                        self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        self._children_yang_names.add("dispostion-stats")

                                        self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                        self._children_yang_names.add("impostion-stats")

                                        self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._children_yang_names.add("sequence-number")


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                            self._children_yang_names.add("broadcast")

                                            self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            self._children_yang_names.add("imposition-mtu-drop")

                                            self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                            self._children_yang_names.add("imposition-stat")

                                            self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            self._children_yang_names.add("impostion-tail-drop")

                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            self._children_yang_names.add("l2fsbi-drop")

                                            self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                            self._children_yang_names.add("multicast")

                                            self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._children_yang_names.add("unknown-unicast")


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class L2FsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2fsbi-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast is not None and self.broadcast.has_data()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                (self.multicast is not None and self.multicast.has_data()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast is not None and self.broadcast.has_operation()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                (self.multicast is not None and self.multicast.has_operation()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast"):
                                                if (self.broadcast is None):
                                                    self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                                    self.broadcast.parent = self
                                                    self._children_name_map["broadcast"] = "broadcast"
                                                return self.broadcast

                                            if (child_yang_name == "imposition-mtu-drop"):
                                                if (self.imposition_mtu_drop is None):
                                                    self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                    self.imposition_mtu_drop.parent = self
                                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                return self.imposition_mtu_drop

                                            if (child_yang_name == "imposition-stat"):
                                                if (self.imposition_stat is None):
                                                    self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                                    self.imposition_stat.parent = self
                                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                                return self.imposition_stat

                                            if (child_yang_name == "impostion-tail-drop"):
                                                if (self.impostion_tail_drop is None):
                                                    self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                                    self.impostion_tail_drop.parent = self
                                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                return self.impostion_tail_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "l2fsbi-drop"):
                                                if (self.l2fsbi_drop is None):
                                                    self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                                    self.l2fsbi_drop.parent = self
                                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                return self.l2fsbi_drop

                                            if (child_yang_name == "multicast"):
                                                if (self.multicast is None):
                                                    self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                                    self.multicast.parent = self
                                                    self._children_name_map["multicast"] = "multicast"
                                                return self.multicast

                                            if (child_yang_name == "unknown-unicast"):
                                                if (self.unknown_unicast is None):
                                                    self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                                    self.unknown_unicast.parent = self
                                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                return self.unknown_unicast

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            self._children_yang_names.add("broadcast-drop")

                                            self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                            self._children_yang_names.add("dai-drop")

                                            self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            self._children_yang_names.add("disposition-mtu-drop")

                                            self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            self._children_yang_names.add("disposition-oo-o-drops")

                                            self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            self._children_yang_names.add("disposition-p2mp-stats")

                                            self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                            self._children_yang_names.add("disposition-stat")

                                            self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            self._children_yang_names.add("disposition-tail-drop")

                                            self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            self._children_yang_names.add("ipsg-drop")

                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._children_yang_names.add("mac-move")

                                            self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                            self._children_yang_names.add("multicast-drop")

                                            self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                            self._children_yang_names.add("received-drops")

                                            self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                            self._children_yang_names.add("unicast-drop")


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "received-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dai-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipsg-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-oo-o-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionP2MpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-p2mp-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mac-move" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.mac_move is not None and self.mac_move.has_data()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                (self.received_drops is not None and self.received_drops.has_data()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.mac_move is not None and self.mac_move.has_operation()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                (self.received_drops is not None and self.received_drops.has_operation()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dispostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast-drop"):
                                                if (self.broadcast_drop is None):
                                                    self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                                    self.broadcast_drop.parent = self
                                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                return self.broadcast_drop

                                            if (child_yang_name == "dai-drop"):
                                                if (self.dai_drop is None):
                                                    self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                                    self.dai_drop.parent = self
                                                    self._children_name_map["dai_drop"] = "dai-drop"
                                                return self.dai_drop

                                            if (child_yang_name == "disposition-mtu-drop"):
                                                if (self.disposition_mtu_drop is None):
                                                    self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                                    self.disposition_mtu_drop.parent = self
                                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                return self.disposition_mtu_drop

                                            if (child_yang_name == "disposition-oo-o-drops"):
                                                if (self.disposition_oo_o_drops is None):
                                                    self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                                    self.disposition_oo_o_drops.parent = self
                                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                return self.disposition_oo_o_drops

                                            if (child_yang_name == "disposition-p2mp-stats"):
                                                if (self.disposition_p2mp_stats is None):
                                                    self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                                    self.disposition_p2mp_stats.parent = self
                                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                return self.disposition_p2mp_stats

                                            if (child_yang_name == "disposition-stat"):
                                                if (self.disposition_stat is None):
                                                    self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                                    self.disposition_stat.parent = self
                                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                                return self.disposition_stat

                                            if (child_yang_name == "disposition-tail-drop"):
                                                if (self.disposition_tail_drop is None):
                                                    self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                                    self.disposition_tail_drop.parent = self
                                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                return self.disposition_tail_drop

                                            if (child_yang_name == "ipsg-drop"):
                                                if (self.ipsg_drop is None):
                                                    self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                                    self.ipsg_drop.parent = self
                                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                return self.ipsg_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "mac-move"):
                                                if (self.mac_move is None):
                                                    self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                                    self.mac_move.parent = self
                                                    self._children_name_map["mac_move"] = "mac-move"
                                                return self.mac_move

                                            if (child_yang_name == "multicast-drop"):
                                                if (self.multicast_drop is None):
                                                    self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                                    self.multicast_drop.parent = self
                                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                                return self.multicast_drop

                                            if (child_yang_name == "received-drops"):
                                                if (self.received_drops is None):
                                                    self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                                    self.received_drops.parent = self
                                                    self._children_name_map["received_drops"] = "received-drops"
                                                return self.received_drops

                                            if (child_yang_name == "unicast-drop"):
                                                if (self.unicast_drop is None):
                                                    self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                                    self.unicast_drop.parent = self
                                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                                return self.unicast_drop

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"

                                            self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                            self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                            self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                            self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bypassed_inbound_sequence_packet",
                                                            "bypassed_out_sequence_packet",
                                                            "sequence_number_expected",
                                                            "sequence_number_sent") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bypassed_inbound_sequence_packet.is_set or
                                                self.bypassed_out_sequence_packet.is_set or
                                                self.sequence_number_expected.is_set or
                                                self.sequence_number_sent.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                self.sequence_number_expected.yfilter != YFilter.not_set or
                                                self.sequence_number_sent.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sequence-number" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                            if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                            if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                            if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bypassed-inbound-sequence-packet"):
                                                self.bypassed_inbound_sequence_packet = value
                                                self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bypassed-out-sequence-packet"):
                                                self.bypassed_out_sequence_packet = value
                                                self.bypassed_out_sequence_packet.value_namespace = name_space
                                                self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-expected"):
                                                self.sequence_number_expected = value
                                                self.sequence_number_expected.value_namespace = name_space
                                                self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-sent"):
                                                self.sequence_number_sent = value
                                                self.sequence_number_sent.value_namespace = name_space
                                                self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                            (self.sequence_number is not None and self.sequence_number.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                            (self.sequence_number is not None and self.sequence_number.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "statistics" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dispostion-stats"):
                                            if (self.dispostion_stats is None):
                                                self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                                self.dispostion_stats.parent = self
                                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            return self.dispostion_stats

                                        if (child_yang_name == "impostion-stats"):
                                            if (self.impostion_stats is None):
                                                self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                                self.impostion_stats.parent = self
                                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                            return self.impostion_stats

                                        if (child_yang_name == "sequence-number"):
                                            if (self.sequence_number is None):
                                                self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                                self.sequence_number.parent = self
                                                self._children_name_map["sequence_number"] = "sequence-number"
                                            return self.sequence_number

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class BmacMapping(Entity):
                                    """
                                    CMAC to BMAC Mapping
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__init__()

                                        self.yang_name = "bmac-mapping"
                                        self.yang_parent_name = "edge-port"

                                        self.address = YLeaf(YType.str, "address")

                                        self.bmac = YLeaf(YType.str, "bmac")

                                        self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("address",
                                                        "bmac",
                                                        "next_hop_ip") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.address.is_set or
                                            self.bmac.is_set or
                                            self.next_hop_ip.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.address.yfilter != YFilter.not_set or
                                            self.bmac.yfilter != YFilter.not_set or
                                            self.next_hop_ip.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bmac-mapping" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.address.get_name_leafdata())
                                        if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bmac.get_name_leafdata())
                                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "address"):
                                            self.address = value
                                            self.address.value_namespace = name_space
                                            self.address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bmac"):
                                            self.bmac = value
                                            self.bmac.value_namespace = name_space
                                            self.bmac.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop-ip"):
                                            self.next_hop_ip = value
                                            self.next_hop_ip.value_namespace = name_space
                                            self.next_hop_ip.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.bmac_mapping:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.edge_port_state.is_set or
                                        self.unknown_unicast_mac.is_set or
                                        self.unknown_unicast_mac_set.is_set or
                                        self.xconnect_id.is_set or
                                        (self.security_parameters is not None and self.security_parameters.has_data()) or
                                        (self.statistics is not None and self.statistics.has_data()))

                                def has_operation(self):
                                    for c in self.bmac_mapping:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.edge_port_state.yfilter != YFilter.not_set or
                                        self.unknown_unicast_mac.yfilter != YFilter.not_set or
                                        self.unknown_unicast_mac_set.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                        (self.statistics is not None and self.statistics.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "edge-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.edge_port_state.is_set or self.edge_port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.edge_port_state.get_name_leafdata())
                                    if (self.unknown_unicast_mac.is_set or self.unknown_unicast_mac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unknown_unicast_mac.get_name_leafdata())
                                    if (self.unknown_unicast_mac_set.is_set or self.unknown_unicast_mac_set.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unknown_unicast_mac_set.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "bmac-mapping"):
                                        for c in self.bmac_mapping:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.bmac_mapping.append(c)
                                        return c

                                    if (child_yang_name == "security-parameters"):
                                        if (self.security_parameters is None):
                                            self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                            self.security_parameters.parent = self
                                            self._children_name_map["security_parameters"] = "security-parameters"
                                        return self.security_parameters

                                    if (child_yang_name == "statistics"):
                                        if (self.statistics is None):
                                            self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                            self.statistics.parent = self
                                            self._children_name_map["statistics"] = "statistics"
                                        return self.statistics

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bmac-mapping" or name == "security-parameters" or name == "statistics" or name == "edge-port-state" or name == "unknown-unicast-mac" or name == "unknown-unicast-mac-set" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "edge-port-state"):
                                        self.edge_port_state = value
                                        self.edge_port_state.value_namespace = name_space
                                        self.edge_port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unknown-unicast-mac"):
                                        self.unknown_unicast_mac = value
                                        self.unknown_unicast_mac.value_namespace = name_space
                                        self.unknown_unicast_mac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unknown-unicast-mac-set"):
                                        self.unknown_unicast_mac_set = value
                                        self.unknown_unicast_mac_set.value_namespace = name_space
                                        self.unknown_unicast_mac_set.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.core_bridge_name.is_set or
                                    self.core_bridge_state.is_set or
                                    self.i_sid.is_set or
                                    self.mirp_lite_protocol.is_set or
                                    self.mirp_lite_status.is_set or
                                    (self.edge_port is not None and self.edge_port.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.core_bridge_name.yfilter != YFilter.not_set or
                                    self.core_bridge_state.yfilter != YFilter.not_set or
                                    self.i_sid.yfilter != YFilter.not_set or
                                    self.mirp_lite_protocol.yfilter != YFilter.not_set or
                                    self.mirp_lite_status.yfilter != YFilter.not_set or
                                    (self.edge_port is not None and self.edge_port.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb-edge" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.core_bridge_name.is_set or self.core_bridge_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_bridge_name.get_name_leafdata())
                                if (self.core_bridge_state.is_set or self.core_bridge_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_bridge_state.get_name_leafdata())
                                if (self.i_sid.is_set or self.i_sid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.i_sid.get_name_leafdata())
                                if (self.mirp_lite_protocol.is_set or self.mirp_lite_protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mirp_lite_protocol.get_name_leafdata())
                                if (self.mirp_lite_status.is_set or self.mirp_lite_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mirp_lite_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "edge-port"):
                                    if (self.edge_port is None):
                                        self.edge_port = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                        self.edge_port.parent = self
                                        self._children_name_map["edge_port"] = "edge-port"
                                    return self.edge_port

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "edge-port" or name == "core-bridge-name" or name == "core-bridge-state" or name == "i-sid" or name == "mirp-lite-protocol" or name == "mirp-lite-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "core-bridge-name"):
                                    self.core_bridge_name = value
                                    self.core_bridge_name.value_namespace = name_space
                                    self.core_bridge_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "core-bridge-state"):
                                    self.core_bridge_state = value
                                    self.core_bridge_state.value_namespace = name_space
                                    self.core_bridge_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "i-sid"):
                                    self.i_sid = value
                                    self.i_sid.value_namespace = name_space
                                    self.i_sid.value_namespace_prefix = name_space_prefix
                                if(value_path == "mirp-lite-protocol"):
                                    self.mirp_lite_protocol = value
                                    self.mirp_lite_protocol.value_namespace = name_space
                                    self.mirp_lite_protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "mirp-lite-status"):
                                    self.mirp_lite_status = value
                                    self.mirp_lite_status.value_namespace = name_space
                                    self.mirp_lite_status.value_namespace_prefix = name_space_prefix


                        class PbbCore(Entity):
                            """
                            PBB Core
                            
                            .. attribute:: core_port
                            
                            	PBB Core Port
                            	**type**\:   :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                            
                            .. attribute:: num_ass_edge
                            
                            	Number of Associated PBB Edges
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__init__()

                                self.yang_name = "pbb-core"
                                self.yang_parent_name = "pbb-parameters"

                                self.num_ass_edge = YLeaf(YType.uint32, "num-ass-edge")

                                self.core_port = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                self.core_port.parent = self
                                self._children_name_map["core_port"] = "core-port"
                                self._children_yang_names.add("core-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("num_ass_edge") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__setattr__(name, value)


                            class CorePort(Entity):
                                """
                                PBB Core Port
                                
                                .. attribute:: core_port_state
                                
                                	PBB Core Port State
                                	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                                
                                .. attribute:: vlan_id
                                
                                	Vlan ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__init__()

                                    self.yang_name = "core-port"
                                    self.yang_parent_name = "pbb-core"

                                    self.core_port_state = YLeaf(YType.enumeration, "core-port-state")

                                    self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                    self._children_yang_names.add("security-parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("core_port_state",
                                                    "vlan_id",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__setattr__(name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "core-port"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                        self._children_yang_names.add("base")

                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dhcpv4_trust",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__setattr__(name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"

                                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                            self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                            self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                            self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                            self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                            self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                            self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                            self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                            self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                            self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                            self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                            self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                            self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                            self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                            self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                            self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                            self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                            self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                            self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                            self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                            self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                            self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                            self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                            self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                            self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                            self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                            self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                            self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                            self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                            self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                            self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                            self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._children_yang_names.add("storm-control")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("broadcast_storm_control_kb_ps",
                                                            "broadcast_storm_control_pps",
                                                            "broadcast_storm_control_rate_unit",
                                                            "dai_address_validation_mask",
                                                            "dhcpv4_profile_name",
                                                            "dhcpv4_snoop",
                                                            "flood_unknown_unicast_enabled",
                                                            "flood_uu_disabled_mac_limit_action",
                                                            "igm_pv4_disabled",
                                                            "igm_pv4_profile_name",
                                                            "is_dai_addr_validate_destination_mac_enabled",
                                                            "is_dai_addr_validate_ipv4_enabled",
                                                            "is_dai_addr_validate_source_mac_enabled",
                                                            "is_dai_enabled",
                                                            "is_dai_logging_enabled",
                                                            "is_ip_source_guard_enabled",
                                                            "is_ipsg_logging_enabled",
                                                            "is_mac_secure_accept_shutdown_enabled",
                                                            "is_mac_secure_enabled",
                                                            "is_mac_secure_logging_enabled",
                                                            "learn_disabled_mac_limit_action",
                                                            "mac_aging_mode",
                                                            "mac_aging_time",
                                                            "mac_flooding",
                                                            "mac_learning",
                                                            "mac_limit",
                                                            "mac_limit_action",
                                                            "mac_limit_notification",
                                                            "mac_limit_reached",
                                                            "mac_port_down_flush_enabled",
                                                            "mac_secure_action",
                                                            "mld_profile_name",
                                                            "mmrp_flood_optimization",
                                                            "multicast_storm_control_kb_ps",
                                                            "multicast_storm_control_pps",
                                                            "multicast_storm_control_rate_unit",
                                                            "split_horizon_group_id",
                                                            "unicast_storm_control_kb_ps",
                                                            "unicast_storm_control_pps",
                                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__setattr__(name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"

                                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                self.multicast = YLeaf(YType.boolean, "multicast")

                                                self.unicast = YLeaf(YType.boolean, "unicast")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bd_policer",
                                                                "broadcast",
                                                                "multicast",
                                                                "unicast") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bd_policer.is_set or
                                                    self.broadcast.is_set or
                                                    self.multicast.is_set or
                                                    self.unicast.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bd_policer.yfilter != YFilter.not_set or
                                                    self.broadcast.yfilter != YFilter.not_set or
                                                    self.multicast.yfilter != YFilter.not_set or
                                                    self.unicast.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "storm-control" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/base/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bd-policer"):
                                                    self.bd_policer = value
                                                    self.bd_policer.value_namespace = name_space
                                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast"):
                                                    self.broadcast = value
                                                    self.broadcast.value_namespace = name_space
                                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast"):
                                                    self.multicast = value
                                                    self.multicast.value_namespace = name_space
                                                    self.multicast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast"):
                                                    self.unicast = value
                                                    self.unicast.value_namespace = name_space
                                                    self.unicast.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.broadcast_storm_control_kb_ps.is_set or
                                                self.broadcast_storm_control_pps.is_set or
                                                self.broadcast_storm_control_rate_unit.is_set or
                                                self.dai_address_validation_mask.is_set or
                                                self.dhcpv4_profile_name.is_set or
                                                self.dhcpv4_snoop.is_set or
                                                self.flood_unknown_unicast_enabled.is_set or
                                                self.flood_uu_disabled_mac_limit_action.is_set or
                                                self.igm_pv4_disabled.is_set or
                                                self.igm_pv4_profile_name.is_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                                self.is_dai_addr_validate_ipv4_enabled.is_set or
                                                self.is_dai_addr_validate_source_mac_enabled.is_set or
                                                self.is_dai_enabled.is_set or
                                                self.is_dai_logging_enabled.is_set or
                                                self.is_ip_source_guard_enabled.is_set or
                                                self.is_ipsg_logging_enabled.is_set or
                                                self.is_mac_secure_accept_shutdown_enabled.is_set or
                                                self.is_mac_secure_enabled.is_set or
                                                self.is_mac_secure_logging_enabled.is_set or
                                                self.learn_disabled_mac_limit_action.is_set or
                                                self.mac_aging_mode.is_set or
                                                self.mac_aging_time.is_set or
                                                self.mac_flooding.is_set or
                                                self.mac_learning.is_set or
                                                self.mac_limit.is_set or
                                                self.mac_limit_action.is_set or
                                                self.mac_limit_notification.is_set or
                                                self.mac_limit_reached.is_set or
                                                self.mac_port_down_flush_enabled.is_set or
                                                self.mac_secure_action.is_set or
                                                self.mld_profile_name.is_set or
                                                self.mmrp_flood_optimization.is_set or
                                                self.multicast_storm_control_kb_ps.is_set or
                                                self.multicast_storm_control_pps.is_set or
                                                self.multicast_storm_control_rate_unit.is_set or
                                                self.split_horizon_group_id.is_set or
                                                self.unicast_storm_control_kb_ps.is_set or
                                                self.unicast_storm_control_pps.is_set or
                                                self.unicast_storm_control_rate_unit.is_set or
                                                (self.storm_control is not None and self.storm_control.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                                self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                                self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                                self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                                self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                                self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                                self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                                self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_aging_mode.yfilter != YFilter.not_set or
                                                self.mac_aging_time.yfilter != YFilter.not_set or
                                                self.mac_flooding.yfilter != YFilter.not_set or
                                                self.mac_learning.yfilter != YFilter.not_set or
                                                self.mac_limit.yfilter != YFilter.not_set or
                                                self.mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_limit_notification.yfilter != YFilter.not_set or
                                                self.mac_limit_reached.yfilter != YFilter.not_set or
                                                self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                                self.mac_secure_action.yfilter != YFilter.not_set or
                                                self.mld_profile_name.yfilter != YFilter.not_set or
                                                self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.split_horizon_group_id.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                (self.storm_control is not None and self.storm_control.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "base" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                            if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                            if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                            if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                            if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                            if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                            if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                            if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                            if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                            if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                            if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                            if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                            if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                            if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                            if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                            if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                            if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                            if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                            if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                            if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                            if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                            if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "storm-control"):
                                                if (self.storm_control is None):
                                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                                    self.storm_control.parent = self
                                                    self._children_name_map["storm_control"] = "storm-control"
                                                return self.storm_control

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "broadcast-storm-control-kb-ps"):
                                                self.broadcast_storm_control_kb_ps = value
                                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-pps"):
                                                self.broadcast_storm_control_pps = value
                                                self.broadcast_storm_control_pps.value_namespace = name_space
                                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-rate-unit"):
                                                self.broadcast_storm_control_rate_unit = value
                                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dai-address-validation-mask"):
                                                self.dai_address_validation_mask = value
                                                self.dai_address_validation_mask.value_namespace = name_space
                                                self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-profile-name"):
                                                self.dhcpv4_profile_name = value
                                                self.dhcpv4_profile_name.value_namespace = name_space
                                                self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-snoop"):
                                                self.dhcpv4_snoop = value
                                                self.dhcpv4_snoop.value_namespace = name_space
                                                self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-unknown-unicast-enabled"):
                                                self.flood_unknown_unicast_enabled = value
                                                self.flood_unknown_unicast_enabled.value_namespace = name_space
                                                self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-uu-disabled-mac-limit-action"):
                                                self.flood_uu_disabled_mac_limit_action = value
                                                self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                                self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-disabled"):
                                                self.igm_pv4_disabled = value
                                                self.igm_pv4_disabled.value_namespace = name_space
                                                self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-profile-name"):
                                                self.igm_pv4_profile_name = value
                                                self.igm_pv4_profile_name.value_namespace = name_space
                                                self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                                self.is_dai_addr_validate_destination_mac_enabled = value
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                                self.is_dai_addr_validate_ipv4_enabled = value
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                                self.is_dai_addr_validate_source_mac_enabled = value
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-enabled"):
                                                self.is_dai_enabled = value
                                                self.is_dai_enabled.value_namespace = name_space
                                                self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-logging-enabled"):
                                                self.is_dai_logging_enabled = value
                                                self.is_dai_logging_enabled.value_namespace = name_space
                                                self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ip-source-guard-enabled"):
                                                self.is_ip_source_guard_enabled = value
                                                self.is_ip_source_guard_enabled.value_namespace = name_space
                                                self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ipsg-logging-enabled"):
                                                self.is_ipsg_logging_enabled = value
                                                self.is_ipsg_logging_enabled.value_namespace = name_space
                                                self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                                self.is_mac_secure_accept_shutdown_enabled = value
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-enabled"):
                                                self.is_mac_secure_enabled = value
                                                self.is_mac_secure_enabled.value_namespace = name_space
                                                self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-logging-enabled"):
                                                self.is_mac_secure_logging_enabled = value
                                                self.is_mac_secure_logging_enabled.value_namespace = name_space
                                                self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "learn-disabled-mac-limit-action"):
                                                self.learn_disabled_mac_limit_action = value
                                                self.learn_disabled_mac_limit_action.value_namespace = name_space
                                                self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-mode"):
                                                self.mac_aging_mode = value
                                                self.mac_aging_mode.value_namespace = name_space
                                                self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-time"):
                                                self.mac_aging_time = value
                                                self.mac_aging_time.value_namespace = name_space
                                                self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-flooding"):
                                                self.mac_flooding = value
                                                self.mac_flooding.value_namespace = name_space
                                                self.mac_flooding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-learning"):
                                                self.mac_learning = value
                                                self.mac_learning.value_namespace = name_space
                                                self.mac_learning.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit"):
                                                self.mac_limit = value
                                                self.mac_limit.value_namespace = name_space
                                                self.mac_limit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-action"):
                                                self.mac_limit_action = value
                                                self.mac_limit_action.value_namespace = name_space
                                                self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-notification"):
                                                self.mac_limit_notification = value
                                                self.mac_limit_notification.value_namespace = name_space
                                                self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-reached"):
                                                self.mac_limit_reached = value
                                                self.mac_limit_reached.value_namespace = name_space
                                                self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-port-down-flush-enabled"):
                                                self.mac_port_down_flush_enabled = value
                                                self.mac_port_down_flush_enabled.value_namespace = name_space
                                                self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-secure-action"):
                                                self.mac_secure_action = value
                                                self.mac_secure_action.value_namespace = name_space
                                                self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mld-profile-name"):
                                                self.mld_profile_name = value
                                                self.mld_profile_name.value_namespace = name_space
                                                self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mmrp-flood-optimization"):
                                                self.mmrp_flood_optimization = value
                                                self.mmrp_flood_optimization.value_namespace = name_space
                                                self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-kb-ps"):
                                                self.multicast_storm_control_kb_ps = value
                                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-pps"):
                                                self.multicast_storm_control_pps = value
                                                self.multicast_storm_control_pps.value_namespace = name_space
                                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-rate-unit"):
                                                self.multicast_storm_control_rate_unit = value
                                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "split-horizon-group-id"):
                                                self.split_horizon_group_id = value
                                                self.split_horizon_group_id.value_namespace = name_space
                                                self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-kb-ps"):
                                                self.unicast_storm_control_kb_ps = value
                                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-pps"):
                                                self.unicast_storm_control_pps = value
                                                self.unicast_storm_control_pps.value_namespace = name_space
                                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-rate-unit"):
                                                self.unicast_storm_control_rate_unit = value
                                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dhcpv4_trust.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.base is not None and self.base.has_data()) or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dhcpv4_trust.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.base is not None and self.base.has_operation()) or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security-parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "base"):
                                            if (self.base is None):
                                                self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                                self.base.parent = self
                                                self._children_name_map["base"] = "base"
                                            return self.base

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-trust"):
                                            self.dhcpv4_trust = value
                                            self.dhcpv4_trust.value_namespace = name_space
                                            self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.core_port_state.is_set or
                                        self.vlan_id.is_set or
                                        self.xconnect_id.is_set or
                                        (self.security_parameters is not None and self.security_parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.core_port_state.yfilter != YFilter.not_set or
                                        self.vlan_id.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.security_parameters is not None and self.security_parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "core-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.core_port_state.is_set or self.core_port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.core_port_state.get_name_leafdata())
                                    if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_id.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "security-parameters"):
                                        if (self.security_parameters is None):
                                            self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                            self.security_parameters.parent = self
                                            self._children_name_map["security_parameters"] = "security-parameters"
                                        return self.security_parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "security-parameters" or name == "core-port-state" or name == "vlan-id" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "core-port-state"):
                                        self.core_port_state = value
                                        self.core_port_state.value_namespace = name_space
                                        self.core_port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-id"):
                                        self.vlan_id = value
                                        self.vlan_id.value_namespace = name_space
                                        self.vlan_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.num_ass_edge.is_set or
                                    (self.core_port is not None and self.core_port.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.num_ass_edge.yfilter != YFilter.not_set or
                                    (self.core_port is not None and self.core_port.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb-core" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.num_ass_edge.is_set or self.num_ass_edge.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ass_edge.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "core-port"):
                                    if (self.core_port is None):
                                        self.core_port = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                        self.core_port.parent = self
                                        self._children_name_map["core_port"] = "core-port"
                                    return self.core_port

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "core-port" or name == "num-ass-edge"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "num-ass-edge"):
                                    self.num_ass_edge = value
                                    self.num_ass_edge.value_namespace = name_space
                                    self.num_ass_edge.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.type.is_set or
                                (self.pbb_core is not None and self.pbb_core.has_data()) or
                                (self.pbb_edge is not None and self.pbb_edge.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.type.yfilter != YFilter.not_set or
                                (self.pbb_core is not None and self.pbb_core.has_operation()) or
                                (self.pbb_edge is not None and self.pbb_edge.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pbb-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "pbb-core"):
                                if (self.pbb_core is None):
                                    self.pbb_core = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                                    self.pbb_core.parent = self
                                    self._children_name_map["pbb_core"] = "pbb-core"
                                return self.pbb_core

                            if (child_yang_name == "pbb-edge"):
                                if (self.pbb_edge is None):
                                    self.pbb_edge = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                                    self.pbb_edge.parent = self
                                    self._children_name_map["pbb_edge"] = "pbb-edge"
                                return self.pbb_edge

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "pbb-core" or name == "pbb-edge" or name == "type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "type"):
                                self.type = value
                                self.type.value_namespace = name_space
                                self.type.value_namespace_prefix = name_space_prefix


                    class EvpnParameters(Entity):
                        """
                        EVPN parameters
                        
                        .. attribute:: evi
                        
                        	E\-VPN id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_port
                        
                        	EVPN Port
                        	**type**\:   :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__init__()

                            self.yang_name = "evpn-parameters"
                            self.yang_parent_name = "bridge-domain-info"

                            self.evi = YLeaf(YType.uint32, "evi")

                            self.evpn_port = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                            self.evpn_port.parent = self
                            self._children_name_map["evpn_port"] = "evpn-port"
                            self._children_yang_names.add("evpn-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("evi") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__setattr__(name, value)


                        class EvpnPort(Entity):
                            """
                            EVPN Port
                            
                            .. attribute:: evpn_port_state
                            
                            	EVPN Port State
                            	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__init__()

                                self.yang_name = "evpn-port"
                                self.yang_parent_name = "evpn-parameters"

                                self.evpn_port_state = YLeaf(YType.enumeration, "evpn-port-state")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                                self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("evpn_port_state",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__setattr__(name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "evpn-port"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/base/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "evpn-port"

                                    self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.evpn_port_state.is_set or
                                    self.xconnect_id.is_set or
                                    (self.security_parameters is not None and self.security_parameters.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.evpn_port_state.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn-port" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.evpn_port_state.is_set or self.evpn_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_port_state.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "security-parameters" or name == "statistics" or name == "evpn-port-state" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "evpn-port-state"):
                                    self.evpn_port_state = value
                                    self.evpn_port_state.value_namespace = name_space
                                    self.evpn_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.evi.is_set or
                                (self.evpn_port is not None and self.evpn_port.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.evi.yfilter != YFilter.not_set or
                                (self.evpn_port is not None and self.evpn_port.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "evpn-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evi.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "evpn-port"):
                                if (self.evpn_port is None):
                                    self.evpn_port = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                                    self.evpn_port.parent = self
                                    self._children_name_map["evpn_port"] = "evpn-port"
                                return self.evpn_port

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "evpn-port" or name == "evi"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "evi"):
                                self.evi = value
                                self.evi.value_namespace = name_space
                                self.evi.value_namespace_prefix = name_space_prefix


                    class VniParameters(Entity):
                        """
                        VNI parameters
                        
                        .. attribute:: anycast_mcast_group_addr
                        
                        	Anycast Multicast Group Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: anycast_vtep_ip_addr
                        
                        	Anycast VTEP IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: multicast_group_addr
                        
                        	Multicast Group Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: overlay
                        
                        	NVE Overlay
                        	**type**\:  str
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                        
                        .. attribute:: source_ip_addr
                        
                        	Source IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                        
                        .. attribute:: udp_port
                        
                        	UDP Port
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vni
                        
                        	VNI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vni_encap_type
                        
                        	VNI Encapsulation Type
                        	**type**\:   :py:class:`L2VpnVniEncaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniEncaps>`
                        
                        .. attribute:: vni_mode
                        
                        	VNI Mode
                        	**type**\:   :py:class:`L2VpnVniMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniMode>`
                        
                        .. attribute:: vni_port_state
                        
                        	VNI Port State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: xconnect_id
                        
                        	Xconnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__init__()

                            self.yang_name = "vni-parameters"
                            self.yang_parent_name = "bridge-domain-info"

                            self.anycast_mcast_group_addr = YLeaf(YType.str, "anycast-mcast-group-addr")

                            self.anycast_vtep_ip_addr = YLeaf(YType.str, "anycast-vtep-ip-addr")

                            self.multicast_group_addr = YLeaf(YType.str, "multicast-group-addr")

                            self.overlay = YLeaf(YType.str, "overlay")

                            self.source_ip_addr = YLeaf(YType.str, "source-ip-addr")

                            self.udp_port = YLeaf(YType.uint32, "udp-port")

                            self.vni = YLeaf(YType.uint32, "vni")

                            self.vni_encap_type = YLeaf(YType.enumeration, "vni-encap-type")

                            self.vni_mode = YLeaf(YType.enumeration, "vni-mode")

                            self.vni_port_state = YLeaf(YType.enumeration, "vni-port-state")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                            self._children_yang_names.add("security-parameters")

                            self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                            self.static_mac = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("anycast_mcast_group_addr",
                                            "anycast_vtep_ip_addr",
                                            "multicast_group_addr",
                                            "overlay",
                                            "source_ip_addr",
                                            "udp_port",
                                            "vni",
                                            "vni_encap_type",
                                            "vni_mode",
                                            "vni_port_state",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__setattr__(name, value)


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "vni-parameters"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dhcpv4_trust",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                    self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                    self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                    self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                    self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                    self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                    self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                    self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                    self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                    self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                    self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                    self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                    self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                    self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                    self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                    self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                    self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                    self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                    self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                    self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                    self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                    self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                    self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                    self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                    self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                    self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                    self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                    self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                    self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                    self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dai_address_validation_mask",
                                                    "dhcpv4_profile_name",
                                                    "dhcpv4_snoop",
                                                    "flood_unknown_unicast_enabled",
                                                    "flood_uu_disabled_mac_limit_action",
                                                    "igm_pv4_disabled",
                                                    "igm_pv4_profile_name",
                                                    "is_dai_addr_validate_destination_mac_enabled",
                                                    "is_dai_addr_validate_ipv4_enabled",
                                                    "is_dai_addr_validate_source_mac_enabled",
                                                    "is_dai_enabled",
                                                    "is_dai_logging_enabled",
                                                    "is_ip_source_guard_enabled",
                                                    "is_ipsg_logging_enabled",
                                                    "is_mac_secure_accept_shutdown_enabled",
                                                    "is_mac_secure_enabled",
                                                    "is_mac_secure_logging_enabled",
                                                    "learn_disabled_mac_limit_action",
                                                    "mac_aging_mode",
                                                    "mac_aging_time",
                                                    "mac_flooding",
                                                    "mac_learning",
                                                    "mac_limit",
                                                    "mac_limit_action",
                                                    "mac_limit_notification",
                                                    "mac_limit_reached",
                                                    "mac_port_down_flush_enabled",
                                                    "mac_secure_action",
                                                    "mld_profile_name",
                                                    "mmrp_flood_optimization",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "split_horizon_group_id",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__setattr__(name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/base/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dai_address_validation_mask.is_set or
                                        self.dhcpv4_profile_name.is_set or
                                        self.dhcpv4_snoop.is_set or
                                        self.flood_unknown_unicast_enabled.is_set or
                                        self.flood_uu_disabled_mac_limit_action.is_set or
                                        self.igm_pv4_disabled.is_set or
                                        self.igm_pv4_profile_name.is_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                        self.is_dai_addr_validate_ipv4_enabled.is_set or
                                        self.is_dai_addr_validate_source_mac_enabled.is_set or
                                        self.is_dai_enabled.is_set or
                                        self.is_dai_logging_enabled.is_set or
                                        self.is_ip_source_guard_enabled.is_set or
                                        self.is_ipsg_logging_enabled.is_set or
                                        self.is_mac_secure_accept_shutdown_enabled.is_set or
                                        self.is_mac_secure_enabled.is_set or
                                        self.is_mac_secure_logging_enabled.is_set or
                                        self.learn_disabled_mac_limit_action.is_set or
                                        self.mac_aging_mode.is_set or
                                        self.mac_aging_time.is_set or
                                        self.mac_flooding.is_set or
                                        self.mac_learning.is_set or
                                        self.mac_limit.is_set or
                                        self.mac_limit_action.is_set or
                                        self.mac_limit_notification.is_set or
                                        self.mac_limit_reached.is_set or
                                        self.mac_port_down_flush_enabled.is_set or
                                        self.mac_secure_action.is_set or
                                        self.mld_profile_name.is_set or
                                        self.mmrp_flood_optimization.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.split_horizon_group_id.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                        self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                        self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                        self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                        self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                        self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                        self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                        self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_aging_mode.yfilter != YFilter.not_set or
                                        self.mac_aging_time.yfilter != YFilter.not_set or
                                        self.mac_flooding.yfilter != YFilter.not_set or
                                        self.mac_learning.yfilter != YFilter.not_set or
                                        self.mac_limit.yfilter != YFilter.not_set or
                                        self.mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_limit_notification.yfilter != YFilter.not_set or
                                        self.mac_limit_reached.yfilter != YFilter.not_set or
                                        self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                        self.mac_secure_action.yfilter != YFilter.not_set or
                                        self.mld_profile_name.yfilter != YFilter.not_set or
                                        self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.split_horizon_group_id.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                    if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                    if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                    if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                    if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                    if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                    if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                    if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                    if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                    if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                    if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                    if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                    if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                    if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                    if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                    if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                    if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                    if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                    if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                    if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                    if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                    if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dai-address-validation-mask"):
                                        self.dai_address_validation_mask = value
                                        self.dai_address_validation_mask.value_namespace = name_space
                                        self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-profile-name"):
                                        self.dhcpv4_profile_name = value
                                        self.dhcpv4_profile_name.value_namespace = name_space
                                        self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-snoop"):
                                        self.dhcpv4_snoop = value
                                        self.dhcpv4_snoop.value_namespace = name_space
                                        self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-unknown-unicast-enabled"):
                                        self.flood_unknown_unicast_enabled = value
                                        self.flood_unknown_unicast_enabled.value_namespace = name_space
                                        self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-uu-disabled-mac-limit-action"):
                                        self.flood_uu_disabled_mac_limit_action = value
                                        self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                        self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-disabled"):
                                        self.igm_pv4_disabled = value
                                        self.igm_pv4_disabled.value_namespace = name_space
                                        self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-profile-name"):
                                        self.igm_pv4_profile_name = value
                                        self.igm_pv4_profile_name.value_namespace = name_space
                                        self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                        self.is_dai_addr_validate_destination_mac_enabled = value
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                        self.is_dai_addr_validate_ipv4_enabled = value
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                        self.is_dai_addr_validate_source_mac_enabled = value
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-enabled"):
                                        self.is_dai_enabled = value
                                        self.is_dai_enabled.value_namespace = name_space
                                        self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-logging-enabled"):
                                        self.is_dai_logging_enabled = value
                                        self.is_dai_logging_enabled.value_namespace = name_space
                                        self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ip-source-guard-enabled"):
                                        self.is_ip_source_guard_enabled = value
                                        self.is_ip_source_guard_enabled.value_namespace = name_space
                                        self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ipsg-logging-enabled"):
                                        self.is_ipsg_logging_enabled = value
                                        self.is_ipsg_logging_enabled.value_namespace = name_space
                                        self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                        self.is_mac_secure_accept_shutdown_enabled = value
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-enabled"):
                                        self.is_mac_secure_enabled = value
                                        self.is_mac_secure_enabled.value_namespace = name_space
                                        self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-logging-enabled"):
                                        self.is_mac_secure_logging_enabled = value
                                        self.is_mac_secure_logging_enabled.value_namespace = name_space
                                        self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "learn-disabled-mac-limit-action"):
                                        self.learn_disabled_mac_limit_action = value
                                        self.learn_disabled_mac_limit_action.value_namespace = name_space
                                        self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-mode"):
                                        self.mac_aging_mode = value
                                        self.mac_aging_mode.value_namespace = name_space
                                        self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-time"):
                                        self.mac_aging_time = value
                                        self.mac_aging_time.value_namespace = name_space
                                        self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flooding"):
                                        self.mac_flooding = value
                                        self.mac_flooding.value_namespace = name_space
                                        self.mac_flooding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-learning"):
                                        self.mac_learning = value
                                        self.mac_learning.value_namespace = name_space
                                        self.mac_learning.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit"):
                                        self.mac_limit = value
                                        self.mac_limit.value_namespace = name_space
                                        self.mac_limit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-action"):
                                        self.mac_limit_action = value
                                        self.mac_limit_action.value_namespace = name_space
                                        self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-notification"):
                                        self.mac_limit_notification = value
                                        self.mac_limit_notification.value_namespace = name_space
                                        self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-reached"):
                                        self.mac_limit_reached = value
                                        self.mac_limit_reached.value_namespace = name_space
                                        self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-port-down-flush-enabled"):
                                        self.mac_port_down_flush_enabled = value
                                        self.mac_port_down_flush_enabled.value_namespace = name_space
                                        self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-secure-action"):
                                        self.mac_secure_action = value
                                        self.mac_secure_action.value_namespace = name_space
                                        self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mld-profile-name"):
                                        self.mld_profile_name = value
                                        self.mld_profile_name.value_namespace = name_space
                                        self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mmrp-flood-optimization"):
                                        self.mmrp_flood_optimization = value
                                        self.mmrp_flood_optimization.value_namespace = name_space
                                        self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "split-horizon-group-id"):
                                        self.split_horizon_group_id = value
                                        self.split_horizon_group_id.value_namespace = name_space
                                        self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dhcpv4_trust.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dhcpv4_trust.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-trust"):
                                    self.dhcpv4_trust = value
                                    self.dhcpv4_trust.value_namespace = name_space
                                    self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "vni-parameters"

                                self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "vni-parameters"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "static-mac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.static_mac:
                                if (c.has_data()):
                                    return True
                            return (
                                self.anycast_mcast_group_addr.is_set or
                                self.anycast_vtep_ip_addr.is_set or
                                self.multicast_group_addr.is_set or
                                self.overlay.is_set or
                                self.source_ip_addr.is_set or
                                self.udp_port.is_set or
                                self.vni.is_set or
                                self.vni_encap_type.is_set or
                                self.vni_mode.is_set or
                                self.vni_port_state.is_set or
                                self.xconnect_id.is_set or
                                (self.security_parameters is not None and self.security_parameters.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            for c in self.static_mac:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.anycast_mcast_group_addr.yfilter != YFilter.not_set or
                                self.anycast_vtep_ip_addr.yfilter != YFilter.not_set or
                                self.multicast_group_addr.yfilter != YFilter.not_set or
                                self.overlay.yfilter != YFilter.not_set or
                                self.source_ip_addr.yfilter != YFilter.not_set or
                                self.udp_port.yfilter != YFilter.not_set or
                                self.vni.yfilter != YFilter.not_set or
                                self.vni_encap_type.yfilter != YFilter.not_set or
                                self.vni_mode.yfilter != YFilter.not_set or
                                self.vni_port_state.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "vni-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.anycast_mcast_group_addr.is_set or self.anycast_mcast_group_addr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_mcast_group_addr.get_name_leafdata())
                            if (self.anycast_vtep_ip_addr.is_set or self.anycast_vtep_ip_addr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_vtep_ip_addr.get_name_leafdata())
                            if (self.multicast_group_addr.is_set or self.multicast_group_addr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_group_addr.get_name_leafdata())
                            if (self.overlay.is_set or self.overlay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.overlay.get_name_leafdata())
                            if (self.source_ip_addr.is_set or self.source_ip_addr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_ip_addr.get_name_leafdata())
                            if (self.udp_port.is_set or self.udp_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.udp_port.get_name_leafdata())
                            if (self.vni.is_set or self.vni.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vni.get_name_leafdata())
                            if (self.vni_encap_type.is_set or self.vni_encap_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vni_encap_type.get_name_leafdata())
                            if (self.vni_mode.is_set or self.vni_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vni_mode.get_name_leafdata())
                            if (self.vni_port_state.is_set or self.vni_port_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vni_port_state.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "security-parameters"):
                                if (self.security_parameters is None):
                                    self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                return self.security_parameters

                            if (child_yang_name == "static-mac"):
                                for c in self.static_mac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.static_mac.append(c)
                                return c

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "security-parameters" or name == "static-mac" or name == "statistics" or name == "anycast-mcast-group-addr" or name == "anycast-vtep-ip-addr" or name == "multicast-group-addr" or name == "overlay" or name == "source-ip-addr" or name == "udp-port" or name == "vni" or name == "vni-encap-type" or name == "vni-mode" or name == "vni-port-state" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "anycast-mcast-group-addr"):
                                self.anycast_mcast_group_addr = value
                                self.anycast_mcast_group_addr.value_namespace = name_space
                                self.anycast_mcast_group_addr.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-vtep-ip-addr"):
                                self.anycast_vtep_ip_addr = value
                                self.anycast_vtep_ip_addr.value_namespace = name_space
                                self.anycast_vtep_ip_addr.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-group-addr"):
                                self.multicast_group_addr = value
                                self.multicast_group_addr.value_namespace = name_space
                                self.multicast_group_addr.value_namespace_prefix = name_space_prefix
                            if(value_path == "overlay"):
                                self.overlay = value
                                self.overlay.value_namespace = name_space
                                self.overlay.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-ip-addr"):
                                self.source_ip_addr = value
                                self.source_ip_addr.value_namespace = name_space
                                self.source_ip_addr.value_namespace_prefix = name_space_prefix
                            if(value_path == "udp-port"):
                                self.udp_port = value
                                self.udp_port.value_namespace = name_space
                                self.udp_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "vni"):
                                self.vni = value
                                self.vni.value_namespace = name_space
                                self.vni.value_namespace_prefix = name_space_prefix
                            if(value_path == "vni-encap-type"):
                                self.vni_encap_type = value
                                self.vni_encap_type.value_namespace = name_space
                                self.vni_encap_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "vni-mode"):
                                self.vni_mode = value
                                self.vni_mode.value_namespace = name_space
                                self.vni_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "vni-port-state"):
                                self.vni_port_state = value
                                self.vni_port_state.value_namespace = name_space
                                self.vni_port_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class Rd(Entity):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__init__()

                            self.yang_name = "rd"
                            self.yang_parent_name = "bridge-domain-info"

                            self.rd = YLeaf(YType.enumeration, "rd")

                            self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"
                            self._children_yang_names.add("auto")

                            self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                            self._children_yang_names.add("four-byte-as")

                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rd") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__setattr__(name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd"

                                self.auto_index = YLeaf(YType.uint16, "auto-index")

                                self.router_id = YLeaf(YType.str, "router-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("auto_index",
                                                "router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.auto_index.is_set or
                                    self.router_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.auto_index.yfilter != YFilter.not_set or
                                    self.router_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "auto" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_index.get_name_leafdata())
                                if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto-index" or name == "router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "auto-index"):
                                    self.auto_index = value
                                    self.auto_index.value_namespace = name_space
                                    self.auto_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-id"):
                                    self.router_id = value
                                    self.router_id.value_namespace = name_space
                                    self.router_id.value_namespace_prefix = name_space_prefix


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd"

                                self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_as",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_as.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_as.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "four-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-as" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-as"):
                                    self.four_byte_as = value
                                    self.four_byte_as.value_namespace = name_space
                                    self.four_byte_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.rd.is_set or
                                (self.auto is not None and self.auto.has_data()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rd.yfilter != YFilter.not_set or
                                (self.auto is not None and self.auto.has_operation()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rd" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rd.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "auto"):
                                if (self.auto is None):
                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                return self.auto

                            if (child_yang_name == "four-byte-as"):
                                if (self.four_byte_as is None):
                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                return self.four_byte_as

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rd"):
                                self.rd = value
                                self.rd.value_namespace = name_space
                                self.rd.value_namespace_prefix = name_space_prefix


                    class MacFilter(Entity):
                        """
                        MAC addresses for filtering
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__init__()

                            self.yang_name = "mac-filter"
                            self.yang_parent_name = "bridge-domain-info"

                            self.address = YLeaf(YType.str, "address")

                            self.bmac = YLeaf(YType.str, "bmac")

                            self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "bmac",
                                            "next_hop_ip") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.bmac.is_set or
                                self.next_hop_ip.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.bmac.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mac-filter" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bmac.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "bmac"):
                                self.bmac = value
                                self.bmac.value_namespace = name_space
                                self.bmac.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix


                    class BridgeVfi(Entity):
                        """
                        Virtual Forwarding Interfaces
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\:  bool
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\:  str
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:   :py:class:`L2VpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiState>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__init__()

                            self.yang_name = "bridge-vfi"
                            self.yang_parent_name = "bridge-domain-info"

                            self.access = YLeaf(YType.boolean, "access")

                            self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.vfi_name = YLeaf(YType.str, "vfi-name")

                            self.vfi_state = YLeaf(YType.enumeration, "vfi-state")

                            self.discovery_information = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self._children_name_map["discovery_information"] = "discovery-information"
                            self._children_yang_names.add("discovery-information")

                            self.p2mp_information = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("access",
                                            "number_pseudowires",
                                            "shutdown",
                                            "vfi_name",
                                            "vfi_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__setattr__(name, value)


                        class DiscoveryInformation(Entity):
                            """
                            Auto Discovery information
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\:  str
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\:  bool
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\:  bool
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\:  bool
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__init__()

                                self.yang_name = "discovery-information"
                                self.yang_parent_name = "bridge-vfi"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                                self.as_number = YLeaf(YType.uint32, "as-number")

                                self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                                self.l2vpn_router_id = YLeaf(YType.str, "l2vpn-router-id")

                                self.provisioned_ve_id = YLeaf(YType.uint32, "provisioned-ve-id")

                                self.service_connected = YLeaf(YType.boolean, "service-connected")

                                self.ve_id = YLeaf(YType.uint32, "ve-id")

                                self.ve_range = YLeaf(YType.uint16, "ve-range")

                                self.vpls_id_conflict = YLeaf(YType.boolean, "vpls-id-conflict")

                                self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                self.rd_value = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self._children_name_map["rd_value"] = "rd-value"
                                self._children_yang_names.add("rd-value")

                                self.vpls_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self._children_name_map["vpls_id"] = "vpls-id"
                                self._children_yang_names.add("vpls-id")

                                self.export_rt = YList(self)
                                self.import_rt = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_signalling_method",
                                                "as_number",
                                                "export_route_policy",
                                                "l2vpn_router_id",
                                                "provisioned_ve_id",
                                                "service_connected",
                                                "ve_id",
                                                "ve_range",
                                                "vpls_id_conflict",
                                                "vpn_added",
                                                "vpn_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__setattr__(name, value)


                            class RdValue(Entity):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__init__()

                                    self.yang_name = "rd-value"
                                    self.yang_parent_name = "discovery-information"

                                    self.rd = YLeaf(YType.enumeration, "rd")

                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rd") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "rd-value"

                                        self.auto_index = YLeaf(YType.uint16, "auto-index")

                                        self.router_id = YLeaf(YType.str, "router-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("auto_index",
                                                        "router_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.auto_index.is_set or
                                            self.router_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.auto_index.yfilter != YFilter.not_set or
                                            self.router_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.auto_index.get_name_leafdata())
                                        if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.router_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto-index" or name == "router-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "auto-index"):
                                            self.auto_index = value
                                            self.auto_index.value_namespace = name_space
                                            self.auto_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "router-id"):
                                            self.router_id = value
                                            self.router_id.value_namespace = name_space
                                            self.router_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "rd-value"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "rd-value"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "rd-value"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rd.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rd.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rd-value" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rd.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rd"):
                                        self.rd = value
                                        self.rd.value_namespace = name_space
                                        self.rd.value_namespace_prefix = name_space_prefix


                            class VplsId(Entity):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__init__()

                                    self.yang_name = "vpls-id"
                                    self.yang_parent_name = "discovery-information"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "vpls-id"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "vpls-id"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "vpls-id"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vpls-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class ImportRt(Entity):
                                """
                                List of import route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__init__()

                                    self.yang_name = "import-rt"
                                    self.yang_parent_name = "discovery-information"

                                    self.rt = YLeaf(YType.enumeration, "rt")

                                    self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._children_yang_names.add("es-import")

                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rt") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "import-rt"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "import-rt"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "import-rt"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "import-rt"

                                        self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                        self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("high_bytes",
                                                        "low_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.high_bytes.is_set or
                                            self.low_bytes.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.high_bytes.yfilter != YFilter.not_set or
                                            self.low_bytes.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-import" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                        if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "high-bytes" or name == "low-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "high-bytes"):
                                            self.high_bytes = value
                                            self.high_bytes.value_namespace = name_space
                                            self.high_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "low-bytes"):
                                            self.low_bytes = value
                                            self.low_bytes.value_namespace = name_space
                                            self.low_bytes.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rt.is_set or
                                        (self.es_import is not None and self.es_import.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rt.yfilter != YFilter.not_set or
                                        (self.es_import is not None and self.es_import.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "import-rt" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rt.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "es-import"):
                                        if (self.es_import is None):
                                            self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                            self.es_import.parent = self
                                            self._children_name_map["es_import"] = "es-import"
                                        return self.es_import

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rt"):
                                        self.rt = value
                                        self.rt.value_namespace = name_space
                                        self.rt.value_namespace_prefix = name_space_prefix


                            class ExportRt(Entity):
                                """
                                List of export route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__init__()

                                    self.yang_name = "export-rt"
                                    self.yang_parent_name = "discovery-information"

                                    self.rt = YLeaf(YType.enumeration, "rt")

                                    self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._children_yang_names.add("es-import")

                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rt") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "export-rt"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "export-rt"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "export-rt"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "export-rt"

                                        self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                        self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("high_bytes",
                                                        "low_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.high_bytes.is_set or
                                            self.low_bytes.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.high_bytes.yfilter != YFilter.not_set or
                                            self.low_bytes.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-import" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                        if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "high-bytes" or name == "low-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "high-bytes"):
                                            self.high_bytes = value
                                            self.high_bytes.value_namespace = name_space
                                            self.high_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "low-bytes"):
                                            self.low_bytes = value
                                            self.low_bytes.value_namespace = name_space
                                            self.low_bytes.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rt.is_set or
                                        (self.es_import is not None and self.es_import.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rt.yfilter != YFilter.not_set or
                                        (self.es_import is not None and self.es_import.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "export-rt" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rt.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "es-import"):
                                        if (self.es_import is None):
                                            self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                            self.es_import.parent = self
                                            self._children_name_map["es_import"] = "es-import"
                                        return self.es_import

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rt"):
                                        self.rt = value
                                        self.rt.value_namespace = name_space
                                        self.rt.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.export_rt:
                                    if (c.has_data()):
                                        return True
                                for c in self.import_rt:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.ad_method.is_set or
                                    self.ad_signalling_method.is_set or
                                    self.as_number.is_set or
                                    self.export_route_policy.is_set or
                                    self.l2vpn_router_id.is_set or
                                    self.provisioned_ve_id.is_set or
                                    self.service_connected.is_set or
                                    self.ve_id.is_set or
                                    self.ve_range.is_set or
                                    self.vpls_id_conflict.is_set or
                                    self.vpn_added.is_set or
                                    self.vpn_id.is_set or
                                    (self.rd_value is not None and self.rd_value.has_data()) or
                                    (self.vpls_id is not None and self.vpls_id.has_data()))

                            def has_operation(self):
                                for c in self.export_rt:
                                    if (c.has_operation()):
                                        return True
                                for c in self.import_rt:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_signalling_method.yfilter != YFilter.not_set or
                                    self.as_number.yfilter != YFilter.not_set or
                                    self.export_route_policy.yfilter != YFilter.not_set or
                                    self.l2vpn_router_id.yfilter != YFilter.not_set or
                                    self.provisioned_ve_id.yfilter != YFilter.not_set or
                                    self.service_connected.yfilter != YFilter.not_set or
                                    self.ve_id.yfilter != YFilter.not_set or
                                    self.ve_range.yfilter != YFilter.not_set or
                                    self.vpls_id_conflict.yfilter != YFilter.not_set or
                                    self.vpn_added.yfilter != YFilter.not_set or
                                    self.vpn_id.yfilter != YFilter.not_set or
                                    (self.rd_value is not None and self.rd_value.has_operation()) or
                                    (self.vpls_id is not None and self.vpls_id.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "discovery-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                                if (self.as_number.is_set or self.as_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_number.get_name_leafdata())
                                if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                                if (self.l2vpn_router_id.is_set or self.l2vpn_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l2vpn_router_id.get_name_leafdata())
                                if (self.provisioned_ve_id.is_set or self.provisioned_ve_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.provisioned_ve_id.get_name_leafdata())
                                if (self.service_connected.is_set or self.service_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_connected.get_name_leafdata())
                                if (self.ve_id.is_set or self.ve_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_id.get_name_leafdata())
                                if (self.ve_range.is_set or self.ve_range.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_range.get_name_leafdata())
                                if (self.vpls_id_conflict.is_set or self.vpls_id_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_conflict.get_name_leafdata())
                                if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpn_added.get_name_leafdata())
                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "export-rt"):
                                    for c in self.export_rt:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.export_rt.append(c)
                                    return c

                                if (child_yang_name == "import-rt"):
                                    for c in self.import_rt:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.import_rt.append(c)
                                    return c

                                if (child_yang_name == "rd-value"):
                                    if (self.rd_value is None):
                                        self.rd_value = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                        self.rd_value.parent = self
                                        self._children_name_map["rd_value"] = "rd-value"
                                    return self.rd_value

                                if (child_yang_name == "vpls-id"):
                                    if (self.vpls_id is None):
                                        self.vpls_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                        self.vpls_id.parent = self
                                        self._children_name_map["vpls_id"] = "vpls-id"
                                    return self.vpls_id

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "vpls-id" or name == "ad-method" or name == "ad-signalling-method" or name == "as-number" or name == "export-route-policy" or name == "l2vpn-router-id" or name == "provisioned-ve-id" or name == "service-connected" or name == "ve-id" or name == "ve-range" or name == "vpls-id-conflict" or name == "vpn-added" or name == "vpn-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-signalling-method"):
                                    self.ad_signalling_method = value
                                    self.ad_signalling_method.value_namespace = name_space
                                    self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-number"):
                                    self.as_number = value
                                    self.as_number.value_namespace = name_space
                                    self.as_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "export-route-policy"):
                                    self.export_route_policy = value
                                    self.export_route_policy.value_namespace = name_space
                                    self.export_route_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "l2vpn-router-id"):
                                    self.l2vpn_router_id = value
                                    self.l2vpn_router_id.value_namespace = name_space
                                    self.l2vpn_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "provisioned-ve-id"):
                                    self.provisioned_ve_id = value
                                    self.provisioned_ve_id.value_namespace = name_space
                                    self.provisioned_ve_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "service-connected"):
                                    self.service_connected = value
                                    self.service_connected.value_namespace = name_space
                                    self.service_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-id"):
                                    self.ve_id = value
                                    self.ve_id.value_namespace = name_space
                                    self.ve_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-range"):
                                    self.ve_range = value
                                    self.ve_range.value_namespace = name_space
                                    self.ve_range.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpls-id-conflict"):
                                    self.vpls_id_conflict = value
                                    self.vpls_id_conflict.value_namespace = name_space
                                    self.vpls_id_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpn-added"):
                                    self.vpn_added = value
                                    self.vpn_added.value_namespace = name_space
                                    self.vpn_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpn-id"):
                                    self.vpn_id = value
                                    self.vpn_id.value_namespace = name_space
                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                        class P2MpInformation(Entity):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\:  str
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:   :py:class:`L2VpnVfiP2MpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignaling>`
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:   :py:class:`L2VpnVfiP2MpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransport>`
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:   :py:class:`P2MpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportState>`
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__init__()

                                self.yang_name = "p2mp-information"
                                self.yang_parent_name = "bridge-vfi"

                                self.attribute_set_name = YLeaf(YType.str, "attribute-set-name")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.ptree_id = YLeaf(YType.uint32, "ptree-id")

                                self.signaling = YLeaf(YType.enumeration, "signaling")

                                self.transport = YLeaf(YType.enumeration, "transport")

                                self.transport_status = YLeaf(YType.enumeration, "transport-status")

                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("attribute_set_name",
                                                "local_label",
                                                "ptree_id",
                                                "signaling",
                                                "transport",
                                                "transport_status",
                                                "tunnel_interface") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.attribute_set_name.is_set or
                                    self.local_label.is_set or
                                    self.ptree_id.is_set or
                                    self.signaling.is_set or
                                    self.transport.is_set or
                                    self.transport_status.is_set or
                                    self.tunnel_interface.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.attribute_set_name.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.ptree_id.yfilter != YFilter.not_set or
                                    self.signaling.yfilter != YFilter.not_set or
                                    self.transport.yfilter != YFilter.not_set or
                                    self.transport_status.yfilter != YFilter.not_set or
                                    self.tunnel_interface.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.attribute_set_name.is_set or self.attribute_set_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attribute_set_name.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.ptree_id.is_set or self.ptree_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ptree_id.get_name_leafdata())
                                if (self.signaling.is_set or self.signaling.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signaling.get_name_leafdata())
                                if (self.transport.is_set or self.transport.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport.get_name_leafdata())
                                if (self.transport_status.is_set or self.transport_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_status.get_name_leafdata())
                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "attribute-set-name" or name == "local-label" or name == "ptree-id" or name == "signaling" or name == "transport" or name == "transport-status" or name == "tunnel-interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "attribute-set-name"):
                                    self.attribute_set_name = value
                                    self.attribute_set_name.value_namespace = name_space
                                    self.attribute_set_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ptree-id"):
                                    self.ptree_id = value
                                    self.ptree_id.value_namespace = name_space
                                    self.ptree_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "signaling"):
                                    self.signaling = value
                                    self.signaling.value_namespace = name_space
                                    self.signaling.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport"):
                                    self.transport = value
                                    self.transport.value_namespace = name_space
                                    self.transport.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-status"):
                                    self.transport_status = value
                                    self.transport_status.value_namespace = name_space
                                    self.transport_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-interface"):
                                    self.tunnel_interface = value
                                    self.tunnel_interface.value_namespace = name_space
                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.p2mp_information:
                                if (c.has_data()):
                                    return True
                            return (
                                self.access.is_set or
                                self.number_pseudowires.is_set or
                                self.shutdown.is_set or
                                self.vfi_name.is_set or
                                self.vfi_state.is_set or
                                (self.discovery_information is not None and self.discovery_information.has_data()))

                        def has_operation(self):
                            for c in self.p2mp_information:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.access.yfilter != YFilter.not_set or
                                self.number_pseudowires.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.vfi_name.yfilter != YFilter.not_set or
                                self.vfi_state.yfilter != YFilter.not_set or
                                (self.discovery_information is not None and self.discovery_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-vfi" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.access.is_set or self.access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.access.get_name_leafdata())
                            if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.vfi_name.is_set or self.vfi_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vfi_name.get_name_leafdata())
                            if (self.vfi_state.is_set or self.vfi_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vfi_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "discovery-information"):
                                if (self.discovery_information is None):
                                    self.discovery_information = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                                    self.discovery_information.parent = self
                                    self._children_name_map["discovery_information"] = "discovery-information"
                                return self.discovery_information

                            if (child_yang_name == "p2mp-information"):
                                for c in self.p2mp_information:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.p2mp_information.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "discovery-information" or name == "p2mp-information" or name == "access" or name == "number-pseudowires" or name == "shutdown" or name == "vfi-name" or name == "vfi-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "access"):
                                self.access = value
                                self.access.value_namespace = name_space
                                self.access.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pseudowires"):
                                self.number_pseudowires = value
                                self.number_pseudowires.value_namespace = name_space
                                self.number_pseudowires.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "vfi-name"):
                                self.vfi_name = value
                                self.vfi_name.value_namespace = name_space
                                self.vfi_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vfi-state"):
                                self.vfi_state = value
                                self.vfi_state.value_namespace = name_space
                                self.vfi_state.value_namespace_prefix = name_space_prefix


                    class BridgeAccessVfi(Entity):
                        """
                        Access Virtual Forwarding Interfaces
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\:  bool
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\:  str
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:   :py:class:`L2VpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiState>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__init__()

                            self.yang_name = "bridge-access-vfi"
                            self.yang_parent_name = "bridge-domain-info"

                            self.access = YLeaf(YType.boolean, "access")

                            self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.vfi_name = YLeaf(YType.str, "vfi-name")

                            self.vfi_state = YLeaf(YType.enumeration, "vfi-state")

                            self.discovery_information = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self._children_name_map["discovery_information"] = "discovery-information"
                            self._children_yang_names.add("discovery-information")

                            self.p2mp_information = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("access",
                                            "number_pseudowires",
                                            "shutdown",
                                            "vfi_name",
                                            "vfi_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__setattr__(name, value)


                        class DiscoveryInformation(Entity):
                            """
                            Auto Discovery information
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\:  str
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\:  bool
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\:  bool
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\:  bool
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__init__()

                                self.yang_name = "discovery-information"
                                self.yang_parent_name = "bridge-access-vfi"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                                self.as_number = YLeaf(YType.uint32, "as-number")

                                self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                                self.l2vpn_router_id = YLeaf(YType.str, "l2vpn-router-id")

                                self.provisioned_ve_id = YLeaf(YType.uint32, "provisioned-ve-id")

                                self.service_connected = YLeaf(YType.boolean, "service-connected")

                                self.ve_id = YLeaf(YType.uint32, "ve-id")

                                self.ve_range = YLeaf(YType.uint16, "ve-range")

                                self.vpls_id_conflict = YLeaf(YType.boolean, "vpls-id-conflict")

                                self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                self.rd_value = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self._children_name_map["rd_value"] = "rd-value"
                                self._children_yang_names.add("rd-value")

                                self.vpls_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self._children_name_map["vpls_id"] = "vpls-id"
                                self._children_yang_names.add("vpls-id")

                                self.export_rt = YList(self)
                                self.import_rt = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_signalling_method",
                                                "as_number",
                                                "export_route_policy",
                                                "l2vpn_router_id",
                                                "provisioned_ve_id",
                                                "service_connected",
                                                "ve_id",
                                                "ve_range",
                                                "vpls_id_conflict",
                                                "vpn_added",
                                                "vpn_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__setattr__(name, value)


                            class RdValue(Entity):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__init__()

                                    self.yang_name = "rd-value"
                                    self.yang_parent_name = "discovery-information"

                                    self.rd = YLeaf(YType.enumeration, "rd")

                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rd") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "rd-value"

                                        self.auto_index = YLeaf(YType.uint16, "auto-index")

                                        self.router_id = YLeaf(YType.str, "router-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("auto_index",
                                                        "router_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.auto_index.is_set or
                                            self.router_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.auto_index.yfilter != YFilter.not_set or
                                            self.router_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.auto_index.get_name_leafdata())
                                        if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.router_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto-index" or name == "router-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "auto-index"):
                                            self.auto_index = value
                                            self.auto_index.value_namespace = name_space
                                            self.auto_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "router-id"):
                                            self.router_id = value
                                            self.router_id.value_namespace = name_space
                                            self.router_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "rd-value"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "rd-value"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "rd-value"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rd.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rd.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rd-value" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rd.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rd"):
                                        self.rd = value
                                        self.rd.value_namespace = name_space
                                        self.rd.value_namespace_prefix = name_space_prefix


                            class VplsId(Entity):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__init__()

                                    self.yang_name = "vpls-id"
                                    self.yang_parent_name = "discovery-information"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "vpls-id"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "vpls-id"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "vpls-id"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vpls-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class ImportRt(Entity):
                                """
                                List of import route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__init__()

                                    self.yang_name = "import-rt"
                                    self.yang_parent_name = "discovery-information"

                                    self.rt = YLeaf(YType.enumeration, "rt")

                                    self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._children_yang_names.add("es-import")

                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rt") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "import-rt"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "import-rt"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "import-rt"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "import-rt"

                                        self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                        self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("high_bytes",
                                                        "low_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.high_bytes.is_set or
                                            self.low_bytes.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.high_bytes.yfilter != YFilter.not_set or
                                            self.low_bytes.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-import" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                        if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "high-bytes" or name == "low-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "high-bytes"):
                                            self.high_bytes = value
                                            self.high_bytes.value_namespace = name_space
                                            self.high_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "low-bytes"):
                                            self.low_bytes = value
                                            self.low_bytes.value_namespace = name_space
                                            self.low_bytes.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rt.is_set or
                                        (self.es_import is not None and self.es_import.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rt.yfilter != YFilter.not_set or
                                        (self.es_import is not None and self.es_import.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "import-rt" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rt.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "es-import"):
                                        if (self.es_import is None):
                                            self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                            self.es_import.parent = self
                                            self._children_name_map["es_import"] = "es-import"
                                        return self.es_import

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rt"):
                                        self.rt = value
                                        self.rt.value_namespace = name_space
                                        self.rt.value_namespace_prefix = name_space_prefix


                            class ExportRt(Entity):
                                """
                                List of export route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__init__()

                                    self.yang_name = "export-rt"
                                    self.yang_parent_name = "discovery-information"

                                    self.rt = YLeaf(YType.enumeration, "rt")

                                    self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._children_yang_names.add("es-import")

                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                    self._children_yang_names.add("four-byte-as")

                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rt") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "export-rt"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "export-rt"

                                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_as",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_as.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_as.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "four-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-as" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-as"):
                                            self.four_byte_as = value
                                            self.four_byte_as.value_namespace = name_space
                                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "export-rt"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "export-rt"

                                        self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                        self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("high_bytes",
                                                        "low_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.high_bytes.is_set or
                                            self.low_bytes.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.high_bytes.yfilter != YFilter.not_set or
                                            self.low_bytes.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-import" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                        if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "high-bytes" or name == "low-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "high-bytes"):
                                            self.high_bytes = value
                                            self.high_bytes.value_namespace = name_space
                                            self.high_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "low-bytes"):
                                            self.low_bytes = value
                                            self.low_bytes.value_namespace = name_space
                                            self.low_bytes.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rt.is_set or
                                        (self.es_import is not None and self.es_import.has_data()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rt.yfilter != YFilter.not_set or
                                        (self.es_import is not None and self.es_import.has_operation()) or
                                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "export-rt" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rt.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "es-import"):
                                        if (self.es_import is None):
                                            self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                            self.es_import.parent = self
                                            self._children_name_map["es_import"] = "es-import"
                                        return self.es_import

                                    if (child_yang_name == "four-byte-as"):
                                        if (self.four_byte_as is None):
                                            self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                            self.four_byte_as.parent = self
                                            self._children_name_map["four_byte_as"] = "four-byte-as"
                                        return self.four_byte_as

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rt"):
                                        self.rt = value
                                        self.rt.value_namespace = name_space
                                        self.rt.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.export_rt:
                                    if (c.has_data()):
                                        return True
                                for c in self.import_rt:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.ad_method.is_set or
                                    self.ad_signalling_method.is_set or
                                    self.as_number.is_set or
                                    self.export_route_policy.is_set or
                                    self.l2vpn_router_id.is_set or
                                    self.provisioned_ve_id.is_set or
                                    self.service_connected.is_set or
                                    self.ve_id.is_set or
                                    self.ve_range.is_set or
                                    self.vpls_id_conflict.is_set or
                                    self.vpn_added.is_set or
                                    self.vpn_id.is_set or
                                    (self.rd_value is not None and self.rd_value.has_data()) or
                                    (self.vpls_id is not None and self.vpls_id.has_data()))

                            def has_operation(self):
                                for c in self.export_rt:
                                    if (c.has_operation()):
                                        return True
                                for c in self.import_rt:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_signalling_method.yfilter != YFilter.not_set or
                                    self.as_number.yfilter != YFilter.not_set or
                                    self.export_route_policy.yfilter != YFilter.not_set or
                                    self.l2vpn_router_id.yfilter != YFilter.not_set or
                                    self.provisioned_ve_id.yfilter != YFilter.not_set or
                                    self.service_connected.yfilter != YFilter.not_set or
                                    self.ve_id.yfilter != YFilter.not_set or
                                    self.ve_range.yfilter != YFilter.not_set or
                                    self.vpls_id_conflict.yfilter != YFilter.not_set or
                                    self.vpn_added.yfilter != YFilter.not_set or
                                    self.vpn_id.yfilter != YFilter.not_set or
                                    (self.rd_value is not None and self.rd_value.has_operation()) or
                                    (self.vpls_id is not None and self.vpls_id.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "discovery-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                                if (self.as_number.is_set or self.as_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_number.get_name_leafdata())
                                if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                                if (self.l2vpn_router_id.is_set or self.l2vpn_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l2vpn_router_id.get_name_leafdata())
                                if (self.provisioned_ve_id.is_set or self.provisioned_ve_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.provisioned_ve_id.get_name_leafdata())
                                if (self.service_connected.is_set or self.service_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.service_connected.get_name_leafdata())
                                if (self.ve_id.is_set or self.ve_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_id.get_name_leafdata())
                                if (self.ve_range.is_set or self.ve_range.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ve_range.get_name_leafdata())
                                if (self.vpls_id_conflict.is_set or self.vpls_id_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_conflict.get_name_leafdata())
                                if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpn_added.get_name_leafdata())
                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "export-rt"):
                                    for c in self.export_rt:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.export_rt.append(c)
                                    return c

                                if (child_yang_name == "import-rt"):
                                    for c in self.import_rt:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.import_rt.append(c)
                                    return c

                                if (child_yang_name == "rd-value"):
                                    if (self.rd_value is None):
                                        self.rd_value = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                        self.rd_value.parent = self
                                        self._children_name_map["rd_value"] = "rd-value"
                                    return self.rd_value

                                if (child_yang_name == "vpls-id"):
                                    if (self.vpls_id is None):
                                        self.vpls_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                        self.vpls_id.parent = self
                                        self._children_name_map["vpls_id"] = "vpls-id"
                                    return self.vpls_id

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "vpls-id" or name == "ad-method" or name == "ad-signalling-method" or name == "as-number" or name == "export-route-policy" or name == "l2vpn-router-id" or name == "provisioned-ve-id" or name == "service-connected" or name == "ve-id" or name == "ve-range" or name == "vpls-id-conflict" or name == "vpn-added" or name == "vpn-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-signalling-method"):
                                    self.ad_signalling_method = value
                                    self.ad_signalling_method.value_namespace = name_space
                                    self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-number"):
                                    self.as_number = value
                                    self.as_number.value_namespace = name_space
                                    self.as_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "export-route-policy"):
                                    self.export_route_policy = value
                                    self.export_route_policy.value_namespace = name_space
                                    self.export_route_policy.value_namespace_prefix = name_space_prefix
                                if(value_path == "l2vpn-router-id"):
                                    self.l2vpn_router_id = value
                                    self.l2vpn_router_id.value_namespace = name_space
                                    self.l2vpn_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "provisioned-ve-id"):
                                    self.provisioned_ve_id = value
                                    self.provisioned_ve_id.value_namespace = name_space
                                    self.provisioned_ve_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "service-connected"):
                                    self.service_connected = value
                                    self.service_connected.value_namespace = name_space
                                    self.service_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-id"):
                                    self.ve_id = value
                                    self.ve_id.value_namespace = name_space
                                    self.ve_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ve-range"):
                                    self.ve_range = value
                                    self.ve_range.value_namespace = name_space
                                    self.ve_range.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpls-id-conflict"):
                                    self.vpls_id_conflict = value
                                    self.vpls_id_conflict.value_namespace = name_space
                                    self.vpls_id_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpn-added"):
                                    self.vpn_added = value
                                    self.vpn_added.value_namespace = name_space
                                    self.vpn_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpn-id"):
                                    self.vpn_id = value
                                    self.vpn_id.value_namespace = name_space
                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                        class P2MpInformation(Entity):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\:  str
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:   :py:class:`L2VpnVfiP2MpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignaling>`
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:   :py:class:`L2VpnVfiP2MpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransport>`
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:   :py:class:`P2MpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportState>`
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__init__()

                                self.yang_name = "p2mp-information"
                                self.yang_parent_name = "bridge-access-vfi"

                                self.attribute_set_name = YLeaf(YType.str, "attribute-set-name")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.ptree_id = YLeaf(YType.uint32, "ptree-id")

                                self.signaling = YLeaf(YType.enumeration, "signaling")

                                self.transport = YLeaf(YType.enumeration, "transport")

                                self.transport_status = YLeaf(YType.enumeration, "transport-status")

                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("attribute_set_name",
                                                "local_label",
                                                "ptree_id",
                                                "signaling",
                                                "transport",
                                                "transport_status",
                                                "tunnel_interface") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.attribute_set_name.is_set or
                                    self.local_label.is_set or
                                    self.ptree_id.is_set or
                                    self.signaling.is_set or
                                    self.transport.is_set or
                                    self.transport_status.is_set or
                                    self.tunnel_interface.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.attribute_set_name.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.ptree_id.yfilter != YFilter.not_set or
                                    self.signaling.yfilter != YFilter.not_set or
                                    self.transport.yfilter != YFilter.not_set or
                                    self.transport_status.yfilter != YFilter.not_set or
                                    self.tunnel_interface.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.attribute_set_name.is_set or self.attribute_set_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attribute_set_name.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.ptree_id.is_set or self.ptree_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ptree_id.get_name_leafdata())
                                if (self.signaling.is_set or self.signaling.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.signaling.get_name_leafdata())
                                if (self.transport.is_set or self.transport.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport.get_name_leafdata())
                                if (self.transport_status.is_set or self.transport_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_status.get_name_leafdata())
                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "attribute-set-name" or name == "local-label" or name == "ptree-id" or name == "signaling" or name == "transport" or name == "transport-status" or name == "tunnel-interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "attribute-set-name"):
                                    self.attribute_set_name = value
                                    self.attribute_set_name.value_namespace = name_space
                                    self.attribute_set_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ptree-id"):
                                    self.ptree_id = value
                                    self.ptree_id.value_namespace = name_space
                                    self.ptree_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "signaling"):
                                    self.signaling = value
                                    self.signaling.value_namespace = name_space
                                    self.signaling.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport"):
                                    self.transport = value
                                    self.transport.value_namespace = name_space
                                    self.transport.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-status"):
                                    self.transport_status = value
                                    self.transport_status.value_namespace = name_space
                                    self.transport_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-interface"):
                                    self.tunnel_interface = value
                                    self.tunnel_interface.value_namespace = name_space
                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.p2mp_information:
                                if (c.has_data()):
                                    return True
                            return (
                                self.access.is_set or
                                self.number_pseudowires.is_set or
                                self.shutdown.is_set or
                                self.vfi_name.is_set or
                                self.vfi_state.is_set or
                                (self.discovery_information is not None and self.discovery_information.has_data()))

                        def has_operation(self):
                            for c in self.p2mp_information:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.access.yfilter != YFilter.not_set or
                                self.number_pseudowires.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.vfi_name.yfilter != YFilter.not_set or
                                self.vfi_state.yfilter != YFilter.not_set or
                                (self.discovery_information is not None and self.discovery_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-access-vfi" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.access.is_set or self.access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.access.get_name_leafdata())
                            if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.vfi_name.is_set or self.vfi_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vfi_name.get_name_leafdata())
                            if (self.vfi_state.is_set or self.vfi_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vfi_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "discovery-information"):
                                if (self.discovery_information is None):
                                    self.discovery_information = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                                    self.discovery_information.parent = self
                                    self._children_name_map["discovery_information"] = "discovery-information"
                                return self.discovery_information

                            if (child_yang_name == "p2mp-information"):
                                for c in self.p2mp_information:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.p2mp_information.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "discovery-information" or name == "p2mp-information" or name == "access" or name == "number-pseudowires" or name == "shutdown" or name == "vfi-name" or name == "vfi-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "access"):
                                self.access = value
                                self.access.value_namespace = name_space
                                self.access.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pseudowires"):
                                self.number_pseudowires = value
                                self.number_pseudowires.value_namespace = name_space
                                self.number_pseudowires.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "vfi-name"):
                                self.vfi_name = value
                                self.vfi_name.value_namespace = name_space
                                self.vfi_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vfi-state"):
                                self.vfi_state = value
                                self.vfi_state.value_namespace = name_space
                                self.vfi_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bridge_access_vfi:
                            if (c.has_data()):
                                return True
                        for c in self.bridge_vfi:
                            if (c.has_data()):
                                return True
                        for c in self.mac_filter:
                            if (c.has_data()):
                                return True
                        return (
                            self.acpwup.is_set or
                            self.as_.is_set or
                            self.bridge_coupled_state.is_set or
                            self.bridge_description.is_set or
                            self.bridge_domain_id.is_set or
                            self.bridge_internal_msti.is_set or
                            self.bridge_msti.is_set or
                            self.bridge_mtu.is_set or
                            self.bridge_name.is_set or
                            self.bridge_shg_id.is_set or
                            self.bridge_state.is_set or
                            self.bridge_type.is_set or
                            self.configured.is_set or
                            self.disposition_bytecount.is_set or
                            self.disposition_pkt_count.is_set or
                            self.evi.is_set or
                            self.flodd_group_id_down.is_set or
                            self.group_name.is_set or
                            self.imposition_byte_count.is_set or
                            self.imposition_pkt_count.is_set or
                            self.is_bridge_partially_programmed.is_set or
                            self.is_rd_configured.is_set or
                            self.last_time_status_changed.is_set or
                            self.load_balance.is_set or
                            self.mac_limit_down.is_set or
                            self.mac_withdraw.is_set or
                            self.mac_withdraw_access.is_set or
                            self.mac_withdraw_option.is_set or
                            self.mac_withdraw_relay.is_set or
                            self.num_vn_is.is_set or
                            self.num_vn_is_up.is_set or
                            self.number_a_cs.is_set or
                            self.number_a_cs_up.is_set or
                            self.number_access_vf_is.is_set or
                            self.number_p_ws_up.is_set or
                            self.number_pb_bs.is_set or
                            self.number_pb_bs_up.is_set or
                            self.number_pseudowires.is_set or
                            self.number_vf_is.is_set or
                            self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                            self.p2mp_enabled.is_set or
                            self.partially_programmed_a_cs.is_set or
                            self.partially_programmed_pseudowires.is_set or
                            self.shutdown.is_set or
                            self.standby_pseudowires.is_set or
                            self.time_created.is_set or
                            self.time_elapsed_creation.is_set or
                            self.time_elapsed_status_changed.is_set or
                            self.vine_fsm_state.is_set or
                            (self.evpn_parameters is not None and self.evpn_parameters.has_data()) or
                            (self.pbb_parameters is not None and self.pbb_parameters.has_data()) or
                            (self.rd is not None and self.rd.has_data()) or
                            (self.security_parameters is not None and self.security_parameters.has_data()) or
                            (self.vni_parameters is not None and self.vni_parameters.has_data()))

                    def has_operation(self):
                        for c in self.bridge_access_vfi:
                            if (c.has_operation()):
                                return True
                        for c in self.bridge_vfi:
                            if (c.has_operation()):
                                return True
                        for c in self.mac_filter:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.acpwup.yfilter != YFilter.not_set or
                            self.as_.yfilter != YFilter.not_set or
                            self.bridge_coupled_state.yfilter != YFilter.not_set or
                            self.bridge_description.yfilter != YFilter.not_set or
                            self.bridge_domain_id.yfilter != YFilter.not_set or
                            self.bridge_internal_msti.yfilter != YFilter.not_set or
                            self.bridge_msti.yfilter != YFilter.not_set or
                            self.bridge_mtu.yfilter != YFilter.not_set or
                            self.bridge_name.yfilter != YFilter.not_set or
                            self.bridge_shg_id.yfilter != YFilter.not_set or
                            self.bridge_state.yfilter != YFilter.not_set or
                            self.bridge_type.yfilter != YFilter.not_set or
                            self.configured.yfilter != YFilter.not_set or
                            self.disposition_bytecount.yfilter != YFilter.not_set or
                            self.disposition_pkt_count.yfilter != YFilter.not_set or
                            self.evi.yfilter != YFilter.not_set or
                            self.flodd_group_id_down.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.imposition_byte_count.yfilter != YFilter.not_set or
                            self.imposition_pkt_count.yfilter != YFilter.not_set or
                            self.is_bridge_partially_programmed.yfilter != YFilter.not_set or
                            self.is_rd_configured.yfilter != YFilter.not_set or
                            self.last_time_status_changed.yfilter != YFilter.not_set or
                            self.load_balance.yfilter != YFilter.not_set or
                            self.mac_limit_down.yfilter != YFilter.not_set or
                            self.mac_withdraw.yfilter != YFilter.not_set or
                            self.mac_withdraw_access.yfilter != YFilter.not_set or
                            self.mac_withdraw_option.yfilter != YFilter.not_set or
                            self.mac_withdraw_relay.yfilter != YFilter.not_set or
                            self.num_vn_is.yfilter != YFilter.not_set or
                            self.num_vn_is_up.yfilter != YFilter.not_set or
                            self.number_a_cs.yfilter != YFilter.not_set or
                            self.number_a_cs_up.yfilter != YFilter.not_set or
                            self.number_access_vf_is.yfilter != YFilter.not_set or
                            self.number_p_ws_up.yfilter != YFilter.not_set or
                            self.number_pb_bs.yfilter != YFilter.not_set or
                            self.number_pb_bs_up.yfilter != YFilter.not_set or
                            self.number_pseudowires.yfilter != YFilter.not_set or
                            self.number_vf_is.yfilter != YFilter.not_set or
                            self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                            self.p2mp_enabled.yfilter != YFilter.not_set or
                            self.partially_programmed_a_cs.yfilter != YFilter.not_set or
                            self.partially_programmed_pseudowires.yfilter != YFilter.not_set or
                            self.shutdown.yfilter != YFilter.not_set or
                            self.standby_pseudowires.yfilter != YFilter.not_set or
                            self.time_created.yfilter != YFilter.not_set or
                            self.time_elapsed_creation.yfilter != YFilter.not_set or
                            self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                            self.vine_fsm_state.yfilter != YFilter.not_set or
                            (self.evpn_parameters is not None and self.evpn_parameters.has_operation()) or
                            (self.pbb_parameters is not None and self.pbb_parameters.has_operation()) or
                            (self.rd is not None and self.rd.has_operation()) or
                            (self.security_parameters is not None and self.security_parameters.has_operation()) or
                            (self.vni_parameters is not None and self.vni_parameters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-domain-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.acpwup.is_set or self.acpwup.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.acpwup.get_name_leafdata())
                        if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.as_.get_name_leafdata())
                        if (self.bridge_coupled_state.is_set or self.bridge_coupled_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_coupled_state.get_name_leafdata())
                        if (self.bridge_description.is_set or self.bridge_description.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_description.get_name_leafdata())
                        if (self.bridge_domain_id.is_set or self.bridge_domain_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_id.get_name_leafdata())
                        if (self.bridge_internal_msti.is_set or self.bridge_internal_msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_internal_msti.get_name_leafdata())
                        if (self.bridge_msti.is_set or self.bridge_msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_msti.get_name_leafdata())
                        if (self.bridge_mtu.is_set or self.bridge_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_mtu.get_name_leafdata())
                        if (self.bridge_name.is_set or self.bridge_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_name.get_name_leafdata())
                        if (self.bridge_shg_id.is_set or self.bridge_shg_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_shg_id.get_name_leafdata())
                        if (self.bridge_state.is_set or self.bridge_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_state.get_name_leafdata())
                        if (self.bridge_type.is_set or self.bridge_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_type.get_name_leafdata())
                        if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured.get_name_leafdata())
                        if (self.disposition_bytecount.is_set or self.disposition_bytecount.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disposition_bytecount.get_name_leafdata())
                        if (self.disposition_pkt_count.is_set or self.disposition_pkt_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disposition_pkt_count.get_name_leafdata())
                        if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evi.get_name_leafdata())
                        if (self.flodd_group_id_down.is_set or self.flodd_group_id_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flodd_group_id_down.get_name_leafdata())
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.imposition_byte_count.is_set or self.imposition_byte_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.imposition_byte_count.get_name_leafdata())
                        if (self.imposition_pkt_count.is_set or self.imposition_pkt_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.imposition_pkt_count.get_name_leafdata())
                        if (self.is_bridge_partially_programmed.is_set or self.is_bridge_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bridge_partially_programmed.get_name_leafdata())
                        if (self.is_rd_configured.is_set or self.is_rd_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rd_configured.get_name_leafdata())
                        if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                        if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance.get_name_leafdata())
                        if (self.mac_limit_down.is_set or self.mac_limit_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_down.get_name_leafdata())
                        if (self.mac_withdraw.is_set or self.mac_withdraw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_withdraw.get_name_leafdata())
                        if (self.mac_withdraw_access.is_set or self.mac_withdraw_access.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_withdraw_access.get_name_leafdata())
                        if (self.mac_withdraw_option.is_set or self.mac_withdraw_option.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_withdraw_option.get_name_leafdata())
                        if (self.mac_withdraw_relay.is_set or self.mac_withdraw_relay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_withdraw_relay.get_name_leafdata())
                        if (self.num_vn_is.is_set or self.num_vn_is.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_vn_is.get_name_leafdata())
                        if (self.num_vn_is_up.is_set or self.num_vn_is_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_vn_is_up.get_name_leafdata())
                        if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                        if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                        if (self.number_access_vf_is.is_set or self.number_access_vf_is.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_access_vf_is.get_name_leafdata())
                        if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                        if (self.number_pb_bs.is_set or self.number_pb_bs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_pb_bs.get_name_leafdata())
                        if (self.number_pb_bs_up.is_set or self.number_pb_bs_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_pb_bs_up.get_name_leafdata())
                        if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                        if (self.number_vf_is.is_set or self.number_vf_is.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_vf_is.get_name_leafdata())
                        if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                        if (self.p2mp_enabled.is_set or self.p2mp_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.p2mp_enabled.get_name_leafdata())
                        if (self.partially_programmed_a_cs.is_set or self.partially_programmed_a_cs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.partially_programmed_a_cs.get_name_leafdata())
                        if (self.partially_programmed_pseudowires.is_set or self.partially_programmed_pseudowires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.partially_programmed_pseudowires.get_name_leafdata())
                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                        if (self.standby_pseudowires.is_set or self.standby_pseudowires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.standby_pseudowires.get_name_leafdata())
                        if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_created.get_name_leafdata())
                        if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                        if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                        if (self.vine_fsm_state.is_set or self.vine_fsm_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vine_fsm_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-access-vfi"):
                            for c in self.bridge_access_vfi:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bridge_access_vfi.append(c)
                            return c

                        if (child_yang_name == "bridge-vfi"):
                            for c in self.bridge_vfi:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bridge_vfi.append(c)
                            return c

                        if (child_yang_name == "evpn-parameters"):
                            if (self.evpn_parameters is None):
                                self.evpn_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                                self.evpn_parameters.parent = self
                                self._children_name_map["evpn_parameters"] = "evpn-parameters"
                            return self.evpn_parameters

                        if (child_yang_name == "mac-filter"):
                            for c in self.mac_filter:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mac_filter.append(c)
                            return c

                        if (child_yang_name == "pbb-parameters"):
                            if (self.pbb_parameters is None):
                                self.pbb_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                                self.pbb_parameters.parent = self
                                self._children_name_map["pbb_parameters"] = "pbb-parameters"
                            return self.pbb_parameters

                        if (child_yang_name == "rd"):
                            if (self.rd is None):
                                self.rd = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                                self.rd.parent = self
                                self._children_name_map["rd"] = "rd"
                            return self.rd

                        if (child_yang_name == "security-parameters"):
                            if (self.security_parameters is None):
                                self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                            return self.security_parameters

                        if (child_yang_name == "vni-parameters"):
                            if (self.vni_parameters is None):
                                self.vni_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                                self.vni_parameters.parent = self
                                self._children_name_map["vni_parameters"] = "vni-parameters"
                            return self.vni_parameters

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-access-vfi" or name == "bridge-vfi" or name == "evpn-parameters" or name == "mac-filter" or name == "pbb-parameters" or name == "rd" or name == "security-parameters" or name == "vni-parameters" or name == "acpwup" or name == "as" or name == "bridge-coupled-state" or name == "bridge-description" or name == "bridge-domain-id" or name == "bridge-internal-msti" or name == "bridge-msti" or name == "bridge-mtu" or name == "bridge-name" or name == "bridge-shg-id" or name == "bridge-state" or name == "bridge-type" or name == "configured" or name == "disposition-bytecount" or name == "disposition-pkt-count" or name == "evi" or name == "flodd-group-id-down" or name == "group-name" or name == "imposition-byte-count" or name == "imposition-pkt-count" or name == "is-bridge-partially-programmed" or name == "is-rd-configured" or name == "last-time-status-changed" or name == "load-balance" or name == "mac-limit-down" or name == "mac-withdraw" or name == "mac-withdraw-access" or name == "mac-withdraw-option" or name == "mac-withdraw-relay" or name == "num-vn-is" or name == "num-vn-is-up" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-access-vf-is" or name == "number-p-ws-up" or name == "number-pb-bs" or name == "number-pb-bs-up" or name == "number-pseudowires" or name == "number-vf-is" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "p2mp-enabled" or name == "partially-programmed-a-cs" or name == "partially-programmed-pseudowires" or name == "shutdown" or name == "standby-pseudowires" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "vine-fsm-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "acpwup"):
                            self.acpwup = value
                            self.acpwup.value_namespace = name_space
                            self.acpwup.value_namespace_prefix = name_space_prefix
                        if(value_path == "as"):
                            self.as_ = value
                            self.as_.value_namespace = name_space
                            self.as_.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-coupled-state"):
                            self.bridge_coupled_state = value
                            self.bridge_coupled_state.value_namespace = name_space
                            self.bridge_coupled_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-description"):
                            self.bridge_description = value
                            self.bridge_description.value_namespace = name_space
                            self.bridge_description.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-id"):
                            self.bridge_domain_id = value
                            self.bridge_domain_id.value_namespace = name_space
                            self.bridge_domain_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-internal-msti"):
                            self.bridge_internal_msti = value
                            self.bridge_internal_msti.value_namespace = name_space
                            self.bridge_internal_msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-msti"):
                            self.bridge_msti = value
                            self.bridge_msti.value_namespace = name_space
                            self.bridge_msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-mtu"):
                            self.bridge_mtu = value
                            self.bridge_mtu.value_namespace = name_space
                            self.bridge_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-name"):
                            self.bridge_name = value
                            self.bridge_name.value_namespace = name_space
                            self.bridge_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-shg-id"):
                            self.bridge_shg_id = value
                            self.bridge_shg_id.value_namespace = name_space
                            self.bridge_shg_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-state"):
                            self.bridge_state = value
                            self.bridge_state.value_namespace = name_space
                            self.bridge_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-type"):
                            self.bridge_type = value
                            self.bridge_type.value_namespace = name_space
                            self.bridge_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured"):
                            self.configured = value
                            self.configured.value_namespace = name_space
                            self.configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "disposition-bytecount"):
                            self.disposition_bytecount = value
                            self.disposition_bytecount.value_namespace = name_space
                            self.disposition_bytecount.value_namespace_prefix = name_space_prefix
                        if(value_path == "disposition-pkt-count"):
                            self.disposition_pkt_count = value
                            self.disposition_pkt_count.value_namespace = name_space
                            self.disposition_pkt_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "evi"):
                            self.evi = value
                            self.evi.value_namespace = name_space
                            self.evi.value_namespace_prefix = name_space_prefix
                        if(value_path == "flodd-group-id-down"):
                            self.flodd_group_id_down = value
                            self.flodd_group_id_down.value_namespace = name_space
                            self.flodd_group_id_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "imposition-byte-count"):
                            self.imposition_byte_count = value
                            self.imposition_byte_count.value_namespace = name_space
                            self.imposition_byte_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "imposition-pkt-count"):
                            self.imposition_pkt_count = value
                            self.imposition_pkt_count.value_namespace = name_space
                            self.imposition_pkt_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bridge-partially-programmed"):
                            self.is_bridge_partially_programmed = value
                            self.is_bridge_partially_programmed.value_namespace = name_space
                            self.is_bridge_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rd-configured"):
                            self.is_rd_configured = value
                            self.is_rd_configured.value_namespace = name_space
                            self.is_rd_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-changed"):
                            self.last_time_status_changed = value
                            self.last_time_status_changed.value_namespace = name_space
                            self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance"):
                            self.load_balance = value
                            self.load_balance.value_namespace = name_space
                            self.load_balance.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-down"):
                            self.mac_limit_down = value
                            self.mac_limit_down.value_namespace = name_space
                            self.mac_limit_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-withdraw"):
                            self.mac_withdraw = value
                            self.mac_withdraw.value_namespace = name_space
                            self.mac_withdraw.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-withdraw-access"):
                            self.mac_withdraw_access = value
                            self.mac_withdraw_access.value_namespace = name_space
                            self.mac_withdraw_access.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-withdraw-option"):
                            self.mac_withdraw_option = value
                            self.mac_withdraw_option.value_namespace = name_space
                            self.mac_withdraw_option.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-withdraw-relay"):
                            self.mac_withdraw_relay = value
                            self.mac_withdraw_relay.value_namespace = name_space
                            self.mac_withdraw_relay.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-vn-is"):
                            self.num_vn_is = value
                            self.num_vn_is.value_namespace = name_space
                            self.num_vn_is.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-vn-is-up"):
                            self.num_vn_is_up = value
                            self.num_vn_is_up.value_namespace = name_space
                            self.num_vn_is_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-a-cs"):
                            self.number_a_cs = value
                            self.number_a_cs.value_namespace = name_space
                            self.number_a_cs.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-a-cs-up"):
                            self.number_a_cs_up = value
                            self.number_a_cs_up.value_namespace = name_space
                            self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-access-vf-is"):
                            self.number_access_vf_is = value
                            self.number_access_vf_is.value_namespace = name_space
                            self.number_access_vf_is.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-p-ws-up"):
                            self.number_p_ws_up = value
                            self.number_p_ws_up.value_namespace = name_space
                            self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-pb-bs"):
                            self.number_pb_bs = value
                            self.number_pb_bs.value_namespace = name_space
                            self.number_pb_bs.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-pb-bs-up"):
                            self.number_pb_bs_up = value
                            self.number_pb_bs_up.value_namespace = name_space
                            self.number_pb_bs_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-pseudowires"):
                            self.number_pseudowires = value
                            self.number_pseudowires.value_namespace = name_space
                            self.number_pseudowires.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-vf-is"):
                            self.number_vf_is = value
                            self.number_vf_is.value_namespace = name_space
                            self.number_vf_is.value_namespace_prefix = name_space_prefix
                        if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                            self.nv_satellite_offload_ipv4_multicast_disabled = value
                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                            self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "p2mp-enabled"):
                            self.p2mp_enabled = value
                            self.p2mp_enabled.value_namespace = name_space
                            self.p2mp_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "partially-programmed-a-cs"):
                            self.partially_programmed_a_cs = value
                            self.partially_programmed_a_cs.value_namespace = name_space
                            self.partially_programmed_a_cs.value_namespace_prefix = name_space_prefix
                        if(value_path == "partially-programmed-pseudowires"):
                            self.partially_programmed_pseudowires = value
                            self.partially_programmed_pseudowires.value_namespace = name_space
                            self.partially_programmed_pseudowires.value_namespace_prefix = name_space_prefix
                        if(value_path == "shutdown"):
                            self.shutdown = value
                            self.shutdown.value_namespace = name_space
                            self.shutdown.value_namespace_prefix = name_space_prefix
                        if(value_path == "standby-pseudowires"):
                            self.standby_pseudowires = value
                            self.standby_pseudowires.value_namespace = name_space
                            self.standby_pseudowires.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-created"):
                            self.time_created = value
                            self.time_created.value_namespace = name_space
                            self.time_created.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-creation"):
                            self.time_elapsed_creation = value
                            self.time_elapsed_creation.value_namespace = name_space
                            self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-changed"):
                            self.time_elapsed_status_changed = value
                            self.time_elapsed_status_changed.value_namespace = name_space
                            self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "vine-fsm-state"):
                            self.vine_fsm_state = value
                            self.vine_fsm_state.value_namespace = name_space
                            self.vine_fsm_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bridge_domain_group_name.is_set or
                        self.bridge_domain_name.is_set or
                        (self.bridge_access_pws is not None and self.bridge_access_pws.has_data()) or
                        (self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table.has_data()) or
                        (self.bridge_acs is not None and self.bridge_acs.has_data()) or
                        (self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table.has_data()) or
                        (self.bridge_domain_info is not None and self.bridge_domain_info.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bridge_domain_group_name.yfilter != YFilter.not_set or
                        self.bridge_domain_name.yfilter != YFilter.not_set or
                        (self.bridge_access_pws is not None and self.bridge_access_pws.has_operation()) or
                        (self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table.has_operation()) or
                        (self.bridge_acs is not None and self.bridge_acs.has_operation()) or
                        (self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table.has_operation()) or
                        (self.bridge_domain_info is not None and self.bridge_domain_info.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bridge-domain" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bridge_domain_group_name.is_set or self.bridge_domain_group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_domain_group_name.get_name_leafdata())
                    if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bridge-access-pws"):
                        if (self.bridge_access_pws is None):
                            self.bridge_access_pws = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws()
                            self.bridge_access_pws.parent = self
                            self._children_name_map["bridge_access_pws"] = "bridge-access-pws"
                        return self.bridge_access_pws

                    if (child_yang_name == "bridge-access-vfi-table"):
                        if (self.bridge_access_vfi_table is None):
                            self.bridge_access_vfi_table = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                            self.bridge_access_vfi_table.parent = self
                            self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"
                        return self.bridge_access_vfi_table

                    if (child_yang_name == "bridge-acs"):
                        if (self.bridge_acs is None):
                            self.bridge_acs = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs()
                            self.bridge_acs.parent = self
                            self._children_name_map["bridge_acs"] = "bridge-acs"
                        return self.bridge_acs

                    if (child_yang_name == "bridge-core-vfi-table"):
                        if (self.bridge_core_vfi_table is None):
                            self.bridge_core_vfi_table = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                            self.bridge_core_vfi_table.parent = self
                            self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"
                        return self.bridge_core_vfi_table

                    if (child_yang_name == "bridge-domain-info"):
                        if (self.bridge_domain_info is None):
                            self.bridge_domain_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                            self.bridge_domain_info.parent = self
                            self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                        return self.bridge_domain_info

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bridge-access-pws" or name == "bridge-access-vfi-table" or name == "bridge-acs" or name == "bridge-core-vfi-table" or name == "bridge-domain-info" or name == "bridge-domain-group-name" or name == "bridge-domain-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bridge-domain-group-name"):
                        self.bridge_domain_group_name = value
                        self.bridge_domain_group_name.value_namespace = name_space
                        self.bridge_domain_group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-domain-name"):
                        self.bridge_domain_name = value
                        self.bridge_domain_name.value_namespace = name_space
                        self.bridge_domain_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.bridge_domain:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.bridge_domain:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bridge-domains" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bridge-domain"):
                    for c in self.bridge_domain:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.BridgeDomains.BridgeDomain()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.bridge_domain.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bridge-domain"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class DiscoverySummary(Entity):
            """
            Discovery summary information
            
            .. attribute:: bgp_current_node_id
            
            	BGP current node id
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: bgp_ipc_transport_mode
            
            	IPC Transport mode with BGP
            	**type**\:   :py:class:`L2VpnIpcTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIpcTransportMode>`
            
            .. attribute:: bgp_stateon_active_rp
            
            	BGP state on the active RP
            	**type**\:  bool
            
            .. attribute:: bgp_stateon_standby_rp
            
            	BGP state on standby RP
            	**type**\:  bool
            
            .. attribute:: number_bridge_domainvpns
            
            	Number of BDs registered
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_bridge_domain
            
            	Number of local Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_xconnect
            
            	Number of local Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2m_pxconnect_vpns
            
            	Number of XCs registered
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_bridge_domain
            
            	Number of NLRI
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_xconnect
            
            	Number of NLRI
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_bridge_domain
            
            	Number of Remote Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_xconnect
            
            	Number of Remote Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: vpls_registered
            
            	Is the VPLS service registered
            	**type**\:  bool
            
            .. attribute:: vpws_registered
            
            	Is the VPWS service registered
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.DiscoverySummary, self).__init__()

                self.yang_name = "discovery-summary"
                self.yang_parent_name = "active"

                self.bgp_current_node_id = YLeaf(YType.str, "bgp-current-node-id")

                self.bgp_ipc_transport_mode = YLeaf(YType.enumeration, "bgp-ipc-transport-mode")

                self.bgp_stateon_active_rp = YLeaf(YType.boolean, "bgp-stateon-active-rp")

                self.bgp_stateon_standby_rp = YLeaf(YType.boolean, "bgp-stateon-standby-rp")

                self.number_bridge_domainvpns = YLeaf(YType.uint32, "number-bridge-domainvpns")

                self.number_local_edges_bridge_domain = YLeaf(YType.uint32, "number-local-edges-bridge-domain")

                self.number_local_edges_xconnect = YLeaf(YType.uint32, "number-local-edges-xconnect")

                self.number_mp2m_pxconnect_vpns = YLeaf(YType.uint32, "number-mp2m-pxconnect-vpns")

                self.number_nlri_bridge_domain = YLeaf(YType.uint32, "number-nlri-bridge-domain")

                self.number_nlri_xconnect = YLeaf(YType.uint32, "number-nlri-xconnect")

                self.number_remote_edges_bridge_domain = YLeaf(YType.uint32, "number-remote-edges-bridge-domain")

                self.number_remote_edges_xconnect = YLeaf(YType.uint32, "number-remote-edges-xconnect")

                self.vpls_registered = YLeaf(YType.boolean, "vpls-registered")

                self.vpws_registered = YLeaf(YType.boolean, "vpws-registered")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("bgp_current_node_id",
                                "bgp_ipc_transport_mode",
                                "bgp_stateon_active_rp",
                                "bgp_stateon_standby_rp",
                                "number_bridge_domainvpns",
                                "number_local_edges_bridge_domain",
                                "number_local_edges_xconnect",
                                "number_mp2m_pxconnect_vpns",
                                "number_nlri_bridge_domain",
                                "number_nlri_xconnect",
                                "number_remote_edges_bridge_domain",
                                "number_remote_edges_xconnect",
                                "vpls_registered",
                                "vpws_registered") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.DiscoverySummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.DiscoverySummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.bgp_current_node_id.is_set or
                    self.bgp_ipc_transport_mode.is_set or
                    self.bgp_stateon_active_rp.is_set or
                    self.bgp_stateon_standby_rp.is_set or
                    self.number_bridge_domainvpns.is_set or
                    self.number_local_edges_bridge_domain.is_set or
                    self.number_local_edges_xconnect.is_set or
                    self.number_mp2m_pxconnect_vpns.is_set or
                    self.number_nlri_bridge_domain.is_set or
                    self.number_nlri_xconnect.is_set or
                    self.number_remote_edges_bridge_domain.is_set or
                    self.number_remote_edges_xconnect.is_set or
                    self.vpls_registered.is_set or
                    self.vpws_registered.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.bgp_current_node_id.yfilter != YFilter.not_set or
                    self.bgp_ipc_transport_mode.yfilter != YFilter.not_set or
                    self.bgp_stateon_active_rp.yfilter != YFilter.not_set or
                    self.bgp_stateon_standby_rp.yfilter != YFilter.not_set or
                    self.number_bridge_domainvpns.yfilter != YFilter.not_set or
                    self.number_local_edges_bridge_domain.yfilter != YFilter.not_set or
                    self.number_local_edges_xconnect.yfilter != YFilter.not_set or
                    self.number_mp2m_pxconnect_vpns.yfilter != YFilter.not_set or
                    self.number_nlri_bridge_domain.yfilter != YFilter.not_set or
                    self.number_nlri_xconnect.yfilter != YFilter.not_set or
                    self.number_remote_edges_bridge_domain.yfilter != YFilter.not_set or
                    self.number_remote_edges_xconnect.yfilter != YFilter.not_set or
                    self.vpls_registered.yfilter != YFilter.not_set or
                    self.vpws_registered.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "discovery-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.bgp_current_node_id.is_set or self.bgp_current_node_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bgp_current_node_id.get_name_leafdata())
                if (self.bgp_ipc_transport_mode.is_set or self.bgp_ipc_transport_mode.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bgp_ipc_transport_mode.get_name_leafdata())
                if (self.bgp_stateon_active_rp.is_set or self.bgp_stateon_active_rp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bgp_stateon_active_rp.get_name_leafdata())
                if (self.bgp_stateon_standby_rp.is_set or self.bgp_stateon_standby_rp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bgp_stateon_standby_rp.get_name_leafdata())
                if (self.number_bridge_domainvpns.is_set or self.number_bridge_domainvpns.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_bridge_domainvpns.get_name_leafdata())
                if (self.number_local_edges_bridge_domain.is_set or self.number_local_edges_bridge_domain.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_local_edges_bridge_domain.get_name_leafdata())
                if (self.number_local_edges_xconnect.is_set or self.number_local_edges_xconnect.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_local_edges_xconnect.get_name_leafdata())
                if (self.number_mp2m_pxconnect_vpns.is_set or self.number_mp2m_pxconnect_vpns.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_mp2m_pxconnect_vpns.get_name_leafdata())
                if (self.number_nlri_bridge_domain.is_set or self.number_nlri_bridge_domain.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_nlri_bridge_domain.get_name_leafdata())
                if (self.number_nlri_xconnect.is_set or self.number_nlri_xconnect.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_nlri_xconnect.get_name_leafdata())
                if (self.number_remote_edges_bridge_domain.is_set or self.number_remote_edges_bridge_domain.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_remote_edges_bridge_domain.get_name_leafdata())
                if (self.number_remote_edges_xconnect.is_set or self.number_remote_edges_xconnect.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_remote_edges_xconnect.get_name_leafdata())
                if (self.vpls_registered.is_set or self.vpls_registered.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vpls_registered.get_name_leafdata())
                if (self.vpws_registered.is_set or self.vpws_registered.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vpws_registered.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bgp-current-node-id" or name == "bgp-ipc-transport-mode" or name == "bgp-stateon-active-rp" or name == "bgp-stateon-standby-rp" or name == "number-bridge-domainvpns" or name == "number-local-edges-bridge-domain" or name == "number-local-edges-xconnect" or name == "number-mp2m-pxconnect-vpns" or name == "number-nlri-bridge-domain" or name == "number-nlri-xconnect" or name == "number-remote-edges-bridge-domain" or name == "number-remote-edges-xconnect" or name == "vpls-registered" or name == "vpws-registered"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "bgp-current-node-id"):
                    self.bgp_current_node_id = value
                    self.bgp_current_node_id.value_namespace = name_space
                    self.bgp_current_node_id.value_namespace_prefix = name_space_prefix
                if(value_path == "bgp-ipc-transport-mode"):
                    self.bgp_ipc_transport_mode = value
                    self.bgp_ipc_transport_mode.value_namespace = name_space
                    self.bgp_ipc_transport_mode.value_namespace_prefix = name_space_prefix
                if(value_path == "bgp-stateon-active-rp"):
                    self.bgp_stateon_active_rp = value
                    self.bgp_stateon_active_rp.value_namespace = name_space
                    self.bgp_stateon_active_rp.value_namespace_prefix = name_space_prefix
                if(value_path == "bgp-stateon-standby-rp"):
                    self.bgp_stateon_standby_rp = value
                    self.bgp_stateon_standby_rp.value_namespace = name_space
                    self.bgp_stateon_standby_rp.value_namespace_prefix = name_space_prefix
                if(value_path == "number-bridge-domainvpns"):
                    self.number_bridge_domainvpns = value
                    self.number_bridge_domainvpns.value_namespace = name_space
                    self.number_bridge_domainvpns.value_namespace_prefix = name_space_prefix
                if(value_path == "number-local-edges-bridge-domain"):
                    self.number_local_edges_bridge_domain = value
                    self.number_local_edges_bridge_domain.value_namespace = name_space
                    self.number_local_edges_bridge_domain.value_namespace_prefix = name_space_prefix
                if(value_path == "number-local-edges-xconnect"):
                    self.number_local_edges_xconnect = value
                    self.number_local_edges_xconnect.value_namespace = name_space
                    self.number_local_edges_xconnect.value_namespace_prefix = name_space_prefix
                if(value_path == "number-mp2m-pxconnect-vpns"):
                    self.number_mp2m_pxconnect_vpns = value
                    self.number_mp2m_pxconnect_vpns.value_namespace = name_space
                    self.number_mp2m_pxconnect_vpns.value_namespace_prefix = name_space_prefix
                if(value_path == "number-nlri-bridge-domain"):
                    self.number_nlri_bridge_domain = value
                    self.number_nlri_bridge_domain.value_namespace = name_space
                    self.number_nlri_bridge_domain.value_namespace_prefix = name_space_prefix
                if(value_path == "number-nlri-xconnect"):
                    self.number_nlri_xconnect = value
                    self.number_nlri_xconnect.value_namespace = name_space
                    self.number_nlri_xconnect.value_namespace_prefix = name_space_prefix
                if(value_path == "number-remote-edges-bridge-domain"):
                    self.number_remote_edges_bridge_domain = value
                    self.number_remote_edges_bridge_domain.value_namespace = name_space
                    self.number_remote_edges_bridge_domain.value_namespace_prefix = name_space_prefix
                if(value_path == "number-remote-edges-xconnect"):
                    self.number_remote_edges_xconnect = value
                    self.number_remote_edges_xconnect.value_namespace = name_space
                    self.number_remote_edges_xconnect.value_namespace_prefix = name_space_prefix
                if(value_path == "vpls-registered"):
                    self.vpls_registered = value
                    self.vpls_registered.value_namespace = name_space
                    self.vpls_registered.value_namespace_prefix = name_space_prefix
                if(value_path == "vpws-registered"):
                    self.vpws_registered = value
                    self.vpws_registered.value_namespace = name_space
                    self.vpws_registered.value_namespace_prefix = name_space_prefix


        class G8032(Entity):
            """
            G8032 information
            
            .. attribute:: g8032_rings
            
            	G8032 Ring table
            	**type**\:   :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.G8032, self).__init__()

                self.yang_name = "g8032"
                self.yang_parent_name = "active"

                self.g8032_rings = L2Vpnv2.Active.G8032.G8032Rings()
                self.g8032_rings.parent = self
                self._children_name_map["g8032_rings"] = "g8032-rings"
                self._children_yang_names.add("g8032-rings")


            class G8032Rings(Entity):
                """
                G8032 Ring table
                
                .. attribute:: g8032_ring
                
                	G8032 Ring
                	**type**\: list of    :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.G8032.G8032Rings, self).__init__()

                    self.yang_name = "g8032-rings"
                    self.yang_parent_name = "g8032"

                    self.g8032_ring = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.G8032.G8032Rings, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.G8032.G8032Rings, self).__setattr__(name, value)


                class G8032Ring(Entity):
                    """
                    G8032 Ring
                    
                    .. attribute:: ring_name  <key>
                    
                    	Ring Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: g8032_ring_detail
                    
                    	G8032 Ring detailed information
                    	**type**\:   :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                    
                    .. attribute:: g8032_ring_instance_details
                    
                    	G8032 Ring Instance detail table
                    	**type**\:   :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                    
                    .. attribute:: g8032_ring_instance_summaries
                    
                    	G8032 Ring Instance summary table
                    	**type**\:   :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                    
                    .. attribute:: g8032_ring_summary
                    
                    	G8032 Ring summary information
                    	**type**\:   :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring, self).__init__()

                        self.yang_name = "g8032-ring"
                        self.yang_parent_name = "g8032-rings"

                        self.ring_name = YLeaf(YType.str, "ring-name")

                        self.g8032_ring_detail = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                        self.g8032_ring_detail.parent = self
                        self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"
                        self._children_yang_names.add("g8032-ring-detail")

                        self.g8032_ring_instance_details = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                        self.g8032_ring_instance_details.parent = self
                        self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                        self._children_yang_names.add("g8032-ring-instance-details")

                        self.g8032_ring_instance_summaries = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                        self.g8032_ring_instance_summaries.parent = self
                        self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"
                        self._children_yang_names.add("g8032-ring-instance-summaries")

                        self.g8032_ring_summary = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                        self.g8032_ring_summary.parent = self
                        self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"
                        self._children_yang_names.add("g8032-ring-summary")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ring_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring, self).__setattr__(name, value)


                    class G8032RingDetail(Entity):
                        """
                        G8032 Ring detailed information
                        
                        .. attribute:: excluded_vlan_id
                        
                        	Exclusion Vlan ids list 
                        	**type**\:  list of int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: is_open_ring
                        
                        	Flag open ring
                        	**type**\:  bool
                        
                        .. attribute:: is_provider_bridge
                        
                        	Operating mode Customer/Provider 
                        	**type**\:  bool
                        
                        .. attribute:: monitor0
                        
                        	Monitor port 0
                        	**type**\:  str
                        
                        .. attribute:: monitor1
                        
                        	Monitor port 1
                        	**type**\:  str
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\:  str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\:  str
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\:  str
                        
                        .. attribute:: tcn_propagation
                        
                        	Global TCN propagation
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__init__()

                            self.yang_name = "g8032-ring-detail"
                            self.yang_parent_name = "g8032-ring"

                            self.excluded_vlan_id = YLeafList(YType.uint16, "excluded-vlan-id")

                            self.is_open_ring = YLeaf(YType.boolean, "is-open-ring")

                            self.is_provider_bridge = YLeaf(YType.boolean, "is-provider-bridge")

                            self.monitor0 = YLeaf(YType.str, "monitor0")

                            self.monitor1 = YLeaf(YType.str, "monitor1")

                            self.port0 = YLeaf(YType.str, "port0")

                            self.port1 = YLeaf(YType.str, "port1")

                            self.ring_name = YLeaf(YType.str, "ring-name")

                            self.tcn_propagation = YLeaf(YType.boolean, "tcn-propagation")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("excluded_vlan_id",
                                            "is_open_ring",
                                            "is_provider_bridge",
                                            "monitor0",
                                            "monitor1",
                                            "port0",
                                            "port1",
                                            "ring_name",
                                            "tcn_propagation") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.excluded_vlan_id.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.is_open_ring.is_set or
                                self.is_provider_bridge.is_set or
                                self.monitor0.is_set or
                                self.monitor1.is_set or
                                self.port0.is_set or
                                self.port1.is_set or
                                self.ring_name.is_set or
                                self.tcn_propagation.is_set)

                        def has_operation(self):
                            for leaf in self.excluded_vlan_id.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.excluded_vlan_id.yfilter != YFilter.not_set or
                                self.is_open_ring.yfilter != YFilter.not_set or
                                self.is_provider_bridge.yfilter != YFilter.not_set or
                                self.monitor0.yfilter != YFilter.not_set or
                                self.monitor1.yfilter != YFilter.not_set or
                                self.port0.yfilter != YFilter.not_set or
                                self.port1.yfilter != YFilter.not_set or
                                self.ring_name.yfilter != YFilter.not_set or
                                self.tcn_propagation.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring-detail" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_open_ring.is_set or self.is_open_ring.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_open_ring.get_name_leafdata())
                            if (self.is_provider_bridge.is_set or self.is_provider_bridge.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_provider_bridge.get_name_leafdata())
                            if (self.monitor0.is_set or self.monitor0.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.monitor0.get_name_leafdata())
                            if (self.monitor1.is_set or self.monitor1.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.monitor1.get_name_leafdata())
                            if (self.port0.is_set or self.port0.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port0.get_name_leafdata())
                            if (self.port1.is_set or self.port1.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port1.get_name_leafdata())
                            if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ring_name.get_name_leafdata())
                            if (self.tcn_propagation.is_set or self.tcn_propagation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tcn_propagation.get_name_leafdata())

                            leaf_name_data.extend(self.excluded_vlan_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "excluded-vlan-id" or name == "is-open-ring" or name == "is-provider-bridge" or name == "monitor0" or name == "monitor1" or name == "port0" or name == "port1" or name == "ring-name" or name == "tcn-propagation"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "excluded-vlan-id"):
                                self.excluded_vlan_id.append(value)
                            if(value_path == "is-open-ring"):
                                self.is_open_ring = value
                                self.is_open_ring.value_namespace = name_space
                                self.is_open_ring.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-provider-bridge"):
                                self.is_provider_bridge = value
                                self.is_provider_bridge.value_namespace = name_space
                                self.is_provider_bridge.value_namespace_prefix = name_space_prefix
                            if(value_path == "monitor0"):
                                self.monitor0 = value
                                self.monitor0.value_namespace = name_space
                                self.monitor0.value_namespace_prefix = name_space_prefix
                            if(value_path == "monitor1"):
                                self.monitor1 = value
                                self.monitor1.value_namespace = name_space
                                self.monitor1.value_namespace_prefix = name_space_prefix
                            if(value_path == "port0"):
                                self.port0 = value
                                self.port0.value_namespace = name_space
                                self.port0.value_namespace_prefix = name_space_prefix
                            if(value_path == "port1"):
                                self.port1 = value
                                self.port1.value_namespace = name_space
                                self.port1.value_namespace_prefix = name_space_prefix
                            if(value_path == "ring-name"):
                                self.ring_name = value
                                self.ring_name.value_namespace = name_space
                                self.ring_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tcn-propagation"):
                                self.tcn_propagation = value
                                self.tcn_propagation.value_namespace = name_space
                                self.tcn_propagation.value_namespace_prefix = name_space_prefix


                    class G8032RingInstanceSummaries(Entity):
                        """
                        G8032 Ring Instance summary table
                        
                        .. attribute:: g8032_ring_instance_summary
                        
                        	G8032 Ring Instance summary information
                        	**type**\: list of    :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__init__()

                            self.yang_name = "g8032-ring-instance-summaries"
                            self.yang_parent_name = "g8032-ring"

                            self.g8032_ring_instance_summary = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__setattr__(name, value)


                        class G8032RingInstanceSummary(Entity):
                            """
                            G8032 Ring Instance summary information
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\:  bool
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\:  list of int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__init__()

                                self.yang_name = "g8032-ring-instance-summary"
                                self.yang_parent_name = "g8032-ring-instance-summaries"

                                self.instance = YLeaf(YType.int32, "instance")

                                self.aps_port0 = YLeaf(YType.str, "aps-port0")

                                self.aps_port1 = YLeaf(YType.str, "aps-port1")

                                self.config_state = YLeaf(YType.boolean, "config-state")

                                self.included_vlan_id = YLeafList(YType.uint16, "included-vlan-id")

                                self.ring_instance = YLeaf(YType.uint32, "ring-instance")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("instance",
                                                "aps_port0",
                                                "aps_port1",
                                                "config_state",
                                                "included_vlan_id",
                                                "ring_instance") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.included_vlan_id.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.instance.is_set or
                                    self.aps_port0.is_set or
                                    self.aps_port1.is_set or
                                    self.config_state.is_set or
                                    self.ring_instance.is_set)

                            def has_operation(self):
                                for leaf in self.included_vlan_id.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.instance.yfilter != YFilter.not_set or
                                    self.aps_port0.yfilter != YFilter.not_set or
                                    self.aps_port1.yfilter != YFilter.not_set or
                                    self.config_state.yfilter != YFilter.not_set or
                                    self.included_vlan_id.yfilter != YFilter.not_set or
                                    self.ring_instance.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g8032-ring-instance-summary" + "[instance='" + self.instance.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                if (self.aps_port0.is_set or self.aps_port0.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aps_port0.get_name_leafdata())
                                if (self.aps_port1.is_set or self.aps_port1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aps_port1.get_name_leafdata())
                                if (self.config_state.is_set or self.config_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.config_state.get_name_leafdata())
                                if (self.ring_instance.is_set or self.ring_instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_instance.get_name_leafdata())

                                leaf_name_data.extend(self.included_vlan_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "instance" or name == "aps-port0" or name == "aps-port1" or name == "config-state" or name == "included-vlan-id" or name == "ring-instance"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "instance"):
                                    self.instance = value
                                    self.instance.value_namespace = name_space
                                    self.instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "aps-port0"):
                                    self.aps_port0 = value
                                    self.aps_port0.value_namespace = name_space
                                    self.aps_port0.value_namespace_prefix = name_space_prefix
                                if(value_path == "aps-port1"):
                                    self.aps_port1 = value
                                    self.aps_port1.value_namespace = name_space
                                    self.aps_port1.value_namespace_prefix = name_space_prefix
                                if(value_path == "config-state"):
                                    self.config_state = value
                                    self.config_state.value_namespace = name_space
                                    self.config_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "included-vlan-id"):
                                    self.included_vlan_id.append(value)
                                if(value_path == "ring-instance"):
                                    self.ring_instance = value
                                    self.ring_instance.value_namespace = name_space
                                    self.ring_instance.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.g8032_ring_instance_summary:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.g8032_ring_instance_summary:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring-instance-summaries" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "g8032-ring-instance-summary"):
                                for c in self.g8032_ring_instance_summary:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.g8032_ring_instance_summary.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "g8032-ring-instance-summary"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class G8032RingSummary(Entity):
                        """
                        G8032 Ring summary information
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\:  str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\:  str
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__init__()

                            self.yang_name = "g8032-ring-summary"
                            self.yang_parent_name = "g8032-ring"

                            self.port0 = YLeaf(YType.str, "port0")

                            self.port1 = YLeaf(YType.str, "port1")

                            self.ring_name = YLeaf(YType.str, "ring-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("port0",
                                            "port1",
                                            "ring_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.port0.is_set or
                                self.port1.is_set or
                                self.ring_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.port0.yfilter != YFilter.not_set or
                                self.port1.yfilter != YFilter.not_set or
                                self.ring_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring-summary" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.port0.is_set or self.port0.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port0.get_name_leafdata())
                            if (self.port1.is_set or self.port1.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port1.get_name_leafdata())
                            if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ring_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "port0" or name == "port1" or name == "ring-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "port0"):
                                self.port0 = value
                                self.port0.value_namespace = name_space
                                self.port0.value_namespace_prefix = name_space_prefix
                            if(value_path == "port1"):
                                self.port1 = value
                                self.port1.value_namespace = name_space
                                self.port1.value_namespace_prefix = name_space_prefix
                            if(value_path == "ring-name"):
                                self.ring_name = value
                                self.ring_name.value_namespace = name_space
                                self.ring_name.value_namespace_prefix = name_space_prefix


                    class G8032RingInstanceDetails(Entity):
                        """
                        G8032 Ring Instance detail table
                        
                        .. attribute:: g8032_ring_instance_detail
                        
                        	G8032 Ring Instance detailed information
                        	**type**\: list of    :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__init__()

                            self.yang_name = "g8032-ring-instance-details"
                            self.yang_parent_name = "g8032-ring"

                            self.g8032_ring_instance_detail = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__setattr__(name, value)


                        class G8032RingInstanceDetail(Entity):
                            """
                            G8032 Ring Instance detailed information
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: aps_channel_level
                            
                            	APS channel level
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\:  bool
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\:  list of int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ring_description
                            
                            	Ring description
                            	**type**\:  str
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ring_profile
                            
                            	Ring Profile
                            	**type**\:  str
                            
                            .. attribute:: rpl
                            
                            	RPL
                            	**type**\:   :py:class:`L2VpnG8032Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032Rpl>`
                            
                            .. attribute:: unresolved_reason
                            
                            	Reason of unresolved state state
                            	**type**\:   :py:class:`L2VpnG8032UncfgReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032UncfgReason>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__init__()

                                self.yang_name = "g8032-ring-instance-detail"
                                self.yang_parent_name = "g8032-ring-instance-details"

                                self.instance = YLeaf(YType.int32, "instance")

                                self.aps_channel_level = YLeaf(YType.uint32, "aps-channel-level")

                                self.aps_port0 = YLeaf(YType.str, "aps-port0")

                                self.aps_port1 = YLeaf(YType.str, "aps-port1")

                                self.config_state = YLeaf(YType.boolean, "config-state")

                                self.included_vlan_id = YLeafList(YType.uint16, "included-vlan-id")

                                self.ring_description = YLeaf(YType.str, "ring-description")

                                self.ring_instance = YLeaf(YType.uint32, "ring-instance")

                                self.ring_profile = YLeaf(YType.str, "ring-profile")

                                self.rpl = YLeaf(YType.enumeration, "rpl")

                                self.unresolved_reason = YLeaf(YType.enumeration, "unresolved-reason")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("instance",
                                                "aps_channel_level",
                                                "aps_port0",
                                                "aps_port1",
                                                "config_state",
                                                "included_vlan_id",
                                                "ring_description",
                                                "ring_instance",
                                                "ring_profile",
                                                "rpl",
                                                "unresolved_reason") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.included_vlan_id.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.instance.is_set or
                                    self.aps_channel_level.is_set or
                                    self.aps_port0.is_set or
                                    self.aps_port1.is_set or
                                    self.config_state.is_set or
                                    self.ring_description.is_set or
                                    self.ring_instance.is_set or
                                    self.ring_profile.is_set or
                                    self.rpl.is_set or
                                    self.unresolved_reason.is_set)

                            def has_operation(self):
                                for leaf in self.included_vlan_id.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.instance.yfilter != YFilter.not_set or
                                    self.aps_channel_level.yfilter != YFilter.not_set or
                                    self.aps_port0.yfilter != YFilter.not_set or
                                    self.aps_port1.yfilter != YFilter.not_set or
                                    self.config_state.yfilter != YFilter.not_set or
                                    self.included_vlan_id.yfilter != YFilter.not_set or
                                    self.ring_description.yfilter != YFilter.not_set or
                                    self.ring_instance.yfilter != YFilter.not_set or
                                    self.ring_profile.yfilter != YFilter.not_set or
                                    self.rpl.yfilter != YFilter.not_set or
                                    self.unresolved_reason.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g8032-ring-instance-detail" + "[instance='" + self.instance.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance.get_name_leafdata())
                                if (self.aps_channel_level.is_set or self.aps_channel_level.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aps_channel_level.get_name_leafdata())
                                if (self.aps_port0.is_set or self.aps_port0.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aps_port0.get_name_leafdata())
                                if (self.aps_port1.is_set or self.aps_port1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aps_port1.get_name_leafdata())
                                if (self.config_state.is_set or self.config_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.config_state.get_name_leafdata())
                                if (self.ring_description.is_set or self.ring_description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_description.get_name_leafdata())
                                if (self.ring_instance.is_set or self.ring_instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_instance.get_name_leafdata())
                                if (self.ring_profile.is_set or self.ring_profile.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_profile.get_name_leafdata())
                                if (self.rpl.is_set or self.rpl.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rpl.get_name_leafdata())
                                if (self.unresolved_reason.is_set or self.unresolved_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unresolved_reason.get_name_leafdata())

                                leaf_name_data.extend(self.included_vlan_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "instance" or name == "aps-channel-level" or name == "aps-port0" or name == "aps-port1" or name == "config-state" or name == "included-vlan-id" or name == "ring-description" or name == "ring-instance" or name == "ring-profile" or name == "rpl" or name == "unresolved-reason"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "instance"):
                                    self.instance = value
                                    self.instance.value_namespace = name_space
                                    self.instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "aps-channel-level"):
                                    self.aps_channel_level = value
                                    self.aps_channel_level.value_namespace = name_space
                                    self.aps_channel_level.value_namespace_prefix = name_space_prefix
                                if(value_path == "aps-port0"):
                                    self.aps_port0 = value
                                    self.aps_port0.value_namespace = name_space
                                    self.aps_port0.value_namespace_prefix = name_space_prefix
                                if(value_path == "aps-port1"):
                                    self.aps_port1 = value
                                    self.aps_port1.value_namespace = name_space
                                    self.aps_port1.value_namespace_prefix = name_space_prefix
                                if(value_path == "config-state"):
                                    self.config_state = value
                                    self.config_state.value_namespace = name_space
                                    self.config_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "included-vlan-id"):
                                    self.included_vlan_id.append(value)
                                if(value_path == "ring-description"):
                                    self.ring_description = value
                                    self.ring_description.value_namespace = name_space
                                    self.ring_description.value_namespace_prefix = name_space_prefix
                                if(value_path == "ring-instance"):
                                    self.ring_instance = value
                                    self.ring_instance.value_namespace = name_space
                                    self.ring_instance.value_namespace_prefix = name_space_prefix
                                if(value_path == "ring-profile"):
                                    self.ring_profile = value
                                    self.ring_profile.value_namespace = name_space
                                    self.ring_profile.value_namespace_prefix = name_space_prefix
                                if(value_path == "rpl"):
                                    self.rpl = value
                                    self.rpl.value_namespace = name_space
                                    self.rpl.value_namespace_prefix = name_space_prefix
                                if(value_path == "unresolved-reason"):
                                    self.unresolved_reason = value
                                    self.unresolved_reason.value_namespace = name_space
                                    self.unresolved_reason.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.g8032_ring_instance_detail:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.g8032_ring_instance_detail:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring-instance-details" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "g8032-ring-instance-detail"):
                                for c in self.g8032_ring_instance_detail:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.g8032_ring_instance_detail.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "g8032-ring-instance-detail"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.ring_name.is_set or
                            (self.g8032_ring_detail is not None and self.g8032_ring_detail.has_data()) or
                            (self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details.has_data()) or
                            (self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries.has_data()) or
                            (self.g8032_ring_summary is not None and self.g8032_ring_summary.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ring_name.yfilter != YFilter.not_set or
                            (self.g8032_ring_detail is not None and self.g8032_ring_detail.has_operation()) or
                            (self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details.has_operation()) or
                            (self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries.has_operation()) or
                            (self.g8032_ring_summary is not None and self.g8032_ring_summary.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g8032-ring" + "[ring-name='" + self.ring_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/g8032/g8032-rings/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ring_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "g8032-ring-detail"):
                            if (self.g8032_ring_detail is None):
                                self.g8032_ring_detail = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                                self.g8032_ring_detail.parent = self
                                self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"
                            return self.g8032_ring_detail

                        if (child_yang_name == "g8032-ring-instance-details"):
                            if (self.g8032_ring_instance_details is None):
                                self.g8032_ring_instance_details = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                                self.g8032_ring_instance_details.parent = self
                                self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                            return self.g8032_ring_instance_details

                        if (child_yang_name == "g8032-ring-instance-summaries"):
                            if (self.g8032_ring_instance_summaries is None):
                                self.g8032_ring_instance_summaries = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                                self.g8032_ring_instance_summaries.parent = self
                                self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"
                            return self.g8032_ring_instance_summaries

                        if (child_yang_name == "g8032-ring-summary"):
                            if (self.g8032_ring_summary is None):
                                self.g8032_ring_summary = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                                self.g8032_ring_summary.parent = self
                                self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"
                            return self.g8032_ring_summary

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "g8032-ring-detail" or name == "g8032-ring-instance-details" or name == "g8032-ring-instance-summaries" or name == "g8032-ring-summary" or name == "ring-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ring-name"):
                            self.ring_name = value
                            self.ring_name.value_namespace = name_space
                            self.ring_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.g8032_ring:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.g8032_ring:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "g8032-rings" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/g8032/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g8032-ring"):
                        for c in self.g8032_ring:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.g8032_ring.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g8032-ring"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.g8032_rings is not None and self.g8032_rings.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.g8032_rings is not None and self.g8032_rings.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "g8032" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "g8032-rings"):
                    if (self.g8032_rings is None):
                        self.g8032_rings = L2Vpnv2.Active.G8032.G8032Rings()
                        self.g8032_rings.parent = self
                        self._children_name_map["g8032_rings"] = "g8032-rings"
                    return self.g8032_rings

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "g8032-rings"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class PseudowireClasses(Entity):
            """
            List of pseudowire classes
            
            .. attribute:: pseudowire_class
            
            	Pseudowire class information
            	**type**\: list of    :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses.PseudowireClass>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.PseudowireClasses, self).__init__()

                self.yang_name = "pseudowire-classes"
                self.yang_parent_name = "active"

                self.pseudowire_class = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.PseudowireClasses, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.PseudowireClasses, self).__setattr__(name, value)


            class PseudowireClass(Entity):
                """
                Pseudowire class information
                
                .. attribute:: pseudowire_class_name  <key>
                
                	Pseudowire Class Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: backup_mac_withdraw
                
                	TRUE if MAC withdraw message is sent
                	**type**\:  bool
                
                .. attribute:: control_word
                
                	Control word
                	**type**\:   :py:class:`L2VpnPwClassControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwClassControlWord>`
                
                .. attribute:: disable_delay
                
                	Disable Deley
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: disable_never
                
                	TRUE if backup is not automatically disabled
                	**type**\:  bool
                
                .. attribute:: encapsulation_info
                
                	Encapsulation specific pseudowire information
                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
                
                .. attribute:: is_flow_label_static
                
                	is flow label static
                	**type**\:  bool
                
                .. attribute:: load_balance
                
                	Load Balance Type
                	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                
                .. attribute:: local_source_address
                
                	Local source address
                	**type**\:   :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
                
                .. attribute:: preferred_path
                
                	MPLS Preferred Path
                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath>`
                
                .. attribute:: preferred_path_disable_fallback
                
                	PreferredPathDisableFallback
                	**type**\:  bool
                
                .. attribute:: protocol
                
                	Protocol
                	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                
                .. attribute:: pw_class_name
                
                	Pseudowire class name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: pw_flow_label_code17_disabled
                
                	Disable sending Code 17 TLV
                	**type**\:  bool
                
                .. attribute:: pw_flow_label_type_cfg
                
                	Configured pseudowire flow label type
                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                
                .. attribute:: resync_enabled
                
                	Resync if packets out of sequence
                	**type**\:  bool
                
                .. attribute:: resync_threshold
                
                	Number of Packets Out of Seqence to trigger resync
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sequencing_type
                
                	Sequencing Type
                	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                
                .. attribute:: tag_rewrite
                
                	Static tag rewrite
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: transport_mode
                
                	Transport mode
                	**type**\:   :py:class:`L2VpnTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTransportMode>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass, self).__init__()

                    self.yang_name = "pseudowire-class"
                    self.yang_parent_name = "pseudowire-classes"

                    self.pseudowire_class_name = YLeaf(YType.str, "pseudowire-class-name")

                    self.backup_mac_withdraw = YLeaf(YType.boolean, "backup-mac-withdraw")

                    self.control_word = YLeaf(YType.enumeration, "control-word")

                    self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                    self.disable_never = YLeaf(YType.boolean, "disable-never")

                    self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                    self.load_balance = YLeaf(YType.enumeration, "load-balance")

                    self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                    self.protocol = YLeaf(YType.enumeration, "protocol")

                    self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                    self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                    self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                    self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                    self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                    self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                    self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                    self.transport_mode = YLeaf(YType.enumeration, "transport-mode")

                    self.encapsulation_info = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                    self.encapsulation_info.parent = self
                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                    self._children_yang_names.add("encapsulation-info")

                    self.local_source_address = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                    self.local_source_address.parent = self
                    self._children_name_map["local_source_address"] = "local-source-address"
                    self._children_yang_names.add("local-source-address")

                    self.preferred_path = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath()
                    self.preferred_path.parent = self
                    self._children_name_map["preferred_path"] = "preferred-path"
                    self._children_yang_names.add("preferred-path")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("pseudowire_class_name",
                                    "backup_mac_withdraw",
                                    "control_word",
                                    "disable_delay",
                                    "disable_never",
                                    "is_flow_label_static",
                                    "load_balance",
                                    "preferred_path_disable_fallback",
                                    "protocol",
                                    "pw_class_name",
                                    "pw_flow_label_code17_disabled",
                                    "pw_flow_label_type_cfg",
                                    "resync_enabled",
                                    "resync_threshold",
                                    "sequencing_type",
                                    "tag_rewrite",
                                    "transport_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass, self).__setattr__(name, value)


                class EncapsulationInfo(Entity):
                    """
                    Encapsulation specific pseudowire information
                    
                    .. attribute:: encapsulation
                    
                    	Encapsulation
                    	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                    
                    .. attribute:: l2tpv3
                    
                    	l2tpv3
                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__init__()

                        self.yang_name = "encapsulation-info"
                        self.yang_parent_name = "pseudowire-class"

                        self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                        self.l2tpv3 = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                        self.l2tpv3.parent = self
                        self._children_name_map["l2tpv3"] = "l2tpv3"
                        self._children_yang_names.add("l2tpv3")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("encapsulation") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__setattr__(name, value)


                    class L2Tpv3(Entity):
                        """
                        l2tpv3
                        
                        .. attribute:: cookie_size
                        
                        	Cookie size\: 0, 4, or 8 bytes
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dont_fragment_bit
                        
                        	Don't Fragment Bit
                        	**type**\:  bool
                        
                        .. attribute:: ipv4_source_address
                        
                        	IPv4 source address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: l2tp_class_name
                        
                        	L2TPClassName
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        .. attribute:: path_mtu_enabled
                        
                        	Path MTU enabled
                        	**type**\:  bool
                        
                        .. attribute:: path_mtu_max_value
                        
                        	Path MTU Maximum allowable session MTU
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: tos
                        
                        	Type Of Service Value
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tos_mode
                        
                        	Type Of Service Mode
                        	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                        
                        .. attribute:: ttl
                        
                        	Time To Live value
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__init__()

                            self.yang_name = "l2tpv3"
                            self.yang_parent_name = "encapsulation-info"

                            self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                            self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                            self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                            self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                            self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                            self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                            self.tos = YLeaf(YType.uint8, "tos")

                            self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                            self.ttl = YLeaf(YType.uint8, "ttl")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("cookie_size",
                                            "dont_fragment_bit",
                                            "ipv4_source_address",
                                            "l2tp_class_name",
                                            "path_mtu_enabled",
                                            "path_mtu_max_value",
                                            "tos",
                                            "tos_mode",
                                            "ttl") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.cookie_size.is_set or
                                self.dont_fragment_bit.is_set or
                                self.ipv4_source_address.is_set or
                                self.l2tp_class_name.is_set or
                                self.path_mtu_enabled.is_set or
                                self.path_mtu_max_value.is_set or
                                self.tos.is_set or
                                self.tos_mode.is_set or
                                self.ttl.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.cookie_size.yfilter != YFilter.not_set or
                                self.dont_fragment_bit.yfilter != YFilter.not_set or
                                self.ipv4_source_address.yfilter != YFilter.not_set or
                                self.l2tp_class_name.yfilter != YFilter.not_set or
                                self.path_mtu_enabled.yfilter != YFilter.not_set or
                                self.path_mtu_max_value.yfilter != YFilter.not_set or
                                self.tos.yfilter != YFilter.not_set or
                                self.tos_mode.yfilter != YFilter.not_set or
                                self.ttl.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2tpv3" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cookie_size.get_name_leafdata())
                            if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                            if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                            if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                            if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                            if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                            if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tos.get_name_leafdata())
                            if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tos_mode.get_name_leafdata())
                            if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ttl.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "cookie-size" or name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "l2tp-class-name" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "tos" or name == "tos-mode" or name == "ttl"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "cookie-size"):
                                self.cookie_size = value
                                self.cookie_size.value_namespace = name_space
                                self.cookie_size.value_namespace_prefix = name_space_prefix
                            if(value_path == "dont-fragment-bit"):
                                self.dont_fragment_bit = value
                                self.dont_fragment_bit.value_namespace = name_space
                                self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-source-address"):
                                self.ipv4_source_address = value
                                self.ipv4_source_address.value_namespace = name_space
                                self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "l2tp-class-name"):
                                self.l2tp_class_name = value
                                self.l2tp_class_name.value_namespace = name_space
                                self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-mtu-enabled"):
                                self.path_mtu_enabled = value
                                self.path_mtu_enabled.value_namespace = name_space
                                self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-mtu-max-value"):
                                self.path_mtu_max_value = value
                                self.path_mtu_max_value.value_namespace = name_space
                                self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                            if(value_path == "tos"):
                                self.tos = value
                                self.tos.value_namespace = name_space
                                self.tos.value_namespace_prefix = name_space_prefix
                            if(value_path == "tos-mode"):
                                self.tos_mode = value
                                self.tos_mode.value_namespace = name_space
                                self.tos_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "ttl"):
                                self.ttl = value
                                self.ttl.value_namespace = name_space
                                self.ttl.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.encapsulation.is_set or
                            (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.encapsulation.yfilter != YFilter.not_set or
                            (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "encapsulation-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "l2tpv3"):
                            if (self.l2tpv3 is None):
                                self.l2tpv3 = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                            return self.l2tpv3

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "l2tpv3" or name == "encapsulation"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "encapsulation"):
                            self.encapsulation = value
                            self.encapsulation.value_namespace = name_space
                            self.encapsulation.value_namespace_prefix = name_space_prefix


                class PreferredPath(Entity):
                    """
                    MPLS Preferred Path
                    
                    .. attribute:: ip_tunnel_interface_number
                    
                    	IPTunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: next_hop_ip
                    
                    	NextHopIP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: option
                    
                    	Option
                    	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                    
                    .. attribute:: te_tunnel_interface_number
                    
                    	TETunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tp_tunnel_interface_number
                    
                    	TPTunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath, self).__init__()

                        self.yang_name = "preferred-path"
                        self.yang_parent_name = "pseudowire-class"

                        self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                        self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                        self.option = YLeaf(YType.enumeration, "option")

                        self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                        self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ip_tunnel_interface_number",
                                        "next_hop_ip",
                                        "option",
                                        "te_tunnel_interface_number",
                                        "tp_tunnel_interface_number") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ip_tunnel_interface_number.is_set or
                            self.next_hop_ip.is_set or
                            self.option.is_set or
                            self.te_tunnel_interface_number.is_set or
                            self.tp_tunnel_interface_number.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                            self.next_hop_ip.yfilter != YFilter.not_set or
                            self.option.yfilter != YFilter.not_set or
                            self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                            self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "preferred-path" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                        if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.option.get_name_leafdata())
                        if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                        if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ip-tunnel-interface-number"):
                            self.ip_tunnel_interface_number = value
                            self.ip_tunnel_interface_number.value_namespace = name_space
                            self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "next-hop-ip"):
                            self.next_hop_ip = value
                            self.next_hop_ip.value_namespace = name_space
                            self.next_hop_ip.value_namespace_prefix = name_space_prefix
                        if(value_path == "option"):
                            self.option = value
                            self.option.value_namespace = name_space
                            self.option.value_namespace_prefix = name_space_prefix
                        if(value_path == "te-tunnel-interface-number"):
                            self.te_tunnel_interface_number = value
                            self.te_tunnel_interface_number.value_namespace = name_space
                            self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "tp-tunnel-interface-number"):
                            self.tp_tunnel_interface_number = value
                            self.tp_tunnel_interface_number.value_namespace = name_space
                            self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                class LocalSourceAddress(Entity):
                    """
                    Local source address
                    
                    .. attribute:: address
                    
                    	Local source address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: configuration
                    
                    	Configuration
                    	**type**\:   :py:class:`L2VpnSrcAddressSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSrcAddressSet>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__init__()

                        self.yang_name = "local-source-address"
                        self.yang_parent_name = "pseudowire-class"

                        self.address = YLeaf(YType.str, "address")

                        self.configuration = YLeaf(YType.enumeration, "configuration")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "configuration") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.configuration.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.configuration.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "local-source-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.configuration.is_set or self.configuration.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "configuration"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration"):
                            self.configuration = value
                            self.configuration.value_namespace = name_space
                            self.configuration.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.pseudowire_class_name.is_set or
                        self.backup_mac_withdraw.is_set or
                        self.control_word.is_set or
                        self.disable_delay.is_set or
                        self.disable_never.is_set or
                        self.is_flow_label_static.is_set or
                        self.load_balance.is_set or
                        self.preferred_path_disable_fallback.is_set or
                        self.protocol.is_set or
                        self.pw_class_name.is_set or
                        self.pw_flow_label_code17_disabled.is_set or
                        self.pw_flow_label_type_cfg.is_set or
                        self.resync_enabled.is_set or
                        self.resync_threshold.is_set or
                        self.sequencing_type.is_set or
                        self.tag_rewrite.is_set or
                        self.transport_mode.is_set or
                        (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                        (self.local_source_address is not None and self.local_source_address.has_data()) or
                        (self.preferred_path is not None and self.preferred_path.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.pseudowire_class_name.yfilter != YFilter.not_set or
                        self.backup_mac_withdraw.yfilter != YFilter.not_set or
                        self.control_word.yfilter != YFilter.not_set or
                        self.disable_delay.yfilter != YFilter.not_set or
                        self.disable_never.yfilter != YFilter.not_set or
                        self.is_flow_label_static.yfilter != YFilter.not_set or
                        self.load_balance.yfilter != YFilter.not_set or
                        self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                        self.protocol.yfilter != YFilter.not_set or
                        self.pw_class_name.yfilter != YFilter.not_set or
                        self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                        self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                        self.resync_enabled.yfilter != YFilter.not_set or
                        self.resync_threshold.yfilter != YFilter.not_set or
                        self.sequencing_type.yfilter != YFilter.not_set or
                        self.tag_rewrite.yfilter != YFilter.not_set or
                        self.transport_mode.yfilter != YFilter.not_set or
                        (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                        (self.local_source_address is not None and self.local_source_address.has_operation()) or
                        (self.preferred_path is not None and self.preferred_path.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pseudowire-class" + "[pseudowire-class-name='" + self.pseudowire_class_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pseudowire-classes/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.pseudowire_class_name.is_set or self.pseudowire_class_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pseudowire_class_name.get_name_leafdata())
                    if (self.backup_mac_withdraw.is_set or self.backup_mac_withdraw.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.backup_mac_withdraw.get_name_leafdata())
                    if (self.control_word.is_set or self.control_word.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.control_word.get_name_leafdata())
                    if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disable_delay.get_name_leafdata())
                    if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disable_never.get_name_leafdata())
                    if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                    if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.load_balance.get_name_leafdata())
                    if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.protocol.get_name_leafdata())
                    if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                    if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                    if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                    if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                    if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                    if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                    if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                    if (self.transport_mode.is_set or self.transport_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.transport_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "encapsulation-info"):
                        if (self.encapsulation_info is None):
                            self.encapsulation_info = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                        return self.encapsulation_info

                    if (child_yang_name == "local-source-address"):
                        if (self.local_source_address is None):
                            self.local_source_address = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                            self.local_source_address.parent = self
                            self._children_name_map["local_source_address"] = "local-source-address"
                        return self.local_source_address

                    if (child_yang_name == "preferred-path"):
                        if (self.preferred_path is None):
                            self.preferred_path = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                        return self.preferred_path

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "encapsulation-info" or name == "local-source-address" or name == "preferred-path" or name == "pseudowire-class-name" or name == "backup-mac-withdraw" or name == "control-word" or name == "disable-delay" or name == "disable-never" or name == "is-flow-label-static" or name == "load-balance" or name == "preferred-path-disable-fallback" or name == "protocol" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type-cfg" or name == "resync-enabled" or name == "resync-threshold" or name == "sequencing-type" or name == "tag-rewrite" or name == "transport-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "pseudowire-class-name"):
                        self.pseudowire_class_name = value
                        self.pseudowire_class_name.value_namespace = name_space
                        self.pseudowire_class_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "backup-mac-withdraw"):
                        self.backup_mac_withdraw = value
                        self.backup_mac_withdraw.value_namespace = name_space
                        self.backup_mac_withdraw.value_namespace_prefix = name_space_prefix
                    if(value_path == "control-word"):
                        self.control_word = value
                        self.control_word.value_namespace = name_space
                        self.control_word.value_namespace_prefix = name_space_prefix
                    if(value_path == "disable-delay"):
                        self.disable_delay = value
                        self.disable_delay.value_namespace = name_space
                        self.disable_delay.value_namespace_prefix = name_space_prefix
                    if(value_path == "disable-never"):
                        self.disable_never = value
                        self.disable_never.value_namespace = name_space
                        self.disable_never.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-flow-label-static"):
                        self.is_flow_label_static = value
                        self.is_flow_label_static.value_namespace = name_space
                        self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                    if(value_path == "load-balance"):
                        self.load_balance = value
                        self.load_balance.value_namespace = name_space
                        self.load_balance.value_namespace_prefix = name_space_prefix
                    if(value_path == "preferred-path-disable-fallback"):
                        self.preferred_path_disable_fallback = value
                        self.preferred_path_disable_fallback.value_namespace = name_space
                        self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                    if(value_path == "protocol"):
                        self.protocol = value
                        self.protocol.value_namespace = name_space
                        self.protocol.value_namespace_prefix = name_space_prefix
                    if(value_path == "pw-class-name"):
                        self.pw_class_name = value
                        self.pw_class_name.value_namespace = name_space
                        self.pw_class_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "pw-flow-label-code17-disabled"):
                        self.pw_flow_label_code17_disabled = value
                        self.pw_flow_label_code17_disabled.value_namespace = name_space
                        self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "pw-flow-label-type-cfg"):
                        self.pw_flow_label_type_cfg = value
                        self.pw_flow_label_type_cfg.value_namespace = name_space
                        self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                    if(value_path == "resync-enabled"):
                        self.resync_enabled = value
                        self.resync_enabled.value_namespace = name_space
                        self.resync_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "resync-threshold"):
                        self.resync_threshold = value
                        self.resync_threshold.value_namespace = name_space
                        self.resync_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "sequencing-type"):
                        self.sequencing_type = value
                        self.sequencing_type.value_namespace = name_space
                        self.sequencing_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "tag-rewrite"):
                        self.tag_rewrite = value
                        self.tag_rewrite.value_namespace = name_space
                        self.tag_rewrite.value_namespace_prefix = name_space_prefix
                    if(value_path == "transport-mode"):
                        self.transport_mode = value
                        self.transport_mode.value_namespace = name_space
                        self.transport_mode.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.pseudowire_class:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.pseudowire_class:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "pseudowire-classes" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "pseudowire-class"):
                    for c in self.pseudowire_class:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.PseudowireClasses.PseudowireClass()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.pseudowire_class.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "pseudowire-class"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class L2VpnCollaborators(Entity):
            """
            L2VPN collaborator information
            
            .. attribute:: collaborator_statistics
            
            	Collaborator Statistics
            	**type**\:   :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.L2VpnCollaborators, self).__init__()

                self.yang_name = "l2vpn-collaborators"
                self.yang_parent_name = "active"

                self.collaborator_statistics = L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics()
                self.collaborator_statistics.parent = self
                self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
                self._children_yang_names.add("collaborator-statistics")


            class CollaboratorStatistics(Entity):
                """
                Collaborator Statistics
                
                .. attribute:: count
                
                	count
                	**type**\: list of    :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics.Count>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics, self).__init__()

                    self.yang_name = "collaborator-statistics"
                    self.yang_parent_name = "l2vpn-collaborators"

                    self.count = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics, self).__setattr__(name, value)


                class Count(Entity):
                    """
                    count
                    
                    .. attribute:: collaborator_name
                    
                    	Collaborator Name
                    	**type**\:  str
                    
                    .. attribute:: down
                    
                    	Down
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_up
                    
                    	Is up
                    	**type**\:  bool
                    
                    .. attribute:: up
                    
                    	Up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics.Count, self).__init__()

                        self.yang_name = "count"
                        self.yang_parent_name = "collaborator-statistics"

                        self.collaborator_name = YLeaf(YType.str, "collaborator-name")

                        self.down = YLeaf(YType.uint32, "down")

                        self.is_up = YLeaf(YType.boolean, "is-up")

                        self.up = YLeaf(YType.uint32, "up")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("collaborator_name",
                                        "down",
                                        "is_up",
                                        "up") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics.Count, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics.Count, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.collaborator_name.is_set or
                            self.down.is_set or
                            self.is_up.is_set or
                            self.up.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.collaborator_name.yfilter != YFilter.not_set or
                            self.down.yfilter != YFilter.not_set or
                            self.is_up.yfilter != YFilter.not_set or
                            self.up.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "count" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/l2vpn-collaborators/collaborator-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.collaborator_name.is_set or self.collaborator_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.collaborator_name.get_name_leafdata())
                        if (self.down.is_set or self.down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.down.get_name_leafdata())
                        if (self.is_up.is_set or self.is_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_up.get_name_leafdata())
                        if (self.up.is_set or self.up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.up.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "collaborator-name" or name == "down" or name == "is-up" or name == "up"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "collaborator-name"):
                            self.collaborator_name = value
                            self.collaborator_name.value_namespace = name_space
                            self.collaborator_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "down"):
                            self.down = value
                            self.down.value_namespace = name_space
                            self.down.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-up"):
                            self.is_up = value
                            self.is_up.value_namespace = name_space
                            self.is_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "up"):
                            self.up = value
                            self.up.value_namespace = name_space
                            self.up.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.count:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.count:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "collaborator-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/l2vpn-collaborators/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "count"):
                        for c in self.count:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics.Count()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.count.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.collaborator_statistics is not None and self.collaborator_statistics.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.collaborator_statistics is not None and self.collaborator_statistics.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "l2vpn-collaborators" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "collaborator-statistics"):
                    if (self.collaborator_statistics is None):
                        self.collaborator_statistics = L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics()
                        self.collaborator_statistics.parent = self
                        self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
                    return self.collaborator_statistics

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "collaborator-statistics"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Mvrp(Entity):
            """
            MVRP
            
            .. attribute:: mvrp_main_ports
            
            	MVRP Main Port Table
            	**type**\:   :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.Mvrp, self).__init__()

                self.yang_name = "mvrp"
                self.yang_parent_name = "active"

                self.mvrp_main_ports = L2Vpnv2.Active.Mvrp.MvrpMainPorts()
                self.mvrp_main_ports.parent = self
                self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
                self._children_yang_names.add("mvrp-main-ports")


            class MvrpMainPorts(Entity):
                """
                MVRP Main Port Table
                
                .. attribute:: mvrp_main_port
                
                	MVRP Main Port
                	**type**\: list of    :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.Mvrp.MvrpMainPorts, self).__init__()

                    self.yang_name = "mvrp-main-ports"
                    self.yang_parent_name = "mvrp"

                    self.mvrp_main_port = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.Mvrp.MvrpMainPorts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.Mvrp.MvrpMainPorts, self).__setattr__(name, value)


                class MvrpMainPort(Entity):
                    """
                    MVRP Main Port
                    
                    .. attribute:: main_port_interface_name  <key>
                    
                    	Main Port interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mvrp_bridge_ports
                    
                    	MVRP Bridge Port Table
                    	**type**\:   :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                    
                    .. attribute:: mvrp_main_port_info
                    
                    	MVRP Main Port Information
                    	**type**\:   :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort, self).__init__()

                        self.yang_name = "mvrp-main-port"
                        self.yang_parent_name = "mvrp-main-ports"

                        self.main_port_interface_name = YLeaf(YType.str, "main-port-interface-name")

                        self.mvrp_bridge_ports = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                        self.mvrp_bridge_ports.parent = self
                        self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                        self._children_yang_names.add("mvrp-bridge-ports")

                        self.mvrp_main_port_info = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                        self.mvrp_main_port_info.parent = self
                        self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"
                        self._children_yang_names.add("mvrp-main-port-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("main_port_interface_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort, self).__setattr__(name, value)


                    class MvrpMainPortInfo(Entity):
                        """
                        MVRP Main Port Information
                        
                        .. attribute:: default_bridge_port
                        
                        	Trunk or default Bridge Port
                        	**type**\:   :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                        
                        .. attribute:: is_default_encap
                        
                        	Is default encap set
                        	**type**\:  bool
                        
                        .. attribute:: is_trunk
                        
                        	Is main port a trunk
                        	**type**\:  bool
                        
                        .. attribute:: main_port_interface_name
                        
                        	Main Port Interface name
                        	**type**\:  str
                        
                        .. attribute:: number_of_bridge_ports
                        
                        	Number of Bridge Ports
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__init__()

                            self.yang_name = "mvrp-main-port-info"
                            self.yang_parent_name = "mvrp-main-port"

                            self.is_default_encap = YLeaf(YType.boolean, "is-default-encap")

                            self.is_trunk = YLeaf(YType.boolean, "is-trunk")

                            self.main_port_interface_name = YLeaf(YType.str, "main-port-interface-name")

                            self.number_of_bridge_ports = YLeaf(YType.uint32, "number-of-bridge-ports")

                            self.default_bridge_port = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                            self.default_bridge_port.parent = self
                            self._children_name_map["default_bridge_port"] = "default-bridge-port"
                            self._children_yang_names.add("default-bridge-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("is_default_encap",
                                            "is_trunk",
                                            "main_port_interface_name",
                                            "number_of_bridge_ports") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__setattr__(name, value)


                        class DefaultBridgePort(Entity):
                            """
                            Trunk or default Bridge Port
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\:  str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__init__()

                                self.yang_name = "default-bridge-port"
                                self.yang_parent_name = "mvrp-main-port-info"

                                self.bridge_port_interface_name = YLeaf(YType.str, "bridge-port-interface-name")

                                self.bridge_port_xconnect_id = YLeaf(YType.uint32, "bridge-port-xconnect-id")

                                self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                                self.vlan_range = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bridge_port_interface_name",
                                                "bridge_port_xconnect_id",
                                                "mvrp_sequence_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__setattr__(name, value)


                            class VlanRange(Entity):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__init__()

                                    self.yang_name = "vlan-range"
                                    self.yang_parent_name = "default-bridge-port"

                                    self.lower = YLeaf(YType.uint16, "lower")

                                    self.upper = YLeaf(YType.uint16, "upper")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("lower",
                                                    "upper") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.lower.is_set or
                                        self.upper.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.lower.yfilter != YFilter.not_set or
                                        self.upper.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan-range" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lower" or name == "upper"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "lower"):
                                        self.lower = value
                                        self.lower.value_namespace = name_space
                                        self.lower.value_namespace_prefix = name_space_prefix
                                    if(value_path == "upper"):
                                        self.upper = value
                                        self.upper.value_namespace = name_space
                                        self.upper.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vlan_range:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.bridge_port_interface_name.is_set or
                                    self.bridge_port_xconnect_id.is_set or
                                    self.mvrp_sequence_number.is_set)

                            def has_operation(self):
                                for c in self.vlan_range:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bridge_port_interface_name.yfilter != YFilter.not_set or
                                    self.bridge_port_xconnect_id.yfilter != YFilter.not_set or
                                    self.mvrp_sequence_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "default-bridge-port" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bridge_port_interface_name.is_set or self.bridge_port_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_port_interface_name.get_name_leafdata())
                                if (self.bridge_port_xconnect_id.is_set or self.bridge_port_xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_port_xconnect_id.get_name_leafdata())
                                if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vlan-range"):
                                    for c in self.vlan_range:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vlan_range.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vlan-range" or name == "bridge-port-interface-name" or name == "bridge-port-xconnect-id" or name == "mvrp-sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bridge-port-interface-name"):
                                    self.bridge_port_interface_name = value
                                    self.bridge_port_interface_name.value_namespace = name_space
                                    self.bridge_port_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-port-xconnect-id"):
                                    self.bridge_port_xconnect_id = value
                                    self.bridge_port_xconnect_id.value_namespace = name_space
                                    self.bridge_port_xconnect_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvrp-sequence-number"):
                                    self.mvrp_sequence_number = value
                                    self.mvrp_sequence_number.value_namespace = name_space
                                    self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.is_default_encap.is_set or
                                self.is_trunk.is_set or
                                self.main_port_interface_name.is_set or
                                self.number_of_bridge_ports.is_set or
                                (self.default_bridge_port is not None and self.default_bridge_port.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.is_default_encap.yfilter != YFilter.not_set or
                                self.is_trunk.yfilter != YFilter.not_set or
                                self.main_port_interface_name.yfilter != YFilter.not_set or
                                self.number_of_bridge_ports.yfilter != YFilter.not_set or
                                (self.default_bridge_port is not None and self.default_bridge_port.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mvrp-main-port-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_default_encap.is_set or self.is_default_encap.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_default_encap.get_name_leafdata())
                            if (self.is_trunk.is_set or self.is_trunk.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_trunk.get_name_leafdata())
                            if (self.main_port_interface_name.is_set or self.main_port_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_port_interface_name.get_name_leafdata())
                            if (self.number_of_bridge_ports.is_set or self.number_of_bridge_ports.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_bridge_ports.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "default-bridge-port"):
                                if (self.default_bridge_port is None):
                                    self.default_bridge_port = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                                    self.default_bridge_port.parent = self
                                    self._children_name_map["default_bridge_port"] = "default-bridge-port"
                                return self.default_bridge_port

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "default-bridge-port" or name == "is-default-encap" or name == "is-trunk" or name == "main-port-interface-name" or name == "number-of-bridge-ports"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "is-default-encap"):
                                self.is_default_encap = value
                                self.is_default_encap.value_namespace = name_space
                                self.is_default_encap.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-trunk"):
                                self.is_trunk = value
                                self.is_trunk.value_namespace = name_space
                                self.is_trunk.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-port-interface-name"):
                                self.main_port_interface_name = value
                                self.main_port_interface_name.value_namespace = name_space
                                self.main_port_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-bridge-ports"):
                                self.number_of_bridge_ports = value
                                self.number_of_bridge_ports.value_namespace = name_space
                                self.number_of_bridge_ports.value_namespace_prefix = name_space_prefix


                    class MvrpBridgePorts(Entity):
                        """
                        MVRP Bridge Port Table
                        
                        .. attribute:: mvrp_bridge_port
                        
                        	MVRP Bridge Port Information
                        	**type**\: list of    :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__init__()

                            self.yang_name = "mvrp-bridge-ports"
                            self.yang_parent_name = "mvrp-main-port"

                            self.mvrp_bridge_port = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__setattr__(name, value)


                        class MvrpBridgePort(Entity):
                            """
                            MVRP Bridge Port Information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Bridge Port Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\:  str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__init__()

                                self.yang_name = "mvrp-bridge-port"
                                self.yang_parent_name = "mvrp-bridge-ports"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.bridge_port_interface_name = YLeaf(YType.str, "bridge-port-interface-name")

                                self.bridge_port_xconnect_id = YLeaf(YType.uint32, "bridge-port-xconnect-id")

                                self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                                self.vlan_range = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "bridge_port_interface_name",
                                                "bridge_port_xconnect_id",
                                                "mvrp_sequence_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__setattr__(name, value)


                            class VlanRange(Entity):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__init__()

                                    self.yang_name = "vlan-range"
                                    self.yang_parent_name = "mvrp-bridge-port"

                                    self.lower = YLeaf(YType.uint16, "lower")

                                    self.upper = YLeaf(YType.uint16, "upper")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("lower",
                                                    "upper") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.lower.is_set or
                                        self.upper.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.lower.yfilter != YFilter.not_set or
                                        self.upper.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan-range" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lower" or name == "upper"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "lower"):
                                        self.lower = value
                                        self.lower.value_namespace = name_space
                                        self.lower.value_namespace_prefix = name_space_prefix
                                    if(value_path == "upper"):
                                        self.upper = value
                                        self.upper.value_namespace = name_space
                                        self.upper.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.vlan_range:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.bridge_port_interface_name.is_set or
                                    self.bridge_port_xconnect_id.is_set or
                                    self.mvrp_sequence_number.is_set)

                            def has_operation(self):
                                for c in self.vlan_range:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.bridge_port_interface_name.yfilter != YFilter.not_set or
                                    self.bridge_port_xconnect_id.yfilter != YFilter.not_set or
                                    self.mvrp_sequence_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mvrp-bridge-port" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.bridge_port_interface_name.is_set or self.bridge_port_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_port_interface_name.get_name_leafdata())
                                if (self.bridge_port_xconnect_id.is_set or self.bridge_port_xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_port_xconnect_id.get_name_leafdata())
                                if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "vlan-range"):
                                    for c in self.vlan_range:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.vlan_range.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "vlan-range" or name == "interface-name" or name == "bridge-port-interface-name" or name == "bridge-port-xconnect-id" or name == "mvrp-sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-port-interface-name"):
                                    self.bridge_port_interface_name = value
                                    self.bridge_port_interface_name.value_namespace = name_space
                                    self.bridge_port_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-port-xconnect-id"):
                                    self.bridge_port_xconnect_id = value
                                    self.bridge_port_xconnect_id.value_namespace = name_space
                                    self.bridge_port_xconnect_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvrp-sequence-number"):
                                    self.mvrp_sequence_number = value
                                    self.mvrp_sequence_number.value_namespace = name_space
                                    self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.mvrp_bridge_port:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.mvrp_bridge_port:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mvrp-bridge-ports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mvrp-bridge-port"):
                                for c in self.mvrp_bridge_port:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.mvrp_bridge_port.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mvrp-bridge-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.main_port_interface_name.is_set or
                            (self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports.has_data()) or
                            (self.mvrp_main_port_info is not None and self.mvrp_main_port_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.main_port_interface_name.yfilter != YFilter.not_set or
                            (self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports.has_operation()) or
                            (self.mvrp_main_port_info is not None and self.mvrp_main_port_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mvrp-main-port" + "[main-port-interface-name='" + self.main_port_interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/mvrp/mvrp-main-ports/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.main_port_interface_name.is_set or self.main_port_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.main_port_interface_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mvrp-bridge-ports"):
                            if (self.mvrp_bridge_ports is None):
                                self.mvrp_bridge_ports = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                                self.mvrp_bridge_ports.parent = self
                                self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                            return self.mvrp_bridge_ports

                        if (child_yang_name == "mvrp-main-port-info"):
                            if (self.mvrp_main_port_info is None):
                                self.mvrp_main_port_info = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                                self.mvrp_main_port_info.parent = self
                                self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"
                            return self.mvrp_main_port_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mvrp-bridge-ports" or name == "mvrp-main-port-info" or name == "main-port-interface-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "main-port-interface-name"):
                            self.main_port_interface_name = value
                            self.main_port_interface_name.value_namespace = name_space
                            self.main_port_interface_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.mvrp_main_port:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.mvrp_main_port:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mvrp-main-ports" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/mvrp/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mvrp-main-port"):
                        for c in self.mvrp_main_port:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.mvrp_main_port.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mvrp-main-port"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.mvrp_main_ports is not None and self.mvrp_main_ports.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.mvrp_main_ports is not None and self.mvrp_main_ports.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mvrp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mvrp-main-ports"):
                    if (self.mvrp_main_ports is None):
                        self.mvrp_main_ports = L2Vpnv2.Active.Mvrp.MvrpMainPorts()
                        self.mvrp_main_ports.parent = self
                        self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
                    return self.mvrp_main_ports

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mvrp-main-ports"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class GenericInterfaces(Entity):
            """
            L2VPN generic interface list Table
            
            .. attribute:: generic_interface
            
            	Generic Interface List information
            	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaces.GenericInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.GenericInterfaces, self).__init__()

                self.yang_name = "generic-interfaces"
                self.yang_parent_name = "active"

                self.generic_interface = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.GenericInterfaces, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.GenericInterfaces, self).__setattr__(name, value)


            class GenericInterface(Entity):
                """
                Generic Interface List information
                
                .. attribute:: interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaces.GenericInterface.Interface>`
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_list_name_xr
                
                	Interface\-list name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: items
                
                	Number of items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.GenericInterfaces.GenericInterface, self).__init__()

                    self.yang_name = "generic-interface"
                    self.yang_parent_name = "generic-interfaces"

                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                    self.interface_list_name_xr = YLeaf(YType.str, "interface-list-name-xr")

                    self.items = YLeaf(YType.uint32, "items")

                    self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_list_name",
                                    "interface_list_id",
                                    "interface_list_name_xr",
                                    "items",
                                    "number_of_interfaces") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.GenericInterfaces.GenericInterface, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.GenericInterfaces.GenericInterface, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.GenericInterfaces.GenericInterface.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                        self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                        self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_fib_downloaded",
                                        "not_supported_replications",
                                        "pending_replications") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.is_fib_downloaded.is_set or
                            self.not_supported_replications.is_set or
                            self.pending_replications.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_fib_downloaded.yfilter != YFilter.not_set or
                            self.not_supported_replications.yfilter != YFilter.not_set or
                            self.pending_replications.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                        if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                        if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pending_replications.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-fib-downloaded"):
                            self.is_fib_downloaded = value
                            self.is_fib_downloaded.value_namespace = name_space
                            self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-replications"):
                            self.not_supported_replications = value
                            self.not_supported_replications.value_namespace = name_space
                            self.not_supported_replications.value_namespace_prefix = name_space_prefix
                        if(value_path == "pending-replications"):
                            self.pending_replications = value
                            self.pending_replications.value_namespace = name_space
                            self.pending_replications.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.interface_list_name.is_set or
                        self.interface_list_id.is_set or
                        self.interface_list_name_xr.is_set or
                        self.items.is_set or
                        self.number_of_interfaces.is_set)

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_list_name.yfilter != YFilter.not_set or
                        self.interface_list_id.yfilter != YFilter.not_set or
                        self.interface_list_name_xr.yfilter != YFilter.not_set or
                        self.items.yfilter != YFilter.not_set or
                        self.number_of_interfaces.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-interface" + "[interface-list-name='" + self.interface_list_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/generic-interfaces/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                    if (self.interface_list_name_xr.is_set or self.interface_list_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_name_xr.get_name_leafdata())
                    if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.items.get_name_leafdata())
                    if (self.number_of_interfaces.is_set or self.number_of_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_of_interfaces.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.GenericInterfaces.GenericInterface.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "interface-list-name" or name == "interface-list-id" or name == "interface-list-name-xr" or name == "items" or name == "number-of-interfaces"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-list-name"):
                        self.interface_list_name = value
                        self.interface_list_name.value_namespace = name_space
                        self.interface_list_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-list-id"):
                        self.interface_list_id = value
                        self.interface_list_id.value_namespace = name_space
                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-list-name-xr"):
                        self.interface_list_name_xr = value
                        self.interface_list_name_xr.value_namespace = name_space
                        self.interface_list_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "items"):
                        self.items = value
                        self.items.value_namespace = name_space
                        self.items.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-of-interfaces"):
                        self.number_of_interfaces = value
                        self.number_of_interfaces.value_namespace = name_space
                        self.number_of_interfaces.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.generic_interface:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.generic_interface:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "generic-interfaces" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "generic-interface"):
                    for c in self.generic_interface:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.GenericInterfaces.GenericInterface()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.generic_interface.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class MstpVlans(Entity):
            """
            L2VPN MSTP VLAN Table
            
            .. attribute:: mstp_vlan
            
            	L2VPN MSTP VLAN information
            	**type**\: list of    :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpVlans.MstpVlan>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.MstpVlans, self).__init__()

                self.yang_name = "mstp-vlans"
                self.yang_parent_name = "active"

                self.mstp_vlan = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.MstpVlans, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.MstpVlans, self).__setattr__(name, value)


            class MstpVlan(Entity):
                """
                L2VPN MSTP VLAN information
                
                .. attribute:: vlan_id  <key>
                
                	vlan id
                	**type**\:  int
                
                	**range:** 0..4098
                
                .. attribute:: msti_id
                
                	MSTI id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_count
                
                	Port Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sub_interface
                
                	Sub interfaces
                	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpVlans.MstpVlan.SubInterface>`
                
                .. attribute:: vlan_id_xr
                
                	Vlan id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.MstpVlans.MstpVlan, self).__init__()

                    self.yang_name = "mstp-vlan"
                    self.yang_parent_name = "mstp-vlans"

                    self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                    self.msti_id = YLeaf(YType.uint32, "msti-id")

                    self.port_count = YLeaf(YType.uint32, "port-count")

                    self.vlan_id_xr = YLeaf(YType.uint32, "vlan-id-xr")

                    self.sub_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vlan_id",
                                    "msti_id",
                                    "port_count",
                                    "vlan_id_xr") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.MstpVlans.MstpVlan, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.MstpVlans.MstpVlan, self).__setattr__(name, value)


                class SubInterface(Entity):
                    """
                    Sub interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.MstpVlans.MstpVlan.SubInterface, self).__init__()

                        self.yang_name = "sub-interface"
                        self.yang_parent_name = "mstp-vlan"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.MstpVlans.MstpVlan.SubInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.MstpVlans.MstpVlan.SubInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return self.interface_name.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sub-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.sub_interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.vlan_id.is_set or
                        self.msti_id.is_set or
                        self.port_count.is_set or
                        self.vlan_id_xr.is_set)

                def has_operation(self):
                    for c in self.sub_interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vlan_id.yfilter != YFilter.not_set or
                        self.msti_id.yfilter != YFilter.not_set or
                        self.port_count.yfilter != YFilter.not_set or
                        self.vlan_id_xr.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mstp-vlan" + "[vlan-id='" + self.vlan_id.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/mstp-vlans/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vlan_id.get_name_leafdata())
                    if (self.msti_id.is_set or self.msti_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.msti_id.get_name_leafdata())
                    if (self.port_count.is_set or self.port_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.port_count.get_name_leafdata())
                    if (self.vlan_id_xr.is_set or self.vlan_id_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vlan_id_xr.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sub-interface"):
                        for c in self.sub_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.MstpVlans.MstpVlan.SubInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.sub_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sub-interface" or name == "vlan-id" or name == "msti-id" or name == "port-count" or name == "vlan-id-xr"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vlan-id"):
                        self.vlan_id = value
                        self.vlan_id.value_namespace = name_space
                        self.vlan_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "msti-id"):
                        self.msti_id = value
                        self.msti_id.value_namespace = name_space
                        self.msti_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "port-count"):
                        self.port_count = value
                        self.port_count.value_namespace = name_space
                        self.port_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "vlan-id-xr"):
                        self.vlan_id_xr = value
                        self.vlan_id_xr.value_namespace = name_space
                        self.vlan_id_xr.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.mstp_vlan:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.mstp_vlan:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mstp-vlans" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mstp-vlan"):
                    for c in self.mstp_vlan:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.MstpVlans.MstpVlan()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.mstp_vlan.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mstp-vlan"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class L2VpnPbbBsa(Entity):
            """
            L2VPN PBB Backbone Source MAC information
            
            .. attribute:: bmac_sa
            
            	BMAC SA
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: chassis_is_provisioned
            
            	Chassis MAC is configured
            	**type**\:  bool
            
            .. attribute:: chassis_mac
            
            	Chassis MAC
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: provisioned
            
            	BMAC SA configured
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.L2VpnPbbBsa, self).__init__()

                self.yang_name = "l2vpn-pbb-bsa"
                self.yang_parent_name = "active"

                self.bmac_sa = YLeaf(YType.str, "bmac-sa")

                self.chassis_is_provisioned = YLeaf(YType.boolean, "chassis-is-provisioned")

                self.chassis_mac = YLeaf(YType.str, "chassis-mac")

                self.provisioned = YLeaf(YType.boolean, "provisioned")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("bmac_sa",
                                "chassis_is_provisioned",
                                "chassis_mac",
                                "provisioned") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.L2VpnPbbBsa, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.L2VpnPbbBsa, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.bmac_sa.is_set or
                    self.chassis_is_provisioned.is_set or
                    self.chassis_mac.is_set or
                    self.provisioned.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.bmac_sa.yfilter != YFilter.not_set or
                    self.chassis_is_provisioned.yfilter != YFilter.not_set or
                    self.chassis_mac.yfilter != YFilter.not_set or
                    self.provisioned.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "l2vpn-pbb-bsa" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.bmac_sa.is_set or self.bmac_sa.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bmac_sa.get_name_leafdata())
                if (self.chassis_is_provisioned.is_set or self.chassis_is_provisioned.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.chassis_is_provisioned.get_name_leafdata())
                if (self.chassis_mac.is_set or self.chassis_mac.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.chassis_mac.get_name_leafdata())
                if (self.provisioned.is_set or self.provisioned.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.provisioned.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bmac-sa" or name == "chassis-is-provisioned" or name == "chassis-mac" or name == "provisioned"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "bmac-sa"):
                    self.bmac_sa = value
                    self.bmac_sa.value_namespace = name_space
                    self.bmac_sa.value_namespace_prefix = name_space_prefix
                if(value_path == "chassis-is-provisioned"):
                    self.chassis_is_provisioned = value
                    self.chassis_is_provisioned.value_namespace = name_space
                    self.chassis_is_provisioned.value_namespace_prefix = name_space_prefix
                if(value_path == "chassis-mac"):
                    self.chassis_mac = value
                    self.chassis_mac.value_namespace = name_space
                    self.chassis_mac.value_namespace_prefix = name_space_prefix
                if(value_path == "provisioned"):
                    self.provisioned = value
                    self.provisioned.value_namespace = name_space
                    self.provisioned.value_namespace_prefix = name_space_prefix


        class FlexibleXconnectServices(Entity):
            """
            Flexible XConnect Service Table
            
            .. attribute:: flexible_xconnect_service
            
            	Flexible XConnect Service Information
            	**type**\: list of    :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.FlexibleXconnectServices, self).__init__()

                self.yang_name = "flexible-xconnect-services"
                self.yang_parent_name = "active"

                self.flexible_xconnect_service = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.FlexibleXconnectServices, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.FlexibleXconnectServices, self).__setattr__(name, value)


            class FlexibleXconnectService(Entity):
                """
                Flexible XConnect Service Information
                
                .. attribute:: name  <key>
                
                	Flexible XConnect Service Name
                	**type**\:  str
                
                	**length:** 1..23
                
                .. attribute:: flexible_xconnect_service_acs
                
                	Flexible XConnect Service Attachment Circuit Table
                	**type**\:   :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
                
                .. attribute:: flexible_xconnect_service_info
                
                	Flexible XConnect Service Information
                	**type**\:   :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService, self).__init__()

                    self.yang_name = "flexible-xconnect-service"
                    self.yang_parent_name = "flexible-xconnect-services"

                    self.name = YLeaf(YType.str, "name")

                    self.flexible_xconnect_service_acs = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                    self.flexible_xconnect_service_acs.parent = self
                    self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"
                    self._children_yang_names.add("flexible-xconnect-service-acs")

                    self.flexible_xconnect_service_info = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                    self.flexible_xconnect_service_info.parent = self
                    self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                    self._children_yang_names.add("flexible-xconnect-service-info")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService, self).__setattr__(name, value)


                class FlexibleXconnectServiceAcs(Entity):
                    """
                    Flexible XConnect Service Attachment Circuit
                    Table
                    
                    .. attribute:: flexible_xconnect_service_ac
                    
                    	Flexible XConnect Service Attachment Circuit
                    	**type**\: list of    :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__init__()

                        self.yang_name = "flexible-xconnect-service-acs"
                        self.yang_parent_name = "flexible-xconnect-service"

                        self.flexible_xconnect_service_ac = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__setattr__(name, value)


                    class FlexibleXconnectServiceAc(Entity):
                        """
                        Flexible XConnect Service Attachment Circuit
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: attachment_circuit
                        
                        	Flexible XConnect Service Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__init__()

                            self.yang_name = "flexible-xconnect-service-ac"
                            self.yang_parent_name = "flexible-xconnect-service-acs"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.attachment_circuit = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            self._children_yang_names.add("attachment-circuit")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__setattr__(name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Flexible XConnect Service Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "flexible-xconnect-service-ac"

                                self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                                self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                                self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                                self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                                self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                                self.msti = YLeaf(YType.str, "msti")

                                self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.node_id = YLeaf(YType.str, "node-id")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.interface = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._children_yang_names.add("interface")

                                self.l2vpn_protection = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._children_yang_names.add("l2vpn-protection")

                                self.statistics = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bvi_mac_conflict",
                                                "bvi_no_port_up",
                                                "control_word_mismatched",
                                                "encapsulation_error",
                                                "encapsulation_mismatched",
                                                "evpn_internal_label",
                                                "interface_handle",
                                                "internal_ms_ti",
                                                "interworking",
                                                "is_ac_partially_programmed",
                                                "mac_limit_oper_down",
                                                "ms_ti_mismatch",
                                                "msti",
                                                "msti_mismatch_down",
                                                "mtu_mismatched",
                                                "node_id",
                                                "out_of_memory_state",
                                                "redundancy_group_id",
                                                "redundancy_group_state",
                                                "redundancy_object_id",
                                                "state",
                                                "tdm_media_mismatched",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__setattr__(name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.dispostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class L2VpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.protected_name = YLeaf(YType.str, "protected-name")

                                    self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                    self.protection_name = YLeaf(YType.str, "protection-name")

                                    self.protection_type = YLeaf(YType.enumeration, "protection-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "protected_name",
                                                    "protection_configured",
                                                    "protection_name",
                                                    "protection_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.protected_name.is_set or
                                        self.protection_configured.is_set or
                                        self.protection_name.is_set or
                                        self.protection_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.protected_name.yfilter != YFilter.not_set or
                                        self.protection_configured.yfilter != YFilter.not_set or
                                        self.protection_name.yfilter != YFilter.not_set or
                                        self.protection_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2vpn-protection" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protected_name.get_name_leafdata())
                                    if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                    if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_name.get_name_leafdata())
                                    if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protected-name"):
                                        self.protected_name = value
                                        self.protected_name.value_namespace = name_space
                                        self.protected_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-configured"):
                                        self.protection_configured = value
                                        self.protection_configured.value_namespace = name_space
                                        self.protection_configured.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-name"):
                                        self.protection_name = value
                                        self.protection_name.value_namespace = name_space
                                        self.protection_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-type"):
                                        self.protection_type = value
                                        self.protection_type.value_namespace = name_space
                                        self.protection_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bvi_mac_conflict.is_set or
                                    self.bvi_no_port_up.is_set or
                                    self.control_word_mismatched.is_set or
                                    self.encapsulation_error.is_set or
                                    self.encapsulation_mismatched.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.interface_handle.is_set or
                                    self.internal_ms_ti.is_set or
                                    self.interworking.is_set or
                                    self.is_ac_partially_programmed.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.ms_ti_mismatch.is_set or
                                    self.msti.is_set or
                                    self.msti_mismatch_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.node_id.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_group_state.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.state.is_set or
                                    self.tdm_media_mismatched.is_set or
                                    self.xconnect_id.is_set or
                                    (self.interface is not None and self.interface.has_data()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                    self.bvi_no_port_up.yfilter != YFilter.not_set or
                                    self.control_word_mismatched.yfilter != YFilter.not_set or
                                    self.encapsulation_error.yfilter != YFilter.not_set or
                                    self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.internal_ms_ti.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                    self.msti.yfilter != YFilter.not_set or
                                    self.msti_mismatch_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_group_state.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.interface is not None and self.interface.has_operation()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "attachment-circuit" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                                if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                                if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                                if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                                if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface"):
                                    if (self.interface is None):
                                        self.interface = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                        self.interface.parent = self
                                        self._children_name_map["interface"] = "interface"
                                    return self.interface

                                if (child_yang_name == "l2vpn-protection"):
                                    if (self.l2vpn_protection is None):
                                        self.l2vpn_protection = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                                        self.l2vpn_protection.parent = self
                                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    return self.l2vpn_protection

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bvi-mac-conflict"):
                                    self.bvi_mac_conflict = value
                                    self.bvi_mac_conflict.value_namespace = name_space
                                    self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-no-port-up"):
                                    self.bvi_no_port_up = value
                                    self.bvi_no_port_up.value_namespace = name_space
                                    self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-word-mismatched"):
                                    self.control_word_mismatched = value
                                    self.control_word_mismatched.value_namespace = name_space
                                    self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-error"):
                                    self.encapsulation_error = value
                                    self.encapsulation_error.value_namespace = name_space
                                    self.encapsulation_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-mismatched"):
                                    self.encapsulation_mismatched = value
                                    self.encapsulation_mismatched.value_namespace = name_space
                                    self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-ms-ti"):
                                    self.internal_ms_ti = value
                                    self.internal_ms_ti.value_namespace = name_space
                                    self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ac-partially-programmed"):
                                    self.is_ac_partially_programmed = value
                                    self.is_ac_partially_programmed.value_namespace = name_space
                                    self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ms-ti-mismatch"):
                                    self.ms_ti_mismatch = value
                                    self.ms_ti_mismatch.value_namespace = name_space
                                    self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti"):
                                    self.msti = value
                                    self.msti.value_namespace = name_space
                                    self.msti.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-mismatch-down"):
                                    self.msti_mismatch_down = value
                                    self.msti_mismatch_down.value_namespace = name_space
                                    self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-state"):
                                    self.redundancy_group_state = value
                                    self.redundancy_group_state.value_namespace = name_space
                                    self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "tdm-media-mismatched"):
                                    self.tdm_media_mismatched = value
                                    self.tdm_media_mismatched.value_namespace = name_space
                                    self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "flexible-xconnect-service-ac" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "attachment-circuit"):
                                if (self.attachment_circuit is None):
                                    self.attachment_circuit = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                                    self.attachment_circuit.parent = self
                                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                return self.attachment_circuit

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "attachment-circuit" or name == "interface-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.flexible_xconnect_service_ac:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.flexible_xconnect_service_ac:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flexible-xconnect-service-acs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "flexible-xconnect-service-ac"):
                            for c in self.flexible_xconnect_service_ac:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.flexible_xconnect_service_ac.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flexible-xconnect-service-ac"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class FlexibleXconnectServiceInfo(Entity):
                    """
                    Flexible XConnect Service Information
                    
                    .. attribute:: fxc_id
                    
                    	Flexible XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	Flexible XConnect Service Name
                    	**type**\:  str
                    
                    .. attribute:: num_p_ws
                    
                    	Number of Pseudowires in Pseudowire List
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: pseudowire
                    
                    	Flexible XConnect Service Pseudowire List
                    	**type**\: list of    :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                    
                    .. attribute:: state
                    
                    	State of the Flexible XConnect Service
                    	**type**\:   :py:class:`L2VpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcState>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__init__()

                        self.yang_name = "flexible-xconnect-service-info"
                        self.yang_parent_name = "flexible-xconnect-service"

                        self.fxc_id = YLeaf(YType.uint32, "fxc-id")

                        self.name = YLeaf(YType.str, "name")

                        self.num_p_ws = YLeaf(YType.uint8, "num-p-ws")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.pseudowire = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("fxc_id",
                                        "name",
                                        "num_p_ws",
                                        "state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__setattr__(name, value)


                    class Pseudowire(Entity):
                        """
                        Flexible XConnect Service Pseudowire List
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__init__()

                            self.yang_name = "pseudowire"
                            self.yang_parent_name = "flexible-xconnect-service-info"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudowire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudowire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudowire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudowire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudowire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudowire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudowire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudowire"

                                self.dispostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudowire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudowire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.pseudowire:
                            if (c.has_data()):
                                return True
                        return (
                            self.fxc_id.is_set or
                            self.name.is_set or
                            self.num_p_ws.is_set or
                            self.state.is_set)

                    def has_operation(self):
                        for c in self.pseudowire:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.fxc_id.yfilter != YFilter.not_set or
                            self.name.yfilter != YFilter.not_set or
                            self.num_p_ws.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flexible-xconnect-service-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.fxc_id.is_set or self.fxc_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fxc_id.get_name_leafdata())
                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.name.get_name_leafdata())
                        if (self.num_p_ws.is_set or self.num_p_ws.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_p_ws.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "pseudowire"):
                            for c in self.pseudowire:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.pseudowire.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "pseudowire" or name == "fxc-id" or name == "name" or name == "num-p-ws" or name == "state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "fxc-id"):
                            self.fxc_id = value
                            self.fxc_id.value_namespace = name_space
                            self.fxc_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "name"):
                            self.name = value
                            self.name.value_namespace = name_space
                            self.name.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-p-ws"):
                            self.num_p_ws = value
                            self.num_p_ws.value_namespace = name_space
                            self.num_p_ws.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs.has_data()) or
                        (self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs.has_operation()) or
                        (self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flexible-xconnect-service" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/flexible-xconnect-services/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "flexible-xconnect-service-acs"):
                        if (self.flexible_xconnect_service_acs is None):
                            self.flexible_xconnect_service_acs = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                            self.flexible_xconnect_service_acs.parent = self
                            self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"
                        return self.flexible_xconnect_service_acs

                    if (child_yang_name == "flexible-xconnect-service-info"):
                        if (self.flexible_xconnect_service_info is None):
                            self.flexible_xconnect_service_info = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                            self.flexible_xconnect_service_info.parent = self
                            self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                        return self.flexible_xconnect_service_info

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flexible-xconnect-service-acs" or name == "flexible-xconnect-service-info" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.flexible_xconnect_service:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.flexible_xconnect_service:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "flexible-xconnect-services" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "flexible-xconnect-service"):
                    for c in self.flexible_xconnect_service:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.flexible_xconnect_service.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "flexible-xconnect-service"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class XconnectBrief(Entity):
            """
            XConnect brief information
            
            .. attribute:: encapsulation_report_matrix
            
            	Encapsulation report counters matrix
            	**type**\: list of    :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix>`
            
            .. attribute:: encapsulation_total
            
            	Total summary
            	**type**\: list of    :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectBrief.EncapsulationTotal>`
            
            .. attribute:: main_total_down
            
            	Total Number of non\-active Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_unresolved
            
            	Total Number of unresolved Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_up
            
            	Total Number of active Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: memory_state
            
            	L2VPN memory state
            	**type**\:   :py:class:`L2VpnMemoryState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMemoryState>`
            
            .. attribute:: undefined_xc
            
            	Undefined xc including PW\-PW
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Active.XconnectBrief, self).__init__()

                self.yang_name = "xconnect-brief"
                self.yang_parent_name = "active"

                self.main_total_down = YLeaf(YType.uint32, "main-total-down")

                self.main_total_unresolved = YLeaf(YType.uint32, "main-total-unresolved")

                self.main_total_up = YLeaf(YType.uint32, "main-total-up")

                self.memory_state = YLeaf(YType.enumeration, "memory-state")

                self.undefined_xc = YLeaf(YType.uint32, "undefined-xc")

                self.encapsulation_report_matrix = YList(self)
                self.encapsulation_total = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("main_total_down",
                                "main_total_unresolved",
                                "main_total_up",
                                "memory_state",
                                "undefined_xc") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Active.XconnectBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Active.XconnectBrief, self).__setattr__(name, value)


            class EncapsulationReportMatrix(Entity):
                """
                Encapsulation report counters matrix
                
                .. attribute:: ac1
                
                	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
                	**type**\: list of    :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix, self).__init__()

                    self.yang_name = "encapsulation-report-matrix"
                    self.yang_parent_name = "xconnect-brief"

                    self.ac1 = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix, self).__setattr__(name, value)


                class Ac1(Entity):
                    """
                    Array of l2vpn\_xc\_brief\_first layer indexed by
                    the AC1 encapsulation type
                    
                    .. attribute:: ac2
                    
                    	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                    	**type**\: list of    :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__init__()

                        self.yang_name = "ac1"
                        self.yang_parent_name = "encapsulation-report-matrix"

                        self.ac2 = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__setattr__(name, value)


                    class Ac2(Entity):
                        """
                        Array of l2vpn\_xc\_brief\_line indexed by the AC2
                        encapsulation type plus one type for PW
                        
                        .. attribute:: ac1_encapsulation
                        
                        	AC1 encapsulation
                        	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                        
                        .. attribute:: ac2_encapsulation
                        
                        	AC2 encapsulation
                        	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                        
                        .. attribute:: down_count
                        
                        	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: psn_type
                        
                        	PSN Type
                        	**type**\:   :py:class:`L2VpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBriefPsn>`
                        
                        .. attribute:: unresolved_count
                        
                        	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: up_count
                        
                        	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__init__()

                            self.yang_name = "ac2"
                            self.yang_parent_name = "ac1"

                            self.ac1_encapsulation = YLeaf(YType.enumeration, "ac1-encapsulation")

                            self.ac2_encapsulation = YLeaf(YType.enumeration, "ac2-encapsulation")

                            self.down_count = YLeafList(YType.uint32, "down-count")

                            self.psn_type = YLeaf(YType.enumeration, "psn-type")

                            self.unresolved_count = YLeafList(YType.uint32, "unresolved-count")

                            self.up_count = YLeafList(YType.uint32, "up-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ac1_encapsulation",
                                            "ac2_encapsulation",
                                            "down_count",
                                            "psn_type",
                                            "unresolved_count",
                                            "up_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.down_count.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.unresolved_count.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            for leaf in self.up_count.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.ac1_encapsulation.is_set or
                                self.ac2_encapsulation.is_set or
                                self.psn_type.is_set)

                        def has_operation(self):
                            for leaf in self.down_count.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.unresolved_count.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            for leaf in self.up_count.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ac1_encapsulation.yfilter != YFilter.not_set or
                                self.ac2_encapsulation.yfilter != YFilter.not_set or
                                self.down_count.yfilter != YFilter.not_set or
                                self.psn_type.yfilter != YFilter.not_set or
                                self.unresolved_count.yfilter != YFilter.not_set or
                                self.up_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ac2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/encapsulation-report-matrix/ac1/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ac1_encapsulation.is_set or self.ac1_encapsulation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ac1_encapsulation.get_name_leafdata())
                            if (self.ac2_encapsulation.is_set or self.ac2_encapsulation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ac2_encapsulation.get_name_leafdata())
                            if (self.psn_type.is_set or self.psn_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.psn_type.get_name_leafdata())

                            leaf_name_data.extend(self.down_count.get_name_leafdata())

                            leaf_name_data.extend(self.unresolved_count.get_name_leafdata())

                            leaf_name_data.extend(self.up_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac1-encapsulation" or name == "ac2-encapsulation" or name == "down-count" or name == "psn-type" or name == "unresolved-count" or name == "up-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ac1-encapsulation"):
                                self.ac1_encapsulation = value
                                self.ac1_encapsulation.value_namespace = name_space
                                self.ac1_encapsulation.value_namespace_prefix = name_space_prefix
                            if(value_path == "ac2-encapsulation"):
                                self.ac2_encapsulation = value
                                self.ac2_encapsulation.value_namespace = name_space
                                self.ac2_encapsulation.value_namespace_prefix = name_space_prefix
                            if(value_path == "down-count"):
                                self.down_count.append(value)
                            if(value_path == "psn-type"):
                                self.psn_type = value
                                self.psn_type.value_namespace = name_space
                                self.psn_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "unresolved-count"):
                                self.unresolved_count.append(value)
                            if(value_path == "up-count"):
                                self.up_count.append(value)

                    def has_data(self):
                        for c in self.ac2:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ac2:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ac1" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/encapsulation-report-matrix/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ac2"):
                            for c in self.ac2:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ac2.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ac2"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    for c in self.ac1:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ac1:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "encapsulation-report-matrix" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ac1"):
                        for c in self.ac1:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ac1.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ac1"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class EncapsulationTotal(Entity):
                """
                Total summary
                
                .. attribute:: ac1_encapsulation
                
                	AC1 encapsulation
                	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                
                .. attribute:: ac2_encapsulation
                
                	AC2 encapsulation
                	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                
                .. attribute:: down_count
                
                	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: psn_type
                
                	PSN Type
                	**type**\:   :py:class:`L2VpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBriefPsn>`
                
                .. attribute:: unresolved_count
                
                	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Active.XconnectBrief.EncapsulationTotal, self).__init__()

                    self.yang_name = "encapsulation-total"
                    self.yang_parent_name = "xconnect-brief"

                    self.ac1_encapsulation = YLeaf(YType.enumeration, "ac1-encapsulation")

                    self.ac2_encapsulation = YLeaf(YType.enumeration, "ac2-encapsulation")

                    self.down_count = YLeafList(YType.uint32, "down-count")

                    self.psn_type = YLeaf(YType.enumeration, "psn-type")

                    self.unresolved_count = YLeafList(YType.uint32, "unresolved-count")

                    self.up_count = YLeafList(YType.uint32, "up-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ac1_encapsulation",
                                    "ac2_encapsulation",
                                    "down_count",
                                    "psn_type",
                                    "unresolved_count",
                                    "up_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Active.XconnectBrief.EncapsulationTotal, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Active.XconnectBrief.EncapsulationTotal, self).__setattr__(name, value)

                def has_data(self):
                    for leaf in self.down_count.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.unresolved_count.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.up_count.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.ac1_encapsulation.is_set or
                        self.ac2_encapsulation.is_set or
                        self.psn_type.is_set)

                def has_operation(self):
                    for leaf in self.down_count.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.unresolved_count.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.up_count.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ac1_encapsulation.yfilter != YFilter.not_set or
                        self.ac2_encapsulation.yfilter != YFilter.not_set or
                        self.down_count.yfilter != YFilter.not_set or
                        self.psn_type.yfilter != YFilter.not_set or
                        self.unresolved_count.yfilter != YFilter.not_set or
                        self.up_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "encapsulation-total" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ac1_encapsulation.is_set or self.ac1_encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ac1_encapsulation.get_name_leafdata())
                    if (self.ac2_encapsulation.is_set or self.ac2_encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ac2_encapsulation.get_name_leafdata())
                    if (self.psn_type.is_set or self.psn_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.psn_type.get_name_leafdata())

                    leaf_name_data.extend(self.down_count.get_name_leafdata())

                    leaf_name_data.extend(self.unresolved_count.get_name_leafdata())

                    leaf_name_data.extend(self.up_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ac1-encapsulation" or name == "ac2-encapsulation" or name == "down-count" or name == "psn-type" or name == "unresolved-count" or name == "up-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ac1-encapsulation"):
                        self.ac1_encapsulation = value
                        self.ac1_encapsulation.value_namespace = name_space
                        self.ac1_encapsulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "ac2-encapsulation"):
                        self.ac2_encapsulation = value
                        self.ac2_encapsulation.value_namespace = name_space
                        self.ac2_encapsulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "down-count"):
                        self.down_count.append(value)
                    if(value_path == "psn-type"):
                        self.psn_type = value
                        self.psn_type.value_namespace = name_space
                        self.psn_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "unresolved-count"):
                        self.unresolved_count.append(value)
                    if(value_path == "up-count"):
                        self.up_count.append(value)

            def has_data(self):
                for c in self.encapsulation_report_matrix:
                    if (c.has_data()):
                        return True
                for c in self.encapsulation_total:
                    if (c.has_data()):
                        return True
                return (
                    self.main_total_down.is_set or
                    self.main_total_unresolved.is_set or
                    self.main_total_up.is_set or
                    self.memory_state.is_set or
                    self.undefined_xc.is_set)

            def has_operation(self):
                for c in self.encapsulation_report_matrix:
                    if (c.has_operation()):
                        return True
                for c in self.encapsulation_total:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.main_total_down.yfilter != YFilter.not_set or
                    self.main_total_unresolved.yfilter != YFilter.not_set or
                    self.main_total_up.yfilter != YFilter.not_set or
                    self.memory_state.yfilter != YFilter.not_set or
                    self.undefined_xc.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-brief" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.main_total_down.is_set or self.main_total_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.main_total_down.get_name_leafdata())
                if (self.main_total_unresolved.is_set or self.main_total_unresolved.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.main_total_unresolved.get_name_leafdata())
                if (self.main_total_up.is_set or self.main_total_up.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.main_total_up.get_name_leafdata())
                if (self.memory_state.is_set or self.memory_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.memory_state.get_name_leafdata())
                if (self.undefined_xc.is_set or self.undefined_xc.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.undefined_xc.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "encapsulation-report-matrix"):
                    for c in self.encapsulation_report_matrix:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.encapsulation_report_matrix.append(c)
                    return c

                if (child_yang_name == "encapsulation-total"):
                    for c in self.encapsulation_total:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpnv2.Active.XconnectBrief.EncapsulationTotal()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.encapsulation_total.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "encapsulation-report-matrix" or name == "encapsulation-total" or name == "main-total-down" or name == "main-total-unresolved" or name == "main-total-up" or name == "memory-state" or name == "undefined-xc"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "main-total-down"):
                    self.main_total_down = value
                    self.main_total_down.value_namespace = name_space
                    self.main_total_down.value_namespace_prefix = name_space_prefix
                if(value_path == "main-total-unresolved"):
                    self.main_total_unresolved = value
                    self.main_total_unresolved.value_namespace = name_space
                    self.main_total_unresolved.value_namespace_prefix = name_space_prefix
                if(value_path == "main-total-up"):
                    self.main_total_up = value
                    self.main_total_up.value_namespace = name_space
                    self.main_total_up.value_namespace_prefix = name_space_prefix
                if(value_path == "memory-state"):
                    self.memory_state = value
                    self.memory_state.value_namespace = name_space
                    self.memory_state.value_namespace_prefix = name_space_prefix
                if(value_path == "undefined-xc"):
                    self.undefined_xc = value
                    self.undefined_xc.value_namespace = name_space
                    self.undefined_xc.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                (self.bridge_domains is not None and self.bridge_domains.has_data()) or
                (self.bridge_summary is not None and self.bridge_summary.has_data()) or
                (self.discoveries is not None and self.discoveries.has_data()) or
                (self.discovery_summary is not None and self.discovery_summary.has_data()) or
                (self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary.has_data()) or
                (self.flexible_xconnect_services is not None and self.flexible_xconnect_services.has_data()) or
                (self.g8032 is not None and self.g8032.has_data()) or
                (self.generic_interface_list_details is not None and self.generic_interface_list_details.has_data()) or
                (self.generic_interfaces is not None and self.generic_interfaces.has_data()) or
                (self.global_settings is not None and self.global_settings.has_data()) or
                (self.iccp_sm is not None and self.iccp_sm.has_data()) or
                (self.indexes is not None and self.indexes.has_data()) or
                (self.l2vpn_collaborators is not None and self.l2vpn_collaborators.has_data()) or
                (self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa.has_data()) or
                (self.l2vpn_resource_state is not None and self.l2vpn_resource_state.has_data()) or
                (self.main_interfaces is not None and self.main_interfaces.has_data()) or
                (self.mstp_ports is not None and self.mstp_ports.has_data()) or
                (self.mstp_vlans is not None and self.mstp_vlans.has_data()) or
                (self.mvrp is not None and self.mvrp.has_data()) or
                (self.nsr is not None and self.nsr.has_data()) or
                (self.proc_fsm is not None and self.proc_fsm.has_data()) or
                (self.pseudowire_classes is not None and self.pseudowire_classes.has_data()) or
                (self.pwr is not None and self.pwr.has_data()) or
                (self.xconnect_brief is not None and self.xconnect_brief.has_data()) or
                (self.xconnect_groups is not None and self.xconnect_groups.has_data()) or
                (self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces.has_data()) or
                (self.xconnect_mp2mps is not None and self.xconnect_mp2mps.has_data()) or
                (self.xconnect_summary is not None and self.xconnect_summary.has_data()) or
                (self.xconnects is not None and self.xconnects.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.bridge_domains is not None and self.bridge_domains.has_operation()) or
                (self.bridge_summary is not None and self.bridge_summary.has_operation()) or
                (self.discoveries is not None and self.discoveries.has_operation()) or
                (self.discovery_summary is not None and self.discovery_summary.has_operation()) or
                (self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary.has_operation()) or
                (self.flexible_xconnect_services is not None and self.flexible_xconnect_services.has_operation()) or
                (self.g8032 is not None and self.g8032.has_operation()) or
                (self.generic_interface_list_details is not None and self.generic_interface_list_details.has_operation()) or
                (self.generic_interfaces is not None and self.generic_interfaces.has_operation()) or
                (self.global_settings is not None and self.global_settings.has_operation()) or
                (self.iccp_sm is not None and self.iccp_sm.has_operation()) or
                (self.indexes is not None and self.indexes.has_operation()) or
                (self.l2vpn_collaborators is not None and self.l2vpn_collaborators.has_operation()) or
                (self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa.has_operation()) or
                (self.l2vpn_resource_state is not None and self.l2vpn_resource_state.has_operation()) or
                (self.main_interfaces is not None and self.main_interfaces.has_operation()) or
                (self.mstp_ports is not None and self.mstp_ports.has_operation()) or
                (self.mstp_vlans is not None and self.mstp_vlans.has_operation()) or
                (self.mvrp is not None and self.mvrp.has_operation()) or
                (self.nsr is not None and self.nsr.has_operation()) or
                (self.proc_fsm is not None and self.proc_fsm.has_operation()) or
                (self.pseudowire_classes is not None and self.pseudowire_classes.has_operation()) or
                (self.pwr is not None and self.pwr.has_operation()) or
                (self.xconnect_brief is not None and self.xconnect_brief.has_operation()) or
                (self.xconnect_groups is not None and self.xconnect_groups.has_operation()) or
                (self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces.has_operation()) or
                (self.xconnect_mp2mps is not None and self.xconnect_mp2mps.has_operation()) or
                (self.xconnect_summary is not None and self.xconnect_summary.has_operation()) or
                (self.xconnects is not None and self.xconnects.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "active" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "bridge-domains"):
                if (self.bridge_domains is None):
                    self.bridge_domains = L2Vpnv2.Active.BridgeDomains()
                    self.bridge_domains.parent = self
                    self._children_name_map["bridge_domains"] = "bridge-domains"
                return self.bridge_domains

            if (child_yang_name == "bridge-summary"):
                if (self.bridge_summary is None):
                    self.bridge_summary = L2Vpnv2.Active.BridgeSummary()
                    self.bridge_summary.parent = self
                    self._children_name_map["bridge_summary"] = "bridge-summary"
                return self.bridge_summary

            if (child_yang_name == "discoveries"):
                if (self.discoveries is None):
                    self.discoveries = L2Vpnv2.Active.Discoveries()
                    self.discoveries.parent = self
                    self._children_name_map["discoveries"] = "discoveries"
                return self.discoveries

            if (child_yang_name == "discovery-summary"):
                if (self.discovery_summary is None):
                    self.discovery_summary = L2Vpnv2.Active.DiscoverySummary()
                    self.discovery_summary.parent = self
                    self._children_name_map["discovery_summary"] = "discovery-summary"
                return self.discovery_summary

            if (child_yang_name == "flexible-xconnect-service-summary"):
                if (self.flexible_xconnect_service_summary is None):
                    self.flexible_xconnect_service_summary = L2Vpnv2.Active.FlexibleXconnectServiceSummary()
                    self.flexible_xconnect_service_summary.parent = self
                    self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"
                return self.flexible_xconnect_service_summary

            if (child_yang_name == "flexible-xconnect-services"):
                if (self.flexible_xconnect_services is None):
                    self.flexible_xconnect_services = L2Vpnv2.Active.FlexibleXconnectServices()
                    self.flexible_xconnect_services.parent = self
                    self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"
                return self.flexible_xconnect_services

            if (child_yang_name == "g8032"):
                if (self.g8032 is None):
                    self.g8032 = L2Vpnv2.Active.G8032()
                    self.g8032.parent = self
                    self._children_name_map["g8032"] = "g8032"
                return self.g8032

            if (child_yang_name == "generic-interface-list-details"):
                if (self.generic_interface_list_details is None):
                    self.generic_interface_list_details = L2Vpnv2.Active.GenericInterfaceListDetails()
                    self.generic_interface_list_details.parent = self
                    self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"
                return self.generic_interface_list_details

            if (child_yang_name == "generic-interfaces"):
                if (self.generic_interfaces is None):
                    self.generic_interfaces = L2Vpnv2.Active.GenericInterfaces()
                    self.generic_interfaces.parent = self
                    self._children_name_map["generic_interfaces"] = "generic-interfaces"
                return self.generic_interfaces

            if (child_yang_name == "global-settings"):
                if (self.global_settings is None):
                    self.global_settings = L2Vpnv2.Active.GlobalSettings()
                    self.global_settings.parent = self
                    self._children_name_map["global_settings"] = "global-settings"
                return self.global_settings

            if (child_yang_name == "iccp-sm"):
                if (self.iccp_sm is None):
                    self.iccp_sm = L2Vpnv2.Active.IccpSm()
                    self.iccp_sm.parent = self
                    self._children_name_map["iccp_sm"] = "iccp-sm"
                return self.iccp_sm

            if (child_yang_name == "indexes"):
                if (self.indexes is None):
                    self.indexes = L2Vpnv2.Active.Indexes()
                    self.indexes.parent = self
                    self._children_name_map["indexes"] = "indexes"
                return self.indexes

            if (child_yang_name == "l2vpn-collaborators"):
                if (self.l2vpn_collaborators is None):
                    self.l2vpn_collaborators = L2Vpnv2.Active.L2VpnCollaborators()
                    self.l2vpn_collaborators.parent = self
                    self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"
                return self.l2vpn_collaborators

            if (child_yang_name == "l2vpn-pbb-bsa"):
                if (self.l2vpn_pbb_bsa is None):
                    self.l2vpn_pbb_bsa = L2Vpnv2.Active.L2VpnPbbBsa()
                    self.l2vpn_pbb_bsa.parent = self
                    self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"
                return self.l2vpn_pbb_bsa

            if (child_yang_name == "l2vpn-resource-state"):
                if (self.l2vpn_resource_state is None):
                    self.l2vpn_resource_state = L2Vpnv2.Active.L2VpnResourceState()
                    self.l2vpn_resource_state.parent = self
                    self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"
                return self.l2vpn_resource_state

            if (child_yang_name == "main-interfaces"):
                if (self.main_interfaces is None):
                    self.main_interfaces = L2Vpnv2.Active.MainInterfaces()
                    self.main_interfaces.parent = self
                    self._children_name_map["main_interfaces"] = "main-interfaces"
                return self.main_interfaces

            if (child_yang_name == "mstp-ports"):
                if (self.mstp_ports is None):
                    self.mstp_ports = L2Vpnv2.Active.MstpPorts()
                    self.mstp_ports.parent = self
                    self._children_name_map["mstp_ports"] = "mstp-ports"
                return self.mstp_ports

            if (child_yang_name == "mstp-vlans"):
                if (self.mstp_vlans is None):
                    self.mstp_vlans = L2Vpnv2.Active.MstpVlans()
                    self.mstp_vlans.parent = self
                    self._children_name_map["mstp_vlans"] = "mstp-vlans"
                return self.mstp_vlans

            if (child_yang_name == "mvrp"):
                if (self.mvrp is None):
                    self.mvrp = L2Vpnv2.Active.Mvrp()
                    self.mvrp.parent = self
                    self._children_name_map["mvrp"] = "mvrp"
                return self.mvrp

            if (child_yang_name == "nsr"):
                if (self.nsr is None):
                    self.nsr = L2Vpnv2.Active.Nsr()
                    self.nsr.parent = self
                    self._children_name_map["nsr"] = "nsr"
                return self.nsr

            if (child_yang_name == "proc-fsm"):
                if (self.proc_fsm is None):
                    self.proc_fsm = L2Vpnv2.Active.ProcFsm()
                    self.proc_fsm.parent = self
                    self._children_name_map["proc_fsm"] = "proc-fsm"
                return self.proc_fsm

            if (child_yang_name == "pseudowire-classes"):
                if (self.pseudowire_classes is None):
                    self.pseudowire_classes = L2Vpnv2.Active.PseudowireClasses()
                    self.pseudowire_classes.parent = self
                    self._children_name_map["pseudowire_classes"] = "pseudowire-classes"
                return self.pseudowire_classes

            if (child_yang_name == "pwr"):
                if (self.pwr is None):
                    self.pwr = L2Vpnv2.Active.Pwr()
                    self.pwr.parent = self
                    self._children_name_map["pwr"] = "pwr"
                return self.pwr

            if (child_yang_name == "xconnect-brief"):
                if (self.xconnect_brief is None):
                    self.xconnect_brief = L2Vpnv2.Active.XconnectBrief()
                    self.xconnect_brief.parent = self
                    self._children_name_map["xconnect_brief"] = "xconnect-brief"
                return self.xconnect_brief

            if (child_yang_name == "xconnect-groups"):
                if (self.xconnect_groups is None):
                    self.xconnect_groups = L2Vpnv2.Active.XconnectGroups()
                    self.xconnect_groups.parent = self
                    self._children_name_map["xconnect_groups"] = "xconnect-groups"
                return self.xconnect_groups

            if (child_yang_name == "xconnect-mp2mp-ce2ces"):
                if (self.xconnect_mp2mp_ce2ces is None):
                    self.xconnect_mp2mp_ce2ces = L2Vpnv2.Active.XconnectMp2MpCe2Ces()
                    self.xconnect_mp2mp_ce2ces.parent = self
                    self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"
                return self.xconnect_mp2mp_ce2ces

            if (child_yang_name == "xconnect-mp2mps"):
                if (self.xconnect_mp2mps is None):
                    self.xconnect_mp2mps = L2Vpnv2.Active.XconnectMp2Mps()
                    self.xconnect_mp2mps.parent = self
                    self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"
                return self.xconnect_mp2mps

            if (child_yang_name == "xconnect-summary"):
                if (self.xconnect_summary is None):
                    self.xconnect_summary = L2Vpnv2.Active.XconnectSummary()
                    self.xconnect_summary.parent = self
                    self._children_name_map["xconnect_summary"] = "xconnect-summary"
                return self.xconnect_summary

            if (child_yang_name == "xconnects"):
                if (self.xconnects is None):
                    self.xconnects = L2Vpnv2.Active.Xconnects()
                    self.xconnects.parent = self
                    self._children_name_map["xconnects"] = "xconnects"
                return self.xconnects

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bridge-domains" or name == "bridge-summary" or name == "discoveries" or name == "discovery-summary" or name == "flexible-xconnect-service-summary" or name == "flexible-xconnect-services" or name == "g8032" or name == "generic-interface-list-details" or name == "generic-interfaces" or name == "global-settings" or name == "iccp-sm" or name == "indexes" or name == "l2vpn-collaborators" or name == "l2vpn-pbb-bsa" or name == "l2vpn-resource-state" or name == "main-interfaces" or name == "mstp-ports" or name == "mstp-vlans" or name == "mvrp" or name == "nsr" or name == "proc-fsm" or name == "pseudowire-classes" or name == "pwr" or name == "xconnect-brief" or name == "xconnect-groups" or name == "xconnect-mp2mp-ce2ces" or name == "xconnect-mp2mps" or name == "xconnect-summary" or name == "xconnects"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Nodes(Entity):
        """
        Table of L2VPN operational data for a particular
        node
        
        .. attribute:: node
        
        	L2VPN operational data for a particular node
        	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpnv2.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "l2vpnv2"

            self.node = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpnv2.Nodes, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpnv2.Nodes, self).__setattr__(name, value)


        class Node(Entity):
            """
            L2VPN operational data for a particular node
            
            .. attribute:: node_id  <key>
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: bridge_domains
            
            	VPLS Bridge Domain Information
            	**type**\:   :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains>`
            
            .. attribute:: bridge_summary
            
            	Bridge Domain summary information
            	**type**\:   :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeSummary>`
            
            .. attribute:: discoveries
            
            	Discovery Table
            	**type**\:   :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries>`
            
            .. attribute:: discovery_summary
            
            	Discovery summary information
            	**type**\:   :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.DiscoverySummary>`
            
            .. attribute:: flexible_xconnect_service_summary
            
            	Flexible XConnect Service summary information
            	**type**\:   :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServiceSummary>`
            
            .. attribute:: flexible_xconnect_services
            
            	Flexible XConnect Service Table
            	**type**\:   :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices>`
            
            .. attribute:: g8032
            
            	G8032 information
            	**type**\:   :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032>`
            
            .. attribute:: generic_interface_list_details
            
            	L2VPN generic interface list Detail Table
            	**type**\:   :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails>`
            
            .. attribute:: generic_interfaces
            
            	L2VPN generic interface list Table
            	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaces>`
            
            .. attribute:: global_settings
            
            	L2VPN global settings
            	**type**\:   :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GlobalSettings>`
            
            .. attribute:: iccp_sm
            
            	ICCP\-based Service Multi\-homing operational data
            	**type**\:   :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm>`
            
            .. attribute:: indexes
            
            	ID Manager Index Table
            	**type**\:   :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Indexes>`
            
            .. attribute:: l2vpn_collaborators
            
            	L2VPN collaborator information
            	**type**\:   :py:class:`L2VpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.L2VpnCollaborators>`
            
            .. attribute:: l2vpn_pbb_bsa
            
            	L2VPN PBB Backbone Source MAC information
            	**type**\:   :py:class:`L2VpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.L2VpnPbbBsa>`
            
            .. attribute:: l2vpn_resource_state
            
            	L2VPN resource state information
            	**type**\:   :py:class:`L2VpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.L2VpnResourceState>`
            
            .. attribute:: main_interfaces
            
            	Main Interface
            	**type**\:   :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces>`
            
            .. attribute:: mstp_ports
            
            	L2VPN MSTP Port Table
            	**type**\:   :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpPorts>`
            
            .. attribute:: mstp_vlans
            
            	L2VPN MSTP VLAN Table
            	**type**\:   :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpVlans>`
            
            .. attribute:: mvrp
            
            	MVRP
            	**type**\:   :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp>`
            
            .. attribute:: nsr
            
            	L2VPN NSR information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr>`
            
            .. attribute:: proc_fsm
            
            	L2VPN Process FSM information
            	**type**\:   :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm>`
            
            .. attribute:: pseudowire_classes
            
            	List of pseudowire classes
            	**type**\:   :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses>`
            
            .. attribute:: pwr
            
            	Pseudowire Routing Table
            	**type**\:   :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr>`
            
            .. attribute:: xconnect_brief
            
            	XConnect brief information
            	**type**\:   :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectBrief>`
            
            .. attribute:: xconnect_groups
            
            	XConnect group Table
            	**type**\:   :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectGroups>`
            
            .. attribute:: xconnect_mp2mp_ce2ces
            
            	XConnect MP2MP CE2CE Table
            	**type**\:   :py:class:`XconnectMp2MpCe2Ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces>`
            
            .. attribute:: xconnect_mp2mps
            
            	XConnect MP2MP Table
            	**type**\:   :py:class:`XconnectMp2Mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps>`
            
            .. attribute:: xconnect_summary
            
            	XConnect summary information
            	**type**\:   :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectSummary>`
            
            .. attribute:: xconnects
            
            	XConnect Table
            	**type**\:   :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpnv2.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"

                self.node_id = YLeaf(YType.str, "node-id")

                self.bridge_domains = L2Vpnv2.Nodes.Node.BridgeDomains()
                self.bridge_domains.parent = self
                self._children_name_map["bridge_domains"] = "bridge-domains"
                self._children_yang_names.add("bridge-domains")

                self.bridge_summary = L2Vpnv2.Nodes.Node.BridgeSummary()
                self.bridge_summary.parent = self
                self._children_name_map["bridge_summary"] = "bridge-summary"
                self._children_yang_names.add("bridge-summary")

                self.discoveries = L2Vpnv2.Nodes.Node.Discoveries()
                self.discoveries.parent = self
                self._children_name_map["discoveries"] = "discoveries"
                self._children_yang_names.add("discoveries")

                self.discovery_summary = L2Vpnv2.Nodes.Node.DiscoverySummary()
                self.discovery_summary.parent = self
                self._children_name_map["discovery_summary"] = "discovery-summary"
                self._children_yang_names.add("discovery-summary")

                self.flexible_xconnect_service_summary = L2Vpnv2.Nodes.Node.FlexibleXconnectServiceSummary()
                self.flexible_xconnect_service_summary.parent = self
                self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"
                self._children_yang_names.add("flexible-xconnect-service-summary")

                self.flexible_xconnect_services = L2Vpnv2.Nodes.Node.FlexibleXconnectServices()
                self.flexible_xconnect_services.parent = self
                self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"
                self._children_yang_names.add("flexible-xconnect-services")

                self.g8032 = L2Vpnv2.Nodes.Node.G8032()
                self.g8032.parent = self
                self._children_name_map["g8032"] = "g8032"
                self._children_yang_names.add("g8032")

                self.generic_interface_list_details = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails()
                self.generic_interface_list_details.parent = self
                self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"
                self._children_yang_names.add("generic-interface-list-details")

                self.generic_interfaces = L2Vpnv2.Nodes.Node.GenericInterfaces()
                self.generic_interfaces.parent = self
                self._children_name_map["generic_interfaces"] = "generic-interfaces"
                self._children_yang_names.add("generic-interfaces")

                self.global_settings = L2Vpnv2.Nodes.Node.GlobalSettings()
                self.global_settings.parent = self
                self._children_name_map["global_settings"] = "global-settings"
                self._children_yang_names.add("global-settings")

                self.iccp_sm = L2Vpnv2.Nodes.Node.IccpSm()
                self.iccp_sm.parent = self
                self._children_name_map["iccp_sm"] = "iccp-sm"
                self._children_yang_names.add("iccp-sm")

                self.indexes = L2Vpnv2.Nodes.Node.Indexes()
                self.indexes.parent = self
                self._children_name_map["indexes"] = "indexes"
                self._children_yang_names.add("indexes")

                self.l2vpn_collaborators = L2Vpnv2.Nodes.Node.L2VpnCollaborators()
                self.l2vpn_collaborators.parent = self
                self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"
                self._children_yang_names.add("l2vpn-collaborators")

                self.l2vpn_pbb_bsa = L2Vpnv2.Nodes.Node.L2VpnPbbBsa()
                self.l2vpn_pbb_bsa.parent = self
                self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"
                self._children_yang_names.add("l2vpn-pbb-bsa")

                self.l2vpn_resource_state = L2Vpnv2.Nodes.Node.L2VpnResourceState()
                self.l2vpn_resource_state.parent = self
                self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"
                self._children_yang_names.add("l2vpn-resource-state")

                self.main_interfaces = L2Vpnv2.Nodes.Node.MainInterfaces()
                self.main_interfaces.parent = self
                self._children_name_map["main_interfaces"] = "main-interfaces"
                self._children_yang_names.add("main-interfaces")

                self.mstp_ports = L2Vpnv2.Nodes.Node.MstpPorts()
                self.mstp_ports.parent = self
                self._children_name_map["mstp_ports"] = "mstp-ports"
                self._children_yang_names.add("mstp-ports")

                self.mstp_vlans = L2Vpnv2.Nodes.Node.MstpVlans()
                self.mstp_vlans.parent = self
                self._children_name_map["mstp_vlans"] = "mstp-vlans"
                self._children_yang_names.add("mstp-vlans")

                self.mvrp = L2Vpnv2.Nodes.Node.Mvrp()
                self.mvrp.parent = self
                self._children_name_map["mvrp"] = "mvrp"
                self._children_yang_names.add("mvrp")

                self.nsr = L2Vpnv2.Nodes.Node.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.proc_fsm = L2Vpnv2.Nodes.Node.ProcFsm()
                self.proc_fsm.parent = self
                self._children_name_map["proc_fsm"] = "proc-fsm"
                self._children_yang_names.add("proc-fsm")

                self.pseudowire_classes = L2Vpnv2.Nodes.Node.PseudowireClasses()
                self.pseudowire_classes.parent = self
                self._children_name_map["pseudowire_classes"] = "pseudowire-classes"
                self._children_yang_names.add("pseudowire-classes")

                self.pwr = L2Vpnv2.Nodes.Node.Pwr()
                self.pwr.parent = self
                self._children_name_map["pwr"] = "pwr"
                self._children_yang_names.add("pwr")

                self.xconnect_brief = L2Vpnv2.Nodes.Node.XconnectBrief()
                self.xconnect_brief.parent = self
                self._children_name_map["xconnect_brief"] = "xconnect-brief"
                self._children_yang_names.add("xconnect-brief")

                self.xconnect_groups = L2Vpnv2.Nodes.Node.XconnectGroups()
                self.xconnect_groups.parent = self
                self._children_name_map["xconnect_groups"] = "xconnect-groups"
                self._children_yang_names.add("xconnect-groups")

                self.xconnect_mp2mp_ce2ces = L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces()
                self.xconnect_mp2mp_ce2ces.parent = self
                self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"
                self._children_yang_names.add("xconnect-mp2mp-ce2ces")

                self.xconnect_mp2mps = L2Vpnv2.Nodes.Node.XconnectMp2Mps()
                self.xconnect_mp2mps.parent = self
                self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"
                self._children_yang_names.add("xconnect-mp2mps")

                self.xconnect_summary = L2Vpnv2.Nodes.Node.XconnectSummary()
                self.xconnect_summary.parent = self
                self._children_name_map["xconnect_summary"] = "xconnect-summary"
                self._children_yang_names.add("xconnect-summary")

                self.xconnects = L2Vpnv2.Nodes.Node.Xconnects()
                self.xconnects.parent = self
                self._children_name_map["xconnects"] = "xconnects"
                self._children_yang_names.add("xconnects")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("node_id") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpnv2.Nodes.Node, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpnv2.Nodes.Node, self).__setattr__(name, value)


            class Discoveries(Entity):
                """
                Discovery Table
                
                .. attribute:: discovery
                
                	VPLS Discovery information
                	**type**\: list of    :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.Discoveries, self).__init__()

                    self.yang_name = "discoveries"
                    self.yang_parent_name = "node"

                    self.discovery = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.Discoveries, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.Discoveries, self).__setattr__(name, value)


                class Discovery(Entity):
                    """
                    VPLS Discovery information
                    
                    .. attribute:: group_name
                    
                    	Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: is_service_connected
                    
                    	Is the service connected
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatch_ignore
                    
                    	Ignore MTU Mismatch
                    	**type**\:  bool
                    
                    .. attribute:: number_vpn
                    
                    	Number of vpns
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: service_name
                    
                    	Service type
                    	**type**\:   :py:class:`L2VpnService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnService>`
                    
                    .. attribute:: service_name_xr
                    
                    	Service Type
                    	**type**\:  str
                    
                    .. attribute:: signalling_info
                    
                    	Info about signalling protocol
                    	**type**\:   :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo>`
                    
                    .. attribute:: vpn_id
                    
                    	VPN id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_name
                    
                    	VPN Name
                    	**type**\:  str
                    
                    	**length:** 1..27
                    
                    .. attribute:: vpn_name_xr
                    
                    	VPN instance name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Discoveries.Discovery, self).__init__()

                        self.yang_name = "discovery"
                        self.yang_parent_name = "discoveries"

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                        self.is_service_connected = YLeaf(YType.boolean, "is-service-connected")

                        self.mtu_mismatch_ignore = YLeaf(YType.boolean, "mtu-mismatch-ignore")

                        self.number_vpn = YLeaf(YType.uint32, "number-vpn")

                        self.service_name = YLeaf(YType.enumeration, "service-name")

                        self.service_name_xr = YLeaf(YType.str, "service-name-xr")

                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                        self.vpn_name = YLeaf(YType.str, "vpn-name")

                        self.vpn_name_xr = YLeaf(YType.str, "vpn-name-xr")

                        self.signalling_info = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo()
                        self.signalling_info.parent = self
                        self._children_name_map["signalling_info"] = "signalling-info"
                        self._children_yang_names.add("signalling-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_name",
                                        "group_name_xr",
                                        "is_service_connected",
                                        "mtu_mismatch_ignore",
                                        "number_vpn",
                                        "service_name",
                                        "service_name_xr",
                                        "vpn_id",
                                        "vpn_name",
                                        "vpn_name_xr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery, self).__setattr__(name, value)


                    class SignallingInfo(Entity):
                        """
                        Info about signalling protocol
                        
                        .. attribute:: ad_signalling_method
                        
                        	ADSignallingMethod
                        	**type**\:   :py:class:`L2VpnAdSigMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdSigMethod>`
                        
                        .. attribute:: bgp_sig_info
                        
                        	bgp sig info
                        	**type**\:   :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                        
                        .. attribute:: ldp_sig_info
                        
                        	ldp sig info
                        	**type**\:   :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo, self).__init__()

                            self.yang_name = "signalling-info"
                            self.yang_parent_name = "discovery"

                            self.ad_signalling_method = YLeaf(YType.enumeration, "ad-signalling-method")

                            self.bgp_sig_info = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                            self.bgp_sig_info.parent = self
                            self._children_name_map["bgp_sig_info"] = "bgp-sig-info"
                            self._children_yang_names.add("bgp-sig-info")

                            self.ldp_sig_info = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                            self.ldp_sig_info.parent = self
                            self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                            self._children_yang_names.add("ldp-sig-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_signalling_method") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo, self).__setattr__(name, value)


                        class BgpSigInfo(Entity):
                            """
                            bgp sig info
                            
                            .. attribute:: edge
                            
                            	List of edge ids
                            	**type**\: list of    :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                            
                            .. attribute:: number_edges
                            
                            	Number of Edges
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_remote_edges
                            
                            	Number of remote Edges
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redge
                            
                            	List of edge ids
                            	**type**\: list of    :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__init__()

                                self.yang_name = "bgp-sig-info"
                                self.yang_parent_name = "signalling-info"

                                self.number_edges = YLeaf(YType.uint32, "number-edges")

                                self.number_remote_edges = YLeaf(YType.uint32, "number-remote-edges")

                                self.edge = YList(self)
                                self.redge = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("number_edges",
                                                "number_remote_edges") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__setattr__(name, value)


                            class Edge(Entity):
                                """
                                List of edge ids
                                
                                .. attribute:: edge_id
                                
                                	Edge ids
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_block
                                
                                	List of label blocks
                                	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                                
                                .. attribute:: label_count
                                
                                	Number of label blocks
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__init__()

                                    self.yang_name = "edge"
                                    self.yang_parent_name = "bgp-sig-info"

                                    self.edge_id = YLeaf(YType.uint32, "edge-id")

                                    self.label_count = YLeaf(YType.uint32, "label-count")

                                    self.label_block = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("edge_id",
                                                    "label_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__setattr__(name, value)


                                class LabelBlock(Entity):
                                    """
                                    List of label blocks
                                    
                                    .. attribute:: block_offset
                                    
                                    	Block offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: block_size
                                    
                                    	Block size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_base
                                    
                                    	Label Base
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_error
                                    
                                    	Label Error
                                    	**type**\:   :py:class:`L2VpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErr>`
                                    
                                    .. attribute:: label_time_created
                                    
                                    	Creation time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_edge_id
                                    
                                    	Local edge ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	 Peer id
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: status_vector
                                    
                                    	Status Vector
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__init__()

                                        self.yang_name = "label-block"
                                        self.yang_parent_name = "edge"

                                        self.block_offset = YLeaf(YType.uint32, "block-offset")

                                        self.block_size = YLeaf(YType.uint32, "block-size")

                                        self.label_base = YLeaf(YType.uint32, "label-base")

                                        self.label_error = YLeaf(YType.enumeration, "label-error")

                                        self.label_time_created = YLeaf(YType.uint32, "label-time-created")

                                        self.local_edge_id = YLeaf(YType.uint32, "local-edge-id")

                                        self.next_hop = YLeaf(YType.str, "next-hop")

                                        self.status_vector = YLeafList(YType.uint8, "status-vector")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("block_offset",
                                                        "block_size",
                                                        "label_base",
                                                        "label_error",
                                                        "label_time_created",
                                                        "local_edge_id",
                                                        "next_hop",
                                                        "status_vector") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__setattr__(name, value)

                                    def has_data(self):
                                        for leaf in self.status_vector.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.block_offset.is_set or
                                            self.block_size.is_set or
                                            self.label_base.is_set or
                                            self.label_error.is_set or
                                            self.label_time_created.is_set or
                                            self.local_edge_id.is_set or
                                            self.next_hop.is_set)

                                    def has_operation(self):
                                        for leaf in self.status_vector.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.block_offset.yfilter != YFilter.not_set or
                                            self.block_size.yfilter != YFilter.not_set or
                                            self.label_base.yfilter != YFilter.not_set or
                                            self.label_error.yfilter != YFilter.not_set or
                                            self.label_time_created.yfilter != YFilter.not_set or
                                            self.local_edge_id.yfilter != YFilter.not_set or
                                            self.next_hop.yfilter != YFilter.not_set or
                                            self.status_vector.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "label-block" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.block_offset.is_set or self.block_offset.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.block_offset.get_name_leafdata())
                                        if (self.block_size.is_set or self.block_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.block_size.get_name_leafdata())
                                        if (self.label_base.is_set or self.label_base.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.label_base.get_name_leafdata())
                                        if (self.label_error.is_set or self.label_error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.label_error.get_name_leafdata())
                                        if (self.label_time_created.is_set or self.label_time_created.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.label_time_created.get_name_leafdata())
                                        if (self.local_edge_id.is_set or self.local_edge_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_edge_id.get_name_leafdata())
                                        if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop.get_name_leafdata())

                                        leaf_name_data.extend(self.status_vector.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "block-offset" or name == "block-size" or name == "label-base" or name == "label-error" or name == "label-time-created" or name == "local-edge-id" or name == "next-hop" or name == "status-vector"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "block-offset"):
                                            self.block_offset = value
                                            self.block_offset.value_namespace = name_space
                                            self.block_offset.value_namespace_prefix = name_space_prefix
                                        if(value_path == "block-size"):
                                            self.block_size = value
                                            self.block_size.value_namespace = name_space
                                            self.block_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "label-base"):
                                            self.label_base = value
                                            self.label_base.value_namespace = name_space
                                            self.label_base.value_namespace_prefix = name_space_prefix
                                        if(value_path == "label-error"):
                                            self.label_error = value
                                            self.label_error.value_namespace = name_space
                                            self.label_error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "label-time-created"):
                                            self.label_time_created = value
                                            self.label_time_created.value_namespace = name_space
                                            self.label_time_created.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-edge-id"):
                                            self.local_edge_id = value
                                            self.local_edge_id.value_namespace = name_space
                                            self.local_edge_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop"):
                                            self.next_hop = value
                                            self.next_hop.value_namespace = name_space
                                            self.next_hop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "status-vector"):
                                            self.status_vector.append(value)

                                def has_data(self):
                                    for c in self.label_block:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.edge_id.is_set or
                                        self.label_count.is_set)

                                def has_operation(self):
                                    for c in self.label_block:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.edge_id.yfilter != YFilter.not_set or
                                        self.label_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "edge" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.edge_id.is_set or self.edge_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.edge_id.get_name_leafdata())
                                    if (self.label_count.is_set or self.label_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "label-block"):
                                        for c in self.label_block:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.label_block.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "label-block" or name == "edge-id" or name == "label-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "edge-id"):
                                        self.edge_id = value
                                        self.edge_id.value_namespace = name_space
                                        self.edge_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-count"):
                                        self.label_count = value
                                        self.label_count.value_namespace = name_space
                                        self.label_count.value_namespace_prefix = name_space_prefix


                            class Redge(Entity):
                                """
                                List of edge ids
                                
                                .. attribute:: edge_id
                                
                                	Edge ids
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_block
                                
                                	List of label blocks
                                	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                                
                                .. attribute:: label_count
                                
                                	Number of label blocks
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__init__()

                                    self.yang_name = "redge"
                                    self.yang_parent_name = "bgp-sig-info"

                                    self.edge_id = YLeaf(YType.uint32, "edge-id")

                                    self.label_count = YLeaf(YType.uint32, "label-count")

                                    self.label_block = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("edge_id",
                                                    "label_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__setattr__(name, value)


                                class LabelBlock(Entity):
                                    """
                                    List of label blocks
                                    
                                    .. attribute:: block_offset
                                    
                                    	Block offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: block_size
                                    
                                    	Block size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_base
                                    
                                    	Label Base
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_error
                                    
                                    	Label Error
                                    	**type**\:   :py:class:`L2VpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErr>`
                                    
                                    .. attribute:: label_time_created
                                    
                                    	Creation time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_edge_id
                                    
                                    	Local edge ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	 Peer id
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: status_vector
                                    
                                    	Status Vector
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__init__()

                                        self.yang_name = "label-block"
                                        self.yang_parent_name = "redge"

                                        self.block_offset = YLeaf(YType.uint32, "block-offset")

                                        self.block_size = YLeaf(YType.uint32, "block-size")

                                        self.label_base = YLeaf(YType.uint32, "label-base")

                                        self.label_error = YLeaf(YType.enumeration, "label-error")

                                        self.label_time_created = YLeaf(YType.uint32, "label-time-created")

                                        self.local_edge_id = YLeaf(YType.uint32, "local-edge-id")

                                        self.next_hop = YLeaf(YType.str, "next-hop")

                                        self.status_vector = YLeafList(YType.uint8, "status-vector")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("block_offset",
                                                        "block_size",
                                                        "label_base",
                                                        "label_error",
                                                        "label_time_created",
                                                        "local_edge_id",
                                                        "next_hop",
                                                        "status_vector") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__setattr__(name, value)

                                    def has_data(self):
                                        for leaf in self.status_vector.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.block_offset.is_set or
                                            self.block_size.is_set or
                                            self.label_base.is_set or
                                            self.label_error.is_set or
                                            self.label_time_created.is_set or
                                            self.local_edge_id.is_set or
                                            self.next_hop.is_set)

                                    def has_operation(self):
                                        for leaf in self.status_vector.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.block_offset.yfilter != YFilter.not_set or
                                            self.block_size.yfilter != YFilter.not_set or
                                            self.label_base.yfilter != YFilter.not_set or
                                            self.label_error.yfilter != YFilter.not_set or
                                            self.label_time_created.yfilter != YFilter.not_set or
                                            self.local_edge_id.yfilter != YFilter.not_set or
                                            self.next_hop.yfilter != YFilter.not_set or
                                            self.status_vector.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "label-block" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.block_offset.is_set or self.block_offset.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.block_offset.get_name_leafdata())
                                        if (self.block_size.is_set or self.block_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.block_size.get_name_leafdata())
                                        if (self.label_base.is_set or self.label_base.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.label_base.get_name_leafdata())
                                        if (self.label_error.is_set or self.label_error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.label_error.get_name_leafdata())
                                        if (self.label_time_created.is_set or self.label_time_created.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.label_time_created.get_name_leafdata())
                                        if (self.local_edge_id.is_set or self.local_edge_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_edge_id.get_name_leafdata())
                                        if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop.get_name_leafdata())

                                        leaf_name_data.extend(self.status_vector.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "block-offset" or name == "block-size" or name == "label-base" or name == "label-error" or name == "label-time-created" or name == "local-edge-id" or name == "next-hop" or name == "status-vector"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "block-offset"):
                                            self.block_offset = value
                                            self.block_offset.value_namespace = name_space
                                            self.block_offset.value_namespace_prefix = name_space_prefix
                                        if(value_path == "block-size"):
                                            self.block_size = value
                                            self.block_size.value_namespace = name_space
                                            self.block_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "label-base"):
                                            self.label_base = value
                                            self.label_base.value_namespace = name_space
                                            self.label_base.value_namespace_prefix = name_space_prefix
                                        if(value_path == "label-error"):
                                            self.label_error = value
                                            self.label_error.value_namespace = name_space
                                            self.label_error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "label-time-created"):
                                            self.label_time_created = value
                                            self.label_time_created.value_namespace = name_space
                                            self.label_time_created.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-edge-id"):
                                            self.local_edge_id = value
                                            self.local_edge_id.value_namespace = name_space
                                            self.local_edge_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop"):
                                            self.next_hop = value
                                            self.next_hop.value_namespace = name_space
                                            self.next_hop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "status-vector"):
                                            self.status_vector.append(value)

                                def has_data(self):
                                    for c in self.label_block:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.edge_id.is_set or
                                        self.label_count.is_set)

                                def has_operation(self):
                                    for c in self.label_block:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.edge_id.yfilter != YFilter.not_set or
                                        self.label_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "redge" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.edge_id.is_set or self.edge_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.edge_id.get_name_leafdata())
                                    if (self.label_count.is_set or self.label_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.label_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "label-block"):
                                        for c in self.label_block:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.label_block.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "label-block" or name == "edge-id" or name == "label-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "edge-id"):
                                        self.edge_id = value
                                        self.edge_id.value_namespace = name_space
                                        self.edge_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "label-count"):
                                        self.label_count = value
                                        self.label_count.value_namespace = name_space
                                        self.label_count.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.edge:
                                    if (c.has_data()):
                                        return True
                                for c in self.redge:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.number_edges.is_set or
                                    self.number_remote_edges.is_set)

                            def has_operation(self):
                                for c in self.edge:
                                    if (c.has_operation()):
                                        return True
                                for c in self.redge:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.number_edges.yfilter != YFilter.not_set or
                                    self.number_remote_edges.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bgp-sig-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.number_edges.is_set or self.number_edges.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_edges.get_name_leafdata())
                                if (self.number_remote_edges.is_set or self.number_remote_edges.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_remote_edges.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "edge"):
                                    for c in self.edge:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.edge.append(c)
                                    return c

                                if (child_yang_name == "redge"):
                                    for c in self.redge:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.redge.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "edge" or name == "redge" or name == "number-edges" or name == "number-remote-edges"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "number-edges"):
                                    self.number_edges = value
                                    self.number_edges.value_namespace = name_space
                                    self.number_edges.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-remote-edges"):
                                    self.number_remote_edges = value
                                    self.number_remote_edges.value_namespace = name_space
                                    self.number_remote_edges.value_namespace_prefix = name_space_prefix


                        class LdpSigInfo(Entity):
                            """
                            ldp sig info
                            
                            .. attribute:: local_l2_router_id
                            
                            	Local L2VPN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_vpls_id
                            
                            	Local VPLS\-ID
                            	**type**\:   :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                            
                            .. attribute:: number_remote_edges
                            
                            	Number of remote Edges
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_nlri
                            
                            	List of NLRIs
                            	**type**\: list of    :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__init__()

                                self.yang_name = "ldp-sig-info"
                                self.yang_parent_name = "signalling-info"

                                self.local_l2_router_id = YLeaf(YType.str, "local-l2-router-id")

                                self.number_remote_edges = YLeaf(YType.uint32, "number-remote-edges")

                                self.local_vpls_id = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                                self.local_vpls_id.parent = self
                                self._children_name_map["local_vpls_id"] = "local-vpls-id"
                                self._children_yang_names.add("local-vpls-id")

                                self.remote_nlri = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_l2_router_id",
                                                "number_remote_edges") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__setattr__(name, value)


                            class LocalVplsId(Entity):
                                """
                                Local VPLS\-ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__init__()

                                    self.yang_name = "local-vpls-id"
                                    self.yang_parent_name = "ldp-sig-info"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "local-vpls-id"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "local-vpls-id"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "local-vpls-id"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-vpls-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class RemoteNlri(Entity):
                                """
                                List of NLRIs
                                
                                .. attribute:: local_address
                                
                                	Local BGP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: nlri_time_created
                                
                                	NLRI creation time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote BGP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_l2_router_id
                                
                                	Remote L2VPN Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__init__()

                                    self.yang_name = "remote-nlri"
                                    self.yang_parent_name = "ldp-sig-info"

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.nlri_time_created = YLeaf(YType.uint32, "nlri-time-created")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                    self.remote_l2_router_id = YLeaf(YType.str, "remote-l2-router-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_address",
                                                    "nlri_time_created",
                                                    "remote_address",
                                                    "remote_l2_router_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_address.is_set or
                                        self.nlri_time_created.is_set or
                                        self.remote_address.is_set or
                                        self.remote_l2_router_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.nlri_time_created.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set or
                                        self.remote_l2_router_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-nlri" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.nlri_time_created.is_set or self.nlri_time_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nlri_time_created.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())
                                    if (self.remote_l2_router_id.is_set or self.remote_l2_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_l2_router_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-address" or name == "nlri-time-created" or name == "remote-address" or name == "remote-l2-router-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nlri-time-created"):
                                        self.nlri_time_created = value
                                        self.nlri_time_created.value_namespace = name_space
                                        self.nlri_time_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-l2-router-id"):
                                        self.remote_l2_router_id = value
                                        self.remote_l2_router_id.value_namespace = name_space
                                        self.remote_l2_router_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.remote_nlri:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.local_l2_router_id.is_set or
                                    self.number_remote_edges.is_set or
                                    (self.local_vpls_id is not None and self.local_vpls_id.has_data()))

                            def has_operation(self):
                                for c in self.remote_nlri:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_l2_router_id.yfilter != YFilter.not_set or
                                    self.number_remote_edges.yfilter != YFilter.not_set or
                                    (self.local_vpls_id is not None and self.local_vpls_id.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ldp-sig-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_l2_router_id.is_set or self.local_l2_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_l2_router_id.get_name_leafdata())
                                if (self.number_remote_edges.is_set or self.number_remote_edges.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_remote_edges.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-vpls-id"):
                                    if (self.local_vpls_id is None):
                                        self.local_vpls_id = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                                        self.local_vpls_id.parent = self
                                        self._children_name_map["local_vpls_id"] = "local-vpls-id"
                                    return self.local_vpls_id

                                if (child_yang_name == "remote-nlri"):
                                    for c in self.remote_nlri:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.remote_nlri.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-vpls-id" or name == "remote-nlri" or name == "local-l2-router-id" or name == "number-remote-edges"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-l2-router-id"):
                                    self.local_l2_router_id = value
                                    self.local_l2_router_id.value_namespace = name_space
                                    self.local_l2_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-remote-edges"):
                                    self.number_remote_edges = value
                                    self.number_remote_edges.value_namespace = name_space
                                    self.number_remote_edges.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_signalling_method.is_set or
                                (self.bgp_sig_info is not None and self.bgp_sig_info.has_data()) or
                                (self.ldp_sig_info is not None and self.ldp_sig_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_signalling_method.yfilter != YFilter.not_set or
                                (self.bgp_sig_info is not None and self.bgp_sig_info.has_operation()) or
                                (self.ldp_sig_info is not None and self.ldp_sig_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "signalling-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bgp-sig-info"):
                                if (self.bgp_sig_info is None):
                                    self.bgp_sig_info = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                                    self.bgp_sig_info.parent = self
                                    self._children_name_map["bgp_sig_info"] = "bgp-sig-info"
                                return self.bgp_sig_info

                            if (child_yang_name == "ldp-sig-info"):
                                if (self.ldp_sig_info is None):
                                    self.ldp_sig_info = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                                    self.ldp_sig_info.parent = self
                                    self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                                return self.ldp_sig_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bgp-sig-info" or name == "ldp-sig-info" or name == "ad-signalling-method"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-signalling-method"):
                                self.ad_signalling_method = value
                                self.ad_signalling_method.value_namespace = name_space
                                self.ad_signalling_method.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_name.is_set or
                            self.group_name_xr.is_set or
                            self.is_service_connected.is_set or
                            self.mtu_mismatch_ignore.is_set or
                            self.number_vpn.is_set or
                            self.service_name.is_set or
                            self.service_name_xr.is_set or
                            self.vpn_id.is_set or
                            self.vpn_name.is_set or
                            self.vpn_name_xr.is_set or
                            (self.signalling_info is not None and self.signalling_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.group_name_xr.yfilter != YFilter.not_set or
                            self.is_service_connected.yfilter != YFilter.not_set or
                            self.mtu_mismatch_ignore.yfilter != YFilter.not_set or
                            self.number_vpn.yfilter != YFilter.not_set or
                            self.service_name.yfilter != YFilter.not_set or
                            self.service_name_xr.yfilter != YFilter.not_set or
                            self.vpn_id.yfilter != YFilter.not_set or
                            self.vpn_name.yfilter != YFilter.not_set or
                            self.vpn_name_xr.yfilter != YFilter.not_set or
                            (self.signalling_info is not None and self.signalling_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "discovery" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                        if (self.is_service_connected.is_set or self.is_service_connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_service_connected.get_name_leafdata())
                        if (self.mtu_mismatch_ignore.is_set or self.mtu_mismatch_ignore.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_mismatch_ignore.get_name_leafdata())
                        if (self.number_vpn.is_set or self.number_vpn.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_vpn.get_name_leafdata())
                        if (self.service_name.is_set or self.service_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.service_name.get_name_leafdata())
                        if (self.service_name_xr.is_set or self.service_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.service_name_xr.get_name_leafdata())
                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_id.get_name_leafdata())
                        if (self.vpn_name.is_set or self.vpn_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_name.get_name_leafdata())
                        if (self.vpn_name_xr.is_set or self.vpn_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_name_xr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "signalling-info"):
                            if (self.signalling_info is None):
                                self.signalling_info = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo()
                                self.signalling_info.parent = self
                                self._children_name_map["signalling_info"] = "signalling-info"
                            return self.signalling_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "signalling-info" or name == "group-name" or name == "group-name-xr" or name == "is-service-connected" or name == "mtu-mismatch-ignore" or name == "number-vpn" or name == "service-name" or name == "service-name-xr" or name == "vpn-id" or name == "vpn-name" or name == "vpn-name-xr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name-xr"):
                            self.group_name_xr = value
                            self.group_name_xr.value_namespace = name_space
                            self.group_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-service-connected"):
                            self.is_service_connected = value
                            self.is_service_connected.value_namespace = name_space
                            self.is_service_connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-mismatch-ignore"):
                            self.mtu_mismatch_ignore = value
                            self.mtu_mismatch_ignore.value_namespace = name_space
                            self.mtu_mismatch_ignore.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-vpn"):
                            self.number_vpn = value
                            self.number_vpn.value_namespace = name_space
                            self.number_vpn.value_namespace_prefix = name_space_prefix
                        if(value_path == "service-name"):
                            self.service_name = value
                            self.service_name.value_namespace = name_space
                            self.service_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "service-name-xr"):
                            self.service_name_xr = value
                            self.service_name_xr.value_namespace = name_space
                            self.service_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-id"):
                            self.vpn_id = value
                            self.vpn_id.value_namespace = name_space
                            self.vpn_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-name"):
                            self.vpn_name = value
                            self.vpn_name.value_namespace = name_space
                            self.vpn_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-name-xr"):
                            self.vpn_name_xr = value
                            self.vpn_name_xr.value_namespace = name_space
                            self.vpn_name_xr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.discovery:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.discovery:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "discoveries" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "discovery"):
                        for c in self.discovery:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.Discoveries.Discovery()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.discovery.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "discovery"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class FlexibleXconnectServiceSummary(Entity):
                """
                Flexible XConnect Service summary information
                
                .. attribute:: number_fxc
                
                	Number of flexible xconnect services
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_fxc_down
                
                	Number of flexible xconnect services whose state is down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_fxc_up
                
                	Number of flexible xconnect services whose state is up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServiceSummary, self).__init__()

                    self.yang_name = "flexible-xconnect-service-summary"
                    self.yang_parent_name = "node"

                    self.number_fxc = YLeaf(YType.uint32, "number-fxc")

                    self.number_fxc_down = YLeaf(YType.uint32, "number-fxc-down")

                    self.number_fxc_up = YLeaf(YType.uint32, "number-fxc-up")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("number_fxc",
                                    "number_fxc_down",
                                    "number_fxc_up") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServiceSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServiceSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.number_fxc.is_set or
                        self.number_fxc_down.is_set or
                        self.number_fxc_up.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.number_fxc.yfilter != YFilter.not_set or
                        self.number_fxc_down.yfilter != YFilter.not_set or
                        self.number_fxc_up.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flexible-xconnect-service-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.number_fxc.is_set or self.number_fxc.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_fxc.get_name_leafdata())
                    if (self.number_fxc_down.is_set or self.number_fxc_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_fxc_down.get_name_leafdata())
                    if (self.number_fxc_up.is_set or self.number_fxc_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_fxc_up.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "number-fxc" or name == "number-fxc-down" or name == "number-fxc-up"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "number-fxc"):
                        self.number_fxc = value
                        self.number_fxc.value_namespace = name_space
                        self.number_fxc.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-fxc-down"):
                        self.number_fxc_down = value
                        self.number_fxc_down.value_namespace = name_space
                        self.number_fxc_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-fxc-up"):
                        self.number_fxc_up = value
                        self.number_fxc_up.value_namespace = name_space
                        self.number_fxc_up.value_namespace_prefix = name_space_prefix


            class MainInterfaces(Entity):
                """
                Main Interface
                
                .. attribute:: main_interface
                
                	Main Interface Table
                	**type**\: list of    :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.MainInterfaces, self).__init__()

                    self.yang_name = "main-interfaces"
                    self.yang_parent_name = "node"

                    self.main_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.MainInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.MainInterfaces, self).__setattr__(name, value)


                class MainInterface(Entity):
                    """
                    Main Interface Table
                    
                    .. attribute:: interface_name  <key>
                    
                    	Main interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: main_interface_info
                    
                    	Main Interface info
                    	**type**\:   :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo>`
                    
                    .. attribute:: main_interface_instances
                    
                    	Main Interface Instance table
                    	**type**\:   :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface, self).__init__()

                        self.yang_name = "main-interface"
                        self.yang_parent_name = "main-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.main_interface_info = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo()
                        self.main_interface_info.parent = self
                        self._children_name_map["main_interface_info"] = "main-interface-info"
                        self._children_yang_names.add("main-interface-info")

                        self.main_interface_instances = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances()
                        self.main_interface_instances.parent = self
                        self._children_name_map["main_interface_instances"] = "main-interface-instances"
                        self._children_yang_names.add("main-interface-instances")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface, self).__setattr__(name, value)


                    class MainInterfaceInstances(Entity):
                        """
                        Main Interface Instance table
                        
                        .. attribute:: main_interface_instance
                        
                        	Main Interface Instance
                        	**type**\: list of    :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances, self).__init__()

                            self.yang_name = "main-interface-instances"
                            self.yang_parent_name = "main-interface"

                            self.main_interface_instance = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances, self).__setattr__(name, value)


                        class MainInterfaceInstance(Entity):
                            """
                            Main Interface Instance
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: main_interface_instance_bridge_ports
                            
                            	Main Interface Instance Bridge Port table
                            	**type**\:   :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                            
                            .. attribute:: main_interface_instance_info
                            
                            	Main Interface Instance info
                            	**type**\:   :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__init__()

                                self.yang_name = "main-interface-instance"
                                self.yang_parent_name = "main-interface-instances"

                                self.instance = YLeaf(YType.int32, "instance")

                                self.main_interface_instance_bridge_ports = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                                self.main_interface_instance_bridge_ports.parent = self
                                self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                                self._children_yang_names.add("main-interface-instance-bridge-ports")

                                self.main_interface_instance_info = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                                self.main_interface_instance_info.parent = self
                                self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"
                                self._children_yang_names.add("main-interface-instance-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("instance") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__setattr__(name, value)


                            class MainInterfaceInstanceInfo(Entity):
                                """
                                Main Interface Instance info
                                
                                .. attribute:: configured_instance
                                
                                	Configured Instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flush_count
                                
                                	Flush count 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_flags
                                
                                	Instance Flags
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_id
                                
                                	Instance ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_state
                                
                                	Instance State
                                	**type**\:   :py:class:`L2VpnMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfInstanceState>`
                                
                                .. attribute:: interface_count
                                
                                	Interface count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__init__()

                                    self.yang_name = "main-interface-instance-info"
                                    self.yang_parent_name = "main-interface-instance"

                                    self.configured_instance = YLeaf(YType.uint32, "configured-instance")

                                    self.flush_count = YLeaf(YType.uint32, "flush-count")

                                    self.instance_flags = YLeaf(YType.uint32, "instance-flags")

                                    self.instance_id = YLeaf(YType.uint32, "instance-id")

                                    self.instance_state = YLeaf(YType.enumeration, "instance-state")

                                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("configured_instance",
                                                    "flush_count",
                                                    "instance_flags",
                                                    "instance_id",
                                                    "instance_state",
                                                    "interface_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.configured_instance.is_set or
                                        self.flush_count.is_set or
                                        self.instance_flags.is_set or
                                        self.instance_id.is_set or
                                        self.instance_state.is_set or
                                        self.interface_count.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.configured_instance.yfilter != YFilter.not_set or
                                        self.flush_count.yfilter != YFilter.not_set or
                                        self.instance_flags.yfilter != YFilter.not_set or
                                        self.instance_id.yfilter != YFilter.not_set or
                                        self.instance_state.yfilter != YFilter.not_set or
                                        self.interface_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "main-interface-instance-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.configured_instance.is_set or self.configured_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.configured_instance.get_name_leafdata())
                                    if (self.flush_count.is_set or self.flush_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flush_count.get_name_leafdata())
                                    if (self.instance_flags.is_set or self.instance_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_flags.get_name_leafdata())
                                    if (self.instance_id.is_set or self.instance_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_id.get_name_leafdata())
                                    if (self.instance_state.is_set or self.instance_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_state.get_name_leafdata())
                                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "configured-instance" or name == "flush-count" or name == "instance-flags" or name == "instance-id" or name == "instance-state" or name == "interface-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "configured-instance"):
                                        self.configured_instance = value
                                        self.configured_instance.value_namespace = name_space
                                        self.configured_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flush-count"):
                                        self.flush_count = value
                                        self.flush_count.value_namespace = name_space
                                        self.flush_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-flags"):
                                        self.instance_flags = value
                                        self.instance_flags.value_namespace = name_space
                                        self.instance_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-id"):
                                        self.instance_id = value
                                        self.instance_id.value_namespace = name_space
                                        self.instance_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "instance-state"):
                                        self.instance_state = value
                                        self.instance_state.value_namespace = name_space
                                        self.instance_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-count"):
                                        self.interface_count = value
                                        self.interface_count.value_namespace = name_space
                                        self.interface_count.value_namespace_prefix = name_space_prefix


                            class MainInterfaceInstanceBridgePorts(Entity):
                                """
                                Main Interface Instance Bridge Port table
                                
                                .. attribute:: main_interface_instance_bridge_port
                                
                                	Main Interface Bridge Port info
                                	**type**\: list of    :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__init__()

                                    self.yang_name = "main-interface-instance-bridge-ports"
                                    self.yang_parent_name = "main-interface-instance"

                                    self.main_interface_instance_bridge_port = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__setattr__(name, value)


                                class MainInterfaceInstanceBridgePort(Entity):
                                    """
                                    Main Interface Bridge Port info
                                    
                                    .. attribute:: bridge_port  <key>
                                    
                                    	Bridge Port
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: bridge_port_xr
                                    
                                    	Bridge port ifhandle
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: instance_id
                                    
                                    	Instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__init__()

                                        self.yang_name = "main-interface-instance-bridge-port"
                                        self.yang_parent_name = "main-interface-instance-bridge-ports"

                                        self.bridge_port = YLeaf(YType.str, "bridge-port")

                                        self.bridge_port_xr = YLeaf(YType.str, "bridge-port-xr")

                                        self.instance_id = YLeaf(YType.uint32, "instance-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bridge_port",
                                                        "bridge_port_xr",
                                                        "instance_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bridge_port.is_set or
                                            self.bridge_port_xr.is_set or
                                            self.instance_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bridge_port.yfilter != YFilter.not_set or
                                            self.bridge_port_xr.yfilter != YFilter.not_set or
                                            self.instance_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "main-interface-instance-bridge-port" + "[bridge-port='" + self.bridge_port.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bridge_port.is_set or self.bridge_port.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bridge_port.get_name_leafdata())
                                        if (self.bridge_port_xr.is_set or self.bridge_port_xr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bridge_port_xr.get_name_leafdata())
                                        if (self.instance_id.is_set or self.instance_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.instance_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bridge-port" or name == "bridge-port-xr" or name == "instance-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bridge-port"):
                                            self.bridge_port = value
                                            self.bridge_port.value_namespace = name_space
                                            self.bridge_port.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bridge-port-xr"):
                                            self.bridge_port_xr = value
                                            self.bridge_port_xr.value_namespace = name_space
                                            self.bridge_port_xr.value_namespace_prefix = name_space_prefix
                                        if(value_path == "instance-id"):
                                            self.instance_id = value
                                            self.instance_id.value_namespace = name_space
                                            self.instance_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.main_interface_instance_bridge_port:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.main_interface_instance_bridge_port:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "main-interface-instance-bridge-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "main-interface-instance-bridge-port"):
                                        for c in self.main_interface_instance_bridge_port:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.main_interface_instance_bridge_port.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "main-interface-instance-bridge-port"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.instance.is_set or
                                    (self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports.has_data()) or
                                    (self.main_interface_instance_info is not None and self.main_interface_instance_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.instance.yfilter != YFilter.not_set or
                                    (self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports.has_operation()) or
                                    (self.main_interface_instance_info is not None and self.main_interface_instance_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "main-interface-instance" + "[instance='" + self.instance.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "main-interface-instance-bridge-ports"):
                                    if (self.main_interface_instance_bridge_ports is None):
                                        self.main_interface_instance_bridge_ports = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                                        self.main_interface_instance_bridge_ports.parent = self
                                        self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                                    return self.main_interface_instance_bridge_ports

                                if (child_yang_name == "main-interface-instance-info"):
                                    if (self.main_interface_instance_info is None):
                                        self.main_interface_instance_info = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                                        self.main_interface_instance_info.parent = self
                                        self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"
                                    return self.main_interface_instance_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "main-interface-instance-bridge-ports" or name == "main-interface-instance-info" or name == "instance"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "instance"):
                                    self.instance = value
                                    self.instance.value_namespace = name_space
                                    self.instance.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.main_interface_instance:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.main_interface_instance:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "main-interface-instances" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "main-interface-instance"):
                                for c in self.main_interface_instance:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.main_interface_instance.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "main-interface-instance"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class MainInterfaceInfo(Entity):
                        """
                        Main Interface info
                        
                        .. attribute:: interface_count
                        
                        	Sub Interface Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: main_interface_handle
                        
                        	Main Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: protected
                        
                        	Protected
                        	**type**\:   :py:class:`L2VpnMainIfProtectected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfProtectected>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo, self).__init__()

                            self.yang_name = "main-interface-info"
                            self.yang_parent_name = "main-interface"

                            self.interface_count = YLeaf(YType.uint32, "interface-count")

                            self.main_interface_handle = YLeaf(YType.str, "main-interface-handle")

                            self.protected = YLeaf(YType.enumeration, "protected")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_count",
                                            "main_interface_handle",
                                            "protected") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_count.is_set or
                                self.main_interface_handle.is_set or
                                self.protected.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_count.yfilter != YFilter.not_set or
                                self.main_interface_handle.yfilter != YFilter.not_set or
                                self.protected.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "main-interface-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_count.get_name_leafdata())
                            if (self.main_interface_handle.is_set or self.main_interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_interface_handle.get_name_leafdata())
                            if (self.protected.is_set or self.protected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protected.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-count" or name == "main-interface-handle" or name == "protected"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-count"):
                                self.interface_count = value
                                self.interface_count.value_namespace = name_space
                                self.interface_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "main-interface-handle"):
                                self.main_interface_handle = value
                                self.main_interface_handle.value_namespace = name_space
                                self.main_interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "protected"):
                                self.protected = value
                                self.protected.value_namespace = name_space
                                self.protected.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            (self.main_interface_info is not None and self.main_interface_info.has_data()) or
                            (self.main_interface_instances is not None and self.main_interface_instances.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            (self.main_interface_info is not None and self.main_interface_info.has_operation()) or
                            (self.main_interface_instances is not None and self.main_interface_instances.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "main-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "main-interface-info"):
                            if (self.main_interface_info is None):
                                self.main_interface_info = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo()
                                self.main_interface_info.parent = self
                                self._children_name_map["main_interface_info"] = "main-interface-info"
                            return self.main_interface_info

                        if (child_yang_name == "main-interface-instances"):
                            if (self.main_interface_instances is None):
                                self.main_interface_instances = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances()
                                self.main_interface_instances.parent = self
                                self._children_name_map["main_interface_instances"] = "main-interface-instances"
                            return self.main_interface_instances

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "main-interface-info" or name == "main-interface-instances" or name == "interface-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.main_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.main_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "main-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "main-interface"):
                        for c in self.main_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.main_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "main-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IccpSm(Entity):
                """
                ICCP\-based Service Multi\-homing operational data
                
                .. attribute:: iccp_groups
                
                	ICCP Group Table
                	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups>`
                
                .. attribute:: iccp_sm_summary
                
                	ICCP\-based Service Multi\-homing database summary
                	**type**\:   :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpSmSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.IccpSm, self).__init__()

                    self.yang_name = "iccp-sm"
                    self.yang_parent_name = "node"

                    self.iccp_groups = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups()
                    self.iccp_groups.parent = self
                    self._children_name_map["iccp_groups"] = "iccp-groups"
                    self._children_yang_names.add("iccp-groups")

                    self.iccp_sm_summary = L2Vpnv2.Nodes.Node.IccpSm.IccpSmSummary()
                    self.iccp_sm_summary.parent = self
                    self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"
                    self._children_yang_names.add("iccp-sm-summary")


                class IccpSmSummary(Entity):
                    """
                    ICCP\-based Service Multi\-homing database
                    summary
                    
                    .. attribute:: connected_groups
                    
                    	Number of Connected Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: connecting_groups
                    
                    	Number of Connecting Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: failed_ports
                    
                    	Number of Failed Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groups
                    
                    	Total Number of Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: operational_ports
                    
                    	Number of Operational Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ports
                    
                    	Total Number of Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: provisioned_groups
                    
                    	Number of Provisioned Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reverting_ports
                    
                    	Number of Reverting Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: synchronized_groups
                    
                    	Number of Synchronized Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: synchronizing_groups
                    
                    	Number of Synchronizing Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unconfigured_ports
                    
                    	Number of Unconfigured Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unknown_ports
                    
                    	Number of Unknown Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unresolved_groups
                    
                    	Number of Unresolved Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsynchronized_ports
                    
                    	Number of Unsynchronized Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.IccpSm.IccpSmSummary, self).__init__()

                        self.yang_name = "iccp-sm-summary"
                        self.yang_parent_name = "iccp-sm"

                        self.connected_groups = YLeaf(YType.uint32, "connected-groups")

                        self.connecting_groups = YLeaf(YType.uint32, "connecting-groups")

                        self.failed_ports = YLeaf(YType.uint32, "failed-ports")

                        self.groups = YLeaf(YType.uint32, "groups")

                        self.operational_ports = YLeaf(YType.uint32, "operational-ports")

                        self.ports = YLeaf(YType.uint32, "ports")

                        self.provisioned_groups = YLeaf(YType.uint32, "provisioned-groups")

                        self.reverting_ports = YLeaf(YType.uint32, "reverting-ports")

                        self.synchronized_groups = YLeaf(YType.uint32, "synchronized-groups")

                        self.synchronizing_groups = YLeaf(YType.uint32, "synchronizing-groups")

                        self.unconfigured_ports = YLeaf(YType.uint32, "unconfigured-ports")

                        self.unknown_ports = YLeaf(YType.uint32, "unknown-ports")

                        self.unresolved_groups = YLeaf(YType.uint32, "unresolved-groups")

                        self.unsynchronized_ports = YLeaf(YType.uint32, "unsynchronized-ports")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("connected_groups",
                                        "connecting_groups",
                                        "failed_ports",
                                        "groups",
                                        "operational_ports",
                                        "ports",
                                        "provisioned_groups",
                                        "reverting_ports",
                                        "synchronized_groups",
                                        "synchronizing_groups",
                                        "unconfigured_ports",
                                        "unknown_ports",
                                        "unresolved_groups",
                                        "unsynchronized_ports") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.IccpSm.IccpSmSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.IccpSm.IccpSmSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.connected_groups.is_set or
                            self.connecting_groups.is_set or
                            self.failed_ports.is_set or
                            self.groups.is_set or
                            self.operational_ports.is_set or
                            self.ports.is_set or
                            self.provisioned_groups.is_set or
                            self.reverting_ports.is_set or
                            self.synchronized_groups.is_set or
                            self.synchronizing_groups.is_set or
                            self.unconfigured_ports.is_set or
                            self.unknown_ports.is_set or
                            self.unresolved_groups.is_set or
                            self.unsynchronized_ports.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.connected_groups.yfilter != YFilter.not_set or
                            self.connecting_groups.yfilter != YFilter.not_set or
                            self.failed_ports.yfilter != YFilter.not_set or
                            self.groups.yfilter != YFilter.not_set or
                            self.operational_ports.yfilter != YFilter.not_set or
                            self.ports.yfilter != YFilter.not_set or
                            self.provisioned_groups.yfilter != YFilter.not_set or
                            self.reverting_ports.yfilter != YFilter.not_set or
                            self.synchronized_groups.yfilter != YFilter.not_set or
                            self.synchronizing_groups.yfilter != YFilter.not_set or
                            self.unconfigured_ports.yfilter != YFilter.not_set or
                            self.unknown_ports.yfilter != YFilter.not_set or
                            self.unresolved_groups.yfilter != YFilter.not_set or
                            self.unsynchronized_ports.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-sm-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.connected_groups.is_set or self.connected_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.connected_groups.get_name_leafdata())
                        if (self.connecting_groups.is_set or self.connecting_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.connecting_groups.get_name_leafdata())
                        if (self.failed_ports.is_set or self.failed_ports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.failed_ports.get_name_leafdata())
                        if (self.groups.is_set or self.groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groups.get_name_leafdata())
                        if (self.operational_ports.is_set or self.operational_ports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.operational_ports.get_name_leafdata())
                        if (self.ports.is_set or self.ports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ports.get_name_leafdata())
                        if (self.provisioned_groups.is_set or self.provisioned_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.provisioned_groups.get_name_leafdata())
                        if (self.reverting_ports.is_set or self.reverting_ports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reverting_ports.get_name_leafdata())
                        if (self.synchronized_groups.is_set or self.synchronized_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.synchronized_groups.get_name_leafdata())
                        if (self.synchronizing_groups.is_set or self.synchronizing_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.synchronizing_groups.get_name_leafdata())
                        if (self.unconfigured_ports.is_set or self.unconfigured_ports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unconfigured_ports.get_name_leafdata())
                        if (self.unknown_ports.is_set or self.unknown_ports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unknown_ports.get_name_leafdata())
                        if (self.unresolved_groups.is_set or self.unresolved_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unresolved_groups.get_name_leafdata())
                        if (self.unsynchronized_ports.is_set or self.unsynchronized_ports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unsynchronized_ports.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "connected-groups" or name == "connecting-groups" or name == "failed-ports" or name == "groups" or name == "operational-ports" or name == "ports" or name == "provisioned-groups" or name == "reverting-ports" or name == "synchronized-groups" or name == "synchronizing-groups" or name == "unconfigured-ports" or name == "unknown-ports" or name == "unresolved-groups" or name == "unsynchronized-ports"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "connected-groups"):
                            self.connected_groups = value
                            self.connected_groups.value_namespace = name_space
                            self.connected_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "connecting-groups"):
                            self.connecting_groups = value
                            self.connecting_groups.value_namespace = name_space
                            self.connecting_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "failed-ports"):
                            self.failed_ports = value
                            self.failed_ports.value_namespace = name_space
                            self.failed_ports.value_namespace_prefix = name_space_prefix
                        if(value_path == "groups"):
                            self.groups = value
                            self.groups.value_namespace = name_space
                            self.groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "operational-ports"):
                            self.operational_ports = value
                            self.operational_ports.value_namespace = name_space
                            self.operational_ports.value_namespace_prefix = name_space_prefix
                        if(value_path == "ports"):
                            self.ports = value
                            self.ports.value_namespace = name_space
                            self.ports.value_namespace_prefix = name_space_prefix
                        if(value_path == "provisioned-groups"):
                            self.provisioned_groups = value
                            self.provisioned_groups.value_namespace = name_space
                            self.provisioned_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "reverting-ports"):
                            self.reverting_ports = value
                            self.reverting_ports.value_namespace = name_space
                            self.reverting_ports.value_namespace_prefix = name_space_prefix
                        if(value_path == "synchronized-groups"):
                            self.synchronized_groups = value
                            self.synchronized_groups.value_namespace = name_space
                            self.synchronized_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "synchronizing-groups"):
                            self.synchronizing_groups = value
                            self.synchronizing_groups.value_namespace = name_space
                            self.synchronizing_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "unconfigured-ports"):
                            self.unconfigured_ports = value
                            self.unconfigured_ports.value_namespace = name_space
                            self.unconfigured_ports.value_namespace_prefix = name_space_prefix
                        if(value_path == "unknown-ports"):
                            self.unknown_ports = value
                            self.unknown_ports.value_namespace = name_space
                            self.unknown_ports.value_namespace_prefix = name_space_prefix
                        if(value_path == "unresolved-groups"):
                            self.unresolved_groups = value
                            self.unresolved_groups.value_namespace = name_space
                            self.unresolved_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "unsynchronized-ports"):
                            self.unsynchronized_ports = value
                            self.unsynchronized_ports.value_namespace = name_space
                            self.unsynchronized_ports.value_namespace_prefix = name_space_prefix


                class IccpGroups(Entity):
                    """
                    ICCP Group Table
                    
                    .. attribute:: iccp_group
                    
                    	ICCP Group
                    	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups, self).__init__()

                        self.yang_name = "iccp-groups"
                        self.yang_parent_name = "iccp-sm"

                        self.iccp_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups, self).__setattr__(name, value)


                    class IccpGroup(Entity):
                        """
                        ICCP Group
                        
                        .. attribute:: group_id  <key>
                        
                        	Group ID
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: iccp_group_info
                        
                        	ICCP Group Information
                        	**type**\:   :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                        
                        .. attribute:: iccp_ports
                        
                        	ICCP Port Table
                        	**type**\:   :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup, self).__init__()

                            self.yang_name = "iccp-group"
                            self.yang_parent_name = "iccp-groups"

                            self.group_id = YLeaf(YType.uint32, "group-id")

                            self.iccp_group_info = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                            self.iccp_group_info.parent = self
                            self._children_name_map["iccp_group_info"] = "iccp-group-info"
                            self._children_yang_names.add("iccp-group-info")

                            self.iccp_ports = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                            self.iccp_ports.parent = self
                            self._children_name_map["iccp_ports"] = "iccp-ports"
                            self._children_yang_names.add("iccp-ports")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup, self).__setattr__(name, value)


                        class IccpGroupInfo(Entity):
                            """
                            ICCP Group Information
                            
                            .. attribute:: group_id
                            
                            	Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_member_up
                            
                            	ICCP Member Up
                            	**type**\:  bool
                            
                            .. attribute:: iccp_transport_up
                            
                            	ICCP Transport Up
                            	**type**\:  bool
                            
                            .. attribute:: local_node_id
                            
                            	Local Node ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ports
                            
                            	List of ports in the group
                            	**type**\: list of    :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                            
                            .. attribute:: remote_node_id
                            
                            	Remote Node ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`IccpSmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__init__()

                                self.yang_name = "iccp-group-info"
                                self.yang_parent_name = "iccp-group"

                                self.group_id = YLeaf(YType.uint32, "group-id")

                                self.iccp_member_up = YLeaf(YType.boolean, "iccp-member-up")

                                self.iccp_transport_up = YLeaf(YType.boolean, "iccp-transport-up")

                                self.local_node_id = YLeaf(YType.uint8, "local-node-id")

                                self.remote_node_id = YLeaf(YType.uint8, "remote-node-id")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.ports = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("group_id",
                                                "iccp_member_up",
                                                "iccp_transport_up",
                                                "local_node_id",
                                                "remote_node_id",
                                                "state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__setattr__(name, value)


                            class Ports(Entity):
                                """
                                List of ports in the group
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: local_port
                                
                                	Local port info
                                	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                                
                                .. attribute:: mac_flush_tcn
                                
                                	Is MAC flush through STP\-TCN?
                                	**type**\:  bool
                                
                                .. attribute:: remote_port
                                
                                	Remote port info
                                	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__init__()

                                    self.yang_name = "ports"
                                    self.yang_parent_name = "iccp-group-info"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.mac_flush_tcn = YLeaf(YType.boolean, "mac-flush-tcn")

                                    self.local_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                    self.local_port.parent = self
                                    self._children_name_map["local_port"] = "local-port"
                                    self._children_yang_names.add("local-port")

                                    self.remote_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                    self.remote_port.parent = self
                                    self._children_name_map["remote_port"] = "remote-port"
                                    self._children_yang_names.add("remote-port")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "mac_flush_tcn") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__setattr__(name, value)


                                class LocalPort(Entity):
                                    """
                                    Local port info
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__init__()

                                        self.yang_name = "local-port"
                                        self.yang_parent_name = "ports"

                                        self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                        self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                        self.port_state = YLeaf(YType.enumeration, "port-state")

                                        self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                        self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                        self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                        self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fsm_state",
                                                        "port_fail_code",
                                                        "port_state",
                                                        "reversion_time",
                                                        "reversion_time_remaining",
                                                        "vlan_state",
                                                        "vlan_vector") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.fsm_state.is_set or
                                            self.port_fail_code.is_set or
                                            self.port_state.is_set or
                                            self.reversion_time.is_set or
                                            self.reversion_time_remaining.is_set or
                                            self.vlan_state.is_set or
                                            self.vlan_vector.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fsm_state.yfilter != YFilter.not_set or
                                            self.port_fail_code.yfilter != YFilter.not_set or
                                            self.port_state.yfilter != YFilter.not_set or
                                            self.reversion_time.yfilter != YFilter.not_set or
                                            self.reversion_time_remaining.yfilter != YFilter.not_set or
                                            self.vlan_state.yfilter != YFilter.not_set or
                                            self.vlan_vector.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                        if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                        if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.port_state.get_name_leafdata())
                                        if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                        if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                        if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                        if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fsm-state"):
                                            self.fsm_state = value
                                            self.fsm_state.value_namespace = name_space
                                            self.fsm_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "port-fail-code"):
                                            self.port_fail_code = value
                                            self.port_fail_code.value_namespace = name_space
                                            self.port_fail_code.value_namespace_prefix = name_space_prefix
                                        if(value_path == "port-state"):
                                            self.port_state = value
                                            self.port_state.value_namespace = name_space
                                            self.port_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "reversion-time"):
                                            self.reversion_time = value
                                            self.reversion_time.value_namespace = name_space
                                            self.reversion_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "reversion-time-remaining"):
                                            self.reversion_time_remaining = value
                                            self.reversion_time_remaining.value_namespace = name_space
                                            self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-state"):
                                            self.vlan_state = value
                                            self.vlan_state.value_namespace = name_space
                                            self.vlan_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-vector"):
                                            self.vlan_vector = value
                                            self.vlan_vector.value_namespace = name_space
                                            self.vlan_vector.value_namespace_prefix = name_space_prefix


                                class RemotePort(Entity):
                                    """
                                    Remote port info
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__init__()

                                        self.yang_name = "remote-port"
                                        self.yang_parent_name = "ports"

                                        self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                        self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                        self.port_state = YLeaf(YType.enumeration, "port-state")

                                        self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                        self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                        self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                        self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fsm_state",
                                                        "port_fail_code",
                                                        "port_state",
                                                        "reversion_time",
                                                        "reversion_time_remaining",
                                                        "vlan_state",
                                                        "vlan_vector") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.fsm_state.is_set or
                                            self.port_fail_code.is_set or
                                            self.port_state.is_set or
                                            self.reversion_time.is_set or
                                            self.reversion_time_remaining.is_set or
                                            self.vlan_state.is_set or
                                            self.vlan_vector.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fsm_state.yfilter != YFilter.not_set or
                                            self.port_fail_code.yfilter != YFilter.not_set or
                                            self.port_state.yfilter != YFilter.not_set or
                                            self.reversion_time.yfilter != YFilter.not_set or
                                            self.reversion_time_remaining.yfilter != YFilter.not_set or
                                            self.vlan_state.yfilter != YFilter.not_set or
                                            self.vlan_vector.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                        if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                        if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.port_state.get_name_leafdata())
                                        if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                        if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                        if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                        if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fsm-state"):
                                            self.fsm_state = value
                                            self.fsm_state.value_namespace = name_space
                                            self.fsm_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "port-fail-code"):
                                            self.port_fail_code = value
                                            self.port_fail_code.value_namespace = name_space
                                            self.port_fail_code.value_namespace_prefix = name_space_prefix
                                        if(value_path == "port-state"):
                                            self.port_state = value
                                            self.port_state.value_namespace = name_space
                                            self.port_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "reversion-time"):
                                            self.reversion_time = value
                                            self.reversion_time.value_namespace = name_space
                                            self.reversion_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "reversion-time-remaining"):
                                            self.reversion_time_remaining = value
                                            self.reversion_time_remaining.value_namespace = name_space
                                            self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-state"):
                                            self.vlan_state = value
                                            self.vlan_state.value_namespace = name_space
                                            self.vlan_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-vector"):
                                            self.vlan_vector = value
                                            self.vlan_vector.value_namespace = name_space
                                            self.vlan_vector.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.interface_name.is_set or
                                        self.mac_flush_tcn.is_set or
                                        (self.local_port is not None and self.local_port.has_data()) or
                                        (self.remote_port is not None and self.remote_port.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.mac_flush_tcn.yfilter != YFilter.not_set or
                                        (self.local_port is not None and self.local_port.has_operation()) or
                                        (self.remote_port is not None and self.remote_port.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.mac_flush_tcn.is_set or self.mac_flush_tcn.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flush_tcn.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-port"):
                                        if (self.local_port is None):
                                            self.local_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                            self.local_port.parent = self
                                            self._children_name_map["local_port"] = "local-port"
                                        return self.local_port

                                    if (child_yang_name == "remote-port"):
                                        if (self.remote_port is None):
                                            self.remote_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                            self.remote_port.parent = self
                                            self._children_name_map["remote_port"] = "remote-port"
                                        return self.remote_port

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-port" or name == "remote-port" or name == "interface-name" or name == "mac-flush-tcn"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flush-tcn"):
                                        self.mac_flush_tcn = value
                                        self.mac_flush_tcn.value_namespace = name_space
                                        self.mac_flush_tcn.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.ports:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.group_id.is_set or
                                    self.iccp_member_up.is_set or
                                    self.iccp_transport_up.is_set or
                                    self.local_node_id.is_set or
                                    self.remote_node_id.is_set or
                                    self.state.is_set)

                            def has_operation(self):
                                for c in self.ports:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.group_id.yfilter != YFilter.not_set or
                                    self.iccp_member_up.yfilter != YFilter.not_set or
                                    self.iccp_transport_up.yfilter != YFilter.not_set or
                                    self.local_node_id.yfilter != YFilter.not_set or
                                    self.remote_node_id.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-group-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_id.get_name_leafdata())
                                if (self.iccp_member_up.is_set or self.iccp_member_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_member_up.get_name_leafdata())
                                if (self.iccp_transport_up.is_set or self.iccp_transport_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_transport_up.get_name_leafdata())
                                if (self.local_node_id.is_set or self.local_node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_node_id.get_name_leafdata())
                                if (self.remote_node_id.is_set or self.remote_node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_node_id.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ports"):
                                    for c in self.ports:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ports.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ports" or name == "group-id" or name == "iccp-member-up" or name == "iccp-transport-up" or name == "local-node-id" or name == "remote-node-id" or name == "state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "group-id"):
                                    self.group_id = value
                                    self.group_id.value_namespace = name_space
                                    self.group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-member-up"):
                                    self.iccp_member_up = value
                                    self.iccp_member_up.value_namespace = name_space
                                    self.iccp_member_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-transport-up"):
                                    self.iccp_transport_up = value
                                    self.iccp_transport_up.value_namespace = name_space
                                    self.iccp_transport_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-node-id"):
                                    self.local_node_id = value
                                    self.local_node_id.value_namespace = name_space
                                    self.local_node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-node-id"):
                                    self.remote_node_id = value
                                    self.remote_node_id.value_namespace = name_space
                                    self.remote_node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix


                        class IccpPorts(Entity):
                            """
                            ICCP Port Table
                            
                            .. attribute:: iccp_port
                            
                            	ICCP Port
                            	**type**\: list of    :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__init__()

                                self.yang_name = "iccp-ports"
                                self.yang_parent_name = "iccp-group"

                                self.iccp_port = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__setattr__(name, value)


                            class IccpPort(Entity):
                                """
                                ICCP Port
                                
                                .. attribute:: interface  <key>
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: local_port
                                
                                	Local port info
                                	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                                
                                .. attribute:: mac_flush_tcn
                                
                                	Is MAC flush through STP\-TCN?
                                	**type**\:  bool
                                
                                .. attribute:: remote_port
                                
                                	Remote port info
                                	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__init__()

                                    self.yang_name = "iccp-port"
                                    self.yang_parent_name = "iccp-ports"

                                    self.interface = YLeaf(YType.str, "interface")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.mac_flush_tcn = YLeaf(YType.boolean, "mac-flush-tcn")

                                    self.local_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                    self.local_port.parent = self
                                    self._children_name_map["local_port"] = "local-port"
                                    self._children_yang_names.add("local-port")

                                    self.remote_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                    self.remote_port.parent = self
                                    self._children_name_map["remote_port"] = "remote-port"
                                    self._children_yang_names.add("remote-port")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface",
                                                    "interface_name",
                                                    "mac_flush_tcn") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__setattr__(name, value)


                                class LocalPort(Entity):
                                    """
                                    Local port info
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__init__()

                                        self.yang_name = "local-port"
                                        self.yang_parent_name = "iccp-port"

                                        self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                        self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                        self.port_state = YLeaf(YType.enumeration, "port-state")

                                        self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                        self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                        self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                        self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fsm_state",
                                                        "port_fail_code",
                                                        "port_state",
                                                        "reversion_time",
                                                        "reversion_time_remaining",
                                                        "vlan_state",
                                                        "vlan_vector") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.fsm_state.is_set or
                                            self.port_fail_code.is_set or
                                            self.port_state.is_set or
                                            self.reversion_time.is_set or
                                            self.reversion_time_remaining.is_set or
                                            self.vlan_state.is_set or
                                            self.vlan_vector.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fsm_state.yfilter != YFilter.not_set or
                                            self.port_fail_code.yfilter != YFilter.not_set or
                                            self.port_state.yfilter != YFilter.not_set or
                                            self.reversion_time.yfilter != YFilter.not_set or
                                            self.reversion_time_remaining.yfilter != YFilter.not_set or
                                            self.vlan_state.yfilter != YFilter.not_set or
                                            self.vlan_vector.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                        if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                        if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.port_state.get_name_leafdata())
                                        if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                        if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                        if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                        if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fsm-state"):
                                            self.fsm_state = value
                                            self.fsm_state.value_namespace = name_space
                                            self.fsm_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "port-fail-code"):
                                            self.port_fail_code = value
                                            self.port_fail_code.value_namespace = name_space
                                            self.port_fail_code.value_namespace_prefix = name_space_prefix
                                        if(value_path == "port-state"):
                                            self.port_state = value
                                            self.port_state.value_namespace = name_space
                                            self.port_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "reversion-time"):
                                            self.reversion_time = value
                                            self.reversion_time.value_namespace = name_space
                                            self.reversion_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "reversion-time-remaining"):
                                            self.reversion_time_remaining = value
                                            self.reversion_time_remaining.value_namespace = name_space
                                            self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-state"):
                                            self.vlan_state = value
                                            self.vlan_state.value_namespace = name_space
                                            self.vlan_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-vector"):
                                            self.vlan_vector = value
                                            self.vlan_vector.value_namespace = name_space
                                            self.vlan_vector.value_namespace_prefix = name_space_prefix


                                class RemotePort(Entity):
                                    """
                                    Remote port info
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__init__()

                                        self.yang_name = "remote-port"
                                        self.yang_parent_name = "iccp-port"

                                        self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                        self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                        self.port_state = YLeaf(YType.enumeration, "port-state")

                                        self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                        self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                        self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                        self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fsm_state",
                                                        "port_fail_code",
                                                        "port_state",
                                                        "reversion_time",
                                                        "reversion_time_remaining",
                                                        "vlan_state",
                                                        "vlan_vector") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.fsm_state.is_set or
                                            self.port_fail_code.is_set or
                                            self.port_state.is_set or
                                            self.reversion_time.is_set or
                                            self.reversion_time_remaining.is_set or
                                            self.vlan_state.is_set or
                                            self.vlan_vector.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fsm_state.yfilter != YFilter.not_set or
                                            self.port_fail_code.yfilter != YFilter.not_set or
                                            self.port_state.yfilter != YFilter.not_set or
                                            self.reversion_time.yfilter != YFilter.not_set or
                                            self.reversion_time_remaining.yfilter != YFilter.not_set or
                                            self.vlan_state.yfilter != YFilter.not_set or
                                            self.vlan_vector.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                        if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                        if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.port_state.get_name_leafdata())
                                        if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                        if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                        if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                        if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fsm-state"):
                                            self.fsm_state = value
                                            self.fsm_state.value_namespace = name_space
                                            self.fsm_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "port-fail-code"):
                                            self.port_fail_code = value
                                            self.port_fail_code.value_namespace = name_space
                                            self.port_fail_code.value_namespace_prefix = name_space_prefix
                                        if(value_path == "port-state"):
                                            self.port_state = value
                                            self.port_state.value_namespace = name_space
                                            self.port_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "reversion-time"):
                                            self.reversion_time = value
                                            self.reversion_time.value_namespace = name_space
                                            self.reversion_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "reversion-time-remaining"):
                                            self.reversion_time_remaining = value
                                            self.reversion_time_remaining.value_namespace = name_space
                                            self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-state"):
                                            self.vlan_state = value
                                            self.vlan_state.value_namespace = name_space
                                            self.vlan_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-vector"):
                                            self.vlan_vector = value
                                            self.vlan_vector.value_namespace = name_space
                                            self.vlan_vector.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.interface.is_set or
                                        self.interface_name.is_set or
                                        self.mac_flush_tcn.is_set or
                                        (self.local_port is not None and self.local_port.has_data()) or
                                        (self.remote_port is not None and self.remote_port.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.mac_flush_tcn.yfilter != YFilter.not_set or
                                        (self.local_port is not None and self.local_port.has_operation()) or
                                        (self.remote_port is not None and self.remote_port.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "iccp-port" + "[interface='" + self.interface.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.mac_flush_tcn.is_set or self.mac_flush_tcn.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flush_tcn.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-port"):
                                        if (self.local_port is None):
                                            self.local_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                            self.local_port.parent = self
                                            self._children_name_map["local_port"] = "local-port"
                                        return self.local_port

                                    if (child_yang_name == "remote-port"):
                                        if (self.remote_port is None):
                                            self.remote_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                            self.remote_port.parent = self
                                            self._children_name_map["remote_port"] = "remote-port"
                                        return self.remote_port

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-port" or name == "remote-port" or name == "interface" or name == "interface-name" or name == "mac-flush-tcn"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface"):
                                        self.interface = value
                                        self.interface.value_namespace = name_space
                                        self.interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flush-tcn"):
                                        self.mac_flush_tcn = value
                                        self.mac_flush_tcn.value_namespace = name_space
                                        self.mac_flush_tcn.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.iccp_port:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.iccp_port:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-ports" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "iccp-port"):
                                    for c in self.iccp_port:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.iccp_port.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "iccp-port"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.group_id.is_set or
                                (self.iccp_group_info is not None and self.iccp_group_info.has_data()) or
                                (self.iccp_ports is not None and self.iccp_ports.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_id.yfilter != YFilter.not_set or
                                (self.iccp_group_info is not None and self.iccp_group_info.has_operation()) or
                                (self.iccp_ports is not None and self.iccp_ports.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group" + "[group-id='" + self.group_id.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "iccp-group-info"):
                                if (self.iccp_group_info is None):
                                    self.iccp_group_info = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                                    self.iccp_group_info.parent = self
                                    self._children_name_map["iccp_group_info"] = "iccp-group-info"
                                return self.iccp_group_info

                            if (child_yang_name == "iccp-ports"):
                                if (self.iccp_ports is None):
                                    self.iccp_ports = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                                    self.iccp_ports.parent = self
                                    self._children_name_map["iccp_ports"] = "iccp-ports"
                                return self.iccp_ports

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "iccp-group-info" or name == "iccp-ports" or name == "group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-id"):
                                self.group_id = value
                                self.group_id.value_namespace = name_space
                                self.group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.iccp_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.iccp_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-group"):
                            for c in self.iccp_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.iccp_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.iccp_groups is not None and self.iccp_groups.has_data()) or
                        (self.iccp_sm_summary is not None and self.iccp_sm_summary.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.iccp_groups is not None and self.iccp_groups.has_operation()) or
                        (self.iccp_sm_summary is not None and self.iccp_sm_summary.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "iccp-sm" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "iccp-groups"):
                        if (self.iccp_groups is None):
                            self.iccp_groups = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups()
                            self.iccp_groups.parent = self
                            self._children_name_map["iccp_groups"] = "iccp-groups"
                        return self.iccp_groups

                    if (child_yang_name == "iccp-sm-summary"):
                        if (self.iccp_sm_summary is None):
                            self.iccp_sm_summary = L2Vpnv2.Nodes.Node.IccpSm.IccpSmSummary()
                            self.iccp_sm_summary.parent = self
                            self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"
                        return self.iccp_sm_summary

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "iccp-groups" or name == "iccp-sm-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BridgeSummary(Entity):
                """
                Bridge Domain summary information
                
                .. attribute:: num_vn_is
                
                	Number of VNIs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_down
                
                	Number of VNIs down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_unresolved
                
                	Number of VNIs unresolved
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_up
                
                	Number of VNIs up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs
                
                	Number of attachment circuits
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs_up
                
                	Number of attachment circuits whose state is up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_bridge_domains
                
                	Number of bridge\-domains
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_bridge_domains_shut
                
                	Number of bridge\-domains admin disabled
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_bridge_domains_up
                
                	Number of bridge\-domains up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_default_bridge_doamins
                
                	Number of default bridge\-domains
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_groups
                
                	Number of groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p2mp
                
                	Number of P2MPs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p2mp_down
                
                	Number of P2MPs whose state is down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p2mp_up
                
                	Number of P2MPs whose state is up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p_ws_up
                
                	Number of pseudowires whose state is up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pbb_core
                
                	Number of PBB Core
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pbb_edge
                
                	Number of PBB Edge
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pseudowires
                
                	Number of pseudowires
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: out_of_memory_state
                
                	L2VPN Out of memory state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_a_cs
                
                	Number of partially programmed attachment circuits
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_bridges
                
                	Number of partially programmed bridge\-domains
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_pseudowires
                
                	Number of partially programmed pseudowires
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_pseudowires
                
                	Number of pseudowires whose state is standby
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.BridgeSummary, self).__init__()

                    self.yang_name = "bridge-summary"
                    self.yang_parent_name = "node"

                    self.num_vn_is = YLeaf(YType.uint32, "num-vn-is")

                    self.num_vn_is_down = YLeaf(YType.uint32, "num-vn-is-down")

                    self.num_vn_is_unresolved = YLeaf(YType.uint32, "num-vn-is-unresolved")

                    self.num_vn_is_up = YLeaf(YType.uint32, "num-vn-is-up")

                    self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                    self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                    self.number_bridge_domains = YLeaf(YType.uint32, "number-bridge-domains")

                    self.number_bridge_domains_shut = YLeaf(YType.uint32, "number-bridge-domains-shut")

                    self.number_bridge_domains_up = YLeaf(YType.uint32, "number-bridge-domains-up")

                    self.number_default_bridge_doamins = YLeaf(YType.uint32, "number-default-bridge-doamins")

                    self.number_groups = YLeaf(YType.uint32, "number-groups")

                    self.number_p2mp = YLeaf(YType.uint32, "number-p2mp")

                    self.number_p2mp_down = YLeaf(YType.uint32, "number-p2mp-down")

                    self.number_p2mp_up = YLeaf(YType.uint32, "number-p2mp-up")

                    self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                    self.number_pbb_core = YLeaf(YType.uint32, "number-pbb-core")

                    self.number_pbb_edge = YLeaf(YType.uint32, "number-pbb-edge")

                    self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                    self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                    self.partially_programmed_a_cs = YLeaf(YType.uint32, "partially-programmed-a-cs")

                    self.partially_programmed_bridges = YLeaf(YType.uint32, "partially-programmed-bridges")

                    self.partially_programmed_pseudowires = YLeaf(YType.uint32, "partially-programmed-pseudowires")

                    self.standby_pseudowires = YLeaf(YType.uint32, "standby-pseudowires")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("num_vn_is",
                                    "num_vn_is_down",
                                    "num_vn_is_unresolved",
                                    "num_vn_is_up",
                                    "number_a_cs",
                                    "number_a_cs_up",
                                    "number_bridge_domains",
                                    "number_bridge_domains_shut",
                                    "number_bridge_domains_up",
                                    "number_default_bridge_doamins",
                                    "number_groups",
                                    "number_p2mp",
                                    "number_p2mp_down",
                                    "number_p2mp_up",
                                    "number_p_ws_up",
                                    "number_pbb_core",
                                    "number_pbb_edge",
                                    "number_pseudowires",
                                    "out_of_memory_state",
                                    "partially_programmed_a_cs",
                                    "partially_programmed_bridges",
                                    "partially_programmed_pseudowires",
                                    "standby_pseudowires") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.BridgeSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.BridgeSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.num_vn_is.is_set or
                        self.num_vn_is_down.is_set or
                        self.num_vn_is_unresolved.is_set or
                        self.num_vn_is_up.is_set or
                        self.number_a_cs.is_set or
                        self.number_a_cs_up.is_set or
                        self.number_bridge_domains.is_set or
                        self.number_bridge_domains_shut.is_set or
                        self.number_bridge_domains_up.is_set or
                        self.number_default_bridge_doamins.is_set or
                        self.number_groups.is_set or
                        self.number_p2mp.is_set or
                        self.number_p2mp_down.is_set or
                        self.number_p2mp_up.is_set or
                        self.number_p_ws_up.is_set or
                        self.number_pbb_core.is_set or
                        self.number_pbb_edge.is_set or
                        self.number_pseudowires.is_set or
                        self.out_of_memory_state.is_set or
                        self.partially_programmed_a_cs.is_set or
                        self.partially_programmed_bridges.is_set or
                        self.partially_programmed_pseudowires.is_set or
                        self.standby_pseudowires.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.num_vn_is.yfilter != YFilter.not_set or
                        self.num_vn_is_down.yfilter != YFilter.not_set or
                        self.num_vn_is_unresolved.yfilter != YFilter.not_set or
                        self.num_vn_is_up.yfilter != YFilter.not_set or
                        self.number_a_cs.yfilter != YFilter.not_set or
                        self.number_a_cs_up.yfilter != YFilter.not_set or
                        self.number_bridge_domains.yfilter != YFilter.not_set or
                        self.number_bridge_domains_shut.yfilter != YFilter.not_set or
                        self.number_bridge_domains_up.yfilter != YFilter.not_set or
                        self.number_default_bridge_doamins.yfilter != YFilter.not_set or
                        self.number_groups.yfilter != YFilter.not_set or
                        self.number_p2mp.yfilter != YFilter.not_set or
                        self.number_p2mp_down.yfilter != YFilter.not_set or
                        self.number_p2mp_up.yfilter != YFilter.not_set or
                        self.number_p_ws_up.yfilter != YFilter.not_set or
                        self.number_pbb_core.yfilter != YFilter.not_set or
                        self.number_pbb_edge.yfilter != YFilter.not_set or
                        self.number_pseudowires.yfilter != YFilter.not_set or
                        self.out_of_memory_state.yfilter != YFilter.not_set or
                        self.partially_programmed_a_cs.yfilter != YFilter.not_set or
                        self.partially_programmed_bridges.yfilter != YFilter.not_set or
                        self.partially_programmed_pseudowires.yfilter != YFilter.not_set or
                        self.standby_pseudowires.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bridge-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.num_vn_is.is_set or self.num_vn_is.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.num_vn_is.get_name_leafdata())
                    if (self.num_vn_is_down.is_set or self.num_vn_is_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.num_vn_is_down.get_name_leafdata())
                    if (self.num_vn_is_unresolved.is_set or self.num_vn_is_unresolved.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.num_vn_is_unresolved.get_name_leafdata())
                    if (self.num_vn_is_up.is_set or self.num_vn_is_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.num_vn_is_up.get_name_leafdata())
                    if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                    if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                    if (self.number_bridge_domains.is_set or self.number_bridge_domains.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_bridge_domains.get_name_leafdata())
                    if (self.number_bridge_domains_shut.is_set or self.number_bridge_domains_shut.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_bridge_domains_shut.get_name_leafdata())
                    if (self.number_bridge_domains_up.is_set or self.number_bridge_domains_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_bridge_domains_up.get_name_leafdata())
                    if (self.number_default_bridge_doamins.is_set or self.number_default_bridge_doamins.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_default_bridge_doamins.get_name_leafdata())
                    if (self.number_groups.is_set or self.number_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_groups.get_name_leafdata())
                    if (self.number_p2mp.is_set or self.number_p2mp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_p2mp.get_name_leafdata())
                    if (self.number_p2mp_down.is_set or self.number_p2mp_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_p2mp_down.get_name_leafdata())
                    if (self.number_p2mp_up.is_set or self.number_p2mp_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_p2mp_up.get_name_leafdata())
                    if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                    if (self.number_pbb_core.is_set or self.number_pbb_core.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_pbb_core.get_name_leafdata())
                    if (self.number_pbb_edge.is_set or self.number_pbb_edge.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_pbb_edge.get_name_leafdata())
                    if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                    if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                    if (self.partially_programmed_a_cs.is_set or self.partially_programmed_a_cs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partially_programmed_a_cs.get_name_leafdata())
                    if (self.partially_programmed_bridges.is_set or self.partially_programmed_bridges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partially_programmed_bridges.get_name_leafdata())
                    if (self.partially_programmed_pseudowires.is_set or self.partially_programmed_pseudowires.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partially_programmed_pseudowires.get_name_leafdata())
                    if (self.standby_pseudowires.is_set or self.standby_pseudowires.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_pseudowires.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "num-vn-is" or name == "num-vn-is-down" or name == "num-vn-is-unresolved" or name == "num-vn-is-up" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-bridge-domains" or name == "number-bridge-domains-shut" or name == "number-bridge-domains-up" or name == "number-default-bridge-doamins" or name == "number-groups" or name == "number-p2mp" or name == "number-p2mp-down" or name == "number-p2mp-up" or name == "number-p-ws-up" or name == "number-pbb-core" or name == "number-pbb-edge" or name == "number-pseudowires" or name == "out-of-memory-state" or name == "partially-programmed-a-cs" or name == "partially-programmed-bridges" or name == "partially-programmed-pseudowires" or name == "standby-pseudowires"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "num-vn-is"):
                        self.num_vn_is = value
                        self.num_vn_is.value_namespace = name_space
                        self.num_vn_is.value_namespace_prefix = name_space_prefix
                    if(value_path == "num-vn-is-down"):
                        self.num_vn_is_down = value
                        self.num_vn_is_down.value_namespace = name_space
                        self.num_vn_is_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "num-vn-is-unresolved"):
                        self.num_vn_is_unresolved = value
                        self.num_vn_is_unresolved.value_namespace = name_space
                        self.num_vn_is_unresolved.value_namespace_prefix = name_space_prefix
                    if(value_path == "num-vn-is-up"):
                        self.num_vn_is_up = value
                        self.num_vn_is_up.value_namespace = name_space
                        self.num_vn_is_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-a-cs"):
                        self.number_a_cs = value
                        self.number_a_cs.value_namespace = name_space
                        self.number_a_cs.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-a-cs-up"):
                        self.number_a_cs_up = value
                        self.number_a_cs_up.value_namespace = name_space
                        self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-bridge-domains"):
                        self.number_bridge_domains = value
                        self.number_bridge_domains.value_namespace = name_space
                        self.number_bridge_domains.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-bridge-domains-shut"):
                        self.number_bridge_domains_shut = value
                        self.number_bridge_domains_shut.value_namespace = name_space
                        self.number_bridge_domains_shut.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-bridge-domains-up"):
                        self.number_bridge_domains_up = value
                        self.number_bridge_domains_up.value_namespace = name_space
                        self.number_bridge_domains_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-default-bridge-doamins"):
                        self.number_default_bridge_doamins = value
                        self.number_default_bridge_doamins.value_namespace = name_space
                        self.number_default_bridge_doamins.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-groups"):
                        self.number_groups = value
                        self.number_groups.value_namespace = name_space
                        self.number_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-p2mp"):
                        self.number_p2mp = value
                        self.number_p2mp.value_namespace = name_space
                        self.number_p2mp.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-p2mp-down"):
                        self.number_p2mp_down = value
                        self.number_p2mp_down.value_namespace = name_space
                        self.number_p2mp_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-p2mp-up"):
                        self.number_p2mp_up = value
                        self.number_p2mp_up.value_namespace = name_space
                        self.number_p2mp_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-p-ws-up"):
                        self.number_p_ws_up = value
                        self.number_p_ws_up.value_namespace = name_space
                        self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-pbb-core"):
                        self.number_pbb_core = value
                        self.number_pbb_core.value_namespace = name_space
                        self.number_pbb_core.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-pbb-edge"):
                        self.number_pbb_edge = value
                        self.number_pbb_edge.value_namespace = name_space
                        self.number_pbb_edge.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-pseudowires"):
                        self.number_pseudowires = value
                        self.number_pseudowires.value_namespace = name_space
                        self.number_pseudowires.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-of-memory-state"):
                        self.out_of_memory_state = value
                        self.out_of_memory_state.value_namespace = name_space
                        self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "partially-programmed-a-cs"):
                        self.partially_programmed_a_cs = value
                        self.partially_programmed_a_cs.value_namespace = name_space
                        self.partially_programmed_a_cs.value_namespace_prefix = name_space_prefix
                    if(value_path == "partially-programmed-bridges"):
                        self.partially_programmed_bridges = value
                        self.partially_programmed_bridges.value_namespace = name_space
                        self.partially_programmed_bridges.value_namespace_prefix = name_space_prefix
                    if(value_path == "partially-programmed-pseudowires"):
                        self.partially_programmed_pseudowires = value
                        self.partially_programmed_pseudowires.value_namespace = name_space
                        self.partially_programmed_pseudowires.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-pseudowires"):
                        self.standby_pseudowires = value
                        self.standby_pseudowires.value_namespace = name_space
                        self.standby_pseudowires.value_namespace_prefix = name_space_prefix


            class Nsr(Entity):
                """
                L2VPN NSR information
                
                .. attribute:: event_history
                
                	L2VPN Process event history
                	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.EventHistory>`
                
                .. attribute:: failover_status
                
                	L2VPN failover status
                	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.FailoverStatus>`
                
                .. attribute:: issu_status
                
                	L2VPN ISSU Status and timestamp
                	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.IssuStatus>`
                
                .. attribute:: nsr_status
                
                	L2VPN NSR status and timestamp
                	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.NsrStatus>`
                
                .. attribute:: process_role
                
                	Current Process Role
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_state
                
                	Current Process State
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: report_card
                
                	L2VPN Collaborator report card
                	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.ReportCard>`
                
                .. attribute:: state_transition_time
                
                	Transition time for all states
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: sw_install_in_progress
                
                	Is s/w install currently in progress?
                	**type**\:  bool
                
                .. attribute:: sync_flags
                
                	Sync complete flags
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: xid_info
                
                	XID information
                	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.XidInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "node"

                    self.process_role = YLeaf(YType.uint8, "process-role")

                    self.process_state = YLeaf(YType.uint8, "process-state")

                    self.state_transition_time = YLeafList(YType.uint32, "state-transition-time")

                    self.sw_install_in_progress = YLeaf(YType.boolean, "sw-install-in-progress")

                    self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                    self.failover_status = L2Vpnv2.Nodes.Node.Nsr.FailoverStatus()
                    self.failover_status.parent = self
                    self._children_name_map["failover_status"] = "failover-status"
                    self._children_yang_names.add("failover-status")

                    self.issu_status = L2Vpnv2.Nodes.Node.Nsr.IssuStatus()
                    self.issu_status.parent = self
                    self._children_name_map["issu_status"] = "issu-status"
                    self._children_yang_names.add("issu-status")

                    self.nsr_status = L2Vpnv2.Nodes.Node.Nsr.NsrStatus()
                    self.nsr_status.parent = self
                    self._children_name_map["nsr_status"] = "nsr-status"
                    self._children_yang_names.add("nsr-status")

                    self.event_history = YList(self)
                    self.report_card = YList(self)
                    self.xid_info = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("process_role",
                                    "process_state",
                                    "state_transition_time",
                                    "sw_install_in_progress",
                                    "sync_flags") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.Nsr, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.Nsr, self).__setattr__(name, value)


                class FailoverStatus(Entity):
                    """
                    L2VPN failover status
                    
                    .. attribute:: master_time
                    
                    	Master time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: start_time
                    
                    	Start time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: triggered_time
                    
                    	Triggered time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Nsr.FailoverStatus, self).__init__()

                        self.yang_name = "failover-status"
                        self.yang_parent_name = "nsr"

                        self.master_time = YLeaf(YType.uint32, "master-time")

                        self.start_time = YLeaf(YType.uint32, "start-time")

                        self.triggered_time = YLeaf(YType.uint32, "triggered-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("master_time",
                                        "start_time",
                                        "triggered_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Nsr.FailoverStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Nsr.FailoverStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.master_time.is_set or
                            self.start_time.is_set or
                            self.triggered_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.master_time.yfilter != YFilter.not_set or
                            self.start_time.yfilter != YFilter.not_set or
                            self.triggered_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "failover-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.master_time.is_set or self.master_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.master_time.get_name_leafdata())
                        if (self.start_time.is_set or self.start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.start_time.get_name_leafdata())
                        if (self.triggered_time.is_set or self.triggered_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.triggered_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "master-time" or name == "start-time" or name == "triggered-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "master-time"):
                            self.master_time = value
                            self.master_time.value_namespace = name_space
                            self.master_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "start-time"):
                            self.start_time = value
                            self.start_time.value_namespace = name_space
                            self.start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "triggered-time"):
                            self.triggered_time = value
                            self.triggered_time.value_namespace = name_space
                            self.triggered_time.value_namespace_prefix = name_space_prefix


                class NsrStatus(Entity):
                    """
                    L2VPN NSR status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Nsr.NsrStatus, self).__init__()

                        self.yang_name = "nsr-status"
                        self.yang_parent_name = "nsr"

                        self.role = YLeaf(YType.enumeration, "role")

                        self.idt_status = L2Vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                        self._children_yang_names.add("idt-status")

                        self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        self._children_yang_names.add("previ-ous-idt-status")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("role") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Nsr.NsrStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Nsr.NsrStatus, self).__setattr__(name, value)


                    class IdtStatus(Entity):
                        """
                        IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus, self).__init__()

                            self.yang_name = "idt-status"
                            self.yang_parent_name = "nsr-status"

                            self.declare_time = YLeaf(YType.uint32, "declare-time")

                            self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                            self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                            self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                            self.sync_status = YLeaf(YType.enumeration, "sync-status")

                            self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("declare_time",
                                            "idt_end_time",
                                            "idt_start_time",
                                            "not_ready_reason",
                                            "sync_status",
                                            "withdraw_time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.declare_time.is_set or
                                self.idt_end_time.is_set or
                                self.idt_start_time.is_set or
                                self.not_ready_reason.is_set or
                                self.sync_status.is_set or
                                self.withdraw_time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.declare_time.yfilter != YFilter.not_set or
                                self.idt_end_time.yfilter != YFilter.not_set or
                                self.idt_start_time.yfilter != YFilter.not_set or
                                self.not_ready_reason.yfilter != YFilter.not_set or
                                self.sync_status.yfilter != YFilter.not_set or
                                self.withdraw_time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "idt-status" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.declare_time.get_name_leafdata())
                            if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                            if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                            if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                            if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sync_status.get_name_leafdata())
                            if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "declare-time"):
                                self.declare_time = value
                                self.declare_time.value_namespace = name_space
                                self.declare_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-end-time"):
                                self.idt_end_time = value
                                self.idt_end_time.value_namespace = name_space
                                self.idt_end_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-start-time"):
                                self.idt_start_time = value
                                self.idt_start_time.value_namespace = name_space
                                self.idt_start_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-ready-reason"):
                                self.not_ready_reason = value
                                self.not_ready_reason.value_namespace = name_space
                                self.not_ready_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "sync-status"):
                                self.sync_status = value
                                self.sync_status.value_namespace = name_space
                                self.sync_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "withdraw-time"):
                                self.withdraw_time = value
                                self.withdraw_time.value_namespace = name_space
                                self.withdraw_time.value_namespace_prefix = name_space_prefix


                    class PreviOusIdtStatus(Entity):
                        """
                        Previous IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus, self).__init__()

                            self.yang_name = "previ-ous-idt-status"
                            self.yang_parent_name = "nsr-status"

                            self.declare_time = YLeaf(YType.uint32, "declare-time")

                            self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                            self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                            self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                            self.sync_status = YLeaf(YType.enumeration, "sync-status")

                            self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("declare_time",
                                            "idt_end_time",
                                            "idt_start_time",
                                            "not_ready_reason",
                                            "sync_status",
                                            "withdraw_time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.declare_time.is_set or
                                self.idt_end_time.is_set or
                                self.idt_start_time.is_set or
                                self.not_ready_reason.is_set or
                                self.sync_status.is_set or
                                self.withdraw_time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.declare_time.yfilter != YFilter.not_set or
                                self.idt_end_time.yfilter != YFilter.not_set or
                                self.idt_start_time.yfilter != YFilter.not_set or
                                self.not_ready_reason.yfilter != YFilter.not_set or
                                self.sync_status.yfilter != YFilter.not_set or
                                self.withdraw_time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "previ-ous-idt-status" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.declare_time.get_name_leafdata())
                            if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                            if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                            if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                            if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sync_status.get_name_leafdata())
                            if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "declare-time"):
                                self.declare_time = value
                                self.declare_time.value_namespace = name_space
                                self.declare_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-end-time"):
                                self.idt_end_time = value
                                self.idt_end_time.value_namespace = name_space
                                self.idt_end_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-start-time"):
                                self.idt_start_time = value
                                self.idt_start_time.value_namespace = name_space
                                self.idt_start_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-ready-reason"):
                                self.not_ready_reason = value
                                self.not_ready_reason.value_namespace = name_space
                                self.not_ready_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "sync-status"):
                                self.sync_status = value
                                self.sync_status.value_namespace = name_space
                                self.sync_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "withdraw-time"):
                                self.withdraw_time = value
                                self.withdraw_time.value_namespace = name_space
                                self.withdraw_time.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.role.is_set or
                            (self.idt_status is not None and self.idt_status.has_data()) or
                            (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.role.yfilter != YFilter.not_set or
                            (self.idt_status is not None and self.idt_status.has_operation()) or
                            (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "nsr-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.role.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "idt-status"):
                            if (self.idt_status is None):
                                self.idt_status = L2Vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus()
                                self.idt_status.parent = self
                                self._children_name_map["idt_status"] = "idt-status"
                            return self.idt_status

                        if (child_yang_name == "previ-ous-idt-status"):
                            if (self.previ_ous_idt_status is None):
                                self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus()
                                self.previ_ous_idt_status.parent = self
                                self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                            return self.previ_ous_idt_status

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "role"):
                            self.role = value
                            self.role.value_namespace = name_space
                            self.role.value_namespace_prefix = name_space_prefix


                class IssuStatus(Entity):
                    """
                    L2VPN ISSU Status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Nsr.IssuStatus, self).__init__()

                        self.yang_name = "issu-status"
                        self.yang_parent_name = "nsr"

                        self.role = YLeaf(YType.enumeration, "role")

                        self.idt_status = L2Vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                        self._children_yang_names.add("idt-status")

                        self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        self._children_yang_names.add("previ-ous-idt-status")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("role") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Nsr.IssuStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Nsr.IssuStatus, self).__setattr__(name, value)


                    class IdtStatus(Entity):
                        """
                        IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus, self).__init__()

                            self.yang_name = "idt-status"
                            self.yang_parent_name = "issu-status"

                            self.declare_time = YLeaf(YType.uint32, "declare-time")

                            self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                            self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                            self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                            self.sync_status = YLeaf(YType.enumeration, "sync-status")

                            self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("declare_time",
                                            "idt_end_time",
                                            "idt_start_time",
                                            "not_ready_reason",
                                            "sync_status",
                                            "withdraw_time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.declare_time.is_set or
                                self.idt_end_time.is_set or
                                self.idt_start_time.is_set or
                                self.not_ready_reason.is_set or
                                self.sync_status.is_set or
                                self.withdraw_time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.declare_time.yfilter != YFilter.not_set or
                                self.idt_end_time.yfilter != YFilter.not_set or
                                self.idt_start_time.yfilter != YFilter.not_set or
                                self.not_ready_reason.yfilter != YFilter.not_set or
                                self.sync_status.yfilter != YFilter.not_set or
                                self.withdraw_time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "idt-status" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.declare_time.get_name_leafdata())
                            if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                            if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                            if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                            if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sync_status.get_name_leafdata())
                            if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "declare-time"):
                                self.declare_time = value
                                self.declare_time.value_namespace = name_space
                                self.declare_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-end-time"):
                                self.idt_end_time = value
                                self.idt_end_time.value_namespace = name_space
                                self.idt_end_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-start-time"):
                                self.idt_start_time = value
                                self.idt_start_time.value_namespace = name_space
                                self.idt_start_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-ready-reason"):
                                self.not_ready_reason = value
                                self.not_ready_reason.value_namespace = name_space
                                self.not_ready_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "sync-status"):
                                self.sync_status = value
                                self.sync_status.value_namespace = name_space
                                self.sync_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "withdraw-time"):
                                self.withdraw_time = value
                                self.withdraw_time.value_namespace = name_space
                                self.withdraw_time.value_namespace_prefix = name_space_prefix


                    class PreviOusIdtStatus(Entity):
                        """
                        Previous IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus, self).__init__()

                            self.yang_name = "previ-ous-idt-status"
                            self.yang_parent_name = "issu-status"

                            self.declare_time = YLeaf(YType.uint32, "declare-time")

                            self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                            self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                            self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                            self.sync_status = YLeaf(YType.enumeration, "sync-status")

                            self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("declare_time",
                                            "idt_end_time",
                                            "idt_start_time",
                                            "not_ready_reason",
                                            "sync_status",
                                            "withdraw_time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.declare_time.is_set or
                                self.idt_end_time.is_set or
                                self.idt_start_time.is_set or
                                self.not_ready_reason.is_set or
                                self.sync_status.is_set or
                                self.withdraw_time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.declare_time.yfilter != YFilter.not_set or
                                self.idt_end_time.yfilter != YFilter.not_set or
                                self.idt_start_time.yfilter != YFilter.not_set or
                                self.not_ready_reason.yfilter != YFilter.not_set or
                                self.sync_status.yfilter != YFilter.not_set or
                                self.withdraw_time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "previ-ous-idt-status" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.declare_time.get_name_leafdata())
                            if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                            if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                            if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                            if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sync_status.get_name_leafdata())
                            if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "declare-time"):
                                self.declare_time = value
                                self.declare_time.value_namespace = name_space
                                self.declare_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-end-time"):
                                self.idt_end_time = value
                                self.idt_end_time.value_namespace = name_space
                                self.idt_end_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-start-time"):
                                self.idt_start_time = value
                                self.idt_start_time.value_namespace = name_space
                                self.idt_start_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-ready-reason"):
                                self.not_ready_reason = value
                                self.not_ready_reason.value_namespace = name_space
                                self.not_ready_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "sync-status"):
                                self.sync_status = value
                                self.sync_status.value_namespace = name_space
                                self.sync_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "withdraw-time"):
                                self.withdraw_time = value
                                self.withdraw_time.value_namespace = name_space
                                self.withdraw_time.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.role.is_set or
                            (self.idt_status is not None and self.idt_status.has_data()) or
                            (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.role.yfilter != YFilter.not_set or
                            (self.idt_status is not None and self.idt_status.has_operation()) or
                            (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "issu-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.role.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "idt-status"):
                            if (self.idt_status is None):
                                self.idt_status = L2Vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus()
                                self.idt_status.parent = self
                                self._children_name_map["idt_status"] = "idt-status"
                            return self.idt_status

                        if (child_yang_name == "previ-ous-idt-status"):
                            if (self.previ_ous_idt_status is None):
                                self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus()
                                self.previ_ous_idt_status.parent = self
                                self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                            return self.previ_ous_idt_status

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "role"):
                            self.role = value
                            self.role.value_namespace = name_space
                            self.role.value_namespace_prefix = name_space_prefix


                class XidInfo(Entity):
                    """
                    XID information
                    
                    .. attribute:: app_type
                    
                    	App type
                    	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
                    
                    .. attribute:: sent_ids
                    
                    	Number of XIDs transferred
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Nsr.XidInfo, self).__init__()

                        self.yang_name = "xid-info"
                        self.yang_parent_name = "nsr"

                        self.app_type = YLeaf(YType.enumeration, "app-type")

                        self.sent_ids = YLeaf(YType.uint32, "sent-ids")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("app_type",
                                        "sent_ids") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Nsr.XidInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Nsr.XidInfo, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.app_type.is_set or
                            self.sent_ids.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.app_type.yfilter != YFilter.not_set or
                            self.sent_ids.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "xid-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.app_type.is_set or self.app_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.app_type.get_name_leafdata())
                        if (self.sent_ids.is_set or self.sent_ids.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sent_ids.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "app-type" or name == "sent-ids"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "app-type"):
                            self.app_type = value
                            self.app_type.value_namespace = name_space
                            self.app_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "sent-ids"):
                            self.sent_ids = value
                            self.sent_ids.value_namespace = name_space
                            self.sent_ids.value_namespace_prefix = name_space_prefix


                class ReportCard(Entity):
                    """
                    L2VPN Collaborator report card
                    
                    .. attribute:: collaborator_idt_done
                    
                    	Is IDT done for this collaborator
                    	**type**\:  bool
                    
                    .. attribute:: collaborator_is_connected
                    
                    	Is the collaborator connected
                    	**type**\:  bool
                    
                    .. attribute:: collaborator_skipped
                    
                    	Was this collaborator skipped for not connecting in time
                    	**type**\:  bool
                    
                    .. attribute:: connection_change_time
                    
                    	Time when connection state (UP/DOWN) changed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idt_time
                    
                    	Time when IDT was done
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Nsr.ReportCard, self).__init__()

                        self.yang_name = "report-card"
                        self.yang_parent_name = "nsr"

                        self.collaborator_idt_done = YLeaf(YType.boolean, "collaborator-idt-done")

                        self.collaborator_is_connected = YLeaf(YType.boolean, "collaborator-is-connected")

                        self.collaborator_skipped = YLeaf(YType.boolean, "collaborator-skipped")

                        self.connection_change_time = YLeaf(YType.uint32, "connection-change-time")

                        self.idt_time = YLeaf(YType.uint32, "idt-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("collaborator_idt_done",
                                        "collaborator_is_connected",
                                        "collaborator_skipped",
                                        "connection_change_time",
                                        "idt_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Nsr.ReportCard, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Nsr.ReportCard, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.collaborator_idt_done.is_set or
                            self.collaborator_is_connected.is_set or
                            self.collaborator_skipped.is_set or
                            self.connection_change_time.is_set or
                            self.idt_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.collaborator_idt_done.yfilter != YFilter.not_set or
                            self.collaborator_is_connected.yfilter != YFilter.not_set or
                            self.collaborator_skipped.yfilter != YFilter.not_set or
                            self.connection_change_time.yfilter != YFilter.not_set or
                            self.idt_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "report-card" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.collaborator_idt_done.is_set or self.collaborator_idt_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.collaborator_idt_done.get_name_leafdata())
                        if (self.collaborator_is_connected.is_set or self.collaborator_is_connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.collaborator_is_connected.get_name_leafdata())
                        if (self.collaborator_skipped.is_set or self.collaborator_skipped.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.collaborator_skipped.get_name_leafdata())
                        if (self.connection_change_time.is_set or self.connection_change_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.connection_change_time.get_name_leafdata())
                        if (self.idt_time.is_set or self.idt_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "collaborator-idt-done" or name == "collaborator-is-connected" or name == "collaborator-skipped" or name == "connection-change-time" or name == "idt-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "collaborator-idt-done"):
                            self.collaborator_idt_done = value
                            self.collaborator_idt_done.value_namespace = name_space
                            self.collaborator_idt_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "collaborator-is-connected"):
                            self.collaborator_is_connected = value
                            self.collaborator_is_connected.value_namespace = name_space
                            self.collaborator_is_connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "collaborator-skipped"):
                            self.collaborator_skipped = value
                            self.collaborator_skipped.value_namespace = name_space
                            self.collaborator_skipped.value_namespace_prefix = name_space_prefix
                        if(value_path == "connection-change-time"):
                            self.connection_change_time = value
                            self.connection_change_time.value_namespace = name_space
                            self.connection_change_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-time"):
                            self.idt_time = value
                            self.idt_time.value_namespace = name_space
                            self.idt_time.value_namespace_prefix = name_space_prefix


                class EventHistory(Entity):
                    """
                    L2VPN Process event history
                    
                    .. attribute:: event_timestamp
                    
                    	Event timestamp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: new_state
                    
                    	New state
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: previous_state
                    
                    	Previous state
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: process_collaborator
                    
                    	Process collaborator
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: process_event
                    
                    	Process event
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Nsr.EventHistory, self).__init__()

                        self.yang_name = "event-history"
                        self.yang_parent_name = "nsr"

                        self.event_timestamp = YLeaf(YType.uint32, "event-timestamp")

                        self.new_state = YLeaf(YType.uint8, "new-state")

                        self.previous_state = YLeaf(YType.uint8, "previous-state")

                        self.process_collaborator = YLeaf(YType.uint16, "process-collaborator")

                        self.process_event = YLeaf(YType.uint16, "process-event")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("event_timestamp",
                                        "new_state",
                                        "previous_state",
                                        "process_collaborator",
                                        "process_event") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Nsr.EventHistory, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Nsr.EventHistory, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.event_timestamp.is_set or
                            self.new_state.is_set or
                            self.previous_state.is_set or
                            self.process_collaborator.is_set or
                            self.process_event.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.event_timestamp.yfilter != YFilter.not_set or
                            self.new_state.yfilter != YFilter.not_set or
                            self.previous_state.yfilter != YFilter.not_set or
                            self.process_collaborator.yfilter != YFilter.not_set or
                            self.process_event.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "event-history" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.event_timestamp.is_set or self.event_timestamp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.event_timestamp.get_name_leafdata())
                        if (self.new_state.is_set or self.new_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.new_state.get_name_leafdata())
                        if (self.previous_state.is_set or self.previous_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.previous_state.get_name_leafdata())
                        if (self.process_collaborator.is_set or self.process_collaborator.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.process_collaborator.get_name_leafdata())
                        if (self.process_event.is_set or self.process_event.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.process_event.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "event-timestamp" or name == "new-state" or name == "previous-state" or name == "process-collaborator" or name == "process-event"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "event-timestamp"):
                            self.event_timestamp = value
                            self.event_timestamp.value_namespace = name_space
                            self.event_timestamp.value_namespace_prefix = name_space_prefix
                        if(value_path == "new-state"):
                            self.new_state = value
                            self.new_state.value_namespace = name_space
                            self.new_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "previous-state"):
                            self.previous_state = value
                            self.previous_state.value_namespace = name_space
                            self.previous_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "process-collaborator"):
                            self.process_collaborator = value
                            self.process_collaborator.value_namespace = name_space
                            self.process_collaborator.value_namespace_prefix = name_space_prefix
                        if(value_path == "process-event"):
                            self.process_event = value
                            self.process_event.value_namespace = name_space
                            self.process_event.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.event_history:
                        if (c.has_data()):
                            return True
                    for c in self.report_card:
                        if (c.has_data()):
                            return True
                    for c in self.xid_info:
                        if (c.has_data()):
                            return True
                    for leaf in self.state_transition_time.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.process_role.is_set or
                        self.process_state.is_set or
                        self.sw_install_in_progress.is_set or
                        self.sync_flags.is_set or
                        (self.failover_status is not None and self.failover_status.has_data()) or
                        (self.issu_status is not None and self.issu_status.has_data()) or
                        (self.nsr_status is not None and self.nsr_status.has_data()))

                def has_operation(self):
                    for c in self.event_history:
                        if (c.has_operation()):
                            return True
                    for c in self.report_card:
                        if (c.has_operation()):
                            return True
                    for c in self.xid_info:
                        if (c.has_operation()):
                            return True
                    for leaf in self.state_transition_time.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.process_role.yfilter != YFilter.not_set or
                        self.process_state.yfilter != YFilter.not_set or
                        self.state_transition_time.yfilter != YFilter.not_set or
                        self.sw_install_in_progress.yfilter != YFilter.not_set or
                        self.sync_flags.yfilter != YFilter.not_set or
                        (self.failover_status is not None and self.failover_status.has_operation()) or
                        (self.issu_status is not None and self.issu_status.has_operation()) or
                        (self.nsr_status is not None and self.nsr_status.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.process_role.is_set or self.process_role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_role.get_name_leafdata())
                    if (self.process_state.is_set or self.process_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_state.get_name_leafdata())
                    if (self.sw_install_in_progress.is_set or self.sw_install_in_progress.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sw_install_in_progress.get_name_leafdata())
                    if (self.sync_flags.is_set or self.sync_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_flags.get_name_leafdata())

                    leaf_name_data.extend(self.state_transition_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "event-history"):
                        for c in self.event_history:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.Nsr.EventHistory()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.event_history.append(c)
                        return c

                    if (child_yang_name == "failover-status"):
                        if (self.failover_status is None):
                            self.failover_status = L2Vpnv2.Nodes.Node.Nsr.FailoverStatus()
                            self.failover_status.parent = self
                            self._children_name_map["failover_status"] = "failover-status"
                        return self.failover_status

                    if (child_yang_name == "issu-status"):
                        if (self.issu_status is None):
                            self.issu_status = L2Vpnv2.Nodes.Node.Nsr.IssuStatus()
                            self.issu_status.parent = self
                            self._children_name_map["issu_status"] = "issu-status"
                        return self.issu_status

                    if (child_yang_name == "nsr-status"):
                        if (self.nsr_status is None):
                            self.nsr_status = L2Vpnv2.Nodes.Node.Nsr.NsrStatus()
                            self.nsr_status.parent = self
                            self._children_name_map["nsr_status"] = "nsr-status"
                        return self.nsr_status

                    if (child_yang_name == "report-card"):
                        for c in self.report_card:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.Nsr.ReportCard()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.report_card.append(c)
                        return c

                    if (child_yang_name == "xid-info"):
                        for c in self.xid_info:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.Nsr.XidInfo()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.xid_info.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "event-history" or name == "failover-status" or name == "issu-status" or name == "nsr-status" or name == "report-card" or name == "xid-info" or name == "process-role" or name == "process-state" or name == "state-transition-time" or name == "sw-install-in-progress" or name == "sync-flags"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "process-role"):
                        self.process_role = value
                        self.process_role.value_namespace = name_space
                        self.process_role.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-state"):
                        self.process_state = value
                        self.process_state.value_namespace = name_space
                        self.process_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "state-transition-time"):
                        self.state_transition_time.append(value)
                    if(value_path == "sw-install-in-progress"):
                        self.sw_install_in_progress = value
                        self.sw_install_in_progress.value_namespace = name_space
                        self.sw_install_in_progress.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-flags"):
                        self.sync_flags = value
                        self.sync_flags.value_namespace = name_space
                        self.sync_flags.value_namespace_prefix = name_space_prefix


            class GlobalSettings(Entity):
                """
                L2VPN global settings
                
                .. attribute:: going_active
                
                	transitioning to Active functional role
                	**type**\:  bool
                
                .. attribute:: ha_role
                
                	Node redundancy role
                	**type**\:  str
                
                .. attribute:: issu_role
                
                	Node ISSU role
                	**type**\:  str
                
                .. attribute:: logging_bd_enabled
                
                	Logging BD state changes enabled
                	**type**\:  bool
                
                .. attribute:: logging_df_election_enabled
                
                	Logging EVPN Designated Forwarder changes enabled
                	**type**\:  bool
                
                .. attribute:: logging_nsr_enabled
                
                	Logging NSR state changes enabled
                	**type**\:  bool
                
                .. attribute:: logging_pw_enabled
                
                	Logging PW enabled
                	**type**\:  bool
                
                .. attribute:: logging_vfi_enabled
                
                	Logging VFI state changes enabled
                	**type**\:  bool
                
                .. attribute:: process_fsm
                
                	Current L2VPN FSM role
                	**type**\:  str
                
                .. attribute:: pw_grouping_enabled
                
                	PW Grouping enabled
                	**type**\:  bool
                
                .. attribute:: pw_oam_refresh_transmit_time
                
                	PW OAM refresh transmit (seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: pw_status_enabled
                
                	PW Status enabled
                	**type**\:  bool
                
                .. attribute:: tcn_propagation_enabled
                
                	TCN propagation enabled
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.GlobalSettings, self).__init__()

                    self.yang_name = "global-settings"
                    self.yang_parent_name = "node"

                    self.going_active = YLeaf(YType.boolean, "going-active")

                    self.ha_role = YLeaf(YType.str, "ha-role")

                    self.issu_role = YLeaf(YType.str, "issu-role")

                    self.logging_bd_enabled = YLeaf(YType.boolean, "logging-bd-enabled")

                    self.logging_df_election_enabled = YLeaf(YType.boolean, "logging-df-election-enabled")

                    self.logging_nsr_enabled = YLeaf(YType.boolean, "logging-nsr-enabled")

                    self.logging_pw_enabled = YLeaf(YType.boolean, "logging-pw-enabled")

                    self.logging_vfi_enabled = YLeaf(YType.boolean, "logging-vfi-enabled")

                    self.process_fsm = YLeaf(YType.str, "process-fsm")

                    self.pw_grouping_enabled = YLeaf(YType.boolean, "pw-grouping-enabled")

                    self.pw_oam_refresh_transmit_time = YLeaf(YType.uint32, "pw-oam-refresh-transmit-time")

                    self.pw_status_enabled = YLeaf(YType.boolean, "pw-status-enabled")

                    self.tcn_propagation_enabled = YLeaf(YType.boolean, "tcn-propagation-enabled")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("going_active",
                                    "ha_role",
                                    "issu_role",
                                    "logging_bd_enabled",
                                    "logging_df_election_enabled",
                                    "logging_nsr_enabled",
                                    "logging_pw_enabled",
                                    "logging_vfi_enabled",
                                    "process_fsm",
                                    "pw_grouping_enabled",
                                    "pw_oam_refresh_transmit_time",
                                    "pw_status_enabled",
                                    "tcn_propagation_enabled") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.GlobalSettings, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.GlobalSettings, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.going_active.is_set or
                        self.ha_role.is_set or
                        self.issu_role.is_set or
                        self.logging_bd_enabled.is_set or
                        self.logging_df_election_enabled.is_set or
                        self.logging_nsr_enabled.is_set or
                        self.logging_pw_enabled.is_set or
                        self.logging_vfi_enabled.is_set or
                        self.process_fsm.is_set or
                        self.pw_grouping_enabled.is_set or
                        self.pw_oam_refresh_transmit_time.is_set or
                        self.pw_status_enabled.is_set or
                        self.tcn_propagation_enabled.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.going_active.yfilter != YFilter.not_set or
                        self.ha_role.yfilter != YFilter.not_set or
                        self.issu_role.yfilter != YFilter.not_set or
                        self.logging_bd_enabled.yfilter != YFilter.not_set or
                        self.logging_df_election_enabled.yfilter != YFilter.not_set or
                        self.logging_nsr_enabled.yfilter != YFilter.not_set or
                        self.logging_pw_enabled.yfilter != YFilter.not_set or
                        self.logging_vfi_enabled.yfilter != YFilter.not_set or
                        self.process_fsm.yfilter != YFilter.not_set or
                        self.pw_grouping_enabled.yfilter != YFilter.not_set or
                        self.pw_oam_refresh_transmit_time.yfilter != YFilter.not_set or
                        self.pw_status_enabled.yfilter != YFilter.not_set or
                        self.tcn_propagation_enabled.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-settings" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.going_active.is_set or self.going_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.going_active.get_name_leafdata())
                    if (self.ha_role.is_set or self.ha_role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ha_role.get_name_leafdata())
                    if (self.issu_role.is_set or self.issu_role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.issu_role.get_name_leafdata())
                    if (self.logging_bd_enabled.is_set or self.logging_bd_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.logging_bd_enabled.get_name_leafdata())
                    if (self.logging_df_election_enabled.is_set or self.logging_df_election_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.logging_df_election_enabled.get_name_leafdata())
                    if (self.logging_nsr_enabled.is_set or self.logging_nsr_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.logging_nsr_enabled.get_name_leafdata())
                    if (self.logging_pw_enabled.is_set or self.logging_pw_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.logging_pw_enabled.get_name_leafdata())
                    if (self.logging_vfi_enabled.is_set or self.logging_vfi_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.logging_vfi_enabled.get_name_leafdata())
                    if (self.process_fsm.is_set or self.process_fsm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_fsm.get_name_leafdata())
                    if (self.pw_grouping_enabled.is_set or self.pw_grouping_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pw_grouping_enabled.get_name_leafdata())
                    if (self.pw_oam_refresh_transmit_time.is_set or self.pw_oam_refresh_transmit_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pw_oam_refresh_transmit_time.get_name_leafdata())
                    if (self.pw_status_enabled.is_set or self.pw_status_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pw_status_enabled.get_name_leafdata())
                    if (self.tcn_propagation_enabled.is_set or self.tcn_propagation_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tcn_propagation_enabled.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "going-active" or name == "ha-role" or name == "issu-role" or name == "logging-bd-enabled" or name == "logging-df-election-enabled" or name == "logging-nsr-enabled" or name == "logging-pw-enabled" or name == "logging-vfi-enabled" or name == "process-fsm" or name == "pw-grouping-enabled" or name == "pw-oam-refresh-transmit-time" or name == "pw-status-enabled" or name == "tcn-propagation-enabled"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "going-active"):
                        self.going_active = value
                        self.going_active.value_namespace = name_space
                        self.going_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "ha-role"):
                        self.ha_role = value
                        self.ha_role.value_namespace = name_space
                        self.ha_role.value_namespace_prefix = name_space_prefix
                    if(value_path == "issu-role"):
                        self.issu_role = value
                        self.issu_role.value_namespace = name_space
                        self.issu_role.value_namespace_prefix = name_space_prefix
                    if(value_path == "logging-bd-enabled"):
                        self.logging_bd_enabled = value
                        self.logging_bd_enabled.value_namespace = name_space
                        self.logging_bd_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "logging-df-election-enabled"):
                        self.logging_df_election_enabled = value
                        self.logging_df_election_enabled.value_namespace = name_space
                        self.logging_df_election_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "logging-nsr-enabled"):
                        self.logging_nsr_enabled = value
                        self.logging_nsr_enabled.value_namespace = name_space
                        self.logging_nsr_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "logging-pw-enabled"):
                        self.logging_pw_enabled = value
                        self.logging_pw_enabled.value_namespace = name_space
                        self.logging_pw_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "logging-vfi-enabled"):
                        self.logging_vfi_enabled = value
                        self.logging_vfi_enabled.value_namespace = name_space
                        self.logging_vfi_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-fsm"):
                        self.process_fsm = value
                        self.process_fsm.value_namespace = name_space
                        self.process_fsm.value_namespace_prefix = name_space_prefix
                    if(value_path == "pw-grouping-enabled"):
                        self.pw_grouping_enabled = value
                        self.pw_grouping_enabled.value_namespace = name_space
                        self.pw_grouping_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "pw-oam-refresh-transmit-time"):
                        self.pw_oam_refresh_transmit_time = value
                        self.pw_oam_refresh_transmit_time.value_namespace = name_space
                        self.pw_oam_refresh_transmit_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "pw-status-enabled"):
                        self.pw_status_enabled = value
                        self.pw_status_enabled.value_namespace = name_space
                        self.pw_status_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "tcn-propagation-enabled"):
                        self.tcn_propagation_enabled = value
                        self.tcn_propagation_enabled.value_namespace = name_space
                        self.tcn_propagation_enabled.value_namespace_prefix = name_space_prefix


            class Pwr(Entity):
                """
                Pseudowire Routing Table
                
                .. attribute:: summary
                
                	L2VPN Pseudowire Routing Summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.Pwr, self).__init__()

                    self.yang_name = "pwr"
                    self.yang_parent_name = "node"

                    self.summary = L2Vpnv2.Nodes.Node.Pwr.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")


                class Summary(Entity):
                    """
                    L2VPN Pseudowire Routing Summary
                    
                    .. attribute:: bgp_as
                    
                    	BGP AS number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_router_id
                    
                    	BGP Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cfg_global_id
                    
                    	Configured Global ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: cfg_router_id
                    
                    	Configured Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: l2vpn_has_bgp_eod
                    
                    	L2VPN got BGP EOD
                    	**type**\:  bool
                    
                    .. attribute:: rd_auto
                    
                    	Automatic Route Distingtuisher
                    	**type**\:   :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto>`
                    
                    .. attribute:: rd_configured
                    
                    	Configured Route Distinguisher
                    	**type**\:   :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Pwr.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "pwr"

                        self.bgp_as = YLeaf(YType.uint32, "bgp-as")

                        self.bgp_router_id = YLeaf(YType.str, "bgp-router-id")

                        self.cfg_global_id = YLeaf(YType.uint32, "cfg-global-id")

                        self.cfg_router_id = YLeaf(YType.str, "cfg-router-id")

                        self.l2vpn_has_bgp_eod = YLeaf(YType.boolean, "l2vpn-has-bgp-eod")

                        self.rd_auto = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto()
                        self.rd_auto.parent = self
                        self._children_name_map["rd_auto"] = "rd-auto"
                        self._children_yang_names.add("rd-auto")

                        self.rd_configured = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured()
                        self.rd_configured.parent = self
                        self._children_name_map["rd_configured"] = "rd-configured"
                        self._children_yang_names.add("rd-configured")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bgp_as",
                                        "bgp_router_id",
                                        "cfg_global_id",
                                        "cfg_router_id",
                                        "l2vpn_has_bgp_eod") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Pwr.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Pwr.Summary, self).__setattr__(name, value)


                    class RdAuto(Entity):
                        """
                        Automatic Route Distingtuisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto, self).__init__()

                            self.yang_name = "rd-auto"
                            self.yang_parent_name = "summary"

                            self.rd = YLeaf(YType.enumeration, "rd")

                            self.auto = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"
                            self._children_yang_names.add("auto")

                            self.four_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                            self._children_yang_names.add("four-byte-as")

                            self.two_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rd") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto, self).__setattr__(name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd-auto"

                                self.auto_index = YLeaf(YType.uint16, "auto-index")

                                self.router_id = YLeaf(YType.str, "router-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("auto_index",
                                                "router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.auto_index.is_set or
                                    self.router_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.auto_index.yfilter != YFilter.not_set or
                                    self.router_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "auto" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_index.get_name_leafdata())
                                if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto-index" or name == "router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "auto-index"):
                                    self.auto_index = value
                                    self.auto_index.value_namespace = name_space
                                    self.auto_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-id"):
                                    self.router_id = value
                                    self.router_id.value_namespace = name_space
                                    self.router_id.value_namespace_prefix = name_space_prefix


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd-auto"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd-auto"

                                self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_as",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_as.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_as.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "four-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-as" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-as"):
                                    self.four_byte_as = value
                                    self.four_byte_as.value_namespace = name_space
                                    self.four_byte_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd-auto"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.rd.is_set or
                                (self.auto is not None and self.auto.has_data()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rd.yfilter != YFilter.not_set or
                                (self.auto is not None and self.auto.has_operation()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rd-auto" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rd.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "auto"):
                                if (self.auto is None):
                                    self.auto = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                return self.auto

                            if (child_yang_name == "four-byte-as"):
                                if (self.four_byte_as is None):
                                    self.four_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                return self.four_byte_as

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rd"):
                                self.rd = value
                                self.rd.value_namespace = name_space
                                self.rd.value_namespace_prefix = name_space_prefix


                    class RdConfigured(Entity):
                        """
                        Configured Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured, self).__init__()

                            self.yang_name = "rd-configured"
                            self.yang_parent_name = "summary"

                            self.rd = YLeaf(YType.enumeration, "rd")

                            self.auto = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"
                            self._children_yang_names.add("auto")

                            self.four_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                            self._children_yang_names.add("four-byte-as")

                            self.two_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rd") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured, self).__setattr__(name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd-configured"

                                self.auto_index = YLeaf(YType.uint16, "auto-index")

                                self.router_id = YLeaf(YType.str, "router-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("auto_index",
                                                "router_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.auto_index.is_set or
                                    self.router_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.auto_index.yfilter != YFilter.not_set or
                                    self.router_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "auto" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_index.get_name_leafdata())
                                if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto-index" or name == "router-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "auto-index"):
                                    self.auto_index = value
                                    self.auto_index.value_namespace = name_space
                                    self.auto_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-id"):
                                    self.router_id = value
                                    self.router_id.value_namespace = name_space
                                    self.router_id.value_namespace_prefix = name_space_prefix


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd-configured"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd-configured"

                                self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_as",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_as.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_as.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "four-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-as" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-as"):
                                    self.four_byte_as = value
                                    self.four_byte_as.value_namespace = name_space
                                    self.four_byte_as.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd-configured"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.rd.is_set or
                                (self.auto is not None and self.auto.has_data()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rd.yfilter != YFilter.not_set or
                                (self.auto is not None and self.auto.has_operation()) or
                                (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rd-configured" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rd.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "auto"):
                                if (self.auto is None):
                                    self.auto = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                return self.auto

                            if (child_yang_name == "four-byte-as"):
                                if (self.four_byte_as is None):
                                    self.four_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"
                                return self.four_byte_as

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rd"):
                                self.rd = value
                                self.rd.value_namespace = name_space
                                self.rd.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bgp_as.is_set or
                            self.bgp_router_id.is_set or
                            self.cfg_global_id.is_set or
                            self.cfg_router_id.is_set or
                            self.l2vpn_has_bgp_eod.is_set or
                            (self.rd_auto is not None and self.rd_auto.has_data()) or
                            (self.rd_configured is not None and self.rd_configured.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bgp_as.yfilter != YFilter.not_set or
                            self.bgp_router_id.yfilter != YFilter.not_set or
                            self.cfg_global_id.yfilter != YFilter.not_set or
                            self.cfg_router_id.yfilter != YFilter.not_set or
                            self.l2vpn_has_bgp_eod.yfilter != YFilter.not_set or
                            (self.rd_auto is not None and self.rd_auto.has_operation()) or
                            (self.rd_configured is not None and self.rd_configured.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bgp_as.is_set or self.bgp_as.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_as.get_name_leafdata())
                        if (self.bgp_router_id.is_set or self.bgp_router_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_router_id.get_name_leafdata())
                        if (self.cfg_global_id.is_set or self.cfg_global_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cfg_global_id.get_name_leafdata())
                        if (self.cfg_router_id.is_set or self.cfg_router_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cfg_router_id.get_name_leafdata())
                        if (self.l2vpn_has_bgp_eod.is_set or self.l2vpn_has_bgp_eod.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.l2vpn_has_bgp_eod.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rd-auto"):
                            if (self.rd_auto is None):
                                self.rd_auto = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto()
                                self.rd_auto.parent = self
                                self._children_name_map["rd_auto"] = "rd-auto"
                            return self.rd_auto

                        if (child_yang_name == "rd-configured"):
                            if (self.rd_configured is None):
                                self.rd_configured = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured()
                                self.rd_configured.parent = self
                                self._children_name_map["rd_configured"] = "rd-configured"
                            return self.rd_configured

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rd-auto" or name == "rd-configured" or name == "bgp-as" or name == "bgp-router-id" or name == "cfg-global-id" or name == "cfg-router-id" or name == "l2vpn-has-bgp-eod"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bgp-as"):
                            self.bgp_as = value
                            self.bgp_as.value_namespace = name_space
                            self.bgp_as.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-router-id"):
                            self.bgp_router_id = value
                            self.bgp_router_id.value_namespace = name_space
                            self.bgp_router_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "cfg-global-id"):
                            self.cfg_global_id = value
                            self.cfg_global_id.value_namespace = name_space
                            self.cfg_global_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "cfg-router-id"):
                            self.cfg_router_id = value
                            self.cfg_router_id.value_namespace = name_space
                            self.cfg_router_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "l2vpn-has-bgp-eod"):
                            self.l2vpn_has_bgp_eod = value
                            self.l2vpn_has_bgp_eod.value_namespace = name_space
                            self.l2vpn_has_bgp_eod.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.summary is not None and self.summary.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.summary is not None and self.summary.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pwr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = L2Vpnv2.Nodes.Node.Pwr.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class XconnectMp2MpCe2Ces(Entity):
                """
                XConnect MP2MP CE2CE Table
                
                .. attribute:: xconnect_mp2mp_ce2ce
                
                	XConnect MP2MP CE2CE information
                	**type**\: list of    :py:class:`XconnectMp2MpCe2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces, self).__init__()

                    self.yang_name = "xconnect-mp2mp-ce2ces"
                    self.yang_parent_name = "node"

                    self.xconnect_mp2mp_ce2ce = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces, self).__setattr__(name, value)


                class XconnectMp2MpCe2Ce(Entity):
                    """
                    XConnect MP2MP CE2CE information
                    
                    .. attribute:: ce_added
                    
                    	CE2CE Advertised
                    	**type**\:  bool
                    
                    .. attribute:: group_name
                    
                    	XConnect Group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: local_ceid
                    
                    	Local CE ID
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: local_customer_edge_id
                    
                    	Local CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: mp2_mp_name
                    
                    	Mp2Mp Name
                    	**type**\:  str
                    
                    	**length:** 1..26
                    
                    .. attribute:: remote_ceid
                    
                    	Remote CE ID
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: remote_customer_edge_id
                    
                    	Remote CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__init__()

                        self.yang_name = "xconnect-mp2mp-ce2ce"
                        self.yang_parent_name = "xconnect-mp2mp-ce2ces"

                        self.ce_added = YLeaf(YType.boolean, "ce-added")

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                        self.local_customer_edge_id = YLeaf(YType.uint16, "local-customer-edge-id")

                        self.mp2_mp_name = YLeaf(YType.str, "mp2-mp-name")

                        self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                        self.remote_customer_edge_id = YLeaf(YType.uint16, "remote-customer-edge-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ce_added",
                                        "group_name",
                                        "local_ceid",
                                        "local_customer_edge_id",
                                        "mp2_mp_name",
                                        "remote_ceid",
                                        "remote_customer_edge_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ce_added.is_set or
                            self.group_name.is_set or
                            self.local_ceid.is_set or
                            self.local_customer_edge_id.is_set or
                            self.mp2_mp_name.is_set or
                            self.remote_ceid.is_set or
                            self.remote_customer_edge_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ce_added.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.local_ceid.yfilter != YFilter.not_set or
                            self.local_customer_edge_id.yfilter != YFilter.not_set or
                            self.mp2_mp_name.yfilter != YFilter.not_set or
                            self.remote_ceid.yfilter != YFilter.not_set or
                            self.remote_customer_edge_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "xconnect-mp2mp-ce2ce" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ce_added.is_set or self.ce_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ce_added.get_name_leafdata())
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_ceid.get_name_leafdata())
                        if (self.local_customer_edge_id.is_set or self.local_customer_edge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_customer_edge_id.get_name_leafdata())
                        if (self.mp2_mp_name.is_set or self.mp2_mp_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mp2_mp_name.get_name_leafdata())
                        if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                        if (self.remote_customer_edge_id.is_set or self.remote_customer_edge_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_customer_edge_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ce-added" or name == "group-name" or name == "local-ceid" or name == "local-customer-edge-id" or name == "mp2-mp-name" or name == "remote-ceid" or name == "remote-customer-edge-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ce-added"):
                            self.ce_added = value
                            self.ce_added.value_namespace = name_space
                            self.ce_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-ceid"):
                            self.local_ceid = value
                            self.local_ceid.value_namespace = name_space
                            self.local_ceid.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-customer-edge-id"):
                            self.local_customer_edge_id = value
                            self.local_customer_edge_id.value_namespace = name_space
                            self.local_customer_edge_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mp2-mp-name"):
                            self.mp2_mp_name = value
                            self.mp2_mp_name.value_namespace = name_space
                            self.mp2_mp_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-ceid"):
                            self.remote_ceid = value
                            self.remote_ceid.value_namespace = name_space
                            self.remote_ceid.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-customer-edge-id"):
                            self.remote_customer_edge_id = value
                            self.remote_customer_edge_id.value_namespace = name_space
                            self.remote_customer_edge_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.xconnect_mp2mp_ce2ce:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.xconnect_mp2mp_ce2ce:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-mp2mp-ce2ces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "xconnect-mp2mp-ce2ce"):
                        for c in self.xconnect_mp2mp_ce2ce:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.xconnect_mp2mp_ce2ce.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "xconnect-mp2mp-ce2ce"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Xconnects(Entity):
                """
                XConnect Table
                
                .. attribute:: xconnect
                
                	XConnect information
                	**type**\: list of    :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.Xconnects, self).__init__()

                    self.yang_name = "xconnects"
                    self.yang_parent_name = "node"

                    self.xconnect = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.Xconnects, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.Xconnects, self).__setattr__(name, value)


                class Xconnect(Entity):
                    """
                    XConnect information
                    
                    .. attribute:: backup
                    
                    	LCR backup
                    	**type**\:   :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup>`
                    
                    .. attribute:: backup_segment
                    
                    	Backup Segment
                    	**type**\: list of    :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment>`
                    
                    .. attribute:: ce2ce
                    
                    	CE2CE
                    	**type**\:   :py:class:`Ce2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2Ce>`
                    
                    .. attribute:: description
                    
                    	P2P Description
                    	**type**\:  str
                    
                    .. attribute:: diag_mask
                    
                    	Mask indicating what if anything is missing before the XC can be provisioned
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_name
                    
                    	XConnect Group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                    
                    .. attribute:: is_mp2mp
                    
                    	xconnect is mp2mp
                    	**type**\:  bool
                    
                    .. attribute:: number_of_backup_p_ws
                    
                    	Number of backups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: segment1
                    
                    	Segment 1
                    	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment 2
                    	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2>`
                    
                    .. attribute:: state
                    
                    	State of the xconnect
                    	**type**\:   :py:class:`L2VpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcState>`
                    
                    .. attribute:: xconnect_name
                    
                    	XConnect Name
                    	**type**\:  str
                    
                    	**length:** 1..38
                    
                    .. attribute:: xconnect_name_xr
                    
                    	XConnect name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect, self).__init__()

                        self.yang_name = "xconnect"
                        self.yang_parent_name = "xconnects"

                        self.description = YLeaf(YType.str, "description")

                        self.diag_mask = YLeaf(YType.uint32, "diag-mask")

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                        self.interworking = YLeaf(YType.enumeration, "interworking")

                        self.is_mp2mp = YLeaf(YType.boolean, "is-mp2mp")

                        self.number_of_backup_p_ws = YLeaf(YType.uint32, "number-of-backup-p-ws")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.xconnect_name = YLeaf(YType.str, "xconnect-name")

                        self.xconnect_name_xr = YLeaf(YType.str, "xconnect-name-xr")

                        self.backup = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"
                        self._children_yang_names.add("backup")

                        self.ce2ce = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2Ce()
                        self.ce2ce.parent = self
                        self._children_name_map["ce2ce"] = "ce2ce"
                        self._children_yang_names.add("ce2ce")

                        self.segment1 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"
                        self._children_yang_names.add("segment1")

                        self.segment2 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"
                        self._children_yang_names.add("segment2")

                        self.backup_segment = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("description",
                                        "diag_mask",
                                        "group_name",
                                        "group_name_xr",
                                        "interworking",
                                        "is_mp2mp",
                                        "number_of_backup_p_ws",
                                        "state",
                                        "xconnect_name",
                                        "xconnect_name_xr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect, self).__setattr__(name, value)


                    class Backup(Entity):
                        """
                        LCR backup
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup, self).__init__()

                            self.yang_name = "backup"
                            self.yang_parent_name = "xconnect"

                            self.segment_type = YLeaf(YType.enumeration, "segment-type")

                            self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            self._children_yang_names.add("attachment-circuit")

                            self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            self._children_yang_names.add("pseudo-wire")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("segment_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup, self).__setattr__(name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "backup"

                                self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                                self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                                self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                                self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                                self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                                self.msti = YLeaf(YType.str, "msti")

                                self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.node_id = YLeaf(YType.str, "node-id")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._children_yang_names.add("interface")

                                self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._children_yang_names.add("l2vpn-protection")

                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bvi_mac_conflict",
                                                "bvi_no_port_up",
                                                "control_word_mismatched",
                                                "encapsulation_error",
                                                "encapsulation_mismatched",
                                                "evpn_internal_label",
                                                "interface_handle",
                                                "internal_ms_ti",
                                                "interworking",
                                                "is_ac_partially_programmed",
                                                "mac_limit_oper_down",
                                                "ms_ti_mismatch",
                                                "msti",
                                                "msti_mismatch_down",
                                                "mtu_mismatched",
                                                "node_id",
                                                "out_of_memory_state",
                                                "redundancy_group_id",
                                                "redundancy_group_state",
                                                "redundancy_object_id",
                                                "state",
                                                "tdm_media_mismatched",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__setattr__(name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class L2VpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.protected_name = YLeaf(YType.str, "protected-name")

                                    self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                    self.protection_name = YLeaf(YType.str, "protection-name")

                                    self.protection_type = YLeaf(YType.enumeration, "protection-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "protected_name",
                                                    "protection_configured",
                                                    "protection_name",
                                                    "protection_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.protected_name.is_set or
                                        self.protection_configured.is_set or
                                        self.protection_name.is_set or
                                        self.protection_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.protected_name.yfilter != YFilter.not_set or
                                        self.protection_configured.yfilter != YFilter.not_set or
                                        self.protection_name.yfilter != YFilter.not_set or
                                        self.protection_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2vpn-protection" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protected_name.get_name_leafdata())
                                    if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                    if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_name.get_name_leafdata())
                                    if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protected-name"):
                                        self.protected_name = value
                                        self.protected_name.value_namespace = name_space
                                        self.protected_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-configured"):
                                        self.protection_configured = value
                                        self.protection_configured.value_namespace = name_space
                                        self.protection_configured.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-name"):
                                        self.protection_name = value
                                        self.protection_name.value_namespace = name_space
                                        self.protection_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-type"):
                                        self.protection_type = value
                                        self.protection_type.value_namespace = name_space
                                        self.protection_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bvi_mac_conflict.is_set or
                                    self.bvi_no_port_up.is_set or
                                    self.control_word_mismatched.is_set or
                                    self.encapsulation_error.is_set or
                                    self.encapsulation_mismatched.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.interface_handle.is_set or
                                    self.internal_ms_ti.is_set or
                                    self.interworking.is_set or
                                    self.is_ac_partially_programmed.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.ms_ti_mismatch.is_set or
                                    self.msti.is_set or
                                    self.msti_mismatch_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.node_id.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_group_state.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.state.is_set or
                                    self.tdm_media_mismatched.is_set or
                                    self.xconnect_id.is_set or
                                    (self.interface is not None and self.interface.has_data()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                    self.bvi_no_port_up.yfilter != YFilter.not_set or
                                    self.control_word_mismatched.yfilter != YFilter.not_set or
                                    self.encapsulation_error.yfilter != YFilter.not_set or
                                    self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.internal_ms_ti.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                    self.msti.yfilter != YFilter.not_set or
                                    self.msti_mismatch_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_group_state.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.interface is not None and self.interface.has_operation()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "attachment-circuit" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                                if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                                if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                                if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                                if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface"):
                                    if (self.interface is None):
                                        self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                                        self.interface.parent = self
                                        self._children_name_map["interface"] = "interface"
                                    return self.interface

                                if (child_yang_name == "l2vpn-protection"):
                                    if (self.l2vpn_protection is None):
                                        self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                                        self.l2vpn_protection.parent = self
                                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    return self.l2vpn_protection

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bvi-mac-conflict"):
                                    self.bvi_mac_conflict = value
                                    self.bvi_mac_conflict.value_namespace = name_space
                                    self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-no-port-up"):
                                    self.bvi_no_port_up = value
                                    self.bvi_no_port_up.value_namespace = name_space
                                    self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-word-mismatched"):
                                    self.control_word_mismatched = value
                                    self.control_word_mismatched.value_namespace = name_space
                                    self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-error"):
                                    self.encapsulation_error = value
                                    self.encapsulation_error.value_namespace = name_space
                                    self.encapsulation_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-mismatched"):
                                    self.encapsulation_mismatched = value
                                    self.encapsulation_mismatched.value_namespace = name_space
                                    self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-ms-ti"):
                                    self.internal_ms_ti = value
                                    self.internal_ms_ti.value_namespace = name_space
                                    self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ac-partially-programmed"):
                                    self.is_ac_partially_programmed = value
                                    self.is_ac_partially_programmed.value_namespace = name_space
                                    self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ms-ti-mismatch"):
                                    self.ms_ti_mismatch = value
                                    self.ms_ti_mismatch.value_namespace = name_space
                                    self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti"):
                                    self.msti = value
                                    self.msti.value_namespace = name_space
                                    self.msti.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-mismatch-down"):
                                    self.msti_mismatch_down = value
                                    self.msti_mismatch_down.value_namespace = name_space
                                    self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-state"):
                                    self.redundancy_group_state = value
                                    self.redundancy_group_state.value_namespace = name_space
                                    self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "tdm-media-mismatched"):
                                    self.tdm_media_mismatched = value
                                    self.tdm_media_mismatched.value_namespace = name_space
                                    self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class PseudoWire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire, self).__init__()

                                self.yang_name = "pseudo-wire"
                                self.yang_parent_name = "backup"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                self.backup_active = YLeaf(YType.boolean, "backup-active")

                                self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                self.disable_never = YLeaf(YType.boolean, "disable-never")

                                self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                self.local_source_address = YLeaf(YType.str, "local-source-address")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                self.required_bw = YLeaf(YType.uint32, "required-bw")

                                self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                self.time_created = YLeaf(YType.str, "time-created")

                                self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                self._children_yang_names.add("encapsulation-info")

                                self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                                self._children_yang_names.add("local-interface")

                                self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                                self._children_yang_names.add("local-signalling")

                                self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._children_yang_names.add("p2mp-pw")

                                self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                                self._children_yang_names.add("peer-id")

                                self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                                self._children_yang_names.add("preferred-path")

                                self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                                self._children_yang_names.add("remote-interface")

                                self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                self._children_yang_names.add("remote-signalling")

                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_remote_down",
                                                "admited_bw",
                                                "auto_discovery",
                                                "backup_active",
                                                "backup_force_active",
                                                "backup_pw",
                                                "bitrate_mismatched",
                                                "bridge_pw_type_mismatch",
                                                "cas_mismatched",
                                                "diff_ts_mismatched",
                                                "disable_delay",
                                                "disable_never",
                                                "evpn_src_acid",
                                                "fe_ctype",
                                                "forward_class",
                                                "freq_mismatched",
                                                "illegal_control_word",
                                                "imposed_vlan_id",
                                                "interworking",
                                                "ipv6_local_source_address",
                                                "is_evpnvpws_type",
                                                "is_flow_label_static",
                                                "is_multi_segment_pseudowire",
                                                "is_partially_programmed",
                                                "is_pwr_type",
                                                "is_vfi",
                                                "last_time_status_changed",
                                                "last_time_status_down",
                                                "ldp_label_advertise_failed",
                                                "load_balance",
                                                "local_control_word",
                                                "local_label_failed",
                                                "local_pseudo_wire_type",
                                                "local_source_address",
                                                "mac_limit_oper_down",
                                                "mtu_mismatched",
                                                "not_supported_qinq",
                                                "num_ma_cwithdraw_msg_received",
                                                "number_ma_cwithdraw_message_sent",
                                                "out_of_memory_state",
                                                "payload_bytes_mismatched",
                                                "payload_type_mismatched",
                                                "preferred_path_disable_fallback",
                                                "primary_peer_id",
                                                "primary_pseudo_wire_id",
                                                "primary_pw",
                                                "protocol",
                                                "pseudo_wire_id",
                                                "pseudo_wire_state",
                                                "pseudo_wire_type_mismatched",
                                                "pw_class_name",
                                                "pw_flow_label_code17_disabled",
                                                "pw_flow_label_type",
                                                "pw_flow_label_type_cfg",
                                                "pw_redundancy_initial_delay",
                                                "pw_redundancy_one_way",
                                                "pw_status_use",
                                                "pwlsd_rewrite_failed",
                                                "remote_control_word",
                                                "remote_label_failed",
                                                "remote_pseudo_wire_type",
                                                "required_bw",
                                                "resync_enabled",
                                                "resync_threshold",
                                                "rtp_mismatched",
                                                "sequencing_type",
                                                "shutdown",
                                                "sig_pkts_mismatched",
                                                "ssrc_mismatched",
                                                "state",
                                                "table_policy_name",
                                                "tag_rewrite",
                                                "time_created",
                                                "time_elapsed_creation",
                                                "time_elapsed_status_changed",
                                                "time_elapsed_status_down",
                                                "transport_lsp_down",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire, self).__setattr__(name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                    self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                    self.type = YLeaf(YType.enumeration, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "ipv4_peer_id",
                                                    "ipv6_peer_id",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.ipv4_peer_id.is_set or
                                        self.ipv6_peer_id.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.ipv4_peer_id.yfilter != YFilter.not_set or
                                        self.ipv6_peer_id.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "peer-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                    if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-peer-id"):
                                        self.ipv4_peer_id = value
                                        self.ipv4_peer_id.value_namespace = name_space
                                        self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-peer-id"):
                                        self.ipv6_peer_id = value
                                        self.ipv6_peer_id.value_namespace = name_space
                                        self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                    self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._children_yang_names.add("l2tpv3")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                        self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                        self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                        self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                        self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                        self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                        self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                        self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                        self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                        self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                        self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                        self.local_veid = YLeaf(YType.uint32, "local-veid")

                                        self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                        self.rem_saii = YLeaf(YType.str, "rem-saii")

                                        self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                        self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                        self.rem_taii = YLeaf(YType.str, "rem-taii")

                                        self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                        self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                        self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                        self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                        self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                        self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                        self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                        self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                        self.saii = YLeaf(YType.str, "saii")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.taii = YLeaf(YType.str, "taii")

                                        self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                        self._children_yang_names.add("local-agi")

                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._children_yang_names.add("multi-segment-pseudowire-stats")

                                        self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                        self._children_yang_names.add("remote-agi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_pseudowire_headend",
                                                        "is_sai_itype2",
                                                        "is_tai_itype2",
                                                        "ldp_label_advertisment_failed",
                                                        "local_c_ctype",
                                                        "local_ceid",
                                                        "local_cv_type",
                                                        "local_group_id",
                                                        "local_label",
                                                        "local_ldp_id",
                                                        "local_saii_gbl_id",
                                                        "local_saiiac_id",
                                                        "local_taii_gbl_id",
                                                        "local_taiiac_id",
                                                        "local_veid",
                                                        "lsd_rewrite_failed",
                                                        "rem_saii",
                                                        "rem_saii_gbl_id",
                                                        "rem_saiiac_id",
                                                        "rem_taii",
                                                        "rem_taii_gbl_id",
                                                        "rem_taiiac_id",
                                                        "remote_c_ctype",
                                                        "remote_ceid",
                                                        "remote_cv_type",
                                                        "remote_group_id",
                                                        "remote_label",
                                                        "remote_ldp_id",
                                                        "remote_source_address",
                                                        "remote_veid",
                                                        "saii",
                                                        "source_address",
                                                        "taii") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"

                                            self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                            self.received_packets = YLeaf(YType.uint64, "received-packets")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("received_bytes",
                                                            "received_packets") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.received_bytes.is_set or
                                                self.received_packets.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.received_bytes.yfilter != YFilter.not_set or
                                                self.received_packets.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                            if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_packets.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "received-bytes" or name == "received-packets"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "received-bytes"):
                                                self.received_bytes = value
                                                self.received_bytes.value_namespace = name_space
                                                self.received_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "received-packets"):
                                                self.received_packets = value
                                                self.received_packets.value_namespace = name_space
                                                self.received_packets.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_pseudowire_headend.is_set or
                                            self.is_sai_itype2.is_set or
                                            self.is_tai_itype2.is_set or
                                            self.ldp_label_advertisment_failed.is_set or
                                            self.local_c_ctype.is_set or
                                            self.local_ceid.is_set or
                                            self.local_cv_type.is_set or
                                            self.local_group_id.is_set or
                                            self.local_label.is_set or
                                            self.local_ldp_id.is_set or
                                            self.local_saii_gbl_id.is_set or
                                            self.local_saiiac_id.is_set or
                                            self.local_taii_gbl_id.is_set or
                                            self.local_taiiac_id.is_set or
                                            self.local_veid.is_set or
                                            self.lsd_rewrite_failed.is_set or
                                            self.rem_saii.is_set or
                                            self.rem_saii_gbl_id.is_set or
                                            self.rem_saiiac_id.is_set or
                                            self.rem_taii.is_set or
                                            self.rem_taii_gbl_id.is_set or
                                            self.rem_taiiac_id.is_set or
                                            self.remote_c_ctype.is_set or
                                            self.remote_ceid.is_set or
                                            self.remote_cv_type.is_set or
                                            self.remote_group_id.is_set or
                                            self.remote_label.is_set or
                                            self.remote_ldp_id.is_set or
                                            self.remote_source_address.is_set or
                                            self.remote_veid.is_set or
                                            self.saii.is_set or
                                            self.source_address.is_set or
                                            self.taii.is_set or
                                            (self.local_agi is not None and self.local_agi.has_data()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                            (self.remote_agi is not None and self.remote_agi.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                            self.is_sai_itype2.yfilter != YFilter.not_set or
                                            self.is_tai_itype2.yfilter != YFilter.not_set or
                                            self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                            self.local_c_ctype.yfilter != YFilter.not_set or
                                            self.local_ceid.yfilter != YFilter.not_set or
                                            self.local_cv_type.yfilter != YFilter.not_set or
                                            self.local_group_id.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_ldp_id.yfilter != YFilter.not_set or
                                            self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_saiiac_id.yfilter != YFilter.not_set or
                                            self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_taiiac_id.yfilter != YFilter.not_set or
                                            self.local_veid.yfilter != YFilter.not_set or
                                            self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.rem_saii.yfilter != YFilter.not_set or
                                            self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_saiiac_id.yfilter != YFilter.not_set or
                                            self.rem_taii.yfilter != YFilter.not_set or
                                            self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_taiiac_id.yfilter != YFilter.not_set or
                                            self.remote_c_ctype.yfilter != YFilter.not_set or
                                            self.remote_ceid.yfilter != YFilter.not_set or
                                            self.remote_cv_type.yfilter != YFilter.not_set or
                                            self.remote_group_id.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_ldp_id.yfilter != YFilter.not_set or
                                            self.remote_source_address.yfilter != YFilter.not_set or
                                            self.remote_veid.yfilter != YFilter.not_set or
                                            self.saii.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.taii.yfilter != YFilter.not_set or
                                            (self.local_agi is not None and self.local_agi.has_operation()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                            (self.remote_agi is not None and self.remote_agi.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                        if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                        if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                        if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                        if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                        if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                        if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                        if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                        if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                        if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                        if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                        if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                        if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_veid.get_name_leafdata())
                                        if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                        if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                        if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                        if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                        if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                        if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                        if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                        if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                        if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                        if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                        if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                        if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                        if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                        if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saii.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.taii.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local-agi"):
                                            if (self.local_agi is None):
                                                self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                            return self.local_agi

                                        if (child_yang_name == "multi-segment-pseudowire-stats"):
                                            if (self.multi_segment_pseudowire_stats is None):
                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            return self.multi_segment_pseudowire_stats

                                        if (child_yang_name == "remote-agi"):
                                            if (self.remote_agi is None):
                                                self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                            return self.remote_agi

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-pseudowire-headend"):
                                            self.is_pseudowire_headend = value
                                            self.is_pseudowire_headend.value_namespace = name_space
                                            self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-sai-itype2"):
                                            self.is_sai_itype2 = value
                                            self.is_sai_itype2.value_namespace = name_space
                                            self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-tai-itype2"):
                                            self.is_tai_itype2 = value
                                            self.is_tai_itype2.value_namespace = name_space
                                            self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertisment-failed"):
                                            self.ldp_label_advertisment_failed = value
                                            self.ldp_label_advertisment_failed.value_namespace = name_space
                                            self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-c-ctype"):
                                            self.local_c_ctype = value
                                            self.local_c_ctype.value_namespace = name_space
                                            self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ceid"):
                                            self.local_ceid = value
                                            self.local_ceid.value_namespace = name_space
                                            self.local_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cv-type"):
                                            self.local_cv_type = value
                                            self.local_cv_type.value_namespace = name_space
                                            self.local_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-group-id"):
                                            self.local_group_id = value
                                            self.local_group_id.value_namespace = name_space
                                            self.local_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ldp-id"):
                                            self.local_ldp_id = value
                                            self.local_ldp_id.value_namespace = name_space
                                            self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saii-gbl-id"):
                                            self.local_saii_gbl_id = value
                                            self.local_saii_gbl_id.value_namespace = name_space
                                            self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saiiac-id"):
                                            self.local_saiiac_id = value
                                            self.local_saiiac_id.value_namespace = name_space
                                            self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taii-gbl-id"):
                                            self.local_taii_gbl_id = value
                                            self.local_taii_gbl_id.value_namespace = name_space
                                            self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taiiac-id"):
                                            self.local_taiiac_id = value
                                            self.local_taiiac_id.value_namespace = name_space
                                            self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-veid"):
                                            self.local_veid = value
                                            self.local_veid.value_namespace = name_space
                                            self.local_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsd-rewrite-failed"):
                                            self.lsd_rewrite_failed = value
                                            self.lsd_rewrite_failed.value_namespace = name_space
                                            self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii"):
                                            self.rem_saii = value
                                            self.rem_saii.value_namespace = name_space
                                            self.rem_saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii-gbl-id"):
                                            self.rem_saii_gbl_id = value
                                            self.rem_saii_gbl_id.value_namespace = name_space
                                            self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saiiac-id"):
                                            self.rem_saiiac_id = value
                                            self.rem_saiiac_id.value_namespace = name_space
                                            self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii"):
                                            self.rem_taii = value
                                            self.rem_taii.value_namespace = name_space
                                            self.rem_taii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii-gbl-id"):
                                            self.rem_taii_gbl_id = value
                                            self.rem_taii_gbl_id.value_namespace = name_space
                                            self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taiiac-id"):
                                            self.rem_taiiac_id = value
                                            self.rem_taiiac_id.value_namespace = name_space
                                            self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-c-ctype"):
                                            self.remote_c_ctype = value
                                            self.remote_c_ctype.value_namespace = name_space
                                            self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ceid"):
                                            self.remote_ceid = value
                                            self.remote_ceid.value_namespace = name_space
                                            self.remote_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cv-type"):
                                            self.remote_cv_type = value
                                            self.remote_cv_type.value_namespace = name_space
                                            self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-group-id"):
                                            self.remote_group_id = value
                                            self.remote_group_id.value_namespace = name_space
                                            self.remote_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ldp-id"):
                                            self.remote_ldp_id = value
                                            self.remote_ldp_id.value_namespace = name_space
                                            self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-source-address"):
                                            self.remote_source_address = value
                                            self.remote_source_address.value_namespace = name_space
                                            self.remote_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-veid"):
                                            self.remote_veid = value
                                            self.remote_veid.value_namespace = name_space
                                            self.remote_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saii"):
                                            self.saii = value
                                            self.saii.value_namespace = name_space
                                            self.saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "taii"):
                                            self.taii = value
                                            self.taii.value_namespace = name_space
                                            self.taii.value_namespace_prefix = name_space_prefix


                                class L2Tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                        self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                        self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                        self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                        self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                        self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                        self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                        self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                        self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                        self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                        self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                        self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                        self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                        self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                        self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                        self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                        self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                        self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                        self.tos = YLeaf(YType.uint8, "tos")

                                        self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dont_fragment_bit",
                                                        "ipv4_source_address",
                                                        "ipv6_source_address",
                                                        "l2tp_class_name",
                                                        "local_cookie_high_value",
                                                        "local_cookie_low_value",
                                                        "local_cookie_size",
                                                        "local_secondary_cookie_high_value",
                                                        "local_secondary_cookie_low_value",
                                                        "local_secondary_cookie_size",
                                                        "local_session_id",
                                                        "path_mtu_enabled",
                                                        "path_mtu_max_value",
                                                        "remote_circuit_status_up",
                                                        "remote_cookie_high_value",
                                                        "remote_cookie_low_value",
                                                        "remote_cookie_size",
                                                        "remote_session_id",
                                                        "tos",
                                                        "tos_mode",
                                                        "ttl",
                                                        "tunnel_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dont_fragment_bit.is_set or
                                            self.ipv4_source_address.is_set or
                                            self.ipv6_source_address.is_set or
                                            self.l2tp_class_name.is_set or
                                            self.local_cookie_high_value.is_set or
                                            self.local_cookie_low_value.is_set or
                                            self.local_cookie_size.is_set or
                                            self.local_secondary_cookie_high_value.is_set or
                                            self.local_secondary_cookie_low_value.is_set or
                                            self.local_secondary_cookie_size.is_set or
                                            self.local_session_id.is_set or
                                            self.path_mtu_enabled.is_set or
                                            self.path_mtu_max_value.is_set or
                                            self.remote_circuit_status_up.is_set or
                                            self.remote_cookie_high_value.is_set or
                                            self.remote_cookie_low_value.is_set or
                                            self.remote_cookie_size.is_set or
                                            self.remote_session_id.is_set or
                                            self.tos.is_set or
                                            self.tos_mode.is_set or
                                            self.ttl.is_set or
                                            self.tunnel_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dont_fragment_bit.yfilter != YFilter.not_set or
                                            self.ipv4_source_address.yfilter != YFilter.not_set or
                                            self.ipv6_source_address.yfilter != YFilter.not_set or
                                            self.l2tp_class_name.yfilter != YFilter.not_set or
                                            self.local_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_cookie_size.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                            self.local_session_id.yfilter != YFilter.not_set or
                                            self.path_mtu_enabled.yfilter != YFilter.not_set or
                                            self.path_mtu_max_value.yfilter != YFilter.not_set or
                                            self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                            self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_size.yfilter != YFilter.not_set or
                                            self.remote_session_id.yfilter != YFilter.not_set or
                                            self.tos.yfilter != YFilter.not_set or
                                            self.tos_mode.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.tunnel_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv3" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                        if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                        if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                        if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                        if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                        if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                        if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                        if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                        if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                        if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                        if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                        if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                        if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                        if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                        if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                        if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                        if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos.get_name_leafdata())
                                        if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dont-fragment-bit"):
                                            self.dont_fragment_bit = value
                                            self.dont_fragment_bit.value_namespace = name_space
                                            self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-source-address"):
                                            self.ipv4_source_address = value
                                            self.ipv4_source_address.value_namespace = name_space
                                            self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-source-address"):
                                            self.ipv6_source_address = value
                                            self.ipv6_source_address.value_namespace = name_space
                                            self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l2tp-class-name"):
                                            self.l2tp_class_name = value
                                            self.l2tp_class_name.value_namespace = name_space
                                            self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-high-value"):
                                            self.local_cookie_high_value = value
                                            self.local_cookie_high_value.value_namespace = name_space
                                            self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-low-value"):
                                            self.local_cookie_low_value = value
                                            self.local_cookie_low_value.value_namespace = name_space
                                            self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-size"):
                                            self.local_cookie_size = value
                                            self.local_cookie_size.value_namespace = name_space
                                            self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-high-value"):
                                            self.local_secondary_cookie_high_value = value
                                            self.local_secondary_cookie_high_value.value_namespace = name_space
                                            self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-low-value"):
                                            self.local_secondary_cookie_low_value = value
                                            self.local_secondary_cookie_low_value.value_namespace = name_space
                                            self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-size"):
                                            self.local_secondary_cookie_size = value
                                            self.local_secondary_cookie_size.value_namespace = name_space
                                            self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-session-id"):
                                            self.local_session_id = value
                                            self.local_session_id.value_namespace = name_space
                                            self.local_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-enabled"):
                                            self.path_mtu_enabled = value
                                            self.path_mtu_enabled.value_namespace = name_space
                                            self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-max-value"):
                                            self.path_mtu_max_value = value
                                            self.path_mtu_max_value.value_namespace = name_space
                                            self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-circuit-status-up"):
                                            self.remote_circuit_status_up = value
                                            self.remote_circuit_status_up.value_namespace = name_space
                                            self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-high-value"):
                                            self.remote_cookie_high_value = value
                                            self.remote_cookie_high_value.value_namespace = name_space
                                            self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-low-value"):
                                            self.remote_cookie_low_value = value
                                            self.remote_cookie_low_value.value_namespace = name_space
                                            self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-size"):
                                            self.remote_cookie_size = value
                                            self.remote_cookie_size.value_namespace = name_space
                                            self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-session-id"):
                                            self.remote_session_id = value
                                            self.remote_session_id.value_namespace = name_space
                                            self.remote_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos"):
                                            self.tos = value
                                            self.tos.value_namespace = name_space
                                            self.tos.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-mode"):
                                            self.tos_mode = value
                                            self.tos_mode.value_namespace = name_space
                                            self.tos_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tunnel-state"):
                                            self.tunnel_state = value
                                            self.tunnel_state.value_namespace = name_space
                                            self.tunnel_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.encapsulation.is_set or
                                        (self.atom is not None and self.atom.has_data()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "encapsulation-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    if (child_yang_name == "l2tpv3"):
                                        if (self.l2tpv3 is None):
                                            self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                        return self.l2tpv3

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation"):
                                        self.encapsulation = value
                                        self.encapsulation.value_namespace = name_space
                                        self.encapsulation.value_namespace_prefix = name_space_prefix


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                    self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                    self.option = YLeaf(YType.enumeration, "option")

                                    self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                    self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ip_tunnel_interface_number",
                                                    "next_hop_ip",
                                                    "option",
                                                    "te_tunnel_interface_number",
                                                    "tp_tunnel_interface_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ip_tunnel_interface_number.is_set or
                                        self.next_hop_ip.is_set or
                                        self.option.is_set or
                                        self.te_tunnel_interface_number.is_set or
                                        self.tp_tunnel_interface_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set or
                                        self.option.yfilter != YFilter.not_set or
                                        self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "preferred-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                    if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.option.get_name_leafdata())
                                    if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                    if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ip-tunnel-interface-number"):
                                        self.ip_tunnel_interface_number = value
                                        self.ip_tunnel_interface_number.value_namespace = name_space
                                        self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                    if(value_path == "option"):
                                        self.option = value
                                        self.option.value_namespace = name_space
                                        self.option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-tunnel-interface-number"):
                                        self.te_tunnel_interface_number = value
                                        self.te_tunnel_interface_number.value_namespace = name_space
                                        self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tp-tunnel-interface-number"):
                                        self.tp_tunnel_interface_number = value
                                        self.tp_tunnel_interface_number.value_namespace = name_space
                                        self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class P2MpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.local_available = YLeaf(YType.boolean, "local-available")

                                    self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                    self.local_flags = YLeaf(YType.uint8, "local-flags")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                    self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                    self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                    self.remote_available = YLeaf(YType.boolean, "remote-available")

                                    self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                    self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                    self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                    self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_available",
                                                    "local_extended_tunnel_id",
                                                    "local_flags",
                                                    "local_label",
                                                    "local_p2mp_id",
                                                    "local_ptree_type",
                                                    "local_tunnel_id",
                                                    "remote_available",
                                                    "remote_extended_tunnel_id",
                                                    "remote_flags",
                                                    "remote_label",
                                                    "remote_p2mp_id",
                                                    "remote_ptree_type",
                                                    "remote_tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_available.is_set or
                                        self.local_extended_tunnel_id.is_set or
                                        self.local_flags.is_set or
                                        self.local_label.is_set or
                                        self.local_p2mp_id.is_set or
                                        self.local_ptree_type.is_set or
                                        self.local_tunnel_id.is_set or
                                        self.remote_available.is_set or
                                        self.remote_extended_tunnel_id.is_set or
                                        self.remote_flags.is_set or
                                        self.remote_label.is_set or
                                        self.remote_p2mp_id.is_set or
                                        self.remote_ptree_type.is_set or
                                        self.remote_tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_available.yfilter != YFilter.not_set or
                                        self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.local_flags.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_p2mp_id.yfilter != YFilter.not_set or
                                        self.local_ptree_type.yfilter != YFilter.not_set or
                                        self.local_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_available.yfilter != YFilter.not_set or
                                        self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_flags.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_p2mp_id.yfilter != YFilter.not_set or
                                        self.remote_ptree_type.yfilter != YFilter.not_set or
                                        self.remote_tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_available.get_name_leafdata())
                                    if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                    if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_flags.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                    if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                    if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                    if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_available.get_name_leafdata())
                                    if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                    if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                    if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                    if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-available"):
                                        self.local_available = value
                                        self.local_available.value_namespace = name_space
                                        self.local_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-extended-tunnel-id"):
                                        self.local_extended_tunnel_id = value
                                        self.local_extended_tunnel_id.value_namespace = name_space
                                        self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-flags"):
                                        self.local_flags = value
                                        self.local_flags.value_namespace = name_space
                                        self.local_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-p2mp-id"):
                                        self.local_p2mp_id = value
                                        self.local_p2mp_id.value_namespace = name_space
                                        self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ptree-type"):
                                        self.local_ptree_type = value
                                        self.local_ptree_type.value_namespace = name_space
                                        self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-tunnel-id"):
                                        self.local_tunnel_id = value
                                        self.local_tunnel_id.value_namespace = name_space
                                        self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-available"):
                                        self.remote_available = value
                                        self.remote_available.value_namespace = name_space
                                        self.remote_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-extended-tunnel-id"):
                                        self.remote_extended_tunnel_id = value
                                        self.remote_extended_tunnel_id.value_namespace = name_space
                                        self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-flags"):
                                        self.remote_flags = value
                                        self.remote_flags.value_namespace = name_space
                                        self.remote_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-p2mp-id"):
                                        self.remote_p2mp_id = value
                                        self.remote_p2mp_id.value_namespace = name_space
                                        self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ptree-type"):
                                        self.remote_ptree_type = value
                                        self.remote_ptree_type.value_namespace = name_space
                                        self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-tunnel-id"):
                                        self.remote_tunnel_id = value
                                        self.remote_tunnel_id.value_namespace = name_space
                                        self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ad_method.is_set or
                                    self.ad_remote_down.is_set or
                                    self.admited_bw.is_set or
                                    self.auto_discovery.is_set or
                                    self.backup_active.is_set or
                                    self.backup_force_active.is_set or
                                    self.backup_pw.is_set or
                                    self.bitrate_mismatched.is_set or
                                    self.bridge_pw_type_mismatch.is_set or
                                    self.cas_mismatched.is_set or
                                    self.diff_ts_mismatched.is_set or
                                    self.disable_delay.is_set or
                                    self.disable_never.is_set or
                                    self.evpn_src_acid.is_set or
                                    self.fe_ctype.is_set or
                                    self.forward_class.is_set or
                                    self.freq_mismatched.is_set or
                                    self.illegal_control_word.is_set or
                                    self.imposed_vlan_id.is_set or
                                    self.interworking.is_set or
                                    self.ipv6_local_source_address.is_set or
                                    self.is_evpnvpws_type.is_set or
                                    self.is_flow_label_static.is_set or
                                    self.is_multi_segment_pseudowire.is_set or
                                    self.is_partially_programmed.is_set or
                                    self.is_pwr_type.is_set or
                                    self.is_vfi.is_set or
                                    self.last_time_status_changed.is_set or
                                    self.last_time_status_down.is_set or
                                    self.ldp_label_advertise_failed.is_set or
                                    self.load_balance.is_set or
                                    self.local_control_word.is_set or
                                    self.local_label_failed.is_set or
                                    self.local_pseudo_wire_type.is_set or
                                    self.local_source_address.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.not_supported_qinq.is_set or
                                    self.num_ma_cwithdraw_msg_received.is_set or
                                    self.number_ma_cwithdraw_message_sent.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.payload_bytes_mismatched.is_set or
                                    self.payload_type_mismatched.is_set or
                                    self.preferred_path_disable_fallback.is_set or
                                    self.primary_peer_id.is_set or
                                    self.primary_pseudo_wire_id.is_set or
                                    self.primary_pw.is_set or
                                    self.protocol.is_set or
                                    self.pseudo_wire_id.is_set or
                                    self.pseudo_wire_state.is_set or
                                    self.pseudo_wire_type_mismatched.is_set or
                                    self.pw_class_name.is_set or
                                    self.pw_flow_label_code17_disabled.is_set or
                                    self.pw_flow_label_type.is_set or
                                    self.pw_flow_label_type_cfg.is_set or
                                    self.pw_redundancy_initial_delay.is_set or
                                    self.pw_redundancy_one_way.is_set or
                                    self.pw_status_use.is_set or
                                    self.pwlsd_rewrite_failed.is_set or
                                    self.remote_control_word.is_set or
                                    self.remote_label_failed.is_set or
                                    self.remote_pseudo_wire_type.is_set or
                                    self.required_bw.is_set or
                                    self.resync_enabled.is_set or
                                    self.resync_threshold.is_set or
                                    self.rtp_mismatched.is_set or
                                    self.sequencing_type.is_set or
                                    self.shutdown.is_set or
                                    self.sig_pkts_mismatched.is_set or
                                    self.ssrc_mismatched.is_set or
                                    self.state.is_set or
                                    self.table_policy_name.is_set or
                                    self.tag_rewrite.is_set or
                                    self.time_created.is_set or
                                    self.time_elapsed_creation.is_set or
                                    self.time_elapsed_status_changed.is_set or
                                    self.time_elapsed_status_down.is_set or
                                    self.transport_lsp_down.is_set or
                                    self.xconnect_id.is_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                    (self.local_interface is not None and self.local_interface.has_data()) or
                                    (self.local_signalling is not None and self.local_signalling.has_data()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                    (self.peer_id is not None and self.peer_id.has_data()) or
                                    (self.preferred_path is not None and self.preferred_path.has_data()) or
                                    (self.remote_interface is not None and self.remote_interface.has_data()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_remote_down.yfilter != YFilter.not_set or
                                    self.admited_bw.yfilter != YFilter.not_set or
                                    self.auto_discovery.yfilter != YFilter.not_set or
                                    self.backup_active.yfilter != YFilter.not_set or
                                    self.backup_force_active.yfilter != YFilter.not_set or
                                    self.backup_pw.yfilter != YFilter.not_set or
                                    self.bitrate_mismatched.yfilter != YFilter.not_set or
                                    self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                    self.cas_mismatched.yfilter != YFilter.not_set or
                                    self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                    self.disable_delay.yfilter != YFilter.not_set or
                                    self.disable_never.yfilter != YFilter.not_set or
                                    self.evpn_src_acid.yfilter != YFilter.not_set or
                                    self.fe_ctype.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.freq_mismatched.yfilter != YFilter.not_set or
                                    self.illegal_control_word.yfilter != YFilter.not_set or
                                    self.imposed_vlan_id.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                    self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                    self.is_flow_label_static.yfilter != YFilter.not_set or
                                    self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                    self.is_partially_programmed.yfilter != YFilter.not_set or
                                    self.is_pwr_type.yfilter != YFilter.not_set or
                                    self.is_vfi.yfilter != YFilter.not_set or
                                    self.last_time_status_changed.yfilter != YFilter.not_set or
                                    self.last_time_status_down.yfilter != YFilter.not_set or
                                    self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                    self.load_balance.yfilter != YFilter.not_set or
                                    self.local_control_word.yfilter != YFilter.not_set or
                                    self.local_label_failed.yfilter != YFilter.not_set or
                                    self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.local_source_address.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.not_supported_qinq.yfilter != YFilter.not_set or
                                    self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                    self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                    self.payload_type_mismatched.yfilter != YFilter.not_set or
                                    self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                    self.primary_peer_id.yfilter != YFilter.not_set or
                                    self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.primary_pw.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.pseudo_wire_state.yfilter != YFilter.not_set or
                                    self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                    self.pw_class_name.yfilter != YFilter.not_set or
                                    self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                    self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                    self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                    self.pw_status_use.yfilter != YFilter.not_set or
                                    self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.remote_control_word.yfilter != YFilter.not_set or
                                    self.remote_label_failed.yfilter != YFilter.not_set or
                                    self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.required_bw.yfilter != YFilter.not_set or
                                    self.resync_enabled.yfilter != YFilter.not_set or
                                    self.resync_threshold.yfilter != YFilter.not_set or
                                    self.rtp_mismatched.yfilter != YFilter.not_set or
                                    self.sequencing_type.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                    self.ssrc_mismatched.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.table_policy_name.yfilter != YFilter.not_set or
                                    self.tag_rewrite.yfilter != YFilter.not_set or
                                    self.time_created.yfilter != YFilter.not_set or
                                    self.time_elapsed_creation.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                    self.transport_lsp_down.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                    (self.local_interface is not None and self.local_interface.has_operation()) or
                                    (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                    (self.peer_id is not None and self.peer_id.has_operation()) or
                                    (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                    (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pseudo-wire" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_active.get_name_leafdata())
                                if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_never.get_name_leafdata())
                                if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance.get_name_leafdata())
                                if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())
                                if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.required_bw.get_name_leafdata())
                                if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_created.get_name_leafdata())
                                if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "encapsulation-info"):
                                    if (self.encapsulation_info is None):
                                        self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    return self.encapsulation_info

                                if (child_yang_name == "local-interface"):
                                    if (self.local_interface is None):
                                        self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                    return self.local_interface

                                if (child_yang_name == "local-signalling"):
                                    if (self.local_signalling is None):
                                        self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                    return self.local_signalling

                                if (child_yang_name == "p2mp-pw"):
                                    if (self.p2mp_pw is None):
                                        self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    return self.p2mp_pw

                                if (child_yang_name == "peer-id"):
                                    if (self.peer_id is None):
                                        self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                    return self.peer_id

                                if (child_yang_name == "preferred-path"):
                                    if (self.preferred_path is None):
                                        self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                    return self.preferred_path

                                if (child_yang_name == "remote-interface"):
                                    if (self.remote_interface is None):
                                        self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                    return self.remote_interface

                                if (child_yang_name == "remote-signalling"):
                                    if (self.remote_signalling is None):
                                        self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                    return self.remote_signalling

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-remote-down"):
                                    self.ad_remote_down = value
                                    self.ad_remote_down.value_namespace = name_space
                                    self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "admited-bw"):
                                    self.admited_bw = value
                                    self.admited_bw.value_namespace = name_space
                                    self.admited_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "auto-discovery"):
                                    self.auto_discovery = value
                                    self.auto_discovery.value_namespace = name_space
                                    self.auto_discovery.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-active"):
                                    self.backup_active = value
                                    self.backup_active.value_namespace = name_space
                                    self.backup_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-force-active"):
                                    self.backup_force_active = value
                                    self.backup_force_active.value_namespace = name_space
                                    self.backup_force_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-pw"):
                                    self.backup_pw = value
                                    self.backup_pw.value_namespace = name_space
                                    self.backup_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "bitrate-mismatched"):
                                    self.bitrate_mismatched = value
                                    self.bitrate_mismatched.value_namespace = name_space
                                    self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-pw-type-mismatch"):
                                    self.bridge_pw_type_mismatch = value
                                    self.bridge_pw_type_mismatch.value_namespace = name_space
                                    self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "cas-mismatched"):
                                    self.cas_mismatched = value
                                    self.cas_mismatched.value_namespace = name_space
                                    self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "diff-ts-mismatched"):
                                    self.diff_ts_mismatched = value
                                    self.diff_ts_mismatched.value_namespace = name_space
                                    self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-delay"):
                                    self.disable_delay = value
                                    self.disable_delay.value_namespace = name_space
                                    self.disable_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-never"):
                                    self.disable_never = value
                                    self.disable_never.value_namespace = name_space
                                    self.disable_never.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-src-acid"):
                                    self.evpn_src_acid = value
                                    self.evpn_src_acid.value_namespace = name_space
                                    self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                if(value_path == "fe-ctype"):
                                    self.fe_ctype = value
                                    self.fe_ctype.value_namespace = name_space
                                    self.fe_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "freq-mismatched"):
                                    self.freq_mismatched = value
                                    self.freq_mismatched.value_namespace = name_space
                                    self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-control-word"):
                                    self.illegal_control_word = value
                                    self.illegal_control_word.value_namespace = name_space
                                    self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "imposed-vlan-id"):
                                    self.imposed_vlan_id = value
                                    self.imposed_vlan_id.value_namespace = name_space
                                    self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-local-source-address"):
                                    self.ipv6_local_source_address = value
                                    self.ipv6_local_source_address.value_namespace = name_space
                                    self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpnvpws-type"):
                                    self.is_evpnvpws_type = value
                                    self.is_evpnvpws_type.value_namespace = name_space
                                    self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-flow-label-static"):
                                    self.is_flow_label_static = value
                                    self.is_flow_label_static.value_namespace = name_space
                                    self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-multi-segment-pseudowire"):
                                    self.is_multi_segment_pseudowire = value
                                    self.is_multi_segment_pseudowire.value_namespace = name_space
                                    self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-partially-programmed"):
                                    self.is_partially_programmed = value
                                    self.is_partially_programmed.value_namespace = name_space
                                    self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pwr-type"):
                                    self.is_pwr_type = value
                                    self.is_pwr_type.value_namespace = name_space
                                    self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vfi"):
                                    self.is_vfi = value
                                    self.is_vfi.value_namespace = name_space
                                    self.is_vfi.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-changed"):
                                    self.last_time_status_changed = value
                                    self.last_time_status_changed.value_namespace = name_space
                                    self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-down"):
                                    self.last_time_status_down = value
                                    self.last_time_status_down.value_namespace = name_space
                                    self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertise-failed"):
                                    self.ldp_label_advertise_failed = value
                                    self.ldp_label_advertise_failed.value_namespace = name_space
                                    self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance"):
                                    self.load_balance = value
                                    self.load_balance.value_namespace = name_space
                                    self.load_balance.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-control-word"):
                                    self.local_control_word = value
                                    self.local_control_word.value_namespace = name_space
                                    self.local_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label-failed"):
                                    self.local_label_failed = value
                                    self.local_label_failed.value_namespace = name_space
                                    self.local_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-pseudo-wire-type"):
                                    self.local_pseudo_wire_type = value
                                    self.local_pseudo_wire_type.value_namespace = name_space
                                    self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-source-address"):
                                    self.local_source_address = value
                                    self.local_source_address.value_namespace = name_space
                                    self.local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-supported-qinq"):
                                    self.not_supported_qinq = value
                                    self.not_supported_qinq.value_namespace = name_space
                                    self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                if(value_path == "num-ma-cwithdraw-msg-received"):
                                    self.num_ma_cwithdraw_msg_received = value
                                    self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                    self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-ma-cwithdraw-message-sent"):
                                    self.number_ma_cwithdraw_message_sent = value
                                    self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                    self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes-mismatched"):
                                    self.payload_bytes_mismatched = value
                                    self.payload_bytes_mismatched.value_namespace = name_space
                                    self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-type-mismatched"):
                                    self.payload_type_mismatched = value
                                    self.payload_type_mismatched.value_namespace = name_space
                                    self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "preferred-path-disable-fallback"):
                                    self.preferred_path_disable_fallback = value
                                    self.preferred_path_disable_fallback.value_namespace = name_space
                                    self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-peer-id"):
                                    self.primary_peer_id = value
                                    self.primary_peer_id.value_namespace = name_space
                                    self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pseudo-wire-id"):
                                    self.primary_pseudo_wire_id = value
                                    self.primary_pseudo_wire_id.value_namespace = name_space
                                    self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pw"):
                                    self.primary_pw = value
                                    self.primary_pw.value_namespace = name_space
                                    self.primary_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id"):
                                    self.pseudo_wire_id = value
                                    self.pseudo_wire_id.value_namespace = name_space
                                    self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-state"):
                                    self.pseudo_wire_state = value
                                    self.pseudo_wire_state.value_namespace = name_space
                                    self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-type-mismatched"):
                                    self.pseudo_wire_type_mismatched = value
                                    self.pseudo_wire_type_mismatched.value_namespace = name_space
                                    self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-class-name"):
                                    self.pw_class_name = value
                                    self.pw_class_name.value_namespace = name_space
                                    self.pw_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-code17-disabled"):
                                    self.pw_flow_label_code17_disabled = value
                                    self.pw_flow_label_code17_disabled.value_namespace = name_space
                                    self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type"):
                                    self.pw_flow_label_type = value
                                    self.pw_flow_label_type.value_namespace = name_space
                                    self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type-cfg"):
                                    self.pw_flow_label_type_cfg = value
                                    self.pw_flow_label_type_cfg.value_namespace = name_space
                                    self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-initial-delay"):
                                    self.pw_redundancy_initial_delay = value
                                    self.pw_redundancy_initial_delay.value_namespace = name_space
                                    self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-one-way"):
                                    self.pw_redundancy_one_way = value
                                    self.pw_redundancy_one_way.value_namespace = name_space
                                    self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-status-use"):
                                    self.pw_status_use = value
                                    self.pw_status_use.value_namespace = name_space
                                    self.pw_status_use.value_namespace_prefix = name_space_prefix
                                if(value_path == "pwlsd-rewrite-failed"):
                                    self.pwlsd_rewrite_failed = value
                                    self.pwlsd_rewrite_failed.value_namespace = name_space
                                    self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-control-word"):
                                    self.remote_control_word = value
                                    self.remote_control_word.value_namespace = name_space
                                    self.remote_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label-failed"):
                                    self.remote_label_failed = value
                                    self.remote_label_failed.value_namespace = name_space
                                    self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-pseudo-wire-type"):
                                    self.remote_pseudo_wire_type = value
                                    self.remote_pseudo_wire_type.value_namespace = name_space
                                    self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "required-bw"):
                                    self.required_bw = value
                                    self.required_bw.value_namespace = name_space
                                    self.required_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-enabled"):
                                    self.resync_enabled = value
                                    self.resync_enabled.value_namespace = name_space
                                    self.resync_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-threshold"):
                                    self.resync_threshold = value
                                    self.resync_threshold.value_namespace = name_space
                                    self.resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "rtp-mismatched"):
                                    self.rtp_mismatched = value
                                    self.rtp_mismatched.value_namespace = name_space
                                    self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequencing-type"):
                                    self.sequencing_type = value
                                    self.sequencing_type.value_namespace = name_space
                                    self.sequencing_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "sig-pkts-mismatched"):
                                    self.sig_pkts_mismatched = value
                                    self.sig_pkts_mismatched.value_namespace = name_space
                                    self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "ssrc-mismatched"):
                                    self.ssrc_mismatched = value
                                    self.ssrc_mismatched.value_namespace = name_space
                                    self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-policy-name"):
                                    self.table_policy_name = value
                                    self.table_policy_name.value_namespace = name_space
                                    self.table_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag-rewrite"):
                                    self.tag_rewrite = value
                                    self.tag_rewrite.value_namespace = name_space
                                    self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-created"):
                                    self.time_created = value
                                    self.time_created.value_namespace = name_space
                                    self.time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-creation"):
                                    self.time_elapsed_creation = value
                                    self.time_elapsed_creation.value_namespace = name_space
                                    self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-changed"):
                                    self.time_elapsed_status_changed = value
                                    self.time_elapsed_status_changed.value_namespace = name_space
                                    self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-down"):
                                    self.time_elapsed_status_down = value
                                    self.time_elapsed_status_down.value_namespace = name_space
                                    self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-lsp-down"):
                                    self.transport_lsp_down = value
                                    self.transport_lsp_down.value_namespace = name_space
                                    self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.segment_type.is_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                                (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.segment_type.yfilter != YFilter.not_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                                (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "backup" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "attachment-circuit"):
                                if (self.attachment_circuit is None):
                                    self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit()
                                    self.attachment_circuit.parent = self
                                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                return self.attachment_circuit

                            if (child_yang_name == "pseudo-wire"):
                                if (self.pseudo_wire is None):
                                    self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire()
                                    self.pseudo_wire.parent = self
                                    self._children_name_map["pseudo_wire"] = "pseudo-wire"
                                return self.pseudo_wire

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "segment-type"):
                                self.segment_type = value
                                self.segment_type.value_namespace = name_space
                                self.segment_type.value_namespace_prefix = name_space_prefix


                    class Segment1(Entity):
                        """
                        Segment 1
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1, self).__init__()

                            self.yang_name = "segment1"
                            self.yang_parent_name = "xconnect"

                            self.segment_type = YLeaf(YType.enumeration, "segment-type")

                            self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            self._children_yang_names.add("attachment-circuit")

                            self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            self._children_yang_names.add("pseudo-wire")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("segment_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1, self).__setattr__(name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "segment1"

                                self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                                self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                                self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                                self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                                self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                                self.msti = YLeaf(YType.str, "msti")

                                self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.node_id = YLeaf(YType.str, "node-id")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._children_yang_names.add("interface")

                                self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._children_yang_names.add("l2vpn-protection")

                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bvi_mac_conflict",
                                                "bvi_no_port_up",
                                                "control_word_mismatched",
                                                "encapsulation_error",
                                                "encapsulation_mismatched",
                                                "evpn_internal_label",
                                                "interface_handle",
                                                "internal_ms_ti",
                                                "interworking",
                                                "is_ac_partially_programmed",
                                                "mac_limit_oper_down",
                                                "ms_ti_mismatch",
                                                "msti",
                                                "msti_mismatch_down",
                                                "mtu_mismatched",
                                                "node_id",
                                                "out_of_memory_state",
                                                "redundancy_group_id",
                                                "redundancy_group_state",
                                                "redundancy_object_id",
                                                "state",
                                                "tdm_media_mismatched",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__setattr__(name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class L2VpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.protected_name = YLeaf(YType.str, "protected-name")

                                    self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                    self.protection_name = YLeaf(YType.str, "protection-name")

                                    self.protection_type = YLeaf(YType.enumeration, "protection-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "protected_name",
                                                    "protection_configured",
                                                    "protection_name",
                                                    "protection_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.protected_name.is_set or
                                        self.protection_configured.is_set or
                                        self.protection_name.is_set or
                                        self.protection_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.protected_name.yfilter != YFilter.not_set or
                                        self.protection_configured.yfilter != YFilter.not_set or
                                        self.protection_name.yfilter != YFilter.not_set or
                                        self.protection_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2vpn-protection" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protected_name.get_name_leafdata())
                                    if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                    if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_name.get_name_leafdata())
                                    if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protected-name"):
                                        self.protected_name = value
                                        self.protected_name.value_namespace = name_space
                                        self.protected_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-configured"):
                                        self.protection_configured = value
                                        self.protection_configured.value_namespace = name_space
                                        self.protection_configured.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-name"):
                                        self.protection_name = value
                                        self.protection_name.value_namespace = name_space
                                        self.protection_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-type"):
                                        self.protection_type = value
                                        self.protection_type.value_namespace = name_space
                                        self.protection_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bvi_mac_conflict.is_set or
                                    self.bvi_no_port_up.is_set or
                                    self.control_word_mismatched.is_set or
                                    self.encapsulation_error.is_set or
                                    self.encapsulation_mismatched.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.interface_handle.is_set or
                                    self.internal_ms_ti.is_set or
                                    self.interworking.is_set or
                                    self.is_ac_partially_programmed.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.ms_ti_mismatch.is_set or
                                    self.msti.is_set or
                                    self.msti_mismatch_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.node_id.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_group_state.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.state.is_set or
                                    self.tdm_media_mismatched.is_set or
                                    self.xconnect_id.is_set or
                                    (self.interface is not None and self.interface.has_data()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                    self.bvi_no_port_up.yfilter != YFilter.not_set or
                                    self.control_word_mismatched.yfilter != YFilter.not_set or
                                    self.encapsulation_error.yfilter != YFilter.not_set or
                                    self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.internal_ms_ti.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                    self.msti.yfilter != YFilter.not_set or
                                    self.msti_mismatch_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_group_state.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.interface is not None and self.interface.has_operation()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "attachment-circuit" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                                if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                                if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                                if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                                if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface"):
                                    if (self.interface is None):
                                        self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                                        self.interface.parent = self
                                        self._children_name_map["interface"] = "interface"
                                    return self.interface

                                if (child_yang_name == "l2vpn-protection"):
                                    if (self.l2vpn_protection is None):
                                        self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                                        self.l2vpn_protection.parent = self
                                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    return self.l2vpn_protection

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bvi-mac-conflict"):
                                    self.bvi_mac_conflict = value
                                    self.bvi_mac_conflict.value_namespace = name_space
                                    self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-no-port-up"):
                                    self.bvi_no_port_up = value
                                    self.bvi_no_port_up.value_namespace = name_space
                                    self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-word-mismatched"):
                                    self.control_word_mismatched = value
                                    self.control_word_mismatched.value_namespace = name_space
                                    self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-error"):
                                    self.encapsulation_error = value
                                    self.encapsulation_error.value_namespace = name_space
                                    self.encapsulation_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-mismatched"):
                                    self.encapsulation_mismatched = value
                                    self.encapsulation_mismatched.value_namespace = name_space
                                    self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-ms-ti"):
                                    self.internal_ms_ti = value
                                    self.internal_ms_ti.value_namespace = name_space
                                    self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ac-partially-programmed"):
                                    self.is_ac_partially_programmed = value
                                    self.is_ac_partially_programmed.value_namespace = name_space
                                    self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ms-ti-mismatch"):
                                    self.ms_ti_mismatch = value
                                    self.ms_ti_mismatch.value_namespace = name_space
                                    self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti"):
                                    self.msti = value
                                    self.msti.value_namespace = name_space
                                    self.msti.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-mismatch-down"):
                                    self.msti_mismatch_down = value
                                    self.msti_mismatch_down.value_namespace = name_space
                                    self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-state"):
                                    self.redundancy_group_state = value
                                    self.redundancy_group_state.value_namespace = name_space
                                    self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "tdm-media-mismatched"):
                                    self.tdm_media_mismatched = value
                                    self.tdm_media_mismatched.value_namespace = name_space
                                    self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class PseudoWire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire, self).__init__()

                                self.yang_name = "pseudo-wire"
                                self.yang_parent_name = "segment1"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                self.backup_active = YLeaf(YType.boolean, "backup-active")

                                self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                self.disable_never = YLeaf(YType.boolean, "disable-never")

                                self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                self.local_source_address = YLeaf(YType.str, "local-source-address")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                self.required_bw = YLeaf(YType.uint32, "required-bw")

                                self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                self.time_created = YLeaf(YType.str, "time-created")

                                self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                self._children_yang_names.add("encapsulation-info")

                                self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                                self._children_yang_names.add("local-interface")

                                self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                                self._children_yang_names.add("local-signalling")

                                self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._children_yang_names.add("p2mp-pw")

                                self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                                self._children_yang_names.add("peer-id")

                                self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                                self._children_yang_names.add("preferred-path")

                                self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                                self._children_yang_names.add("remote-interface")

                                self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                self._children_yang_names.add("remote-signalling")

                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_remote_down",
                                                "admited_bw",
                                                "auto_discovery",
                                                "backup_active",
                                                "backup_force_active",
                                                "backup_pw",
                                                "bitrate_mismatched",
                                                "bridge_pw_type_mismatch",
                                                "cas_mismatched",
                                                "diff_ts_mismatched",
                                                "disable_delay",
                                                "disable_never",
                                                "evpn_src_acid",
                                                "fe_ctype",
                                                "forward_class",
                                                "freq_mismatched",
                                                "illegal_control_word",
                                                "imposed_vlan_id",
                                                "interworking",
                                                "ipv6_local_source_address",
                                                "is_evpnvpws_type",
                                                "is_flow_label_static",
                                                "is_multi_segment_pseudowire",
                                                "is_partially_programmed",
                                                "is_pwr_type",
                                                "is_vfi",
                                                "last_time_status_changed",
                                                "last_time_status_down",
                                                "ldp_label_advertise_failed",
                                                "load_balance",
                                                "local_control_word",
                                                "local_label_failed",
                                                "local_pseudo_wire_type",
                                                "local_source_address",
                                                "mac_limit_oper_down",
                                                "mtu_mismatched",
                                                "not_supported_qinq",
                                                "num_ma_cwithdraw_msg_received",
                                                "number_ma_cwithdraw_message_sent",
                                                "out_of_memory_state",
                                                "payload_bytes_mismatched",
                                                "payload_type_mismatched",
                                                "preferred_path_disable_fallback",
                                                "primary_peer_id",
                                                "primary_pseudo_wire_id",
                                                "primary_pw",
                                                "protocol",
                                                "pseudo_wire_id",
                                                "pseudo_wire_state",
                                                "pseudo_wire_type_mismatched",
                                                "pw_class_name",
                                                "pw_flow_label_code17_disabled",
                                                "pw_flow_label_type",
                                                "pw_flow_label_type_cfg",
                                                "pw_redundancy_initial_delay",
                                                "pw_redundancy_one_way",
                                                "pw_status_use",
                                                "pwlsd_rewrite_failed",
                                                "remote_control_word",
                                                "remote_label_failed",
                                                "remote_pseudo_wire_type",
                                                "required_bw",
                                                "resync_enabled",
                                                "resync_threshold",
                                                "rtp_mismatched",
                                                "sequencing_type",
                                                "shutdown",
                                                "sig_pkts_mismatched",
                                                "ssrc_mismatched",
                                                "state",
                                                "table_policy_name",
                                                "tag_rewrite",
                                                "time_created",
                                                "time_elapsed_creation",
                                                "time_elapsed_status_changed",
                                                "time_elapsed_status_down",
                                                "transport_lsp_down",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire, self).__setattr__(name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                    self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                    self.type = YLeaf(YType.enumeration, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "ipv4_peer_id",
                                                    "ipv6_peer_id",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.ipv4_peer_id.is_set or
                                        self.ipv6_peer_id.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.ipv4_peer_id.yfilter != YFilter.not_set or
                                        self.ipv6_peer_id.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "peer-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                    if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-peer-id"):
                                        self.ipv4_peer_id = value
                                        self.ipv4_peer_id.value_namespace = name_space
                                        self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-peer-id"):
                                        self.ipv6_peer_id = value
                                        self.ipv6_peer_id.value_namespace = name_space
                                        self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                    self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._children_yang_names.add("l2tpv3")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                        self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                        self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                        self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                        self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                        self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                        self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                        self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                        self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                        self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                        self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                        self.local_veid = YLeaf(YType.uint32, "local-veid")

                                        self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                        self.rem_saii = YLeaf(YType.str, "rem-saii")

                                        self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                        self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                        self.rem_taii = YLeaf(YType.str, "rem-taii")

                                        self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                        self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                        self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                        self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                        self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                        self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                        self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                        self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                        self.saii = YLeaf(YType.str, "saii")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.taii = YLeaf(YType.str, "taii")

                                        self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                        self._children_yang_names.add("local-agi")

                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._children_yang_names.add("multi-segment-pseudowire-stats")

                                        self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                        self._children_yang_names.add("remote-agi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_pseudowire_headend",
                                                        "is_sai_itype2",
                                                        "is_tai_itype2",
                                                        "ldp_label_advertisment_failed",
                                                        "local_c_ctype",
                                                        "local_ceid",
                                                        "local_cv_type",
                                                        "local_group_id",
                                                        "local_label",
                                                        "local_ldp_id",
                                                        "local_saii_gbl_id",
                                                        "local_saiiac_id",
                                                        "local_taii_gbl_id",
                                                        "local_taiiac_id",
                                                        "local_veid",
                                                        "lsd_rewrite_failed",
                                                        "rem_saii",
                                                        "rem_saii_gbl_id",
                                                        "rem_saiiac_id",
                                                        "rem_taii",
                                                        "rem_taii_gbl_id",
                                                        "rem_taiiac_id",
                                                        "remote_c_ctype",
                                                        "remote_ceid",
                                                        "remote_cv_type",
                                                        "remote_group_id",
                                                        "remote_label",
                                                        "remote_ldp_id",
                                                        "remote_source_address",
                                                        "remote_veid",
                                                        "saii",
                                                        "source_address",
                                                        "taii") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"

                                            self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                            self.received_packets = YLeaf(YType.uint64, "received-packets")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("received_bytes",
                                                            "received_packets") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.received_bytes.is_set or
                                                self.received_packets.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.received_bytes.yfilter != YFilter.not_set or
                                                self.received_packets.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                            if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_packets.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "received-bytes" or name == "received-packets"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "received-bytes"):
                                                self.received_bytes = value
                                                self.received_bytes.value_namespace = name_space
                                                self.received_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "received-packets"):
                                                self.received_packets = value
                                                self.received_packets.value_namespace = name_space
                                                self.received_packets.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_pseudowire_headend.is_set or
                                            self.is_sai_itype2.is_set or
                                            self.is_tai_itype2.is_set or
                                            self.ldp_label_advertisment_failed.is_set or
                                            self.local_c_ctype.is_set or
                                            self.local_ceid.is_set or
                                            self.local_cv_type.is_set or
                                            self.local_group_id.is_set or
                                            self.local_label.is_set or
                                            self.local_ldp_id.is_set or
                                            self.local_saii_gbl_id.is_set or
                                            self.local_saiiac_id.is_set or
                                            self.local_taii_gbl_id.is_set or
                                            self.local_taiiac_id.is_set or
                                            self.local_veid.is_set or
                                            self.lsd_rewrite_failed.is_set or
                                            self.rem_saii.is_set or
                                            self.rem_saii_gbl_id.is_set or
                                            self.rem_saiiac_id.is_set or
                                            self.rem_taii.is_set or
                                            self.rem_taii_gbl_id.is_set or
                                            self.rem_taiiac_id.is_set or
                                            self.remote_c_ctype.is_set or
                                            self.remote_ceid.is_set or
                                            self.remote_cv_type.is_set or
                                            self.remote_group_id.is_set or
                                            self.remote_label.is_set or
                                            self.remote_ldp_id.is_set or
                                            self.remote_source_address.is_set or
                                            self.remote_veid.is_set or
                                            self.saii.is_set or
                                            self.source_address.is_set or
                                            self.taii.is_set or
                                            (self.local_agi is not None and self.local_agi.has_data()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                            (self.remote_agi is not None and self.remote_agi.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                            self.is_sai_itype2.yfilter != YFilter.not_set or
                                            self.is_tai_itype2.yfilter != YFilter.not_set or
                                            self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                            self.local_c_ctype.yfilter != YFilter.not_set or
                                            self.local_ceid.yfilter != YFilter.not_set or
                                            self.local_cv_type.yfilter != YFilter.not_set or
                                            self.local_group_id.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_ldp_id.yfilter != YFilter.not_set or
                                            self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_saiiac_id.yfilter != YFilter.not_set or
                                            self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_taiiac_id.yfilter != YFilter.not_set or
                                            self.local_veid.yfilter != YFilter.not_set or
                                            self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.rem_saii.yfilter != YFilter.not_set or
                                            self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_saiiac_id.yfilter != YFilter.not_set or
                                            self.rem_taii.yfilter != YFilter.not_set or
                                            self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_taiiac_id.yfilter != YFilter.not_set or
                                            self.remote_c_ctype.yfilter != YFilter.not_set or
                                            self.remote_ceid.yfilter != YFilter.not_set or
                                            self.remote_cv_type.yfilter != YFilter.not_set or
                                            self.remote_group_id.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_ldp_id.yfilter != YFilter.not_set or
                                            self.remote_source_address.yfilter != YFilter.not_set or
                                            self.remote_veid.yfilter != YFilter.not_set or
                                            self.saii.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.taii.yfilter != YFilter.not_set or
                                            (self.local_agi is not None and self.local_agi.has_operation()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                            (self.remote_agi is not None and self.remote_agi.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                        if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                        if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                        if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                        if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                        if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                        if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                        if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                        if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                        if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                        if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                        if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                        if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_veid.get_name_leafdata())
                                        if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                        if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                        if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                        if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                        if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                        if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                        if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                        if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                        if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                        if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                        if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                        if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                        if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                        if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saii.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.taii.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local-agi"):
                                            if (self.local_agi is None):
                                                self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                            return self.local_agi

                                        if (child_yang_name == "multi-segment-pseudowire-stats"):
                                            if (self.multi_segment_pseudowire_stats is None):
                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            return self.multi_segment_pseudowire_stats

                                        if (child_yang_name == "remote-agi"):
                                            if (self.remote_agi is None):
                                                self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                            return self.remote_agi

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-pseudowire-headend"):
                                            self.is_pseudowire_headend = value
                                            self.is_pseudowire_headend.value_namespace = name_space
                                            self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-sai-itype2"):
                                            self.is_sai_itype2 = value
                                            self.is_sai_itype2.value_namespace = name_space
                                            self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-tai-itype2"):
                                            self.is_tai_itype2 = value
                                            self.is_tai_itype2.value_namespace = name_space
                                            self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertisment-failed"):
                                            self.ldp_label_advertisment_failed = value
                                            self.ldp_label_advertisment_failed.value_namespace = name_space
                                            self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-c-ctype"):
                                            self.local_c_ctype = value
                                            self.local_c_ctype.value_namespace = name_space
                                            self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ceid"):
                                            self.local_ceid = value
                                            self.local_ceid.value_namespace = name_space
                                            self.local_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cv-type"):
                                            self.local_cv_type = value
                                            self.local_cv_type.value_namespace = name_space
                                            self.local_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-group-id"):
                                            self.local_group_id = value
                                            self.local_group_id.value_namespace = name_space
                                            self.local_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ldp-id"):
                                            self.local_ldp_id = value
                                            self.local_ldp_id.value_namespace = name_space
                                            self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saii-gbl-id"):
                                            self.local_saii_gbl_id = value
                                            self.local_saii_gbl_id.value_namespace = name_space
                                            self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saiiac-id"):
                                            self.local_saiiac_id = value
                                            self.local_saiiac_id.value_namespace = name_space
                                            self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taii-gbl-id"):
                                            self.local_taii_gbl_id = value
                                            self.local_taii_gbl_id.value_namespace = name_space
                                            self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taiiac-id"):
                                            self.local_taiiac_id = value
                                            self.local_taiiac_id.value_namespace = name_space
                                            self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-veid"):
                                            self.local_veid = value
                                            self.local_veid.value_namespace = name_space
                                            self.local_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsd-rewrite-failed"):
                                            self.lsd_rewrite_failed = value
                                            self.lsd_rewrite_failed.value_namespace = name_space
                                            self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii"):
                                            self.rem_saii = value
                                            self.rem_saii.value_namespace = name_space
                                            self.rem_saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii-gbl-id"):
                                            self.rem_saii_gbl_id = value
                                            self.rem_saii_gbl_id.value_namespace = name_space
                                            self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saiiac-id"):
                                            self.rem_saiiac_id = value
                                            self.rem_saiiac_id.value_namespace = name_space
                                            self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii"):
                                            self.rem_taii = value
                                            self.rem_taii.value_namespace = name_space
                                            self.rem_taii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii-gbl-id"):
                                            self.rem_taii_gbl_id = value
                                            self.rem_taii_gbl_id.value_namespace = name_space
                                            self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taiiac-id"):
                                            self.rem_taiiac_id = value
                                            self.rem_taiiac_id.value_namespace = name_space
                                            self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-c-ctype"):
                                            self.remote_c_ctype = value
                                            self.remote_c_ctype.value_namespace = name_space
                                            self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ceid"):
                                            self.remote_ceid = value
                                            self.remote_ceid.value_namespace = name_space
                                            self.remote_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cv-type"):
                                            self.remote_cv_type = value
                                            self.remote_cv_type.value_namespace = name_space
                                            self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-group-id"):
                                            self.remote_group_id = value
                                            self.remote_group_id.value_namespace = name_space
                                            self.remote_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ldp-id"):
                                            self.remote_ldp_id = value
                                            self.remote_ldp_id.value_namespace = name_space
                                            self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-source-address"):
                                            self.remote_source_address = value
                                            self.remote_source_address.value_namespace = name_space
                                            self.remote_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-veid"):
                                            self.remote_veid = value
                                            self.remote_veid.value_namespace = name_space
                                            self.remote_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saii"):
                                            self.saii = value
                                            self.saii.value_namespace = name_space
                                            self.saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "taii"):
                                            self.taii = value
                                            self.taii.value_namespace = name_space
                                            self.taii.value_namespace_prefix = name_space_prefix


                                class L2Tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                        self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                        self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                        self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                        self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                        self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                        self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                        self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                        self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                        self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                        self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                        self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                        self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                        self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                        self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                        self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                        self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                        self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                        self.tos = YLeaf(YType.uint8, "tos")

                                        self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dont_fragment_bit",
                                                        "ipv4_source_address",
                                                        "ipv6_source_address",
                                                        "l2tp_class_name",
                                                        "local_cookie_high_value",
                                                        "local_cookie_low_value",
                                                        "local_cookie_size",
                                                        "local_secondary_cookie_high_value",
                                                        "local_secondary_cookie_low_value",
                                                        "local_secondary_cookie_size",
                                                        "local_session_id",
                                                        "path_mtu_enabled",
                                                        "path_mtu_max_value",
                                                        "remote_circuit_status_up",
                                                        "remote_cookie_high_value",
                                                        "remote_cookie_low_value",
                                                        "remote_cookie_size",
                                                        "remote_session_id",
                                                        "tos",
                                                        "tos_mode",
                                                        "ttl",
                                                        "tunnel_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dont_fragment_bit.is_set or
                                            self.ipv4_source_address.is_set or
                                            self.ipv6_source_address.is_set or
                                            self.l2tp_class_name.is_set or
                                            self.local_cookie_high_value.is_set or
                                            self.local_cookie_low_value.is_set or
                                            self.local_cookie_size.is_set or
                                            self.local_secondary_cookie_high_value.is_set or
                                            self.local_secondary_cookie_low_value.is_set or
                                            self.local_secondary_cookie_size.is_set or
                                            self.local_session_id.is_set or
                                            self.path_mtu_enabled.is_set or
                                            self.path_mtu_max_value.is_set or
                                            self.remote_circuit_status_up.is_set or
                                            self.remote_cookie_high_value.is_set or
                                            self.remote_cookie_low_value.is_set or
                                            self.remote_cookie_size.is_set or
                                            self.remote_session_id.is_set or
                                            self.tos.is_set or
                                            self.tos_mode.is_set or
                                            self.ttl.is_set or
                                            self.tunnel_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dont_fragment_bit.yfilter != YFilter.not_set or
                                            self.ipv4_source_address.yfilter != YFilter.not_set or
                                            self.ipv6_source_address.yfilter != YFilter.not_set or
                                            self.l2tp_class_name.yfilter != YFilter.not_set or
                                            self.local_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_cookie_size.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                            self.local_session_id.yfilter != YFilter.not_set or
                                            self.path_mtu_enabled.yfilter != YFilter.not_set or
                                            self.path_mtu_max_value.yfilter != YFilter.not_set or
                                            self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                            self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_size.yfilter != YFilter.not_set or
                                            self.remote_session_id.yfilter != YFilter.not_set or
                                            self.tos.yfilter != YFilter.not_set or
                                            self.tos_mode.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.tunnel_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv3" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                        if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                        if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                        if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                        if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                        if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                        if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                        if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                        if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                        if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                        if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                        if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                        if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                        if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                        if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                        if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                        if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos.get_name_leafdata())
                                        if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dont-fragment-bit"):
                                            self.dont_fragment_bit = value
                                            self.dont_fragment_bit.value_namespace = name_space
                                            self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-source-address"):
                                            self.ipv4_source_address = value
                                            self.ipv4_source_address.value_namespace = name_space
                                            self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-source-address"):
                                            self.ipv6_source_address = value
                                            self.ipv6_source_address.value_namespace = name_space
                                            self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l2tp-class-name"):
                                            self.l2tp_class_name = value
                                            self.l2tp_class_name.value_namespace = name_space
                                            self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-high-value"):
                                            self.local_cookie_high_value = value
                                            self.local_cookie_high_value.value_namespace = name_space
                                            self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-low-value"):
                                            self.local_cookie_low_value = value
                                            self.local_cookie_low_value.value_namespace = name_space
                                            self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-size"):
                                            self.local_cookie_size = value
                                            self.local_cookie_size.value_namespace = name_space
                                            self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-high-value"):
                                            self.local_secondary_cookie_high_value = value
                                            self.local_secondary_cookie_high_value.value_namespace = name_space
                                            self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-low-value"):
                                            self.local_secondary_cookie_low_value = value
                                            self.local_secondary_cookie_low_value.value_namespace = name_space
                                            self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-size"):
                                            self.local_secondary_cookie_size = value
                                            self.local_secondary_cookie_size.value_namespace = name_space
                                            self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-session-id"):
                                            self.local_session_id = value
                                            self.local_session_id.value_namespace = name_space
                                            self.local_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-enabled"):
                                            self.path_mtu_enabled = value
                                            self.path_mtu_enabled.value_namespace = name_space
                                            self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-max-value"):
                                            self.path_mtu_max_value = value
                                            self.path_mtu_max_value.value_namespace = name_space
                                            self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-circuit-status-up"):
                                            self.remote_circuit_status_up = value
                                            self.remote_circuit_status_up.value_namespace = name_space
                                            self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-high-value"):
                                            self.remote_cookie_high_value = value
                                            self.remote_cookie_high_value.value_namespace = name_space
                                            self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-low-value"):
                                            self.remote_cookie_low_value = value
                                            self.remote_cookie_low_value.value_namespace = name_space
                                            self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-size"):
                                            self.remote_cookie_size = value
                                            self.remote_cookie_size.value_namespace = name_space
                                            self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-session-id"):
                                            self.remote_session_id = value
                                            self.remote_session_id.value_namespace = name_space
                                            self.remote_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos"):
                                            self.tos = value
                                            self.tos.value_namespace = name_space
                                            self.tos.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-mode"):
                                            self.tos_mode = value
                                            self.tos_mode.value_namespace = name_space
                                            self.tos_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tunnel-state"):
                                            self.tunnel_state = value
                                            self.tunnel_state.value_namespace = name_space
                                            self.tunnel_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.encapsulation.is_set or
                                        (self.atom is not None and self.atom.has_data()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "encapsulation-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    if (child_yang_name == "l2tpv3"):
                                        if (self.l2tpv3 is None):
                                            self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                        return self.l2tpv3

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation"):
                                        self.encapsulation = value
                                        self.encapsulation.value_namespace = name_space
                                        self.encapsulation.value_namespace_prefix = name_space_prefix


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                    self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                    self.option = YLeaf(YType.enumeration, "option")

                                    self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                    self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ip_tunnel_interface_number",
                                                    "next_hop_ip",
                                                    "option",
                                                    "te_tunnel_interface_number",
                                                    "tp_tunnel_interface_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ip_tunnel_interface_number.is_set or
                                        self.next_hop_ip.is_set or
                                        self.option.is_set or
                                        self.te_tunnel_interface_number.is_set or
                                        self.tp_tunnel_interface_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set or
                                        self.option.yfilter != YFilter.not_set or
                                        self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "preferred-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                    if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.option.get_name_leafdata())
                                    if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                    if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ip-tunnel-interface-number"):
                                        self.ip_tunnel_interface_number = value
                                        self.ip_tunnel_interface_number.value_namespace = name_space
                                        self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                    if(value_path == "option"):
                                        self.option = value
                                        self.option.value_namespace = name_space
                                        self.option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-tunnel-interface-number"):
                                        self.te_tunnel_interface_number = value
                                        self.te_tunnel_interface_number.value_namespace = name_space
                                        self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tp-tunnel-interface-number"):
                                        self.tp_tunnel_interface_number = value
                                        self.tp_tunnel_interface_number.value_namespace = name_space
                                        self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class P2MpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.local_available = YLeaf(YType.boolean, "local-available")

                                    self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                    self.local_flags = YLeaf(YType.uint8, "local-flags")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                    self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                    self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                    self.remote_available = YLeaf(YType.boolean, "remote-available")

                                    self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                    self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                    self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                    self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_available",
                                                    "local_extended_tunnel_id",
                                                    "local_flags",
                                                    "local_label",
                                                    "local_p2mp_id",
                                                    "local_ptree_type",
                                                    "local_tunnel_id",
                                                    "remote_available",
                                                    "remote_extended_tunnel_id",
                                                    "remote_flags",
                                                    "remote_label",
                                                    "remote_p2mp_id",
                                                    "remote_ptree_type",
                                                    "remote_tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_available.is_set or
                                        self.local_extended_tunnel_id.is_set or
                                        self.local_flags.is_set or
                                        self.local_label.is_set or
                                        self.local_p2mp_id.is_set or
                                        self.local_ptree_type.is_set or
                                        self.local_tunnel_id.is_set or
                                        self.remote_available.is_set or
                                        self.remote_extended_tunnel_id.is_set or
                                        self.remote_flags.is_set or
                                        self.remote_label.is_set or
                                        self.remote_p2mp_id.is_set or
                                        self.remote_ptree_type.is_set or
                                        self.remote_tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_available.yfilter != YFilter.not_set or
                                        self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.local_flags.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_p2mp_id.yfilter != YFilter.not_set or
                                        self.local_ptree_type.yfilter != YFilter.not_set or
                                        self.local_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_available.yfilter != YFilter.not_set or
                                        self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_flags.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_p2mp_id.yfilter != YFilter.not_set or
                                        self.remote_ptree_type.yfilter != YFilter.not_set or
                                        self.remote_tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_available.get_name_leafdata())
                                    if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                    if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_flags.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                    if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                    if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                    if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_available.get_name_leafdata())
                                    if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                    if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                    if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                    if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-available"):
                                        self.local_available = value
                                        self.local_available.value_namespace = name_space
                                        self.local_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-extended-tunnel-id"):
                                        self.local_extended_tunnel_id = value
                                        self.local_extended_tunnel_id.value_namespace = name_space
                                        self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-flags"):
                                        self.local_flags = value
                                        self.local_flags.value_namespace = name_space
                                        self.local_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-p2mp-id"):
                                        self.local_p2mp_id = value
                                        self.local_p2mp_id.value_namespace = name_space
                                        self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ptree-type"):
                                        self.local_ptree_type = value
                                        self.local_ptree_type.value_namespace = name_space
                                        self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-tunnel-id"):
                                        self.local_tunnel_id = value
                                        self.local_tunnel_id.value_namespace = name_space
                                        self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-available"):
                                        self.remote_available = value
                                        self.remote_available.value_namespace = name_space
                                        self.remote_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-extended-tunnel-id"):
                                        self.remote_extended_tunnel_id = value
                                        self.remote_extended_tunnel_id.value_namespace = name_space
                                        self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-flags"):
                                        self.remote_flags = value
                                        self.remote_flags.value_namespace = name_space
                                        self.remote_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-p2mp-id"):
                                        self.remote_p2mp_id = value
                                        self.remote_p2mp_id.value_namespace = name_space
                                        self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ptree-type"):
                                        self.remote_ptree_type = value
                                        self.remote_ptree_type.value_namespace = name_space
                                        self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-tunnel-id"):
                                        self.remote_tunnel_id = value
                                        self.remote_tunnel_id.value_namespace = name_space
                                        self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ad_method.is_set or
                                    self.ad_remote_down.is_set or
                                    self.admited_bw.is_set or
                                    self.auto_discovery.is_set or
                                    self.backup_active.is_set or
                                    self.backup_force_active.is_set or
                                    self.backup_pw.is_set or
                                    self.bitrate_mismatched.is_set or
                                    self.bridge_pw_type_mismatch.is_set or
                                    self.cas_mismatched.is_set or
                                    self.diff_ts_mismatched.is_set or
                                    self.disable_delay.is_set or
                                    self.disable_never.is_set or
                                    self.evpn_src_acid.is_set or
                                    self.fe_ctype.is_set or
                                    self.forward_class.is_set or
                                    self.freq_mismatched.is_set or
                                    self.illegal_control_word.is_set or
                                    self.imposed_vlan_id.is_set or
                                    self.interworking.is_set or
                                    self.ipv6_local_source_address.is_set or
                                    self.is_evpnvpws_type.is_set or
                                    self.is_flow_label_static.is_set or
                                    self.is_multi_segment_pseudowire.is_set or
                                    self.is_partially_programmed.is_set or
                                    self.is_pwr_type.is_set or
                                    self.is_vfi.is_set or
                                    self.last_time_status_changed.is_set or
                                    self.last_time_status_down.is_set or
                                    self.ldp_label_advertise_failed.is_set or
                                    self.load_balance.is_set or
                                    self.local_control_word.is_set or
                                    self.local_label_failed.is_set or
                                    self.local_pseudo_wire_type.is_set or
                                    self.local_source_address.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.not_supported_qinq.is_set or
                                    self.num_ma_cwithdraw_msg_received.is_set or
                                    self.number_ma_cwithdraw_message_sent.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.payload_bytes_mismatched.is_set or
                                    self.payload_type_mismatched.is_set or
                                    self.preferred_path_disable_fallback.is_set or
                                    self.primary_peer_id.is_set or
                                    self.primary_pseudo_wire_id.is_set or
                                    self.primary_pw.is_set or
                                    self.protocol.is_set or
                                    self.pseudo_wire_id.is_set or
                                    self.pseudo_wire_state.is_set or
                                    self.pseudo_wire_type_mismatched.is_set or
                                    self.pw_class_name.is_set or
                                    self.pw_flow_label_code17_disabled.is_set or
                                    self.pw_flow_label_type.is_set or
                                    self.pw_flow_label_type_cfg.is_set or
                                    self.pw_redundancy_initial_delay.is_set or
                                    self.pw_redundancy_one_way.is_set or
                                    self.pw_status_use.is_set or
                                    self.pwlsd_rewrite_failed.is_set or
                                    self.remote_control_word.is_set or
                                    self.remote_label_failed.is_set or
                                    self.remote_pseudo_wire_type.is_set or
                                    self.required_bw.is_set or
                                    self.resync_enabled.is_set or
                                    self.resync_threshold.is_set or
                                    self.rtp_mismatched.is_set or
                                    self.sequencing_type.is_set or
                                    self.shutdown.is_set or
                                    self.sig_pkts_mismatched.is_set or
                                    self.ssrc_mismatched.is_set or
                                    self.state.is_set or
                                    self.table_policy_name.is_set or
                                    self.tag_rewrite.is_set or
                                    self.time_created.is_set or
                                    self.time_elapsed_creation.is_set or
                                    self.time_elapsed_status_changed.is_set or
                                    self.time_elapsed_status_down.is_set or
                                    self.transport_lsp_down.is_set or
                                    self.xconnect_id.is_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                    (self.local_interface is not None and self.local_interface.has_data()) or
                                    (self.local_signalling is not None and self.local_signalling.has_data()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                    (self.peer_id is not None and self.peer_id.has_data()) or
                                    (self.preferred_path is not None and self.preferred_path.has_data()) or
                                    (self.remote_interface is not None and self.remote_interface.has_data()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_remote_down.yfilter != YFilter.not_set or
                                    self.admited_bw.yfilter != YFilter.not_set or
                                    self.auto_discovery.yfilter != YFilter.not_set or
                                    self.backup_active.yfilter != YFilter.not_set or
                                    self.backup_force_active.yfilter != YFilter.not_set or
                                    self.backup_pw.yfilter != YFilter.not_set or
                                    self.bitrate_mismatched.yfilter != YFilter.not_set or
                                    self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                    self.cas_mismatched.yfilter != YFilter.not_set or
                                    self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                    self.disable_delay.yfilter != YFilter.not_set or
                                    self.disable_never.yfilter != YFilter.not_set or
                                    self.evpn_src_acid.yfilter != YFilter.not_set or
                                    self.fe_ctype.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.freq_mismatched.yfilter != YFilter.not_set or
                                    self.illegal_control_word.yfilter != YFilter.not_set or
                                    self.imposed_vlan_id.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                    self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                    self.is_flow_label_static.yfilter != YFilter.not_set or
                                    self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                    self.is_partially_programmed.yfilter != YFilter.not_set or
                                    self.is_pwr_type.yfilter != YFilter.not_set or
                                    self.is_vfi.yfilter != YFilter.not_set or
                                    self.last_time_status_changed.yfilter != YFilter.not_set or
                                    self.last_time_status_down.yfilter != YFilter.not_set or
                                    self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                    self.load_balance.yfilter != YFilter.not_set or
                                    self.local_control_word.yfilter != YFilter.not_set or
                                    self.local_label_failed.yfilter != YFilter.not_set or
                                    self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.local_source_address.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.not_supported_qinq.yfilter != YFilter.not_set or
                                    self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                    self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                    self.payload_type_mismatched.yfilter != YFilter.not_set or
                                    self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                    self.primary_peer_id.yfilter != YFilter.not_set or
                                    self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.primary_pw.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.pseudo_wire_state.yfilter != YFilter.not_set or
                                    self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                    self.pw_class_name.yfilter != YFilter.not_set or
                                    self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                    self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                    self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                    self.pw_status_use.yfilter != YFilter.not_set or
                                    self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.remote_control_word.yfilter != YFilter.not_set or
                                    self.remote_label_failed.yfilter != YFilter.not_set or
                                    self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.required_bw.yfilter != YFilter.not_set or
                                    self.resync_enabled.yfilter != YFilter.not_set or
                                    self.resync_threshold.yfilter != YFilter.not_set or
                                    self.rtp_mismatched.yfilter != YFilter.not_set or
                                    self.sequencing_type.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                    self.ssrc_mismatched.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.table_policy_name.yfilter != YFilter.not_set or
                                    self.tag_rewrite.yfilter != YFilter.not_set or
                                    self.time_created.yfilter != YFilter.not_set or
                                    self.time_elapsed_creation.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                    self.transport_lsp_down.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                    (self.local_interface is not None and self.local_interface.has_operation()) or
                                    (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                    (self.peer_id is not None and self.peer_id.has_operation()) or
                                    (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                    (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pseudo-wire" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_active.get_name_leafdata())
                                if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_never.get_name_leafdata())
                                if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance.get_name_leafdata())
                                if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())
                                if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.required_bw.get_name_leafdata())
                                if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_created.get_name_leafdata())
                                if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "encapsulation-info"):
                                    if (self.encapsulation_info is None):
                                        self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    return self.encapsulation_info

                                if (child_yang_name == "local-interface"):
                                    if (self.local_interface is None):
                                        self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                    return self.local_interface

                                if (child_yang_name == "local-signalling"):
                                    if (self.local_signalling is None):
                                        self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                    return self.local_signalling

                                if (child_yang_name == "p2mp-pw"):
                                    if (self.p2mp_pw is None):
                                        self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    return self.p2mp_pw

                                if (child_yang_name == "peer-id"):
                                    if (self.peer_id is None):
                                        self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                    return self.peer_id

                                if (child_yang_name == "preferred-path"):
                                    if (self.preferred_path is None):
                                        self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                    return self.preferred_path

                                if (child_yang_name == "remote-interface"):
                                    if (self.remote_interface is None):
                                        self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                    return self.remote_interface

                                if (child_yang_name == "remote-signalling"):
                                    if (self.remote_signalling is None):
                                        self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                    return self.remote_signalling

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-remote-down"):
                                    self.ad_remote_down = value
                                    self.ad_remote_down.value_namespace = name_space
                                    self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "admited-bw"):
                                    self.admited_bw = value
                                    self.admited_bw.value_namespace = name_space
                                    self.admited_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "auto-discovery"):
                                    self.auto_discovery = value
                                    self.auto_discovery.value_namespace = name_space
                                    self.auto_discovery.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-active"):
                                    self.backup_active = value
                                    self.backup_active.value_namespace = name_space
                                    self.backup_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-force-active"):
                                    self.backup_force_active = value
                                    self.backup_force_active.value_namespace = name_space
                                    self.backup_force_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-pw"):
                                    self.backup_pw = value
                                    self.backup_pw.value_namespace = name_space
                                    self.backup_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "bitrate-mismatched"):
                                    self.bitrate_mismatched = value
                                    self.bitrate_mismatched.value_namespace = name_space
                                    self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-pw-type-mismatch"):
                                    self.bridge_pw_type_mismatch = value
                                    self.bridge_pw_type_mismatch.value_namespace = name_space
                                    self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "cas-mismatched"):
                                    self.cas_mismatched = value
                                    self.cas_mismatched.value_namespace = name_space
                                    self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "diff-ts-mismatched"):
                                    self.diff_ts_mismatched = value
                                    self.diff_ts_mismatched.value_namespace = name_space
                                    self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-delay"):
                                    self.disable_delay = value
                                    self.disable_delay.value_namespace = name_space
                                    self.disable_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-never"):
                                    self.disable_never = value
                                    self.disable_never.value_namespace = name_space
                                    self.disable_never.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-src-acid"):
                                    self.evpn_src_acid = value
                                    self.evpn_src_acid.value_namespace = name_space
                                    self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                if(value_path == "fe-ctype"):
                                    self.fe_ctype = value
                                    self.fe_ctype.value_namespace = name_space
                                    self.fe_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "freq-mismatched"):
                                    self.freq_mismatched = value
                                    self.freq_mismatched.value_namespace = name_space
                                    self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-control-word"):
                                    self.illegal_control_word = value
                                    self.illegal_control_word.value_namespace = name_space
                                    self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "imposed-vlan-id"):
                                    self.imposed_vlan_id = value
                                    self.imposed_vlan_id.value_namespace = name_space
                                    self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-local-source-address"):
                                    self.ipv6_local_source_address = value
                                    self.ipv6_local_source_address.value_namespace = name_space
                                    self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpnvpws-type"):
                                    self.is_evpnvpws_type = value
                                    self.is_evpnvpws_type.value_namespace = name_space
                                    self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-flow-label-static"):
                                    self.is_flow_label_static = value
                                    self.is_flow_label_static.value_namespace = name_space
                                    self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-multi-segment-pseudowire"):
                                    self.is_multi_segment_pseudowire = value
                                    self.is_multi_segment_pseudowire.value_namespace = name_space
                                    self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-partially-programmed"):
                                    self.is_partially_programmed = value
                                    self.is_partially_programmed.value_namespace = name_space
                                    self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pwr-type"):
                                    self.is_pwr_type = value
                                    self.is_pwr_type.value_namespace = name_space
                                    self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vfi"):
                                    self.is_vfi = value
                                    self.is_vfi.value_namespace = name_space
                                    self.is_vfi.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-changed"):
                                    self.last_time_status_changed = value
                                    self.last_time_status_changed.value_namespace = name_space
                                    self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-down"):
                                    self.last_time_status_down = value
                                    self.last_time_status_down.value_namespace = name_space
                                    self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertise-failed"):
                                    self.ldp_label_advertise_failed = value
                                    self.ldp_label_advertise_failed.value_namespace = name_space
                                    self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance"):
                                    self.load_balance = value
                                    self.load_balance.value_namespace = name_space
                                    self.load_balance.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-control-word"):
                                    self.local_control_word = value
                                    self.local_control_word.value_namespace = name_space
                                    self.local_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label-failed"):
                                    self.local_label_failed = value
                                    self.local_label_failed.value_namespace = name_space
                                    self.local_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-pseudo-wire-type"):
                                    self.local_pseudo_wire_type = value
                                    self.local_pseudo_wire_type.value_namespace = name_space
                                    self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-source-address"):
                                    self.local_source_address = value
                                    self.local_source_address.value_namespace = name_space
                                    self.local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-supported-qinq"):
                                    self.not_supported_qinq = value
                                    self.not_supported_qinq.value_namespace = name_space
                                    self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                if(value_path == "num-ma-cwithdraw-msg-received"):
                                    self.num_ma_cwithdraw_msg_received = value
                                    self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                    self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-ma-cwithdraw-message-sent"):
                                    self.number_ma_cwithdraw_message_sent = value
                                    self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                    self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes-mismatched"):
                                    self.payload_bytes_mismatched = value
                                    self.payload_bytes_mismatched.value_namespace = name_space
                                    self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-type-mismatched"):
                                    self.payload_type_mismatched = value
                                    self.payload_type_mismatched.value_namespace = name_space
                                    self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "preferred-path-disable-fallback"):
                                    self.preferred_path_disable_fallback = value
                                    self.preferred_path_disable_fallback.value_namespace = name_space
                                    self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-peer-id"):
                                    self.primary_peer_id = value
                                    self.primary_peer_id.value_namespace = name_space
                                    self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pseudo-wire-id"):
                                    self.primary_pseudo_wire_id = value
                                    self.primary_pseudo_wire_id.value_namespace = name_space
                                    self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pw"):
                                    self.primary_pw = value
                                    self.primary_pw.value_namespace = name_space
                                    self.primary_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id"):
                                    self.pseudo_wire_id = value
                                    self.pseudo_wire_id.value_namespace = name_space
                                    self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-state"):
                                    self.pseudo_wire_state = value
                                    self.pseudo_wire_state.value_namespace = name_space
                                    self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-type-mismatched"):
                                    self.pseudo_wire_type_mismatched = value
                                    self.pseudo_wire_type_mismatched.value_namespace = name_space
                                    self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-class-name"):
                                    self.pw_class_name = value
                                    self.pw_class_name.value_namespace = name_space
                                    self.pw_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-code17-disabled"):
                                    self.pw_flow_label_code17_disabled = value
                                    self.pw_flow_label_code17_disabled.value_namespace = name_space
                                    self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type"):
                                    self.pw_flow_label_type = value
                                    self.pw_flow_label_type.value_namespace = name_space
                                    self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type-cfg"):
                                    self.pw_flow_label_type_cfg = value
                                    self.pw_flow_label_type_cfg.value_namespace = name_space
                                    self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-initial-delay"):
                                    self.pw_redundancy_initial_delay = value
                                    self.pw_redundancy_initial_delay.value_namespace = name_space
                                    self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-one-way"):
                                    self.pw_redundancy_one_way = value
                                    self.pw_redundancy_one_way.value_namespace = name_space
                                    self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-status-use"):
                                    self.pw_status_use = value
                                    self.pw_status_use.value_namespace = name_space
                                    self.pw_status_use.value_namespace_prefix = name_space_prefix
                                if(value_path == "pwlsd-rewrite-failed"):
                                    self.pwlsd_rewrite_failed = value
                                    self.pwlsd_rewrite_failed.value_namespace = name_space
                                    self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-control-word"):
                                    self.remote_control_word = value
                                    self.remote_control_word.value_namespace = name_space
                                    self.remote_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label-failed"):
                                    self.remote_label_failed = value
                                    self.remote_label_failed.value_namespace = name_space
                                    self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-pseudo-wire-type"):
                                    self.remote_pseudo_wire_type = value
                                    self.remote_pseudo_wire_type.value_namespace = name_space
                                    self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "required-bw"):
                                    self.required_bw = value
                                    self.required_bw.value_namespace = name_space
                                    self.required_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-enabled"):
                                    self.resync_enabled = value
                                    self.resync_enabled.value_namespace = name_space
                                    self.resync_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-threshold"):
                                    self.resync_threshold = value
                                    self.resync_threshold.value_namespace = name_space
                                    self.resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "rtp-mismatched"):
                                    self.rtp_mismatched = value
                                    self.rtp_mismatched.value_namespace = name_space
                                    self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequencing-type"):
                                    self.sequencing_type = value
                                    self.sequencing_type.value_namespace = name_space
                                    self.sequencing_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "sig-pkts-mismatched"):
                                    self.sig_pkts_mismatched = value
                                    self.sig_pkts_mismatched.value_namespace = name_space
                                    self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "ssrc-mismatched"):
                                    self.ssrc_mismatched = value
                                    self.ssrc_mismatched.value_namespace = name_space
                                    self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-policy-name"):
                                    self.table_policy_name = value
                                    self.table_policy_name.value_namespace = name_space
                                    self.table_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag-rewrite"):
                                    self.tag_rewrite = value
                                    self.tag_rewrite.value_namespace = name_space
                                    self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-created"):
                                    self.time_created = value
                                    self.time_created.value_namespace = name_space
                                    self.time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-creation"):
                                    self.time_elapsed_creation = value
                                    self.time_elapsed_creation.value_namespace = name_space
                                    self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-changed"):
                                    self.time_elapsed_status_changed = value
                                    self.time_elapsed_status_changed.value_namespace = name_space
                                    self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-down"):
                                    self.time_elapsed_status_down = value
                                    self.time_elapsed_status_down.value_namespace = name_space
                                    self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-lsp-down"):
                                    self.transport_lsp_down = value
                                    self.transport_lsp_down.value_namespace = name_space
                                    self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.segment_type.is_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                                (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.segment_type.yfilter != YFilter.not_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                                (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "attachment-circuit"):
                                if (self.attachment_circuit is None):
                                    self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                                    self.attachment_circuit.parent = self
                                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                return self.attachment_circuit

                            if (child_yang_name == "pseudo-wire"):
                                if (self.pseudo_wire is None):
                                    self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire()
                                    self.pseudo_wire.parent = self
                                    self._children_name_map["pseudo_wire"] = "pseudo-wire"
                                return self.pseudo_wire

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "segment-type"):
                                self.segment_type = value
                                self.segment_type.value_namespace = name_space
                                self.segment_type.value_namespace_prefix = name_space_prefix


                    class Segment2(Entity):
                        """
                        Segment 2
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2, self).__init__()

                            self.yang_name = "segment2"
                            self.yang_parent_name = "xconnect"

                            self.segment_type = YLeaf(YType.enumeration, "segment-type")

                            self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            self._children_yang_names.add("attachment-circuit")

                            self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            self._children_yang_names.add("pseudo-wire")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("segment_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2, self).__setattr__(name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "segment2"

                                self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                                self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                                self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                                self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                                self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                                self.msti = YLeaf(YType.str, "msti")

                                self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.node_id = YLeaf(YType.str, "node-id")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._children_yang_names.add("interface")

                                self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._children_yang_names.add("l2vpn-protection")

                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bvi_mac_conflict",
                                                "bvi_no_port_up",
                                                "control_word_mismatched",
                                                "encapsulation_error",
                                                "encapsulation_mismatched",
                                                "evpn_internal_label",
                                                "interface_handle",
                                                "internal_ms_ti",
                                                "interworking",
                                                "is_ac_partially_programmed",
                                                "mac_limit_oper_down",
                                                "ms_ti_mismatch",
                                                "msti",
                                                "msti_mismatch_down",
                                                "mtu_mismatched",
                                                "node_id",
                                                "out_of_memory_state",
                                                "redundancy_group_id",
                                                "redundancy_group_state",
                                                "redundancy_object_id",
                                                "state",
                                                "tdm_media_mismatched",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__setattr__(name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class L2VpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.protected_name = YLeaf(YType.str, "protected-name")

                                    self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                    self.protection_name = YLeaf(YType.str, "protection-name")

                                    self.protection_type = YLeaf(YType.enumeration, "protection-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "protected_name",
                                                    "protection_configured",
                                                    "protection_name",
                                                    "protection_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.protected_name.is_set or
                                        self.protection_configured.is_set or
                                        self.protection_name.is_set or
                                        self.protection_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.protected_name.yfilter != YFilter.not_set or
                                        self.protection_configured.yfilter != YFilter.not_set or
                                        self.protection_name.yfilter != YFilter.not_set or
                                        self.protection_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2vpn-protection" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protected_name.get_name_leafdata())
                                    if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                    if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_name.get_name_leafdata())
                                    if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protected-name"):
                                        self.protected_name = value
                                        self.protected_name.value_namespace = name_space
                                        self.protected_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-configured"):
                                        self.protection_configured = value
                                        self.protection_configured.value_namespace = name_space
                                        self.protection_configured.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-name"):
                                        self.protection_name = value
                                        self.protection_name.value_namespace = name_space
                                        self.protection_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-type"):
                                        self.protection_type = value
                                        self.protection_type.value_namespace = name_space
                                        self.protection_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bvi_mac_conflict.is_set or
                                    self.bvi_no_port_up.is_set or
                                    self.control_word_mismatched.is_set or
                                    self.encapsulation_error.is_set or
                                    self.encapsulation_mismatched.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.interface_handle.is_set or
                                    self.internal_ms_ti.is_set or
                                    self.interworking.is_set or
                                    self.is_ac_partially_programmed.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.ms_ti_mismatch.is_set or
                                    self.msti.is_set or
                                    self.msti_mismatch_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.node_id.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_group_state.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.state.is_set or
                                    self.tdm_media_mismatched.is_set or
                                    self.xconnect_id.is_set or
                                    (self.interface is not None and self.interface.has_data()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                    self.bvi_no_port_up.yfilter != YFilter.not_set or
                                    self.control_word_mismatched.yfilter != YFilter.not_set or
                                    self.encapsulation_error.yfilter != YFilter.not_set or
                                    self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.internal_ms_ti.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                    self.msti.yfilter != YFilter.not_set or
                                    self.msti_mismatch_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_group_state.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.interface is not None and self.interface.has_operation()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "attachment-circuit" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                                if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                                if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                                if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                                if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface"):
                                    if (self.interface is None):
                                        self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                                        self.interface.parent = self
                                        self._children_name_map["interface"] = "interface"
                                    return self.interface

                                if (child_yang_name == "l2vpn-protection"):
                                    if (self.l2vpn_protection is None):
                                        self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                                        self.l2vpn_protection.parent = self
                                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    return self.l2vpn_protection

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bvi-mac-conflict"):
                                    self.bvi_mac_conflict = value
                                    self.bvi_mac_conflict.value_namespace = name_space
                                    self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-no-port-up"):
                                    self.bvi_no_port_up = value
                                    self.bvi_no_port_up.value_namespace = name_space
                                    self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-word-mismatched"):
                                    self.control_word_mismatched = value
                                    self.control_word_mismatched.value_namespace = name_space
                                    self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-error"):
                                    self.encapsulation_error = value
                                    self.encapsulation_error.value_namespace = name_space
                                    self.encapsulation_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-mismatched"):
                                    self.encapsulation_mismatched = value
                                    self.encapsulation_mismatched.value_namespace = name_space
                                    self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-ms-ti"):
                                    self.internal_ms_ti = value
                                    self.internal_ms_ti.value_namespace = name_space
                                    self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ac-partially-programmed"):
                                    self.is_ac_partially_programmed = value
                                    self.is_ac_partially_programmed.value_namespace = name_space
                                    self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ms-ti-mismatch"):
                                    self.ms_ti_mismatch = value
                                    self.ms_ti_mismatch.value_namespace = name_space
                                    self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti"):
                                    self.msti = value
                                    self.msti.value_namespace = name_space
                                    self.msti.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-mismatch-down"):
                                    self.msti_mismatch_down = value
                                    self.msti_mismatch_down.value_namespace = name_space
                                    self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-state"):
                                    self.redundancy_group_state = value
                                    self.redundancy_group_state.value_namespace = name_space
                                    self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "tdm-media-mismatched"):
                                    self.tdm_media_mismatched = value
                                    self.tdm_media_mismatched.value_namespace = name_space
                                    self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class PseudoWire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire, self).__init__()

                                self.yang_name = "pseudo-wire"
                                self.yang_parent_name = "segment2"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                self.backup_active = YLeaf(YType.boolean, "backup-active")

                                self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                self.disable_never = YLeaf(YType.boolean, "disable-never")

                                self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                self.local_source_address = YLeaf(YType.str, "local-source-address")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                self.required_bw = YLeaf(YType.uint32, "required-bw")

                                self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                self.time_created = YLeaf(YType.str, "time-created")

                                self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                self._children_yang_names.add("encapsulation-info")

                                self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                                self._children_yang_names.add("local-interface")

                                self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                                self._children_yang_names.add("local-signalling")

                                self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._children_yang_names.add("p2mp-pw")

                                self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                                self._children_yang_names.add("peer-id")

                                self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                                self._children_yang_names.add("preferred-path")

                                self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                                self._children_yang_names.add("remote-interface")

                                self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                self._children_yang_names.add("remote-signalling")

                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_remote_down",
                                                "admited_bw",
                                                "auto_discovery",
                                                "backup_active",
                                                "backup_force_active",
                                                "backup_pw",
                                                "bitrate_mismatched",
                                                "bridge_pw_type_mismatch",
                                                "cas_mismatched",
                                                "diff_ts_mismatched",
                                                "disable_delay",
                                                "disable_never",
                                                "evpn_src_acid",
                                                "fe_ctype",
                                                "forward_class",
                                                "freq_mismatched",
                                                "illegal_control_word",
                                                "imposed_vlan_id",
                                                "interworking",
                                                "ipv6_local_source_address",
                                                "is_evpnvpws_type",
                                                "is_flow_label_static",
                                                "is_multi_segment_pseudowire",
                                                "is_partially_programmed",
                                                "is_pwr_type",
                                                "is_vfi",
                                                "last_time_status_changed",
                                                "last_time_status_down",
                                                "ldp_label_advertise_failed",
                                                "load_balance",
                                                "local_control_word",
                                                "local_label_failed",
                                                "local_pseudo_wire_type",
                                                "local_source_address",
                                                "mac_limit_oper_down",
                                                "mtu_mismatched",
                                                "not_supported_qinq",
                                                "num_ma_cwithdraw_msg_received",
                                                "number_ma_cwithdraw_message_sent",
                                                "out_of_memory_state",
                                                "payload_bytes_mismatched",
                                                "payload_type_mismatched",
                                                "preferred_path_disable_fallback",
                                                "primary_peer_id",
                                                "primary_pseudo_wire_id",
                                                "primary_pw",
                                                "protocol",
                                                "pseudo_wire_id",
                                                "pseudo_wire_state",
                                                "pseudo_wire_type_mismatched",
                                                "pw_class_name",
                                                "pw_flow_label_code17_disabled",
                                                "pw_flow_label_type",
                                                "pw_flow_label_type_cfg",
                                                "pw_redundancy_initial_delay",
                                                "pw_redundancy_one_way",
                                                "pw_status_use",
                                                "pwlsd_rewrite_failed",
                                                "remote_control_word",
                                                "remote_label_failed",
                                                "remote_pseudo_wire_type",
                                                "required_bw",
                                                "resync_enabled",
                                                "resync_threshold",
                                                "rtp_mismatched",
                                                "sequencing_type",
                                                "shutdown",
                                                "sig_pkts_mismatched",
                                                "ssrc_mismatched",
                                                "state",
                                                "table_policy_name",
                                                "tag_rewrite",
                                                "time_created",
                                                "time_elapsed_creation",
                                                "time_elapsed_status_changed",
                                                "time_elapsed_status_down",
                                                "transport_lsp_down",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire, self).__setattr__(name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                    self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                    self.type = YLeaf(YType.enumeration, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "ipv4_peer_id",
                                                    "ipv6_peer_id",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.ipv4_peer_id.is_set or
                                        self.ipv6_peer_id.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.ipv4_peer_id.yfilter != YFilter.not_set or
                                        self.ipv6_peer_id.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "peer-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                    if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-peer-id"):
                                        self.ipv4_peer_id = value
                                        self.ipv4_peer_id.value_namespace = name_space
                                        self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-peer-id"):
                                        self.ipv6_peer_id = value
                                        self.ipv6_peer_id.value_namespace = name_space
                                        self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                    self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._children_yang_names.add("l2tpv3")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                        self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                        self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                        self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                        self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                        self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                        self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                        self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                        self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                        self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                        self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                        self.local_veid = YLeaf(YType.uint32, "local-veid")

                                        self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                        self.rem_saii = YLeaf(YType.str, "rem-saii")

                                        self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                        self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                        self.rem_taii = YLeaf(YType.str, "rem-taii")

                                        self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                        self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                        self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                        self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                        self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                        self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                        self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                        self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                        self.saii = YLeaf(YType.str, "saii")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.taii = YLeaf(YType.str, "taii")

                                        self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                        self._children_yang_names.add("local-agi")

                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._children_yang_names.add("multi-segment-pseudowire-stats")

                                        self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                        self._children_yang_names.add("remote-agi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_pseudowire_headend",
                                                        "is_sai_itype2",
                                                        "is_tai_itype2",
                                                        "ldp_label_advertisment_failed",
                                                        "local_c_ctype",
                                                        "local_ceid",
                                                        "local_cv_type",
                                                        "local_group_id",
                                                        "local_label",
                                                        "local_ldp_id",
                                                        "local_saii_gbl_id",
                                                        "local_saiiac_id",
                                                        "local_taii_gbl_id",
                                                        "local_taiiac_id",
                                                        "local_veid",
                                                        "lsd_rewrite_failed",
                                                        "rem_saii",
                                                        "rem_saii_gbl_id",
                                                        "rem_saiiac_id",
                                                        "rem_taii",
                                                        "rem_taii_gbl_id",
                                                        "rem_taiiac_id",
                                                        "remote_c_ctype",
                                                        "remote_ceid",
                                                        "remote_cv_type",
                                                        "remote_group_id",
                                                        "remote_label",
                                                        "remote_ldp_id",
                                                        "remote_source_address",
                                                        "remote_veid",
                                                        "saii",
                                                        "source_address",
                                                        "taii") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"

                                            self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                            self.received_packets = YLeaf(YType.uint64, "received-packets")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("received_bytes",
                                                            "received_packets") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.received_bytes.is_set or
                                                self.received_packets.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.received_bytes.yfilter != YFilter.not_set or
                                                self.received_packets.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                            if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_packets.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "received-bytes" or name == "received-packets"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "received-bytes"):
                                                self.received_bytes = value
                                                self.received_bytes.value_namespace = name_space
                                                self.received_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "received-packets"):
                                                self.received_packets = value
                                                self.received_packets.value_namespace = name_space
                                                self.received_packets.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_pseudowire_headend.is_set or
                                            self.is_sai_itype2.is_set or
                                            self.is_tai_itype2.is_set or
                                            self.ldp_label_advertisment_failed.is_set or
                                            self.local_c_ctype.is_set or
                                            self.local_ceid.is_set or
                                            self.local_cv_type.is_set or
                                            self.local_group_id.is_set or
                                            self.local_label.is_set or
                                            self.local_ldp_id.is_set or
                                            self.local_saii_gbl_id.is_set or
                                            self.local_saiiac_id.is_set or
                                            self.local_taii_gbl_id.is_set or
                                            self.local_taiiac_id.is_set or
                                            self.local_veid.is_set or
                                            self.lsd_rewrite_failed.is_set or
                                            self.rem_saii.is_set or
                                            self.rem_saii_gbl_id.is_set or
                                            self.rem_saiiac_id.is_set or
                                            self.rem_taii.is_set or
                                            self.rem_taii_gbl_id.is_set or
                                            self.rem_taiiac_id.is_set or
                                            self.remote_c_ctype.is_set or
                                            self.remote_ceid.is_set or
                                            self.remote_cv_type.is_set or
                                            self.remote_group_id.is_set or
                                            self.remote_label.is_set or
                                            self.remote_ldp_id.is_set or
                                            self.remote_source_address.is_set or
                                            self.remote_veid.is_set or
                                            self.saii.is_set or
                                            self.source_address.is_set or
                                            self.taii.is_set or
                                            (self.local_agi is not None and self.local_agi.has_data()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                            (self.remote_agi is not None and self.remote_agi.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                            self.is_sai_itype2.yfilter != YFilter.not_set or
                                            self.is_tai_itype2.yfilter != YFilter.not_set or
                                            self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                            self.local_c_ctype.yfilter != YFilter.not_set or
                                            self.local_ceid.yfilter != YFilter.not_set or
                                            self.local_cv_type.yfilter != YFilter.not_set or
                                            self.local_group_id.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_ldp_id.yfilter != YFilter.not_set or
                                            self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_saiiac_id.yfilter != YFilter.not_set or
                                            self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_taiiac_id.yfilter != YFilter.not_set or
                                            self.local_veid.yfilter != YFilter.not_set or
                                            self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.rem_saii.yfilter != YFilter.not_set or
                                            self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_saiiac_id.yfilter != YFilter.not_set or
                                            self.rem_taii.yfilter != YFilter.not_set or
                                            self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_taiiac_id.yfilter != YFilter.not_set or
                                            self.remote_c_ctype.yfilter != YFilter.not_set or
                                            self.remote_ceid.yfilter != YFilter.not_set or
                                            self.remote_cv_type.yfilter != YFilter.not_set or
                                            self.remote_group_id.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_ldp_id.yfilter != YFilter.not_set or
                                            self.remote_source_address.yfilter != YFilter.not_set or
                                            self.remote_veid.yfilter != YFilter.not_set or
                                            self.saii.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.taii.yfilter != YFilter.not_set or
                                            (self.local_agi is not None and self.local_agi.has_operation()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                            (self.remote_agi is not None and self.remote_agi.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                        if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                        if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                        if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                        if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                        if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                        if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                        if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                        if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                        if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                        if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                        if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                        if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_veid.get_name_leafdata())
                                        if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                        if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                        if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                        if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                        if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                        if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                        if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                        if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                        if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                        if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                        if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                        if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                        if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                        if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saii.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.taii.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local-agi"):
                                            if (self.local_agi is None):
                                                self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                            return self.local_agi

                                        if (child_yang_name == "multi-segment-pseudowire-stats"):
                                            if (self.multi_segment_pseudowire_stats is None):
                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            return self.multi_segment_pseudowire_stats

                                        if (child_yang_name == "remote-agi"):
                                            if (self.remote_agi is None):
                                                self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                            return self.remote_agi

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-pseudowire-headend"):
                                            self.is_pseudowire_headend = value
                                            self.is_pseudowire_headend.value_namespace = name_space
                                            self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-sai-itype2"):
                                            self.is_sai_itype2 = value
                                            self.is_sai_itype2.value_namespace = name_space
                                            self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-tai-itype2"):
                                            self.is_tai_itype2 = value
                                            self.is_tai_itype2.value_namespace = name_space
                                            self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertisment-failed"):
                                            self.ldp_label_advertisment_failed = value
                                            self.ldp_label_advertisment_failed.value_namespace = name_space
                                            self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-c-ctype"):
                                            self.local_c_ctype = value
                                            self.local_c_ctype.value_namespace = name_space
                                            self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ceid"):
                                            self.local_ceid = value
                                            self.local_ceid.value_namespace = name_space
                                            self.local_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cv-type"):
                                            self.local_cv_type = value
                                            self.local_cv_type.value_namespace = name_space
                                            self.local_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-group-id"):
                                            self.local_group_id = value
                                            self.local_group_id.value_namespace = name_space
                                            self.local_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ldp-id"):
                                            self.local_ldp_id = value
                                            self.local_ldp_id.value_namespace = name_space
                                            self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saii-gbl-id"):
                                            self.local_saii_gbl_id = value
                                            self.local_saii_gbl_id.value_namespace = name_space
                                            self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saiiac-id"):
                                            self.local_saiiac_id = value
                                            self.local_saiiac_id.value_namespace = name_space
                                            self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taii-gbl-id"):
                                            self.local_taii_gbl_id = value
                                            self.local_taii_gbl_id.value_namespace = name_space
                                            self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taiiac-id"):
                                            self.local_taiiac_id = value
                                            self.local_taiiac_id.value_namespace = name_space
                                            self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-veid"):
                                            self.local_veid = value
                                            self.local_veid.value_namespace = name_space
                                            self.local_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsd-rewrite-failed"):
                                            self.lsd_rewrite_failed = value
                                            self.lsd_rewrite_failed.value_namespace = name_space
                                            self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii"):
                                            self.rem_saii = value
                                            self.rem_saii.value_namespace = name_space
                                            self.rem_saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii-gbl-id"):
                                            self.rem_saii_gbl_id = value
                                            self.rem_saii_gbl_id.value_namespace = name_space
                                            self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saiiac-id"):
                                            self.rem_saiiac_id = value
                                            self.rem_saiiac_id.value_namespace = name_space
                                            self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii"):
                                            self.rem_taii = value
                                            self.rem_taii.value_namespace = name_space
                                            self.rem_taii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii-gbl-id"):
                                            self.rem_taii_gbl_id = value
                                            self.rem_taii_gbl_id.value_namespace = name_space
                                            self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taiiac-id"):
                                            self.rem_taiiac_id = value
                                            self.rem_taiiac_id.value_namespace = name_space
                                            self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-c-ctype"):
                                            self.remote_c_ctype = value
                                            self.remote_c_ctype.value_namespace = name_space
                                            self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ceid"):
                                            self.remote_ceid = value
                                            self.remote_ceid.value_namespace = name_space
                                            self.remote_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cv-type"):
                                            self.remote_cv_type = value
                                            self.remote_cv_type.value_namespace = name_space
                                            self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-group-id"):
                                            self.remote_group_id = value
                                            self.remote_group_id.value_namespace = name_space
                                            self.remote_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ldp-id"):
                                            self.remote_ldp_id = value
                                            self.remote_ldp_id.value_namespace = name_space
                                            self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-source-address"):
                                            self.remote_source_address = value
                                            self.remote_source_address.value_namespace = name_space
                                            self.remote_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-veid"):
                                            self.remote_veid = value
                                            self.remote_veid.value_namespace = name_space
                                            self.remote_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saii"):
                                            self.saii = value
                                            self.saii.value_namespace = name_space
                                            self.saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "taii"):
                                            self.taii = value
                                            self.taii.value_namespace = name_space
                                            self.taii.value_namespace_prefix = name_space_prefix


                                class L2Tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                        self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                        self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                        self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                        self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                        self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                        self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                        self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                        self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                        self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                        self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                        self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                        self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                        self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                        self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                        self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                        self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                        self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                        self.tos = YLeaf(YType.uint8, "tos")

                                        self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dont_fragment_bit",
                                                        "ipv4_source_address",
                                                        "ipv6_source_address",
                                                        "l2tp_class_name",
                                                        "local_cookie_high_value",
                                                        "local_cookie_low_value",
                                                        "local_cookie_size",
                                                        "local_secondary_cookie_high_value",
                                                        "local_secondary_cookie_low_value",
                                                        "local_secondary_cookie_size",
                                                        "local_session_id",
                                                        "path_mtu_enabled",
                                                        "path_mtu_max_value",
                                                        "remote_circuit_status_up",
                                                        "remote_cookie_high_value",
                                                        "remote_cookie_low_value",
                                                        "remote_cookie_size",
                                                        "remote_session_id",
                                                        "tos",
                                                        "tos_mode",
                                                        "ttl",
                                                        "tunnel_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dont_fragment_bit.is_set or
                                            self.ipv4_source_address.is_set or
                                            self.ipv6_source_address.is_set or
                                            self.l2tp_class_name.is_set or
                                            self.local_cookie_high_value.is_set or
                                            self.local_cookie_low_value.is_set or
                                            self.local_cookie_size.is_set or
                                            self.local_secondary_cookie_high_value.is_set or
                                            self.local_secondary_cookie_low_value.is_set or
                                            self.local_secondary_cookie_size.is_set or
                                            self.local_session_id.is_set or
                                            self.path_mtu_enabled.is_set or
                                            self.path_mtu_max_value.is_set or
                                            self.remote_circuit_status_up.is_set or
                                            self.remote_cookie_high_value.is_set or
                                            self.remote_cookie_low_value.is_set or
                                            self.remote_cookie_size.is_set or
                                            self.remote_session_id.is_set or
                                            self.tos.is_set or
                                            self.tos_mode.is_set or
                                            self.ttl.is_set or
                                            self.tunnel_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dont_fragment_bit.yfilter != YFilter.not_set or
                                            self.ipv4_source_address.yfilter != YFilter.not_set or
                                            self.ipv6_source_address.yfilter != YFilter.not_set or
                                            self.l2tp_class_name.yfilter != YFilter.not_set or
                                            self.local_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_cookie_size.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                            self.local_session_id.yfilter != YFilter.not_set or
                                            self.path_mtu_enabled.yfilter != YFilter.not_set or
                                            self.path_mtu_max_value.yfilter != YFilter.not_set or
                                            self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                            self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_size.yfilter != YFilter.not_set or
                                            self.remote_session_id.yfilter != YFilter.not_set or
                                            self.tos.yfilter != YFilter.not_set or
                                            self.tos_mode.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.tunnel_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv3" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                        if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                        if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                        if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                        if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                        if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                        if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                        if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                        if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                        if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                        if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                        if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                        if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                        if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                        if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                        if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                        if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos.get_name_leafdata())
                                        if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dont-fragment-bit"):
                                            self.dont_fragment_bit = value
                                            self.dont_fragment_bit.value_namespace = name_space
                                            self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-source-address"):
                                            self.ipv4_source_address = value
                                            self.ipv4_source_address.value_namespace = name_space
                                            self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-source-address"):
                                            self.ipv6_source_address = value
                                            self.ipv6_source_address.value_namespace = name_space
                                            self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l2tp-class-name"):
                                            self.l2tp_class_name = value
                                            self.l2tp_class_name.value_namespace = name_space
                                            self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-high-value"):
                                            self.local_cookie_high_value = value
                                            self.local_cookie_high_value.value_namespace = name_space
                                            self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-low-value"):
                                            self.local_cookie_low_value = value
                                            self.local_cookie_low_value.value_namespace = name_space
                                            self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-size"):
                                            self.local_cookie_size = value
                                            self.local_cookie_size.value_namespace = name_space
                                            self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-high-value"):
                                            self.local_secondary_cookie_high_value = value
                                            self.local_secondary_cookie_high_value.value_namespace = name_space
                                            self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-low-value"):
                                            self.local_secondary_cookie_low_value = value
                                            self.local_secondary_cookie_low_value.value_namespace = name_space
                                            self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-size"):
                                            self.local_secondary_cookie_size = value
                                            self.local_secondary_cookie_size.value_namespace = name_space
                                            self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-session-id"):
                                            self.local_session_id = value
                                            self.local_session_id.value_namespace = name_space
                                            self.local_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-enabled"):
                                            self.path_mtu_enabled = value
                                            self.path_mtu_enabled.value_namespace = name_space
                                            self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-max-value"):
                                            self.path_mtu_max_value = value
                                            self.path_mtu_max_value.value_namespace = name_space
                                            self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-circuit-status-up"):
                                            self.remote_circuit_status_up = value
                                            self.remote_circuit_status_up.value_namespace = name_space
                                            self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-high-value"):
                                            self.remote_cookie_high_value = value
                                            self.remote_cookie_high_value.value_namespace = name_space
                                            self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-low-value"):
                                            self.remote_cookie_low_value = value
                                            self.remote_cookie_low_value.value_namespace = name_space
                                            self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-size"):
                                            self.remote_cookie_size = value
                                            self.remote_cookie_size.value_namespace = name_space
                                            self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-session-id"):
                                            self.remote_session_id = value
                                            self.remote_session_id.value_namespace = name_space
                                            self.remote_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos"):
                                            self.tos = value
                                            self.tos.value_namespace = name_space
                                            self.tos.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-mode"):
                                            self.tos_mode = value
                                            self.tos_mode.value_namespace = name_space
                                            self.tos_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tunnel-state"):
                                            self.tunnel_state = value
                                            self.tunnel_state.value_namespace = name_space
                                            self.tunnel_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.encapsulation.is_set or
                                        (self.atom is not None and self.atom.has_data()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "encapsulation-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    if (child_yang_name == "l2tpv3"):
                                        if (self.l2tpv3 is None):
                                            self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                        return self.l2tpv3

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation"):
                                        self.encapsulation = value
                                        self.encapsulation.value_namespace = name_space
                                        self.encapsulation.value_namespace_prefix = name_space_prefix


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                    self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                    self.option = YLeaf(YType.enumeration, "option")

                                    self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                    self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ip_tunnel_interface_number",
                                                    "next_hop_ip",
                                                    "option",
                                                    "te_tunnel_interface_number",
                                                    "tp_tunnel_interface_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ip_tunnel_interface_number.is_set or
                                        self.next_hop_ip.is_set or
                                        self.option.is_set or
                                        self.te_tunnel_interface_number.is_set or
                                        self.tp_tunnel_interface_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set or
                                        self.option.yfilter != YFilter.not_set or
                                        self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "preferred-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                    if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.option.get_name_leafdata())
                                    if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                    if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ip-tunnel-interface-number"):
                                        self.ip_tunnel_interface_number = value
                                        self.ip_tunnel_interface_number.value_namespace = name_space
                                        self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                    if(value_path == "option"):
                                        self.option = value
                                        self.option.value_namespace = name_space
                                        self.option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-tunnel-interface-number"):
                                        self.te_tunnel_interface_number = value
                                        self.te_tunnel_interface_number.value_namespace = name_space
                                        self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tp-tunnel-interface-number"):
                                        self.tp_tunnel_interface_number = value
                                        self.tp_tunnel_interface_number.value_namespace = name_space
                                        self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class P2MpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.local_available = YLeaf(YType.boolean, "local-available")

                                    self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                    self.local_flags = YLeaf(YType.uint8, "local-flags")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                    self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                    self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                    self.remote_available = YLeaf(YType.boolean, "remote-available")

                                    self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                    self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                    self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                    self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_available",
                                                    "local_extended_tunnel_id",
                                                    "local_flags",
                                                    "local_label",
                                                    "local_p2mp_id",
                                                    "local_ptree_type",
                                                    "local_tunnel_id",
                                                    "remote_available",
                                                    "remote_extended_tunnel_id",
                                                    "remote_flags",
                                                    "remote_label",
                                                    "remote_p2mp_id",
                                                    "remote_ptree_type",
                                                    "remote_tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_available.is_set or
                                        self.local_extended_tunnel_id.is_set or
                                        self.local_flags.is_set or
                                        self.local_label.is_set or
                                        self.local_p2mp_id.is_set or
                                        self.local_ptree_type.is_set or
                                        self.local_tunnel_id.is_set or
                                        self.remote_available.is_set or
                                        self.remote_extended_tunnel_id.is_set or
                                        self.remote_flags.is_set or
                                        self.remote_label.is_set or
                                        self.remote_p2mp_id.is_set or
                                        self.remote_ptree_type.is_set or
                                        self.remote_tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_available.yfilter != YFilter.not_set or
                                        self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.local_flags.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_p2mp_id.yfilter != YFilter.not_set or
                                        self.local_ptree_type.yfilter != YFilter.not_set or
                                        self.local_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_available.yfilter != YFilter.not_set or
                                        self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_flags.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_p2mp_id.yfilter != YFilter.not_set or
                                        self.remote_ptree_type.yfilter != YFilter.not_set or
                                        self.remote_tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_available.get_name_leafdata())
                                    if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                    if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_flags.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                    if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                    if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                    if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_available.get_name_leafdata())
                                    if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                    if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                    if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                    if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-available"):
                                        self.local_available = value
                                        self.local_available.value_namespace = name_space
                                        self.local_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-extended-tunnel-id"):
                                        self.local_extended_tunnel_id = value
                                        self.local_extended_tunnel_id.value_namespace = name_space
                                        self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-flags"):
                                        self.local_flags = value
                                        self.local_flags.value_namespace = name_space
                                        self.local_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-p2mp-id"):
                                        self.local_p2mp_id = value
                                        self.local_p2mp_id.value_namespace = name_space
                                        self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ptree-type"):
                                        self.local_ptree_type = value
                                        self.local_ptree_type.value_namespace = name_space
                                        self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-tunnel-id"):
                                        self.local_tunnel_id = value
                                        self.local_tunnel_id.value_namespace = name_space
                                        self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-available"):
                                        self.remote_available = value
                                        self.remote_available.value_namespace = name_space
                                        self.remote_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-extended-tunnel-id"):
                                        self.remote_extended_tunnel_id = value
                                        self.remote_extended_tunnel_id.value_namespace = name_space
                                        self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-flags"):
                                        self.remote_flags = value
                                        self.remote_flags.value_namespace = name_space
                                        self.remote_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-p2mp-id"):
                                        self.remote_p2mp_id = value
                                        self.remote_p2mp_id.value_namespace = name_space
                                        self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ptree-type"):
                                        self.remote_ptree_type = value
                                        self.remote_ptree_type.value_namespace = name_space
                                        self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-tunnel-id"):
                                        self.remote_tunnel_id = value
                                        self.remote_tunnel_id.value_namespace = name_space
                                        self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ad_method.is_set or
                                    self.ad_remote_down.is_set or
                                    self.admited_bw.is_set or
                                    self.auto_discovery.is_set or
                                    self.backup_active.is_set or
                                    self.backup_force_active.is_set or
                                    self.backup_pw.is_set or
                                    self.bitrate_mismatched.is_set or
                                    self.bridge_pw_type_mismatch.is_set or
                                    self.cas_mismatched.is_set or
                                    self.diff_ts_mismatched.is_set or
                                    self.disable_delay.is_set or
                                    self.disable_never.is_set or
                                    self.evpn_src_acid.is_set or
                                    self.fe_ctype.is_set or
                                    self.forward_class.is_set or
                                    self.freq_mismatched.is_set or
                                    self.illegal_control_word.is_set or
                                    self.imposed_vlan_id.is_set or
                                    self.interworking.is_set or
                                    self.ipv6_local_source_address.is_set or
                                    self.is_evpnvpws_type.is_set or
                                    self.is_flow_label_static.is_set or
                                    self.is_multi_segment_pseudowire.is_set or
                                    self.is_partially_programmed.is_set or
                                    self.is_pwr_type.is_set or
                                    self.is_vfi.is_set or
                                    self.last_time_status_changed.is_set or
                                    self.last_time_status_down.is_set or
                                    self.ldp_label_advertise_failed.is_set or
                                    self.load_balance.is_set or
                                    self.local_control_word.is_set or
                                    self.local_label_failed.is_set or
                                    self.local_pseudo_wire_type.is_set or
                                    self.local_source_address.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.not_supported_qinq.is_set or
                                    self.num_ma_cwithdraw_msg_received.is_set or
                                    self.number_ma_cwithdraw_message_sent.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.payload_bytes_mismatched.is_set or
                                    self.payload_type_mismatched.is_set or
                                    self.preferred_path_disable_fallback.is_set or
                                    self.primary_peer_id.is_set or
                                    self.primary_pseudo_wire_id.is_set or
                                    self.primary_pw.is_set or
                                    self.protocol.is_set or
                                    self.pseudo_wire_id.is_set or
                                    self.pseudo_wire_state.is_set or
                                    self.pseudo_wire_type_mismatched.is_set or
                                    self.pw_class_name.is_set or
                                    self.pw_flow_label_code17_disabled.is_set or
                                    self.pw_flow_label_type.is_set or
                                    self.pw_flow_label_type_cfg.is_set or
                                    self.pw_redundancy_initial_delay.is_set or
                                    self.pw_redundancy_one_way.is_set or
                                    self.pw_status_use.is_set or
                                    self.pwlsd_rewrite_failed.is_set or
                                    self.remote_control_word.is_set or
                                    self.remote_label_failed.is_set or
                                    self.remote_pseudo_wire_type.is_set or
                                    self.required_bw.is_set or
                                    self.resync_enabled.is_set or
                                    self.resync_threshold.is_set or
                                    self.rtp_mismatched.is_set or
                                    self.sequencing_type.is_set or
                                    self.shutdown.is_set or
                                    self.sig_pkts_mismatched.is_set or
                                    self.ssrc_mismatched.is_set or
                                    self.state.is_set or
                                    self.table_policy_name.is_set or
                                    self.tag_rewrite.is_set or
                                    self.time_created.is_set or
                                    self.time_elapsed_creation.is_set or
                                    self.time_elapsed_status_changed.is_set or
                                    self.time_elapsed_status_down.is_set or
                                    self.transport_lsp_down.is_set or
                                    self.xconnect_id.is_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                    (self.local_interface is not None and self.local_interface.has_data()) or
                                    (self.local_signalling is not None and self.local_signalling.has_data()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                    (self.peer_id is not None and self.peer_id.has_data()) or
                                    (self.preferred_path is not None and self.preferred_path.has_data()) or
                                    (self.remote_interface is not None and self.remote_interface.has_data()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_remote_down.yfilter != YFilter.not_set or
                                    self.admited_bw.yfilter != YFilter.not_set or
                                    self.auto_discovery.yfilter != YFilter.not_set or
                                    self.backup_active.yfilter != YFilter.not_set or
                                    self.backup_force_active.yfilter != YFilter.not_set or
                                    self.backup_pw.yfilter != YFilter.not_set or
                                    self.bitrate_mismatched.yfilter != YFilter.not_set or
                                    self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                    self.cas_mismatched.yfilter != YFilter.not_set or
                                    self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                    self.disable_delay.yfilter != YFilter.not_set or
                                    self.disable_never.yfilter != YFilter.not_set or
                                    self.evpn_src_acid.yfilter != YFilter.not_set or
                                    self.fe_ctype.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.freq_mismatched.yfilter != YFilter.not_set or
                                    self.illegal_control_word.yfilter != YFilter.not_set or
                                    self.imposed_vlan_id.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                    self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                    self.is_flow_label_static.yfilter != YFilter.not_set or
                                    self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                    self.is_partially_programmed.yfilter != YFilter.not_set or
                                    self.is_pwr_type.yfilter != YFilter.not_set or
                                    self.is_vfi.yfilter != YFilter.not_set or
                                    self.last_time_status_changed.yfilter != YFilter.not_set or
                                    self.last_time_status_down.yfilter != YFilter.not_set or
                                    self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                    self.load_balance.yfilter != YFilter.not_set or
                                    self.local_control_word.yfilter != YFilter.not_set or
                                    self.local_label_failed.yfilter != YFilter.not_set or
                                    self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.local_source_address.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.not_supported_qinq.yfilter != YFilter.not_set or
                                    self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                    self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                    self.payload_type_mismatched.yfilter != YFilter.not_set or
                                    self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                    self.primary_peer_id.yfilter != YFilter.not_set or
                                    self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.primary_pw.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.pseudo_wire_state.yfilter != YFilter.not_set or
                                    self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                    self.pw_class_name.yfilter != YFilter.not_set or
                                    self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                    self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                    self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                    self.pw_status_use.yfilter != YFilter.not_set or
                                    self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.remote_control_word.yfilter != YFilter.not_set or
                                    self.remote_label_failed.yfilter != YFilter.not_set or
                                    self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.required_bw.yfilter != YFilter.not_set or
                                    self.resync_enabled.yfilter != YFilter.not_set or
                                    self.resync_threshold.yfilter != YFilter.not_set or
                                    self.rtp_mismatched.yfilter != YFilter.not_set or
                                    self.sequencing_type.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                    self.ssrc_mismatched.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.table_policy_name.yfilter != YFilter.not_set or
                                    self.tag_rewrite.yfilter != YFilter.not_set or
                                    self.time_created.yfilter != YFilter.not_set or
                                    self.time_elapsed_creation.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                    self.transport_lsp_down.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                    (self.local_interface is not None and self.local_interface.has_operation()) or
                                    (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                    (self.peer_id is not None and self.peer_id.has_operation()) or
                                    (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                    (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pseudo-wire" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_active.get_name_leafdata())
                                if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_never.get_name_leafdata())
                                if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance.get_name_leafdata())
                                if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())
                                if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.required_bw.get_name_leafdata())
                                if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_created.get_name_leafdata())
                                if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "encapsulation-info"):
                                    if (self.encapsulation_info is None):
                                        self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    return self.encapsulation_info

                                if (child_yang_name == "local-interface"):
                                    if (self.local_interface is None):
                                        self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                    return self.local_interface

                                if (child_yang_name == "local-signalling"):
                                    if (self.local_signalling is None):
                                        self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                    return self.local_signalling

                                if (child_yang_name == "p2mp-pw"):
                                    if (self.p2mp_pw is None):
                                        self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    return self.p2mp_pw

                                if (child_yang_name == "peer-id"):
                                    if (self.peer_id is None):
                                        self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                    return self.peer_id

                                if (child_yang_name == "preferred-path"):
                                    if (self.preferred_path is None):
                                        self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                    return self.preferred_path

                                if (child_yang_name == "remote-interface"):
                                    if (self.remote_interface is None):
                                        self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                    return self.remote_interface

                                if (child_yang_name == "remote-signalling"):
                                    if (self.remote_signalling is None):
                                        self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                    return self.remote_signalling

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-remote-down"):
                                    self.ad_remote_down = value
                                    self.ad_remote_down.value_namespace = name_space
                                    self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "admited-bw"):
                                    self.admited_bw = value
                                    self.admited_bw.value_namespace = name_space
                                    self.admited_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "auto-discovery"):
                                    self.auto_discovery = value
                                    self.auto_discovery.value_namespace = name_space
                                    self.auto_discovery.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-active"):
                                    self.backup_active = value
                                    self.backup_active.value_namespace = name_space
                                    self.backup_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-force-active"):
                                    self.backup_force_active = value
                                    self.backup_force_active.value_namespace = name_space
                                    self.backup_force_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-pw"):
                                    self.backup_pw = value
                                    self.backup_pw.value_namespace = name_space
                                    self.backup_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "bitrate-mismatched"):
                                    self.bitrate_mismatched = value
                                    self.bitrate_mismatched.value_namespace = name_space
                                    self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-pw-type-mismatch"):
                                    self.bridge_pw_type_mismatch = value
                                    self.bridge_pw_type_mismatch.value_namespace = name_space
                                    self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "cas-mismatched"):
                                    self.cas_mismatched = value
                                    self.cas_mismatched.value_namespace = name_space
                                    self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "diff-ts-mismatched"):
                                    self.diff_ts_mismatched = value
                                    self.diff_ts_mismatched.value_namespace = name_space
                                    self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-delay"):
                                    self.disable_delay = value
                                    self.disable_delay.value_namespace = name_space
                                    self.disable_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-never"):
                                    self.disable_never = value
                                    self.disable_never.value_namespace = name_space
                                    self.disable_never.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-src-acid"):
                                    self.evpn_src_acid = value
                                    self.evpn_src_acid.value_namespace = name_space
                                    self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                if(value_path == "fe-ctype"):
                                    self.fe_ctype = value
                                    self.fe_ctype.value_namespace = name_space
                                    self.fe_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "freq-mismatched"):
                                    self.freq_mismatched = value
                                    self.freq_mismatched.value_namespace = name_space
                                    self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-control-word"):
                                    self.illegal_control_word = value
                                    self.illegal_control_word.value_namespace = name_space
                                    self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "imposed-vlan-id"):
                                    self.imposed_vlan_id = value
                                    self.imposed_vlan_id.value_namespace = name_space
                                    self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-local-source-address"):
                                    self.ipv6_local_source_address = value
                                    self.ipv6_local_source_address.value_namespace = name_space
                                    self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpnvpws-type"):
                                    self.is_evpnvpws_type = value
                                    self.is_evpnvpws_type.value_namespace = name_space
                                    self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-flow-label-static"):
                                    self.is_flow_label_static = value
                                    self.is_flow_label_static.value_namespace = name_space
                                    self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-multi-segment-pseudowire"):
                                    self.is_multi_segment_pseudowire = value
                                    self.is_multi_segment_pseudowire.value_namespace = name_space
                                    self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-partially-programmed"):
                                    self.is_partially_programmed = value
                                    self.is_partially_programmed.value_namespace = name_space
                                    self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pwr-type"):
                                    self.is_pwr_type = value
                                    self.is_pwr_type.value_namespace = name_space
                                    self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vfi"):
                                    self.is_vfi = value
                                    self.is_vfi.value_namespace = name_space
                                    self.is_vfi.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-changed"):
                                    self.last_time_status_changed = value
                                    self.last_time_status_changed.value_namespace = name_space
                                    self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-down"):
                                    self.last_time_status_down = value
                                    self.last_time_status_down.value_namespace = name_space
                                    self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertise-failed"):
                                    self.ldp_label_advertise_failed = value
                                    self.ldp_label_advertise_failed.value_namespace = name_space
                                    self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance"):
                                    self.load_balance = value
                                    self.load_balance.value_namespace = name_space
                                    self.load_balance.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-control-word"):
                                    self.local_control_word = value
                                    self.local_control_word.value_namespace = name_space
                                    self.local_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label-failed"):
                                    self.local_label_failed = value
                                    self.local_label_failed.value_namespace = name_space
                                    self.local_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-pseudo-wire-type"):
                                    self.local_pseudo_wire_type = value
                                    self.local_pseudo_wire_type.value_namespace = name_space
                                    self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-source-address"):
                                    self.local_source_address = value
                                    self.local_source_address.value_namespace = name_space
                                    self.local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-supported-qinq"):
                                    self.not_supported_qinq = value
                                    self.not_supported_qinq.value_namespace = name_space
                                    self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                if(value_path == "num-ma-cwithdraw-msg-received"):
                                    self.num_ma_cwithdraw_msg_received = value
                                    self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                    self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-ma-cwithdraw-message-sent"):
                                    self.number_ma_cwithdraw_message_sent = value
                                    self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                    self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes-mismatched"):
                                    self.payload_bytes_mismatched = value
                                    self.payload_bytes_mismatched.value_namespace = name_space
                                    self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-type-mismatched"):
                                    self.payload_type_mismatched = value
                                    self.payload_type_mismatched.value_namespace = name_space
                                    self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "preferred-path-disable-fallback"):
                                    self.preferred_path_disable_fallback = value
                                    self.preferred_path_disable_fallback.value_namespace = name_space
                                    self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-peer-id"):
                                    self.primary_peer_id = value
                                    self.primary_peer_id.value_namespace = name_space
                                    self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pseudo-wire-id"):
                                    self.primary_pseudo_wire_id = value
                                    self.primary_pseudo_wire_id.value_namespace = name_space
                                    self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pw"):
                                    self.primary_pw = value
                                    self.primary_pw.value_namespace = name_space
                                    self.primary_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id"):
                                    self.pseudo_wire_id = value
                                    self.pseudo_wire_id.value_namespace = name_space
                                    self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-state"):
                                    self.pseudo_wire_state = value
                                    self.pseudo_wire_state.value_namespace = name_space
                                    self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-type-mismatched"):
                                    self.pseudo_wire_type_mismatched = value
                                    self.pseudo_wire_type_mismatched.value_namespace = name_space
                                    self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-class-name"):
                                    self.pw_class_name = value
                                    self.pw_class_name.value_namespace = name_space
                                    self.pw_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-code17-disabled"):
                                    self.pw_flow_label_code17_disabled = value
                                    self.pw_flow_label_code17_disabled.value_namespace = name_space
                                    self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type"):
                                    self.pw_flow_label_type = value
                                    self.pw_flow_label_type.value_namespace = name_space
                                    self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type-cfg"):
                                    self.pw_flow_label_type_cfg = value
                                    self.pw_flow_label_type_cfg.value_namespace = name_space
                                    self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-initial-delay"):
                                    self.pw_redundancy_initial_delay = value
                                    self.pw_redundancy_initial_delay.value_namespace = name_space
                                    self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-one-way"):
                                    self.pw_redundancy_one_way = value
                                    self.pw_redundancy_one_way.value_namespace = name_space
                                    self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-status-use"):
                                    self.pw_status_use = value
                                    self.pw_status_use.value_namespace = name_space
                                    self.pw_status_use.value_namespace_prefix = name_space_prefix
                                if(value_path == "pwlsd-rewrite-failed"):
                                    self.pwlsd_rewrite_failed = value
                                    self.pwlsd_rewrite_failed.value_namespace = name_space
                                    self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-control-word"):
                                    self.remote_control_word = value
                                    self.remote_control_word.value_namespace = name_space
                                    self.remote_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label-failed"):
                                    self.remote_label_failed = value
                                    self.remote_label_failed.value_namespace = name_space
                                    self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-pseudo-wire-type"):
                                    self.remote_pseudo_wire_type = value
                                    self.remote_pseudo_wire_type.value_namespace = name_space
                                    self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "required-bw"):
                                    self.required_bw = value
                                    self.required_bw.value_namespace = name_space
                                    self.required_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-enabled"):
                                    self.resync_enabled = value
                                    self.resync_enabled.value_namespace = name_space
                                    self.resync_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-threshold"):
                                    self.resync_threshold = value
                                    self.resync_threshold.value_namespace = name_space
                                    self.resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "rtp-mismatched"):
                                    self.rtp_mismatched = value
                                    self.rtp_mismatched.value_namespace = name_space
                                    self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequencing-type"):
                                    self.sequencing_type = value
                                    self.sequencing_type.value_namespace = name_space
                                    self.sequencing_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "sig-pkts-mismatched"):
                                    self.sig_pkts_mismatched = value
                                    self.sig_pkts_mismatched.value_namespace = name_space
                                    self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "ssrc-mismatched"):
                                    self.ssrc_mismatched = value
                                    self.ssrc_mismatched.value_namespace = name_space
                                    self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-policy-name"):
                                    self.table_policy_name = value
                                    self.table_policy_name.value_namespace = name_space
                                    self.table_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag-rewrite"):
                                    self.tag_rewrite = value
                                    self.tag_rewrite.value_namespace = name_space
                                    self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-created"):
                                    self.time_created = value
                                    self.time_created.value_namespace = name_space
                                    self.time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-creation"):
                                    self.time_elapsed_creation = value
                                    self.time_elapsed_creation.value_namespace = name_space
                                    self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-changed"):
                                    self.time_elapsed_status_changed = value
                                    self.time_elapsed_status_changed.value_namespace = name_space
                                    self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-down"):
                                    self.time_elapsed_status_down = value
                                    self.time_elapsed_status_down.value_namespace = name_space
                                    self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-lsp-down"):
                                    self.transport_lsp_down = value
                                    self.transport_lsp_down.value_namespace = name_space
                                    self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.segment_type.is_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                                (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.segment_type.yfilter != YFilter.not_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                                (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "segment2" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "attachment-circuit"):
                                if (self.attachment_circuit is None):
                                    self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                                    self.attachment_circuit.parent = self
                                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                return self.attachment_circuit

                            if (child_yang_name == "pseudo-wire"):
                                if (self.pseudo_wire is None):
                                    self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire()
                                    self.pseudo_wire.parent = self
                                    self._children_name_map["pseudo_wire"] = "pseudo-wire"
                                return self.pseudo_wire

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "segment-type"):
                                self.segment_type = value
                                self.segment_type.value_namespace = name_space
                                self.segment_type.value_namespace_prefix = name_space_prefix


                    class Ce2Ce(Entity):
                        """
                        CE2CE
                        
                        .. attribute:: ce_added
                        
                        	CE2CE Advertised
                        	**type**\:  bool
                        
                        .. attribute:: local_customer_edge_id
                        
                        	Local CE ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: remote_customer_edge_id
                        
                        	Remote CE ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2Ce, self).__init__()

                            self.yang_name = "ce2ce"
                            self.yang_parent_name = "xconnect"

                            self.ce_added = YLeaf(YType.boolean, "ce-added")

                            self.local_customer_edge_id = YLeaf(YType.uint16, "local-customer-edge-id")

                            self.remote_customer_edge_id = YLeaf(YType.uint16, "remote-customer-edge-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ce_added",
                                            "local_customer_edge_id",
                                            "remote_customer_edge_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2Ce, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2Ce, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ce_added.is_set or
                                self.local_customer_edge_id.is_set or
                                self.remote_customer_edge_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ce_added.yfilter != YFilter.not_set or
                                self.local_customer_edge_id.yfilter != YFilter.not_set or
                                self.remote_customer_edge_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ce2ce" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ce_added.is_set or self.ce_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ce_added.get_name_leafdata())
                            if (self.local_customer_edge_id.is_set or self.local_customer_edge_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_customer_edge_id.get_name_leafdata())
                            if (self.remote_customer_edge_id.is_set or self.remote_customer_edge_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_customer_edge_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ce-added" or name == "local-customer-edge-id" or name == "remote-customer-edge-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ce-added"):
                                self.ce_added = value
                                self.ce_added.value_namespace = name_space
                                self.ce_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-customer-edge-id"):
                                self.local_customer_edge_id = value
                                self.local_customer_edge_id.value_namespace = name_space
                                self.local_customer_edge_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-customer-edge-id"):
                                self.remote_customer_edge_id = value
                                self.remote_customer_edge_id.value_namespace = name_space
                                self.remote_customer_edge_id.value_namespace_prefix = name_space_prefix


                    class BackupSegment(Entity):
                        """
                        Backup Segment
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment, self).__init__()

                            self.yang_name = "backup-segment"
                            self.yang_parent_name = "xconnect"

                            self.segment_type = YLeaf(YType.enumeration, "segment-type")

                            self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            self._children_yang_names.add("attachment-circuit")

                            self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            self._children_yang_names.add("pseudo-wire")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("segment_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment, self).__setattr__(name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "backup-segment"

                                self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                                self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                                self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                                self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                                self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                                self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                                self.msti = YLeaf(YType.str, "msti")

                                self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.node_id = YLeaf(YType.str, "node-id")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                                self._children_yang_names.add("interface")

                                self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._children_yang_names.add("l2vpn-protection")

                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bvi_mac_conflict",
                                                "bvi_no_port_up",
                                                "control_word_mismatched",
                                                "encapsulation_error",
                                                "encapsulation_mismatched",
                                                "evpn_internal_label",
                                                "interface_handle",
                                                "internal_ms_ti",
                                                "interworking",
                                                "is_ac_partially_programmed",
                                                "mac_limit_oper_down",
                                                "ms_ti_mismatch",
                                                "msti",
                                                "msti_mismatch_down",
                                                "mtu_mismatched",
                                                "node_id",
                                                "out_of_memory_state",
                                                "redundancy_group_id",
                                                "redundancy_group_state",
                                                "redundancy_object_id",
                                                "state",
                                                "tdm_media_mismatched",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__setattr__(name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class L2VpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.protected_name = YLeaf(YType.str, "protected-name")

                                    self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                    self.protection_name = YLeaf(YType.str, "protection-name")

                                    self.protection_type = YLeaf(YType.enumeration, "protection-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("active",
                                                    "protected_name",
                                                    "protection_configured",
                                                    "protection_name",
                                                    "protection_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.active.is_set or
                                        self.protected_name.is_set or
                                        self.protection_configured.is_set or
                                        self.protection_name.is_set or
                                        self.protection_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.active.yfilter != YFilter.not_set or
                                        self.protected_name.yfilter != YFilter.not_set or
                                        self.protection_configured.yfilter != YFilter.not_set or
                                        self.protection_name.yfilter != YFilter.not_set or
                                        self.protection_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2vpn-protection" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.active.get_name_leafdata())
                                    if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protected_name.get_name_leafdata())
                                    if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                    if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_name.get_name_leafdata())
                                    if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protection_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "active"):
                                        self.active = value
                                        self.active.value_namespace = name_space
                                        self.active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protected-name"):
                                        self.protected_name = value
                                        self.protected_name.value_namespace = name_space
                                        self.protected_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-configured"):
                                        self.protection_configured = value
                                        self.protection_configured.value_namespace = name_space
                                        self.protection_configured.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-name"):
                                        self.protection_name = value
                                        self.protection_name.value_namespace = name_space
                                        self.protection_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protection-type"):
                                        self.protection_type = value
                                        self.protection_type.value_namespace = name_space
                                        self.protection_type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bvi_mac_conflict.is_set or
                                    self.bvi_no_port_up.is_set or
                                    self.control_word_mismatched.is_set or
                                    self.encapsulation_error.is_set or
                                    self.encapsulation_mismatched.is_set or
                                    self.evpn_internal_label.is_set or
                                    self.interface_handle.is_set or
                                    self.internal_ms_ti.is_set or
                                    self.interworking.is_set or
                                    self.is_ac_partially_programmed.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.ms_ti_mismatch.is_set or
                                    self.msti.is_set or
                                    self.msti_mismatch_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.node_id.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.redundancy_group_id.is_set or
                                    self.redundancy_group_state.is_set or
                                    self.redundancy_object_id.is_set or
                                    self.state.is_set or
                                    self.tdm_media_mismatched.is_set or
                                    self.xconnect_id.is_set or
                                    (self.interface is not None and self.interface.has_data()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                    self.bvi_no_port_up.yfilter != YFilter.not_set or
                                    self.control_word_mismatched.yfilter != YFilter.not_set or
                                    self.encapsulation_error.yfilter != YFilter.not_set or
                                    self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                    self.evpn_internal_label.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.internal_ms_ti.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                    self.msti.yfilter != YFilter.not_set or
                                    self.msti_mismatch_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.redundancy_group_id.yfilter != YFilter.not_set or
                                    self.redundancy_group_state.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.interface is not None and self.interface.has_operation()) or
                                    (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "attachment-circuit" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                                if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                                if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                                if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                                if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                                if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                                if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti.get_name_leafdata())
                                if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "interface"):
                                    if (self.interface is None):
                                        self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                                        self.interface.parent = self
                                        self._children_name_map["interface"] = "interface"
                                    return self.interface

                                if (child_yang_name == "l2vpn-protection"):
                                    if (self.l2vpn_protection is None):
                                        self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                                        self.l2vpn_protection.parent = self
                                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    return self.l2vpn_protection

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bvi-mac-conflict"):
                                    self.bvi_mac_conflict = value
                                    self.bvi_mac_conflict.value_namespace = name_space
                                    self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-no-port-up"):
                                    self.bvi_no_port_up = value
                                    self.bvi_no_port_up.value_namespace = name_space
                                    self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "control-word-mismatched"):
                                    self.control_word_mismatched = value
                                    self.control_word_mismatched.value_namespace = name_space
                                    self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-error"):
                                    self.encapsulation_error = value
                                    self.encapsulation_error.value_namespace = name_space
                                    self.encapsulation_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "encapsulation-mismatched"):
                                    self.encapsulation_mismatched = value
                                    self.encapsulation_mismatched.value_namespace = name_space
                                    self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-internal-label"):
                                    self.evpn_internal_label = value
                                    self.evpn_internal_label.value_namespace = name_space
                                    self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-ms-ti"):
                                    self.internal_ms_ti = value
                                    self.internal_ms_ti.value_namespace = name_space
                                    self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ac-partially-programmed"):
                                    self.is_ac_partially_programmed = value
                                    self.is_ac_partially_programmed.value_namespace = name_space
                                    self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ms-ti-mismatch"):
                                    self.ms_ti_mismatch = value
                                    self.ms_ti_mismatch.value_namespace = name_space
                                    self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti"):
                                    self.msti = value
                                    self.msti.value_namespace = name_space
                                    self.msti.value_namespace_prefix = name_space_prefix
                                if(value_path == "msti-mismatch-down"):
                                    self.msti_mismatch_down = value
                                    self.msti_mismatch_down.value_namespace = name_space
                                    self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-id"):
                                    self.redundancy_group_id = value
                                    self.redundancy_group_id.value_namespace = name_space
                                    self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-group-state"):
                                    self.redundancy_group_state = value
                                    self.redundancy_group_state.value_namespace = name_space
                                    self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "tdm-media-mismatched"):
                                    self.tdm_media_mismatched = value
                                    self.tdm_media_mismatched.value_namespace = name_space
                                    self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class PseudoWire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__init__()

                                self.yang_name = "pseudo-wire"
                                self.yang_parent_name = "backup-segment"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                self.backup_active = YLeaf(YType.boolean, "backup-active")

                                self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                self.disable_never = YLeaf(YType.boolean, "disable-never")

                                self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                self.local_source_address = YLeaf(YType.str, "local-source-address")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                self.required_bw = YLeaf(YType.uint32, "required-bw")

                                self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                self.time_created = YLeaf(YType.str, "time-created")

                                self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                self._children_yang_names.add("encapsulation-info")

                                self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                                self._children_yang_names.add("local-interface")

                                self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                                self._children_yang_names.add("local-signalling")

                                self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._children_yang_names.add("p2mp-pw")

                                self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                                self._children_yang_names.add("peer-id")

                                self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                                self._children_yang_names.add("preferred-path")

                                self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                                self._children_yang_names.add("remote-interface")

                                self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                self._children_yang_names.add("remote-signalling")

                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_remote_down",
                                                "admited_bw",
                                                "auto_discovery",
                                                "backup_active",
                                                "backup_force_active",
                                                "backup_pw",
                                                "bitrate_mismatched",
                                                "bridge_pw_type_mismatch",
                                                "cas_mismatched",
                                                "diff_ts_mismatched",
                                                "disable_delay",
                                                "disable_never",
                                                "evpn_src_acid",
                                                "fe_ctype",
                                                "forward_class",
                                                "freq_mismatched",
                                                "illegal_control_word",
                                                "imposed_vlan_id",
                                                "interworking",
                                                "ipv6_local_source_address",
                                                "is_evpnvpws_type",
                                                "is_flow_label_static",
                                                "is_multi_segment_pseudowire",
                                                "is_partially_programmed",
                                                "is_pwr_type",
                                                "is_vfi",
                                                "last_time_status_changed",
                                                "last_time_status_down",
                                                "ldp_label_advertise_failed",
                                                "load_balance",
                                                "local_control_word",
                                                "local_label_failed",
                                                "local_pseudo_wire_type",
                                                "local_source_address",
                                                "mac_limit_oper_down",
                                                "mtu_mismatched",
                                                "not_supported_qinq",
                                                "num_ma_cwithdraw_msg_received",
                                                "number_ma_cwithdraw_message_sent",
                                                "out_of_memory_state",
                                                "payload_bytes_mismatched",
                                                "payload_type_mismatched",
                                                "preferred_path_disable_fallback",
                                                "primary_peer_id",
                                                "primary_pseudo_wire_id",
                                                "primary_pw",
                                                "protocol",
                                                "pseudo_wire_id",
                                                "pseudo_wire_state",
                                                "pseudo_wire_type_mismatched",
                                                "pw_class_name",
                                                "pw_flow_label_code17_disabled",
                                                "pw_flow_label_type",
                                                "pw_flow_label_type_cfg",
                                                "pw_redundancy_initial_delay",
                                                "pw_redundancy_one_way",
                                                "pw_status_use",
                                                "pwlsd_rewrite_failed",
                                                "remote_control_word",
                                                "remote_label_failed",
                                                "remote_pseudo_wire_type",
                                                "required_bw",
                                                "resync_enabled",
                                                "resync_threshold",
                                                "rtp_mismatched",
                                                "sequencing_type",
                                                "shutdown",
                                                "sig_pkts_mismatched",
                                                "ssrc_mismatched",
                                                "state",
                                                "table_policy_name",
                                                "tag_rewrite",
                                                "time_created",
                                                "time_elapsed_creation",
                                                "time_elapsed_status_changed",
                                                "time_elapsed_status_down",
                                                "transport_lsp_down",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__setattr__(name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                    self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                    self.type = YLeaf(YType.enumeration, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "ipv4_peer_id",
                                                    "ipv6_peer_id",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.ipv4_peer_id.is_set or
                                        self.ipv6_peer_id.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.ipv4_peer_id.yfilter != YFilter.not_set or
                                        self.ipv6_peer_id.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "peer-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                    if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-peer-id"):
                                        self.ipv4_peer_id = value
                                        self.ipv4_peer_id.value_namespace = name_space
                                        self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-peer-id"):
                                        self.ipv6_peer_id = value
                                        self.ipv6_peer_id.value_namespace = name_space
                                        self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                    self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._children_yang_names.add("l2tpv3")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                        self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                        self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                        self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                        self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                        self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                        self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                        self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                        self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                        self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                        self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                        self.local_veid = YLeaf(YType.uint32, "local-veid")

                                        self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                        self.rem_saii = YLeaf(YType.str, "rem-saii")

                                        self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                        self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                        self.rem_taii = YLeaf(YType.str, "rem-taii")

                                        self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                        self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                        self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                        self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                        self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                        self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                        self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                        self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                        self.saii = YLeaf(YType.str, "saii")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.taii = YLeaf(YType.str, "taii")

                                        self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                        self._children_yang_names.add("local-agi")

                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._children_yang_names.add("multi-segment-pseudowire-stats")

                                        self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                        self._children_yang_names.add("remote-agi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_pseudowire_headend",
                                                        "is_sai_itype2",
                                                        "is_tai_itype2",
                                                        "ldp_label_advertisment_failed",
                                                        "local_c_ctype",
                                                        "local_ceid",
                                                        "local_cv_type",
                                                        "local_group_id",
                                                        "local_label",
                                                        "local_ldp_id",
                                                        "local_saii_gbl_id",
                                                        "local_saiiac_id",
                                                        "local_taii_gbl_id",
                                                        "local_taiiac_id",
                                                        "local_veid",
                                                        "lsd_rewrite_failed",
                                                        "rem_saii",
                                                        "rem_saii_gbl_id",
                                                        "rem_saiiac_id",
                                                        "rem_taii",
                                                        "rem_taii_gbl_id",
                                                        "rem_taiiac_id",
                                                        "remote_c_ctype",
                                                        "remote_ceid",
                                                        "remote_cv_type",
                                                        "remote_group_id",
                                                        "remote_label",
                                                        "remote_ldp_id",
                                                        "remote_source_address",
                                                        "remote_veid",
                                                        "saii",
                                                        "source_address",
                                                        "taii") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"

                                            self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                            self.received_packets = YLeaf(YType.uint64, "received-packets")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("received_bytes",
                                                            "received_packets") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.received_bytes.is_set or
                                                self.received_packets.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.received_bytes.yfilter != YFilter.not_set or
                                                self.received_packets.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                            if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_packets.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "received-bytes" or name == "received-packets"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "received-bytes"):
                                                self.received_bytes = value
                                                self.received_bytes.value_namespace = name_space
                                                self.received_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "received-packets"):
                                                self.received_packets = value
                                                self.received_packets.value_namespace = name_space
                                                self.received_packets.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_pseudowire_headend.is_set or
                                            self.is_sai_itype2.is_set or
                                            self.is_tai_itype2.is_set or
                                            self.ldp_label_advertisment_failed.is_set or
                                            self.local_c_ctype.is_set or
                                            self.local_ceid.is_set or
                                            self.local_cv_type.is_set or
                                            self.local_group_id.is_set or
                                            self.local_label.is_set or
                                            self.local_ldp_id.is_set or
                                            self.local_saii_gbl_id.is_set or
                                            self.local_saiiac_id.is_set or
                                            self.local_taii_gbl_id.is_set or
                                            self.local_taiiac_id.is_set or
                                            self.local_veid.is_set or
                                            self.lsd_rewrite_failed.is_set or
                                            self.rem_saii.is_set or
                                            self.rem_saii_gbl_id.is_set or
                                            self.rem_saiiac_id.is_set or
                                            self.rem_taii.is_set or
                                            self.rem_taii_gbl_id.is_set or
                                            self.rem_taiiac_id.is_set or
                                            self.remote_c_ctype.is_set or
                                            self.remote_ceid.is_set or
                                            self.remote_cv_type.is_set or
                                            self.remote_group_id.is_set or
                                            self.remote_label.is_set or
                                            self.remote_ldp_id.is_set or
                                            self.remote_source_address.is_set or
                                            self.remote_veid.is_set or
                                            self.saii.is_set or
                                            self.source_address.is_set or
                                            self.taii.is_set or
                                            (self.local_agi is not None and self.local_agi.has_data()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                            (self.remote_agi is not None and self.remote_agi.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                            self.is_sai_itype2.yfilter != YFilter.not_set or
                                            self.is_tai_itype2.yfilter != YFilter.not_set or
                                            self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                            self.local_c_ctype.yfilter != YFilter.not_set or
                                            self.local_ceid.yfilter != YFilter.not_set or
                                            self.local_cv_type.yfilter != YFilter.not_set or
                                            self.local_group_id.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_ldp_id.yfilter != YFilter.not_set or
                                            self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_saiiac_id.yfilter != YFilter.not_set or
                                            self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_taiiac_id.yfilter != YFilter.not_set or
                                            self.local_veid.yfilter != YFilter.not_set or
                                            self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.rem_saii.yfilter != YFilter.not_set or
                                            self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_saiiac_id.yfilter != YFilter.not_set or
                                            self.rem_taii.yfilter != YFilter.not_set or
                                            self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_taiiac_id.yfilter != YFilter.not_set or
                                            self.remote_c_ctype.yfilter != YFilter.not_set or
                                            self.remote_ceid.yfilter != YFilter.not_set or
                                            self.remote_cv_type.yfilter != YFilter.not_set or
                                            self.remote_group_id.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_ldp_id.yfilter != YFilter.not_set or
                                            self.remote_source_address.yfilter != YFilter.not_set or
                                            self.remote_veid.yfilter != YFilter.not_set or
                                            self.saii.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.taii.yfilter != YFilter.not_set or
                                            (self.local_agi is not None and self.local_agi.has_operation()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                            (self.remote_agi is not None and self.remote_agi.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                        if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                        if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                        if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                        if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                        if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                        if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                        if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                        if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                        if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                        if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                        if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                        if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_veid.get_name_leafdata())
                                        if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                        if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                        if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                        if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                        if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                        if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                        if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                        if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                        if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                        if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                        if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                        if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                        if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                        if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saii.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.taii.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local-agi"):
                                            if (self.local_agi is None):
                                                self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                            return self.local_agi

                                        if (child_yang_name == "multi-segment-pseudowire-stats"):
                                            if (self.multi_segment_pseudowire_stats is None):
                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            return self.multi_segment_pseudowire_stats

                                        if (child_yang_name == "remote-agi"):
                                            if (self.remote_agi is None):
                                                self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                            return self.remote_agi

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-pseudowire-headend"):
                                            self.is_pseudowire_headend = value
                                            self.is_pseudowire_headend.value_namespace = name_space
                                            self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-sai-itype2"):
                                            self.is_sai_itype2 = value
                                            self.is_sai_itype2.value_namespace = name_space
                                            self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-tai-itype2"):
                                            self.is_tai_itype2 = value
                                            self.is_tai_itype2.value_namespace = name_space
                                            self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertisment-failed"):
                                            self.ldp_label_advertisment_failed = value
                                            self.ldp_label_advertisment_failed.value_namespace = name_space
                                            self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-c-ctype"):
                                            self.local_c_ctype = value
                                            self.local_c_ctype.value_namespace = name_space
                                            self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ceid"):
                                            self.local_ceid = value
                                            self.local_ceid.value_namespace = name_space
                                            self.local_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cv-type"):
                                            self.local_cv_type = value
                                            self.local_cv_type.value_namespace = name_space
                                            self.local_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-group-id"):
                                            self.local_group_id = value
                                            self.local_group_id.value_namespace = name_space
                                            self.local_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ldp-id"):
                                            self.local_ldp_id = value
                                            self.local_ldp_id.value_namespace = name_space
                                            self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saii-gbl-id"):
                                            self.local_saii_gbl_id = value
                                            self.local_saii_gbl_id.value_namespace = name_space
                                            self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saiiac-id"):
                                            self.local_saiiac_id = value
                                            self.local_saiiac_id.value_namespace = name_space
                                            self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taii-gbl-id"):
                                            self.local_taii_gbl_id = value
                                            self.local_taii_gbl_id.value_namespace = name_space
                                            self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taiiac-id"):
                                            self.local_taiiac_id = value
                                            self.local_taiiac_id.value_namespace = name_space
                                            self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-veid"):
                                            self.local_veid = value
                                            self.local_veid.value_namespace = name_space
                                            self.local_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsd-rewrite-failed"):
                                            self.lsd_rewrite_failed = value
                                            self.lsd_rewrite_failed.value_namespace = name_space
                                            self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii"):
                                            self.rem_saii = value
                                            self.rem_saii.value_namespace = name_space
                                            self.rem_saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii-gbl-id"):
                                            self.rem_saii_gbl_id = value
                                            self.rem_saii_gbl_id.value_namespace = name_space
                                            self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saiiac-id"):
                                            self.rem_saiiac_id = value
                                            self.rem_saiiac_id.value_namespace = name_space
                                            self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii"):
                                            self.rem_taii = value
                                            self.rem_taii.value_namespace = name_space
                                            self.rem_taii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii-gbl-id"):
                                            self.rem_taii_gbl_id = value
                                            self.rem_taii_gbl_id.value_namespace = name_space
                                            self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taiiac-id"):
                                            self.rem_taiiac_id = value
                                            self.rem_taiiac_id.value_namespace = name_space
                                            self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-c-ctype"):
                                            self.remote_c_ctype = value
                                            self.remote_c_ctype.value_namespace = name_space
                                            self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ceid"):
                                            self.remote_ceid = value
                                            self.remote_ceid.value_namespace = name_space
                                            self.remote_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cv-type"):
                                            self.remote_cv_type = value
                                            self.remote_cv_type.value_namespace = name_space
                                            self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-group-id"):
                                            self.remote_group_id = value
                                            self.remote_group_id.value_namespace = name_space
                                            self.remote_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ldp-id"):
                                            self.remote_ldp_id = value
                                            self.remote_ldp_id.value_namespace = name_space
                                            self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-source-address"):
                                            self.remote_source_address = value
                                            self.remote_source_address.value_namespace = name_space
                                            self.remote_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-veid"):
                                            self.remote_veid = value
                                            self.remote_veid.value_namespace = name_space
                                            self.remote_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saii"):
                                            self.saii = value
                                            self.saii.value_namespace = name_space
                                            self.saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "taii"):
                                            self.taii = value
                                            self.taii.value_namespace = name_space
                                            self.taii.value_namespace_prefix = name_space_prefix


                                class L2Tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                        self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                        self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                        self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                        self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                        self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                        self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                        self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                        self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                        self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                        self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                        self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                        self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                        self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                        self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                        self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                        self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                        self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                        self.tos = YLeaf(YType.uint8, "tos")

                                        self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dont_fragment_bit",
                                                        "ipv4_source_address",
                                                        "ipv6_source_address",
                                                        "l2tp_class_name",
                                                        "local_cookie_high_value",
                                                        "local_cookie_low_value",
                                                        "local_cookie_size",
                                                        "local_secondary_cookie_high_value",
                                                        "local_secondary_cookie_low_value",
                                                        "local_secondary_cookie_size",
                                                        "local_session_id",
                                                        "path_mtu_enabled",
                                                        "path_mtu_max_value",
                                                        "remote_circuit_status_up",
                                                        "remote_cookie_high_value",
                                                        "remote_cookie_low_value",
                                                        "remote_cookie_size",
                                                        "remote_session_id",
                                                        "tos",
                                                        "tos_mode",
                                                        "ttl",
                                                        "tunnel_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dont_fragment_bit.is_set or
                                            self.ipv4_source_address.is_set or
                                            self.ipv6_source_address.is_set or
                                            self.l2tp_class_name.is_set or
                                            self.local_cookie_high_value.is_set or
                                            self.local_cookie_low_value.is_set or
                                            self.local_cookie_size.is_set or
                                            self.local_secondary_cookie_high_value.is_set or
                                            self.local_secondary_cookie_low_value.is_set or
                                            self.local_secondary_cookie_size.is_set or
                                            self.local_session_id.is_set or
                                            self.path_mtu_enabled.is_set or
                                            self.path_mtu_max_value.is_set or
                                            self.remote_circuit_status_up.is_set or
                                            self.remote_cookie_high_value.is_set or
                                            self.remote_cookie_low_value.is_set or
                                            self.remote_cookie_size.is_set or
                                            self.remote_session_id.is_set or
                                            self.tos.is_set or
                                            self.tos_mode.is_set or
                                            self.ttl.is_set or
                                            self.tunnel_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dont_fragment_bit.yfilter != YFilter.not_set or
                                            self.ipv4_source_address.yfilter != YFilter.not_set or
                                            self.ipv6_source_address.yfilter != YFilter.not_set or
                                            self.l2tp_class_name.yfilter != YFilter.not_set or
                                            self.local_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_cookie_size.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                            self.local_session_id.yfilter != YFilter.not_set or
                                            self.path_mtu_enabled.yfilter != YFilter.not_set or
                                            self.path_mtu_max_value.yfilter != YFilter.not_set or
                                            self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                            self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_size.yfilter != YFilter.not_set or
                                            self.remote_session_id.yfilter != YFilter.not_set or
                                            self.tos.yfilter != YFilter.not_set or
                                            self.tos_mode.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.tunnel_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv3" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                        if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                        if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                        if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                        if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                        if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                        if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                        if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                        if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                        if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                        if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                        if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                        if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                        if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                        if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                        if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                        if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos.get_name_leafdata())
                                        if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dont-fragment-bit"):
                                            self.dont_fragment_bit = value
                                            self.dont_fragment_bit.value_namespace = name_space
                                            self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-source-address"):
                                            self.ipv4_source_address = value
                                            self.ipv4_source_address.value_namespace = name_space
                                            self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-source-address"):
                                            self.ipv6_source_address = value
                                            self.ipv6_source_address.value_namespace = name_space
                                            self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l2tp-class-name"):
                                            self.l2tp_class_name = value
                                            self.l2tp_class_name.value_namespace = name_space
                                            self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-high-value"):
                                            self.local_cookie_high_value = value
                                            self.local_cookie_high_value.value_namespace = name_space
                                            self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-low-value"):
                                            self.local_cookie_low_value = value
                                            self.local_cookie_low_value.value_namespace = name_space
                                            self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-size"):
                                            self.local_cookie_size = value
                                            self.local_cookie_size.value_namespace = name_space
                                            self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-high-value"):
                                            self.local_secondary_cookie_high_value = value
                                            self.local_secondary_cookie_high_value.value_namespace = name_space
                                            self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-low-value"):
                                            self.local_secondary_cookie_low_value = value
                                            self.local_secondary_cookie_low_value.value_namespace = name_space
                                            self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-size"):
                                            self.local_secondary_cookie_size = value
                                            self.local_secondary_cookie_size.value_namespace = name_space
                                            self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-session-id"):
                                            self.local_session_id = value
                                            self.local_session_id.value_namespace = name_space
                                            self.local_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-enabled"):
                                            self.path_mtu_enabled = value
                                            self.path_mtu_enabled.value_namespace = name_space
                                            self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-max-value"):
                                            self.path_mtu_max_value = value
                                            self.path_mtu_max_value.value_namespace = name_space
                                            self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-circuit-status-up"):
                                            self.remote_circuit_status_up = value
                                            self.remote_circuit_status_up.value_namespace = name_space
                                            self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-high-value"):
                                            self.remote_cookie_high_value = value
                                            self.remote_cookie_high_value.value_namespace = name_space
                                            self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-low-value"):
                                            self.remote_cookie_low_value = value
                                            self.remote_cookie_low_value.value_namespace = name_space
                                            self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-size"):
                                            self.remote_cookie_size = value
                                            self.remote_cookie_size.value_namespace = name_space
                                            self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-session-id"):
                                            self.remote_session_id = value
                                            self.remote_session_id.value_namespace = name_space
                                            self.remote_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos"):
                                            self.tos = value
                                            self.tos.value_namespace = name_space
                                            self.tos.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-mode"):
                                            self.tos_mode = value
                                            self.tos_mode.value_namespace = name_space
                                            self.tos_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tunnel-state"):
                                            self.tunnel_state = value
                                            self.tunnel_state.value_namespace = name_space
                                            self.tunnel_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.encapsulation.is_set or
                                        (self.atom is not None and self.atom.has_data()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "encapsulation-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    if (child_yang_name == "l2tpv3"):
                                        if (self.l2tpv3 is None):
                                            self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                        return self.l2tpv3

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation"):
                                        self.encapsulation = value
                                        self.encapsulation.value_namespace = name_space
                                        self.encapsulation.value_namespace_prefix = name_space_prefix


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                    self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                    self.option = YLeaf(YType.enumeration, "option")

                                    self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                    self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ip_tunnel_interface_number",
                                                    "next_hop_ip",
                                                    "option",
                                                    "te_tunnel_interface_number",
                                                    "tp_tunnel_interface_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ip_tunnel_interface_number.is_set or
                                        self.next_hop_ip.is_set or
                                        self.option.is_set or
                                        self.te_tunnel_interface_number.is_set or
                                        self.tp_tunnel_interface_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set or
                                        self.option.yfilter != YFilter.not_set or
                                        self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "preferred-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                    if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.option.get_name_leafdata())
                                    if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                    if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ip-tunnel-interface-number"):
                                        self.ip_tunnel_interface_number = value
                                        self.ip_tunnel_interface_number.value_namespace = name_space
                                        self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                    if(value_path == "option"):
                                        self.option = value
                                        self.option.value_namespace = name_space
                                        self.option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-tunnel-interface-number"):
                                        self.te_tunnel_interface_number = value
                                        self.te_tunnel_interface_number.value_namespace = name_space
                                        self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tp-tunnel-interface-number"):
                                        self.tp_tunnel_interface_number = value
                                        self.tp_tunnel_interface_number.value_namespace = name_space
                                        self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class P2MpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudo-wire"

                                    self.local_available = YLeaf(YType.boolean, "local-available")

                                    self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                    self.local_flags = YLeaf(YType.uint8, "local-flags")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                    self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                    self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                    self.remote_available = YLeaf(YType.boolean, "remote-available")

                                    self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                    self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                    self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                    self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_available",
                                                    "local_extended_tunnel_id",
                                                    "local_flags",
                                                    "local_label",
                                                    "local_p2mp_id",
                                                    "local_ptree_type",
                                                    "local_tunnel_id",
                                                    "remote_available",
                                                    "remote_extended_tunnel_id",
                                                    "remote_flags",
                                                    "remote_label",
                                                    "remote_p2mp_id",
                                                    "remote_ptree_type",
                                                    "remote_tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_available.is_set or
                                        self.local_extended_tunnel_id.is_set or
                                        self.local_flags.is_set or
                                        self.local_label.is_set or
                                        self.local_p2mp_id.is_set or
                                        self.local_ptree_type.is_set or
                                        self.local_tunnel_id.is_set or
                                        self.remote_available.is_set or
                                        self.remote_extended_tunnel_id.is_set or
                                        self.remote_flags.is_set or
                                        self.remote_label.is_set or
                                        self.remote_p2mp_id.is_set or
                                        self.remote_ptree_type.is_set or
                                        self.remote_tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_available.yfilter != YFilter.not_set or
                                        self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.local_flags.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_p2mp_id.yfilter != YFilter.not_set or
                                        self.local_ptree_type.yfilter != YFilter.not_set or
                                        self.local_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_available.yfilter != YFilter.not_set or
                                        self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_flags.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_p2mp_id.yfilter != YFilter.not_set or
                                        self.remote_ptree_type.yfilter != YFilter.not_set or
                                        self.remote_tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_available.get_name_leafdata())
                                    if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                    if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_flags.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                    if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                    if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                    if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_available.get_name_leafdata())
                                    if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                    if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                    if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                    if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-available"):
                                        self.local_available = value
                                        self.local_available.value_namespace = name_space
                                        self.local_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-extended-tunnel-id"):
                                        self.local_extended_tunnel_id = value
                                        self.local_extended_tunnel_id.value_namespace = name_space
                                        self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-flags"):
                                        self.local_flags = value
                                        self.local_flags.value_namespace = name_space
                                        self.local_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-p2mp-id"):
                                        self.local_p2mp_id = value
                                        self.local_p2mp_id.value_namespace = name_space
                                        self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ptree-type"):
                                        self.local_ptree_type = value
                                        self.local_ptree_type.value_namespace = name_space
                                        self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-tunnel-id"):
                                        self.local_tunnel_id = value
                                        self.local_tunnel_id.value_namespace = name_space
                                        self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-available"):
                                        self.remote_available = value
                                        self.remote_available.value_namespace = name_space
                                        self.remote_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-extended-tunnel-id"):
                                        self.remote_extended_tunnel_id = value
                                        self.remote_extended_tunnel_id.value_namespace = name_space
                                        self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-flags"):
                                        self.remote_flags = value
                                        self.remote_flags.value_namespace = name_space
                                        self.remote_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-p2mp-id"):
                                        self.remote_p2mp_id = value
                                        self.remote_p2mp_id.value_namespace = name_space
                                        self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ptree-type"):
                                        self.remote_ptree_type = value
                                        self.remote_ptree_type.value_namespace = name_space
                                        self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-tunnel-id"):
                                        self.remote_tunnel_id = value
                                        self.remote_tunnel_id.value_namespace = name_space
                                        self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ad_method.is_set or
                                    self.ad_remote_down.is_set or
                                    self.admited_bw.is_set or
                                    self.auto_discovery.is_set or
                                    self.backup_active.is_set or
                                    self.backup_force_active.is_set or
                                    self.backup_pw.is_set or
                                    self.bitrate_mismatched.is_set or
                                    self.bridge_pw_type_mismatch.is_set or
                                    self.cas_mismatched.is_set or
                                    self.diff_ts_mismatched.is_set or
                                    self.disable_delay.is_set or
                                    self.disable_never.is_set or
                                    self.evpn_src_acid.is_set or
                                    self.fe_ctype.is_set or
                                    self.forward_class.is_set or
                                    self.freq_mismatched.is_set or
                                    self.illegal_control_word.is_set or
                                    self.imposed_vlan_id.is_set or
                                    self.interworking.is_set or
                                    self.ipv6_local_source_address.is_set or
                                    self.is_evpnvpws_type.is_set or
                                    self.is_flow_label_static.is_set or
                                    self.is_multi_segment_pseudowire.is_set or
                                    self.is_partially_programmed.is_set or
                                    self.is_pwr_type.is_set or
                                    self.is_vfi.is_set or
                                    self.last_time_status_changed.is_set or
                                    self.last_time_status_down.is_set or
                                    self.ldp_label_advertise_failed.is_set or
                                    self.load_balance.is_set or
                                    self.local_control_word.is_set or
                                    self.local_label_failed.is_set or
                                    self.local_pseudo_wire_type.is_set or
                                    self.local_source_address.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.not_supported_qinq.is_set or
                                    self.num_ma_cwithdraw_msg_received.is_set or
                                    self.number_ma_cwithdraw_message_sent.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.payload_bytes_mismatched.is_set or
                                    self.payload_type_mismatched.is_set or
                                    self.preferred_path_disable_fallback.is_set or
                                    self.primary_peer_id.is_set or
                                    self.primary_pseudo_wire_id.is_set or
                                    self.primary_pw.is_set or
                                    self.protocol.is_set or
                                    self.pseudo_wire_id.is_set or
                                    self.pseudo_wire_state.is_set or
                                    self.pseudo_wire_type_mismatched.is_set or
                                    self.pw_class_name.is_set or
                                    self.pw_flow_label_code17_disabled.is_set or
                                    self.pw_flow_label_type.is_set or
                                    self.pw_flow_label_type_cfg.is_set or
                                    self.pw_redundancy_initial_delay.is_set or
                                    self.pw_redundancy_one_way.is_set or
                                    self.pw_status_use.is_set or
                                    self.pwlsd_rewrite_failed.is_set or
                                    self.remote_control_word.is_set or
                                    self.remote_label_failed.is_set or
                                    self.remote_pseudo_wire_type.is_set or
                                    self.required_bw.is_set or
                                    self.resync_enabled.is_set or
                                    self.resync_threshold.is_set or
                                    self.rtp_mismatched.is_set or
                                    self.sequencing_type.is_set or
                                    self.shutdown.is_set or
                                    self.sig_pkts_mismatched.is_set or
                                    self.ssrc_mismatched.is_set or
                                    self.state.is_set or
                                    self.table_policy_name.is_set or
                                    self.tag_rewrite.is_set or
                                    self.time_created.is_set or
                                    self.time_elapsed_creation.is_set or
                                    self.time_elapsed_status_changed.is_set or
                                    self.time_elapsed_status_down.is_set or
                                    self.transport_lsp_down.is_set or
                                    self.xconnect_id.is_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                    (self.local_interface is not None and self.local_interface.has_data()) or
                                    (self.local_signalling is not None and self.local_signalling.has_data()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                    (self.peer_id is not None and self.peer_id.has_data()) or
                                    (self.preferred_path is not None and self.preferred_path.has_data()) or
                                    (self.remote_interface is not None and self.remote_interface.has_data()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_remote_down.yfilter != YFilter.not_set or
                                    self.admited_bw.yfilter != YFilter.not_set or
                                    self.auto_discovery.yfilter != YFilter.not_set or
                                    self.backup_active.yfilter != YFilter.not_set or
                                    self.backup_force_active.yfilter != YFilter.not_set or
                                    self.backup_pw.yfilter != YFilter.not_set or
                                    self.bitrate_mismatched.yfilter != YFilter.not_set or
                                    self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                    self.cas_mismatched.yfilter != YFilter.not_set or
                                    self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                    self.disable_delay.yfilter != YFilter.not_set or
                                    self.disable_never.yfilter != YFilter.not_set or
                                    self.evpn_src_acid.yfilter != YFilter.not_set or
                                    self.fe_ctype.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.freq_mismatched.yfilter != YFilter.not_set or
                                    self.illegal_control_word.yfilter != YFilter.not_set or
                                    self.imposed_vlan_id.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                    self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                    self.is_flow_label_static.yfilter != YFilter.not_set or
                                    self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                    self.is_partially_programmed.yfilter != YFilter.not_set or
                                    self.is_pwr_type.yfilter != YFilter.not_set or
                                    self.is_vfi.yfilter != YFilter.not_set or
                                    self.last_time_status_changed.yfilter != YFilter.not_set or
                                    self.last_time_status_down.yfilter != YFilter.not_set or
                                    self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                    self.load_balance.yfilter != YFilter.not_set or
                                    self.local_control_word.yfilter != YFilter.not_set or
                                    self.local_label_failed.yfilter != YFilter.not_set or
                                    self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.local_source_address.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.not_supported_qinq.yfilter != YFilter.not_set or
                                    self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                    self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                    self.payload_type_mismatched.yfilter != YFilter.not_set or
                                    self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                    self.primary_peer_id.yfilter != YFilter.not_set or
                                    self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.primary_pw.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.pseudo_wire_state.yfilter != YFilter.not_set or
                                    self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                    self.pw_class_name.yfilter != YFilter.not_set or
                                    self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                    self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                    self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                    self.pw_status_use.yfilter != YFilter.not_set or
                                    self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.remote_control_word.yfilter != YFilter.not_set or
                                    self.remote_label_failed.yfilter != YFilter.not_set or
                                    self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.required_bw.yfilter != YFilter.not_set or
                                    self.resync_enabled.yfilter != YFilter.not_set or
                                    self.resync_threshold.yfilter != YFilter.not_set or
                                    self.rtp_mismatched.yfilter != YFilter.not_set or
                                    self.sequencing_type.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                    self.ssrc_mismatched.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.table_policy_name.yfilter != YFilter.not_set or
                                    self.tag_rewrite.yfilter != YFilter.not_set or
                                    self.time_created.yfilter != YFilter.not_set or
                                    self.time_elapsed_creation.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                    self.transport_lsp_down.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                    (self.local_interface is not None and self.local_interface.has_operation()) or
                                    (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                    (self.peer_id is not None and self.peer_id.has_operation()) or
                                    (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                    (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pseudo-wire" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_active.get_name_leafdata())
                                if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_never.get_name_leafdata())
                                if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance.get_name_leafdata())
                                if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())
                                if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.required_bw.get_name_leafdata())
                                if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_created.get_name_leafdata())
                                if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "encapsulation-info"):
                                    if (self.encapsulation_info is None):
                                        self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    return self.encapsulation_info

                                if (child_yang_name == "local-interface"):
                                    if (self.local_interface is None):
                                        self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                    return self.local_interface

                                if (child_yang_name == "local-signalling"):
                                    if (self.local_signalling is None):
                                        self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                    return self.local_signalling

                                if (child_yang_name == "p2mp-pw"):
                                    if (self.p2mp_pw is None):
                                        self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    return self.p2mp_pw

                                if (child_yang_name == "peer-id"):
                                    if (self.peer_id is None):
                                        self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                    return self.peer_id

                                if (child_yang_name == "preferred-path"):
                                    if (self.preferred_path is None):
                                        self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                    return self.preferred_path

                                if (child_yang_name == "remote-interface"):
                                    if (self.remote_interface is None):
                                        self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                    return self.remote_interface

                                if (child_yang_name == "remote-signalling"):
                                    if (self.remote_signalling is None):
                                        self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                    return self.remote_signalling

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-remote-down"):
                                    self.ad_remote_down = value
                                    self.ad_remote_down.value_namespace = name_space
                                    self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "admited-bw"):
                                    self.admited_bw = value
                                    self.admited_bw.value_namespace = name_space
                                    self.admited_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "auto-discovery"):
                                    self.auto_discovery = value
                                    self.auto_discovery.value_namespace = name_space
                                    self.auto_discovery.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-active"):
                                    self.backup_active = value
                                    self.backup_active.value_namespace = name_space
                                    self.backup_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-force-active"):
                                    self.backup_force_active = value
                                    self.backup_force_active.value_namespace = name_space
                                    self.backup_force_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-pw"):
                                    self.backup_pw = value
                                    self.backup_pw.value_namespace = name_space
                                    self.backup_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "bitrate-mismatched"):
                                    self.bitrate_mismatched = value
                                    self.bitrate_mismatched.value_namespace = name_space
                                    self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-pw-type-mismatch"):
                                    self.bridge_pw_type_mismatch = value
                                    self.bridge_pw_type_mismatch.value_namespace = name_space
                                    self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "cas-mismatched"):
                                    self.cas_mismatched = value
                                    self.cas_mismatched.value_namespace = name_space
                                    self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "diff-ts-mismatched"):
                                    self.diff_ts_mismatched = value
                                    self.diff_ts_mismatched.value_namespace = name_space
                                    self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-delay"):
                                    self.disable_delay = value
                                    self.disable_delay.value_namespace = name_space
                                    self.disable_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-never"):
                                    self.disable_never = value
                                    self.disable_never.value_namespace = name_space
                                    self.disable_never.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-src-acid"):
                                    self.evpn_src_acid = value
                                    self.evpn_src_acid.value_namespace = name_space
                                    self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                if(value_path == "fe-ctype"):
                                    self.fe_ctype = value
                                    self.fe_ctype.value_namespace = name_space
                                    self.fe_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "freq-mismatched"):
                                    self.freq_mismatched = value
                                    self.freq_mismatched.value_namespace = name_space
                                    self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-control-word"):
                                    self.illegal_control_word = value
                                    self.illegal_control_word.value_namespace = name_space
                                    self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "imposed-vlan-id"):
                                    self.imposed_vlan_id = value
                                    self.imposed_vlan_id.value_namespace = name_space
                                    self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-local-source-address"):
                                    self.ipv6_local_source_address = value
                                    self.ipv6_local_source_address.value_namespace = name_space
                                    self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpnvpws-type"):
                                    self.is_evpnvpws_type = value
                                    self.is_evpnvpws_type.value_namespace = name_space
                                    self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-flow-label-static"):
                                    self.is_flow_label_static = value
                                    self.is_flow_label_static.value_namespace = name_space
                                    self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-multi-segment-pseudowire"):
                                    self.is_multi_segment_pseudowire = value
                                    self.is_multi_segment_pseudowire.value_namespace = name_space
                                    self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-partially-programmed"):
                                    self.is_partially_programmed = value
                                    self.is_partially_programmed.value_namespace = name_space
                                    self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pwr-type"):
                                    self.is_pwr_type = value
                                    self.is_pwr_type.value_namespace = name_space
                                    self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vfi"):
                                    self.is_vfi = value
                                    self.is_vfi.value_namespace = name_space
                                    self.is_vfi.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-changed"):
                                    self.last_time_status_changed = value
                                    self.last_time_status_changed.value_namespace = name_space
                                    self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-down"):
                                    self.last_time_status_down = value
                                    self.last_time_status_down.value_namespace = name_space
                                    self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertise-failed"):
                                    self.ldp_label_advertise_failed = value
                                    self.ldp_label_advertise_failed.value_namespace = name_space
                                    self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance"):
                                    self.load_balance = value
                                    self.load_balance.value_namespace = name_space
                                    self.load_balance.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-control-word"):
                                    self.local_control_word = value
                                    self.local_control_word.value_namespace = name_space
                                    self.local_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label-failed"):
                                    self.local_label_failed = value
                                    self.local_label_failed.value_namespace = name_space
                                    self.local_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-pseudo-wire-type"):
                                    self.local_pseudo_wire_type = value
                                    self.local_pseudo_wire_type.value_namespace = name_space
                                    self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-source-address"):
                                    self.local_source_address = value
                                    self.local_source_address.value_namespace = name_space
                                    self.local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-supported-qinq"):
                                    self.not_supported_qinq = value
                                    self.not_supported_qinq.value_namespace = name_space
                                    self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                if(value_path == "num-ma-cwithdraw-msg-received"):
                                    self.num_ma_cwithdraw_msg_received = value
                                    self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                    self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-ma-cwithdraw-message-sent"):
                                    self.number_ma_cwithdraw_message_sent = value
                                    self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                    self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes-mismatched"):
                                    self.payload_bytes_mismatched = value
                                    self.payload_bytes_mismatched.value_namespace = name_space
                                    self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-type-mismatched"):
                                    self.payload_type_mismatched = value
                                    self.payload_type_mismatched.value_namespace = name_space
                                    self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "preferred-path-disable-fallback"):
                                    self.preferred_path_disable_fallback = value
                                    self.preferred_path_disable_fallback.value_namespace = name_space
                                    self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-peer-id"):
                                    self.primary_peer_id = value
                                    self.primary_peer_id.value_namespace = name_space
                                    self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pseudo-wire-id"):
                                    self.primary_pseudo_wire_id = value
                                    self.primary_pseudo_wire_id.value_namespace = name_space
                                    self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pw"):
                                    self.primary_pw = value
                                    self.primary_pw.value_namespace = name_space
                                    self.primary_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id"):
                                    self.pseudo_wire_id = value
                                    self.pseudo_wire_id.value_namespace = name_space
                                    self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-state"):
                                    self.pseudo_wire_state = value
                                    self.pseudo_wire_state.value_namespace = name_space
                                    self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-type-mismatched"):
                                    self.pseudo_wire_type_mismatched = value
                                    self.pseudo_wire_type_mismatched.value_namespace = name_space
                                    self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-class-name"):
                                    self.pw_class_name = value
                                    self.pw_class_name.value_namespace = name_space
                                    self.pw_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-code17-disabled"):
                                    self.pw_flow_label_code17_disabled = value
                                    self.pw_flow_label_code17_disabled.value_namespace = name_space
                                    self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type"):
                                    self.pw_flow_label_type = value
                                    self.pw_flow_label_type.value_namespace = name_space
                                    self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type-cfg"):
                                    self.pw_flow_label_type_cfg = value
                                    self.pw_flow_label_type_cfg.value_namespace = name_space
                                    self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-initial-delay"):
                                    self.pw_redundancy_initial_delay = value
                                    self.pw_redundancy_initial_delay.value_namespace = name_space
                                    self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-one-way"):
                                    self.pw_redundancy_one_way = value
                                    self.pw_redundancy_one_way.value_namespace = name_space
                                    self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-status-use"):
                                    self.pw_status_use = value
                                    self.pw_status_use.value_namespace = name_space
                                    self.pw_status_use.value_namespace_prefix = name_space_prefix
                                if(value_path == "pwlsd-rewrite-failed"):
                                    self.pwlsd_rewrite_failed = value
                                    self.pwlsd_rewrite_failed.value_namespace = name_space
                                    self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-control-word"):
                                    self.remote_control_word = value
                                    self.remote_control_word.value_namespace = name_space
                                    self.remote_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label-failed"):
                                    self.remote_label_failed = value
                                    self.remote_label_failed.value_namespace = name_space
                                    self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-pseudo-wire-type"):
                                    self.remote_pseudo_wire_type = value
                                    self.remote_pseudo_wire_type.value_namespace = name_space
                                    self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "required-bw"):
                                    self.required_bw = value
                                    self.required_bw.value_namespace = name_space
                                    self.required_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-enabled"):
                                    self.resync_enabled = value
                                    self.resync_enabled.value_namespace = name_space
                                    self.resync_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-threshold"):
                                    self.resync_threshold = value
                                    self.resync_threshold.value_namespace = name_space
                                    self.resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "rtp-mismatched"):
                                    self.rtp_mismatched = value
                                    self.rtp_mismatched.value_namespace = name_space
                                    self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequencing-type"):
                                    self.sequencing_type = value
                                    self.sequencing_type.value_namespace = name_space
                                    self.sequencing_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "sig-pkts-mismatched"):
                                    self.sig_pkts_mismatched = value
                                    self.sig_pkts_mismatched.value_namespace = name_space
                                    self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "ssrc-mismatched"):
                                    self.ssrc_mismatched = value
                                    self.ssrc_mismatched.value_namespace = name_space
                                    self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-policy-name"):
                                    self.table_policy_name = value
                                    self.table_policy_name.value_namespace = name_space
                                    self.table_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag-rewrite"):
                                    self.tag_rewrite = value
                                    self.tag_rewrite.value_namespace = name_space
                                    self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-created"):
                                    self.time_created = value
                                    self.time_created.value_namespace = name_space
                                    self.time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-creation"):
                                    self.time_elapsed_creation = value
                                    self.time_elapsed_creation.value_namespace = name_space
                                    self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-changed"):
                                    self.time_elapsed_status_changed = value
                                    self.time_elapsed_status_changed.value_namespace = name_space
                                    self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-down"):
                                    self.time_elapsed_status_down = value
                                    self.time_elapsed_status_down.value_namespace = name_space
                                    self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-lsp-down"):
                                    self.transport_lsp_down = value
                                    self.transport_lsp_down.value_namespace = name_space
                                    self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.segment_type.is_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                                (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.segment_type.yfilter != YFilter.not_set or
                                (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                                (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "backup-segment" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "attachment-circuit"):
                                if (self.attachment_circuit is None):
                                    self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                                    self.attachment_circuit.parent = self
                                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                return self.attachment_circuit

                            if (child_yang_name == "pseudo-wire"):
                                if (self.pseudo_wire is None):
                                    self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire()
                                    self.pseudo_wire.parent = self
                                    self._children_name_map["pseudo_wire"] = "pseudo-wire"
                                return self.pseudo_wire

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "segment-type"):
                                self.segment_type = value
                                self.segment_type.value_namespace = name_space
                                self.segment_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.backup_segment:
                            if (c.has_data()):
                                return True
                        return (
                            self.description.is_set or
                            self.diag_mask.is_set or
                            self.group_name.is_set or
                            self.group_name_xr.is_set or
                            self.interworking.is_set or
                            self.is_mp2mp.is_set or
                            self.number_of_backup_p_ws.is_set or
                            self.state.is_set or
                            self.xconnect_name.is_set or
                            self.xconnect_name_xr.is_set or
                            (self.backup is not None and self.backup.has_data()) or
                            (self.ce2ce is not None and self.ce2ce.has_data()) or
                            (self.segment1 is not None and self.segment1.has_data()) or
                            (self.segment2 is not None and self.segment2.has_data()))

                    def has_operation(self):
                        for c in self.backup_segment:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.description.yfilter != YFilter.not_set or
                            self.diag_mask.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.group_name_xr.yfilter != YFilter.not_set or
                            self.interworking.yfilter != YFilter.not_set or
                            self.is_mp2mp.yfilter != YFilter.not_set or
                            self.number_of_backup_p_ws.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.xconnect_name.yfilter != YFilter.not_set or
                            self.xconnect_name_xr.yfilter != YFilter.not_set or
                            (self.backup is not None and self.backup.has_operation()) or
                            (self.ce2ce is not None and self.ce2ce.has_operation()) or
                            (self.segment1 is not None and self.segment1.has_operation()) or
                            (self.segment2 is not None and self.segment2.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "xconnect" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.description.get_name_leafdata())
                        if (self.diag_mask.is_set or self.diag_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.diag_mask.get_name_leafdata())
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interworking.get_name_leafdata())
                        if (self.is_mp2mp.is_set or self.is_mp2mp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mp2mp.get_name_leafdata())
                        if (self.number_of_backup_p_ws.is_set or self.number_of_backup_p_ws.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_backup_p_ws.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.xconnect_name.is_set or self.xconnect_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_name.get_name_leafdata())
                        if (self.xconnect_name_xr.is_set or self.xconnect_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_name_xr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "backup"):
                            if (self.backup is None):
                                self.backup = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup()
                                self.backup.parent = self
                                self._children_name_map["backup"] = "backup"
                            return self.backup

                        if (child_yang_name == "backup-segment"):
                            for c in self.backup_segment:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.backup_segment.append(c)
                            return c

                        if (child_yang_name == "ce2ce"):
                            if (self.ce2ce is None):
                                self.ce2ce = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2Ce()
                                self.ce2ce.parent = self
                                self._children_name_map["ce2ce"] = "ce2ce"
                            return self.ce2ce

                        if (child_yang_name == "segment1"):
                            if (self.segment1 is None):
                                self.segment1 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1()
                                self.segment1.parent = self
                                self._children_name_map["segment1"] = "segment1"
                            return self.segment1

                        if (child_yang_name == "segment2"):
                            if (self.segment2 is None):
                                self.segment2 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2()
                                self.segment2.parent = self
                                self._children_name_map["segment2"] = "segment2"
                            return self.segment2

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "backup" or name == "backup-segment" or name == "ce2ce" or name == "segment1" or name == "segment2" or name == "description" or name == "diag-mask" or name == "group-name" or name == "group-name-xr" or name == "interworking" or name == "is-mp2mp" or name == "number-of-backup-p-ws" or name == "state" or name == "xconnect-name" or name == "xconnect-name-xr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "description"):
                            self.description = value
                            self.description.value_namespace = name_space
                            self.description.value_namespace_prefix = name_space_prefix
                        if(value_path == "diag-mask"):
                            self.diag_mask = value
                            self.diag_mask.value_namespace = name_space
                            self.diag_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name-xr"):
                            self.group_name_xr = value
                            self.group_name_xr.value_namespace = name_space
                            self.group_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "interworking"):
                            self.interworking = value
                            self.interworking.value_namespace = name_space
                            self.interworking.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mp2mp"):
                            self.is_mp2mp = value
                            self.is_mp2mp.value_namespace = name_space
                            self.is_mp2mp.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-backup-p-ws"):
                            self.number_of_backup_p_ws = value
                            self.number_of_backup_p_ws.value_namespace = name_space
                            self.number_of_backup_p_ws.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-name"):
                            self.xconnect_name = value
                            self.xconnect_name.value_namespace = name_space
                            self.xconnect_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-name-xr"):
                            self.xconnect_name_xr = value
                            self.xconnect_name_xr.value_namespace = name_space
                            self.xconnect_name_xr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.xconnect:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.xconnect:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnects" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "xconnect"):
                        for c in self.xconnect:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.Xconnects.Xconnect()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.xconnect.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "xconnect"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class XconnectGroups(Entity):
                """
                XConnect group Table
                
                .. attribute:: xconnect_group
                
                	XConnect group information
                	**type**\: list of    :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectGroups.XconnectGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.XconnectGroups, self).__init__()

                    self.yang_name = "xconnect-groups"
                    self.yang_parent_name = "node"

                    self.xconnect_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.XconnectGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.XconnectGroups, self).__setattr__(name, value)


                class XconnectGroup(Entity):
                    """
                    XConnect group information
                    
                    .. attribute:: group_name  <key>
                    
                    	XConnect Group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: number_xconnects
                    
                    	Number of xconnects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.XconnectGroups.XconnectGroup, self).__init__()

                        self.yang_name = "xconnect-group"
                        self.yang_parent_name = "xconnect-groups"

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                        self.number_xconnects = YLeaf(YType.uint32, "number-xconnects")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_name",
                                        "group_name_xr",
                                        "number_xconnects") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.XconnectGroups.XconnectGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.XconnectGroups.XconnectGroup, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.group_name.is_set or
                            self.group_name_xr.is_set or
                            self.number_xconnects.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.group_name_xr.yfilter != YFilter.not_set or
                            self.number_xconnects.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "xconnect-group" + "[group-name='" + self.group_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                        if (self.number_xconnects.is_set or self.number_xconnects.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_xconnects.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-name" or name == "group-name-xr" or name == "number-xconnects"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name-xr"):
                            self.group_name_xr = value
                            self.group_name_xr.value_namespace = name_space
                            self.group_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-xconnects"):
                            self.number_xconnects = value
                            self.number_xconnects.value_namespace = name_space
                            self.number_xconnects.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.xconnect_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.xconnect_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "xconnect-group"):
                        for c in self.xconnect_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.XconnectGroups.XconnectGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.xconnect_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "xconnect-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class XconnectMp2Mps(Entity):
                """
                XConnect MP2MP Table
                
                .. attribute:: xconnect_mp2mp
                
                	XConnect MP2MP information
                	**type**\: list of    :py:class:`XconnectMp2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps, self).__init__()

                    self.yang_name = "xconnect-mp2mps"
                    self.yang_parent_name = "node"

                    self.xconnect_mp2mp = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps, self).__setattr__(name, value)


                class XconnectMp2Mp(Entity):
                    """
                    XConnect MP2MP information
                    
                    .. attribute:: discovery
                    
                    	l2vpn xc auto discovery info
                    	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery>`
                    
                    .. attribute:: group_name
                    
                    	XConnect Group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: l2_encapsulation
                    
                    	L2 Encapsulation
                    	**type**\:   :py:class:`L2VpnBagAdEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagAdEncap>`
                    
                    .. attribute:: mp2_mp_name
                    
                    	Mp2Mp Name
                    	**type**\:  str
                    
                    	**length:** 1..26
                    
                    .. attribute:: mp2mp_name
                    
                    	MP2MP name
                    	**type**\:  str
                    
                    .. attribute:: mp2mpid
                    
                    	Identification Number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_id
                    
                    	Vpn ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_mtu
                    
                    	VPN MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect_shutdown
                    
                    	Administratively disabled
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp, self).__init__()

                        self.yang_name = "xconnect-mp2mp"
                        self.yang_parent_name = "xconnect-mp2mps"

                        self.group_name = YLeaf(YType.str, "group-name")

                        self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                        self.l2_encapsulation = YLeaf(YType.enumeration, "l2-encapsulation")

                        self.mp2_mp_name = YLeaf(YType.str, "mp2-mp-name")

                        self.mp2mp_name = YLeaf(YType.str, "mp2mp-name")

                        self.mp2mpid = YLeaf(YType.uint32, "mp2mpid")

                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                        self.vpn_mtu = YLeaf(YType.uint32, "vpn-mtu")

                        self.xconnect_shutdown = YLeaf(YType.boolean, "xconnect-shutdown")

                        self.discovery = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"
                        self._children_yang_names.add("discovery")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_name",
                                        "group_name_xr",
                                        "l2_encapsulation",
                                        "mp2_mp_name",
                                        "mp2mp_name",
                                        "mp2mpid",
                                        "vpn_id",
                                        "vpn_mtu",
                                        "xconnect_shutdown") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp, self).__setattr__(name, value)


                    class Discovery(Entity):
                        """
                        l2vpn xc auto discovery info
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery Method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_service_connected
                        
                        	Service Connected
                        	**type**\:  bool
                        
                        .. attribute:: ad_signalling_method
                        
                        	Signaling Protocol
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ce_range
                        
                        	CE Range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: export_route_policy
                        
                        	Export Route Policy
                        	**type**\:  str
                        
                        .. attribute:: export_rt
                        
                        	Export Route Targets
                        	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt>`
                        
                        .. attribute:: import_rt
                        
                        	Import Route Targets
                        	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt>`
                        
                        .. attribute:: number_a_cs
                        
                        	Number of attachment circuits
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_a_cs_up
                        
                        	Number of attachment circuits up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ce2c_es
                        
                        	Number of ce2ce
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ce2ce_advertised
                        
                        	Number of ce2ce Advertised
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_p_ws_up
                        
                        	Number of pseudowires up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rd_value
                        
                        	Route Distinguisher
                        	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue>`
                        
                        .. attribute:: vpn_added
                        
                        	VPN Added
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "xconnect-mp2mp"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_service_connected = YLeaf(YType.boolean, "ad-service-connected")

                            self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                            self.ce_range = YLeaf(YType.uint16, "ce-range")

                            self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                            self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                            self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                            self.number_ce2c_es = YLeaf(YType.uint32, "number-ce2c-es")

                            self.number_ce2ce_advertised = YLeaf(YType.uint32, "number-ce2ce-advertised")

                            self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                            self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                            self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                            self.rd_value = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                            self.rd_value.parent = self
                            self._children_name_map["rd_value"] = "rd-value"
                            self._children_yang_names.add("rd-value")

                            self.export_rt = YList(self)
                            self.import_rt = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_service_connected",
                                            "ad_signalling_method",
                                            "ce_range",
                                            "export_route_policy",
                                            "number_a_cs",
                                            "number_a_cs_up",
                                            "number_ce2c_es",
                                            "number_ce2ce_advertised",
                                            "number_p_ws_up",
                                            "number_pseudowires",
                                            "vpn_added") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__setattr__(name, value)


                        class RdValue(Entity):
                            """
                            Route Distinguisher
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs>`
                            
                            .. attribute:: rd
                            
                            	RD
                            	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__init__()

                                self.yang_name = "rd-value"
                                self.yang_parent_name = "discovery"

                                self.rd = YLeaf(YType.enumeration, "rd")

                                self.auto = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                                self._children_yang_names.add("auto")

                                self.four_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                self._children_yang_names.add("four-byte-as")

                                self.two_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rd") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__setattr__(name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: auto_index
                                
                                	Auto\-generated Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: router_id
                                
                                	BGP Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "rd-value"

                                    self.auto_index = YLeaf(YType.uint16, "auto-index")

                                    self.router_id = YLeaf(YType.str, "router-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("auto_index",
                                                    "router_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.auto_index.is_set or
                                        self.router_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.auto_index.yfilter != YFilter.not_set or
                                        self.router_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "auto" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.auto_index.get_name_leafdata())
                                    if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto-index" or name == "router-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "auto-index"):
                                        self.auto_index = value
                                        self.auto_index.value_namespace = name_space
                                        self.auto_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router-id"):
                                        self.router_id = value
                                        self.router_id.value_namespace = name_space
                                        self.router_id.value_namespace_prefix = name_space_prefix


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "rd-value"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "rd-value"

                                    self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_as",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_as.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_as.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "four-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-as" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-as"):
                                        self.four_byte_as = value
                                        self.four_byte_as.value_namespace = name_space
                                        self.four_byte_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "rd-value"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rd.is_set or
                                    (self.auto is not None and self.auto.has_data()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rd.yfilter != YFilter.not_set or
                                    (self.auto is not None and self.auto.has_operation()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rd-value" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rd.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "auto"):
                                    if (self.auto is None):
                                        self.auto = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                    return self.auto

                                if (child_yang_name == "four-byte-as"):
                                    if (self.four_byte_as is None):
                                        self.four_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                    return self.four_byte_as

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rd"):
                                    self.rd = value
                                    self.rd.value_namespace = name_space
                                    self.rd.value_namespace_prefix = name_space_prefix


                        class ImportRt(Entity):
                            """
                            Import Route Targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__init__()

                                self.yang_name = "import-rt"
                                self.yang_parent_name = "discovery"

                                self.rt = YLeaf(YType.enumeration, "rt")

                                self.es_import = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                                self.es_import.parent = self
                                self._children_name_map["es_import"] = "es-import"
                                self._children_yang_names.add("es-import")

                                self.four_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                self._children_yang_names.add("four-byte-as")

                                self.two_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rt") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__setattr__(name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "import-rt"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "import-rt"

                                    self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_as",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_as.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_as.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "four-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-as" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-as"):
                                        self.four_byte_as = value
                                        self.four_byte_as.value_namespace = name_space
                                        self.four_byte_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "import-rt"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class EsImport(Entity):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__init__()

                                    self.yang_name = "es-import"
                                    self.yang_parent_name = "import-rt"

                                    self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                    self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("high_bytes",
                                                    "low_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.high_bytes.is_set or
                                        self.low_bytes.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.high_bytes.yfilter != YFilter.not_set or
                                        self.low_bytes.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "es-import" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                    if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "high-bytes" or name == "low-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "high-bytes"):
                                        self.high_bytes = value
                                        self.high_bytes.value_namespace = name_space
                                        self.high_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low-bytes"):
                                        self.low_bytes = value
                                        self.low_bytes.value_namespace = name_space
                                        self.low_bytes.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rt.is_set or
                                    (self.es_import is not None and self.es_import.has_data()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rt.yfilter != YFilter.not_set or
                                    (self.es_import is not None and self.es_import.has_operation()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "import-rt" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rt.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "es-import"):
                                    if (self.es_import is None):
                                        self.es_import = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                    return self.es_import

                                if (child_yang_name == "four-byte-as"):
                                    if (self.four_byte_as is None):
                                        self.four_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                    return self.four_byte_as

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rt"):
                                    self.rt = value
                                    self.rt.value_namespace = name_space
                                    self.rt.value_namespace_prefix = name_space_prefix


                        class ExportRt(Entity):
                            """
                            Export Route Targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__init__()

                                self.yang_name = "export-rt"
                                self.yang_parent_name = "discovery"

                                self.rt = YLeaf(YType.enumeration, "rt")

                                self.es_import = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                                self.es_import.parent = self
                                self._children_name_map["es_import"] = "es-import"
                                self._children_yang_names.add("es-import")

                                self.four_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                self._children_yang_names.add("four-byte-as")

                                self.two_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rt") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__setattr__(name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "export-rt"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "export-rt"

                                    self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_as",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_as.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_as.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "four-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-as" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-as"):
                                        self.four_byte_as = value
                                        self.four_byte_as.value_namespace = name_space
                                        self.four_byte_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "export-rt"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class EsImport(Entity):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__init__()

                                    self.yang_name = "es-import"
                                    self.yang_parent_name = "export-rt"

                                    self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                    self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("high_bytes",
                                                    "low_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.high_bytes.is_set or
                                        self.low_bytes.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.high_bytes.yfilter != YFilter.not_set or
                                        self.low_bytes.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "es-import" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                    if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "high-bytes" or name == "low-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "high-bytes"):
                                        self.high_bytes = value
                                        self.high_bytes.value_namespace = name_space
                                        self.high_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low-bytes"):
                                        self.low_bytes = value
                                        self.low_bytes.value_namespace = name_space
                                        self.low_bytes.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rt.is_set or
                                    (self.es_import is not None and self.es_import.has_data()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rt.yfilter != YFilter.not_set or
                                    (self.es_import is not None and self.es_import.has_operation()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "export-rt" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rt.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "es-import"):
                                    if (self.es_import is None):
                                        self.es_import = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                    return self.es_import

                                if (child_yang_name == "four-byte-as"):
                                    if (self.four_byte_as is None):
                                        self.four_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                    return self.four_byte_as

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rt"):
                                    self.rt = value
                                    self.rt.value_namespace = name_space
                                    self.rt.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.export_rt:
                                if (c.has_data()):
                                    return True
                            for c in self.import_rt:
                                if (c.has_data()):
                                    return True
                            return (
                                self.ad_method.is_set or
                                self.ad_service_connected.is_set or
                                self.ad_signalling_method.is_set or
                                self.ce_range.is_set or
                                self.export_route_policy.is_set or
                                self.number_a_cs.is_set or
                                self.number_a_cs_up.is_set or
                                self.number_ce2c_es.is_set or
                                self.number_ce2ce_advertised.is_set or
                                self.number_p_ws_up.is_set or
                                self.number_pseudowires.is_set or
                                self.vpn_added.is_set or
                                (self.rd_value is not None and self.rd_value.has_data()))

                        def has_operation(self):
                            for c in self.export_rt:
                                if (c.has_operation()):
                                    return True
                            for c in self.import_rt:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_service_connected.yfilter != YFilter.not_set or
                                self.ad_signalling_method.yfilter != YFilter.not_set or
                                self.ce_range.yfilter != YFilter.not_set or
                                self.export_route_policy.yfilter != YFilter.not_set or
                                self.number_a_cs.yfilter != YFilter.not_set or
                                self.number_a_cs_up.yfilter != YFilter.not_set or
                                self.number_ce2c_es.yfilter != YFilter.not_set or
                                self.number_ce2ce_advertised.yfilter != YFilter.not_set or
                                self.number_p_ws_up.yfilter != YFilter.not_set or
                                self.number_pseudowires.yfilter != YFilter.not_set or
                                self.vpn_added.yfilter != YFilter.not_set or
                                (self.rd_value is not None and self.rd_value.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "discovery" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_service_connected.is_set or self.ad_service_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_service_connected.get_name_leafdata())
                            if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                            if (self.ce_range.is_set or self.ce_range.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ce_range.get_name_leafdata())
                            if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                            if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                            if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                            if (self.number_ce2c_es.is_set or self.number_ce2c_es.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ce2c_es.get_name_leafdata())
                            if (self.number_ce2ce_advertised.is_set or self.number_ce2ce_advertised.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ce2ce_advertised.get_name_leafdata())
                            if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                            if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                            if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vpn_added.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "export-rt"):
                                for c in self.export_rt:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.export_rt.append(c)
                                return c

                            if (child_yang_name == "import-rt"):
                                for c in self.import_rt:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.import_rt.append(c)
                                return c

                            if (child_yang_name == "rd-value"):
                                if (self.rd_value is None):
                                    self.rd_value = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                                    self.rd_value.parent = self
                                    self._children_name_map["rd_value"] = "rd-value"
                                return self.rd_value

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "ad-method" or name == "ad-service-connected" or name == "ad-signalling-method" or name == "ce-range" or name == "export-route-policy" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-ce2c-es" or name == "number-ce2ce-advertised" or name == "number-p-ws-up" or name == "number-pseudowires" or name == "vpn-added"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-service-connected"):
                                self.ad_service_connected = value
                                self.ad_service_connected.value_namespace = name_space
                                self.ad_service_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-signalling-method"):
                                self.ad_signalling_method = value
                                self.ad_signalling_method.value_namespace = name_space
                                self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ce-range"):
                                self.ce_range = value
                                self.ce_range.value_namespace = name_space
                                self.ce_range.value_namespace_prefix = name_space_prefix
                            if(value_path == "export-route-policy"):
                                self.export_route_policy = value
                                self.export_route_policy.value_namespace = name_space
                                self.export_route_policy.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-a-cs"):
                                self.number_a_cs = value
                                self.number_a_cs.value_namespace = name_space
                                self.number_a_cs.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-a-cs-up"):
                                self.number_a_cs_up = value
                                self.number_a_cs_up.value_namespace = name_space
                                self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ce2c-es"):
                                self.number_ce2c_es = value
                                self.number_ce2c_es.value_namespace = name_space
                                self.number_ce2c_es.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ce2ce-advertised"):
                                self.number_ce2ce_advertised = value
                                self.number_ce2ce_advertised.value_namespace = name_space
                                self.number_ce2ce_advertised.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-p-ws-up"):
                                self.number_p_ws_up = value
                                self.number_p_ws_up.value_namespace = name_space
                                self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pseudowires"):
                                self.number_pseudowires = value
                                self.number_pseudowires.value_namespace = name_space
                                self.number_pseudowires.value_namespace_prefix = name_space_prefix
                            if(value_path == "vpn-added"):
                                self.vpn_added = value
                                self.vpn_added.value_namespace = name_space
                                self.vpn_added.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_name.is_set or
                            self.group_name_xr.is_set or
                            self.l2_encapsulation.is_set or
                            self.mp2_mp_name.is_set or
                            self.mp2mp_name.is_set or
                            self.mp2mpid.is_set or
                            self.vpn_id.is_set or
                            self.vpn_mtu.is_set or
                            self.xconnect_shutdown.is_set or
                            (self.discovery is not None and self.discovery.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_name.yfilter != YFilter.not_set or
                            self.group_name_xr.yfilter != YFilter.not_set or
                            self.l2_encapsulation.yfilter != YFilter.not_set or
                            self.mp2_mp_name.yfilter != YFilter.not_set or
                            self.mp2mp_name.yfilter != YFilter.not_set or
                            self.mp2mpid.yfilter != YFilter.not_set or
                            self.vpn_id.yfilter != YFilter.not_set or
                            self.vpn_mtu.yfilter != YFilter.not_set or
                            self.xconnect_shutdown.yfilter != YFilter.not_set or
                            (self.discovery is not None and self.discovery.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "xconnect-mp2mp" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name.get_name_leafdata())
                        if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                        if (self.l2_encapsulation.is_set or self.l2_encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.l2_encapsulation.get_name_leafdata())
                        if (self.mp2_mp_name.is_set or self.mp2_mp_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mp2_mp_name.get_name_leafdata())
                        if (self.mp2mp_name.is_set or self.mp2mp_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mp2mp_name.get_name_leafdata())
                        if (self.mp2mpid.is_set or self.mp2mpid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mp2mpid.get_name_leafdata())
                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_id.get_name_leafdata())
                        if (self.vpn_mtu.is_set or self.vpn_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_mtu.get_name_leafdata())
                        if (self.xconnect_shutdown.is_set or self.xconnect_shutdown.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_shutdown.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "discovery"):
                            if (self.discovery is None):
                                self.discovery = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                                self.discovery.parent = self
                                self._children_name_map["discovery"] = "discovery"
                            return self.discovery

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "discovery" or name == "group-name" or name == "group-name-xr" or name == "l2-encapsulation" or name == "mp2-mp-name" or name == "mp2mp-name" or name == "mp2mpid" or name == "vpn-id" or name == "vpn-mtu" or name == "xconnect-shutdown"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-name"):
                            self.group_name = value
                            self.group_name.value_namespace = name_space
                            self.group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-name-xr"):
                            self.group_name_xr = value
                            self.group_name_xr.value_namespace = name_space
                            self.group_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "l2-encapsulation"):
                            self.l2_encapsulation = value
                            self.l2_encapsulation.value_namespace = name_space
                            self.l2_encapsulation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mp2-mp-name"):
                            self.mp2_mp_name = value
                            self.mp2_mp_name.value_namespace = name_space
                            self.mp2_mp_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mp2mp-name"):
                            self.mp2mp_name = value
                            self.mp2mp_name.value_namespace = name_space
                            self.mp2mp_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mp2mpid"):
                            self.mp2mpid = value
                            self.mp2mpid.value_namespace = name_space
                            self.mp2mpid.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-id"):
                            self.vpn_id = value
                            self.vpn_id.value_namespace = name_space
                            self.vpn_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-mtu"):
                            self.vpn_mtu = value
                            self.vpn_mtu.value_namespace = name_space
                            self.vpn_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-shutdown"):
                            self.xconnect_shutdown = value
                            self.xconnect_shutdown.value_namespace = name_space
                            self.xconnect_shutdown.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.xconnect_mp2mp:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.xconnect_mp2mp:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-mp2mps" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "xconnect-mp2mp"):
                        for c in self.xconnect_mp2mp:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.xconnect_mp2mp.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "xconnect-mp2mp"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Indexes(Entity):
                """
                ID Manager Index Table
                
                .. attribute:: index
                
                	ID Manager Index Pool
                	**type**\: list of    :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Indexes.Index>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.Indexes, self).__init__()

                    self.yang_name = "indexes"
                    self.yang_parent_name = "node"

                    self.index = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.Indexes, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.Indexes, self).__setattr__(name, value)


                class Index(Entity):
                    """
                    ID Manager Index Pool
                    
                    .. attribute:: pool_id  <key>
                    
                    	Pool ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: allocated_ids
                    
                    	Number of IDs allocated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: application_type
                    
                    	Application Type
                    	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
                    
                    .. attribute:: max_num_id_mgr
                    
                    	Maximum number of pool extensions
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: num_id_mgr_in_use
                    
                    	ID mgr instances in use
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pool_id_xr
                    
                    	Pool Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pool_size
                    
                    	Pool size
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: zombied_ids
                    
                    	Number of IDs allocated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Indexes.Index, self).__init__()

                        self.yang_name = "index"
                        self.yang_parent_name = "indexes"

                        self.pool_id = YLeaf(YType.str, "pool-id")

                        self.allocated_ids = YLeaf(YType.uint32, "allocated-ids")

                        self.application_type = YLeaf(YType.enumeration, "application-type")

                        self.max_num_id_mgr = YLeaf(YType.uint32, "max-num-id-mgr")

                        self.num_id_mgr_in_use = YLeaf(YType.uint32, "num-id-mgr-in-use")

                        self.pool_id_xr = YLeaf(YType.uint32, "pool-id-xr")

                        self.pool_size = YLeaf(YType.uint32, "pool-size")

                        self.zombied_ids = YLeaf(YType.uint32, "zombied-ids")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("pool_id",
                                        "allocated_ids",
                                        "application_type",
                                        "max_num_id_mgr",
                                        "num_id_mgr_in_use",
                                        "pool_id_xr",
                                        "pool_size",
                                        "zombied_ids") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Indexes.Index, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Indexes.Index, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.pool_id.is_set or
                            self.allocated_ids.is_set or
                            self.application_type.is_set or
                            self.max_num_id_mgr.is_set or
                            self.num_id_mgr_in_use.is_set or
                            self.pool_id_xr.is_set or
                            self.pool_size.is_set or
                            self.zombied_ids.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.pool_id.yfilter != YFilter.not_set or
                            self.allocated_ids.yfilter != YFilter.not_set or
                            self.application_type.yfilter != YFilter.not_set or
                            self.max_num_id_mgr.yfilter != YFilter.not_set or
                            self.num_id_mgr_in_use.yfilter != YFilter.not_set or
                            self.pool_id_xr.yfilter != YFilter.not_set or
                            self.pool_size.yfilter != YFilter.not_set or
                            self.zombied_ids.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "index" + "[pool-id='" + self.pool_id.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.pool_id.is_set or self.pool_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pool_id.get_name_leafdata())
                        if (self.allocated_ids.is_set or self.allocated_ids.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_ids.get_name_leafdata())
                        if (self.application_type.is_set or self.application_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.application_type.get_name_leafdata())
                        if (self.max_num_id_mgr.is_set or self.max_num_id_mgr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_num_id_mgr.get_name_leafdata())
                        if (self.num_id_mgr_in_use.is_set or self.num_id_mgr_in_use.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_id_mgr_in_use.get_name_leafdata())
                        if (self.pool_id_xr.is_set or self.pool_id_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pool_id_xr.get_name_leafdata())
                        if (self.pool_size.is_set or self.pool_size.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pool_size.get_name_leafdata())
                        if (self.zombied_ids.is_set or self.zombied_ids.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.zombied_ids.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "pool-id" or name == "allocated-ids" or name == "application-type" or name == "max-num-id-mgr" or name == "num-id-mgr-in-use" or name == "pool-id-xr" or name == "pool-size" or name == "zombied-ids"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "pool-id"):
                            self.pool_id = value
                            self.pool_id.value_namespace = name_space
                            self.pool_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "allocated-ids"):
                            self.allocated_ids = value
                            self.allocated_ids.value_namespace = name_space
                            self.allocated_ids.value_namespace_prefix = name_space_prefix
                        if(value_path == "application-type"):
                            self.application_type = value
                            self.application_type.value_namespace = name_space
                            self.application_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-num-id-mgr"):
                            self.max_num_id_mgr = value
                            self.max_num_id_mgr.value_namespace = name_space
                            self.max_num_id_mgr.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-id-mgr-in-use"):
                            self.num_id_mgr_in_use = value
                            self.num_id_mgr_in_use.value_namespace = name_space
                            self.num_id_mgr_in_use.value_namespace_prefix = name_space_prefix
                        if(value_path == "pool-id-xr"):
                            self.pool_id_xr = value
                            self.pool_id_xr.value_namespace = name_space
                            self.pool_id_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "pool-size"):
                            self.pool_size = value
                            self.pool_size.value_namespace = name_space
                            self.pool_size.value_namespace_prefix = name_space_prefix
                        if(value_path == "zombied-ids"):
                            self.zombied_ids = value
                            self.zombied_ids.value_namespace = name_space
                            self.zombied_ids.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.index:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.index:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "indexes" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "index"):
                        for c in self.index:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.Indexes.Index()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.index.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "index"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class XconnectSummary(Entity):
                """
                XConnect summary information
                
                .. attribute:: admin_down_backup_interface_xconnects
                
                	Number of XCs with backup interface in admin down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: admin_down_backup_xconnects
                
                	Number of XCs with backup PW in admin down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: down_backup_interface_xconnects
                
                	Number of XCs with backup interface in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: down_backup_xconnects
                
                	Number of XCs with backup PW in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2_ceconnections
                
                	Number of Ce2Ce connections
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2ce_advertized
                
                	Number of CE2CE connections that have been advertized
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2ce_not_advertized
                
                	Number of CE2CE connections that have not been advertized
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_groups
                
                	Number of groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects
                
                	Number of mp2mp xconnects
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects_advertised
                
                	Number of Mp2mp XCs that have been advertized
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects_down
                
                	Number of Mp2mp XCs that have ben admined down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects_up
                
                	Number of Mp2mp XCs that have been admined up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnectss_not_advertised
                
                	Number of Mp2mp XCs that have not been advertized
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects
                
                	Number of xconnects
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_administratively_down
                
                	Number of xconnects with segments in admin down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_currently_using_backup
                
                	Number of XCs currently using backup PW (UP state)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_currently_using_backup_interface
                
                	Number of XCs currently using backup interface (UP state)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_down
                
                	Number of xconnects whose state is down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_locally_switched
                
                	Number of locally switched xconnects
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
                
                	Number of xconnects of type attachment circuit to pseudowire
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
                
                	Number of xconnects of type monitor session to pseudowire
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
                
                	Number of xconnects of type PseudoWire To PseudoWire
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_unresolved
                
                	Number of xconnects whose state is unresolved
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_up
                
                	Numxber of xconnects whose state is up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_with_backup_interface
                
                	Number of XCs configured with backup interface
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_with_backup_pw
                
                	Number of XCs configured with backup PW
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: out_of_memory_state
                
                	L2VPN Out of memory state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_xconnects
                
                	Number of cross\-connects partially programmed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_backup_interface_xconnects
                
                	Number of XCs with backup interface in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_backup_xconnects
                
                	Number of XCs with backup PW in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_ready_backup_xconnects
                
                	Number of XCs with backup PW in standby ready state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_backup_interface_xconnects
                
                	Number of XCs with backup interface in unresolved state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_backup_xconnects
                
                	Number of XCs with backup PW in unresolved state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.XconnectSummary, self).__init__()

                    self.yang_name = "xconnect-summary"
                    self.yang_parent_name = "node"

                    self.admin_down_backup_interface_xconnects = YLeaf(YType.uint32, "admin-down-backup-interface-xconnects")

                    self.admin_down_backup_xconnects = YLeaf(YType.uint32, "admin-down-backup-xconnects")

                    self.down_backup_interface_xconnects = YLeaf(YType.uint32, "down-backup-interface-xconnects")

                    self.down_backup_xconnects = YLeaf(YType.uint32, "down-backup-xconnects")

                    self.number_ce2_ceconnections = YLeaf(YType.uint32, "number-ce2-ceconnections")

                    self.number_ce2ce_advertized = YLeaf(YType.uint32, "number-ce2ce-advertized")

                    self.number_ce2ce_not_advertized = YLeaf(YType.uint32, "number-ce2ce-not-advertized")

                    self.number_groups = YLeaf(YType.uint32, "number-groups")

                    self.number_mp2mp_xconnects = YLeaf(YType.uint32, "number-mp2mp-xconnects")

                    self.number_mp2mp_xconnects_advertised = YLeaf(YType.uint32, "number-mp2mp-xconnects-advertised")

                    self.number_mp2mp_xconnects_down = YLeaf(YType.uint32, "number-mp2mp-xconnects-down")

                    self.number_mp2mp_xconnects_up = YLeaf(YType.uint32, "number-mp2mp-xconnects-up")

                    self.number_mp2mp_xconnectss_not_advertised = YLeaf(YType.uint32, "number-mp2mp-xconnectss-not-advertised")

                    self.number_xconnects = YLeaf(YType.uint32, "number-xconnects")

                    self.number_xconnects_administratively_down = YLeaf(YType.uint32, "number-xconnects-administratively-down")

                    self.number_xconnects_currently_using_backup = YLeaf(YType.uint32, "number-xconnects-currently-using-backup")

                    self.number_xconnects_currently_using_backup_interface = YLeaf(YType.uint32, "number-xconnects-currently-using-backup-interface")

                    self.number_xconnects_down = YLeaf(YType.uint32, "number-xconnects-down")

                    self.number_xconnects_locally_switched = YLeaf(YType.uint32, "number-xconnects-locally-switched")

                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-attachment-circuit-to-pseudo-wire")

                    self.number_xconnects_type_monitor_session_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-monitor-session-to-pseudo-wire")

                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-pseudo-wire-to-pseudo-wire")

                    self.number_xconnects_unresolved = YLeaf(YType.uint32, "number-xconnects-unresolved")

                    self.number_xconnects_up = YLeaf(YType.uint32, "number-xconnects-up")

                    self.number_xconnects_with_backup_interface = YLeaf(YType.uint32, "number-xconnects-with-backup-interface")

                    self.number_xconnects_with_backup_pw = YLeaf(YType.uint32, "number-xconnects-with-backup-pw")

                    self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                    self.partially_programmed_xconnects = YLeaf(YType.uint32, "partially-programmed-xconnects")

                    self.standby_backup_interface_xconnects = YLeaf(YType.uint32, "standby-backup-interface-xconnects")

                    self.standby_backup_xconnects = YLeaf(YType.uint32, "standby-backup-xconnects")

                    self.standby_ready_backup_xconnects = YLeaf(YType.uint32, "standby-ready-backup-xconnects")

                    self.unresolved_backup_interface_xconnects = YLeaf(YType.uint32, "unresolved-backup-interface-xconnects")

                    self.unresolved_backup_xconnects = YLeaf(YType.uint32, "unresolved-backup-xconnects")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("admin_down_backup_interface_xconnects",
                                    "admin_down_backup_xconnects",
                                    "down_backup_interface_xconnects",
                                    "down_backup_xconnects",
                                    "number_ce2_ceconnections",
                                    "number_ce2ce_advertized",
                                    "number_ce2ce_not_advertized",
                                    "number_groups",
                                    "number_mp2mp_xconnects",
                                    "number_mp2mp_xconnects_advertised",
                                    "number_mp2mp_xconnects_down",
                                    "number_mp2mp_xconnects_up",
                                    "number_mp2mp_xconnectss_not_advertised",
                                    "number_xconnects",
                                    "number_xconnects_administratively_down",
                                    "number_xconnects_currently_using_backup",
                                    "number_xconnects_currently_using_backup_interface",
                                    "number_xconnects_down",
                                    "number_xconnects_locally_switched",
                                    "number_xconnects_type_attachment_circuit_to_pseudo_wire",
                                    "number_xconnects_type_monitor_session_to_pseudo_wire",
                                    "number_xconnects_type_pseudo_wire_to_pseudo_wire",
                                    "number_xconnects_unresolved",
                                    "number_xconnects_up",
                                    "number_xconnects_with_backup_interface",
                                    "number_xconnects_with_backup_pw",
                                    "out_of_memory_state",
                                    "partially_programmed_xconnects",
                                    "standby_backup_interface_xconnects",
                                    "standby_backup_xconnects",
                                    "standby_ready_backup_xconnects",
                                    "unresolved_backup_interface_xconnects",
                                    "unresolved_backup_xconnects") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.XconnectSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.XconnectSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.admin_down_backup_interface_xconnects.is_set or
                        self.admin_down_backup_xconnects.is_set or
                        self.down_backup_interface_xconnects.is_set or
                        self.down_backup_xconnects.is_set or
                        self.number_ce2_ceconnections.is_set or
                        self.number_ce2ce_advertized.is_set or
                        self.number_ce2ce_not_advertized.is_set or
                        self.number_groups.is_set or
                        self.number_mp2mp_xconnects.is_set or
                        self.number_mp2mp_xconnects_advertised.is_set or
                        self.number_mp2mp_xconnects_down.is_set or
                        self.number_mp2mp_xconnects_up.is_set or
                        self.number_mp2mp_xconnectss_not_advertised.is_set or
                        self.number_xconnects.is_set or
                        self.number_xconnects_administratively_down.is_set or
                        self.number_xconnects_currently_using_backup.is_set or
                        self.number_xconnects_currently_using_backup_interface.is_set or
                        self.number_xconnects_down.is_set or
                        self.number_xconnects_locally_switched.is_set or
                        self.number_xconnects_type_attachment_circuit_to_pseudo_wire.is_set or
                        self.number_xconnects_type_monitor_session_to_pseudo_wire.is_set or
                        self.number_xconnects_type_pseudo_wire_to_pseudo_wire.is_set or
                        self.number_xconnects_unresolved.is_set or
                        self.number_xconnects_up.is_set or
                        self.number_xconnects_with_backup_interface.is_set or
                        self.number_xconnects_with_backup_pw.is_set or
                        self.out_of_memory_state.is_set or
                        self.partially_programmed_xconnects.is_set or
                        self.standby_backup_interface_xconnects.is_set or
                        self.standby_backup_xconnects.is_set or
                        self.standby_ready_backup_xconnects.is_set or
                        self.unresolved_backup_interface_xconnects.is_set or
                        self.unresolved_backup_xconnects.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.admin_down_backup_interface_xconnects.yfilter != YFilter.not_set or
                        self.admin_down_backup_xconnects.yfilter != YFilter.not_set or
                        self.down_backup_interface_xconnects.yfilter != YFilter.not_set or
                        self.down_backup_xconnects.yfilter != YFilter.not_set or
                        self.number_ce2_ceconnections.yfilter != YFilter.not_set or
                        self.number_ce2ce_advertized.yfilter != YFilter.not_set or
                        self.number_ce2ce_not_advertized.yfilter != YFilter.not_set or
                        self.number_groups.yfilter != YFilter.not_set or
                        self.number_mp2mp_xconnects.yfilter != YFilter.not_set or
                        self.number_mp2mp_xconnects_advertised.yfilter != YFilter.not_set or
                        self.number_mp2mp_xconnects_down.yfilter != YFilter.not_set or
                        self.number_mp2mp_xconnects_up.yfilter != YFilter.not_set or
                        self.number_mp2mp_xconnectss_not_advertised.yfilter != YFilter.not_set or
                        self.number_xconnects.yfilter != YFilter.not_set or
                        self.number_xconnects_administratively_down.yfilter != YFilter.not_set or
                        self.number_xconnects_currently_using_backup.yfilter != YFilter.not_set or
                        self.number_xconnects_currently_using_backup_interface.yfilter != YFilter.not_set or
                        self.number_xconnects_down.yfilter != YFilter.not_set or
                        self.number_xconnects_locally_switched.yfilter != YFilter.not_set or
                        self.number_xconnects_type_attachment_circuit_to_pseudo_wire.yfilter != YFilter.not_set or
                        self.number_xconnects_type_monitor_session_to_pseudo_wire.yfilter != YFilter.not_set or
                        self.number_xconnects_type_pseudo_wire_to_pseudo_wire.yfilter != YFilter.not_set or
                        self.number_xconnects_unresolved.yfilter != YFilter.not_set or
                        self.number_xconnects_up.yfilter != YFilter.not_set or
                        self.number_xconnects_with_backup_interface.yfilter != YFilter.not_set or
                        self.number_xconnects_with_backup_pw.yfilter != YFilter.not_set or
                        self.out_of_memory_state.yfilter != YFilter.not_set or
                        self.partially_programmed_xconnects.yfilter != YFilter.not_set or
                        self.standby_backup_interface_xconnects.yfilter != YFilter.not_set or
                        self.standby_backup_xconnects.yfilter != YFilter.not_set or
                        self.standby_ready_backup_xconnects.yfilter != YFilter.not_set or
                        self.unresolved_backup_interface_xconnects.yfilter != YFilter.not_set or
                        self.unresolved_backup_xconnects.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.admin_down_backup_interface_xconnects.is_set or self.admin_down_backup_interface_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.admin_down_backup_interface_xconnects.get_name_leafdata())
                    if (self.admin_down_backup_xconnects.is_set or self.admin_down_backup_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.admin_down_backup_xconnects.get_name_leafdata())
                    if (self.down_backup_interface_xconnects.is_set or self.down_backup_interface_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.down_backup_interface_xconnects.get_name_leafdata())
                    if (self.down_backup_xconnects.is_set or self.down_backup_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.down_backup_xconnects.get_name_leafdata())
                    if (self.number_ce2_ceconnections.is_set or self.number_ce2_ceconnections.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_ce2_ceconnections.get_name_leafdata())
                    if (self.number_ce2ce_advertized.is_set or self.number_ce2ce_advertized.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_ce2ce_advertized.get_name_leafdata())
                    if (self.number_ce2ce_not_advertized.is_set or self.number_ce2ce_not_advertized.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_ce2ce_not_advertized.get_name_leafdata())
                    if (self.number_groups.is_set or self.number_groups.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_groups.get_name_leafdata())
                    if (self.number_mp2mp_xconnects.is_set or self.number_mp2mp_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_mp2mp_xconnects.get_name_leafdata())
                    if (self.number_mp2mp_xconnects_advertised.is_set or self.number_mp2mp_xconnects_advertised.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_mp2mp_xconnects_advertised.get_name_leafdata())
                    if (self.number_mp2mp_xconnects_down.is_set or self.number_mp2mp_xconnects_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_mp2mp_xconnects_down.get_name_leafdata())
                    if (self.number_mp2mp_xconnects_up.is_set or self.number_mp2mp_xconnects_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_mp2mp_xconnects_up.get_name_leafdata())
                    if (self.number_mp2mp_xconnectss_not_advertised.is_set or self.number_mp2mp_xconnectss_not_advertised.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_mp2mp_xconnectss_not_advertised.get_name_leafdata())
                    if (self.number_xconnects.is_set or self.number_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects.get_name_leafdata())
                    if (self.number_xconnects_administratively_down.is_set or self.number_xconnects_administratively_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_administratively_down.get_name_leafdata())
                    if (self.number_xconnects_currently_using_backup.is_set or self.number_xconnects_currently_using_backup.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_currently_using_backup.get_name_leafdata())
                    if (self.number_xconnects_currently_using_backup_interface.is_set or self.number_xconnects_currently_using_backup_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_currently_using_backup_interface.get_name_leafdata())
                    if (self.number_xconnects_down.is_set or self.number_xconnects_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_down.get_name_leafdata())
                    if (self.number_xconnects_locally_switched.is_set or self.number_xconnects_locally_switched.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_locally_switched.get_name_leafdata())
                    if (self.number_xconnects_type_attachment_circuit_to_pseudo_wire.is_set or self.number_xconnects_type_attachment_circuit_to_pseudo_wire.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_type_attachment_circuit_to_pseudo_wire.get_name_leafdata())
                    if (self.number_xconnects_type_monitor_session_to_pseudo_wire.is_set or self.number_xconnects_type_monitor_session_to_pseudo_wire.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_type_monitor_session_to_pseudo_wire.get_name_leafdata())
                    if (self.number_xconnects_type_pseudo_wire_to_pseudo_wire.is_set or self.number_xconnects_type_pseudo_wire_to_pseudo_wire.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_type_pseudo_wire_to_pseudo_wire.get_name_leafdata())
                    if (self.number_xconnects_unresolved.is_set or self.number_xconnects_unresolved.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_unresolved.get_name_leafdata())
                    if (self.number_xconnects_up.is_set or self.number_xconnects_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_up.get_name_leafdata())
                    if (self.number_xconnects_with_backup_interface.is_set or self.number_xconnects_with_backup_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_with_backup_interface.get_name_leafdata())
                    if (self.number_xconnects_with_backup_pw.is_set or self.number_xconnects_with_backup_pw.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_xconnects_with_backup_pw.get_name_leafdata())
                    if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                    if (self.partially_programmed_xconnects.is_set or self.partially_programmed_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partially_programmed_xconnects.get_name_leafdata())
                    if (self.standby_backup_interface_xconnects.is_set or self.standby_backup_interface_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_backup_interface_xconnects.get_name_leafdata())
                    if (self.standby_backup_xconnects.is_set or self.standby_backup_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_backup_xconnects.get_name_leafdata())
                    if (self.standby_ready_backup_xconnects.is_set or self.standby_ready_backup_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_ready_backup_xconnects.get_name_leafdata())
                    if (self.unresolved_backup_interface_xconnects.is_set or self.unresolved_backup_interface_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unresolved_backup_interface_xconnects.get_name_leafdata())
                    if (self.unresolved_backup_xconnects.is_set or self.unresolved_backup_xconnects.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unresolved_backup_xconnects.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "admin-down-backup-interface-xconnects" or name == "admin-down-backup-xconnects" or name == "down-backup-interface-xconnects" or name == "down-backup-xconnects" or name == "number-ce2-ceconnections" or name == "number-ce2ce-advertized" or name == "number-ce2ce-not-advertized" or name == "number-groups" or name == "number-mp2mp-xconnects" or name == "number-mp2mp-xconnects-advertised" or name == "number-mp2mp-xconnects-down" or name == "number-mp2mp-xconnects-up" or name == "number-mp2mp-xconnectss-not-advertised" or name == "number-xconnects" or name == "number-xconnects-administratively-down" or name == "number-xconnects-currently-using-backup" or name == "number-xconnects-currently-using-backup-interface" or name == "number-xconnects-down" or name == "number-xconnects-locally-switched" or name == "number-xconnects-type-attachment-circuit-to-pseudo-wire" or name == "number-xconnects-type-monitor-session-to-pseudo-wire" or name == "number-xconnects-type-pseudo-wire-to-pseudo-wire" or name == "number-xconnects-unresolved" or name == "number-xconnects-up" or name == "number-xconnects-with-backup-interface" or name == "number-xconnects-with-backup-pw" or name == "out-of-memory-state" or name == "partially-programmed-xconnects" or name == "standby-backup-interface-xconnects" or name == "standby-backup-xconnects" or name == "standby-ready-backup-xconnects" or name == "unresolved-backup-interface-xconnects" or name == "unresolved-backup-xconnects"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "admin-down-backup-interface-xconnects"):
                        self.admin_down_backup_interface_xconnects = value
                        self.admin_down_backup_interface_xconnects.value_namespace = name_space
                        self.admin_down_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "admin-down-backup-xconnects"):
                        self.admin_down_backup_xconnects = value
                        self.admin_down_backup_xconnects.value_namespace = name_space
                        self.admin_down_backup_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "down-backup-interface-xconnects"):
                        self.down_backup_interface_xconnects = value
                        self.down_backup_interface_xconnects.value_namespace = name_space
                        self.down_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "down-backup-xconnects"):
                        self.down_backup_xconnects = value
                        self.down_backup_xconnects.value_namespace = name_space
                        self.down_backup_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-ce2-ceconnections"):
                        self.number_ce2_ceconnections = value
                        self.number_ce2_ceconnections.value_namespace = name_space
                        self.number_ce2_ceconnections.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-ce2ce-advertized"):
                        self.number_ce2ce_advertized = value
                        self.number_ce2ce_advertized.value_namespace = name_space
                        self.number_ce2ce_advertized.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-ce2ce-not-advertized"):
                        self.number_ce2ce_not_advertized = value
                        self.number_ce2ce_not_advertized.value_namespace = name_space
                        self.number_ce2ce_not_advertized.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-groups"):
                        self.number_groups = value
                        self.number_groups.value_namespace = name_space
                        self.number_groups.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-mp2mp-xconnects"):
                        self.number_mp2mp_xconnects = value
                        self.number_mp2mp_xconnects.value_namespace = name_space
                        self.number_mp2mp_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-mp2mp-xconnects-advertised"):
                        self.number_mp2mp_xconnects_advertised = value
                        self.number_mp2mp_xconnects_advertised.value_namespace = name_space
                        self.number_mp2mp_xconnects_advertised.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-mp2mp-xconnects-down"):
                        self.number_mp2mp_xconnects_down = value
                        self.number_mp2mp_xconnects_down.value_namespace = name_space
                        self.number_mp2mp_xconnects_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-mp2mp-xconnects-up"):
                        self.number_mp2mp_xconnects_up = value
                        self.number_mp2mp_xconnects_up.value_namespace = name_space
                        self.number_mp2mp_xconnects_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-mp2mp-xconnectss-not-advertised"):
                        self.number_mp2mp_xconnectss_not_advertised = value
                        self.number_mp2mp_xconnectss_not_advertised.value_namespace = name_space
                        self.number_mp2mp_xconnectss_not_advertised.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects"):
                        self.number_xconnects = value
                        self.number_xconnects.value_namespace = name_space
                        self.number_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-administratively-down"):
                        self.number_xconnects_administratively_down = value
                        self.number_xconnects_administratively_down.value_namespace = name_space
                        self.number_xconnects_administratively_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-currently-using-backup"):
                        self.number_xconnects_currently_using_backup = value
                        self.number_xconnects_currently_using_backup.value_namespace = name_space
                        self.number_xconnects_currently_using_backup.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-currently-using-backup-interface"):
                        self.number_xconnects_currently_using_backup_interface = value
                        self.number_xconnects_currently_using_backup_interface.value_namespace = name_space
                        self.number_xconnects_currently_using_backup_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-down"):
                        self.number_xconnects_down = value
                        self.number_xconnects_down.value_namespace = name_space
                        self.number_xconnects_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-locally-switched"):
                        self.number_xconnects_locally_switched = value
                        self.number_xconnects_locally_switched.value_namespace = name_space
                        self.number_xconnects_locally_switched.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-type-attachment-circuit-to-pseudo-wire"):
                        self.number_xconnects_type_attachment_circuit_to_pseudo_wire = value
                        self.number_xconnects_type_attachment_circuit_to_pseudo_wire.value_namespace = name_space
                        self.number_xconnects_type_attachment_circuit_to_pseudo_wire.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-type-monitor-session-to-pseudo-wire"):
                        self.number_xconnects_type_monitor_session_to_pseudo_wire = value
                        self.number_xconnects_type_monitor_session_to_pseudo_wire.value_namespace = name_space
                        self.number_xconnects_type_monitor_session_to_pseudo_wire.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-type-pseudo-wire-to-pseudo-wire"):
                        self.number_xconnects_type_pseudo_wire_to_pseudo_wire = value
                        self.number_xconnects_type_pseudo_wire_to_pseudo_wire.value_namespace = name_space
                        self.number_xconnects_type_pseudo_wire_to_pseudo_wire.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-unresolved"):
                        self.number_xconnects_unresolved = value
                        self.number_xconnects_unresolved.value_namespace = name_space
                        self.number_xconnects_unresolved.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-up"):
                        self.number_xconnects_up = value
                        self.number_xconnects_up.value_namespace = name_space
                        self.number_xconnects_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-with-backup-interface"):
                        self.number_xconnects_with_backup_interface = value
                        self.number_xconnects_with_backup_interface.value_namespace = name_space
                        self.number_xconnects_with_backup_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-xconnects-with-backup-pw"):
                        self.number_xconnects_with_backup_pw = value
                        self.number_xconnects_with_backup_pw.value_namespace = name_space
                        self.number_xconnects_with_backup_pw.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-of-memory-state"):
                        self.out_of_memory_state = value
                        self.out_of_memory_state.value_namespace = name_space
                        self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "partially-programmed-xconnects"):
                        self.partially_programmed_xconnects = value
                        self.partially_programmed_xconnects.value_namespace = name_space
                        self.partially_programmed_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-backup-interface-xconnects"):
                        self.standby_backup_interface_xconnects = value
                        self.standby_backup_interface_xconnects.value_namespace = name_space
                        self.standby_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-backup-xconnects"):
                        self.standby_backup_xconnects = value
                        self.standby_backup_xconnects.value_namespace = name_space
                        self.standby_backup_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-ready-backup-xconnects"):
                        self.standby_ready_backup_xconnects = value
                        self.standby_ready_backup_xconnects.value_namespace = name_space
                        self.standby_ready_backup_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "unresolved-backup-interface-xconnects"):
                        self.unresolved_backup_interface_xconnects = value
                        self.unresolved_backup_interface_xconnects.value_namespace = name_space
                        self.unresolved_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
                    if(value_path == "unresolved-backup-xconnects"):
                        self.unresolved_backup_xconnects = value
                        self.unresolved_backup_xconnects.value_namespace = name_space
                        self.unresolved_backup_xconnects.value_namespace_prefix = name_space_prefix


            class ProcFsm(Entity):
                """
                L2VPN Process FSM information
                
                .. attribute:: event_history
                
                	L2VPN Process event history
                	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.EventHistory>`
                
                .. attribute:: failover_status
                
                	L2VPN failover status
                	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.FailoverStatus>`
                
                .. attribute:: issu_status
                
                	L2VPN ISSU Status and timestamp
                	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus>`
                
                .. attribute:: nsr_status
                
                	L2VPN NSR status and timestamp
                	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus>`
                
                .. attribute:: process_role
                
                	Current Process Role
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_state
                
                	Current Process State
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: report_card
                
                	L2VPN Collaborator report card
                	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.ReportCard>`
                
                .. attribute:: state_transition_time
                
                	Transition time for all states
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: sw_install_in_progress
                
                	Is s/w install currently in progress?
                	**type**\:  bool
                
                .. attribute:: sync_flags
                
                	Sync complete flags
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: xid_info
                
                	XID information
                	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.XidInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.ProcFsm, self).__init__()

                    self.yang_name = "proc-fsm"
                    self.yang_parent_name = "node"

                    self.process_role = YLeaf(YType.uint8, "process-role")

                    self.process_state = YLeaf(YType.uint8, "process-state")

                    self.state_transition_time = YLeafList(YType.uint32, "state-transition-time")

                    self.sw_install_in_progress = YLeaf(YType.boolean, "sw-install-in-progress")

                    self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                    self.failover_status = L2Vpnv2.Nodes.Node.ProcFsm.FailoverStatus()
                    self.failover_status.parent = self
                    self._children_name_map["failover_status"] = "failover-status"
                    self._children_yang_names.add("failover-status")

                    self.issu_status = L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus()
                    self.issu_status.parent = self
                    self._children_name_map["issu_status"] = "issu-status"
                    self._children_yang_names.add("issu-status")

                    self.nsr_status = L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus()
                    self.nsr_status.parent = self
                    self._children_name_map["nsr_status"] = "nsr-status"
                    self._children_yang_names.add("nsr-status")

                    self.event_history = YList(self)
                    self.report_card = YList(self)
                    self.xid_info = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("process_role",
                                    "process_state",
                                    "state_transition_time",
                                    "sw_install_in_progress",
                                    "sync_flags") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.ProcFsm, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.ProcFsm, self).__setattr__(name, value)


                class FailoverStatus(Entity):
                    """
                    L2VPN failover status
                    
                    .. attribute:: master_time
                    
                    	Master time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: start_time
                    
                    	Start time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: triggered_time
                    
                    	Triggered time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.ProcFsm.FailoverStatus, self).__init__()

                        self.yang_name = "failover-status"
                        self.yang_parent_name = "proc-fsm"

                        self.master_time = YLeaf(YType.uint32, "master-time")

                        self.start_time = YLeaf(YType.uint32, "start-time")

                        self.triggered_time = YLeaf(YType.uint32, "triggered-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("master_time",
                                        "start_time",
                                        "triggered_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.ProcFsm.FailoverStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.ProcFsm.FailoverStatus, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.master_time.is_set or
                            self.start_time.is_set or
                            self.triggered_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.master_time.yfilter != YFilter.not_set or
                            self.start_time.yfilter != YFilter.not_set or
                            self.triggered_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "failover-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.master_time.is_set or self.master_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.master_time.get_name_leafdata())
                        if (self.start_time.is_set or self.start_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.start_time.get_name_leafdata())
                        if (self.triggered_time.is_set or self.triggered_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.triggered_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "master-time" or name == "start-time" or name == "triggered-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "master-time"):
                            self.master_time = value
                            self.master_time.value_namespace = name_space
                            self.master_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "start-time"):
                            self.start_time = value
                            self.start_time.value_namespace = name_space
                            self.start_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "triggered-time"):
                            self.triggered_time = value
                            self.triggered_time.value_namespace = name_space
                            self.triggered_time.value_namespace_prefix = name_space_prefix


                class NsrStatus(Entity):
                    """
                    L2VPN NSR status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus, self).__init__()

                        self.yang_name = "nsr-status"
                        self.yang_parent_name = "proc-fsm"

                        self.role = YLeaf(YType.enumeration, "role")

                        self.idt_status = L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                        self._children_yang_names.add("idt-status")

                        self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        self._children_yang_names.add("previ-ous-idt-status")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("role") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus, self).__setattr__(name, value)


                    class IdtStatus(Entity):
                        """
                        IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus, self).__init__()

                            self.yang_name = "idt-status"
                            self.yang_parent_name = "nsr-status"

                            self.declare_time = YLeaf(YType.uint32, "declare-time")

                            self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                            self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                            self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                            self.sync_status = YLeaf(YType.enumeration, "sync-status")

                            self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("declare_time",
                                            "idt_end_time",
                                            "idt_start_time",
                                            "not_ready_reason",
                                            "sync_status",
                                            "withdraw_time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.declare_time.is_set or
                                self.idt_end_time.is_set or
                                self.idt_start_time.is_set or
                                self.not_ready_reason.is_set or
                                self.sync_status.is_set or
                                self.withdraw_time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.declare_time.yfilter != YFilter.not_set or
                                self.idt_end_time.yfilter != YFilter.not_set or
                                self.idt_start_time.yfilter != YFilter.not_set or
                                self.not_ready_reason.yfilter != YFilter.not_set or
                                self.sync_status.yfilter != YFilter.not_set or
                                self.withdraw_time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "idt-status" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.declare_time.get_name_leafdata())
                            if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                            if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                            if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                            if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sync_status.get_name_leafdata())
                            if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "declare-time"):
                                self.declare_time = value
                                self.declare_time.value_namespace = name_space
                                self.declare_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-end-time"):
                                self.idt_end_time = value
                                self.idt_end_time.value_namespace = name_space
                                self.idt_end_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-start-time"):
                                self.idt_start_time = value
                                self.idt_start_time.value_namespace = name_space
                                self.idt_start_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-ready-reason"):
                                self.not_ready_reason = value
                                self.not_ready_reason.value_namespace = name_space
                                self.not_ready_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "sync-status"):
                                self.sync_status = value
                                self.sync_status.value_namespace = name_space
                                self.sync_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "withdraw-time"):
                                self.withdraw_time = value
                                self.withdraw_time.value_namespace = name_space
                                self.withdraw_time.value_namespace_prefix = name_space_prefix


                    class PreviOusIdtStatus(Entity):
                        """
                        Previous IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__init__()

                            self.yang_name = "previ-ous-idt-status"
                            self.yang_parent_name = "nsr-status"

                            self.declare_time = YLeaf(YType.uint32, "declare-time")

                            self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                            self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                            self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                            self.sync_status = YLeaf(YType.enumeration, "sync-status")

                            self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("declare_time",
                                            "idt_end_time",
                                            "idt_start_time",
                                            "not_ready_reason",
                                            "sync_status",
                                            "withdraw_time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.declare_time.is_set or
                                self.idt_end_time.is_set or
                                self.idt_start_time.is_set or
                                self.not_ready_reason.is_set or
                                self.sync_status.is_set or
                                self.withdraw_time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.declare_time.yfilter != YFilter.not_set or
                                self.idt_end_time.yfilter != YFilter.not_set or
                                self.idt_start_time.yfilter != YFilter.not_set or
                                self.not_ready_reason.yfilter != YFilter.not_set or
                                self.sync_status.yfilter != YFilter.not_set or
                                self.withdraw_time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "previ-ous-idt-status" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.declare_time.get_name_leafdata())
                            if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                            if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                            if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                            if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sync_status.get_name_leafdata())
                            if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "declare-time"):
                                self.declare_time = value
                                self.declare_time.value_namespace = name_space
                                self.declare_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-end-time"):
                                self.idt_end_time = value
                                self.idt_end_time.value_namespace = name_space
                                self.idt_end_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-start-time"):
                                self.idt_start_time = value
                                self.idt_start_time.value_namespace = name_space
                                self.idt_start_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-ready-reason"):
                                self.not_ready_reason = value
                                self.not_ready_reason.value_namespace = name_space
                                self.not_ready_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "sync-status"):
                                self.sync_status = value
                                self.sync_status.value_namespace = name_space
                                self.sync_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "withdraw-time"):
                                self.withdraw_time = value
                                self.withdraw_time.value_namespace = name_space
                                self.withdraw_time.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.role.is_set or
                            (self.idt_status is not None and self.idt_status.has_data()) or
                            (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.role.yfilter != YFilter.not_set or
                            (self.idt_status is not None and self.idt_status.has_operation()) or
                            (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "nsr-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.role.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "idt-status"):
                            if (self.idt_status is None):
                                self.idt_status = L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus()
                                self.idt_status.parent = self
                                self._children_name_map["idt_status"] = "idt-status"
                            return self.idt_status

                        if (child_yang_name == "previ-ous-idt-status"):
                            if (self.previ_ous_idt_status is None):
                                self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus()
                                self.previ_ous_idt_status.parent = self
                                self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                            return self.previ_ous_idt_status

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "role"):
                            self.role = value
                            self.role.value_namespace = name_space
                            self.role.value_namespace_prefix = name_space_prefix


                class IssuStatus(Entity):
                    """
                    L2VPN ISSU Status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus, self).__init__()

                        self.yang_name = "issu-status"
                        self.yang_parent_name = "proc-fsm"

                        self.role = YLeaf(YType.enumeration, "role")

                        self.idt_status = L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                        self._children_yang_names.add("idt-status")

                        self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        self._children_yang_names.add("previ-ous-idt-status")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("role") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus, self).__setattr__(name, value)


                    class IdtStatus(Entity):
                        """
                        IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus, self).__init__()

                            self.yang_name = "idt-status"
                            self.yang_parent_name = "issu-status"

                            self.declare_time = YLeaf(YType.uint32, "declare-time")

                            self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                            self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                            self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                            self.sync_status = YLeaf(YType.enumeration, "sync-status")

                            self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("declare_time",
                                            "idt_end_time",
                                            "idt_start_time",
                                            "not_ready_reason",
                                            "sync_status",
                                            "withdraw_time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.declare_time.is_set or
                                self.idt_end_time.is_set or
                                self.idt_start_time.is_set or
                                self.not_ready_reason.is_set or
                                self.sync_status.is_set or
                                self.withdraw_time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.declare_time.yfilter != YFilter.not_set or
                                self.idt_end_time.yfilter != YFilter.not_set or
                                self.idt_start_time.yfilter != YFilter.not_set or
                                self.not_ready_reason.yfilter != YFilter.not_set or
                                self.sync_status.yfilter != YFilter.not_set or
                                self.withdraw_time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "idt-status" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.declare_time.get_name_leafdata())
                            if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                            if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                            if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                            if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sync_status.get_name_leafdata())
                            if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "declare-time"):
                                self.declare_time = value
                                self.declare_time.value_namespace = name_space
                                self.declare_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-end-time"):
                                self.idt_end_time = value
                                self.idt_end_time.value_namespace = name_space
                                self.idt_end_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-start-time"):
                                self.idt_start_time = value
                                self.idt_start_time.value_namespace = name_space
                                self.idt_start_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-ready-reason"):
                                self.not_ready_reason = value
                                self.not_ready_reason.value_namespace = name_space
                                self.not_ready_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "sync-status"):
                                self.sync_status = value
                                self.sync_status.value_namespace = name_space
                                self.sync_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "withdraw-time"):
                                self.withdraw_time = value
                                self.withdraw_time.value_namespace = name_space
                                self.withdraw_time.value_namespace_prefix = name_space_prefix


                    class PreviOusIdtStatus(Entity):
                        """
                        Previous IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__init__()

                            self.yang_name = "previ-ous-idt-status"
                            self.yang_parent_name = "issu-status"

                            self.declare_time = YLeaf(YType.uint32, "declare-time")

                            self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                            self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                            self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                            self.sync_status = YLeaf(YType.enumeration, "sync-status")

                            self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("declare_time",
                                            "idt_end_time",
                                            "idt_start_time",
                                            "not_ready_reason",
                                            "sync_status",
                                            "withdraw_time") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.declare_time.is_set or
                                self.idt_end_time.is_set or
                                self.idt_start_time.is_set or
                                self.not_ready_reason.is_set or
                                self.sync_status.is_set or
                                self.withdraw_time.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.declare_time.yfilter != YFilter.not_set or
                                self.idt_end_time.yfilter != YFilter.not_set or
                                self.idt_start_time.yfilter != YFilter.not_set or
                                self.not_ready_reason.yfilter != YFilter.not_set or
                                self.sync_status.yfilter != YFilter.not_set or
                                self.withdraw_time.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "previ-ous-idt-status" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.declare_time.get_name_leafdata())
                            if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                            if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                            if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                            if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sync_status.get_name_leafdata())
                            if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "declare-time"):
                                self.declare_time = value
                                self.declare_time.value_namespace = name_space
                                self.declare_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-end-time"):
                                self.idt_end_time = value
                                self.idt_end_time.value_namespace = name_space
                                self.idt_end_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "idt-start-time"):
                                self.idt_start_time = value
                                self.idt_start_time.value_namespace = name_space
                                self.idt_start_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-ready-reason"):
                                self.not_ready_reason = value
                                self.not_ready_reason.value_namespace = name_space
                                self.not_ready_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "sync-status"):
                                self.sync_status = value
                                self.sync_status.value_namespace = name_space
                                self.sync_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "withdraw-time"):
                                self.withdraw_time = value
                                self.withdraw_time.value_namespace = name_space
                                self.withdraw_time.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.role.is_set or
                            (self.idt_status is not None and self.idt_status.has_data()) or
                            (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.role.yfilter != YFilter.not_set or
                            (self.idt_status is not None and self.idt_status.has_operation()) or
                            (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "issu-status" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.role.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "idt-status"):
                            if (self.idt_status is None):
                                self.idt_status = L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus()
                                self.idt_status.parent = self
                                self._children_name_map["idt_status"] = "idt-status"
                            return self.idt_status

                        if (child_yang_name == "previ-ous-idt-status"):
                            if (self.previ_ous_idt_status is None):
                                self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus()
                                self.previ_ous_idt_status.parent = self
                                self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                            return self.previ_ous_idt_status

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "role"):
                            self.role = value
                            self.role.value_namespace = name_space
                            self.role.value_namespace_prefix = name_space_prefix


                class XidInfo(Entity):
                    """
                    XID information
                    
                    .. attribute:: app_type
                    
                    	App type
                    	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
                    
                    .. attribute:: sent_ids
                    
                    	Number of XIDs transferred
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.ProcFsm.XidInfo, self).__init__()

                        self.yang_name = "xid-info"
                        self.yang_parent_name = "proc-fsm"

                        self.app_type = YLeaf(YType.enumeration, "app-type")

                        self.sent_ids = YLeaf(YType.uint32, "sent-ids")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("app_type",
                                        "sent_ids") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.ProcFsm.XidInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.ProcFsm.XidInfo, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.app_type.is_set or
                            self.sent_ids.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.app_type.yfilter != YFilter.not_set or
                            self.sent_ids.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "xid-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.app_type.is_set or self.app_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.app_type.get_name_leafdata())
                        if (self.sent_ids.is_set or self.sent_ids.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sent_ids.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "app-type" or name == "sent-ids"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "app-type"):
                            self.app_type = value
                            self.app_type.value_namespace = name_space
                            self.app_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "sent-ids"):
                            self.sent_ids = value
                            self.sent_ids.value_namespace = name_space
                            self.sent_ids.value_namespace_prefix = name_space_prefix


                class ReportCard(Entity):
                    """
                    L2VPN Collaborator report card
                    
                    .. attribute:: collaborator_idt_done
                    
                    	Is IDT done for this collaborator
                    	**type**\:  bool
                    
                    .. attribute:: collaborator_is_connected
                    
                    	Is the collaborator connected
                    	**type**\:  bool
                    
                    .. attribute:: collaborator_skipped
                    
                    	Was this collaborator skipped for not connecting in time
                    	**type**\:  bool
                    
                    .. attribute:: connection_change_time
                    
                    	Time when connection state (UP/DOWN) changed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idt_time
                    
                    	Time when IDT was done
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.ProcFsm.ReportCard, self).__init__()

                        self.yang_name = "report-card"
                        self.yang_parent_name = "proc-fsm"

                        self.collaborator_idt_done = YLeaf(YType.boolean, "collaborator-idt-done")

                        self.collaborator_is_connected = YLeaf(YType.boolean, "collaborator-is-connected")

                        self.collaborator_skipped = YLeaf(YType.boolean, "collaborator-skipped")

                        self.connection_change_time = YLeaf(YType.uint32, "connection-change-time")

                        self.idt_time = YLeaf(YType.uint32, "idt-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("collaborator_idt_done",
                                        "collaborator_is_connected",
                                        "collaborator_skipped",
                                        "connection_change_time",
                                        "idt_time") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.ProcFsm.ReportCard, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.ProcFsm.ReportCard, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.collaborator_idt_done.is_set or
                            self.collaborator_is_connected.is_set or
                            self.collaborator_skipped.is_set or
                            self.connection_change_time.is_set or
                            self.idt_time.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.collaborator_idt_done.yfilter != YFilter.not_set or
                            self.collaborator_is_connected.yfilter != YFilter.not_set or
                            self.collaborator_skipped.yfilter != YFilter.not_set or
                            self.connection_change_time.yfilter != YFilter.not_set or
                            self.idt_time.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "report-card" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.collaborator_idt_done.is_set or self.collaborator_idt_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.collaborator_idt_done.get_name_leafdata())
                        if (self.collaborator_is_connected.is_set or self.collaborator_is_connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.collaborator_is_connected.get_name_leafdata())
                        if (self.collaborator_skipped.is_set or self.collaborator_skipped.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.collaborator_skipped.get_name_leafdata())
                        if (self.connection_change_time.is_set or self.connection_change_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.connection_change_time.get_name_leafdata())
                        if (self.idt_time.is_set or self.idt_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idt_time.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "collaborator-idt-done" or name == "collaborator-is-connected" or name == "collaborator-skipped" or name == "connection-change-time" or name == "idt-time"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "collaborator-idt-done"):
                            self.collaborator_idt_done = value
                            self.collaborator_idt_done.value_namespace = name_space
                            self.collaborator_idt_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "collaborator-is-connected"):
                            self.collaborator_is_connected = value
                            self.collaborator_is_connected.value_namespace = name_space
                            self.collaborator_is_connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "collaborator-skipped"):
                            self.collaborator_skipped = value
                            self.collaborator_skipped.value_namespace = name_space
                            self.collaborator_skipped.value_namespace_prefix = name_space_prefix
                        if(value_path == "connection-change-time"):
                            self.connection_change_time = value
                            self.connection_change_time.value_namespace = name_space
                            self.connection_change_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "idt-time"):
                            self.idt_time = value
                            self.idt_time.value_namespace = name_space
                            self.idt_time.value_namespace_prefix = name_space_prefix


                class EventHistory(Entity):
                    """
                    L2VPN Process event history
                    
                    .. attribute:: event_timestamp
                    
                    	Event timestamp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: new_state
                    
                    	New state
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: previous_state
                    
                    	Previous state
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: process_collaborator
                    
                    	Process collaborator
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: process_event
                    
                    	Process event
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.ProcFsm.EventHistory, self).__init__()

                        self.yang_name = "event-history"
                        self.yang_parent_name = "proc-fsm"

                        self.event_timestamp = YLeaf(YType.uint32, "event-timestamp")

                        self.new_state = YLeaf(YType.uint8, "new-state")

                        self.previous_state = YLeaf(YType.uint8, "previous-state")

                        self.process_collaborator = YLeaf(YType.uint16, "process-collaborator")

                        self.process_event = YLeaf(YType.uint16, "process-event")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("event_timestamp",
                                        "new_state",
                                        "previous_state",
                                        "process_collaborator",
                                        "process_event") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.ProcFsm.EventHistory, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.ProcFsm.EventHistory, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.event_timestamp.is_set or
                            self.new_state.is_set or
                            self.previous_state.is_set or
                            self.process_collaborator.is_set or
                            self.process_event.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.event_timestamp.yfilter != YFilter.not_set or
                            self.new_state.yfilter != YFilter.not_set or
                            self.previous_state.yfilter != YFilter.not_set or
                            self.process_collaborator.yfilter != YFilter.not_set or
                            self.process_event.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "event-history" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.event_timestamp.is_set or self.event_timestamp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.event_timestamp.get_name_leafdata())
                        if (self.new_state.is_set or self.new_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.new_state.get_name_leafdata())
                        if (self.previous_state.is_set or self.previous_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.previous_state.get_name_leafdata())
                        if (self.process_collaborator.is_set or self.process_collaborator.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.process_collaborator.get_name_leafdata())
                        if (self.process_event.is_set or self.process_event.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.process_event.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "event-timestamp" or name == "new-state" or name == "previous-state" or name == "process-collaborator" or name == "process-event"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "event-timestamp"):
                            self.event_timestamp = value
                            self.event_timestamp.value_namespace = name_space
                            self.event_timestamp.value_namespace_prefix = name_space_prefix
                        if(value_path == "new-state"):
                            self.new_state = value
                            self.new_state.value_namespace = name_space
                            self.new_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "previous-state"):
                            self.previous_state = value
                            self.previous_state.value_namespace = name_space
                            self.previous_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "process-collaborator"):
                            self.process_collaborator = value
                            self.process_collaborator.value_namespace = name_space
                            self.process_collaborator.value_namespace_prefix = name_space_prefix
                        if(value_path == "process-event"):
                            self.process_event = value
                            self.process_event.value_namespace = name_space
                            self.process_event.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.event_history:
                        if (c.has_data()):
                            return True
                    for c in self.report_card:
                        if (c.has_data()):
                            return True
                    for c in self.xid_info:
                        if (c.has_data()):
                            return True
                    for leaf in self.state_transition_time.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.process_role.is_set or
                        self.process_state.is_set or
                        self.sw_install_in_progress.is_set or
                        self.sync_flags.is_set or
                        (self.failover_status is not None and self.failover_status.has_data()) or
                        (self.issu_status is not None and self.issu_status.has_data()) or
                        (self.nsr_status is not None and self.nsr_status.has_data()))

                def has_operation(self):
                    for c in self.event_history:
                        if (c.has_operation()):
                            return True
                    for c in self.report_card:
                        if (c.has_operation()):
                            return True
                    for c in self.xid_info:
                        if (c.has_operation()):
                            return True
                    for leaf in self.state_transition_time.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.process_role.yfilter != YFilter.not_set or
                        self.process_state.yfilter != YFilter.not_set or
                        self.state_transition_time.yfilter != YFilter.not_set or
                        self.sw_install_in_progress.yfilter != YFilter.not_set or
                        self.sync_flags.yfilter != YFilter.not_set or
                        (self.failover_status is not None and self.failover_status.has_operation()) or
                        (self.issu_status is not None and self.issu_status.has_operation()) or
                        (self.nsr_status is not None and self.nsr_status.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "proc-fsm" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.process_role.is_set or self.process_role.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_role.get_name_leafdata())
                    if (self.process_state.is_set or self.process_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.process_state.get_name_leafdata())
                    if (self.sw_install_in_progress.is_set or self.sw_install_in_progress.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sw_install_in_progress.get_name_leafdata())
                    if (self.sync_flags.is_set or self.sync_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_flags.get_name_leafdata())

                    leaf_name_data.extend(self.state_transition_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "event-history"):
                        for c in self.event_history:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.ProcFsm.EventHistory()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.event_history.append(c)
                        return c

                    if (child_yang_name == "failover-status"):
                        if (self.failover_status is None):
                            self.failover_status = L2Vpnv2.Nodes.Node.ProcFsm.FailoverStatus()
                            self.failover_status.parent = self
                            self._children_name_map["failover_status"] = "failover-status"
                        return self.failover_status

                    if (child_yang_name == "issu-status"):
                        if (self.issu_status is None):
                            self.issu_status = L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus()
                            self.issu_status.parent = self
                            self._children_name_map["issu_status"] = "issu-status"
                        return self.issu_status

                    if (child_yang_name == "nsr-status"):
                        if (self.nsr_status is None):
                            self.nsr_status = L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus()
                            self.nsr_status.parent = self
                            self._children_name_map["nsr_status"] = "nsr-status"
                        return self.nsr_status

                    if (child_yang_name == "report-card"):
                        for c in self.report_card:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.ProcFsm.ReportCard()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.report_card.append(c)
                        return c

                    if (child_yang_name == "xid-info"):
                        for c in self.xid_info:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.ProcFsm.XidInfo()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.xid_info.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "event-history" or name == "failover-status" or name == "issu-status" or name == "nsr-status" or name == "report-card" or name == "xid-info" or name == "process-role" or name == "process-state" or name == "state-transition-time" or name == "sw-install-in-progress" or name == "sync-flags"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "process-role"):
                        self.process_role = value
                        self.process_role.value_namespace = name_space
                        self.process_role.value_namespace_prefix = name_space_prefix
                    if(value_path == "process-state"):
                        self.process_state = value
                        self.process_state.value_namespace = name_space
                        self.process_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "state-transition-time"):
                        self.state_transition_time.append(value)
                    if(value_path == "sw-install-in-progress"):
                        self.sw_install_in_progress = value
                        self.sw_install_in_progress.value_namespace = name_space
                        self.sw_install_in_progress.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-flags"):
                        self.sync_flags = value
                        self.sync_flags.value_namespace = name_space
                        self.sync_flags.value_namespace_prefix = name_space_prefix


            class MstpPorts(Entity):
                """
                L2VPN MSTP Port Table
                
                .. attribute:: mstp_port
                
                	MSTP Port information
                	**type**\: list of    :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpPorts.MstpPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.MstpPorts, self).__init__()

                    self.yang_name = "mstp-ports"
                    self.yang_parent_name = "node"

                    self.mstp_port = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.MstpPorts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.MstpPorts, self).__setattr__(name, value)


                class MstpPort(Entity):
                    """
                    MSTP Port information
                    
                    .. attribute:: interface  <key>
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: msti_entry
                    
                    	MSTI
                    	**type**\: list of    :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry>`
                    
                    .. attribute:: mstp_interface_handle
                    
                    	Interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: protected
                    
                    	Protected
                    	**type**\:  bool
                    
                    .. attribute:: reference_count
                    
                    	Reference Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.MstpPorts.MstpPort, self).__init__()

                        self.yang_name = "mstp-port"
                        self.yang_parent_name = "mstp-ports"

                        self.interface = YLeaf(YType.str, "interface")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.mstp_interface_handle = YLeaf(YType.str, "mstp-interface-handle")

                        self.protected = YLeaf(YType.boolean, "protected")

                        self.reference_count = YLeaf(YType.uint32, "reference-count")

                        self.msti_entry = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface",
                                        "interface_name",
                                        "mstp_interface_handle",
                                        "protected",
                                        "reference_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.MstpPorts.MstpPort, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.MstpPorts.MstpPort, self).__setattr__(name, value)


                    class MstiEntry(Entity):
                        """
                        MSTI
                        
                        .. attribute:: ack_count
                        
                        	Ack count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bd_count
                        
                        	BD count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bd_entry
                        
                        	BD entries
                        	**type**\: list of    :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                        
                        .. attribute:: cfg_ms_ti
                        
                        	 Configured MSTi
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flush_count
                        
                        	Flush count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_count
                        
                        	Interface count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_flags
                        
                        	Msti Flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_state
                        
                        	Msti State
                        	**type**\:   :py:class:`L2VpnMstiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMstiState>`
                        
                        .. attribute:: nack_count
                        
                        	Nack count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rcv_count
                        
                        	Receive count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry, self).__init__()

                            self.yang_name = "msti-entry"
                            self.yang_parent_name = "mstp-port"

                            self.ack_count = YLeaf(YType.uint32, "ack-count")

                            self.bd_count = YLeaf(YType.uint32, "bd-count")

                            self.cfg_ms_ti = YLeaf(YType.uint32, "cfg-ms-ti")

                            self.flush_count = YLeaf(YType.uint32, "flush-count")

                            self.interface_count = YLeaf(YType.uint32, "interface-count")

                            self.msti_flags = YLeaf(YType.uint32, "msti-flags")

                            self.msti_state = YLeaf(YType.enumeration, "msti-state")

                            self.nack_count = YLeaf(YType.uint32, "nack-count")

                            self.rcv_count = YLeaf(YType.uint32, "rcv-count")

                            self.bd_entry = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ack_count",
                                            "bd_count",
                                            "cfg_ms_ti",
                                            "flush_count",
                                            "interface_count",
                                            "msti_flags",
                                            "msti_state",
                                            "nack_count",
                                            "rcv_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry, self).__setattr__(name, value)


                        class BdEntry(Entity):
                            """
                            BD entries
                            
                            .. attribute:: bdid
                            
                            	BD ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bdif_count
                            
                            	BD Intf Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__init__()

                                self.yang_name = "bd-entry"
                                self.yang_parent_name = "msti-entry"

                                self.bdid = YLeaf(YType.uint32, "bdid")

                                self.bdif_count = YLeaf(YType.uint32, "bdif-count")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bdid",
                                                "bdif_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bdid.is_set or
                                    self.bdif_count.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bdid.yfilter != YFilter.not_set or
                                    self.bdif_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bd-entry" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bdid.is_set or self.bdid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bdid.get_name_leafdata())
                                if (self.bdif_count.is_set or self.bdif_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bdif_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bdid" or name == "bdif-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bdid"):
                                    self.bdid = value
                                    self.bdid.value_namespace = name_space
                                    self.bdid.value_namespace_prefix = name_space_prefix
                                if(value_path == "bdif-count"):
                                    self.bdif_count = value
                                    self.bdif_count.value_namespace = name_space
                                    self.bdif_count.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bd_entry:
                                if (c.has_data()):
                                    return True
                            return (
                                self.ack_count.is_set or
                                self.bd_count.is_set or
                                self.cfg_ms_ti.is_set or
                                self.flush_count.is_set or
                                self.interface_count.is_set or
                                self.msti_flags.is_set or
                                self.msti_state.is_set or
                                self.nack_count.is_set or
                                self.rcv_count.is_set)

                        def has_operation(self):
                            for c in self.bd_entry:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ack_count.yfilter != YFilter.not_set or
                                self.bd_count.yfilter != YFilter.not_set or
                                self.cfg_ms_ti.yfilter != YFilter.not_set or
                                self.flush_count.yfilter != YFilter.not_set or
                                self.interface_count.yfilter != YFilter.not_set or
                                self.msti_flags.yfilter != YFilter.not_set or
                                self.msti_state.yfilter != YFilter.not_set or
                                self.nack_count.yfilter != YFilter.not_set or
                                self.rcv_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "msti-entry" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ack_count.is_set or self.ack_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ack_count.get_name_leafdata())
                            if (self.bd_count.is_set or self.bd_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bd_count.get_name_leafdata())
                            if (self.cfg_ms_ti.is_set or self.cfg_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cfg_ms_ti.get_name_leafdata())
                            if (self.flush_count.is_set or self.flush_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flush_count.get_name_leafdata())
                            if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_count.get_name_leafdata())
                            if (self.msti_flags.is_set or self.msti_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_flags.get_name_leafdata())
                            if (self.msti_state.is_set or self.msti_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_state.get_name_leafdata())
                            if (self.nack_count.is_set or self.nack_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nack_count.get_name_leafdata())
                            if (self.rcv_count.is_set or self.rcv_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rcv_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bd-entry"):
                                for c in self.bd_entry:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bd_entry.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bd-entry" or name == "ack-count" or name == "bd-count" or name == "cfg-ms-ti" or name == "flush-count" or name == "interface-count" or name == "msti-flags" or name == "msti-state" or name == "nack-count" or name == "rcv-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ack-count"):
                                self.ack_count = value
                                self.ack_count.value_namespace = name_space
                                self.ack_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "bd-count"):
                                self.bd_count = value
                                self.bd_count.value_namespace = name_space
                                self.bd_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "cfg-ms-ti"):
                                self.cfg_ms_ti = value
                                self.cfg_ms_ti.value_namespace = name_space
                                self.cfg_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "flush-count"):
                                self.flush_count = value
                                self.flush_count.value_namespace = name_space
                                self.flush_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-count"):
                                self.interface_count = value
                                self.interface_count.value_namespace = name_space
                                self.interface_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-flags"):
                                self.msti_flags = value
                                self.msti_flags.value_namespace = name_space
                                self.msti_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-state"):
                                self.msti_state = value
                                self.msti_state.value_namespace = name_space
                                self.msti_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "nack-count"):
                                self.nack_count = value
                                self.nack_count.value_namespace = name_space
                                self.nack_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "rcv-count"):
                                self.rcv_count = value
                                self.rcv_count.value_namespace = name_space
                                self.rcv_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.msti_entry:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface.is_set or
                            self.interface_name.is_set or
                            self.mstp_interface_handle.is_set or
                            self.protected.is_set or
                            self.reference_count.is_set)

                    def has_operation(self):
                        for c in self.msti_entry:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.mstp_interface_handle.yfilter != YFilter.not_set or
                            self.protected.yfilter != YFilter.not_set or
                            self.reference_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mstp-port" + "[interface='" + self.interface.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.mstp_interface_handle.is_set or self.mstp_interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mstp_interface_handle.get_name_leafdata())
                        if (self.protected.is_set or self.protected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protected.get_name_leafdata())
                        if (self.reference_count.is_set or self.reference_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reference_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "msti-entry"):
                            for c in self.msti_entry:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.msti_entry.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "msti-entry" or name == "interface" or name == "interface-name" or name == "mstp-interface-handle" or name == "protected" or name == "reference-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface"):
                            self.interface = value
                            self.interface.value_namespace = name_space
                            self.interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mstp-interface-handle"):
                            self.mstp_interface_handle = value
                            self.mstp_interface_handle.value_namespace = name_space
                            self.mstp_interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "protected"):
                            self.protected = value
                            self.protected.value_namespace = name_space
                            self.protected.value_namespace_prefix = name_space_prefix
                        if(value_path == "reference-count"):
                            self.reference_count = value
                            self.reference_count.value_namespace = name_space
                            self.reference_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.mstp_port:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.mstp_port:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mstp-ports" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mstp-port"):
                        for c in self.mstp_port:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.MstpPorts.MstpPort()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.mstp_port.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mstp-port"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GenericInterfaceListDetails(Entity):
                """
                L2VPN generic interface list Detail Table
                
                .. attribute:: generic_interface_list_detail
                
                	Generic Interface List detail information
                	**type**\: list of    :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails, self).__init__()

                    self.yang_name = "generic-interface-list-details"
                    self.yang_parent_name = "node"

                    self.generic_interface_list_detail = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails, self).__setattr__(name, value)


                class GenericInterfaceListDetail(Entity):
                    """
                    Generic Interface List detail information
                    
                    .. attribute:: interface_list_name  <key>
                    
                    	Generic Interface List Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
                    
                    .. attribute:: is_provisioned
                    
                    	Is Provisioned
                    	**type**\:  bool
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: psedowire_ether_items
                    
                    	Number PW Ether Items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pseudowire_ether_range
                    
                    	PW\-Ether ranges
                    	**type**\: list of    :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
                    
                    .. attribute:: pseudowire_iw_items
                    
                    	Number PW IW Items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pseudowire_iw_range
                    
                    	PW\-IW ranges
                    	**type**\: list of    :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
                    
                    .. attribute:: summary
                    
                    	Summary information
                    	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__init__()

                        self.yang_name = "generic-interface-list-detail"
                        self.yang_parent_name = "generic-interface-list-details"

                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                        self.is_provisioned = YLeaf(YType.boolean, "is-provisioned")

                        self.items = YLeaf(YType.uint32, "items")

                        self.psedowire_ether_items = YLeaf(YType.uint32, "psedowire-ether-items")

                        self.pseudowire_iw_items = YLeaf(YType.uint32, "pseudowire-iw-items")

                        self.summary = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                        self._children_yang_names.add("summary")

                        self.interface = YList(self)
                        self.pseudowire_ether_range = YList(self)
                        self.pseudowire_iw_range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_list_name",
                                        "is_provisioned",
                                        "items",
                                        "psedowire_ether_items",
                                        "pseudowire_iw_items") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__setattr__(name, value)


                    class Summary(Entity):
                        """
                        Summary information
                        
                        .. attribute:: interface
                        
                        	Interfaces
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                        
                        .. attribute:: interface_list_id
                        
                        	Interface internal ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_list_name_xr
                        
                        	Interface\-list name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: items
                        
                        	Number of items
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_interfaces
                        
                        	Number of interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "generic-interface-list-detail"

                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                            self.interface_list_name_xr = YLeaf(YType.str, "interface-list-name-xr")

                            self.items = YLeaf(YType.uint32, "items")

                            self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                            self.interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_list_id",
                                            "interface_list_name_xr",
                                            "items",
                                            "number_of_interfaces") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interfaces
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            .. attribute:: is_fib_downloaded
                            
                            	Is interface downloaded to FIB
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_replications
                            
                            	Number of replications failed because unsupported
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pending_replications
                            
                            	Number of pending replications
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "summary"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                                self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                                self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "is_fib_downloaded",
                                                "not_supported_replications",
                                                "pending_replications") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.interface_name.is_set or
                                    self.is_fib_downloaded.is_set or
                                    self.not_supported_replications.is_set or
                                    self.pending_replications.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.is_fib_downloaded.yfilter != YFilter.not_set or
                                    self.not_supported_replications.yfilter != YFilter.not_set or
                                    self.pending_replications.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                                if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                                if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pending_replications.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-fib-downloaded"):
                                    self.is_fib_downloaded = value
                                    self.is_fib_downloaded.value_namespace = name_space
                                    self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-supported-replications"):
                                    self.not_supported_replications = value
                                    self.not_supported_replications.value_namespace = name_space
                                    self.not_supported_replications.value_namespace_prefix = name_space_prefix
                                if(value_path == "pending-replications"):
                                    self.pending_replications = value
                                    self.pending_replications.value_namespace = name_space
                                    self.pending_replications.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_list_id.is_set or
                                self.interface_list_name_xr.is_set or
                                self.items.is_set or
                                self.number_of_interfaces.is_set)

                        def has_operation(self):
                            for c in self.interface:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_list_id.yfilter != YFilter.not_set or
                                self.interface_list_name_xr.yfilter != YFilter.not_set or
                                self.items.yfilter != YFilter.not_set or
                                self.number_of_interfaces.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "summary" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                            if (self.interface_list_name_xr.is_set or self.interface_list_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_list_name_xr.get_name_leafdata())
                            if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.items.get_name_leafdata())
                            if (self.number_of_interfaces.is_set or self.number_of_interfaces.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_interfaces.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                for c in self.interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name-xr" or name == "items" or name == "number-of-interfaces"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-list-id"):
                                self.interface_list_id = value
                                self.interface_list_id.value_namespace = name_space
                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-list-name-xr"):
                                self.interface_list_name_xr = value
                                self.interface_list_name_xr.value_namespace = name_space
                                self.interface_list_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "items"):
                                self.items = value
                                self.items.value_namespace = name_space
                                self.items.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-interfaces"):
                                self.number_of_interfaces = value
                                self.number_of_interfaces.value_namespace = name_space
                                self.number_of_interfaces.value_namespace_prefix = name_space_prefix


                    class Interface(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "generic-interface-list-detail"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                            self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                            self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "is_fib_downloaded",
                                            "not_supported_replications",
                                            "pending_replications") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.is_fib_downloaded.is_set or
                                self.not_supported_replications.is_set or
                                self.pending_replications.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_fib_downloaded.yfilter != YFilter.not_set or
                                self.not_supported_replications.yfilter != YFilter.not_set or
                                self.pending_replications.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                            if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                            if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pending_replications.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-fib-downloaded"):
                                self.is_fib_downloaded = value
                                self.is_fib_downloaded.value_namespace = name_space
                                self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-replications"):
                                self.not_supported_replications = value
                                self.not_supported_replications.value_namespace = name_space
                                self.not_supported_replications.value_namespace_prefix = name_space_prefix
                            if(value_path == "pending-replications"):
                                self.pending_replications = value
                                self.pending_replications.value_namespace = name_space
                                self.pending_replications.value_namespace_prefix = name_space_prefix


                    class PseudowireEtherRange(Entity):
                        """
                        PW\-Ether ranges
                        
                        .. attribute:: lower
                        
                        	lower range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: upper
                        
                        	upper range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__init__()

                            self.yang_name = "pseudowire-ether-range"
                            self.yang_parent_name = "generic-interface-list-detail"

                            self.lower = YLeaf(YType.uint16, "lower")

                            self.upper = YLeaf(YType.uint16, "upper")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("lower",
                                            "upper") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.lower.is_set or
                                self.upper.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.lower.yfilter != YFilter.not_set or
                                self.upper.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudowire-ether-range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lower.get_name_leafdata())
                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.upper.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "lower" or name == "upper"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "lower"):
                                self.lower = value
                                self.lower.value_namespace = name_space
                                self.lower.value_namespace_prefix = name_space_prefix
                            if(value_path == "upper"):
                                self.upper = value
                                self.upper.value_namespace = name_space
                                self.upper.value_namespace_prefix = name_space_prefix


                    class PseudowireIwRange(Entity):
                        """
                        PW\-IW ranges
                        
                        .. attribute:: lower
                        
                        	lower range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: upper
                        
                        	upper range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__init__()

                            self.yang_name = "pseudowire-iw-range"
                            self.yang_parent_name = "generic-interface-list-detail"

                            self.lower = YLeaf(YType.uint16, "lower")

                            self.upper = YLeaf(YType.uint16, "upper")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("lower",
                                            "upper") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.lower.is_set or
                                self.upper.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.lower.yfilter != YFilter.not_set or
                                self.upper.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudowire-iw-range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lower.get_name_leafdata())
                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.upper.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "lower" or name == "upper"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "lower"):
                                self.lower = value
                                self.lower.value_namespace = name_space
                                self.lower.value_namespace_prefix = name_space_prefix
                            if(value_path == "upper"):
                                self.upper = value
                                self.upper.value_namespace = name_space
                                self.upper.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        for c in self.pseudowire_ether_range:
                            if (c.has_data()):
                                return True
                        for c in self.pseudowire_iw_range:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_list_name.is_set or
                            self.is_provisioned.is_set or
                            self.items.is_set or
                            self.psedowire_ether_items.is_set or
                            self.pseudowire_iw_items.is_set or
                            (self.summary is not None and self.summary.has_data()))

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        for c in self.pseudowire_ether_range:
                            if (c.has_operation()):
                                return True
                        for c in self.pseudowire_iw_range:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_list_name.yfilter != YFilter.not_set or
                            self.is_provisioned.yfilter != YFilter.not_set or
                            self.items.yfilter != YFilter.not_set or
                            self.psedowire_ether_items.yfilter != YFilter.not_set or
                            self.pseudowire_iw_items.yfilter != YFilter.not_set or
                            (self.summary is not None and self.summary.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-interface-list-detail" + "[interface-list-name='" + self.interface_list_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                        if (self.is_provisioned.is_set or self.is_provisioned.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_provisioned.get_name_leafdata())
                        if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.items.get_name_leafdata())
                        if (self.psedowire_ether_items.is_set or self.psedowire_ether_items.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.psedowire_ether_items.get_name_leafdata())
                        if (self.pseudowire_iw_items.is_set or self.pseudowire_iw_items.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudowire_iw_items.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        if (child_yang_name == "pseudowire-ether-range"):
                            for c in self.pseudowire_ether_range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.pseudowire_ether_range.append(c)
                            return c

                        if (child_yang_name == "pseudowire-iw-range"):
                            for c in self.pseudowire_iw_range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.pseudowire_iw_range.append(c)
                            return c

                        if (child_yang_name == "summary"):
                            if (self.summary is None):
                                self.summary = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                                self.summary.parent = self
                                self._children_name_map["summary"] = "summary"
                            return self.summary

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "pseudowire-ether-range" or name == "pseudowire-iw-range" or name == "summary" or name == "interface-list-name" or name == "is-provisioned" or name == "items" or name == "psedowire-ether-items" or name == "pseudowire-iw-items"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-list-name"):
                            self.interface_list_name = value
                            self.interface_list_name.value_namespace = name_space
                            self.interface_list_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-provisioned"):
                            self.is_provisioned = value
                            self.is_provisioned.value_namespace = name_space
                            self.is_provisioned.value_namespace_prefix = name_space_prefix
                        if(value_path == "items"):
                            self.items = value
                            self.items.value_namespace = name_space
                            self.items.value_namespace_prefix = name_space_prefix
                        if(value_path == "psedowire-ether-items"):
                            self.psedowire_ether_items = value
                            self.psedowire_ether_items.value_namespace = name_space
                            self.psedowire_ether_items.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudowire-iw-items"):
                            self.pseudowire_iw_items = value
                            self.pseudowire_iw_items.value_namespace = name_space
                            self.pseudowire_iw_items.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.generic_interface_list_detail:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.generic_interface_list_detail:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-interface-list-details" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "generic-interface-list-detail"):
                        for c in self.generic_interface_list_detail:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.generic_interface_list_detail.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "generic-interface-list-detail"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2VpnResourceState(Entity):
                """
                L2VPN resource state information
                
                .. attribute:: resource_out_of_memory_state
                
                	L2VPN Out of memory state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.L2VpnResourceState, self).__init__()

                    self.yang_name = "l2vpn-resource-state"
                    self.yang_parent_name = "node"

                    self.resource_out_of_memory_state = YLeaf(YType.uint32, "resource-out-of-memory-state")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("resource_out_of_memory_state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.L2VpnResourceState, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.L2VpnResourceState, self).__setattr__(name, value)

                def has_data(self):
                    return self.resource_out_of_memory_state.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.resource_out_of_memory_state.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2vpn-resource-state" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.resource_out_of_memory_state.is_set or self.resource_out_of_memory_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.resource_out_of_memory_state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "resource-out-of-memory-state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "resource-out-of-memory-state"):
                        self.resource_out_of_memory_state = value
                        self.resource_out_of_memory_state.value_namespace = name_space
                        self.resource_out_of_memory_state.value_namespace_prefix = name_space_prefix


            class BridgeDomains(Entity):
                """
                VPLS Bridge Domain Information
                
                .. attribute:: bridge_domain
                
                	VPLS Bridge Domain Information
                	**type**\: list of    :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.BridgeDomains, self).__init__()

                    self.yang_name = "bridge-domains"
                    self.yang_parent_name = "node"

                    self.bridge_domain = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.BridgeDomains, self).__setattr__(name, value)


                class BridgeDomain(Entity):
                    """
                    VPLS Bridge Domain Information
                    
                    .. attribute:: bridge_access_pws
                    
                    	VPLS Bridge Domain Access Pseudowire Table
                    	**type**\:   :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws>`
                    
                    .. attribute:: bridge_access_vfi_table
                    
                    	Bridge Domain Access VFI Table
                    	**type**\:   :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
                    
                    .. attribute:: bridge_acs
                    
                    	VPLS Bridge Domain Attachment Circuit Table
                    	**type**\:   :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs>`
                    
                    .. attribute:: bridge_core_vfi_table
                    
                    	Bridge Domain Core VFI Table
                    	**type**\:   :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
                    
                    .. attribute:: bridge_domain_group_name
                    
                    	Bridge Domain Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bridge_domain_info
                    
                    	VPLS Bridge Domain Information
                    	**type**\:   :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..27
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain, self).__init__()

                        self.yang_name = "bridge-domain"
                        self.yang_parent_name = "bridge-domains"

                        self.bridge_domain_group_name = YLeaf(YType.str, "bridge-domain-group-name")

                        self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                        self.bridge_access_pws = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws()
                        self.bridge_access_pws.parent = self
                        self._children_name_map["bridge_access_pws"] = "bridge-access-pws"
                        self._children_yang_names.add("bridge-access-pws")

                        self.bridge_access_vfi_table = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                        self.bridge_access_vfi_table.parent = self
                        self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"
                        self._children_yang_names.add("bridge-access-vfi-table")

                        self.bridge_acs = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs()
                        self.bridge_acs.parent = self
                        self._children_name_map["bridge_acs"] = "bridge-acs"
                        self._children_yang_names.add("bridge-acs")

                        self.bridge_core_vfi_table = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                        self.bridge_core_vfi_table.parent = self
                        self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"
                        self._children_yang_names.add("bridge-core-vfi-table")

                        self.bridge_domain_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                        self.bridge_domain_info.parent = self
                        self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                        self._children_yang_names.add("bridge-domain-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bridge_domain_group_name",
                                        "bridge_domain_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain, self).__setattr__(name, value)


                    class BridgeAccessVfiTable(Entity):
                        """
                        Bridge Domain Access VFI Table
                        
                        .. attribute:: bridge_pws
                        
                        	Bridge Domain Access/Core Pseudowire Table
                        	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable, self).__init__()

                            self.yang_name = "bridge-access-vfi-table"
                            self.yang_parent_name = "bridge-domain"

                            self.bridge_pws = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                            self.bridge_pws.parent = self
                            self._children_name_map["bridge_pws"] = "bridge-pws"
                            self._children_yang_names.add("bridge-pws")


                        class BridgePws(Entity):
                            """
                            Bridge Domain Access/Core Pseudowire Table
                            
                            .. attribute:: bridge_pw
                            
                            	VPLS Bridge Domain Pseudowire
                            	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__init__()

                                self.yang_name = "bridge-pws"
                                self.yang_parent_name = "bridge-access-vfi-table"

                                self.bridge_pw = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__setattr__(name, value)


                            class BridgePw(Entity):
                                """
                                VPLS Bridge Domain Pseudowire
                                
                                .. attribute:: is_access
                                
                                	Is Access PW
                                	**type**\:  bool
                                
                                .. attribute:: neighbor
                                
                                	Neighbor IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire
                                	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                                
                                .. attribute:: pseudowire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_type
                                
                                	PW Type
                                	**type**\:   :py:class:`L2Vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnpw>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                                
                                .. attribute:: static_mac
                                
                                	Static MAC addresses
                                	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                                
                                .. attribute:: ve_id_vpls_id_0_3
                                
                                	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vpls_id_4_7
                                
                                	Zero or Last 4 bytes of VPLS\-ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__init__()

                                    self.yang_name = "bridge-pw"
                                    self.yang_parent_name = "bridge-pws"

                                    self.is_access = YLeaf(YType.boolean, "is-access")

                                    self.neighbor = YLeaf(YType.str, "neighbor")

                                    self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                                    self.pw_type = YLeaf(YType.enumeration, "pw-type")

                                    self.ve_id_vpls_id_0_3 = YLeaf(YType.uint32, "ve-id-vpls-id-0-3")

                                    self.vpls_id_4_7 = YLeaf(YType.uint32, "vpls-id-4-7")

                                    self.pseudowire = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                    self.pseudowire.parent = self
                                    self._children_name_map["pseudowire"] = "pseudowire"
                                    self._children_yang_names.add("pseudowire")

                                    self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                    self._children_yang_names.add("security-parameters")

                                    self.static_mac = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_access",
                                                    "neighbor",
                                                    "pseudowire_id",
                                                    "pw_type",
                                                    "ve_id_vpls_id_0_3",
                                                    "vpls_id_4_7") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)


                                class Pseudowire(Entity):
                                    """
                                    Pseudowire
                                    
                                    .. attribute:: ad_method
                                    
                                    	Autodiscovery method
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ad_remote_down
                                    
                                    	Auto\-Discovered PW remote state down
                                    	**type**\:  bool
                                    
                                    .. attribute:: admited_bw
                                    
                                    	Admited Bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: auto_discovery
                                    
                                    	Is autodiscovery
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_active
                                    
                                    	TRUE if backup is active
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_force_active
                                    
                                    	TRUE if backup is active due to switchover
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_pw
                                    
                                    	TRUE if PW is a backup PW
                                    	**type**\:  bool
                                    
                                    .. attribute:: bitrate_mismatched
                                    
                                    	Bitrate mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: bridge_pw_type_mismatch
                                    
                                    	Oper down because Bridge has mismatched PW Types
                                    	**type**\:  bool
                                    
                                    .. attribute:: cas_mismatched
                                    
                                    	CAS mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: diff_ts_mismatched
                                    
                                    	Differential timestamp mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_delay
                                    
                                    	Backup disable delay
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: disable_never
                                    
                                    	TRUE if backup is not automatically disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_info
                                    
                                    	Encapsulation specific pseudowire information
                                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                    
                                    .. attribute:: evpn_src_acid
                                    
                                    	EVPN VPWS Source AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fe_ctype
                                    
                                    	Pseudowire FEC type
                                    	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                                    
                                    .. attribute:: forward_class
                                    
                                    	Forward Class attribute
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: freq_mismatched
                                    
                                    	Frequency mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: illegal_control_word
                                    
                                    	Illegal control word
                                    	**type**\:  bool
                                    
                                    .. attribute:: imposed_vlan_id
                                    
                                    	Imposed vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interworking
                                    
                                    	Interworking type
                                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                                    
                                    .. attribute:: ipv6_local_source_address
                                    
                                    	Local IPv6 Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_evpnvpws_type
                                    
                                    	is EVPN VPWS
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_flow_label_static
                                    
                                    	is flow label static
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_multi_segment_pseudowire
                                    
                                    	Is Multi\-Segment Pseudowire
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_partially_programmed
                                    
                                    	Is Pseudowire partially programmed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pwr_type
                                    
                                    	is Pseudowire\-routed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vfi
                                    
                                    	Is VFI interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_time_status_changed
                                    
                                    	Last time the pseudowire status changed
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: last_time_status_down
                                    
                                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: ldp_label_advertise_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: load_balance
                                    
                                    	Load Balance Type
                                    	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                                    
                                    .. attribute:: local_control_word
                                    
                                    	Local control word
                                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                    
                                    .. attribute:: local_interface
                                    
                                    	Local interface
                                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                    
                                    .. attribute:: local_label_failed
                                    
                                    	Failed to set BGP advertised local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_pseudo_wire_type
                                    
                                    	Local pseudowire type
                                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                    
                                    .. attribute:: local_signalling
                                    
                                    	Local signalling
                                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                    
                                    .. attribute:: local_source_address
                                    
                                    	Local Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mac_limit_oper_down
                                    
                                    	Oper down because MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mtu_mismatched
                                    
                                    	MTU mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: not_supported_qinq
                                    
                                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                    	**type**\:  bool
                                    
                                    .. attribute:: num_ma_cwithdraw_msg_received
                                    
                                    	Num MW messages received over PW
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_ma_cwithdraw_message_sent
                                    
                                    	Num MW messages sent over PW
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: out_of_memory_state
                                    
                                    	L2VPN Out of memory state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: p2mp_pw
                                    
                                    	P2MP Pseudowire Information
                                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                    
                                    .. attribute:: payload_bytes_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: payload_type_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer
                                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                    
                                    .. attribute:: preferred_path
                                    
                                    	MPLS Preferred Path
                                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                    
                                    .. attribute:: preferred_path_disable_fallback
                                    
                                    	Prefpath fallback enable/disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_peer_id
                                    
                                    	Primary Peer IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary_pseudo_wire_id
                                    
                                    	Primary Pseudowire ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: primary_pw
                                    
                                    	TRUE if PW is a primary PW
                                    	**type**\:  bool
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol
                                    	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                                    
                                    .. attribute:: pseudo_wire_id
                                    
                                    	Pseudowire ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: pseudo_wire_state
                                    
                                    	Pseudowire state
                                    	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                                    
                                    .. attribute:: pseudo_wire_type_mismatched
                                    
                                    	Pseudowire type mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_class_name
                                    
                                    	Pseudowire class name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: pw_flow_label_code17_disabled
                                    
                                    	Disable sending Code 17 TLV
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_flow_label_type
                                    
                                    	Negotiated pseudowire flow label type
                                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                    
                                    .. attribute:: pw_flow_label_type_cfg
                                    
                                    	Configured pseudowire flow label Type
                                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                    
                                    .. attribute:: pw_redundancy_initial_delay
                                    
                                    	Initial delay for redundant PW in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: pw_redundancy_one_way
                                    
                                    	Force one\-way PW redundancy behaviour in Redundancy Group
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_status_use
                                    
                                    	PW status in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: pwlsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_control_word
                                    
                                    	Remote control word
                                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                    
                                    .. attribute:: remote_interface
                                    
                                    	Remote interface
                                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                    
                                    .. attribute:: remote_label_failed
                                    
                                    	Failed to set BGP advertised remote label
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_pseudo_wire_type
                                    
                                    	Remote pseudowire type
                                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                    
                                    .. attribute:: remote_signalling
                                    
                                    	Remote signalling
                                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                    
                                    .. attribute:: required_bw
                                    
                                    	Required Bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: resync_enabled
                                    
                                    	Resync if packets out of sequence
                                    	**type**\:  bool
                                    
                                    .. attribute:: resync_threshold
                                    
                                    	Number of Packets Out of Seqence to trigger resync
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rtp_mismatched
                                    
                                    	RTP mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: sequencing_type
                                    
                                    	Sequencing Type
                                    	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown
                                    	**type**\:  bool
                                    
                                    .. attribute:: sig_pkts_mismatched
                                    
                                    	Signalling packets mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: ssrc_mismatched
                                    
                                    	SSRC mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                                    
                                    .. attribute:: statistics
                                    
                                    	Statistics
                                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                    
                                    .. attribute:: table_policy_name
                                    
                                    	Table\-policy Name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag_rewrite
                                    
                                    	StaticTagRewrite
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: time_created
                                    
                                    	Time when the pseudowire was created
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_creation
                                    
                                    	Time elapsed since creation
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_changed
                                    
                                    	Time elapsed since status changed
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_down
                                    
                                    	Time elapsed since last status down in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: transport_lsp_down
                                    
                                    	Oper down due to Transport LSP down
                                    	**type**\:  bool
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	XConnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                        self.yang_name = "pseudowire"
                                        self.yang_parent_name = "bridge-pw"

                                        self.ad_method = YLeaf(YType.uint32, "ad-method")

                                        self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                        self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                        self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                        self.backup_active = YLeaf(YType.boolean, "backup-active")

                                        self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                        self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                        self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                        self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                        self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                        self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                        self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                        self.disable_never = YLeaf(YType.boolean, "disable-never")

                                        self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                        self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                        self.forward_class = YLeaf(YType.uint8, "forward-class")

                                        self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                        self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                        self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                        self.interworking = YLeaf(YType.enumeration, "interworking")

                                        self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                        self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                        self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                        self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                        self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                        self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                        self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                        self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                        self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                        self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                        self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                        self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                        self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                        self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                        self.local_source_address = YLeaf(YType.str, "local-source-address")

                                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                        self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                        self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                        self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                        self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                        self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                        self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                        self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                        self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                        self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                        self.protocol = YLeaf(YType.enumeration, "protocol")

                                        self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                        self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                        self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                        self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                        self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                        self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                        self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                        self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                        self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                        self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                        self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                        self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                        self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                        self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                        self.required_bw = YLeaf(YType.uint32, "required-bw")

                                        self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                        self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                        self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                        self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                                        self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                        self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                        self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                        self.time_created = YLeaf(YType.str, "time-created")

                                        self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                        self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                        self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                        self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.encapsulation_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                        self._children_yang_names.add("encapsulation-info")

                                        self.local_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                        self._children_yang_names.add("local-interface")

                                        self.local_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                        self._children_yang_names.add("local-signalling")

                                        self.p2mp_pw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                        self._children_yang_names.add("p2mp-pw")

                                        self.peer_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                        self._children_yang_names.add("peer-id")

                                        self.preferred_path = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                        self._children_yang_names.add("preferred-path")

                                        self.remote_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                        self._children_yang_names.add("remote-interface")

                                        self.remote_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                        self._children_yang_names.add("remote-signalling")

                                        self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                        self._children_yang_names.add("statistics")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ad_method",
                                                        "ad_remote_down",
                                                        "admited_bw",
                                                        "auto_discovery",
                                                        "backup_active",
                                                        "backup_force_active",
                                                        "backup_pw",
                                                        "bitrate_mismatched",
                                                        "bridge_pw_type_mismatch",
                                                        "cas_mismatched",
                                                        "diff_ts_mismatched",
                                                        "disable_delay",
                                                        "disable_never",
                                                        "evpn_src_acid",
                                                        "fe_ctype",
                                                        "forward_class",
                                                        "freq_mismatched",
                                                        "illegal_control_word",
                                                        "imposed_vlan_id",
                                                        "interworking",
                                                        "ipv6_local_source_address",
                                                        "is_evpnvpws_type",
                                                        "is_flow_label_static",
                                                        "is_multi_segment_pseudowire",
                                                        "is_partially_programmed",
                                                        "is_pwr_type",
                                                        "is_vfi",
                                                        "last_time_status_changed",
                                                        "last_time_status_down",
                                                        "ldp_label_advertise_failed",
                                                        "load_balance",
                                                        "local_control_word",
                                                        "local_label_failed",
                                                        "local_pseudo_wire_type",
                                                        "local_source_address",
                                                        "mac_limit_oper_down",
                                                        "mtu_mismatched",
                                                        "not_supported_qinq",
                                                        "num_ma_cwithdraw_msg_received",
                                                        "number_ma_cwithdraw_message_sent",
                                                        "out_of_memory_state",
                                                        "payload_bytes_mismatched",
                                                        "payload_type_mismatched",
                                                        "preferred_path_disable_fallback",
                                                        "primary_peer_id",
                                                        "primary_pseudo_wire_id",
                                                        "primary_pw",
                                                        "protocol",
                                                        "pseudo_wire_id",
                                                        "pseudo_wire_state",
                                                        "pseudo_wire_type_mismatched",
                                                        "pw_class_name",
                                                        "pw_flow_label_code17_disabled",
                                                        "pw_flow_label_type",
                                                        "pw_flow_label_type_cfg",
                                                        "pw_redundancy_initial_delay",
                                                        "pw_redundancy_one_way",
                                                        "pw_status_use",
                                                        "pwlsd_rewrite_failed",
                                                        "remote_control_word",
                                                        "remote_label_failed",
                                                        "remote_pseudo_wire_type",
                                                        "required_bw",
                                                        "resync_enabled",
                                                        "resync_threshold",
                                                        "rtp_mismatched",
                                                        "sequencing_type",
                                                        "shutdown",
                                                        "sig_pkts_mismatched",
                                                        "ssrc_mismatched",
                                                        "state",
                                                        "table_policy_name",
                                                        "tag_rewrite",
                                                        "time_created",
                                                        "time_elapsed_creation",
                                                        "time_elapsed_status_changed",
                                                        "time_elapsed_status_down",
                                                        "transport_lsp_down",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)


                                    class PeerId(Entity):
                                        """
                                        Peer
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ipv4_peer_id
                                        
                                        	Peer IPv4 address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_peer_id
                                        
                                        	Peer IPv6 address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: type
                                        
                                        	type
                                        	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                            self.yang_name = "peer-id"
                                            self.yang_parent_name = "pseudowire"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                            self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                            self.type = YLeaf(YType.enumeration, "type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "ipv4_peer_id",
                                                            "ipv6_peer_id",
                                                            "type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.ipv4_peer_id.is_set or
                                                self.ipv6_peer_id.is_set or
                                                self.type.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.ipv4_peer_id.yfilter != YFilter.not_set or
                                                self.ipv6_peer_id.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "peer-id" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                            if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-peer-id"):
                                                self.ipv4_peer_id = value
                                                self.ipv4_peer_id.value_namespace = name_space
                                                self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-peer-id"):
                                                self.ipv6_peer_id = value
                                                self.ipv6_peer_id.value_namespace = name_space
                                                self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix


                                    class EncapsulationInfo(Entity):
                                        """
                                        Encapsulation specific pseudowire information
                                        
                                        .. attribute:: atom
                                        
                                        	atom
                                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                        
                                        .. attribute:: encapsulation
                                        
                                        	Encapsulation
                                        	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                        
                                        .. attribute:: l2tpv3
                                        
                                        	l2tpv3
                                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                            self.yang_name = "encapsulation-info"
                                            self.yang_parent_name = "pseudowire"

                                            self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                            self.atom = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                            self._children_yang_names.add("atom")

                                            self.l2tpv3 = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                            self._children_yang_names.add("l2tpv3")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                        class Atom(Entity):
                                            """
                                            atom
                                            
                                            .. attribute:: is_pseudowire_headend
                                            
                                            	Is this connected to a PW\-HE AC
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_sai_itype2
                                            
                                            	Is SAII FEC129 Type 2
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tai_itype2
                                            
                                            	Is TAII type 2
                                            	**type**\:  bool
                                            
                                            .. attribute:: ldp_label_advertisment_failed
                                            
                                            	LDP label advertisment failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_agi
                                            
                                            	Local Attachment Group Identifier
                                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                            
                                            .. attribute:: local_c_ctype
                                            
                                            	Local VCCV CC type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_ceid
                                            
                                            	Local CE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cv_type
                                            
                                            	Local VCCV CV type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_group_id
                                            
                                            	Local group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_ldp_id
                                            
                                            	Local LDP ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: local_saii_gbl_id
                                            
                                            	Local SAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_saiiac_id
                                            
                                            	Local SAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_taii_gbl_id
                                            
                                            	Local TAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_taiiac_id
                                            
                                            	Local TAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_veid
                                            
                                            	Local VE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsd_rewrite_failed
                                            
                                            	LSD rewrite failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: multi_segment_pseudowire_stats
                                            
                                            	Multisegment pseudowire statistics
                                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                            
                                            .. attribute:: rem_saii
                                            
                                            	Remote Source Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rem_saii_gbl_id
                                            
                                            	Remote SAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_saiiac_id
                                            
                                            	Remote SAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taii
                                            
                                            	Remote Target Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rem_taii_gbl_id
                                            
                                            	Remote TAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taiiac_id
                                            
                                            	Remote TAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_agi
                                            
                                            	Remote Attachment Group Identifier
                                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                            
                                            .. attribute:: remote_c_ctype
                                            
                                            	Remote VCCV CC type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_ceid
                                            
                                            	Remote CE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cv_type
                                            
                                            	Remote VCCV CV type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_group_id
                                            
                                            	Remote group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_label
                                            
                                            	Remote label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_ldp_id
                                            
                                            	Remote LDP ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_source_address
                                            
                                            	Remote BGP source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_veid
                                            
                                            	Remote VE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: saii
                                            
                                            	Source Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_address
                                            
                                            	Local BGP source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: taii
                                            
                                            	Target Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                                self.yang_name = "atom"
                                                self.yang_parent_name = "encapsulation-info"

                                                self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                                self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                                self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                                self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                                self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                                self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                                self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                                self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                                self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                                self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                                self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                                self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                                self.local_veid = YLeaf(YType.uint32, "local-veid")

                                                self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                                self.rem_saii = YLeaf(YType.str, "rem-saii")

                                                self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                                self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                                self.rem_taii = YLeaf(YType.str, "rem-taii")

                                                self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                                self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                                self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                                self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                                self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                                self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                                self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                                self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                                self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                                self.saii = YLeaf(YType.str, "saii")

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.taii = YLeaf(YType.str, "taii")

                                                self.local_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                                self._children_yang_names.add("local-agi")

                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                self._children_yang_names.add("multi-segment-pseudowire-stats")

                                                self.remote_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                                self._children_yang_names.add("remote-agi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("is_pseudowire_headend",
                                                                "is_sai_itype2",
                                                                "is_tai_itype2",
                                                                "ldp_label_advertisment_failed",
                                                                "local_c_ctype",
                                                                "local_ceid",
                                                                "local_cv_type",
                                                                "local_group_id",
                                                                "local_label",
                                                                "local_ldp_id",
                                                                "local_saii_gbl_id",
                                                                "local_saiiac_id",
                                                                "local_taii_gbl_id",
                                                                "local_taiiac_id",
                                                                "local_veid",
                                                                "lsd_rewrite_failed",
                                                                "rem_saii",
                                                                "rem_saii_gbl_id",
                                                                "rem_saiiac_id",
                                                                "rem_taii",
                                                                "rem_taii_gbl_id",
                                                                "rem_taiiac_id",
                                                                "remote_c_ctype",
                                                                "remote_ceid",
                                                                "remote_cv_type",
                                                                "remote_group_id",
                                                                "remote_label",
                                                                "remote_ldp_id",
                                                                "remote_source_address",
                                                                "remote_veid",
                                                                "saii",
                                                                "source_address",
                                                                "taii") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                            class LocalAgi(Entity):
                                                """
                                                Local Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                    self.yang_name = "local-agi"
                                                    self.yang_parent_name = "atom"

                                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                    self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                    self._children_yang_names.add("auto")

                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    self._children_yang_names.add("two-byte-as")

                                                    self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                    self._children_yang_names.add("v4-addr")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("vpls_id_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                                class Auto(Entity):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                        self.yang_name = "auto"
                                                        self.yang_parent_name = "local-agi"

                                                        self.asn = YLeaf(YType.uint16, "asn")

                                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("asn",
                                                                        "vpn_id") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.asn.is_set or
                                                            self.vpn_id.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.asn.yfilter != YFilter.not_set or
                                                            self.vpn_id.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "auto" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "asn" or name == "vpn-id"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "asn"):
                                                            self.asn = value
                                                            self.asn.value_namespace = name_space
                                                            self.asn.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vpn-id"):
                                                            self.vpn_id = value
                                                            self.vpn_id.value_namespace = name_space
                                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                                class TwoByteAs(Entity):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                        self.yang_name = "two-byte-as"
                                                        self.yang_parent_name = "local-agi"

                                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("four_byte_index",
                                                                        "two_byte_as") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.four_byte_index.is_set or
                                                            self.two_byte_as.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.four_byte_index.yfilter != YFilter.not_set or
                                                            self.two_byte_as.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "two-byte-as" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "four-byte-index"):
                                                            self.four_byte_index = value
                                                            self.four_byte_index.value_namespace = name_space
                                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "two-byte-as"):
                                                            self.two_byte_as = value
                                                            self.two_byte_as.value_namespace = name_space
                                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                                class V4Addr(Entity):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                        self.yang_name = "v4-addr"
                                                        self.yang_parent_name = "local-agi"

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("ipv4_address",
                                                                        "two_byte_index") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.ipv4_address.is_set or
                                                            self.two_byte_index.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.ipv4_address.yfilter != YFilter.not_set or
                                                            self.two_byte_index.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "v4-addr" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "ipv4-address"):
                                                            self.ipv4_address = value
                                                            self.ipv4_address.value_namespace = name_space
                                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "two-byte-index"):
                                                            self.two_byte_index = value
                                                            self.two_byte_index.value_namespace = name_space
                                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.vpls_id_type.is_set or
                                                        (self.auto is not None and self.auto.has_data()) or
                                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                                        (self.auto is not None and self.auto.has_operation()) or
                                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "local-agi" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "auto"):
                                                        if (self.auto is None):
                                                            self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                            self.auto.parent = self
                                                            self._children_name_map["auto"] = "auto"
                                                        return self.auto

                                                    if (child_yang_name == "two-byte-as"):
                                                        if (self.two_byte_as is None):
                                                            self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                            self.two_byte_as.parent = self
                                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                                        return self.two_byte_as

                                                    if (child_yang_name == "v4-addr"):
                                                        if (self.v4_addr is None):
                                                            self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                            self.v4_addr.parent = self
                                                            self._children_name_map["v4_addr"] = "v4-addr"
                                                        return self.v4_addr

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "vpls-id-type"):
                                                        self.vpls_id_type = value
                                                        self.vpls_id_type.value_namespace = name_space
                                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                            class RemoteAgi(Entity):
                                                """
                                                Remote Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                    self.yang_name = "remote-agi"
                                                    self.yang_parent_name = "atom"

                                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                    self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                    self._children_yang_names.add("auto")

                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    self._children_yang_names.add("two-byte-as")

                                                    self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                    self._children_yang_names.add("v4-addr")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("vpls_id_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                                class Auto(Entity):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                        self.yang_name = "auto"
                                                        self.yang_parent_name = "remote-agi"

                                                        self.asn = YLeaf(YType.uint16, "asn")

                                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("asn",
                                                                        "vpn_id") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.asn.is_set or
                                                            self.vpn_id.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.asn.yfilter != YFilter.not_set or
                                                            self.vpn_id.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "auto" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "asn" or name == "vpn-id"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "asn"):
                                                            self.asn = value
                                                            self.asn.value_namespace = name_space
                                                            self.asn.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vpn-id"):
                                                            self.vpn_id = value
                                                            self.vpn_id.value_namespace = name_space
                                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                                class TwoByteAs(Entity):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                        self.yang_name = "two-byte-as"
                                                        self.yang_parent_name = "remote-agi"

                                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("four_byte_index",
                                                                        "two_byte_as") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.four_byte_index.is_set or
                                                            self.two_byte_as.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.four_byte_index.yfilter != YFilter.not_set or
                                                            self.two_byte_as.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "two-byte-as" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "four-byte-index"):
                                                            self.four_byte_index = value
                                                            self.four_byte_index.value_namespace = name_space
                                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "two-byte-as"):
                                                            self.two_byte_as = value
                                                            self.two_byte_as.value_namespace = name_space
                                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                                class V4Addr(Entity):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                        self.yang_name = "v4-addr"
                                                        self.yang_parent_name = "remote-agi"

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("ipv4_address",
                                                                        "two_byte_index") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.ipv4_address.is_set or
                                                            self.two_byte_index.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.ipv4_address.yfilter != YFilter.not_set or
                                                            self.two_byte_index.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "v4-addr" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "ipv4-address"):
                                                            self.ipv4_address = value
                                                            self.ipv4_address.value_namespace = name_space
                                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "two-byte-index"):
                                                            self.two_byte_index = value
                                                            self.two_byte_index.value_namespace = name_space
                                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.vpls_id_type.is_set or
                                                        (self.auto is not None and self.auto.has_data()) or
                                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                                        (self.auto is not None and self.auto.has_operation()) or
                                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "remote-agi" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "auto"):
                                                        if (self.auto is None):
                                                            self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                            self.auto.parent = self
                                                            self._children_name_map["auto"] = "auto"
                                                        return self.auto

                                                    if (child_yang_name == "two-byte-as"):
                                                        if (self.two_byte_as is None):
                                                            self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                            self.two_byte_as.parent = self
                                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                                        return self.two_byte_as

                                                    if (child_yang_name == "v4-addr"):
                                                        if (self.v4_addr is None):
                                                            self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                            self.v4_addr.parent = self
                                                            self._children_name_map["v4_addr"] = "v4-addr"
                                                        return self.v4_addr

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "vpls-id-type"):
                                                        self.vpls_id_type = value
                                                        self.vpls_id_type.value_namespace = name_space
                                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                            class MultiSegmentPseudowireStats(Entity):
                                                """
                                                Multisegment pseudowire statistics
                                                
                                                .. attribute:: received_bytes
                                                
                                                	Bytes received
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: received_packets
                                                
                                                	Packets received
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                    self.yang_name = "multi-segment-pseudowire-stats"
                                                    self.yang_parent_name = "atom"

                                                    self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                                    self.received_packets = YLeaf(YType.uint64, "received-packets")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("received_bytes",
                                                                    "received_packets") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.received_bytes.is_set or
                                                        self.received_packets.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.received_bytes.yfilter != YFilter.not_set or
                                                        self.received_packets.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                                    if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.received_packets.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "received-bytes" or name == "received-packets"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "received-bytes"):
                                                        self.received_bytes = value
                                                        self.received_bytes.value_namespace = name_space
                                                        self.received_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "received-packets"):
                                                        self.received_packets = value
                                                        self.received_packets.value_namespace = name_space
                                                        self.received_packets.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.is_pseudowire_headend.is_set or
                                                    self.is_sai_itype2.is_set or
                                                    self.is_tai_itype2.is_set or
                                                    self.ldp_label_advertisment_failed.is_set or
                                                    self.local_c_ctype.is_set or
                                                    self.local_ceid.is_set or
                                                    self.local_cv_type.is_set or
                                                    self.local_group_id.is_set or
                                                    self.local_label.is_set or
                                                    self.local_ldp_id.is_set or
                                                    self.local_saii_gbl_id.is_set or
                                                    self.local_saiiac_id.is_set or
                                                    self.local_taii_gbl_id.is_set or
                                                    self.local_taiiac_id.is_set or
                                                    self.local_veid.is_set or
                                                    self.lsd_rewrite_failed.is_set or
                                                    self.rem_saii.is_set or
                                                    self.rem_saii_gbl_id.is_set or
                                                    self.rem_saiiac_id.is_set or
                                                    self.rem_taii.is_set or
                                                    self.rem_taii_gbl_id.is_set or
                                                    self.rem_taiiac_id.is_set or
                                                    self.remote_c_ctype.is_set or
                                                    self.remote_ceid.is_set or
                                                    self.remote_cv_type.is_set or
                                                    self.remote_group_id.is_set or
                                                    self.remote_label.is_set or
                                                    self.remote_ldp_id.is_set or
                                                    self.remote_source_address.is_set or
                                                    self.remote_veid.is_set or
                                                    self.saii.is_set or
                                                    self.source_address.is_set or
                                                    self.taii.is_set or
                                                    (self.local_agi is not None and self.local_agi.has_data()) or
                                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                                    (self.remote_agi is not None and self.remote_agi.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                                    self.is_sai_itype2.yfilter != YFilter.not_set or
                                                    self.is_tai_itype2.yfilter != YFilter.not_set or
                                                    self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                                    self.local_c_ctype.yfilter != YFilter.not_set or
                                                    self.local_ceid.yfilter != YFilter.not_set or
                                                    self.local_cv_type.yfilter != YFilter.not_set or
                                                    self.local_group_id.yfilter != YFilter.not_set or
                                                    self.local_label.yfilter != YFilter.not_set or
                                                    self.local_ldp_id.yfilter != YFilter.not_set or
                                                    self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                                    self.local_saiiac_id.yfilter != YFilter.not_set or
                                                    self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                                    self.local_taiiac_id.yfilter != YFilter.not_set or
                                                    self.local_veid.yfilter != YFilter.not_set or
                                                    self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                                    self.rem_saii.yfilter != YFilter.not_set or
                                                    self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                                    self.rem_saiiac_id.yfilter != YFilter.not_set or
                                                    self.rem_taii.yfilter != YFilter.not_set or
                                                    self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                                    self.rem_taiiac_id.yfilter != YFilter.not_set or
                                                    self.remote_c_ctype.yfilter != YFilter.not_set or
                                                    self.remote_ceid.yfilter != YFilter.not_set or
                                                    self.remote_cv_type.yfilter != YFilter.not_set or
                                                    self.remote_group_id.yfilter != YFilter.not_set or
                                                    self.remote_label.yfilter != YFilter.not_set or
                                                    self.remote_ldp_id.yfilter != YFilter.not_set or
                                                    self.remote_source_address.yfilter != YFilter.not_set or
                                                    self.remote_veid.yfilter != YFilter.not_set or
                                                    self.saii.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.taii.yfilter != YFilter.not_set or
                                                    (self.local_agi is not None and self.local_agi.has_operation()) or
                                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                                    (self.remote_agi is not None and self.remote_agi.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atom" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                                if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                                if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                                if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                                if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                                if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                                if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                                if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                                if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                                if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                                if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                                if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                                if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                                if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_veid.get_name_leafdata())
                                                if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                                if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                                if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                                if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                                if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                                if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                                if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                                if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                                if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                                if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                                if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                                if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                                if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                                if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                                if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.saii.get_name_leafdata())
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.taii.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "local-agi"):
                                                    if (self.local_agi is None):
                                                        self.local_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                        self.local_agi.parent = self
                                                        self._children_name_map["local_agi"] = "local-agi"
                                                    return self.local_agi

                                                if (child_yang_name == "multi-segment-pseudowire-stats"):
                                                    if (self.multi_segment_pseudowire_stats is None):
                                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                        self.multi_segment_pseudowire_stats.parent = self
                                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                    return self.multi_segment_pseudowire_stats

                                                if (child_yang_name == "remote-agi"):
                                                    if (self.remote_agi is None):
                                                        self.remote_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                        self.remote_agi.parent = self
                                                        self._children_name_map["remote_agi"] = "remote-agi"
                                                    return self.remote_agi

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "is-pseudowire-headend"):
                                                    self.is_pseudowire_headend = value
                                                    self.is_pseudowire_headend.value_namespace = name_space
                                                    self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sai-itype2"):
                                                    self.is_sai_itype2 = value
                                                    self.is_sai_itype2.value_namespace = name_space
                                                    self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-tai-itype2"):
                                                    self.is_tai_itype2 = value
                                                    self.is_tai_itype2.value_namespace = name_space
                                                    self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ldp-label-advertisment-failed"):
                                                    self.ldp_label_advertisment_failed = value
                                                    self.ldp_label_advertisment_failed.value_namespace = name_space
                                                    self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-c-ctype"):
                                                    self.local_c_ctype = value
                                                    self.local_c_ctype.value_namespace = name_space
                                                    self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-ceid"):
                                                    self.local_ceid = value
                                                    self.local_ceid.value_namespace = name_space
                                                    self.local_ceid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-cv-type"):
                                                    self.local_cv_type = value
                                                    self.local_cv_type.value_namespace = name_space
                                                    self.local_cv_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-group-id"):
                                                    self.local_group_id = value
                                                    self.local_group_id.value_namespace = name_space
                                                    self.local_group_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-label"):
                                                    self.local_label = value
                                                    self.local_label.value_namespace = name_space
                                                    self.local_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-ldp-id"):
                                                    self.local_ldp_id = value
                                                    self.local_ldp_id.value_namespace = name_space
                                                    self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-saii-gbl-id"):
                                                    self.local_saii_gbl_id = value
                                                    self.local_saii_gbl_id.value_namespace = name_space
                                                    self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-saiiac-id"):
                                                    self.local_saiiac_id = value
                                                    self.local_saiiac_id.value_namespace = name_space
                                                    self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-taii-gbl-id"):
                                                    self.local_taii_gbl_id = value
                                                    self.local_taii_gbl_id.value_namespace = name_space
                                                    self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-taiiac-id"):
                                                    self.local_taiiac_id = value
                                                    self.local_taiiac_id.value_namespace = name_space
                                                    self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-veid"):
                                                    self.local_veid = value
                                                    self.local_veid.value_namespace = name_space
                                                    self.local_veid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsd-rewrite-failed"):
                                                    self.lsd_rewrite_failed = value
                                                    self.lsd_rewrite_failed.value_namespace = name_space
                                                    self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-saii"):
                                                    self.rem_saii = value
                                                    self.rem_saii.value_namespace = name_space
                                                    self.rem_saii.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-saii-gbl-id"):
                                                    self.rem_saii_gbl_id = value
                                                    self.rem_saii_gbl_id.value_namespace = name_space
                                                    self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-saiiac-id"):
                                                    self.rem_saiiac_id = value
                                                    self.rem_saiiac_id.value_namespace = name_space
                                                    self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-taii"):
                                                    self.rem_taii = value
                                                    self.rem_taii.value_namespace = name_space
                                                    self.rem_taii.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-taii-gbl-id"):
                                                    self.rem_taii_gbl_id = value
                                                    self.rem_taii_gbl_id.value_namespace = name_space
                                                    self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-taiiac-id"):
                                                    self.rem_taiiac_id = value
                                                    self.rem_taiiac_id.value_namespace = name_space
                                                    self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-c-ctype"):
                                                    self.remote_c_ctype = value
                                                    self.remote_c_ctype.value_namespace = name_space
                                                    self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-ceid"):
                                                    self.remote_ceid = value
                                                    self.remote_ceid.value_namespace = name_space
                                                    self.remote_ceid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-cv-type"):
                                                    self.remote_cv_type = value
                                                    self.remote_cv_type.value_namespace = name_space
                                                    self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-group-id"):
                                                    self.remote_group_id = value
                                                    self.remote_group_id.value_namespace = name_space
                                                    self.remote_group_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-label"):
                                                    self.remote_label = value
                                                    self.remote_label.value_namespace = name_space
                                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-ldp-id"):
                                                    self.remote_ldp_id = value
                                                    self.remote_ldp_id.value_namespace = name_space
                                                    self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-source-address"):
                                                    self.remote_source_address = value
                                                    self.remote_source_address.value_namespace = name_space
                                                    self.remote_source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-veid"):
                                                    self.remote_veid = value
                                                    self.remote_veid.value_namespace = name_space
                                                    self.remote_veid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "saii"):
                                                    self.saii = value
                                                    self.saii.value_namespace = name_space
                                                    self.saii.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "taii"):
                                                    self.taii = value
                                                    self.taii.value_namespace = name_space
                                                    self.taii.value_namespace_prefix = name_space_prefix


                                        class L2Tpv3(Entity):
                                            """
                                            l2tpv3
                                            
                                            .. attribute:: dont_fragment_bit
                                            
                                            	Don't Fragment Bit
                                            	**type**\:  bool
                                            
                                            .. attribute:: ipv4_source_address
                                            
                                            	IPv4 source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_source_address
                                            
                                            	IPv6 source address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tp_class_name
                                            
                                            	L2TPClassName
                                            	**type**\:  str
                                            
                                            	**length:** 0..32
                                            
                                            .. attribute:: local_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_size
                                            
                                            	Local cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_secondary_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local secondary cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_secondary_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local secondary cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_secondary_cookie_size
                                            
                                            	Local secondary cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_session_id
                                            
                                            	Local session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_mtu_enabled
                                            
                                            	Path MTU enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_mtu_max_value
                                            
                                            	Path MTU Maximum allowable session MTU
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: remote_circuit_status_up
                                            
                                            	RemoteCircuitStatusUp
                                            	**type**\:  bool
                                            
                                            .. attribute:: remote_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the remote cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the remote cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_size
                                            
                                            	Remote cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_session_id
                                            
                                            	Remote session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tos
                                            
                                            	Type Of Service Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tos_mode
                                            
                                            	Type Of Service Mode
                                            	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                            
                                            .. attribute:: ttl
                                            
                                            	Time To Live value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tunnel_state
                                            
                                            	L2TP tunnel state
                                            	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                                self.yang_name = "l2tpv3"
                                                self.yang_parent_name = "encapsulation-info"

                                                self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                                self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                                self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                                self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                                self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                                self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                                self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                                self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                                self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                                self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                                self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                                self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                                self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                                self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                                self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                                self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                                self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                                self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                                self.tos = YLeaf(YType.uint8, "tos")

                                                self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                                self.ttl = YLeaf(YType.uint8, "ttl")

                                                self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dont_fragment_bit",
                                                                "ipv4_source_address",
                                                                "ipv6_source_address",
                                                                "l2tp_class_name",
                                                                "local_cookie_high_value",
                                                                "local_cookie_low_value",
                                                                "local_cookie_size",
                                                                "local_secondary_cookie_high_value",
                                                                "local_secondary_cookie_low_value",
                                                                "local_secondary_cookie_size",
                                                                "local_session_id",
                                                                "path_mtu_enabled",
                                                                "path_mtu_max_value",
                                                                "remote_circuit_status_up",
                                                                "remote_cookie_high_value",
                                                                "remote_cookie_low_value",
                                                                "remote_cookie_size",
                                                                "remote_session_id",
                                                                "tos",
                                                                "tos_mode",
                                                                "ttl",
                                                                "tunnel_state") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dont_fragment_bit.is_set or
                                                    self.ipv4_source_address.is_set or
                                                    self.ipv6_source_address.is_set or
                                                    self.l2tp_class_name.is_set or
                                                    self.local_cookie_high_value.is_set or
                                                    self.local_cookie_low_value.is_set or
                                                    self.local_cookie_size.is_set or
                                                    self.local_secondary_cookie_high_value.is_set or
                                                    self.local_secondary_cookie_low_value.is_set or
                                                    self.local_secondary_cookie_size.is_set or
                                                    self.local_session_id.is_set or
                                                    self.path_mtu_enabled.is_set or
                                                    self.path_mtu_max_value.is_set or
                                                    self.remote_circuit_status_up.is_set or
                                                    self.remote_cookie_high_value.is_set or
                                                    self.remote_cookie_low_value.is_set or
                                                    self.remote_cookie_size.is_set or
                                                    self.remote_session_id.is_set or
                                                    self.tos.is_set or
                                                    self.tos_mode.is_set or
                                                    self.ttl.is_set or
                                                    self.tunnel_state.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dont_fragment_bit.yfilter != YFilter.not_set or
                                                    self.ipv4_source_address.yfilter != YFilter.not_set or
                                                    self.ipv6_source_address.yfilter != YFilter.not_set or
                                                    self.l2tp_class_name.yfilter != YFilter.not_set or
                                                    self.local_cookie_high_value.yfilter != YFilter.not_set or
                                                    self.local_cookie_low_value.yfilter != YFilter.not_set or
                                                    self.local_cookie_size.yfilter != YFilter.not_set or
                                                    self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                    self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                    self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                                    self.local_session_id.yfilter != YFilter.not_set or
                                                    self.path_mtu_enabled.yfilter != YFilter.not_set or
                                                    self.path_mtu_max_value.yfilter != YFilter.not_set or
                                                    self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                                    self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                                    self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                                    self.remote_cookie_size.yfilter != YFilter.not_set or
                                                    self.remote_session_id.yfilter != YFilter.not_set or
                                                    self.tos.yfilter != YFilter.not_set or
                                                    self.tos_mode.yfilter != YFilter.not_set or
                                                    self.ttl.yfilter != YFilter.not_set or
                                                    self.tunnel_state.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2tpv3" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                                if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                                if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                                if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                                if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                                if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                                if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                                if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                                if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                                if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                                if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                                if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                                if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                                if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                                if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                                if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                                if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                                if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                                if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tos.get_name_leafdata())
                                                if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                                if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ttl.get_name_leafdata())
                                                if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dont-fragment-bit"):
                                                    self.dont_fragment_bit = value
                                                    self.dont_fragment_bit.value_namespace = name_space
                                                    self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ipv4-source-address"):
                                                    self.ipv4_source_address = value
                                                    self.ipv4_source_address.value_namespace = name_space
                                                    self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ipv6-source-address"):
                                                    self.ipv6_source_address = value
                                                    self.ipv6_source_address.value_namespace = name_space
                                                    self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "l2tp-class-name"):
                                                    self.l2tp_class_name = value
                                                    self.l2tp_class_name.value_namespace = name_space
                                                    self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-cookie-high-value"):
                                                    self.local_cookie_high_value = value
                                                    self.local_cookie_high_value.value_namespace = name_space
                                                    self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-cookie-low-value"):
                                                    self.local_cookie_low_value = value
                                                    self.local_cookie_low_value.value_namespace = name_space
                                                    self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-cookie-size"):
                                                    self.local_cookie_size = value
                                                    self.local_cookie_size.value_namespace = name_space
                                                    self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-secondary-cookie-high-value"):
                                                    self.local_secondary_cookie_high_value = value
                                                    self.local_secondary_cookie_high_value.value_namespace = name_space
                                                    self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-secondary-cookie-low-value"):
                                                    self.local_secondary_cookie_low_value = value
                                                    self.local_secondary_cookie_low_value.value_namespace = name_space
                                                    self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-secondary-cookie-size"):
                                                    self.local_secondary_cookie_size = value
                                                    self.local_secondary_cookie_size.value_namespace = name_space
                                                    self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-session-id"):
                                                    self.local_session_id = value
                                                    self.local_session_id.value_namespace = name_space
                                                    self.local_session_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "path-mtu-enabled"):
                                                    self.path_mtu_enabled = value
                                                    self.path_mtu_enabled.value_namespace = name_space
                                                    self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "path-mtu-max-value"):
                                                    self.path_mtu_max_value = value
                                                    self.path_mtu_max_value.value_namespace = name_space
                                                    self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-circuit-status-up"):
                                                    self.remote_circuit_status_up = value
                                                    self.remote_circuit_status_up.value_namespace = name_space
                                                    self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-cookie-high-value"):
                                                    self.remote_cookie_high_value = value
                                                    self.remote_cookie_high_value.value_namespace = name_space
                                                    self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-cookie-low-value"):
                                                    self.remote_cookie_low_value = value
                                                    self.remote_cookie_low_value.value_namespace = name_space
                                                    self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-cookie-size"):
                                                    self.remote_cookie_size = value
                                                    self.remote_cookie_size.value_namespace = name_space
                                                    self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-session-id"):
                                                    self.remote_session_id = value
                                                    self.remote_session_id.value_namespace = name_space
                                                    self.remote_session_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tos"):
                                                    self.tos = value
                                                    self.tos.value_namespace = name_space
                                                    self.tos.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tos-mode"):
                                                    self.tos_mode = value
                                                    self.tos_mode.value_namespace = name_space
                                                    self.tos_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ttl"):
                                                    self.ttl = value
                                                    self.ttl.value_namespace = name_space
                                                    self.ttl.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-state"):
                                                    self.tunnel_state = value
                                                    self.tunnel_state.value_namespace = name_space
                                                    self.tunnel_state.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.encapsulation.is_set or
                                                (self.atom is not None and self.atom.has_data()) or
                                                (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation.yfilter != YFilter.not_set or
                                                (self.atom is not None and self.atom.has_operation()) or
                                                (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "encapsulation-info" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atom"):
                                                if (self.atom is None):
                                                    self.atom = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                                    self.atom.parent = self
                                                    self._children_name_map["atom"] = "atom"
                                                return self.atom

                                            if (child_yang_name == "l2tpv3"):
                                                if (self.l2tpv3 is None):
                                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                                    self.l2tpv3.parent = self
                                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                                return self.l2tpv3

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation"):
                                                self.encapsulation = value
                                                self.encapsulation.value_namespace = name_space
                                                self.encapsulation.value_namespace_prefix = name_space_prefix


                                    class LocalInterface(Entity):
                                        """
                                        Local interface
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                            self.yang_name = "local-interface"
                                            self.yang_parent_name = "pseudowire"

                                            self.mtu = YLeaf(YType.uint32, "mtu")

                                            self.name = YLeaf(YType.str, "name")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                            self._children_yang_names.add("parameters")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mtu",
                                                            "name",
                                                            "payload_bytes") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                        class Parameters(Entity):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                                self.yang_name = "parameters"
                                                self.yang_parent_name = "local-interface"

                                                self.type = YLeaf(YType.enumeration, "type")

                                                self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                                self._children_yang_names.add("atm")

                                                self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                                self._children_yang_names.add("ethernet")

                                                self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                                self._children_yang_names.add("fr")

                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                self._children_yang_names.add("pseudowire-ether")

                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                self._children_yang_names.add("pseudowire-iw")

                                                self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                                self._children_yang_names.add("tdm")

                                                self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                                self._children_yang_names.add("vlan")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                            class Ethernet(Entity):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                    self.yang_name = "ethernet"
                                                    self.yang_parent_name = "parameters"

                                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("xconnect_tags") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.xconnect_tags.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ethernet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "xconnect-tags"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "xconnect-tags"):
                                                        self.xconnect_tags = value
                                                        self.xconnect_tags.value_namespace = name_space
                                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                            class Vlan(Entity):
                                                """
                                                VLAN
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\:  list of int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                    self.yang_name = "vlan"
                                                    self.yang_parent_name = "parameters"

                                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                    self.vlan_range = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("encapsulation_type",
                                                                    "outer_tag",
                                                                    "rewrite_tag",
                                                                    "simple_efp",
                                                                    "vlan_rewrite_tag",
                                                                    "xconnect_tags") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                                class VlanRange(Entity):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                        self.yang_name = "vlan-range"
                                                        self.yang_parent_name = "vlan"

                                                        self.lower = YLeaf(YType.uint16, "lower")

                                                        self.upper = YLeaf(YType.uint16, "upper")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("lower",
                                                                        "upper") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.lower.is_set or
                                                            self.upper.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.lower.yfilter != YFilter.not_set or
                                                            self.upper.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vlan-range" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "lower" or name == "upper"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "lower"):
                                                            self.lower = value
                                                            self.lower.value_namespace = name_space
                                                            self.lower.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "upper"):
                                                            self.upper = value
                                                            self.upper.value_namespace = name_space
                                                            self.upper.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vlan_range:
                                                        if (c.has_data()):
                                                            return True
                                                    for leaf in self.rewrite_tag.getYLeafs():
                                                        if (leaf.yfilter != YFilter.not_set):
                                                            return True
                                                    return (
                                                        self.encapsulation_type.is_set or
                                                        self.outer_tag.is_set or
                                                        self.simple_efp.is_set or
                                                        self.vlan_rewrite_tag.is_set or
                                                        self.xconnect_tags.is_set)

                                                def has_operation(self):
                                                    for c in self.vlan_range:
                                                        if (c.has_operation()):
                                                            return True
                                                    for leaf in self.rewrite_tag.getYLeafs():
                                                        if (leaf.is_set):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                                        self.outer_tag.yfilter != YFilter.not_set or
                                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                                        self.simple_efp.yfilter != YFilter.not_set or
                                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vlan-range"):
                                                        for c in self.vlan_range:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vlan_range.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "encapsulation-type"):
                                                        self.encapsulation_type = value
                                                        self.encapsulation_type.value_namespace = name_space
                                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "outer-tag"):
                                                        self.outer_tag = value
                                                        self.outer_tag.value_namespace = name_space
                                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rewrite-tag"):
                                                        self.rewrite_tag.append(value)
                                                    if(value_path == "simple-efp"):
                                                        self.simple_efp = value
                                                        self.simple_efp.value_namespace = name_space
                                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vlan-rewrite-tag"):
                                                        self.vlan_rewrite_tag = value
                                                        self.vlan_rewrite_tag.value_namespace = name_space
                                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "xconnect-tags"):
                                                        self.xconnect_tags = value
                                                        self.xconnect_tags.value_namespace = name_space
                                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                            class Tdm(Entity):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\:  str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                    self.yang_name = "tdm"
                                                    self.yang_parent_name = "parameters"

                                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                    self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                    self._children_yang_names.add("tdm-options")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("tdm_mode",
                                                                    "timeslot_group",
                                                                    "timeslot_rate") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                                class TdmOptions(Entity):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                        self.yang_name = "tdm-options"
                                                        self.yang_parent_name = "tdm"

                                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                        self.cas = YLeaf(YType.uint8, "cas")

                                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("bit_rate",
                                                                        "cas",
                                                                        "payload_bytes",
                                                                        "rtp",
                                                                        "rtp_header_payload_type",
                                                                        "signalling_packets",
                                                                        "ssrc",
                                                                        "timestamp_clock_freq",
                                                                        "timestamp_mode") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.bit_rate.is_set or
                                                            self.cas.is_set or
                                                            self.payload_bytes.is_set or
                                                            self.rtp.is_set or
                                                            self.rtp_header_payload_type.is_set or
                                                            self.signalling_packets.is_set or
                                                            self.ssrc.is_set or
                                                            self.timestamp_clock_freq.is_set or
                                                            self.timestamp_mode.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.bit_rate.yfilter != YFilter.not_set or
                                                            self.cas.yfilter != YFilter.not_set or
                                                            self.payload_bytes.yfilter != YFilter.not_set or
                                                            self.rtp.yfilter != YFilter.not_set or
                                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                            self.signalling_packets.yfilter != YFilter.not_set or
                                                            self.ssrc.yfilter != YFilter.not_set or
                                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tdm-options" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "bit-rate"):
                                                            self.bit_rate = value
                                                            self.bit_rate.value_namespace = name_space
                                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "cas"):
                                                            self.cas = value
                                                            self.cas.value_namespace = name_space
                                                            self.cas.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "payload-bytes"):
                                                            self.payload_bytes = value
                                                            self.payload_bytes.value_namespace = name_space
                                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtp"):
                                                            self.rtp = value
                                                            self.rtp.value_namespace = name_space
                                                            self.rtp.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtp-header-payload-type"):
                                                            self.rtp_header_payload_type = value
                                                            self.rtp_header_payload_type.value_namespace = name_space
                                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "signalling-packets"):
                                                            self.signalling_packets = value
                                                            self.signalling_packets.value_namespace = name_space
                                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ssrc"):
                                                            self.ssrc = value
                                                            self.ssrc.value_namespace = name_space
                                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "timestamp-clock-freq"):
                                                            self.timestamp_clock_freq = value
                                                            self.timestamp_clock_freq.value_namespace = name_space
                                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "timestamp-mode"):
                                                            self.timestamp_mode = value
                                                            self.timestamp_mode.value_namespace = name_space
                                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.tdm_mode.is_set or
                                                        self.timeslot_group.is_set or
                                                        self.timeslot_rate.is_set or
                                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.tdm_mode.yfilter != YFilter.not_set or
                                                        self.timeslot_group.yfilter != YFilter.not_set or
                                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tdm-options"):
                                                        if (self.tdm_options is None):
                                                            self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                            self.tdm_options.parent = self
                                                            self._children_name_map["tdm_options"] = "tdm-options"
                                                        return self.tdm_options

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "tdm-mode"):
                                                        self.tdm_mode = value
                                                        self.tdm_mode.value_namespace = name_space
                                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timeslot-group"):
                                                        self.timeslot_group = value
                                                        self.timeslot_group.value_namespace = name_space
                                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timeslot-rate"):
                                                        self.timeslot_rate = value
                                                        self.timeslot_rate.value_namespace = name_space
                                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                            class Atm(Entity):
                                                """
                                                ATM
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                    self.yang_name = "atm"
                                                    self.yang_parent_name = "parameters"

                                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                    self.vci = YLeaf(YType.uint16, "vci")

                                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("atm_mode",
                                                                    "maximum_number_cells_packed",
                                                                    "maximum_number_cells_un_packed",
                                                                    "vci",
                                                                    "vpi") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.atm_mode.is_set or
                                                        self.maximum_number_cells_packed.is_set or
                                                        self.maximum_number_cells_un_packed.is_set or
                                                        self.vci.is_set or
                                                        self.vpi.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.atm_mode.yfilter != YFilter.not_set or
                                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                        self.vci.yfilter != YFilter.not_set or
                                                        self.vpi.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "atm" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "atm-mode"):
                                                        self.atm_mode = value
                                                        self.atm_mode.value_namespace = name_space
                                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-number-cells-packed"):
                                                        self.maximum_number_cells_packed = value
                                                        self.maximum_number_cells_packed.value_namespace = name_space
                                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-number-cells-un-packed"):
                                                        self.maximum_number_cells_un_packed = value
                                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vci"):
                                                        self.vci = value
                                                        self.vci.value_namespace = name_space
                                                        self.vci.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpi"):
                                                        self.vpi = value
                                                        self.vpi.value_namespace = name_space
                                                        self.vpi.value_namespace_prefix = name_space_prefix


                                            class Fr(Entity):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                    self.yang_name = "fr"
                                                    self.yang_parent_name = "parameters"

                                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("dlci",
                                                                    "fr_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.dlci.is_set or
                                                        self.fr_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.dlci.yfilter != YFilter.not_set or
                                                        self.fr_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "dlci" or name == "fr-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "dlci"):
                                                        self.dlci = value
                                                        self.dlci.value_namespace = name_space
                                                        self.dlci.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fr-mode"):
                                                        self.fr_mode = value
                                                        self.fr_mode.value_namespace = name_space
                                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                                            class PseudowireEther(Entity):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                    self.yang_name = "pseudowire-ether"
                                                    self.yang_parent_name = "parameters"

                                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._children_yang_names.add("interface-list")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("internal_label",
                                                                    "is_valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-ether"

                                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                        self.interface = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_list_id",
                                                                        "interface_list_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "replicate_status") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.replicate_status.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.replicate_status.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "interface" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "replicate-status"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "replicate-status"):
                                                                self.replicate_status = value
                                                                self.replicate_status.value_namespace = name_space
                                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.interface:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.interface_list_id.is_set or
                                                            self.interface_list_name.is_set)

                                                    def has_operation(self):
                                                        for c in self.interface:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_list_id.yfilter != YFilter.not_set or
                                                            self.interface_list_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface-list" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "interface"):
                                                            for c in self.interface:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.interface.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-list-id"):
                                                            self.interface_list_id = value
                                                            self.interface_list_id.value_namespace = name_space
                                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-list-name"):
                                                            self.interface_list_name = value
                                                            self.interface_list_name.value_namespace = name_space
                                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.internal_label.is_set or
                                                        self.is_valid.is_set or
                                                        (self.interface_list is not None and self.interface_list.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.internal_label.yfilter != YFilter.not_set or
                                                        self.is_valid.yfilter != YFilter.not_set or
                                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pseudowire-ether" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface-list"):
                                                        if (self.interface_list is None):
                                                            self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                            self.interface_list.parent = self
                                                            self._children_name_map["interface_list"] = "interface-list"
                                                        return self.interface_list

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "internal-label"):
                                                        self.internal_label = value
                                                        self.internal_label.value_namespace = name_space
                                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-valid"):
                                                        self.is_valid = value
                                                        self.is_valid.value_namespace = name_space
                                                        self.is_valid.value_namespace_prefix = name_space_prefix


                                            class PseudowireIw(Entity):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                    self.yang_name = "pseudowire-iw"
                                                    self.yang_parent_name = "parameters"

                                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._children_yang_names.add("interface-list")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("internal_label",
                                                                    "is_valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-iw"

                                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                        self.interface = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_list_id",
                                                                        "interface_list_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "replicate_status") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.replicate_status.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.replicate_status.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "interface" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "replicate-status"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "replicate-status"):
                                                                self.replicate_status = value
                                                                self.replicate_status.value_namespace = name_space
                                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.interface:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.interface_list_id.is_set or
                                                            self.interface_list_name.is_set)

                                                    def has_operation(self):
                                                        for c in self.interface:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_list_id.yfilter != YFilter.not_set or
                                                            self.interface_list_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface-list" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "interface"):
                                                            for c in self.interface:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.interface.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-list-id"):
                                                            self.interface_list_id = value
                                                            self.interface_list_id.value_namespace = name_space
                                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-list-name"):
                                                            self.interface_list_name = value
                                                            self.interface_list_name.value_namespace = name_space
                                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.internal_label.is_set or
                                                        self.is_valid.is_set or
                                                        (self.interface_list is not None and self.interface_list.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.internal_label.yfilter != YFilter.not_set or
                                                        self.is_valid.yfilter != YFilter.not_set or
                                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pseudowire-iw" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface-list"):
                                                        if (self.interface_list is None):
                                                            self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                            self.interface_list.parent = self
                                                            self._children_name_map["interface_list"] = "interface-list"
                                                        return self.interface_list

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "internal-label"):
                                                        self.internal_label = value
                                                        self.internal_label.value_namespace = name_space
                                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-valid"):
                                                        self.is_valid = value
                                                        self.is_valid.value_namespace = name_space
                                                        self.is_valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.type.is_set or
                                                    (self.atm is not None and self.atm.has_data()) or
                                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                                    (self.fr is not None and self.fr.has_data()) or
                                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                    (self.tdm is not None and self.tdm.has_data()) or
                                                    (self.vlan is not None and self.vlan.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.type.yfilter != YFilter.not_set or
                                                    (self.atm is not None and self.atm.has_operation()) or
                                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                                    (self.fr is not None and self.fr.has_operation()) or
                                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                    (self.tdm is not None and self.tdm.has_operation()) or
                                                    (self.vlan is not None and self.vlan.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "parameters" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "atm"):
                                                    if (self.atm is None):
                                                        self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                        self.atm.parent = self
                                                        self._children_name_map["atm"] = "atm"
                                                    return self.atm

                                                if (child_yang_name == "ethernet"):
                                                    if (self.ethernet is None):
                                                        self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                        self.ethernet.parent = self
                                                        self._children_name_map["ethernet"] = "ethernet"
                                                    return self.ethernet

                                                if (child_yang_name == "fr"):
                                                    if (self.fr is None):
                                                        self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                        self.fr.parent = self
                                                        self._children_name_map["fr"] = "fr"
                                                    return self.fr

                                                if (child_yang_name == "pseudowire-ether"):
                                                    if (self.pseudowire_ether is None):
                                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                        self.pseudowire_ether.parent = self
                                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                    return self.pseudowire_ether

                                                if (child_yang_name == "pseudowire-iw"):
                                                    if (self.pseudowire_iw is None):
                                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                        self.pseudowire_iw.parent = self
                                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                    return self.pseudowire_iw

                                                if (child_yang_name == "tdm"):
                                                    if (self.tdm is None):
                                                        self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                        self.tdm.parent = self
                                                        self._children_name_map["tdm"] = "tdm"
                                                    return self.tdm

                                                if (child_yang_name == "vlan"):
                                                    if (self.vlan is None):
                                                        self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                        self.vlan.parent = self
                                                        self._children_name_map["vlan"] = "vlan"
                                                    return self.vlan

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "type"):
                                                    self.type = value
                                                    self.type.value_namespace = name_space
                                                    self.type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.mtu.is_set or
                                                self.name.is_set or
                                                self.payload_bytes.is_set or
                                                (self.parameters is not None and self.parameters.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mtu.yfilter != YFilter.not_set or
                                                self.name.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                (self.parameters is not None and self.parameters.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mtu.get_name_leafdata())
                                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.name.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "parameters"):
                                                if (self.parameters is None):
                                                    self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                                    self.parameters.parent = self
                                                    self._children_name_map["parameters"] = "parameters"
                                                return self.parameters

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mtu"):
                                                self.mtu = value
                                                self.mtu.value_namespace = name_space
                                                self.mtu.value_namespace_prefix = name_space_prefix
                                            if(value_path == "name"):
                                                self.name = value
                                                self.name.value_namespace = name_space
                                                self.name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                                    class RemoteInterface(Entity):
                                        """
                                        Remote interface
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                            self.yang_name = "remote-interface"
                                            self.yang_parent_name = "pseudowire"

                                            self.mtu = YLeaf(YType.uint32, "mtu")

                                            self.name = YLeaf(YType.str, "name")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                            self._children_yang_names.add("parameters")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mtu",
                                                            "name",
                                                            "payload_bytes") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                        class Parameters(Entity):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                                self.yang_name = "parameters"
                                                self.yang_parent_name = "remote-interface"

                                                self.type = YLeaf(YType.enumeration, "type")

                                                self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                                self._children_yang_names.add("atm")

                                                self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                                self._children_yang_names.add("ethernet")

                                                self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                                self._children_yang_names.add("fr")

                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                self._children_yang_names.add("pseudowire-ether")

                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                self._children_yang_names.add("pseudowire-iw")

                                                self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                                self._children_yang_names.add("tdm")

                                                self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                                self._children_yang_names.add("vlan")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                            class Ethernet(Entity):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                    self.yang_name = "ethernet"
                                                    self.yang_parent_name = "parameters"

                                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("xconnect_tags") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.xconnect_tags.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ethernet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "xconnect-tags"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "xconnect-tags"):
                                                        self.xconnect_tags = value
                                                        self.xconnect_tags.value_namespace = name_space
                                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                            class Vlan(Entity):
                                                """
                                                VLAN
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\:  list of int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                    self.yang_name = "vlan"
                                                    self.yang_parent_name = "parameters"

                                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                    self.vlan_range = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("encapsulation_type",
                                                                    "outer_tag",
                                                                    "rewrite_tag",
                                                                    "simple_efp",
                                                                    "vlan_rewrite_tag",
                                                                    "xconnect_tags") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                                class VlanRange(Entity):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                        self.yang_name = "vlan-range"
                                                        self.yang_parent_name = "vlan"

                                                        self.lower = YLeaf(YType.uint16, "lower")

                                                        self.upper = YLeaf(YType.uint16, "upper")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("lower",
                                                                        "upper") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.lower.is_set or
                                                            self.upper.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.lower.yfilter != YFilter.not_set or
                                                            self.upper.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vlan-range" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "lower" or name == "upper"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "lower"):
                                                            self.lower = value
                                                            self.lower.value_namespace = name_space
                                                            self.lower.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "upper"):
                                                            self.upper = value
                                                            self.upper.value_namespace = name_space
                                                            self.upper.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vlan_range:
                                                        if (c.has_data()):
                                                            return True
                                                    for leaf in self.rewrite_tag.getYLeafs():
                                                        if (leaf.yfilter != YFilter.not_set):
                                                            return True
                                                    return (
                                                        self.encapsulation_type.is_set or
                                                        self.outer_tag.is_set or
                                                        self.simple_efp.is_set or
                                                        self.vlan_rewrite_tag.is_set or
                                                        self.xconnect_tags.is_set)

                                                def has_operation(self):
                                                    for c in self.vlan_range:
                                                        if (c.has_operation()):
                                                            return True
                                                    for leaf in self.rewrite_tag.getYLeafs():
                                                        if (leaf.is_set):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                                        self.outer_tag.yfilter != YFilter.not_set or
                                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                                        self.simple_efp.yfilter != YFilter.not_set or
                                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vlan-range"):
                                                        for c in self.vlan_range:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vlan_range.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "encapsulation-type"):
                                                        self.encapsulation_type = value
                                                        self.encapsulation_type.value_namespace = name_space
                                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "outer-tag"):
                                                        self.outer_tag = value
                                                        self.outer_tag.value_namespace = name_space
                                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rewrite-tag"):
                                                        self.rewrite_tag.append(value)
                                                    if(value_path == "simple-efp"):
                                                        self.simple_efp = value
                                                        self.simple_efp.value_namespace = name_space
                                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vlan-rewrite-tag"):
                                                        self.vlan_rewrite_tag = value
                                                        self.vlan_rewrite_tag.value_namespace = name_space
                                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "xconnect-tags"):
                                                        self.xconnect_tags = value
                                                        self.xconnect_tags.value_namespace = name_space
                                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                            class Tdm(Entity):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\:  str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                    self.yang_name = "tdm"
                                                    self.yang_parent_name = "parameters"

                                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                    self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                    self._children_yang_names.add("tdm-options")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("tdm_mode",
                                                                    "timeslot_group",
                                                                    "timeslot_rate") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                                class TdmOptions(Entity):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                        self.yang_name = "tdm-options"
                                                        self.yang_parent_name = "tdm"

                                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                        self.cas = YLeaf(YType.uint8, "cas")

                                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("bit_rate",
                                                                        "cas",
                                                                        "payload_bytes",
                                                                        "rtp",
                                                                        "rtp_header_payload_type",
                                                                        "signalling_packets",
                                                                        "ssrc",
                                                                        "timestamp_clock_freq",
                                                                        "timestamp_mode") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.bit_rate.is_set or
                                                            self.cas.is_set or
                                                            self.payload_bytes.is_set or
                                                            self.rtp.is_set or
                                                            self.rtp_header_payload_type.is_set or
                                                            self.signalling_packets.is_set or
                                                            self.ssrc.is_set or
                                                            self.timestamp_clock_freq.is_set or
                                                            self.timestamp_mode.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.bit_rate.yfilter != YFilter.not_set or
                                                            self.cas.yfilter != YFilter.not_set or
                                                            self.payload_bytes.yfilter != YFilter.not_set or
                                                            self.rtp.yfilter != YFilter.not_set or
                                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                            self.signalling_packets.yfilter != YFilter.not_set or
                                                            self.ssrc.yfilter != YFilter.not_set or
                                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tdm-options" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "bit-rate"):
                                                            self.bit_rate = value
                                                            self.bit_rate.value_namespace = name_space
                                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "cas"):
                                                            self.cas = value
                                                            self.cas.value_namespace = name_space
                                                            self.cas.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "payload-bytes"):
                                                            self.payload_bytes = value
                                                            self.payload_bytes.value_namespace = name_space
                                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtp"):
                                                            self.rtp = value
                                                            self.rtp.value_namespace = name_space
                                                            self.rtp.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtp-header-payload-type"):
                                                            self.rtp_header_payload_type = value
                                                            self.rtp_header_payload_type.value_namespace = name_space
                                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "signalling-packets"):
                                                            self.signalling_packets = value
                                                            self.signalling_packets.value_namespace = name_space
                                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ssrc"):
                                                            self.ssrc = value
                                                            self.ssrc.value_namespace = name_space
                                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "timestamp-clock-freq"):
                                                            self.timestamp_clock_freq = value
                                                            self.timestamp_clock_freq.value_namespace = name_space
                                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "timestamp-mode"):
                                                            self.timestamp_mode = value
                                                            self.timestamp_mode.value_namespace = name_space
                                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.tdm_mode.is_set or
                                                        self.timeslot_group.is_set or
                                                        self.timeslot_rate.is_set or
                                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.tdm_mode.yfilter != YFilter.not_set or
                                                        self.timeslot_group.yfilter != YFilter.not_set or
                                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tdm-options"):
                                                        if (self.tdm_options is None):
                                                            self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                            self.tdm_options.parent = self
                                                            self._children_name_map["tdm_options"] = "tdm-options"
                                                        return self.tdm_options

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "tdm-mode"):
                                                        self.tdm_mode = value
                                                        self.tdm_mode.value_namespace = name_space
                                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timeslot-group"):
                                                        self.timeslot_group = value
                                                        self.timeslot_group.value_namespace = name_space
                                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timeslot-rate"):
                                                        self.timeslot_rate = value
                                                        self.timeslot_rate.value_namespace = name_space
                                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                            class Atm(Entity):
                                                """
                                                ATM
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                    self.yang_name = "atm"
                                                    self.yang_parent_name = "parameters"

                                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                    self.vci = YLeaf(YType.uint16, "vci")

                                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("atm_mode",
                                                                    "maximum_number_cells_packed",
                                                                    "maximum_number_cells_un_packed",
                                                                    "vci",
                                                                    "vpi") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.atm_mode.is_set or
                                                        self.maximum_number_cells_packed.is_set or
                                                        self.maximum_number_cells_un_packed.is_set or
                                                        self.vci.is_set or
                                                        self.vpi.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.atm_mode.yfilter != YFilter.not_set or
                                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                        self.vci.yfilter != YFilter.not_set or
                                                        self.vpi.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "atm" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "atm-mode"):
                                                        self.atm_mode = value
                                                        self.atm_mode.value_namespace = name_space
                                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-number-cells-packed"):
                                                        self.maximum_number_cells_packed = value
                                                        self.maximum_number_cells_packed.value_namespace = name_space
                                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-number-cells-un-packed"):
                                                        self.maximum_number_cells_un_packed = value
                                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vci"):
                                                        self.vci = value
                                                        self.vci.value_namespace = name_space
                                                        self.vci.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpi"):
                                                        self.vpi = value
                                                        self.vpi.value_namespace = name_space
                                                        self.vpi.value_namespace_prefix = name_space_prefix


                                            class Fr(Entity):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                    self.yang_name = "fr"
                                                    self.yang_parent_name = "parameters"

                                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("dlci",
                                                                    "fr_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.dlci.is_set or
                                                        self.fr_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.dlci.yfilter != YFilter.not_set or
                                                        self.fr_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "dlci" or name == "fr-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "dlci"):
                                                        self.dlci = value
                                                        self.dlci.value_namespace = name_space
                                                        self.dlci.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fr-mode"):
                                                        self.fr_mode = value
                                                        self.fr_mode.value_namespace = name_space
                                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                                            class PseudowireEther(Entity):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                    self.yang_name = "pseudowire-ether"
                                                    self.yang_parent_name = "parameters"

                                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._children_yang_names.add("interface-list")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("internal_label",
                                                                    "is_valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-ether"

                                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                        self.interface = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_list_id",
                                                                        "interface_list_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "replicate_status") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.replicate_status.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.replicate_status.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "interface" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "replicate-status"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "replicate-status"):
                                                                self.replicate_status = value
                                                                self.replicate_status.value_namespace = name_space
                                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.interface:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.interface_list_id.is_set or
                                                            self.interface_list_name.is_set)

                                                    def has_operation(self):
                                                        for c in self.interface:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_list_id.yfilter != YFilter.not_set or
                                                            self.interface_list_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface-list" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "interface"):
                                                            for c in self.interface:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.interface.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-list-id"):
                                                            self.interface_list_id = value
                                                            self.interface_list_id.value_namespace = name_space
                                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-list-name"):
                                                            self.interface_list_name = value
                                                            self.interface_list_name.value_namespace = name_space
                                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.internal_label.is_set or
                                                        self.is_valid.is_set or
                                                        (self.interface_list is not None and self.interface_list.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.internal_label.yfilter != YFilter.not_set or
                                                        self.is_valid.yfilter != YFilter.not_set or
                                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pseudowire-ether" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface-list"):
                                                        if (self.interface_list is None):
                                                            self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                            self.interface_list.parent = self
                                                            self._children_name_map["interface_list"] = "interface-list"
                                                        return self.interface_list

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "internal-label"):
                                                        self.internal_label = value
                                                        self.internal_label.value_namespace = name_space
                                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-valid"):
                                                        self.is_valid = value
                                                        self.is_valid.value_namespace = name_space
                                                        self.is_valid.value_namespace_prefix = name_space_prefix


                                            class PseudowireIw(Entity):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                    self.yang_name = "pseudowire-iw"
                                                    self.yang_parent_name = "parameters"

                                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._children_yang_names.add("interface-list")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("internal_label",
                                                                    "is_valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-iw"

                                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                        self.interface = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_list_id",
                                                                        "interface_list_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "replicate_status") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.replicate_status.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.replicate_status.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "interface" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "replicate-status"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "replicate-status"):
                                                                self.replicate_status = value
                                                                self.replicate_status.value_namespace = name_space
                                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.interface:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.interface_list_id.is_set or
                                                            self.interface_list_name.is_set)

                                                    def has_operation(self):
                                                        for c in self.interface:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_list_id.yfilter != YFilter.not_set or
                                                            self.interface_list_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface-list" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "interface"):
                                                            for c in self.interface:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.interface.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-list-id"):
                                                            self.interface_list_id = value
                                                            self.interface_list_id.value_namespace = name_space
                                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-list-name"):
                                                            self.interface_list_name = value
                                                            self.interface_list_name.value_namespace = name_space
                                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.internal_label.is_set or
                                                        self.is_valid.is_set or
                                                        (self.interface_list is not None and self.interface_list.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.internal_label.yfilter != YFilter.not_set or
                                                        self.is_valid.yfilter != YFilter.not_set or
                                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pseudowire-iw" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface-list"):
                                                        if (self.interface_list is None):
                                                            self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                            self.interface_list.parent = self
                                                            self._children_name_map["interface_list"] = "interface-list"
                                                        return self.interface_list

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "internal-label"):
                                                        self.internal_label = value
                                                        self.internal_label.value_namespace = name_space
                                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-valid"):
                                                        self.is_valid = value
                                                        self.is_valid.value_namespace = name_space
                                                        self.is_valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.type.is_set or
                                                    (self.atm is not None and self.atm.has_data()) or
                                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                                    (self.fr is not None and self.fr.has_data()) or
                                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                    (self.tdm is not None and self.tdm.has_data()) or
                                                    (self.vlan is not None and self.vlan.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.type.yfilter != YFilter.not_set or
                                                    (self.atm is not None and self.atm.has_operation()) or
                                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                                    (self.fr is not None and self.fr.has_operation()) or
                                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                    (self.tdm is not None and self.tdm.has_operation()) or
                                                    (self.vlan is not None and self.vlan.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "parameters" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "atm"):
                                                    if (self.atm is None):
                                                        self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                        self.atm.parent = self
                                                        self._children_name_map["atm"] = "atm"
                                                    return self.atm

                                                if (child_yang_name == "ethernet"):
                                                    if (self.ethernet is None):
                                                        self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                        self.ethernet.parent = self
                                                        self._children_name_map["ethernet"] = "ethernet"
                                                    return self.ethernet

                                                if (child_yang_name == "fr"):
                                                    if (self.fr is None):
                                                        self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                        self.fr.parent = self
                                                        self._children_name_map["fr"] = "fr"
                                                    return self.fr

                                                if (child_yang_name == "pseudowire-ether"):
                                                    if (self.pseudowire_ether is None):
                                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                        self.pseudowire_ether.parent = self
                                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                    return self.pseudowire_ether

                                                if (child_yang_name == "pseudowire-iw"):
                                                    if (self.pseudowire_iw is None):
                                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                        self.pseudowire_iw.parent = self
                                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                    return self.pseudowire_iw

                                                if (child_yang_name == "tdm"):
                                                    if (self.tdm is None):
                                                        self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                        self.tdm.parent = self
                                                        self._children_name_map["tdm"] = "tdm"
                                                    return self.tdm

                                                if (child_yang_name == "vlan"):
                                                    if (self.vlan is None):
                                                        self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                        self.vlan.parent = self
                                                        self._children_name_map["vlan"] = "vlan"
                                                    return self.vlan

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "type"):
                                                    self.type = value
                                                    self.type.value_namespace = name_space
                                                    self.type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.mtu.is_set or
                                                self.name.is_set or
                                                self.payload_bytes.is_set or
                                                (self.parameters is not None and self.parameters.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mtu.yfilter != YFilter.not_set or
                                                self.name.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                (self.parameters is not None and self.parameters.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mtu.get_name_leafdata())
                                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.name.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "parameters"):
                                                if (self.parameters is None):
                                                    self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                                    self.parameters.parent = self
                                                    self._children_name_map["parameters"] = "parameters"
                                                return self.parameters

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mtu"):
                                                self.mtu = value
                                                self.mtu.value_namespace = name_space
                                                self.mtu.value_namespace_prefix = name_space_prefix
                                            if(value_path == "name"):
                                                self.name = value
                                                self.name.value_namespace = name_space
                                                self.name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                                    class PreferredPath(Entity):
                                        """
                                        MPLS Preferred Path
                                        
                                        .. attribute:: ip_tunnel_interface_number
                                        
                                        	IPTunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop_ip
                                        
                                        	NextHopIP
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: option
                                        
                                        	Option
                                        	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                        
                                        .. attribute:: te_tunnel_interface_number
                                        
                                        	TETunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tp_tunnel_interface_number
                                        
                                        	TPTunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                            self.yang_name = "preferred-path"
                                            self.yang_parent_name = "pseudowire"

                                            self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                            self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                            self.option = YLeaf(YType.enumeration, "option")

                                            self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                            self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ip_tunnel_interface_number",
                                                            "next_hop_ip",
                                                            "option",
                                                            "te_tunnel_interface_number",
                                                            "tp_tunnel_interface_number") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ip_tunnel_interface_number.is_set or
                                                self.next_hop_ip.is_set or
                                                self.option.is_set or
                                                self.te_tunnel_interface_number.is_set or
                                                self.tp_tunnel_interface_number.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                                self.next_hop_ip.yfilter != YFilter.not_set or
                                                self.option.yfilter != YFilter.not_set or
                                                self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                                self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "preferred-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                            if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.option.get_name_leafdata())
                                            if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                            if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ip-tunnel-interface-number"):
                                                self.ip_tunnel_interface_number = value
                                                self.ip_tunnel_interface_number.value_namespace = name_space
                                                self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-ip"):
                                                self.next_hop_ip = value
                                                self.next_hop_ip.value_namespace = name_space
                                                self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                            if(value_path == "option"):
                                                self.option = value
                                                self.option.value_namespace = name_space
                                                self.option.value_namespace_prefix = name_space_prefix
                                            if(value_path == "te-tunnel-interface-number"):
                                                self.te_tunnel_interface_number = value
                                                self.te_tunnel_interface_number.value_namespace = name_space
                                                self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tp-tunnel-interface-number"):
                                                self.tp_tunnel_interface_number = value
                                                self.tp_tunnel_interface_number.value_namespace = name_space
                                                self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                                    class LocalSignalling(Entity):
                                        """
                                        Local signalling
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                            self.yang_name = "local-signalling"
                                            self.yang_parent_name = "pseudowire"

                                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                                            self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                            self._children_yang_names.add("status-tlv")

                                            self.tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("pw_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                        class StatusTlv(Entity):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                                self.yang_name = "status-tlv"
                                                self.yang_parent_name = "local-signalling"

                                                self.description = YLeaf(YType.str, "description")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                                self.remote_address = YLeaf(YType.str, "remote-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("description",
                                                                "local_address",
                                                                "pw_id",
                                                                "remote_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.description.is_set or
                                                    self.local_address.is_set or
                                                    self.pw_id.is_set or
                                                    self.remote_address.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.local_address.yfilter != YFilter.not_set or
                                                    self.pw_id.yfilter != YFilter.not_set or
                                                    self.remote_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "status-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-address"):
                                                    self.local_address = value
                                                    self.local_address.value_namespace = name_space
                                                    self.local_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pw-id"):
                                                    self.pw_id = value
                                                    self.pw_id.value_namespace = name_space
                                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-address"):
                                                    self.remote_address = value
                                                    self.remote_address.value_namespace = name_space
                                                    self.remote_address.value_namespace_prefix = name_space_prefix


                                        class Tlv(Entity):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "local-signalling"

                                                self.description = YLeaf(YType.str, "description")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                                self.remote_address = YLeaf(YType.str, "remote-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("description",
                                                                "local_address",
                                                                "pw_id",
                                                                "remote_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.description.is_set or
                                                    self.local_address.is_set or
                                                    self.pw_id.is_set or
                                                    self.remote_address.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.local_address.yfilter != YFilter.not_set or
                                                    self.pw_id.yfilter != YFilter.not_set or
                                                    self.remote_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-address"):
                                                    self.local_address = value
                                                    self.local_address.value_namespace = name_space
                                                    self.local_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pw-id"):
                                                    self.pw_id = value
                                                    self.pw_id.value_namespace = name_space
                                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-address"):
                                                    self.remote_address = value
                                                    self.remote_address.value_namespace = name_space
                                                    self.remote_address.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.tlv:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.pw_status.is_set or
                                                (self.status_tlv is not None and self.status_tlv.has_data()))

                                        def has_operation(self):
                                            for c in self.tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.pw_status.yfilter != YFilter.not_set or
                                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-signalling" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "status-tlv"):
                                                if (self.status_tlv is None):
                                                    self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                                    self.status_tlv.parent = self
                                                    self._children_name_map["status_tlv"] = "status-tlv"
                                                return self.status_tlv

                                            if (child_yang_name == "tlv"):
                                                for c in self.tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.tlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "pw-status"):
                                                self.pw_status = value
                                                self.pw_status.value_namespace = name_space
                                                self.pw_status.value_namespace_prefix = name_space_prefix


                                    class RemoteSignalling(Entity):
                                        """
                                        Remote signalling
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                            self.yang_name = "remote-signalling"
                                            self.yang_parent_name = "pseudowire"

                                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                                            self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                            self._children_yang_names.add("status-tlv")

                                            self.tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("pw_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                        class StatusTlv(Entity):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                                self.yang_name = "status-tlv"
                                                self.yang_parent_name = "remote-signalling"

                                                self.description = YLeaf(YType.str, "description")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                                self.remote_address = YLeaf(YType.str, "remote-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("description",
                                                                "local_address",
                                                                "pw_id",
                                                                "remote_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.description.is_set or
                                                    self.local_address.is_set or
                                                    self.pw_id.is_set or
                                                    self.remote_address.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.local_address.yfilter != YFilter.not_set or
                                                    self.pw_id.yfilter != YFilter.not_set or
                                                    self.remote_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "status-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-address"):
                                                    self.local_address = value
                                                    self.local_address.value_namespace = name_space
                                                    self.local_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pw-id"):
                                                    self.pw_id = value
                                                    self.pw_id.value_namespace = name_space
                                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-address"):
                                                    self.remote_address = value
                                                    self.remote_address.value_namespace = name_space
                                                    self.remote_address.value_namespace_prefix = name_space_prefix


                                        class Tlv(Entity):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "remote-signalling"

                                                self.description = YLeaf(YType.str, "description")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                                self.remote_address = YLeaf(YType.str, "remote-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("description",
                                                                "local_address",
                                                                "pw_id",
                                                                "remote_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.description.is_set or
                                                    self.local_address.is_set or
                                                    self.pw_id.is_set or
                                                    self.remote_address.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.local_address.yfilter != YFilter.not_set or
                                                    self.pw_id.yfilter != YFilter.not_set or
                                                    self.remote_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-address"):
                                                    self.local_address = value
                                                    self.local_address.value_namespace = name_space
                                                    self.local_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pw-id"):
                                                    self.pw_id = value
                                                    self.pw_id.value_namespace = name_space
                                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-address"):
                                                    self.remote_address = value
                                                    self.remote_address.value_namespace = name_space
                                                    self.remote_address.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.tlv:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.pw_status.is_set or
                                                (self.status_tlv is not None and self.status_tlv.has_data()))

                                        def has_operation(self):
                                            for c in self.tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.pw_status.yfilter != YFilter.not_set or
                                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-signalling" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "status-tlv"):
                                                if (self.status_tlv is None):
                                                    self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                                    self.status_tlv.parent = self
                                                    self._children_name_map["status_tlv"] = "status-tlv"
                                                return self.status_tlv

                                            if (child_yang_name == "tlv"):
                                                for c in self.tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.tlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "pw-status"):
                                                self.pw_status = value
                                                self.pw_status.value_namespace = name_space
                                                self.pw_status.value_namespace_prefix = name_space_prefix


                                    class Statistics(Entity):
                                        """
                                        Statistics
                                        
                                        .. attribute:: dispostion_stats
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                        
                                        .. attribute:: impostion_stats
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                        
                                        .. attribute:: sequence_number
                                        
                                        	sequence numbers
                                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                            self.yang_name = "statistics"
                                            self.yang_parent_name = "pseudowire"

                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            self._children_yang_names.add("dispostion-stats")

                                            self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                            self._children_yang_names.add("impostion-stats")

                                            self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                            self._children_yang_names.add("sequence-number")


                                        class ImpostionStats(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast
                                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                            
                                            .. attribute:: imposition_mtu_drop
                                            
                                            	imposition mtu drop stats
                                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                            
                                            .. attribute:: imposition_stat
                                            
                                            	imposition stats
                                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                            
                                            .. attribute:: impostion_tail_drop
                                            
                                            	imposition tail drop stats
                                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                            
                                            .. attribute:: l2fsbi_drop
                                            
                                            	rx discards
                                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast
                                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Unknown Unicast
                                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                                self.yang_name = "impostion-stats"
                                                self.yang_parent_name = "statistics"

                                                self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                                self._children_yang_names.add("broadcast")

                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                self._children_yang_names.add("imposition-mtu-drop")

                                                self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                                self._children_yang_names.add("imposition-stat")

                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                self._children_yang_names.add("impostion-tail-drop")

                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                                self._children_yang_names.add("known-unicast")

                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                self._children_yang_names.add("l2fsbi-drop")

                                                self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                                self._children_yang_names.add("multicast")

                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                self._children_yang_names.add("unknown-unicast")


                                            class ImpositionStat(Entity):
                                                """
                                                imposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                    self.yang_name = "imposition-stat"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "imposition-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class ImpositionMtuDrop(Entity):
                                                """
                                                imposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                    self.yang_name = "imposition-mtu-drop"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class ImpostionTailDrop(Entity):
                                                """
                                                imposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                    self.yang_name = "impostion-tail-drop"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "impostion-tail-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class L2FsbiDrop(Entity):
                                                """
                                                rx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                    self.yang_name = "l2fsbi-drop"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "l2fsbi-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class Multicast(Entity):
                                                """
                                                Multicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                    self.yang_name = "multicast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class Broadcast(Entity):
                                                """
                                                Broadcast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                    self.yang_name = "broadcast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "broadcast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "known-unicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class UnknownUnicast(Entity):
                                                """
                                                Unknown Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                    self.yang_name = "unknown-unicast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unknown-unicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                    (self.multicast is not None and self.multicast.has_data()) or
                                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                    (self.multicast is not None and self.multicast.has_operation()) or
                                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "broadcast"):
                                                    if (self.broadcast is None):
                                                        self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                        self.broadcast.parent = self
                                                        self._children_name_map["broadcast"] = "broadcast"
                                                    return self.broadcast

                                                if (child_yang_name == "imposition-mtu-drop"):
                                                    if (self.imposition_mtu_drop is None):
                                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                        self.imposition_mtu_drop.parent = self
                                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                    return self.imposition_mtu_drop

                                                if (child_yang_name == "imposition-stat"):
                                                    if (self.imposition_stat is None):
                                                        self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                        self.imposition_stat.parent = self
                                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                                    return self.imposition_stat

                                                if (child_yang_name == "impostion-tail-drop"):
                                                    if (self.impostion_tail_drop is None):
                                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                        self.impostion_tail_drop.parent = self
                                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                    return self.impostion_tail_drop

                                                if (child_yang_name == "known-unicast"):
                                                    if (self.known_unicast is None):
                                                        self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                        self.known_unicast.parent = self
                                                        self._children_name_map["known_unicast"] = "known-unicast"
                                                    return self.known_unicast

                                                if (child_yang_name == "l2fsbi-drop"):
                                                    if (self.l2fsbi_drop is None):
                                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                        self.l2fsbi_drop.parent = self
                                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                    return self.l2fsbi_drop

                                                if (child_yang_name == "multicast"):
                                                    if (self.multicast is None):
                                                        self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                        self.multicast.parent = self
                                                        self._children_name_map["multicast"] = "multicast"
                                                    return self.multicast

                                                if (child_yang_name == "unknown-unicast"):
                                                    if (self.unknown_unicast is None):
                                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                        self.unknown_unicast.parent = self
                                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                    return self.unknown_unicast

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class DispostionStats(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: broadcast_drop
                                            
                                            	disposition storm control broadcast drop stats
                                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                            
                                            .. attribute:: dai_drop
                                            
                                            	Disposition dynamic ARP inspection drop statistics
                                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                            
                                            .. attribute:: disposition_mtu_drop
                                            
                                            	disposition mtu drop stats
                                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                            
                                            .. attribute:: disposition_oo_o_drops
                                            
                                            	Disposition Out\-of\-Order Drops
                                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                            
                                            .. attribute:: disposition_p2mp_stats
                                            
                                            	Disposition P2MP Stats
                                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                            
                                            .. attribute:: disposition_stat
                                            
                                            	disposition stats
                                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                            
                                            .. attribute:: disposition_tail_drop
                                            
                                            	disposition tail drop stats
                                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                            
                                            .. attribute:: ipsg_drop
                                            
                                            	disposition IP source guard drop statistics
                                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                            
                                            .. attribute:: mac_move
                                            
                                            	MAC Move
                                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                            
                                            .. attribute:: multicast_drop
                                            
                                            	disposition storm control multicast drop stats
                                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                            
                                            .. attribute:: received_drops
                                            
                                            	tx discards
                                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                            
                                            .. attribute:: unicast_drop
                                            
                                            	disposition storm control unknown unicast drop stats
                                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                                self.yang_name = "dispostion-stats"
                                                self.yang_parent_name = "statistics"

                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                self._children_yang_names.add("broadcast-drop")

                                                self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                                self._children_yang_names.add("dai-drop")

                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                self._children_yang_names.add("disposition-mtu-drop")

                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                self._children_yang_names.add("disposition-oo-o-drops")

                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                self._children_yang_names.add("disposition-p2mp-stats")

                                                self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                                self._children_yang_names.add("disposition-stat")

                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                self._children_yang_names.add("disposition-tail-drop")

                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                self._children_yang_names.add("ipsg-drop")

                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                                self._children_yang_names.add("known-unicast")

                                                self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                                self._children_yang_names.add("mac-move")

                                                self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                                self._children_yang_names.add("multicast-drop")

                                                self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                                self._children_yang_names.add("received-drops")

                                                self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                                self._children_yang_names.add("unicast-drop")


                                            class DispositionStat(Entity):
                                                """
                                                disposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                    self.yang_name = "disposition-stat"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionMtuDrop(Entity):
                                                """
                                                disposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                    self.yang_name = "disposition-mtu-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionTailDrop(Entity):
                                                """
                                                disposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                    self.yang_name = "disposition-tail-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-tail-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class MulticastDrop(Entity):
                                                """
                                                disposition storm control multicast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                    self.yang_name = "multicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multicast-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class UnicastDrop(Entity):
                                                """
                                                disposition storm control unknown unicast drop
                                                stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                    self.yang_name = "unicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unicast-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class BroadcastDrop(Entity):
                                                """
                                                disposition storm control broadcast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                    self.yang_name = "broadcast-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "broadcast-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class ReceivedDrops(Entity):
                                                """
                                                tx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                    self.yang_name = "received-drops"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "received-drops" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DaiDrop(Entity):
                                                """
                                                Disposition dynamic ARP inspection drop
                                                statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                    self.yang_name = "dai-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dai-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class IpsgDrop(Entity):
                                                """
                                                disposition IP source guard drop statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                    self.yang_name = "ipsg-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ipsg-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionOoODrops(Entity):
                                                """
                                                Disposition Out\-of\-Order Drops
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                    self.yang_name = "disposition-oo-o-drops"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionP2MpStats(Entity):
                                                """
                                                Disposition P2MP Stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                    self.yang_name = "disposition-p2mp-stats"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "known-unicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class MacMove(Entity):
                                                """
                                                MAC Move
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                    self.yang_name = "mac-move"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "mac-move" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dispostion-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "broadcast-drop"):
                                                    if (self.broadcast_drop is None):
                                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                        self.broadcast_drop.parent = self
                                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                    return self.broadcast_drop

                                                if (child_yang_name == "dai-drop"):
                                                    if (self.dai_drop is None):
                                                        self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                        self.dai_drop.parent = self
                                                        self._children_name_map["dai_drop"] = "dai-drop"
                                                    return self.dai_drop

                                                if (child_yang_name == "disposition-mtu-drop"):
                                                    if (self.disposition_mtu_drop is None):
                                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                        self.disposition_mtu_drop.parent = self
                                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                    return self.disposition_mtu_drop

                                                if (child_yang_name == "disposition-oo-o-drops"):
                                                    if (self.disposition_oo_o_drops is None):
                                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                        self.disposition_oo_o_drops.parent = self
                                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                    return self.disposition_oo_o_drops

                                                if (child_yang_name == "disposition-p2mp-stats"):
                                                    if (self.disposition_p2mp_stats is None):
                                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                        self.disposition_p2mp_stats.parent = self
                                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                    return self.disposition_p2mp_stats

                                                if (child_yang_name == "disposition-stat"):
                                                    if (self.disposition_stat is None):
                                                        self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                        self.disposition_stat.parent = self
                                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                                    return self.disposition_stat

                                                if (child_yang_name == "disposition-tail-drop"):
                                                    if (self.disposition_tail_drop is None):
                                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                        self.disposition_tail_drop.parent = self
                                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                    return self.disposition_tail_drop

                                                if (child_yang_name == "ipsg-drop"):
                                                    if (self.ipsg_drop is None):
                                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                        self.ipsg_drop.parent = self
                                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                    return self.ipsg_drop

                                                if (child_yang_name == "known-unicast"):
                                                    if (self.known_unicast is None):
                                                        self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                        self.known_unicast.parent = self
                                                        self._children_name_map["known_unicast"] = "known-unicast"
                                                    return self.known_unicast

                                                if (child_yang_name == "mac-move"):
                                                    if (self.mac_move is None):
                                                        self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                        self.mac_move.parent = self
                                                        self._children_name_map["mac_move"] = "mac-move"
                                                    return self.mac_move

                                                if (child_yang_name == "multicast-drop"):
                                                    if (self.multicast_drop is None):
                                                        self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                        self.multicast_drop.parent = self
                                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                                    return self.multicast_drop

                                                if (child_yang_name == "received-drops"):
                                                    if (self.received_drops is None):
                                                        self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                        self.received_drops.parent = self
                                                        self._children_name_map["received_drops"] = "received-drops"
                                                    return self.received_drops

                                                if (child_yang_name == "unicast-drop"):
                                                    if (self.unicast_drop is None):
                                                        self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                        self.unicast_drop.parent = self
                                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                                    return self.unicast_drop

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class SequenceNumber(Entity):
                                            """
                                            sequence numbers
                                            
                                            .. attribute:: bypassed_inbound_sequence_packet
                                            
                                            	Bypassed inbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bypassed_out_sequence_packet
                                            
                                            	Bypassed outbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: sequence_number_expected
                                            
                                            	sequence number expected
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sequence_number_sent
                                            
                                            	sequence number sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                                self.yang_name = "sequence-number"
                                                self.yang_parent_name = "statistics"

                                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bypassed_inbound_sequence_packet",
                                                                "bypassed_out_sequence_packet",
                                                                "sequence_number_expected",
                                                                "sequence_number_sent") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bypassed_inbound_sequence_packet.is_set or
                                                    self.bypassed_out_sequence_packet.is_set or
                                                    self.sequence_number_expected.is_set or
                                                    self.sequence_number_sent.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sequence-number" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bypassed-inbound-sequence-packet"):
                                                    self.bypassed_inbound_sequence_packet = value
                                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bypassed-out-sequence-packet"):
                                                    self.bypassed_out_sequence_packet = value
                                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sequence-number-expected"):
                                                    self.sequence_number_expected = value
                                                    self.sequence_number_expected.value_namespace = name_space
                                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sequence-number-sent"):
                                                    self.sequence_number_sent = value
                                                    self.sequence_number_sent.value_namespace = name_space
                                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                                (self.sequence_number is not None and self.sequence_number.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "statistics" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dispostion-stats"):
                                                if (self.dispostion_stats is None):
                                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                                    self.dispostion_stats.parent = self
                                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                                return self.dispostion_stats

                                            if (child_yang_name == "impostion-stats"):
                                                if (self.impostion_stats is None):
                                                    self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                                    self.impostion_stats.parent = self
                                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                                return self.impostion_stats

                                            if (child_yang_name == "sequence-number"):
                                                if (self.sequence_number is None):
                                                    self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                                    self.sequence_number.parent = self
                                                    self._children_name_map["sequence_number"] = "sequence-number"
                                                return self.sequence_number

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class P2MpPw(Entity):
                                        """
                                        P2MP Pseudowire Information
                                        
                                        .. attribute:: local_available
                                        
                                        	Local LSM info available
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_extended_tunnel_id
                                        
                                        	Local Extended Tunnel ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_flags
                                        
                                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_label
                                        
                                        	Local Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_p2mp_id
                                        
                                        	Local P2MP ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ptree_type
                                        
                                        	Local P\-Tree Type
                                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                        
                                        .. attribute:: local_tunnel_id
                                        
                                        	Local Tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_available
                                        
                                        	Remote LSM info available
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_extended_tunnel_id
                                        
                                        	Remote Extended Tunnel ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_flags
                                        
                                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_p2mp_id
                                        
                                        	Remote P2MP ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ptree_type
                                        
                                        	Remote P\-Tree Type
                                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                        
                                        .. attribute:: remote_tunnel_id
                                        
                                        	Remote Tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__init__()

                                            self.yang_name = "p2mp-pw"
                                            self.yang_parent_name = "pseudowire"

                                            self.local_available = YLeaf(YType.boolean, "local-available")

                                            self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                            self.local_flags = YLeaf(YType.uint8, "local-flags")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                            self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                            self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                            self.remote_available = YLeaf(YType.boolean, "remote-available")

                                            self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                            self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                                            self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                            self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                            self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("local_available",
                                                            "local_extended_tunnel_id",
                                                            "local_flags",
                                                            "local_label",
                                                            "local_p2mp_id",
                                                            "local_ptree_type",
                                                            "local_tunnel_id",
                                                            "remote_available",
                                                            "remote_extended_tunnel_id",
                                                            "remote_flags",
                                                            "remote_label",
                                                            "remote_p2mp_id",
                                                            "remote_ptree_type",
                                                            "remote_tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.local_available.is_set or
                                                self.local_extended_tunnel_id.is_set or
                                                self.local_flags.is_set or
                                                self.local_label.is_set or
                                                self.local_p2mp_id.is_set or
                                                self.local_ptree_type.is_set or
                                                self.local_tunnel_id.is_set or
                                                self.remote_available.is_set or
                                                self.remote_extended_tunnel_id.is_set or
                                                self.remote_flags.is_set or
                                                self.remote_label.is_set or
                                                self.remote_p2mp_id.is_set or
                                                self.remote_ptree_type.is_set or
                                                self.remote_tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.local_available.yfilter != YFilter.not_set or
                                                self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                                self.local_flags.yfilter != YFilter.not_set or
                                                self.local_label.yfilter != YFilter.not_set or
                                                self.local_p2mp_id.yfilter != YFilter.not_set or
                                                self.local_ptree_type.yfilter != YFilter.not_set or
                                                self.local_tunnel_id.yfilter != YFilter.not_set or
                                                self.remote_available.yfilter != YFilter.not_set or
                                                self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                                self.remote_flags.yfilter != YFilter.not_set or
                                                self.remote_label.yfilter != YFilter.not_set or
                                                self.remote_p2mp_id.yfilter != YFilter.not_set or
                                                self.remote_ptree_type.yfilter != YFilter.not_set or
                                                self.remote_tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "p2mp-pw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_available.get_name_leafdata())
                                            if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                            if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_flags.get_name_leafdata())
                                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_label.get_name_leafdata())
                                            if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                            if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                            if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                            if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_available.get_name_leafdata())
                                            if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                            if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                                            if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                            if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                            if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "local-available"):
                                                self.local_available = value
                                                self.local_available.value_namespace = name_space
                                                self.local_available.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-extended-tunnel-id"):
                                                self.local_extended_tunnel_id = value
                                                self.local_extended_tunnel_id.value_namespace = name_space
                                                self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-flags"):
                                                self.local_flags = value
                                                self.local_flags.value_namespace = name_space
                                                self.local_flags.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-label"):
                                                self.local_label = value
                                                self.local_label.value_namespace = name_space
                                                self.local_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-p2mp-id"):
                                                self.local_p2mp_id = value
                                                self.local_p2mp_id.value_namespace = name_space
                                                self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ptree-type"):
                                                self.local_ptree_type = value
                                                self.local_ptree_type.value_namespace = name_space
                                                self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-tunnel-id"):
                                                self.local_tunnel_id = value
                                                self.local_tunnel_id.value_namespace = name_space
                                                self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-available"):
                                                self.remote_available = value
                                                self.remote_available.value_namespace = name_space
                                                self.remote_available.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-extended-tunnel-id"):
                                                self.remote_extended_tunnel_id = value
                                                self.remote_extended_tunnel_id.value_namespace = name_space
                                                self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-flags"):
                                                self.remote_flags = value
                                                self.remote_flags.value_namespace = name_space
                                                self.remote_flags.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-label"):
                                                self.remote_label = value
                                                self.remote_label.value_namespace = name_space
                                                self.remote_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-p2mp-id"):
                                                self.remote_p2mp_id = value
                                                self.remote_p2mp_id.value_namespace = name_space
                                                self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ptree-type"):
                                                self.remote_ptree_type = value
                                                self.remote_ptree_type.value_namespace = name_space
                                                self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-tunnel-id"):
                                                self.remote_tunnel_id = value
                                                self.remote_tunnel_id.value_namespace = name_space
                                                self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.ad_method.is_set or
                                            self.ad_remote_down.is_set or
                                            self.admited_bw.is_set or
                                            self.auto_discovery.is_set or
                                            self.backup_active.is_set or
                                            self.backup_force_active.is_set or
                                            self.backup_pw.is_set or
                                            self.bitrate_mismatched.is_set or
                                            self.bridge_pw_type_mismatch.is_set or
                                            self.cas_mismatched.is_set or
                                            self.diff_ts_mismatched.is_set or
                                            self.disable_delay.is_set or
                                            self.disable_never.is_set or
                                            self.evpn_src_acid.is_set or
                                            self.fe_ctype.is_set or
                                            self.forward_class.is_set or
                                            self.freq_mismatched.is_set or
                                            self.illegal_control_word.is_set or
                                            self.imposed_vlan_id.is_set or
                                            self.interworking.is_set or
                                            self.ipv6_local_source_address.is_set or
                                            self.is_evpnvpws_type.is_set or
                                            self.is_flow_label_static.is_set or
                                            self.is_multi_segment_pseudowire.is_set or
                                            self.is_partially_programmed.is_set or
                                            self.is_pwr_type.is_set or
                                            self.is_vfi.is_set or
                                            self.last_time_status_changed.is_set or
                                            self.last_time_status_down.is_set or
                                            self.ldp_label_advertise_failed.is_set or
                                            self.load_balance.is_set or
                                            self.local_control_word.is_set or
                                            self.local_label_failed.is_set or
                                            self.local_pseudo_wire_type.is_set or
                                            self.local_source_address.is_set or
                                            self.mac_limit_oper_down.is_set or
                                            self.mtu_mismatched.is_set or
                                            self.not_supported_qinq.is_set or
                                            self.num_ma_cwithdraw_msg_received.is_set or
                                            self.number_ma_cwithdraw_message_sent.is_set or
                                            self.out_of_memory_state.is_set or
                                            self.payload_bytes_mismatched.is_set or
                                            self.payload_type_mismatched.is_set or
                                            self.preferred_path_disable_fallback.is_set or
                                            self.primary_peer_id.is_set or
                                            self.primary_pseudo_wire_id.is_set or
                                            self.primary_pw.is_set or
                                            self.protocol.is_set or
                                            self.pseudo_wire_id.is_set or
                                            self.pseudo_wire_state.is_set or
                                            self.pseudo_wire_type_mismatched.is_set or
                                            self.pw_class_name.is_set or
                                            self.pw_flow_label_code17_disabled.is_set or
                                            self.pw_flow_label_type.is_set or
                                            self.pw_flow_label_type_cfg.is_set or
                                            self.pw_redundancy_initial_delay.is_set or
                                            self.pw_redundancy_one_way.is_set or
                                            self.pw_status_use.is_set or
                                            self.pwlsd_rewrite_failed.is_set or
                                            self.remote_control_word.is_set or
                                            self.remote_label_failed.is_set or
                                            self.remote_pseudo_wire_type.is_set or
                                            self.required_bw.is_set or
                                            self.resync_enabled.is_set or
                                            self.resync_threshold.is_set or
                                            self.rtp_mismatched.is_set or
                                            self.sequencing_type.is_set or
                                            self.shutdown.is_set or
                                            self.sig_pkts_mismatched.is_set or
                                            self.ssrc_mismatched.is_set or
                                            self.state.is_set or
                                            self.table_policy_name.is_set or
                                            self.tag_rewrite.is_set or
                                            self.time_created.is_set or
                                            self.time_elapsed_creation.is_set or
                                            self.time_elapsed_status_changed.is_set or
                                            self.time_elapsed_status_down.is_set or
                                            self.transport_lsp_down.is_set or
                                            self.xconnect_id.is_set or
                                            (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                            (self.local_interface is not None and self.local_interface.has_data()) or
                                            (self.local_signalling is not None and self.local_signalling.has_data()) or
                                            (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                            (self.peer_id is not None and self.peer_id.has_data()) or
                                            (self.preferred_path is not None and self.preferred_path.has_data()) or
                                            (self.remote_interface is not None and self.remote_interface.has_data()) or
                                            (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                            (self.statistics is not None and self.statistics.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ad_method.yfilter != YFilter.not_set or
                                            self.ad_remote_down.yfilter != YFilter.not_set or
                                            self.admited_bw.yfilter != YFilter.not_set or
                                            self.auto_discovery.yfilter != YFilter.not_set or
                                            self.backup_active.yfilter != YFilter.not_set or
                                            self.backup_force_active.yfilter != YFilter.not_set or
                                            self.backup_pw.yfilter != YFilter.not_set or
                                            self.bitrate_mismatched.yfilter != YFilter.not_set or
                                            self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                            self.cas_mismatched.yfilter != YFilter.not_set or
                                            self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                            self.disable_delay.yfilter != YFilter.not_set or
                                            self.disable_never.yfilter != YFilter.not_set or
                                            self.evpn_src_acid.yfilter != YFilter.not_set or
                                            self.fe_ctype.yfilter != YFilter.not_set or
                                            self.forward_class.yfilter != YFilter.not_set or
                                            self.freq_mismatched.yfilter != YFilter.not_set or
                                            self.illegal_control_word.yfilter != YFilter.not_set or
                                            self.imposed_vlan_id.yfilter != YFilter.not_set or
                                            self.interworking.yfilter != YFilter.not_set or
                                            self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                            self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                            self.is_flow_label_static.yfilter != YFilter.not_set or
                                            self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                            self.is_partially_programmed.yfilter != YFilter.not_set or
                                            self.is_pwr_type.yfilter != YFilter.not_set or
                                            self.is_vfi.yfilter != YFilter.not_set or
                                            self.last_time_status_changed.yfilter != YFilter.not_set or
                                            self.last_time_status_down.yfilter != YFilter.not_set or
                                            self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                            self.load_balance.yfilter != YFilter.not_set or
                                            self.local_control_word.yfilter != YFilter.not_set or
                                            self.local_label_failed.yfilter != YFilter.not_set or
                                            self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                            self.local_source_address.yfilter != YFilter.not_set or
                                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                            self.mtu_mismatched.yfilter != YFilter.not_set or
                                            self.not_supported_qinq.yfilter != YFilter.not_set or
                                            self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                            self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                            self.out_of_memory_state.yfilter != YFilter.not_set or
                                            self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                            self.payload_type_mismatched.yfilter != YFilter.not_set or
                                            self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                            self.primary_peer_id.yfilter != YFilter.not_set or
                                            self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                            self.primary_pw.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pseudo_wire_id.yfilter != YFilter.not_set or
                                            self.pseudo_wire_state.yfilter != YFilter.not_set or
                                            self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                            self.pw_class_name.yfilter != YFilter.not_set or
                                            self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                            self.pw_flow_label_type.yfilter != YFilter.not_set or
                                            self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                            self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                            self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                            self.pw_status_use.yfilter != YFilter.not_set or
                                            self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.remote_control_word.yfilter != YFilter.not_set or
                                            self.remote_label_failed.yfilter != YFilter.not_set or
                                            self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                            self.required_bw.yfilter != YFilter.not_set or
                                            self.resync_enabled.yfilter != YFilter.not_set or
                                            self.resync_threshold.yfilter != YFilter.not_set or
                                            self.rtp_mismatched.yfilter != YFilter.not_set or
                                            self.sequencing_type.yfilter != YFilter.not_set or
                                            self.shutdown.yfilter != YFilter.not_set or
                                            self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                            self.ssrc_mismatched.yfilter != YFilter.not_set or
                                            self.state.yfilter != YFilter.not_set or
                                            self.table_policy_name.yfilter != YFilter.not_set or
                                            self.tag_rewrite.yfilter != YFilter.not_set or
                                            self.time_created.yfilter != YFilter.not_set or
                                            self.time_elapsed_creation.yfilter != YFilter.not_set or
                                            self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                            self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                            self.transport_lsp_down.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                            (self.local_interface is not None and self.local_interface.has_operation()) or
                                            (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                            (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                            (self.peer_id is not None and self.peer_id.has_operation()) or
                                            (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                            (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                            (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                            (self.statistics is not None and self.statistics.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ad_method.get_name_leafdata())
                                        if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                        if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                        if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                        if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_active.get_name_leafdata())
                                        if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                        if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                        if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                        if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                        if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                        if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                        if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                        if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable_never.get_name_leafdata())
                                        if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                        if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                        if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.forward_class.get_name_leafdata())
                                        if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                        if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                        if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interworking.get_name_leafdata())
                                        if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                        if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                        if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                        if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                        if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                        if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                        if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                        if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                        if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                        if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                        if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.load_balance.get_name_leafdata())
                                        if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                        if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                        if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                        if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                        if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                        if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                        if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                        if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                        if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                        if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                        if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                        if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                        if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                        if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                        if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                        if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                        if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                        if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                        if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                        if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                        if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                        if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                        if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                        if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                        if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                        if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                        if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.required_bw.get_name_leafdata())
                                        if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                        if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                        if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                        if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                                        if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                        if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state.get_name_leafdata())
                                        if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                        if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                        if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_created.get_name_leafdata())
                                        if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                        if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                        if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                        if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "encapsulation-info"):
                                            if (self.encapsulation_info is None):
                                                self.encapsulation_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                                self.encapsulation_info.parent = self
                                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                            return self.encapsulation_info

                                        if (child_yang_name == "local-interface"):
                                            if (self.local_interface is None):
                                                self.local_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                                self.local_interface.parent = self
                                                self._children_name_map["local_interface"] = "local-interface"
                                            return self.local_interface

                                        if (child_yang_name == "local-signalling"):
                                            if (self.local_signalling is None):
                                                self.local_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                                self.local_signalling.parent = self
                                                self._children_name_map["local_signalling"] = "local-signalling"
                                            return self.local_signalling

                                        if (child_yang_name == "p2mp-pw"):
                                            if (self.p2mp_pw is None):
                                                self.p2mp_pw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                                self.p2mp_pw.parent = self
                                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                            return self.p2mp_pw

                                        if (child_yang_name == "peer-id"):
                                            if (self.peer_id is None):
                                                self.peer_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                                self.peer_id.parent = self
                                                self._children_name_map["peer_id"] = "peer-id"
                                            return self.peer_id

                                        if (child_yang_name == "preferred-path"):
                                            if (self.preferred_path is None):
                                                self.preferred_path = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                                self.preferred_path.parent = self
                                                self._children_name_map["preferred_path"] = "preferred-path"
                                            return self.preferred_path

                                        if (child_yang_name == "remote-interface"):
                                            if (self.remote_interface is None):
                                                self.remote_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                                self.remote_interface.parent = self
                                                self._children_name_map["remote_interface"] = "remote-interface"
                                            return self.remote_interface

                                        if (child_yang_name == "remote-signalling"):
                                            if (self.remote_signalling is None):
                                                self.remote_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                                self.remote_signalling.parent = self
                                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                            return self.remote_signalling

                                        if (child_yang_name == "statistics"):
                                            if (self.statistics is None):
                                                self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                                self.statistics.parent = self
                                                self._children_name_map["statistics"] = "statistics"
                                            return self.statistics

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ad-method"):
                                            self.ad_method = value
                                            self.ad_method.value_namespace = name_space
                                            self.ad_method.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ad-remote-down"):
                                            self.ad_remote_down = value
                                            self.ad_remote_down.value_namespace = name_space
                                            self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "admited-bw"):
                                            self.admited_bw = value
                                            self.admited_bw.value_namespace = name_space
                                            self.admited_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "auto-discovery"):
                                            self.auto_discovery = value
                                            self.auto_discovery.value_namespace = name_space
                                            self.auto_discovery.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-active"):
                                            self.backup_active = value
                                            self.backup_active.value_namespace = name_space
                                            self.backup_active.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-force-active"):
                                            self.backup_force_active = value
                                            self.backup_force_active.value_namespace = name_space
                                            self.backup_force_active.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-pw"):
                                            self.backup_pw = value
                                            self.backup_pw.value_namespace = name_space
                                            self.backup_pw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bitrate-mismatched"):
                                            self.bitrate_mismatched = value
                                            self.bitrate_mismatched.value_namespace = name_space
                                            self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bridge-pw-type-mismatch"):
                                            self.bridge_pw_type_mismatch = value
                                            self.bridge_pw_type_mismatch.value_namespace = name_space
                                            self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas-mismatched"):
                                            self.cas_mismatched = value
                                            self.cas_mismatched.value_namespace = name_space
                                            self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "diff-ts-mismatched"):
                                            self.diff_ts_mismatched = value
                                            self.diff_ts_mismatched.value_namespace = name_space
                                            self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable-delay"):
                                            self.disable_delay = value
                                            self.disable_delay.value_namespace = name_space
                                            self.disable_delay.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable-never"):
                                            self.disable_never = value
                                            self.disable_never.value_namespace = name_space
                                            self.disable_never.value_namespace_prefix = name_space_prefix
                                        if(value_path == "evpn-src-acid"):
                                            self.evpn_src_acid = value
                                            self.evpn_src_acid.value_namespace = name_space
                                            self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fe-ctype"):
                                            self.fe_ctype = value
                                            self.fe_ctype.value_namespace = name_space
                                            self.fe_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "forward-class"):
                                            self.forward_class = value
                                            self.forward_class.value_namespace = name_space
                                            self.forward_class.value_namespace_prefix = name_space_prefix
                                        if(value_path == "freq-mismatched"):
                                            self.freq_mismatched = value
                                            self.freq_mismatched.value_namespace = name_space
                                            self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "illegal-control-word"):
                                            self.illegal_control_word = value
                                            self.illegal_control_word.value_namespace = name_space
                                            self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                        if(value_path == "imposed-vlan-id"):
                                            self.imposed_vlan_id = value
                                            self.imposed_vlan_id.value_namespace = name_space
                                            self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interworking"):
                                            self.interworking = value
                                            self.interworking.value_namespace = name_space
                                            self.interworking.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-local-source-address"):
                                            self.ipv6_local_source_address = value
                                            self.ipv6_local_source_address.value_namespace = name_space
                                            self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpnvpws-type"):
                                            self.is_evpnvpws_type = value
                                            self.is_evpnvpws_type.value_namespace = name_space
                                            self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-flow-label-static"):
                                            self.is_flow_label_static = value
                                            self.is_flow_label_static.value_namespace = name_space
                                            self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-multi-segment-pseudowire"):
                                            self.is_multi_segment_pseudowire = value
                                            self.is_multi_segment_pseudowire.value_namespace = name_space
                                            self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-partially-programmed"):
                                            self.is_partially_programmed = value
                                            self.is_partially_programmed.value_namespace = name_space
                                            self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-pwr-type"):
                                            self.is_pwr_type = value
                                            self.is_pwr_type.value_namespace = name_space
                                            self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-vfi"):
                                            self.is_vfi = value
                                            self.is_vfi.value_namespace = name_space
                                            self.is_vfi.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-time-status-changed"):
                                            self.last_time_status_changed = value
                                            self.last_time_status_changed.value_namespace = name_space
                                            self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-time-status-down"):
                                            self.last_time_status_down = value
                                            self.last_time_status_down.value_namespace = name_space
                                            self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertise-failed"):
                                            self.ldp_label_advertise_failed = value
                                            self.ldp_label_advertise_failed.value_namespace = name_space
                                            self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "load-balance"):
                                            self.load_balance = value
                                            self.load_balance.value_namespace = name_space
                                            self.load_balance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-control-word"):
                                            self.local_control_word = value
                                            self.local_control_word.value_namespace = name_space
                                            self.local_control_word.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label-failed"):
                                            self.local_label_failed = value
                                            self.local_label_failed.value_namespace = name_space
                                            self.local_label_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-pseudo-wire-type"):
                                            self.local_pseudo_wire_type = value
                                            self.local_pseudo_wire_type.value_namespace = name_space
                                            self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-source-address"):
                                            self.local_source_address = value
                                            self.local_source_address.value_namespace = name_space
                                            self.local_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-oper-down"):
                                            self.mac_limit_oper_down = value
                                            self.mac_limit_oper_down.value_namespace = name_space
                                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mtu-mismatched"):
                                            self.mtu_mismatched = value
                                            self.mtu_mismatched.value_namespace = name_space
                                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "not-supported-qinq"):
                                            self.not_supported_qinq = value
                                            self.not_supported_qinq.value_namespace = name_space
                                            self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "num-ma-cwithdraw-msg-received"):
                                            self.num_ma_cwithdraw_msg_received = value
                                            self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                            self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-ma-cwithdraw-message-sent"):
                                            self.number_ma_cwithdraw_message_sent = value
                                            self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                            self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "out-of-memory-state"):
                                            self.out_of_memory_state = value
                                            self.out_of_memory_state.value_namespace = name_space
                                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes-mismatched"):
                                            self.payload_bytes_mismatched = value
                                            self.payload_bytes_mismatched.value_namespace = name_space
                                            self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-type-mismatched"):
                                            self.payload_type_mismatched = value
                                            self.payload_type_mismatched.value_namespace = name_space
                                            self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "preferred-path-disable-fallback"):
                                            self.preferred_path_disable_fallback = value
                                            self.preferred_path_disable_fallback.value_namespace = name_space
                                            self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                        if(value_path == "primary-peer-id"):
                                            self.primary_peer_id = value
                                            self.primary_peer_id.value_namespace = name_space
                                            self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "primary-pseudo-wire-id"):
                                            self.primary_pseudo_wire_id = value
                                            self.primary_pseudo_wire_id.value_namespace = name_space
                                            self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "primary-pw"):
                                            self.primary_pw = value
                                            self.primary_pw.value_namespace = name_space
                                            self.primary_pw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pseudo-wire-id"):
                                            self.pseudo_wire_id = value
                                            self.pseudo_wire_id.value_namespace = name_space
                                            self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pseudo-wire-state"):
                                            self.pseudo_wire_state = value
                                            self.pseudo_wire_state.value_namespace = name_space
                                            self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pseudo-wire-type-mismatched"):
                                            self.pseudo_wire_type_mismatched = value
                                            self.pseudo_wire_type_mismatched.value_namespace = name_space
                                            self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-class-name"):
                                            self.pw_class_name = value
                                            self.pw_class_name.value_namespace = name_space
                                            self.pw_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flow-label-code17-disabled"):
                                            self.pw_flow_label_code17_disabled = value
                                            self.pw_flow_label_code17_disabled.value_namespace = name_space
                                            self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flow-label-type"):
                                            self.pw_flow_label_type = value
                                            self.pw_flow_label_type.value_namespace = name_space
                                            self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flow-label-type-cfg"):
                                            self.pw_flow_label_type_cfg = value
                                            self.pw_flow_label_type_cfg.value_namespace = name_space
                                            self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-redundancy-initial-delay"):
                                            self.pw_redundancy_initial_delay = value
                                            self.pw_redundancy_initial_delay.value_namespace = name_space
                                            self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-redundancy-one-way"):
                                            self.pw_redundancy_one_way = value
                                            self.pw_redundancy_one_way.value_namespace = name_space
                                            self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-status-use"):
                                            self.pw_status_use = value
                                            self.pw_status_use.value_namespace = name_space
                                            self.pw_status_use.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pwlsd-rewrite-failed"):
                                            self.pwlsd_rewrite_failed = value
                                            self.pwlsd_rewrite_failed.value_namespace = name_space
                                            self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-control-word"):
                                            self.remote_control_word = value
                                            self.remote_control_word.value_namespace = name_space
                                            self.remote_control_word.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label-failed"):
                                            self.remote_label_failed = value
                                            self.remote_label_failed.value_namespace = name_space
                                            self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-pseudo-wire-type"):
                                            self.remote_pseudo_wire_type = value
                                            self.remote_pseudo_wire_type.value_namespace = name_space
                                            self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "required-bw"):
                                            self.required_bw = value
                                            self.required_bw.value_namespace = name_space
                                            self.required_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "resync-enabled"):
                                            self.resync_enabled = value
                                            self.resync_enabled.value_namespace = name_space
                                            self.resync_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "resync-threshold"):
                                            self.resync_threshold = value
                                            self.resync_threshold.value_namespace = name_space
                                            self.resync_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-mismatched"):
                                            self.rtp_mismatched = value
                                            self.rtp_mismatched.value_namespace = name_space
                                            self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequencing-type"):
                                            self.sequencing_type = value
                                            self.sequencing_type.value_namespace = name_space
                                            self.sequencing_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "shutdown"):
                                            self.shutdown = value
                                            self.shutdown.value_namespace = name_space
                                            self.shutdown.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sig-pkts-mismatched"):
                                            self.sig_pkts_mismatched = value
                                            self.sig_pkts_mismatched.value_namespace = name_space
                                            self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc-mismatched"):
                                            self.ssrc_mismatched = value
                                            self.ssrc_mismatched.value_namespace = name_space
                                            self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state"):
                                            self.state = value
                                            self.state.value_namespace = name_space
                                            self.state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "table-policy-name"):
                                            self.table_policy_name = value
                                            self.table_policy_name.value_namespace = name_space
                                            self.table_policy_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tag-rewrite"):
                                            self.tag_rewrite = value
                                            self.tag_rewrite.value_namespace = name_space
                                            self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-created"):
                                            self.time_created = value
                                            self.time_created.value_namespace = name_space
                                            self.time_created.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-elapsed-creation"):
                                            self.time_elapsed_creation = value
                                            self.time_elapsed_creation.value_namespace = name_space
                                            self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-elapsed-status-changed"):
                                            self.time_elapsed_status_changed = value
                                            self.time_elapsed_status_changed.value_namespace = name_space
                                            self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-elapsed-status-down"):
                                            self.time_elapsed_status_down = value
                                            self.time_elapsed_status_down.value_namespace = name_space
                                            self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transport-lsp-down"):
                                            self.transport_lsp_down = value
                                            self.transport_lsp_down.value_namespace = name_space
                                            self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "bridge-pw"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                        self._children_yang_names.add("base")

                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dhcpv4_trust",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"

                                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                            self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                            self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                            self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                            self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                            self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                            self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                            self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                            self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                            self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                            self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                            self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                            self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                            self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                            self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                            self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                            self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                            self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                            self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                            self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                            self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                            self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                            self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                            self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                            self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                            self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                            self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                            self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                            self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                            self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                            self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                            self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._children_yang_names.add("storm-control")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("broadcast_storm_control_kb_ps",
                                                            "broadcast_storm_control_pps",
                                                            "broadcast_storm_control_rate_unit",
                                                            "dai_address_validation_mask",
                                                            "dhcpv4_profile_name",
                                                            "dhcpv4_snoop",
                                                            "flood_unknown_unicast_enabled",
                                                            "flood_uu_disabled_mac_limit_action",
                                                            "igm_pv4_disabled",
                                                            "igm_pv4_profile_name",
                                                            "is_dai_addr_validate_destination_mac_enabled",
                                                            "is_dai_addr_validate_ipv4_enabled",
                                                            "is_dai_addr_validate_source_mac_enabled",
                                                            "is_dai_enabled",
                                                            "is_dai_logging_enabled",
                                                            "is_ip_source_guard_enabled",
                                                            "is_ipsg_logging_enabled",
                                                            "is_mac_secure_accept_shutdown_enabled",
                                                            "is_mac_secure_enabled",
                                                            "is_mac_secure_logging_enabled",
                                                            "learn_disabled_mac_limit_action",
                                                            "mac_aging_mode",
                                                            "mac_aging_time",
                                                            "mac_flooding",
                                                            "mac_learning",
                                                            "mac_limit",
                                                            "mac_limit_action",
                                                            "mac_limit_notification",
                                                            "mac_limit_reached",
                                                            "mac_port_down_flush_enabled",
                                                            "mac_secure_action",
                                                            "mld_profile_name",
                                                            "mmrp_flood_optimization",
                                                            "multicast_storm_control_kb_ps",
                                                            "multicast_storm_control_pps",
                                                            "multicast_storm_control_rate_unit",
                                                            "split_horizon_group_id",
                                                            "unicast_storm_control_kb_ps",
                                                            "unicast_storm_control_pps",
                                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"

                                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                self.multicast = YLeaf(YType.boolean, "multicast")

                                                self.unicast = YLeaf(YType.boolean, "unicast")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bd_policer",
                                                                "broadcast",
                                                                "multicast",
                                                                "unicast") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bd_policer.is_set or
                                                    self.broadcast.is_set or
                                                    self.multicast.is_set or
                                                    self.unicast.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bd_policer.yfilter != YFilter.not_set or
                                                    self.broadcast.yfilter != YFilter.not_set or
                                                    self.multicast.yfilter != YFilter.not_set or
                                                    self.unicast.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "storm-control" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bd-policer"):
                                                    self.bd_policer = value
                                                    self.bd_policer.value_namespace = name_space
                                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast"):
                                                    self.broadcast = value
                                                    self.broadcast.value_namespace = name_space
                                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast"):
                                                    self.multicast = value
                                                    self.multicast.value_namespace = name_space
                                                    self.multicast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast"):
                                                    self.unicast = value
                                                    self.unicast.value_namespace = name_space
                                                    self.unicast.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.broadcast_storm_control_kb_ps.is_set or
                                                self.broadcast_storm_control_pps.is_set or
                                                self.broadcast_storm_control_rate_unit.is_set or
                                                self.dai_address_validation_mask.is_set or
                                                self.dhcpv4_profile_name.is_set or
                                                self.dhcpv4_snoop.is_set or
                                                self.flood_unknown_unicast_enabled.is_set or
                                                self.flood_uu_disabled_mac_limit_action.is_set or
                                                self.igm_pv4_disabled.is_set or
                                                self.igm_pv4_profile_name.is_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                                self.is_dai_addr_validate_ipv4_enabled.is_set or
                                                self.is_dai_addr_validate_source_mac_enabled.is_set or
                                                self.is_dai_enabled.is_set or
                                                self.is_dai_logging_enabled.is_set or
                                                self.is_ip_source_guard_enabled.is_set or
                                                self.is_ipsg_logging_enabled.is_set or
                                                self.is_mac_secure_accept_shutdown_enabled.is_set or
                                                self.is_mac_secure_enabled.is_set or
                                                self.is_mac_secure_logging_enabled.is_set or
                                                self.learn_disabled_mac_limit_action.is_set or
                                                self.mac_aging_mode.is_set or
                                                self.mac_aging_time.is_set or
                                                self.mac_flooding.is_set or
                                                self.mac_learning.is_set or
                                                self.mac_limit.is_set or
                                                self.mac_limit_action.is_set or
                                                self.mac_limit_notification.is_set or
                                                self.mac_limit_reached.is_set or
                                                self.mac_port_down_flush_enabled.is_set or
                                                self.mac_secure_action.is_set or
                                                self.mld_profile_name.is_set or
                                                self.mmrp_flood_optimization.is_set or
                                                self.multicast_storm_control_kb_ps.is_set or
                                                self.multicast_storm_control_pps.is_set or
                                                self.multicast_storm_control_rate_unit.is_set or
                                                self.split_horizon_group_id.is_set or
                                                self.unicast_storm_control_kb_ps.is_set or
                                                self.unicast_storm_control_pps.is_set or
                                                self.unicast_storm_control_rate_unit.is_set or
                                                (self.storm_control is not None and self.storm_control.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                                self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                                self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                                self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                                self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                                self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                                self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                                self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_aging_mode.yfilter != YFilter.not_set or
                                                self.mac_aging_time.yfilter != YFilter.not_set or
                                                self.mac_flooding.yfilter != YFilter.not_set or
                                                self.mac_learning.yfilter != YFilter.not_set or
                                                self.mac_limit.yfilter != YFilter.not_set or
                                                self.mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_limit_notification.yfilter != YFilter.not_set or
                                                self.mac_limit_reached.yfilter != YFilter.not_set or
                                                self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                                self.mac_secure_action.yfilter != YFilter.not_set or
                                                self.mld_profile_name.yfilter != YFilter.not_set or
                                                self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.split_horizon_group_id.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                (self.storm_control is not None and self.storm_control.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "base" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                            if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                            if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                            if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                            if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                            if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                            if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                            if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                            if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                            if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                            if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                            if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                            if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                            if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                            if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                            if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                            if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                            if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                            if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                            if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                            if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                            if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "storm-control"):
                                                if (self.storm_control is None):
                                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                                    self.storm_control.parent = self
                                                    self._children_name_map["storm_control"] = "storm-control"
                                                return self.storm_control

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "broadcast-storm-control-kb-ps"):
                                                self.broadcast_storm_control_kb_ps = value
                                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-pps"):
                                                self.broadcast_storm_control_pps = value
                                                self.broadcast_storm_control_pps.value_namespace = name_space
                                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-rate-unit"):
                                                self.broadcast_storm_control_rate_unit = value
                                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dai-address-validation-mask"):
                                                self.dai_address_validation_mask = value
                                                self.dai_address_validation_mask.value_namespace = name_space
                                                self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-profile-name"):
                                                self.dhcpv4_profile_name = value
                                                self.dhcpv4_profile_name.value_namespace = name_space
                                                self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-snoop"):
                                                self.dhcpv4_snoop = value
                                                self.dhcpv4_snoop.value_namespace = name_space
                                                self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-unknown-unicast-enabled"):
                                                self.flood_unknown_unicast_enabled = value
                                                self.flood_unknown_unicast_enabled.value_namespace = name_space
                                                self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-uu-disabled-mac-limit-action"):
                                                self.flood_uu_disabled_mac_limit_action = value
                                                self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                                self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-disabled"):
                                                self.igm_pv4_disabled = value
                                                self.igm_pv4_disabled.value_namespace = name_space
                                                self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-profile-name"):
                                                self.igm_pv4_profile_name = value
                                                self.igm_pv4_profile_name.value_namespace = name_space
                                                self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                                self.is_dai_addr_validate_destination_mac_enabled = value
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                                self.is_dai_addr_validate_ipv4_enabled = value
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                                self.is_dai_addr_validate_source_mac_enabled = value
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-enabled"):
                                                self.is_dai_enabled = value
                                                self.is_dai_enabled.value_namespace = name_space
                                                self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-logging-enabled"):
                                                self.is_dai_logging_enabled = value
                                                self.is_dai_logging_enabled.value_namespace = name_space
                                                self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ip-source-guard-enabled"):
                                                self.is_ip_source_guard_enabled = value
                                                self.is_ip_source_guard_enabled.value_namespace = name_space
                                                self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ipsg-logging-enabled"):
                                                self.is_ipsg_logging_enabled = value
                                                self.is_ipsg_logging_enabled.value_namespace = name_space
                                                self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                                self.is_mac_secure_accept_shutdown_enabled = value
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-enabled"):
                                                self.is_mac_secure_enabled = value
                                                self.is_mac_secure_enabled.value_namespace = name_space
                                                self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-logging-enabled"):
                                                self.is_mac_secure_logging_enabled = value
                                                self.is_mac_secure_logging_enabled.value_namespace = name_space
                                                self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "learn-disabled-mac-limit-action"):
                                                self.learn_disabled_mac_limit_action = value
                                                self.learn_disabled_mac_limit_action.value_namespace = name_space
                                                self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-mode"):
                                                self.mac_aging_mode = value
                                                self.mac_aging_mode.value_namespace = name_space
                                                self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-time"):
                                                self.mac_aging_time = value
                                                self.mac_aging_time.value_namespace = name_space
                                                self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-flooding"):
                                                self.mac_flooding = value
                                                self.mac_flooding.value_namespace = name_space
                                                self.mac_flooding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-learning"):
                                                self.mac_learning = value
                                                self.mac_learning.value_namespace = name_space
                                                self.mac_learning.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit"):
                                                self.mac_limit = value
                                                self.mac_limit.value_namespace = name_space
                                                self.mac_limit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-action"):
                                                self.mac_limit_action = value
                                                self.mac_limit_action.value_namespace = name_space
                                                self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-notification"):
                                                self.mac_limit_notification = value
                                                self.mac_limit_notification.value_namespace = name_space
                                                self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-reached"):
                                                self.mac_limit_reached = value
                                                self.mac_limit_reached.value_namespace = name_space
                                                self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-port-down-flush-enabled"):
                                                self.mac_port_down_flush_enabled = value
                                                self.mac_port_down_flush_enabled.value_namespace = name_space
                                                self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-secure-action"):
                                                self.mac_secure_action = value
                                                self.mac_secure_action.value_namespace = name_space
                                                self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mld-profile-name"):
                                                self.mld_profile_name = value
                                                self.mld_profile_name.value_namespace = name_space
                                                self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mmrp-flood-optimization"):
                                                self.mmrp_flood_optimization = value
                                                self.mmrp_flood_optimization.value_namespace = name_space
                                                self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-kb-ps"):
                                                self.multicast_storm_control_kb_ps = value
                                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-pps"):
                                                self.multicast_storm_control_pps = value
                                                self.multicast_storm_control_pps.value_namespace = name_space
                                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-rate-unit"):
                                                self.multicast_storm_control_rate_unit = value
                                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "split-horizon-group-id"):
                                                self.split_horizon_group_id = value
                                                self.split_horizon_group_id.value_namespace = name_space
                                                self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-kb-ps"):
                                                self.unicast_storm_control_kb_ps = value
                                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-pps"):
                                                self.unicast_storm_control_pps = value
                                                self.unicast_storm_control_pps.value_namespace = name_space
                                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-rate-unit"):
                                                self.unicast_storm_control_rate_unit = value
                                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dhcpv4_trust.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.base is not None and self.base.has_data()) or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dhcpv4_trust.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.base is not None and self.base.has_operation()) or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security-parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "base"):
                                            if (self.base is None):
                                                self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                                self.base.parent = self
                                                self._children_name_map["base"] = "base"
                                            return self.base

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-trust"):
                                            self.dhcpv4_trust = value
                                            self.dhcpv4_trust.value_namespace = name_space
                                            self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StaticMac(Entity):
                                    """
                                    Static MAC addresses
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                        self.yang_name = "static-mac"
                                        self.yang_parent_name = "bridge-pw"

                                        self.address = YLeaf(YType.str, "address")

                                        self.bmac = YLeaf(YType.str, "bmac")

                                        self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("address",
                                                        "bmac",
                                                        "next_hop_ip") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.address.is_set or
                                            self.bmac.is_set or
                                            self.next_hop_ip.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.address.yfilter != YFilter.not_set or
                                            self.bmac.yfilter != YFilter.not_set or
                                            self.next_hop_ip.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "static-mac" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.address.get_name_leafdata())
                                        if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bmac.get_name_leafdata())
                                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "address"):
                                            self.address = value
                                            self.address.value_namespace = name_space
                                            self.address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bmac"):
                                            self.bmac = value
                                            self.bmac.value_namespace = name_space
                                            self.bmac.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop-ip"):
                                            self.next_hop_ip = value
                                            self.next_hop_ip.value_namespace = name_space
                                            self.next_hop_ip.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.static_mac:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.is_access.is_set or
                                        self.neighbor.is_set or
                                        self.pseudowire_id.is_set or
                                        self.pw_type.is_set or
                                        self.ve_id_vpls_id_0_3.is_set or
                                        self.vpls_id_4_7.is_set or
                                        (self.pseudowire is not None and self.pseudowire.has_data()) or
                                        (self.security_parameters is not None and self.security_parameters.has_data()))

                                def has_operation(self):
                                    for c in self.static_mac:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_access.yfilter != YFilter.not_set or
                                        self.neighbor.yfilter != YFilter.not_set or
                                        self.pseudowire_id.yfilter != YFilter.not_set or
                                        self.pw_type.yfilter != YFilter.not_set or
                                        self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set or
                                        self.vpls_id_4_7.yfilter != YFilter.not_set or
                                        (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                        (self.security_parameters is not None and self.security_parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bridge-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_access.get_name_leafdata())
                                    if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor.get_name_leafdata())
                                    if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudowire_id.get_name_leafdata())
                                    if (self.pw_type.is_set or self.pw_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_type.get_name_leafdata())
                                    if (self.ve_id_vpls_id_0_3.is_set or self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ve_id_vpls_id_0_3.get_name_leafdata())
                                    if (self.vpls_id_4_7.is_set or self.vpls_id_4_7.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_4_7.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "pseudowire"):
                                        if (self.pseudowire is None):
                                            self.pseudowire = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                            self.pseudowire.parent = self
                                            self._children_name_map["pseudowire"] = "pseudowire"
                                        return self.pseudowire

                                    if (child_yang_name == "security-parameters"):
                                        if (self.security_parameters is None):
                                            self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                            self.security_parameters.parent = self
                                            self._children_name_map["security_parameters"] = "security-parameters"
                                        return self.security_parameters

                                    if (child_yang_name == "static-mac"):
                                        for c in self.static_mac:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.static_mac.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id" or name == "pw-type" or name == "ve-id-vpls-id-0-3" or name == "vpls-id-4-7"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-access"):
                                        self.is_access = value
                                        self.is_access.value_namespace = name_space
                                        self.is_access.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor"):
                                        self.neighbor = value
                                        self.neighbor.value_namespace = name_space
                                        self.neighbor.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudowire-id"):
                                        self.pseudowire_id = value
                                        self.pseudowire_id.value_namespace = name_space
                                        self.pseudowire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-type"):
                                        self.pw_type = value
                                        self.pw_type.value_namespace = name_space
                                        self.pw_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ve-id-vpls-id-0-3"):
                                        self.ve_id_vpls_id_0_3 = value
                                        self.ve_id_vpls_id_0_3.value_namespace = name_space
                                        self.ve_id_vpls_id_0_3.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpls-id-4-7"):
                                        self.vpls_id_4_7 = value
                                        self.vpls_id_4_7.value_namespace = name_space
                                        self.vpls_id_4_7.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.bridge_pw:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.bridge_pw:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bridge-pws" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bridge-pw"):
                                    for c in self.bridge_pw:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.bridge_pw.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bridge-pw"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.bridge_pws is not None and self.bridge_pws.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.bridge_pws is not None and self.bridge_pws.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-access-vfi-table" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bridge-pws"):
                                if (self.bridge_pws is None):
                                    self.bridge_pws = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                                    self.bridge_pws.parent = self
                                    self._children_name_map["bridge_pws"] = "bridge-pws"
                                return self.bridge_pws

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-pws"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BridgeCoreVfiTable(Entity):
                        """
                        Bridge Domain Core VFI Table
                        
                        .. attribute:: bridge_pws
                        
                        	Bridge Domain Access/Core Pseudowire Table
                        	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable, self).__init__()

                            self.yang_name = "bridge-core-vfi-table"
                            self.yang_parent_name = "bridge-domain"

                            self.bridge_pws = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                            self.bridge_pws.parent = self
                            self._children_name_map["bridge_pws"] = "bridge-pws"
                            self._children_yang_names.add("bridge-pws")


                        class BridgePws(Entity):
                            """
                            Bridge Domain Access/Core Pseudowire Table
                            
                            .. attribute:: bridge_pw
                            
                            	VPLS Bridge Domain Pseudowire
                            	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__init__()

                                self.yang_name = "bridge-pws"
                                self.yang_parent_name = "bridge-core-vfi-table"

                                self.bridge_pw = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__setattr__(name, value)


                            class BridgePw(Entity):
                                """
                                VPLS Bridge Domain Pseudowire
                                
                                .. attribute:: is_access
                                
                                	Is Access PW
                                	**type**\:  bool
                                
                                .. attribute:: neighbor
                                
                                	Neighbor IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire
                                	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                                
                                .. attribute:: pseudowire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_type
                                
                                	PW Type
                                	**type**\:   :py:class:`L2Vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnpw>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                                
                                .. attribute:: static_mac
                                
                                	Static MAC addresses
                                	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                                
                                .. attribute:: ve_id_vpls_id_0_3
                                
                                	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vpls_id_4_7
                                
                                	Zero or Last 4 bytes of VPLS\-ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__init__()

                                    self.yang_name = "bridge-pw"
                                    self.yang_parent_name = "bridge-pws"

                                    self.is_access = YLeaf(YType.boolean, "is-access")

                                    self.neighbor = YLeaf(YType.str, "neighbor")

                                    self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                                    self.pw_type = YLeaf(YType.enumeration, "pw-type")

                                    self.ve_id_vpls_id_0_3 = YLeaf(YType.uint32, "ve-id-vpls-id-0-3")

                                    self.vpls_id_4_7 = YLeaf(YType.uint32, "vpls-id-4-7")

                                    self.pseudowire = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                    self.pseudowire.parent = self
                                    self._children_name_map["pseudowire"] = "pseudowire"
                                    self._children_yang_names.add("pseudowire")

                                    self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                    self._children_yang_names.add("security-parameters")

                                    self.static_mac = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_access",
                                                    "neighbor",
                                                    "pseudowire_id",
                                                    "pw_type",
                                                    "ve_id_vpls_id_0_3",
                                                    "vpls_id_4_7") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)


                                class Pseudowire(Entity):
                                    """
                                    Pseudowire
                                    
                                    .. attribute:: ad_method
                                    
                                    	Autodiscovery method
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ad_remote_down
                                    
                                    	Auto\-Discovered PW remote state down
                                    	**type**\:  bool
                                    
                                    .. attribute:: admited_bw
                                    
                                    	Admited Bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: auto_discovery
                                    
                                    	Is autodiscovery
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_active
                                    
                                    	TRUE if backup is active
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_force_active
                                    
                                    	TRUE if backup is active due to switchover
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_pw
                                    
                                    	TRUE if PW is a backup PW
                                    	**type**\:  bool
                                    
                                    .. attribute:: bitrate_mismatched
                                    
                                    	Bitrate mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: bridge_pw_type_mismatch
                                    
                                    	Oper down because Bridge has mismatched PW Types
                                    	**type**\:  bool
                                    
                                    .. attribute:: cas_mismatched
                                    
                                    	CAS mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: diff_ts_mismatched
                                    
                                    	Differential timestamp mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_delay
                                    
                                    	Backup disable delay
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: disable_never
                                    
                                    	TRUE if backup is not automatically disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_info
                                    
                                    	Encapsulation specific pseudowire information
                                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                    
                                    .. attribute:: evpn_src_acid
                                    
                                    	EVPN VPWS Source AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fe_ctype
                                    
                                    	Pseudowire FEC type
                                    	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                                    
                                    .. attribute:: forward_class
                                    
                                    	Forward Class attribute
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: freq_mismatched
                                    
                                    	Frequency mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: illegal_control_word
                                    
                                    	Illegal control word
                                    	**type**\:  bool
                                    
                                    .. attribute:: imposed_vlan_id
                                    
                                    	Imposed vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interworking
                                    
                                    	Interworking type
                                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                                    
                                    .. attribute:: ipv6_local_source_address
                                    
                                    	Local IPv6 Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_evpnvpws_type
                                    
                                    	is EVPN VPWS
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_flow_label_static
                                    
                                    	is flow label static
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_multi_segment_pseudowire
                                    
                                    	Is Multi\-Segment Pseudowire
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_partially_programmed
                                    
                                    	Is Pseudowire partially programmed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pwr_type
                                    
                                    	is Pseudowire\-routed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vfi
                                    
                                    	Is VFI interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_time_status_changed
                                    
                                    	Last time the pseudowire status changed
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: last_time_status_down
                                    
                                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: ldp_label_advertise_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: load_balance
                                    
                                    	Load Balance Type
                                    	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                                    
                                    .. attribute:: local_control_word
                                    
                                    	Local control word
                                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                    
                                    .. attribute:: local_interface
                                    
                                    	Local interface
                                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                    
                                    .. attribute:: local_label_failed
                                    
                                    	Failed to set BGP advertised local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_pseudo_wire_type
                                    
                                    	Local pseudowire type
                                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                    
                                    .. attribute:: local_signalling
                                    
                                    	Local signalling
                                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                    
                                    .. attribute:: local_source_address
                                    
                                    	Local Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mac_limit_oper_down
                                    
                                    	Oper down because MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mtu_mismatched
                                    
                                    	MTU mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: not_supported_qinq
                                    
                                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                    	**type**\:  bool
                                    
                                    .. attribute:: num_ma_cwithdraw_msg_received
                                    
                                    	Num MW messages received over PW
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_ma_cwithdraw_message_sent
                                    
                                    	Num MW messages sent over PW
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: out_of_memory_state
                                    
                                    	L2VPN Out of memory state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: p2mp_pw
                                    
                                    	P2MP Pseudowire Information
                                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                    
                                    .. attribute:: payload_bytes_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: payload_type_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer
                                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                    
                                    .. attribute:: preferred_path
                                    
                                    	MPLS Preferred Path
                                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                    
                                    .. attribute:: preferred_path_disable_fallback
                                    
                                    	Prefpath fallback enable/disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_peer_id
                                    
                                    	Primary Peer IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary_pseudo_wire_id
                                    
                                    	Primary Pseudowire ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: primary_pw
                                    
                                    	TRUE if PW is a primary PW
                                    	**type**\:  bool
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol
                                    	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                                    
                                    .. attribute:: pseudo_wire_id
                                    
                                    	Pseudowire ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: pseudo_wire_state
                                    
                                    	Pseudowire state
                                    	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                                    
                                    .. attribute:: pseudo_wire_type_mismatched
                                    
                                    	Pseudowire type mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_class_name
                                    
                                    	Pseudowire class name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: pw_flow_label_code17_disabled
                                    
                                    	Disable sending Code 17 TLV
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_flow_label_type
                                    
                                    	Negotiated pseudowire flow label type
                                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                    
                                    .. attribute:: pw_flow_label_type_cfg
                                    
                                    	Configured pseudowire flow label Type
                                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                    
                                    .. attribute:: pw_redundancy_initial_delay
                                    
                                    	Initial delay for redundant PW in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: pw_redundancy_one_way
                                    
                                    	Force one\-way PW redundancy behaviour in Redundancy Group
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_status_use
                                    
                                    	PW status in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: pwlsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_control_word
                                    
                                    	Remote control word
                                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                    
                                    .. attribute:: remote_interface
                                    
                                    	Remote interface
                                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                    
                                    .. attribute:: remote_label_failed
                                    
                                    	Failed to set BGP advertised remote label
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_pseudo_wire_type
                                    
                                    	Remote pseudowire type
                                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                    
                                    .. attribute:: remote_signalling
                                    
                                    	Remote signalling
                                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                    
                                    .. attribute:: required_bw
                                    
                                    	Required Bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: resync_enabled
                                    
                                    	Resync if packets out of sequence
                                    	**type**\:  bool
                                    
                                    .. attribute:: resync_threshold
                                    
                                    	Number of Packets Out of Seqence to trigger resync
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rtp_mismatched
                                    
                                    	RTP mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: sequencing_type
                                    
                                    	Sequencing Type
                                    	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown
                                    	**type**\:  bool
                                    
                                    .. attribute:: sig_pkts_mismatched
                                    
                                    	Signalling packets mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: ssrc_mismatched
                                    
                                    	SSRC mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                                    
                                    .. attribute:: statistics
                                    
                                    	Statistics
                                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                    
                                    .. attribute:: table_policy_name
                                    
                                    	Table\-policy Name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag_rewrite
                                    
                                    	StaticTagRewrite
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: time_created
                                    
                                    	Time when the pseudowire was created
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_creation
                                    
                                    	Time elapsed since creation
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_changed
                                    
                                    	Time elapsed since status changed
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_down
                                    
                                    	Time elapsed since last status down in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: transport_lsp_down
                                    
                                    	Oper down due to Transport LSP down
                                    	**type**\:  bool
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	XConnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                        self.yang_name = "pseudowire"
                                        self.yang_parent_name = "bridge-pw"

                                        self.ad_method = YLeaf(YType.uint32, "ad-method")

                                        self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                        self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                        self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                        self.backup_active = YLeaf(YType.boolean, "backup-active")

                                        self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                        self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                        self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                        self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                        self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                        self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                        self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                        self.disable_never = YLeaf(YType.boolean, "disable-never")

                                        self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                        self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                        self.forward_class = YLeaf(YType.uint8, "forward-class")

                                        self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                        self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                        self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                        self.interworking = YLeaf(YType.enumeration, "interworking")

                                        self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                        self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                        self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                        self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                        self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                        self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                        self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                        self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                        self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                        self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                        self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                        self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                        self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                        self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                        self.local_source_address = YLeaf(YType.str, "local-source-address")

                                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                        self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                        self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                        self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                        self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                        self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                        self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                        self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                        self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                        self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                        self.protocol = YLeaf(YType.enumeration, "protocol")

                                        self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                        self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                        self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                        self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                        self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                        self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                        self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                        self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                        self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                        self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                        self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                        self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                        self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                        self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                        self.required_bw = YLeaf(YType.uint32, "required-bw")

                                        self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                        self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                        self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                        self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                                        self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                        self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                        self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                        self.time_created = YLeaf(YType.str, "time-created")

                                        self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                        self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                        self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                        self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.encapsulation_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                        self._children_yang_names.add("encapsulation-info")

                                        self.local_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                        self._children_yang_names.add("local-interface")

                                        self.local_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                        self._children_yang_names.add("local-signalling")

                                        self.p2mp_pw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                        self._children_yang_names.add("p2mp-pw")

                                        self.peer_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                        self._children_yang_names.add("peer-id")

                                        self.preferred_path = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                        self._children_yang_names.add("preferred-path")

                                        self.remote_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                        self._children_yang_names.add("remote-interface")

                                        self.remote_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                        self._children_yang_names.add("remote-signalling")

                                        self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                        self._children_yang_names.add("statistics")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ad_method",
                                                        "ad_remote_down",
                                                        "admited_bw",
                                                        "auto_discovery",
                                                        "backup_active",
                                                        "backup_force_active",
                                                        "backup_pw",
                                                        "bitrate_mismatched",
                                                        "bridge_pw_type_mismatch",
                                                        "cas_mismatched",
                                                        "diff_ts_mismatched",
                                                        "disable_delay",
                                                        "disable_never",
                                                        "evpn_src_acid",
                                                        "fe_ctype",
                                                        "forward_class",
                                                        "freq_mismatched",
                                                        "illegal_control_word",
                                                        "imposed_vlan_id",
                                                        "interworking",
                                                        "ipv6_local_source_address",
                                                        "is_evpnvpws_type",
                                                        "is_flow_label_static",
                                                        "is_multi_segment_pseudowire",
                                                        "is_partially_programmed",
                                                        "is_pwr_type",
                                                        "is_vfi",
                                                        "last_time_status_changed",
                                                        "last_time_status_down",
                                                        "ldp_label_advertise_failed",
                                                        "load_balance",
                                                        "local_control_word",
                                                        "local_label_failed",
                                                        "local_pseudo_wire_type",
                                                        "local_source_address",
                                                        "mac_limit_oper_down",
                                                        "mtu_mismatched",
                                                        "not_supported_qinq",
                                                        "num_ma_cwithdraw_msg_received",
                                                        "number_ma_cwithdraw_message_sent",
                                                        "out_of_memory_state",
                                                        "payload_bytes_mismatched",
                                                        "payload_type_mismatched",
                                                        "preferred_path_disable_fallback",
                                                        "primary_peer_id",
                                                        "primary_pseudo_wire_id",
                                                        "primary_pw",
                                                        "protocol",
                                                        "pseudo_wire_id",
                                                        "pseudo_wire_state",
                                                        "pseudo_wire_type_mismatched",
                                                        "pw_class_name",
                                                        "pw_flow_label_code17_disabled",
                                                        "pw_flow_label_type",
                                                        "pw_flow_label_type_cfg",
                                                        "pw_redundancy_initial_delay",
                                                        "pw_redundancy_one_way",
                                                        "pw_status_use",
                                                        "pwlsd_rewrite_failed",
                                                        "remote_control_word",
                                                        "remote_label_failed",
                                                        "remote_pseudo_wire_type",
                                                        "required_bw",
                                                        "resync_enabled",
                                                        "resync_threshold",
                                                        "rtp_mismatched",
                                                        "sequencing_type",
                                                        "shutdown",
                                                        "sig_pkts_mismatched",
                                                        "ssrc_mismatched",
                                                        "state",
                                                        "table_policy_name",
                                                        "tag_rewrite",
                                                        "time_created",
                                                        "time_elapsed_creation",
                                                        "time_elapsed_status_changed",
                                                        "time_elapsed_status_down",
                                                        "transport_lsp_down",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)


                                    class PeerId(Entity):
                                        """
                                        Peer
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ipv4_peer_id
                                        
                                        	Peer IPv4 address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_peer_id
                                        
                                        	Peer IPv6 address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: type
                                        
                                        	type
                                        	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                            self.yang_name = "peer-id"
                                            self.yang_parent_name = "pseudowire"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                            self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                            self.type = YLeaf(YType.enumeration, "type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "ipv4_peer_id",
                                                            "ipv6_peer_id",
                                                            "type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.ipv4_peer_id.is_set or
                                                self.ipv6_peer_id.is_set or
                                                self.type.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.ipv4_peer_id.yfilter != YFilter.not_set or
                                                self.ipv6_peer_id.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "peer-id" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                            if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-peer-id"):
                                                self.ipv4_peer_id = value
                                                self.ipv4_peer_id.value_namespace = name_space
                                                self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-peer-id"):
                                                self.ipv6_peer_id = value
                                                self.ipv6_peer_id.value_namespace = name_space
                                                self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix


                                    class EncapsulationInfo(Entity):
                                        """
                                        Encapsulation specific pseudowire information
                                        
                                        .. attribute:: atom
                                        
                                        	atom
                                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                        
                                        .. attribute:: encapsulation
                                        
                                        	Encapsulation
                                        	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                        
                                        .. attribute:: l2tpv3
                                        
                                        	l2tpv3
                                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                            self.yang_name = "encapsulation-info"
                                            self.yang_parent_name = "pseudowire"

                                            self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                            self.atom = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                            self._children_yang_names.add("atom")

                                            self.l2tpv3 = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                            self._children_yang_names.add("l2tpv3")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                        class Atom(Entity):
                                            """
                                            atom
                                            
                                            .. attribute:: is_pseudowire_headend
                                            
                                            	Is this connected to a PW\-HE AC
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_sai_itype2
                                            
                                            	Is SAII FEC129 Type 2
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tai_itype2
                                            
                                            	Is TAII type 2
                                            	**type**\:  bool
                                            
                                            .. attribute:: ldp_label_advertisment_failed
                                            
                                            	LDP label advertisment failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_agi
                                            
                                            	Local Attachment Group Identifier
                                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                            
                                            .. attribute:: local_c_ctype
                                            
                                            	Local VCCV CC type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_ceid
                                            
                                            	Local CE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cv_type
                                            
                                            	Local VCCV CV type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_group_id
                                            
                                            	Local group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_ldp_id
                                            
                                            	Local LDP ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: local_saii_gbl_id
                                            
                                            	Local SAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_saiiac_id
                                            
                                            	Local SAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_taii_gbl_id
                                            
                                            	Local TAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_taiiac_id
                                            
                                            	Local TAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_veid
                                            
                                            	Local VE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsd_rewrite_failed
                                            
                                            	LSD rewrite failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: multi_segment_pseudowire_stats
                                            
                                            	Multisegment pseudowire statistics
                                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                            
                                            .. attribute:: rem_saii
                                            
                                            	Remote Source Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rem_saii_gbl_id
                                            
                                            	Remote SAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_saiiac_id
                                            
                                            	Remote SAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taii
                                            
                                            	Remote Target Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rem_taii_gbl_id
                                            
                                            	Remote TAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taiiac_id
                                            
                                            	Remote TAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_agi
                                            
                                            	Remote Attachment Group Identifier
                                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                            
                                            .. attribute:: remote_c_ctype
                                            
                                            	Remote VCCV CC type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_ceid
                                            
                                            	Remote CE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cv_type
                                            
                                            	Remote VCCV CV type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_group_id
                                            
                                            	Remote group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_label
                                            
                                            	Remote label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_ldp_id
                                            
                                            	Remote LDP ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_source_address
                                            
                                            	Remote BGP source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_veid
                                            
                                            	Remote VE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: saii
                                            
                                            	Source Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_address
                                            
                                            	Local BGP source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: taii
                                            
                                            	Target Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                                self.yang_name = "atom"
                                                self.yang_parent_name = "encapsulation-info"

                                                self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                                self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                                self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                                self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                                self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                                self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                                self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                                self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                                self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                                self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                                self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                                self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                                self.local_veid = YLeaf(YType.uint32, "local-veid")

                                                self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                                self.rem_saii = YLeaf(YType.str, "rem-saii")

                                                self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                                self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                                self.rem_taii = YLeaf(YType.str, "rem-taii")

                                                self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                                self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                                self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                                self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                                self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                                self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                                self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                                self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                                self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                                self.saii = YLeaf(YType.str, "saii")

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.taii = YLeaf(YType.str, "taii")

                                                self.local_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                                self._children_yang_names.add("local-agi")

                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                self._children_yang_names.add("multi-segment-pseudowire-stats")

                                                self.remote_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                                self._children_yang_names.add("remote-agi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("is_pseudowire_headend",
                                                                "is_sai_itype2",
                                                                "is_tai_itype2",
                                                                "ldp_label_advertisment_failed",
                                                                "local_c_ctype",
                                                                "local_ceid",
                                                                "local_cv_type",
                                                                "local_group_id",
                                                                "local_label",
                                                                "local_ldp_id",
                                                                "local_saii_gbl_id",
                                                                "local_saiiac_id",
                                                                "local_taii_gbl_id",
                                                                "local_taiiac_id",
                                                                "local_veid",
                                                                "lsd_rewrite_failed",
                                                                "rem_saii",
                                                                "rem_saii_gbl_id",
                                                                "rem_saiiac_id",
                                                                "rem_taii",
                                                                "rem_taii_gbl_id",
                                                                "rem_taiiac_id",
                                                                "remote_c_ctype",
                                                                "remote_ceid",
                                                                "remote_cv_type",
                                                                "remote_group_id",
                                                                "remote_label",
                                                                "remote_ldp_id",
                                                                "remote_source_address",
                                                                "remote_veid",
                                                                "saii",
                                                                "source_address",
                                                                "taii") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                            class LocalAgi(Entity):
                                                """
                                                Local Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                    self.yang_name = "local-agi"
                                                    self.yang_parent_name = "atom"

                                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                    self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                    self._children_yang_names.add("auto")

                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    self._children_yang_names.add("two-byte-as")

                                                    self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                    self._children_yang_names.add("v4-addr")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("vpls_id_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                                class Auto(Entity):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                        self.yang_name = "auto"
                                                        self.yang_parent_name = "local-agi"

                                                        self.asn = YLeaf(YType.uint16, "asn")

                                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("asn",
                                                                        "vpn_id") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.asn.is_set or
                                                            self.vpn_id.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.asn.yfilter != YFilter.not_set or
                                                            self.vpn_id.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "auto" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "asn" or name == "vpn-id"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "asn"):
                                                            self.asn = value
                                                            self.asn.value_namespace = name_space
                                                            self.asn.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vpn-id"):
                                                            self.vpn_id = value
                                                            self.vpn_id.value_namespace = name_space
                                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                                class TwoByteAs(Entity):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                        self.yang_name = "two-byte-as"
                                                        self.yang_parent_name = "local-agi"

                                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("four_byte_index",
                                                                        "two_byte_as") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.four_byte_index.is_set or
                                                            self.two_byte_as.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.four_byte_index.yfilter != YFilter.not_set or
                                                            self.two_byte_as.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "two-byte-as" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "four-byte-index"):
                                                            self.four_byte_index = value
                                                            self.four_byte_index.value_namespace = name_space
                                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "two-byte-as"):
                                                            self.two_byte_as = value
                                                            self.two_byte_as.value_namespace = name_space
                                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                                class V4Addr(Entity):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                        self.yang_name = "v4-addr"
                                                        self.yang_parent_name = "local-agi"

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("ipv4_address",
                                                                        "two_byte_index") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.ipv4_address.is_set or
                                                            self.two_byte_index.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.ipv4_address.yfilter != YFilter.not_set or
                                                            self.two_byte_index.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "v4-addr" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "ipv4-address"):
                                                            self.ipv4_address = value
                                                            self.ipv4_address.value_namespace = name_space
                                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "two-byte-index"):
                                                            self.two_byte_index = value
                                                            self.two_byte_index.value_namespace = name_space
                                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.vpls_id_type.is_set or
                                                        (self.auto is not None and self.auto.has_data()) or
                                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                                        (self.auto is not None and self.auto.has_operation()) or
                                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "local-agi" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "auto"):
                                                        if (self.auto is None):
                                                            self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                            self.auto.parent = self
                                                            self._children_name_map["auto"] = "auto"
                                                        return self.auto

                                                    if (child_yang_name == "two-byte-as"):
                                                        if (self.two_byte_as is None):
                                                            self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                            self.two_byte_as.parent = self
                                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                                        return self.two_byte_as

                                                    if (child_yang_name == "v4-addr"):
                                                        if (self.v4_addr is None):
                                                            self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                            self.v4_addr.parent = self
                                                            self._children_name_map["v4_addr"] = "v4-addr"
                                                        return self.v4_addr

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "vpls-id-type"):
                                                        self.vpls_id_type = value
                                                        self.vpls_id_type.value_namespace = name_space
                                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                            class RemoteAgi(Entity):
                                                """
                                                Remote Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                    self.yang_name = "remote-agi"
                                                    self.yang_parent_name = "atom"

                                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                    self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                    self._children_yang_names.add("auto")

                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    self._children_yang_names.add("two-byte-as")

                                                    self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                    self._children_yang_names.add("v4-addr")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("vpls_id_type") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                                class Auto(Entity):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                        self.yang_name = "auto"
                                                        self.yang_parent_name = "remote-agi"

                                                        self.asn = YLeaf(YType.uint16, "asn")

                                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("asn",
                                                                        "vpn_id") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.asn.is_set or
                                                            self.vpn_id.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.asn.yfilter != YFilter.not_set or
                                                            self.vpn_id.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "auto" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "asn" or name == "vpn-id"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "asn"):
                                                            self.asn = value
                                                            self.asn.value_namespace = name_space
                                                            self.asn.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "vpn-id"):
                                                            self.vpn_id = value
                                                            self.vpn_id.value_namespace = name_space
                                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                                class TwoByteAs(Entity):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                        self.yang_name = "two-byte-as"
                                                        self.yang_parent_name = "remote-agi"

                                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("four_byte_index",
                                                                        "two_byte_as") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.four_byte_index.is_set or
                                                            self.two_byte_as.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.four_byte_index.yfilter != YFilter.not_set or
                                                            self.two_byte_as.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "two-byte-as" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "four-byte-index"):
                                                            self.four_byte_index = value
                                                            self.four_byte_index.value_namespace = name_space
                                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "two-byte-as"):
                                                            self.two_byte_as = value
                                                            self.two_byte_as.value_namespace = name_space
                                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                                class V4Addr(Entity):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                        self.yang_name = "v4-addr"
                                                        self.yang_parent_name = "remote-agi"

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("ipv4_address",
                                                                        "two_byte_index") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.ipv4_address.is_set or
                                                            self.two_byte_index.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.ipv4_address.yfilter != YFilter.not_set or
                                                            self.two_byte_index.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "v4-addr" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "ipv4-address"):
                                                            self.ipv4_address = value
                                                            self.ipv4_address.value_namespace = name_space
                                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "two-byte-index"):
                                                            self.two_byte_index = value
                                                            self.two_byte_index.value_namespace = name_space
                                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.vpls_id_type.is_set or
                                                        (self.auto is not None and self.auto.has_data()) or
                                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                                        (self.auto is not None and self.auto.has_operation()) or
                                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "remote-agi" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "auto"):
                                                        if (self.auto is None):
                                                            self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                            self.auto.parent = self
                                                            self._children_name_map["auto"] = "auto"
                                                        return self.auto

                                                    if (child_yang_name == "two-byte-as"):
                                                        if (self.two_byte_as is None):
                                                            self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                            self.two_byte_as.parent = self
                                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                                        return self.two_byte_as

                                                    if (child_yang_name == "v4-addr"):
                                                        if (self.v4_addr is None):
                                                            self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                            self.v4_addr.parent = self
                                                            self._children_name_map["v4_addr"] = "v4-addr"
                                                        return self.v4_addr

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "vpls-id-type"):
                                                        self.vpls_id_type = value
                                                        self.vpls_id_type.value_namespace = name_space
                                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                            class MultiSegmentPseudowireStats(Entity):
                                                """
                                                Multisegment pseudowire statistics
                                                
                                                .. attribute:: received_bytes
                                                
                                                	Bytes received
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: received_packets
                                                
                                                	Packets received
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                    self.yang_name = "multi-segment-pseudowire-stats"
                                                    self.yang_parent_name = "atom"

                                                    self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                                    self.received_packets = YLeaf(YType.uint64, "received-packets")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("received_bytes",
                                                                    "received_packets") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.received_bytes.is_set or
                                                        self.received_packets.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.received_bytes.yfilter != YFilter.not_set or
                                                        self.received_packets.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                                    if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.received_packets.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "received-bytes" or name == "received-packets"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "received-bytes"):
                                                        self.received_bytes = value
                                                        self.received_bytes.value_namespace = name_space
                                                        self.received_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "received-packets"):
                                                        self.received_packets = value
                                                        self.received_packets.value_namespace = name_space
                                                        self.received_packets.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.is_pseudowire_headend.is_set or
                                                    self.is_sai_itype2.is_set or
                                                    self.is_tai_itype2.is_set or
                                                    self.ldp_label_advertisment_failed.is_set or
                                                    self.local_c_ctype.is_set or
                                                    self.local_ceid.is_set or
                                                    self.local_cv_type.is_set or
                                                    self.local_group_id.is_set or
                                                    self.local_label.is_set or
                                                    self.local_ldp_id.is_set or
                                                    self.local_saii_gbl_id.is_set or
                                                    self.local_saiiac_id.is_set or
                                                    self.local_taii_gbl_id.is_set or
                                                    self.local_taiiac_id.is_set or
                                                    self.local_veid.is_set or
                                                    self.lsd_rewrite_failed.is_set or
                                                    self.rem_saii.is_set or
                                                    self.rem_saii_gbl_id.is_set or
                                                    self.rem_saiiac_id.is_set or
                                                    self.rem_taii.is_set or
                                                    self.rem_taii_gbl_id.is_set or
                                                    self.rem_taiiac_id.is_set or
                                                    self.remote_c_ctype.is_set or
                                                    self.remote_ceid.is_set or
                                                    self.remote_cv_type.is_set or
                                                    self.remote_group_id.is_set or
                                                    self.remote_label.is_set or
                                                    self.remote_ldp_id.is_set or
                                                    self.remote_source_address.is_set or
                                                    self.remote_veid.is_set or
                                                    self.saii.is_set or
                                                    self.source_address.is_set or
                                                    self.taii.is_set or
                                                    (self.local_agi is not None and self.local_agi.has_data()) or
                                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                                    (self.remote_agi is not None and self.remote_agi.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                                    self.is_sai_itype2.yfilter != YFilter.not_set or
                                                    self.is_tai_itype2.yfilter != YFilter.not_set or
                                                    self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                                    self.local_c_ctype.yfilter != YFilter.not_set or
                                                    self.local_ceid.yfilter != YFilter.not_set or
                                                    self.local_cv_type.yfilter != YFilter.not_set or
                                                    self.local_group_id.yfilter != YFilter.not_set or
                                                    self.local_label.yfilter != YFilter.not_set or
                                                    self.local_ldp_id.yfilter != YFilter.not_set or
                                                    self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                                    self.local_saiiac_id.yfilter != YFilter.not_set or
                                                    self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                                    self.local_taiiac_id.yfilter != YFilter.not_set or
                                                    self.local_veid.yfilter != YFilter.not_set or
                                                    self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                                    self.rem_saii.yfilter != YFilter.not_set or
                                                    self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                                    self.rem_saiiac_id.yfilter != YFilter.not_set or
                                                    self.rem_taii.yfilter != YFilter.not_set or
                                                    self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                                    self.rem_taiiac_id.yfilter != YFilter.not_set or
                                                    self.remote_c_ctype.yfilter != YFilter.not_set or
                                                    self.remote_ceid.yfilter != YFilter.not_set or
                                                    self.remote_cv_type.yfilter != YFilter.not_set or
                                                    self.remote_group_id.yfilter != YFilter.not_set or
                                                    self.remote_label.yfilter != YFilter.not_set or
                                                    self.remote_ldp_id.yfilter != YFilter.not_set or
                                                    self.remote_source_address.yfilter != YFilter.not_set or
                                                    self.remote_veid.yfilter != YFilter.not_set or
                                                    self.saii.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.taii.yfilter != YFilter.not_set or
                                                    (self.local_agi is not None and self.local_agi.has_operation()) or
                                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                                    (self.remote_agi is not None and self.remote_agi.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atom" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                                if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                                if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                                if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                                if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                                if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                                if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                                if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                                if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                                if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                                if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                                if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                                if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                                if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_veid.get_name_leafdata())
                                                if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                                if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                                if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                                if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                                if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                                if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                                if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                                if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                                if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                                if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                                if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                                if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                                if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                                if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                                if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.saii.get_name_leafdata())
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.taii.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "local-agi"):
                                                    if (self.local_agi is None):
                                                        self.local_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                        self.local_agi.parent = self
                                                        self._children_name_map["local_agi"] = "local-agi"
                                                    return self.local_agi

                                                if (child_yang_name == "multi-segment-pseudowire-stats"):
                                                    if (self.multi_segment_pseudowire_stats is None):
                                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                        self.multi_segment_pseudowire_stats.parent = self
                                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                    return self.multi_segment_pseudowire_stats

                                                if (child_yang_name == "remote-agi"):
                                                    if (self.remote_agi is None):
                                                        self.remote_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                        self.remote_agi.parent = self
                                                        self._children_name_map["remote_agi"] = "remote-agi"
                                                    return self.remote_agi

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "is-pseudowire-headend"):
                                                    self.is_pseudowire_headend = value
                                                    self.is_pseudowire_headend.value_namespace = name_space
                                                    self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sai-itype2"):
                                                    self.is_sai_itype2 = value
                                                    self.is_sai_itype2.value_namespace = name_space
                                                    self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-tai-itype2"):
                                                    self.is_tai_itype2 = value
                                                    self.is_tai_itype2.value_namespace = name_space
                                                    self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ldp-label-advertisment-failed"):
                                                    self.ldp_label_advertisment_failed = value
                                                    self.ldp_label_advertisment_failed.value_namespace = name_space
                                                    self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-c-ctype"):
                                                    self.local_c_ctype = value
                                                    self.local_c_ctype.value_namespace = name_space
                                                    self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-ceid"):
                                                    self.local_ceid = value
                                                    self.local_ceid.value_namespace = name_space
                                                    self.local_ceid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-cv-type"):
                                                    self.local_cv_type = value
                                                    self.local_cv_type.value_namespace = name_space
                                                    self.local_cv_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-group-id"):
                                                    self.local_group_id = value
                                                    self.local_group_id.value_namespace = name_space
                                                    self.local_group_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-label"):
                                                    self.local_label = value
                                                    self.local_label.value_namespace = name_space
                                                    self.local_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-ldp-id"):
                                                    self.local_ldp_id = value
                                                    self.local_ldp_id.value_namespace = name_space
                                                    self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-saii-gbl-id"):
                                                    self.local_saii_gbl_id = value
                                                    self.local_saii_gbl_id.value_namespace = name_space
                                                    self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-saiiac-id"):
                                                    self.local_saiiac_id = value
                                                    self.local_saiiac_id.value_namespace = name_space
                                                    self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-taii-gbl-id"):
                                                    self.local_taii_gbl_id = value
                                                    self.local_taii_gbl_id.value_namespace = name_space
                                                    self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-taiiac-id"):
                                                    self.local_taiiac_id = value
                                                    self.local_taiiac_id.value_namespace = name_space
                                                    self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-veid"):
                                                    self.local_veid = value
                                                    self.local_veid.value_namespace = name_space
                                                    self.local_veid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lsd-rewrite-failed"):
                                                    self.lsd_rewrite_failed = value
                                                    self.lsd_rewrite_failed.value_namespace = name_space
                                                    self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-saii"):
                                                    self.rem_saii = value
                                                    self.rem_saii.value_namespace = name_space
                                                    self.rem_saii.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-saii-gbl-id"):
                                                    self.rem_saii_gbl_id = value
                                                    self.rem_saii_gbl_id.value_namespace = name_space
                                                    self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-saiiac-id"):
                                                    self.rem_saiiac_id = value
                                                    self.rem_saiiac_id.value_namespace = name_space
                                                    self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-taii"):
                                                    self.rem_taii = value
                                                    self.rem_taii.value_namespace = name_space
                                                    self.rem_taii.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-taii-gbl-id"):
                                                    self.rem_taii_gbl_id = value
                                                    self.rem_taii_gbl_id.value_namespace = name_space
                                                    self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rem-taiiac-id"):
                                                    self.rem_taiiac_id = value
                                                    self.rem_taiiac_id.value_namespace = name_space
                                                    self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-c-ctype"):
                                                    self.remote_c_ctype = value
                                                    self.remote_c_ctype.value_namespace = name_space
                                                    self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-ceid"):
                                                    self.remote_ceid = value
                                                    self.remote_ceid.value_namespace = name_space
                                                    self.remote_ceid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-cv-type"):
                                                    self.remote_cv_type = value
                                                    self.remote_cv_type.value_namespace = name_space
                                                    self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-group-id"):
                                                    self.remote_group_id = value
                                                    self.remote_group_id.value_namespace = name_space
                                                    self.remote_group_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-label"):
                                                    self.remote_label = value
                                                    self.remote_label.value_namespace = name_space
                                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-ldp-id"):
                                                    self.remote_ldp_id = value
                                                    self.remote_ldp_id.value_namespace = name_space
                                                    self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-source-address"):
                                                    self.remote_source_address = value
                                                    self.remote_source_address.value_namespace = name_space
                                                    self.remote_source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-veid"):
                                                    self.remote_veid = value
                                                    self.remote_veid.value_namespace = name_space
                                                    self.remote_veid.value_namespace_prefix = name_space_prefix
                                                if(value_path == "saii"):
                                                    self.saii = value
                                                    self.saii.value_namespace = name_space
                                                    self.saii.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "taii"):
                                                    self.taii = value
                                                    self.taii.value_namespace = name_space
                                                    self.taii.value_namespace_prefix = name_space_prefix


                                        class L2Tpv3(Entity):
                                            """
                                            l2tpv3
                                            
                                            .. attribute:: dont_fragment_bit
                                            
                                            	Don't Fragment Bit
                                            	**type**\:  bool
                                            
                                            .. attribute:: ipv4_source_address
                                            
                                            	IPv4 source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_source_address
                                            
                                            	IPv6 source address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tp_class_name
                                            
                                            	L2TPClassName
                                            	**type**\:  str
                                            
                                            	**length:** 0..32
                                            
                                            .. attribute:: local_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_size
                                            
                                            	Local cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_secondary_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local secondary cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_secondary_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local secondary cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_secondary_cookie_size
                                            
                                            	Local secondary cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_session_id
                                            
                                            	Local session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_mtu_enabled
                                            
                                            	Path MTU enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_mtu_max_value
                                            
                                            	Path MTU Maximum allowable session MTU
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: remote_circuit_status_up
                                            
                                            	RemoteCircuitStatusUp
                                            	**type**\:  bool
                                            
                                            .. attribute:: remote_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the remote cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the remote cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_size
                                            
                                            	Remote cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_session_id
                                            
                                            	Remote session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tos
                                            
                                            	Type Of Service Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tos_mode
                                            
                                            	Type Of Service Mode
                                            	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                            
                                            .. attribute:: ttl
                                            
                                            	Time To Live value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tunnel_state
                                            
                                            	L2TP tunnel state
                                            	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                                self.yang_name = "l2tpv3"
                                                self.yang_parent_name = "encapsulation-info"

                                                self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                                self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                                self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                                self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                                self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                                self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                                self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                                self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                                self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                                self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                                self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                                self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                                self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                                self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                                self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                                self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                                self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                                self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                                self.tos = YLeaf(YType.uint8, "tos")

                                                self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                                self.ttl = YLeaf(YType.uint8, "ttl")

                                                self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dont_fragment_bit",
                                                                "ipv4_source_address",
                                                                "ipv6_source_address",
                                                                "l2tp_class_name",
                                                                "local_cookie_high_value",
                                                                "local_cookie_low_value",
                                                                "local_cookie_size",
                                                                "local_secondary_cookie_high_value",
                                                                "local_secondary_cookie_low_value",
                                                                "local_secondary_cookie_size",
                                                                "local_session_id",
                                                                "path_mtu_enabled",
                                                                "path_mtu_max_value",
                                                                "remote_circuit_status_up",
                                                                "remote_cookie_high_value",
                                                                "remote_cookie_low_value",
                                                                "remote_cookie_size",
                                                                "remote_session_id",
                                                                "tos",
                                                                "tos_mode",
                                                                "ttl",
                                                                "tunnel_state") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dont_fragment_bit.is_set or
                                                    self.ipv4_source_address.is_set or
                                                    self.ipv6_source_address.is_set or
                                                    self.l2tp_class_name.is_set or
                                                    self.local_cookie_high_value.is_set or
                                                    self.local_cookie_low_value.is_set or
                                                    self.local_cookie_size.is_set or
                                                    self.local_secondary_cookie_high_value.is_set or
                                                    self.local_secondary_cookie_low_value.is_set or
                                                    self.local_secondary_cookie_size.is_set or
                                                    self.local_session_id.is_set or
                                                    self.path_mtu_enabled.is_set or
                                                    self.path_mtu_max_value.is_set or
                                                    self.remote_circuit_status_up.is_set or
                                                    self.remote_cookie_high_value.is_set or
                                                    self.remote_cookie_low_value.is_set or
                                                    self.remote_cookie_size.is_set or
                                                    self.remote_session_id.is_set or
                                                    self.tos.is_set or
                                                    self.tos_mode.is_set or
                                                    self.ttl.is_set or
                                                    self.tunnel_state.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dont_fragment_bit.yfilter != YFilter.not_set or
                                                    self.ipv4_source_address.yfilter != YFilter.not_set or
                                                    self.ipv6_source_address.yfilter != YFilter.not_set or
                                                    self.l2tp_class_name.yfilter != YFilter.not_set or
                                                    self.local_cookie_high_value.yfilter != YFilter.not_set or
                                                    self.local_cookie_low_value.yfilter != YFilter.not_set or
                                                    self.local_cookie_size.yfilter != YFilter.not_set or
                                                    self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                    self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                    self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                                    self.local_session_id.yfilter != YFilter.not_set or
                                                    self.path_mtu_enabled.yfilter != YFilter.not_set or
                                                    self.path_mtu_max_value.yfilter != YFilter.not_set or
                                                    self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                                    self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                                    self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                                    self.remote_cookie_size.yfilter != YFilter.not_set or
                                                    self.remote_session_id.yfilter != YFilter.not_set or
                                                    self.tos.yfilter != YFilter.not_set or
                                                    self.tos_mode.yfilter != YFilter.not_set or
                                                    self.ttl.yfilter != YFilter.not_set or
                                                    self.tunnel_state.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2tpv3" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                                if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                                if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                                if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                                if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                                if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                                if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                                if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                                if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                                if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                                if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                                if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                                if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                                if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                                if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                                if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                                if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                                if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                                if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tos.get_name_leafdata())
                                                if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                                if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ttl.get_name_leafdata())
                                                if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dont-fragment-bit"):
                                                    self.dont_fragment_bit = value
                                                    self.dont_fragment_bit.value_namespace = name_space
                                                    self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ipv4-source-address"):
                                                    self.ipv4_source_address = value
                                                    self.ipv4_source_address.value_namespace = name_space
                                                    self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ipv6-source-address"):
                                                    self.ipv6_source_address = value
                                                    self.ipv6_source_address.value_namespace = name_space
                                                    self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "l2tp-class-name"):
                                                    self.l2tp_class_name = value
                                                    self.l2tp_class_name.value_namespace = name_space
                                                    self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-cookie-high-value"):
                                                    self.local_cookie_high_value = value
                                                    self.local_cookie_high_value.value_namespace = name_space
                                                    self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-cookie-low-value"):
                                                    self.local_cookie_low_value = value
                                                    self.local_cookie_low_value.value_namespace = name_space
                                                    self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-cookie-size"):
                                                    self.local_cookie_size = value
                                                    self.local_cookie_size.value_namespace = name_space
                                                    self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-secondary-cookie-high-value"):
                                                    self.local_secondary_cookie_high_value = value
                                                    self.local_secondary_cookie_high_value.value_namespace = name_space
                                                    self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-secondary-cookie-low-value"):
                                                    self.local_secondary_cookie_low_value = value
                                                    self.local_secondary_cookie_low_value.value_namespace = name_space
                                                    self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-secondary-cookie-size"):
                                                    self.local_secondary_cookie_size = value
                                                    self.local_secondary_cookie_size.value_namespace = name_space
                                                    self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-session-id"):
                                                    self.local_session_id = value
                                                    self.local_session_id.value_namespace = name_space
                                                    self.local_session_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "path-mtu-enabled"):
                                                    self.path_mtu_enabled = value
                                                    self.path_mtu_enabled.value_namespace = name_space
                                                    self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "path-mtu-max-value"):
                                                    self.path_mtu_max_value = value
                                                    self.path_mtu_max_value.value_namespace = name_space
                                                    self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-circuit-status-up"):
                                                    self.remote_circuit_status_up = value
                                                    self.remote_circuit_status_up.value_namespace = name_space
                                                    self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-cookie-high-value"):
                                                    self.remote_cookie_high_value = value
                                                    self.remote_cookie_high_value.value_namespace = name_space
                                                    self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-cookie-low-value"):
                                                    self.remote_cookie_low_value = value
                                                    self.remote_cookie_low_value.value_namespace = name_space
                                                    self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-cookie-size"):
                                                    self.remote_cookie_size = value
                                                    self.remote_cookie_size.value_namespace = name_space
                                                    self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-session-id"):
                                                    self.remote_session_id = value
                                                    self.remote_session_id.value_namespace = name_space
                                                    self.remote_session_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tos"):
                                                    self.tos = value
                                                    self.tos.value_namespace = name_space
                                                    self.tos.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tos-mode"):
                                                    self.tos_mode = value
                                                    self.tos_mode.value_namespace = name_space
                                                    self.tos_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ttl"):
                                                    self.ttl = value
                                                    self.ttl.value_namespace = name_space
                                                    self.ttl.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-state"):
                                                    self.tunnel_state = value
                                                    self.tunnel_state.value_namespace = name_space
                                                    self.tunnel_state.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.encapsulation.is_set or
                                                (self.atom is not None and self.atom.has_data()) or
                                                (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation.yfilter != YFilter.not_set or
                                                (self.atom is not None and self.atom.has_operation()) or
                                                (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "encapsulation-info" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atom"):
                                                if (self.atom is None):
                                                    self.atom = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                                    self.atom.parent = self
                                                    self._children_name_map["atom"] = "atom"
                                                return self.atom

                                            if (child_yang_name == "l2tpv3"):
                                                if (self.l2tpv3 is None):
                                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                                    self.l2tpv3.parent = self
                                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                                return self.l2tpv3

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation"):
                                                self.encapsulation = value
                                                self.encapsulation.value_namespace = name_space
                                                self.encapsulation.value_namespace_prefix = name_space_prefix


                                    class LocalInterface(Entity):
                                        """
                                        Local interface
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                            self.yang_name = "local-interface"
                                            self.yang_parent_name = "pseudowire"

                                            self.mtu = YLeaf(YType.uint32, "mtu")

                                            self.name = YLeaf(YType.str, "name")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                            self._children_yang_names.add("parameters")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mtu",
                                                            "name",
                                                            "payload_bytes") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                        class Parameters(Entity):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                                self.yang_name = "parameters"
                                                self.yang_parent_name = "local-interface"

                                                self.type = YLeaf(YType.enumeration, "type")

                                                self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                                self._children_yang_names.add("atm")

                                                self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                                self._children_yang_names.add("ethernet")

                                                self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                                self._children_yang_names.add("fr")

                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                self._children_yang_names.add("pseudowire-ether")

                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                self._children_yang_names.add("pseudowire-iw")

                                                self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                                self._children_yang_names.add("tdm")

                                                self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                                self._children_yang_names.add("vlan")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                            class Ethernet(Entity):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                    self.yang_name = "ethernet"
                                                    self.yang_parent_name = "parameters"

                                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("xconnect_tags") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.xconnect_tags.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ethernet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "xconnect-tags"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "xconnect-tags"):
                                                        self.xconnect_tags = value
                                                        self.xconnect_tags.value_namespace = name_space
                                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                            class Vlan(Entity):
                                                """
                                                VLAN
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\:  list of int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                    self.yang_name = "vlan"
                                                    self.yang_parent_name = "parameters"

                                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                    self.vlan_range = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("encapsulation_type",
                                                                    "outer_tag",
                                                                    "rewrite_tag",
                                                                    "simple_efp",
                                                                    "vlan_rewrite_tag",
                                                                    "xconnect_tags") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                                class VlanRange(Entity):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                        self.yang_name = "vlan-range"
                                                        self.yang_parent_name = "vlan"

                                                        self.lower = YLeaf(YType.uint16, "lower")

                                                        self.upper = YLeaf(YType.uint16, "upper")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("lower",
                                                                        "upper") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.lower.is_set or
                                                            self.upper.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.lower.yfilter != YFilter.not_set or
                                                            self.upper.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vlan-range" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "lower" or name == "upper"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "lower"):
                                                            self.lower = value
                                                            self.lower.value_namespace = name_space
                                                            self.lower.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "upper"):
                                                            self.upper = value
                                                            self.upper.value_namespace = name_space
                                                            self.upper.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vlan_range:
                                                        if (c.has_data()):
                                                            return True
                                                    for leaf in self.rewrite_tag.getYLeafs():
                                                        if (leaf.yfilter != YFilter.not_set):
                                                            return True
                                                    return (
                                                        self.encapsulation_type.is_set or
                                                        self.outer_tag.is_set or
                                                        self.simple_efp.is_set or
                                                        self.vlan_rewrite_tag.is_set or
                                                        self.xconnect_tags.is_set)

                                                def has_operation(self):
                                                    for c in self.vlan_range:
                                                        if (c.has_operation()):
                                                            return True
                                                    for leaf in self.rewrite_tag.getYLeafs():
                                                        if (leaf.is_set):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                                        self.outer_tag.yfilter != YFilter.not_set or
                                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                                        self.simple_efp.yfilter != YFilter.not_set or
                                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vlan-range"):
                                                        for c in self.vlan_range:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vlan_range.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "encapsulation-type"):
                                                        self.encapsulation_type = value
                                                        self.encapsulation_type.value_namespace = name_space
                                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "outer-tag"):
                                                        self.outer_tag = value
                                                        self.outer_tag.value_namespace = name_space
                                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rewrite-tag"):
                                                        self.rewrite_tag.append(value)
                                                    if(value_path == "simple-efp"):
                                                        self.simple_efp = value
                                                        self.simple_efp.value_namespace = name_space
                                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vlan-rewrite-tag"):
                                                        self.vlan_rewrite_tag = value
                                                        self.vlan_rewrite_tag.value_namespace = name_space
                                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "xconnect-tags"):
                                                        self.xconnect_tags = value
                                                        self.xconnect_tags.value_namespace = name_space
                                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                            class Tdm(Entity):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\:  str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                    self.yang_name = "tdm"
                                                    self.yang_parent_name = "parameters"

                                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                    self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                    self._children_yang_names.add("tdm-options")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("tdm_mode",
                                                                    "timeslot_group",
                                                                    "timeslot_rate") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                                class TdmOptions(Entity):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                        self.yang_name = "tdm-options"
                                                        self.yang_parent_name = "tdm"

                                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                        self.cas = YLeaf(YType.uint8, "cas")

                                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("bit_rate",
                                                                        "cas",
                                                                        "payload_bytes",
                                                                        "rtp",
                                                                        "rtp_header_payload_type",
                                                                        "signalling_packets",
                                                                        "ssrc",
                                                                        "timestamp_clock_freq",
                                                                        "timestamp_mode") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.bit_rate.is_set or
                                                            self.cas.is_set or
                                                            self.payload_bytes.is_set or
                                                            self.rtp.is_set or
                                                            self.rtp_header_payload_type.is_set or
                                                            self.signalling_packets.is_set or
                                                            self.ssrc.is_set or
                                                            self.timestamp_clock_freq.is_set or
                                                            self.timestamp_mode.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.bit_rate.yfilter != YFilter.not_set or
                                                            self.cas.yfilter != YFilter.not_set or
                                                            self.payload_bytes.yfilter != YFilter.not_set or
                                                            self.rtp.yfilter != YFilter.not_set or
                                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                            self.signalling_packets.yfilter != YFilter.not_set or
                                                            self.ssrc.yfilter != YFilter.not_set or
                                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tdm-options" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "bit-rate"):
                                                            self.bit_rate = value
                                                            self.bit_rate.value_namespace = name_space
                                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "cas"):
                                                            self.cas = value
                                                            self.cas.value_namespace = name_space
                                                            self.cas.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "payload-bytes"):
                                                            self.payload_bytes = value
                                                            self.payload_bytes.value_namespace = name_space
                                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtp"):
                                                            self.rtp = value
                                                            self.rtp.value_namespace = name_space
                                                            self.rtp.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtp-header-payload-type"):
                                                            self.rtp_header_payload_type = value
                                                            self.rtp_header_payload_type.value_namespace = name_space
                                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "signalling-packets"):
                                                            self.signalling_packets = value
                                                            self.signalling_packets.value_namespace = name_space
                                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ssrc"):
                                                            self.ssrc = value
                                                            self.ssrc.value_namespace = name_space
                                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "timestamp-clock-freq"):
                                                            self.timestamp_clock_freq = value
                                                            self.timestamp_clock_freq.value_namespace = name_space
                                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "timestamp-mode"):
                                                            self.timestamp_mode = value
                                                            self.timestamp_mode.value_namespace = name_space
                                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.tdm_mode.is_set or
                                                        self.timeslot_group.is_set or
                                                        self.timeslot_rate.is_set or
                                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.tdm_mode.yfilter != YFilter.not_set or
                                                        self.timeslot_group.yfilter != YFilter.not_set or
                                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tdm-options"):
                                                        if (self.tdm_options is None):
                                                            self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                            self.tdm_options.parent = self
                                                            self._children_name_map["tdm_options"] = "tdm-options"
                                                        return self.tdm_options

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "tdm-mode"):
                                                        self.tdm_mode = value
                                                        self.tdm_mode.value_namespace = name_space
                                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timeslot-group"):
                                                        self.timeslot_group = value
                                                        self.timeslot_group.value_namespace = name_space
                                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timeslot-rate"):
                                                        self.timeslot_rate = value
                                                        self.timeslot_rate.value_namespace = name_space
                                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                            class Atm(Entity):
                                                """
                                                ATM
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                    self.yang_name = "atm"
                                                    self.yang_parent_name = "parameters"

                                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                    self.vci = YLeaf(YType.uint16, "vci")

                                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("atm_mode",
                                                                    "maximum_number_cells_packed",
                                                                    "maximum_number_cells_un_packed",
                                                                    "vci",
                                                                    "vpi") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.atm_mode.is_set or
                                                        self.maximum_number_cells_packed.is_set or
                                                        self.maximum_number_cells_un_packed.is_set or
                                                        self.vci.is_set or
                                                        self.vpi.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.atm_mode.yfilter != YFilter.not_set or
                                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                        self.vci.yfilter != YFilter.not_set or
                                                        self.vpi.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "atm" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "atm-mode"):
                                                        self.atm_mode = value
                                                        self.atm_mode.value_namespace = name_space
                                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-number-cells-packed"):
                                                        self.maximum_number_cells_packed = value
                                                        self.maximum_number_cells_packed.value_namespace = name_space
                                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-number-cells-un-packed"):
                                                        self.maximum_number_cells_un_packed = value
                                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vci"):
                                                        self.vci = value
                                                        self.vci.value_namespace = name_space
                                                        self.vci.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpi"):
                                                        self.vpi = value
                                                        self.vpi.value_namespace = name_space
                                                        self.vpi.value_namespace_prefix = name_space_prefix


                                            class Fr(Entity):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                    self.yang_name = "fr"
                                                    self.yang_parent_name = "parameters"

                                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("dlci",
                                                                    "fr_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.dlci.is_set or
                                                        self.fr_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.dlci.yfilter != YFilter.not_set or
                                                        self.fr_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "dlci" or name == "fr-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "dlci"):
                                                        self.dlci = value
                                                        self.dlci.value_namespace = name_space
                                                        self.dlci.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fr-mode"):
                                                        self.fr_mode = value
                                                        self.fr_mode.value_namespace = name_space
                                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                                            class PseudowireEther(Entity):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                    self.yang_name = "pseudowire-ether"
                                                    self.yang_parent_name = "parameters"

                                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._children_yang_names.add("interface-list")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("internal_label",
                                                                    "is_valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-ether"

                                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                        self.interface = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_list_id",
                                                                        "interface_list_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "replicate_status") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.replicate_status.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.replicate_status.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "interface" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "replicate-status"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "replicate-status"):
                                                                self.replicate_status = value
                                                                self.replicate_status.value_namespace = name_space
                                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.interface:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.interface_list_id.is_set or
                                                            self.interface_list_name.is_set)

                                                    def has_operation(self):
                                                        for c in self.interface:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_list_id.yfilter != YFilter.not_set or
                                                            self.interface_list_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface-list" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "interface"):
                                                            for c in self.interface:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.interface.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-list-id"):
                                                            self.interface_list_id = value
                                                            self.interface_list_id.value_namespace = name_space
                                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-list-name"):
                                                            self.interface_list_name = value
                                                            self.interface_list_name.value_namespace = name_space
                                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.internal_label.is_set or
                                                        self.is_valid.is_set or
                                                        (self.interface_list is not None and self.interface_list.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.internal_label.yfilter != YFilter.not_set or
                                                        self.is_valid.yfilter != YFilter.not_set or
                                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pseudowire-ether" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface-list"):
                                                        if (self.interface_list is None):
                                                            self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                            self.interface_list.parent = self
                                                            self._children_name_map["interface_list"] = "interface-list"
                                                        return self.interface_list

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "internal-label"):
                                                        self.internal_label = value
                                                        self.internal_label.value_namespace = name_space
                                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-valid"):
                                                        self.is_valid = value
                                                        self.is_valid.value_namespace = name_space
                                                        self.is_valid.value_namespace_prefix = name_space_prefix


                                            class PseudowireIw(Entity):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                    self.yang_name = "pseudowire-iw"
                                                    self.yang_parent_name = "parameters"

                                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._children_yang_names.add("interface-list")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("internal_label",
                                                                    "is_valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-iw"

                                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                        self.interface = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_list_id",
                                                                        "interface_list_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "replicate_status") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.replicate_status.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.replicate_status.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "interface" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "replicate-status"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "replicate-status"):
                                                                self.replicate_status = value
                                                                self.replicate_status.value_namespace = name_space
                                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.interface:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.interface_list_id.is_set or
                                                            self.interface_list_name.is_set)

                                                    def has_operation(self):
                                                        for c in self.interface:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_list_id.yfilter != YFilter.not_set or
                                                            self.interface_list_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface-list" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "interface"):
                                                            for c in self.interface:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.interface.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-list-id"):
                                                            self.interface_list_id = value
                                                            self.interface_list_id.value_namespace = name_space
                                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-list-name"):
                                                            self.interface_list_name = value
                                                            self.interface_list_name.value_namespace = name_space
                                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.internal_label.is_set or
                                                        self.is_valid.is_set or
                                                        (self.interface_list is not None and self.interface_list.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.internal_label.yfilter != YFilter.not_set or
                                                        self.is_valid.yfilter != YFilter.not_set or
                                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pseudowire-iw" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface-list"):
                                                        if (self.interface_list is None):
                                                            self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                            self.interface_list.parent = self
                                                            self._children_name_map["interface_list"] = "interface-list"
                                                        return self.interface_list

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "internal-label"):
                                                        self.internal_label = value
                                                        self.internal_label.value_namespace = name_space
                                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-valid"):
                                                        self.is_valid = value
                                                        self.is_valid.value_namespace = name_space
                                                        self.is_valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.type.is_set or
                                                    (self.atm is not None and self.atm.has_data()) or
                                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                                    (self.fr is not None and self.fr.has_data()) or
                                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                    (self.tdm is not None and self.tdm.has_data()) or
                                                    (self.vlan is not None and self.vlan.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.type.yfilter != YFilter.not_set or
                                                    (self.atm is not None and self.atm.has_operation()) or
                                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                                    (self.fr is not None and self.fr.has_operation()) or
                                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                    (self.tdm is not None and self.tdm.has_operation()) or
                                                    (self.vlan is not None and self.vlan.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "parameters" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "atm"):
                                                    if (self.atm is None):
                                                        self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                        self.atm.parent = self
                                                        self._children_name_map["atm"] = "atm"
                                                    return self.atm

                                                if (child_yang_name == "ethernet"):
                                                    if (self.ethernet is None):
                                                        self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                        self.ethernet.parent = self
                                                        self._children_name_map["ethernet"] = "ethernet"
                                                    return self.ethernet

                                                if (child_yang_name == "fr"):
                                                    if (self.fr is None):
                                                        self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                        self.fr.parent = self
                                                        self._children_name_map["fr"] = "fr"
                                                    return self.fr

                                                if (child_yang_name == "pseudowire-ether"):
                                                    if (self.pseudowire_ether is None):
                                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                        self.pseudowire_ether.parent = self
                                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                    return self.pseudowire_ether

                                                if (child_yang_name == "pseudowire-iw"):
                                                    if (self.pseudowire_iw is None):
                                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                        self.pseudowire_iw.parent = self
                                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                    return self.pseudowire_iw

                                                if (child_yang_name == "tdm"):
                                                    if (self.tdm is None):
                                                        self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                        self.tdm.parent = self
                                                        self._children_name_map["tdm"] = "tdm"
                                                    return self.tdm

                                                if (child_yang_name == "vlan"):
                                                    if (self.vlan is None):
                                                        self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                        self.vlan.parent = self
                                                        self._children_name_map["vlan"] = "vlan"
                                                    return self.vlan

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "type"):
                                                    self.type = value
                                                    self.type.value_namespace = name_space
                                                    self.type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.mtu.is_set or
                                                self.name.is_set or
                                                self.payload_bytes.is_set or
                                                (self.parameters is not None and self.parameters.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mtu.yfilter != YFilter.not_set or
                                                self.name.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                (self.parameters is not None and self.parameters.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mtu.get_name_leafdata())
                                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.name.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "parameters"):
                                                if (self.parameters is None):
                                                    self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                                    self.parameters.parent = self
                                                    self._children_name_map["parameters"] = "parameters"
                                                return self.parameters

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mtu"):
                                                self.mtu = value
                                                self.mtu.value_namespace = name_space
                                                self.mtu.value_namespace_prefix = name_space_prefix
                                            if(value_path == "name"):
                                                self.name = value
                                                self.name.value_namespace = name_space
                                                self.name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                                    class RemoteInterface(Entity):
                                        """
                                        Remote interface
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                            self.yang_name = "remote-interface"
                                            self.yang_parent_name = "pseudowire"

                                            self.mtu = YLeaf(YType.uint32, "mtu")

                                            self.name = YLeaf(YType.str, "name")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                            self._children_yang_names.add("parameters")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("mtu",
                                                            "name",
                                                            "payload_bytes") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                        class Parameters(Entity):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                                self.yang_name = "parameters"
                                                self.yang_parent_name = "remote-interface"

                                                self.type = YLeaf(YType.enumeration, "type")

                                                self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                                self._children_yang_names.add("atm")

                                                self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                                self._children_yang_names.add("ethernet")

                                                self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                                self._children_yang_names.add("fr")

                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                self._children_yang_names.add("pseudowire-ether")

                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                self._children_yang_names.add("pseudowire-iw")

                                                self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                                self._children_yang_names.add("tdm")

                                                self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                                self._children_yang_names.add("vlan")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                            class Ethernet(Entity):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                    self.yang_name = "ethernet"
                                                    self.yang_parent_name = "parameters"

                                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("xconnect_tags") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.xconnect_tags.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ethernet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "xconnect-tags"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "xconnect-tags"):
                                                        self.xconnect_tags = value
                                                        self.xconnect_tags.value_namespace = name_space
                                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                            class Vlan(Entity):
                                                """
                                                VLAN
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\:  list of int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                    self.yang_name = "vlan"
                                                    self.yang_parent_name = "parameters"

                                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                    self.vlan_range = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("encapsulation_type",
                                                                    "outer_tag",
                                                                    "rewrite_tag",
                                                                    "simple_efp",
                                                                    "vlan_rewrite_tag",
                                                                    "xconnect_tags") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                                class VlanRange(Entity):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                        self.yang_name = "vlan-range"
                                                        self.yang_parent_name = "vlan"

                                                        self.lower = YLeaf(YType.uint16, "lower")

                                                        self.upper = YLeaf(YType.uint16, "upper")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("lower",
                                                                        "upper") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.lower.is_set or
                                                            self.upper.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.lower.yfilter != YFilter.not_set or
                                                            self.upper.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "vlan-range" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "lower" or name == "upper"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "lower"):
                                                            self.lower = value
                                                            self.lower.value_namespace = name_space
                                                            self.lower.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "upper"):
                                                            self.upper = value
                                                            self.upper.value_namespace = name_space
                                                            self.upper.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.vlan_range:
                                                        if (c.has_data()):
                                                            return True
                                                    for leaf in self.rewrite_tag.getYLeafs():
                                                        if (leaf.yfilter != YFilter.not_set):
                                                            return True
                                                    return (
                                                        self.encapsulation_type.is_set or
                                                        self.outer_tag.is_set or
                                                        self.simple_efp.is_set or
                                                        self.vlan_rewrite_tag.is_set or
                                                        self.xconnect_tags.is_set)

                                                def has_operation(self):
                                                    for c in self.vlan_range:
                                                        if (c.has_operation()):
                                                            return True
                                                    for leaf in self.rewrite_tag.getYLeafs():
                                                        if (leaf.is_set):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                                        self.outer_tag.yfilter != YFilter.not_set or
                                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                                        self.simple_efp.yfilter != YFilter.not_set or
                                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "vlan-range"):
                                                        for c in self.vlan_range:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.vlan_range.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "encapsulation-type"):
                                                        self.encapsulation_type = value
                                                        self.encapsulation_type.value_namespace = name_space
                                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "outer-tag"):
                                                        self.outer_tag = value
                                                        self.outer_tag.value_namespace = name_space
                                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rewrite-tag"):
                                                        self.rewrite_tag.append(value)
                                                    if(value_path == "simple-efp"):
                                                        self.simple_efp = value
                                                        self.simple_efp.value_namespace = name_space
                                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vlan-rewrite-tag"):
                                                        self.vlan_rewrite_tag = value
                                                        self.vlan_rewrite_tag.value_namespace = name_space
                                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "xconnect-tags"):
                                                        self.xconnect_tags = value
                                                        self.xconnect_tags.value_namespace = name_space
                                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                            class Tdm(Entity):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\:  str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                    self.yang_name = "tdm"
                                                    self.yang_parent_name = "parameters"

                                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                    self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                    self._children_yang_names.add("tdm-options")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("tdm_mode",
                                                                    "timeslot_group",
                                                                    "timeslot_rate") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                                class TdmOptions(Entity):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                        self.yang_name = "tdm-options"
                                                        self.yang_parent_name = "tdm"

                                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                        self.cas = YLeaf(YType.uint8, "cas")

                                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("bit_rate",
                                                                        "cas",
                                                                        "payload_bytes",
                                                                        "rtp",
                                                                        "rtp_header_payload_type",
                                                                        "signalling_packets",
                                                                        "ssrc",
                                                                        "timestamp_clock_freq",
                                                                        "timestamp_mode") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.bit_rate.is_set or
                                                            self.cas.is_set or
                                                            self.payload_bytes.is_set or
                                                            self.rtp.is_set or
                                                            self.rtp_header_payload_type.is_set or
                                                            self.signalling_packets.is_set or
                                                            self.ssrc.is_set or
                                                            self.timestamp_clock_freq.is_set or
                                                            self.timestamp_mode.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.bit_rate.yfilter != YFilter.not_set or
                                                            self.cas.yfilter != YFilter.not_set or
                                                            self.payload_bytes.yfilter != YFilter.not_set or
                                                            self.rtp.yfilter != YFilter.not_set or
                                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                            self.signalling_packets.yfilter != YFilter.not_set or
                                                            self.ssrc.yfilter != YFilter.not_set or
                                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tdm-options" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "bit-rate"):
                                                            self.bit_rate = value
                                                            self.bit_rate.value_namespace = name_space
                                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "cas"):
                                                            self.cas = value
                                                            self.cas.value_namespace = name_space
                                                            self.cas.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "payload-bytes"):
                                                            self.payload_bytes = value
                                                            self.payload_bytes.value_namespace = name_space
                                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtp"):
                                                            self.rtp = value
                                                            self.rtp.value_namespace = name_space
                                                            self.rtp.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "rtp-header-payload-type"):
                                                            self.rtp_header_payload_type = value
                                                            self.rtp_header_payload_type.value_namespace = name_space
                                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "signalling-packets"):
                                                            self.signalling_packets = value
                                                            self.signalling_packets.value_namespace = name_space
                                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ssrc"):
                                                            self.ssrc = value
                                                            self.ssrc.value_namespace = name_space
                                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "timestamp-clock-freq"):
                                                            self.timestamp_clock_freq = value
                                                            self.timestamp_clock_freq.value_namespace = name_space
                                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "timestamp-mode"):
                                                            self.timestamp_mode = value
                                                            self.timestamp_mode.value_namespace = name_space
                                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.tdm_mode.is_set or
                                                        self.timeslot_group.is_set or
                                                        self.timeslot_rate.is_set or
                                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.tdm_mode.yfilter != YFilter.not_set or
                                                        self.timeslot_group.yfilter != YFilter.not_set or
                                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tdm-options"):
                                                        if (self.tdm_options is None):
                                                            self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                            self.tdm_options.parent = self
                                                            self._children_name_map["tdm_options"] = "tdm-options"
                                                        return self.tdm_options

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "tdm-mode"):
                                                        self.tdm_mode = value
                                                        self.tdm_mode.value_namespace = name_space
                                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timeslot-group"):
                                                        self.timeslot_group = value
                                                        self.timeslot_group.value_namespace = name_space
                                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timeslot-rate"):
                                                        self.timeslot_rate = value
                                                        self.timeslot_rate.value_namespace = name_space
                                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                            class Atm(Entity):
                                                """
                                                ATM
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                    self.yang_name = "atm"
                                                    self.yang_parent_name = "parameters"

                                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                    self.vci = YLeaf(YType.uint16, "vci")

                                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("atm_mode",
                                                                    "maximum_number_cells_packed",
                                                                    "maximum_number_cells_un_packed",
                                                                    "vci",
                                                                    "vpi") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.atm_mode.is_set or
                                                        self.maximum_number_cells_packed.is_set or
                                                        self.maximum_number_cells_un_packed.is_set or
                                                        self.vci.is_set or
                                                        self.vpi.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.atm_mode.yfilter != YFilter.not_set or
                                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                        self.vci.yfilter != YFilter.not_set or
                                                        self.vpi.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "atm" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "atm-mode"):
                                                        self.atm_mode = value
                                                        self.atm_mode.value_namespace = name_space
                                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-number-cells-packed"):
                                                        self.maximum_number_cells_packed = value
                                                        self.maximum_number_cells_packed.value_namespace = name_space
                                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-number-cells-un-packed"):
                                                        self.maximum_number_cells_un_packed = value
                                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vci"):
                                                        self.vci = value
                                                        self.vci.value_namespace = name_space
                                                        self.vci.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpi"):
                                                        self.vpi = value
                                                        self.vpi.value_namespace = name_space
                                                        self.vpi.value_namespace_prefix = name_space_prefix


                                            class Fr(Entity):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                    self.yang_name = "fr"
                                                    self.yang_parent_name = "parameters"

                                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("dlci",
                                                                    "fr_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.dlci.is_set or
                                                        self.fr_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.dlci.yfilter != YFilter.not_set or
                                                        self.fr_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "dlci" or name == "fr-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "dlci"):
                                                        self.dlci = value
                                                        self.dlci.value_namespace = name_space
                                                        self.dlci.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "fr-mode"):
                                                        self.fr_mode = value
                                                        self.fr_mode.value_namespace = name_space
                                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                                            class PseudowireEther(Entity):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                    self.yang_name = "pseudowire-ether"
                                                    self.yang_parent_name = "parameters"

                                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._children_yang_names.add("interface-list")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("internal_label",
                                                                    "is_valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-ether"

                                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                        self.interface = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_list_id",
                                                                        "interface_list_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "replicate_status") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.replicate_status.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.replicate_status.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "interface" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "replicate-status"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "replicate-status"):
                                                                self.replicate_status = value
                                                                self.replicate_status.value_namespace = name_space
                                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.interface:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.interface_list_id.is_set or
                                                            self.interface_list_name.is_set)

                                                    def has_operation(self):
                                                        for c in self.interface:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_list_id.yfilter != YFilter.not_set or
                                                            self.interface_list_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface-list" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "interface"):
                                                            for c in self.interface:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.interface.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-list-id"):
                                                            self.interface_list_id = value
                                                            self.interface_list_id.value_namespace = name_space
                                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-list-name"):
                                                            self.interface_list_name = value
                                                            self.interface_list_name.value_namespace = name_space
                                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.internal_label.is_set or
                                                        self.is_valid.is_set or
                                                        (self.interface_list is not None and self.interface_list.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.internal_label.yfilter != YFilter.not_set or
                                                        self.is_valid.yfilter != YFilter.not_set or
                                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pseudowire-ether" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface-list"):
                                                        if (self.interface_list is None):
                                                            self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                            self.interface_list.parent = self
                                                            self._children_name_map["interface_list"] = "interface-list"
                                                        return self.interface_list

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "internal-label"):
                                                        self.internal_label = value
                                                        self.internal_label.value_namespace = name_space
                                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-valid"):
                                                        self.is_valid = value
                                                        self.is_valid.value_namespace = name_space
                                                        self.is_valid.value_namespace_prefix = name_space_prefix


                                            class PseudowireIw(Entity):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                    self.yang_name = "pseudowire-iw"
                                                    self.yang_parent_name = "parameters"

                                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._children_yang_names.add("interface-list")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("internal_label",
                                                                    "is_valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-iw"

                                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                        self.interface = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_list_id",
                                                                        "interface_list_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("interface_name",
                                                                            "replicate_status") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.interface_name.is_set or
                                                                self.replicate_status.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.interface_name.yfilter != YFilter.not_set or
                                                                self.replicate_status.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "interface" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "interface-name" or name == "replicate-status"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "interface-name"):
                                                                self.interface_name = value
                                                                self.interface_name.value_namespace = name_space
                                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "replicate-status"):
                                                                self.replicate_status = value
                                                                self.replicate_status.value_namespace = name_space
                                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.interface:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.interface_list_id.is_set or
                                                            self.interface_list_name.is_set)

                                                    def has_operation(self):
                                                        for c in self.interface:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_list_id.yfilter != YFilter.not_set or
                                                            self.interface_list_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface-list" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "interface"):
                                                            for c in self.interface:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.interface.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-list-id"):
                                                            self.interface_list_id = value
                                                            self.interface_list_id.value_namespace = name_space
                                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "interface-list-name"):
                                                            self.interface_list_name = value
                                                            self.interface_list_name.value_namespace = name_space
                                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.internal_label.is_set or
                                                        self.is_valid.is_set or
                                                        (self.interface_list is not None and self.interface_list.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.internal_label.yfilter != YFilter.not_set or
                                                        self.is_valid.yfilter != YFilter.not_set or
                                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pseudowire-iw" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface-list"):
                                                        if (self.interface_list is None):
                                                            self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                            self.interface_list.parent = self
                                                            self._children_name_map["interface_list"] = "interface-list"
                                                        return self.interface_list

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "internal-label"):
                                                        self.internal_label = value
                                                        self.internal_label.value_namespace = name_space
                                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-valid"):
                                                        self.is_valid = value
                                                        self.is_valid.value_namespace = name_space
                                                        self.is_valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.type.is_set or
                                                    (self.atm is not None and self.atm.has_data()) or
                                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                                    (self.fr is not None and self.fr.has_data()) or
                                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                    (self.tdm is not None and self.tdm.has_data()) or
                                                    (self.vlan is not None and self.vlan.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.type.yfilter != YFilter.not_set or
                                                    (self.atm is not None and self.atm.has_operation()) or
                                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                                    (self.fr is not None and self.fr.has_operation()) or
                                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                    (self.tdm is not None and self.tdm.has_operation()) or
                                                    (self.vlan is not None and self.vlan.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "parameters" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "atm"):
                                                    if (self.atm is None):
                                                        self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                        self.atm.parent = self
                                                        self._children_name_map["atm"] = "atm"
                                                    return self.atm

                                                if (child_yang_name == "ethernet"):
                                                    if (self.ethernet is None):
                                                        self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                        self.ethernet.parent = self
                                                        self._children_name_map["ethernet"] = "ethernet"
                                                    return self.ethernet

                                                if (child_yang_name == "fr"):
                                                    if (self.fr is None):
                                                        self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                        self.fr.parent = self
                                                        self._children_name_map["fr"] = "fr"
                                                    return self.fr

                                                if (child_yang_name == "pseudowire-ether"):
                                                    if (self.pseudowire_ether is None):
                                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                        self.pseudowire_ether.parent = self
                                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                    return self.pseudowire_ether

                                                if (child_yang_name == "pseudowire-iw"):
                                                    if (self.pseudowire_iw is None):
                                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                        self.pseudowire_iw.parent = self
                                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                    return self.pseudowire_iw

                                                if (child_yang_name == "tdm"):
                                                    if (self.tdm is None):
                                                        self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                        self.tdm.parent = self
                                                        self._children_name_map["tdm"] = "tdm"
                                                    return self.tdm

                                                if (child_yang_name == "vlan"):
                                                    if (self.vlan is None):
                                                        self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                        self.vlan.parent = self
                                                        self._children_name_map["vlan"] = "vlan"
                                                    return self.vlan

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "type"):
                                                    self.type = value
                                                    self.type.value_namespace = name_space
                                                    self.type.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.mtu.is_set or
                                                self.name.is_set or
                                                self.payload_bytes.is_set or
                                                (self.parameters is not None and self.parameters.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.mtu.yfilter != YFilter.not_set or
                                                self.name.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                (self.parameters is not None and self.parameters.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mtu.get_name_leafdata())
                                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.name.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "parameters"):
                                                if (self.parameters is None):
                                                    self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                                    self.parameters.parent = self
                                                    self._children_name_map["parameters"] = "parameters"
                                                return self.parameters

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "mtu"):
                                                self.mtu = value
                                                self.mtu.value_namespace = name_space
                                                self.mtu.value_namespace_prefix = name_space_prefix
                                            if(value_path == "name"):
                                                self.name = value
                                                self.name.value_namespace = name_space
                                                self.name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                                    class PreferredPath(Entity):
                                        """
                                        MPLS Preferred Path
                                        
                                        .. attribute:: ip_tunnel_interface_number
                                        
                                        	IPTunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop_ip
                                        
                                        	NextHopIP
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: option
                                        
                                        	Option
                                        	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                        
                                        .. attribute:: te_tunnel_interface_number
                                        
                                        	TETunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tp_tunnel_interface_number
                                        
                                        	TPTunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                            self.yang_name = "preferred-path"
                                            self.yang_parent_name = "pseudowire"

                                            self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                            self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                            self.option = YLeaf(YType.enumeration, "option")

                                            self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                            self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ip_tunnel_interface_number",
                                                            "next_hop_ip",
                                                            "option",
                                                            "te_tunnel_interface_number",
                                                            "tp_tunnel_interface_number") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ip_tunnel_interface_number.is_set or
                                                self.next_hop_ip.is_set or
                                                self.option.is_set or
                                                self.te_tunnel_interface_number.is_set or
                                                self.tp_tunnel_interface_number.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                                self.next_hop_ip.yfilter != YFilter.not_set or
                                                self.option.yfilter != YFilter.not_set or
                                                self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                                self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "preferred-path" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                            if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.option.get_name_leafdata())
                                            if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                            if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ip-tunnel-interface-number"):
                                                self.ip_tunnel_interface_number = value
                                                self.ip_tunnel_interface_number.value_namespace = name_space
                                                self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-ip"):
                                                self.next_hop_ip = value
                                                self.next_hop_ip.value_namespace = name_space
                                                self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                            if(value_path == "option"):
                                                self.option = value
                                                self.option.value_namespace = name_space
                                                self.option.value_namespace_prefix = name_space_prefix
                                            if(value_path == "te-tunnel-interface-number"):
                                                self.te_tunnel_interface_number = value
                                                self.te_tunnel_interface_number.value_namespace = name_space
                                                self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tp-tunnel-interface-number"):
                                                self.tp_tunnel_interface_number = value
                                                self.tp_tunnel_interface_number.value_namespace = name_space
                                                self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                                    class LocalSignalling(Entity):
                                        """
                                        Local signalling
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                            self.yang_name = "local-signalling"
                                            self.yang_parent_name = "pseudowire"

                                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                                            self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                            self._children_yang_names.add("status-tlv")

                                            self.tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("pw_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                        class StatusTlv(Entity):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                                self.yang_name = "status-tlv"
                                                self.yang_parent_name = "local-signalling"

                                                self.description = YLeaf(YType.str, "description")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                                self.remote_address = YLeaf(YType.str, "remote-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("description",
                                                                "local_address",
                                                                "pw_id",
                                                                "remote_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.description.is_set or
                                                    self.local_address.is_set or
                                                    self.pw_id.is_set or
                                                    self.remote_address.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.local_address.yfilter != YFilter.not_set or
                                                    self.pw_id.yfilter != YFilter.not_set or
                                                    self.remote_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "status-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-address"):
                                                    self.local_address = value
                                                    self.local_address.value_namespace = name_space
                                                    self.local_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pw-id"):
                                                    self.pw_id = value
                                                    self.pw_id.value_namespace = name_space
                                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-address"):
                                                    self.remote_address = value
                                                    self.remote_address.value_namespace = name_space
                                                    self.remote_address.value_namespace_prefix = name_space_prefix


                                        class Tlv(Entity):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "local-signalling"

                                                self.description = YLeaf(YType.str, "description")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                                self.remote_address = YLeaf(YType.str, "remote-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("description",
                                                                "local_address",
                                                                "pw_id",
                                                                "remote_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.description.is_set or
                                                    self.local_address.is_set or
                                                    self.pw_id.is_set or
                                                    self.remote_address.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.local_address.yfilter != YFilter.not_set or
                                                    self.pw_id.yfilter != YFilter.not_set or
                                                    self.remote_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-address"):
                                                    self.local_address = value
                                                    self.local_address.value_namespace = name_space
                                                    self.local_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pw-id"):
                                                    self.pw_id = value
                                                    self.pw_id.value_namespace = name_space
                                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-address"):
                                                    self.remote_address = value
                                                    self.remote_address.value_namespace = name_space
                                                    self.remote_address.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.tlv:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.pw_status.is_set or
                                                (self.status_tlv is not None and self.status_tlv.has_data()))

                                        def has_operation(self):
                                            for c in self.tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.pw_status.yfilter != YFilter.not_set or
                                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-signalling" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "status-tlv"):
                                                if (self.status_tlv is None):
                                                    self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                                    self.status_tlv.parent = self
                                                    self._children_name_map["status_tlv"] = "status-tlv"
                                                return self.status_tlv

                                            if (child_yang_name == "tlv"):
                                                for c in self.tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.tlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "pw-status"):
                                                self.pw_status = value
                                                self.pw_status.value_namespace = name_space
                                                self.pw_status.value_namespace_prefix = name_space_prefix


                                    class RemoteSignalling(Entity):
                                        """
                                        Remote signalling
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                            self.yang_name = "remote-signalling"
                                            self.yang_parent_name = "pseudowire"

                                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                                            self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                            self._children_yang_names.add("status-tlv")

                                            self.tlv = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("pw_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                        class StatusTlv(Entity):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                                self.yang_name = "status-tlv"
                                                self.yang_parent_name = "remote-signalling"

                                                self.description = YLeaf(YType.str, "description")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                                self.remote_address = YLeaf(YType.str, "remote-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("description",
                                                                "local_address",
                                                                "pw_id",
                                                                "remote_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.description.is_set or
                                                    self.local_address.is_set or
                                                    self.pw_id.is_set or
                                                    self.remote_address.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.local_address.yfilter != YFilter.not_set or
                                                    self.pw_id.yfilter != YFilter.not_set or
                                                    self.remote_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "status-tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-address"):
                                                    self.local_address = value
                                                    self.local_address.value_namespace = name_space
                                                    self.local_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pw-id"):
                                                    self.pw_id = value
                                                    self.pw_id.value_namespace = name_space
                                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-address"):
                                                    self.remote_address = value
                                                    self.remote_address.value_namespace = name_space
                                                    self.remote_address.value_namespace_prefix = name_space_prefix


                                        class Tlv(Entity):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "remote-signalling"

                                                self.description = YLeaf(YType.str, "description")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                                self.remote_address = YLeaf(YType.str, "remote-address")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("description",
                                                                "local_address",
                                                                "pw_id",
                                                                "remote_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.description.is_set or
                                                    self.local_address.is_set or
                                                    self.pw_id.is_set or
                                                    self.remote_address.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.description.yfilter != YFilter.not_set or
                                                    self.local_address.yfilter != YFilter.not_set or
                                                    self.pw_id.yfilter != YFilter.not_set or
                                                    self.remote_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tlv" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.description.get_name_leafdata())
                                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "description"):
                                                    self.description = value
                                                    self.description.value_namespace = name_space
                                                    self.description.value_namespace_prefix = name_space_prefix
                                                if(value_path == "local-address"):
                                                    self.local_address = value
                                                    self.local_address.value_namespace = name_space
                                                    self.local_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "pw-id"):
                                                    self.pw_id = value
                                                    self.pw_id.value_namespace = name_space
                                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "remote-address"):
                                                    self.remote_address = value
                                                    self.remote_address.value_namespace = name_space
                                                    self.remote_address.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.tlv:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.pw_status.is_set or
                                                (self.status_tlv is not None and self.status_tlv.has_data()))

                                        def has_operation(self):
                                            for c in self.tlv:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.pw_status.yfilter != YFilter.not_set or
                                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-signalling" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "status-tlv"):
                                                if (self.status_tlv is None):
                                                    self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                                    self.status_tlv.parent = self
                                                    self._children_name_map["status_tlv"] = "status-tlv"
                                                return self.status_tlv

                                            if (child_yang_name == "tlv"):
                                                for c in self.tlv:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.tlv.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "pw-status"):
                                                self.pw_status = value
                                                self.pw_status.value_namespace = name_space
                                                self.pw_status.value_namespace_prefix = name_space_prefix


                                    class Statistics(Entity):
                                        """
                                        Statistics
                                        
                                        .. attribute:: dispostion_stats
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                        
                                        .. attribute:: impostion_stats
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                        
                                        .. attribute:: sequence_number
                                        
                                        	sequence numbers
                                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                            self.yang_name = "statistics"
                                            self.yang_parent_name = "pseudowire"

                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            self._children_yang_names.add("dispostion-stats")

                                            self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                            self._children_yang_names.add("impostion-stats")

                                            self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                            self._children_yang_names.add("sequence-number")


                                        class ImpostionStats(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast
                                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                            
                                            .. attribute:: imposition_mtu_drop
                                            
                                            	imposition mtu drop stats
                                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                            
                                            .. attribute:: imposition_stat
                                            
                                            	imposition stats
                                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                            
                                            .. attribute:: impostion_tail_drop
                                            
                                            	imposition tail drop stats
                                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                            
                                            .. attribute:: l2fsbi_drop
                                            
                                            	rx discards
                                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast
                                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Unknown Unicast
                                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                                self.yang_name = "impostion-stats"
                                                self.yang_parent_name = "statistics"

                                                self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                                self._children_yang_names.add("broadcast")

                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                self._children_yang_names.add("imposition-mtu-drop")

                                                self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                                self._children_yang_names.add("imposition-stat")

                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                self._children_yang_names.add("impostion-tail-drop")

                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                                self._children_yang_names.add("known-unicast")

                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                self._children_yang_names.add("l2fsbi-drop")

                                                self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                                self._children_yang_names.add("multicast")

                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                self._children_yang_names.add("unknown-unicast")


                                            class ImpositionStat(Entity):
                                                """
                                                imposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                    self.yang_name = "imposition-stat"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "imposition-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class ImpositionMtuDrop(Entity):
                                                """
                                                imposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                    self.yang_name = "imposition-mtu-drop"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class ImpostionTailDrop(Entity):
                                                """
                                                imposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                    self.yang_name = "impostion-tail-drop"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "impostion-tail-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class L2FsbiDrop(Entity):
                                                """
                                                rx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                    self.yang_name = "l2fsbi-drop"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "l2fsbi-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class Multicast(Entity):
                                                """
                                                Multicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                    self.yang_name = "multicast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class Broadcast(Entity):
                                                """
                                                Broadcast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                    self.yang_name = "broadcast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "broadcast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "known-unicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class UnknownUnicast(Entity):
                                                """
                                                Unknown Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                    self.yang_name = "unknown-unicast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unknown-unicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                    (self.multicast is not None and self.multicast.has_data()) or
                                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                    (self.multicast is not None and self.multicast.has_operation()) or
                                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "broadcast"):
                                                    if (self.broadcast is None):
                                                        self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                        self.broadcast.parent = self
                                                        self._children_name_map["broadcast"] = "broadcast"
                                                    return self.broadcast

                                                if (child_yang_name == "imposition-mtu-drop"):
                                                    if (self.imposition_mtu_drop is None):
                                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                        self.imposition_mtu_drop.parent = self
                                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                    return self.imposition_mtu_drop

                                                if (child_yang_name == "imposition-stat"):
                                                    if (self.imposition_stat is None):
                                                        self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                        self.imposition_stat.parent = self
                                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                                    return self.imposition_stat

                                                if (child_yang_name == "impostion-tail-drop"):
                                                    if (self.impostion_tail_drop is None):
                                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                        self.impostion_tail_drop.parent = self
                                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                    return self.impostion_tail_drop

                                                if (child_yang_name == "known-unicast"):
                                                    if (self.known_unicast is None):
                                                        self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                        self.known_unicast.parent = self
                                                        self._children_name_map["known_unicast"] = "known-unicast"
                                                    return self.known_unicast

                                                if (child_yang_name == "l2fsbi-drop"):
                                                    if (self.l2fsbi_drop is None):
                                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                        self.l2fsbi_drop.parent = self
                                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                    return self.l2fsbi_drop

                                                if (child_yang_name == "multicast"):
                                                    if (self.multicast is None):
                                                        self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                        self.multicast.parent = self
                                                        self._children_name_map["multicast"] = "multicast"
                                                    return self.multicast

                                                if (child_yang_name == "unknown-unicast"):
                                                    if (self.unknown_unicast is None):
                                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                        self.unknown_unicast.parent = self
                                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                    return self.unknown_unicast

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class DispostionStats(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: broadcast_drop
                                            
                                            	disposition storm control broadcast drop stats
                                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                            
                                            .. attribute:: dai_drop
                                            
                                            	Disposition dynamic ARP inspection drop statistics
                                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                            
                                            .. attribute:: disposition_mtu_drop
                                            
                                            	disposition mtu drop stats
                                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                            
                                            .. attribute:: disposition_oo_o_drops
                                            
                                            	Disposition Out\-of\-Order Drops
                                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                            
                                            .. attribute:: disposition_p2mp_stats
                                            
                                            	Disposition P2MP Stats
                                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                            
                                            .. attribute:: disposition_stat
                                            
                                            	disposition stats
                                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                            
                                            .. attribute:: disposition_tail_drop
                                            
                                            	disposition tail drop stats
                                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                            
                                            .. attribute:: ipsg_drop
                                            
                                            	disposition IP source guard drop statistics
                                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                            
                                            .. attribute:: mac_move
                                            
                                            	MAC Move
                                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                            
                                            .. attribute:: multicast_drop
                                            
                                            	disposition storm control multicast drop stats
                                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                            
                                            .. attribute:: received_drops
                                            
                                            	tx discards
                                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                            
                                            .. attribute:: unicast_drop
                                            
                                            	disposition storm control unknown unicast drop stats
                                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                                self.yang_name = "dispostion-stats"
                                                self.yang_parent_name = "statistics"

                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                self._children_yang_names.add("broadcast-drop")

                                                self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                                self._children_yang_names.add("dai-drop")

                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                self._children_yang_names.add("disposition-mtu-drop")

                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                self._children_yang_names.add("disposition-oo-o-drops")

                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                self._children_yang_names.add("disposition-p2mp-stats")

                                                self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                                self._children_yang_names.add("disposition-stat")

                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                self._children_yang_names.add("disposition-tail-drop")

                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                self._children_yang_names.add("ipsg-drop")

                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                                self._children_yang_names.add("known-unicast")

                                                self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                                self._children_yang_names.add("mac-move")

                                                self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                                self._children_yang_names.add("multicast-drop")

                                                self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                                self._children_yang_names.add("received-drops")

                                                self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                                self._children_yang_names.add("unicast-drop")


                                            class DispositionStat(Entity):
                                                """
                                                disposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                    self.yang_name = "disposition-stat"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionMtuDrop(Entity):
                                                """
                                                disposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                    self.yang_name = "disposition-mtu-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionTailDrop(Entity):
                                                """
                                                disposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                    self.yang_name = "disposition-tail-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-tail-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class MulticastDrop(Entity):
                                                """
                                                disposition storm control multicast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                    self.yang_name = "multicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multicast-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class UnicastDrop(Entity):
                                                """
                                                disposition storm control unknown unicast drop
                                                stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                    self.yang_name = "unicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unicast-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class BroadcastDrop(Entity):
                                                """
                                                disposition storm control broadcast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                    self.yang_name = "broadcast-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "broadcast-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class ReceivedDrops(Entity):
                                                """
                                                tx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                    self.yang_name = "received-drops"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "received-drops" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DaiDrop(Entity):
                                                """
                                                Disposition dynamic ARP inspection drop
                                                statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                    self.yang_name = "dai-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dai-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class IpsgDrop(Entity):
                                                """
                                                disposition IP source guard drop statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                    self.yang_name = "ipsg-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ipsg-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionOoODrops(Entity):
                                                """
                                                Disposition Out\-of\-Order Drops
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                    self.yang_name = "disposition-oo-o-drops"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionP2MpStats(Entity):
                                                """
                                                Disposition P2MP Stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                    self.yang_name = "disposition-p2mp-stats"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "known-unicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class MacMove(Entity):
                                                """
                                                MAC Move
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                    self.yang_name = "mac-move"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "mac-move" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dispostion-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "broadcast-drop"):
                                                    if (self.broadcast_drop is None):
                                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                        self.broadcast_drop.parent = self
                                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                    return self.broadcast_drop

                                                if (child_yang_name == "dai-drop"):
                                                    if (self.dai_drop is None):
                                                        self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                        self.dai_drop.parent = self
                                                        self._children_name_map["dai_drop"] = "dai-drop"
                                                    return self.dai_drop

                                                if (child_yang_name == "disposition-mtu-drop"):
                                                    if (self.disposition_mtu_drop is None):
                                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                        self.disposition_mtu_drop.parent = self
                                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                    return self.disposition_mtu_drop

                                                if (child_yang_name == "disposition-oo-o-drops"):
                                                    if (self.disposition_oo_o_drops is None):
                                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                        self.disposition_oo_o_drops.parent = self
                                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                    return self.disposition_oo_o_drops

                                                if (child_yang_name == "disposition-p2mp-stats"):
                                                    if (self.disposition_p2mp_stats is None):
                                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                        self.disposition_p2mp_stats.parent = self
                                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                    return self.disposition_p2mp_stats

                                                if (child_yang_name == "disposition-stat"):
                                                    if (self.disposition_stat is None):
                                                        self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                        self.disposition_stat.parent = self
                                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                                    return self.disposition_stat

                                                if (child_yang_name == "disposition-tail-drop"):
                                                    if (self.disposition_tail_drop is None):
                                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                        self.disposition_tail_drop.parent = self
                                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                    return self.disposition_tail_drop

                                                if (child_yang_name == "ipsg-drop"):
                                                    if (self.ipsg_drop is None):
                                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                        self.ipsg_drop.parent = self
                                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                    return self.ipsg_drop

                                                if (child_yang_name == "known-unicast"):
                                                    if (self.known_unicast is None):
                                                        self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                        self.known_unicast.parent = self
                                                        self._children_name_map["known_unicast"] = "known-unicast"
                                                    return self.known_unicast

                                                if (child_yang_name == "mac-move"):
                                                    if (self.mac_move is None):
                                                        self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                        self.mac_move.parent = self
                                                        self._children_name_map["mac_move"] = "mac-move"
                                                    return self.mac_move

                                                if (child_yang_name == "multicast-drop"):
                                                    if (self.multicast_drop is None):
                                                        self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                        self.multicast_drop.parent = self
                                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                                    return self.multicast_drop

                                                if (child_yang_name == "received-drops"):
                                                    if (self.received_drops is None):
                                                        self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                        self.received_drops.parent = self
                                                        self._children_name_map["received_drops"] = "received-drops"
                                                    return self.received_drops

                                                if (child_yang_name == "unicast-drop"):
                                                    if (self.unicast_drop is None):
                                                        self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                        self.unicast_drop.parent = self
                                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                                    return self.unicast_drop

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class SequenceNumber(Entity):
                                            """
                                            sequence numbers
                                            
                                            .. attribute:: bypassed_inbound_sequence_packet
                                            
                                            	Bypassed inbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bypassed_out_sequence_packet
                                            
                                            	Bypassed outbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: sequence_number_expected
                                            
                                            	sequence number expected
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sequence_number_sent
                                            
                                            	sequence number sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                                self.yang_name = "sequence-number"
                                                self.yang_parent_name = "statistics"

                                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bypassed_inbound_sequence_packet",
                                                                "bypassed_out_sequence_packet",
                                                                "sequence_number_expected",
                                                                "sequence_number_sent") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bypassed_inbound_sequence_packet.is_set or
                                                    self.bypassed_out_sequence_packet.is_set or
                                                    self.sequence_number_expected.is_set or
                                                    self.sequence_number_sent.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sequence-number" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bypassed-inbound-sequence-packet"):
                                                    self.bypassed_inbound_sequence_packet = value
                                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bypassed-out-sequence-packet"):
                                                    self.bypassed_out_sequence_packet = value
                                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sequence-number-expected"):
                                                    self.sequence_number_expected = value
                                                    self.sequence_number_expected.value_namespace = name_space
                                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sequence-number-sent"):
                                                    self.sequence_number_sent = value
                                                    self.sequence_number_sent.value_namespace = name_space
                                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                                (self.sequence_number is not None and self.sequence_number.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "statistics" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dispostion-stats"):
                                                if (self.dispostion_stats is None):
                                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                                    self.dispostion_stats.parent = self
                                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                                return self.dispostion_stats

                                            if (child_yang_name == "impostion-stats"):
                                                if (self.impostion_stats is None):
                                                    self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                                    self.impostion_stats.parent = self
                                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                                return self.impostion_stats

                                            if (child_yang_name == "sequence-number"):
                                                if (self.sequence_number is None):
                                                    self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                                    self.sequence_number.parent = self
                                                    self._children_name_map["sequence_number"] = "sequence-number"
                                                return self.sequence_number

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class P2MpPw(Entity):
                                        """
                                        P2MP Pseudowire Information
                                        
                                        .. attribute:: local_available
                                        
                                        	Local LSM info available
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_extended_tunnel_id
                                        
                                        	Local Extended Tunnel ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_flags
                                        
                                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_label
                                        
                                        	Local Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_p2mp_id
                                        
                                        	Local P2MP ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ptree_type
                                        
                                        	Local P\-Tree Type
                                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                        
                                        .. attribute:: local_tunnel_id
                                        
                                        	Local Tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_available
                                        
                                        	Remote LSM info available
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_extended_tunnel_id
                                        
                                        	Remote Extended Tunnel ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_flags
                                        
                                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_p2mp_id
                                        
                                        	Remote P2MP ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ptree_type
                                        
                                        	Remote P\-Tree Type
                                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                        
                                        .. attribute:: remote_tunnel_id
                                        
                                        	Remote Tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__init__()

                                            self.yang_name = "p2mp-pw"
                                            self.yang_parent_name = "pseudowire"

                                            self.local_available = YLeaf(YType.boolean, "local-available")

                                            self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                            self.local_flags = YLeaf(YType.uint8, "local-flags")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                            self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                            self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                            self.remote_available = YLeaf(YType.boolean, "remote-available")

                                            self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                            self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                                            self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                            self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                            self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("local_available",
                                                            "local_extended_tunnel_id",
                                                            "local_flags",
                                                            "local_label",
                                                            "local_p2mp_id",
                                                            "local_ptree_type",
                                                            "local_tunnel_id",
                                                            "remote_available",
                                                            "remote_extended_tunnel_id",
                                                            "remote_flags",
                                                            "remote_label",
                                                            "remote_p2mp_id",
                                                            "remote_ptree_type",
                                                            "remote_tunnel_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.local_available.is_set or
                                                self.local_extended_tunnel_id.is_set or
                                                self.local_flags.is_set or
                                                self.local_label.is_set or
                                                self.local_p2mp_id.is_set or
                                                self.local_ptree_type.is_set or
                                                self.local_tunnel_id.is_set or
                                                self.remote_available.is_set or
                                                self.remote_extended_tunnel_id.is_set or
                                                self.remote_flags.is_set or
                                                self.remote_label.is_set or
                                                self.remote_p2mp_id.is_set or
                                                self.remote_ptree_type.is_set or
                                                self.remote_tunnel_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.local_available.yfilter != YFilter.not_set or
                                                self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                                self.local_flags.yfilter != YFilter.not_set or
                                                self.local_label.yfilter != YFilter.not_set or
                                                self.local_p2mp_id.yfilter != YFilter.not_set or
                                                self.local_ptree_type.yfilter != YFilter.not_set or
                                                self.local_tunnel_id.yfilter != YFilter.not_set or
                                                self.remote_available.yfilter != YFilter.not_set or
                                                self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                                self.remote_flags.yfilter != YFilter.not_set or
                                                self.remote_label.yfilter != YFilter.not_set or
                                                self.remote_p2mp_id.yfilter != YFilter.not_set or
                                                self.remote_ptree_type.yfilter != YFilter.not_set or
                                                self.remote_tunnel_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "p2mp-pw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_available.get_name_leafdata())
                                            if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                            if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_flags.get_name_leafdata())
                                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_label.get_name_leafdata())
                                            if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                            if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                            if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                            if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_available.get_name_leafdata())
                                            if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                            if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                                            if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                            if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                            if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "local-available"):
                                                self.local_available = value
                                                self.local_available.value_namespace = name_space
                                                self.local_available.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-extended-tunnel-id"):
                                                self.local_extended_tunnel_id = value
                                                self.local_extended_tunnel_id.value_namespace = name_space
                                                self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-flags"):
                                                self.local_flags = value
                                                self.local_flags.value_namespace = name_space
                                                self.local_flags.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-label"):
                                                self.local_label = value
                                                self.local_label.value_namespace = name_space
                                                self.local_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-p2mp-id"):
                                                self.local_p2mp_id = value
                                                self.local_p2mp_id.value_namespace = name_space
                                                self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ptree-type"):
                                                self.local_ptree_type = value
                                                self.local_ptree_type.value_namespace = name_space
                                                self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-tunnel-id"):
                                                self.local_tunnel_id = value
                                                self.local_tunnel_id.value_namespace = name_space
                                                self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-available"):
                                                self.remote_available = value
                                                self.remote_available.value_namespace = name_space
                                                self.remote_available.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-extended-tunnel-id"):
                                                self.remote_extended_tunnel_id = value
                                                self.remote_extended_tunnel_id.value_namespace = name_space
                                                self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-flags"):
                                                self.remote_flags = value
                                                self.remote_flags.value_namespace = name_space
                                                self.remote_flags.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-label"):
                                                self.remote_label = value
                                                self.remote_label.value_namespace = name_space
                                                self.remote_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-p2mp-id"):
                                                self.remote_p2mp_id = value
                                                self.remote_p2mp_id.value_namespace = name_space
                                                self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ptree-type"):
                                                self.remote_ptree_type = value
                                                self.remote_ptree_type.value_namespace = name_space
                                                self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-tunnel-id"):
                                                self.remote_tunnel_id = value
                                                self.remote_tunnel_id.value_namespace = name_space
                                                self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.ad_method.is_set or
                                            self.ad_remote_down.is_set or
                                            self.admited_bw.is_set or
                                            self.auto_discovery.is_set or
                                            self.backup_active.is_set or
                                            self.backup_force_active.is_set or
                                            self.backup_pw.is_set or
                                            self.bitrate_mismatched.is_set or
                                            self.bridge_pw_type_mismatch.is_set or
                                            self.cas_mismatched.is_set or
                                            self.diff_ts_mismatched.is_set or
                                            self.disable_delay.is_set or
                                            self.disable_never.is_set or
                                            self.evpn_src_acid.is_set or
                                            self.fe_ctype.is_set or
                                            self.forward_class.is_set or
                                            self.freq_mismatched.is_set or
                                            self.illegal_control_word.is_set or
                                            self.imposed_vlan_id.is_set or
                                            self.interworking.is_set or
                                            self.ipv6_local_source_address.is_set or
                                            self.is_evpnvpws_type.is_set or
                                            self.is_flow_label_static.is_set or
                                            self.is_multi_segment_pseudowire.is_set or
                                            self.is_partially_programmed.is_set or
                                            self.is_pwr_type.is_set or
                                            self.is_vfi.is_set or
                                            self.last_time_status_changed.is_set or
                                            self.last_time_status_down.is_set or
                                            self.ldp_label_advertise_failed.is_set or
                                            self.load_balance.is_set or
                                            self.local_control_word.is_set or
                                            self.local_label_failed.is_set or
                                            self.local_pseudo_wire_type.is_set or
                                            self.local_source_address.is_set or
                                            self.mac_limit_oper_down.is_set or
                                            self.mtu_mismatched.is_set or
                                            self.not_supported_qinq.is_set or
                                            self.num_ma_cwithdraw_msg_received.is_set or
                                            self.number_ma_cwithdraw_message_sent.is_set or
                                            self.out_of_memory_state.is_set or
                                            self.payload_bytes_mismatched.is_set or
                                            self.payload_type_mismatched.is_set or
                                            self.preferred_path_disable_fallback.is_set or
                                            self.primary_peer_id.is_set or
                                            self.primary_pseudo_wire_id.is_set or
                                            self.primary_pw.is_set or
                                            self.protocol.is_set or
                                            self.pseudo_wire_id.is_set or
                                            self.pseudo_wire_state.is_set or
                                            self.pseudo_wire_type_mismatched.is_set or
                                            self.pw_class_name.is_set or
                                            self.pw_flow_label_code17_disabled.is_set or
                                            self.pw_flow_label_type.is_set or
                                            self.pw_flow_label_type_cfg.is_set or
                                            self.pw_redundancy_initial_delay.is_set or
                                            self.pw_redundancy_one_way.is_set or
                                            self.pw_status_use.is_set or
                                            self.pwlsd_rewrite_failed.is_set or
                                            self.remote_control_word.is_set or
                                            self.remote_label_failed.is_set or
                                            self.remote_pseudo_wire_type.is_set or
                                            self.required_bw.is_set or
                                            self.resync_enabled.is_set or
                                            self.resync_threshold.is_set or
                                            self.rtp_mismatched.is_set or
                                            self.sequencing_type.is_set or
                                            self.shutdown.is_set or
                                            self.sig_pkts_mismatched.is_set or
                                            self.ssrc_mismatched.is_set or
                                            self.state.is_set or
                                            self.table_policy_name.is_set or
                                            self.tag_rewrite.is_set or
                                            self.time_created.is_set or
                                            self.time_elapsed_creation.is_set or
                                            self.time_elapsed_status_changed.is_set or
                                            self.time_elapsed_status_down.is_set or
                                            self.transport_lsp_down.is_set or
                                            self.xconnect_id.is_set or
                                            (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                            (self.local_interface is not None and self.local_interface.has_data()) or
                                            (self.local_signalling is not None and self.local_signalling.has_data()) or
                                            (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                            (self.peer_id is not None and self.peer_id.has_data()) or
                                            (self.preferred_path is not None and self.preferred_path.has_data()) or
                                            (self.remote_interface is not None and self.remote_interface.has_data()) or
                                            (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                            (self.statistics is not None and self.statistics.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ad_method.yfilter != YFilter.not_set or
                                            self.ad_remote_down.yfilter != YFilter.not_set or
                                            self.admited_bw.yfilter != YFilter.not_set or
                                            self.auto_discovery.yfilter != YFilter.not_set or
                                            self.backup_active.yfilter != YFilter.not_set or
                                            self.backup_force_active.yfilter != YFilter.not_set or
                                            self.backup_pw.yfilter != YFilter.not_set or
                                            self.bitrate_mismatched.yfilter != YFilter.not_set or
                                            self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                            self.cas_mismatched.yfilter != YFilter.not_set or
                                            self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                            self.disable_delay.yfilter != YFilter.not_set or
                                            self.disable_never.yfilter != YFilter.not_set or
                                            self.evpn_src_acid.yfilter != YFilter.not_set or
                                            self.fe_ctype.yfilter != YFilter.not_set or
                                            self.forward_class.yfilter != YFilter.not_set or
                                            self.freq_mismatched.yfilter != YFilter.not_set or
                                            self.illegal_control_word.yfilter != YFilter.not_set or
                                            self.imposed_vlan_id.yfilter != YFilter.not_set or
                                            self.interworking.yfilter != YFilter.not_set or
                                            self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                            self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                            self.is_flow_label_static.yfilter != YFilter.not_set or
                                            self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                            self.is_partially_programmed.yfilter != YFilter.not_set or
                                            self.is_pwr_type.yfilter != YFilter.not_set or
                                            self.is_vfi.yfilter != YFilter.not_set or
                                            self.last_time_status_changed.yfilter != YFilter.not_set or
                                            self.last_time_status_down.yfilter != YFilter.not_set or
                                            self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                            self.load_balance.yfilter != YFilter.not_set or
                                            self.local_control_word.yfilter != YFilter.not_set or
                                            self.local_label_failed.yfilter != YFilter.not_set or
                                            self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                            self.local_source_address.yfilter != YFilter.not_set or
                                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                            self.mtu_mismatched.yfilter != YFilter.not_set or
                                            self.not_supported_qinq.yfilter != YFilter.not_set or
                                            self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                            self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                            self.out_of_memory_state.yfilter != YFilter.not_set or
                                            self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                            self.payload_type_mismatched.yfilter != YFilter.not_set or
                                            self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                            self.primary_peer_id.yfilter != YFilter.not_set or
                                            self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                            self.primary_pw.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            self.pseudo_wire_id.yfilter != YFilter.not_set or
                                            self.pseudo_wire_state.yfilter != YFilter.not_set or
                                            self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                            self.pw_class_name.yfilter != YFilter.not_set or
                                            self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                            self.pw_flow_label_type.yfilter != YFilter.not_set or
                                            self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                            self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                            self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                            self.pw_status_use.yfilter != YFilter.not_set or
                                            self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.remote_control_word.yfilter != YFilter.not_set or
                                            self.remote_label_failed.yfilter != YFilter.not_set or
                                            self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                            self.required_bw.yfilter != YFilter.not_set or
                                            self.resync_enabled.yfilter != YFilter.not_set or
                                            self.resync_threshold.yfilter != YFilter.not_set or
                                            self.rtp_mismatched.yfilter != YFilter.not_set or
                                            self.sequencing_type.yfilter != YFilter.not_set or
                                            self.shutdown.yfilter != YFilter.not_set or
                                            self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                            self.ssrc_mismatched.yfilter != YFilter.not_set or
                                            self.state.yfilter != YFilter.not_set or
                                            self.table_policy_name.yfilter != YFilter.not_set or
                                            self.tag_rewrite.yfilter != YFilter.not_set or
                                            self.time_created.yfilter != YFilter.not_set or
                                            self.time_elapsed_creation.yfilter != YFilter.not_set or
                                            self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                            self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                            self.transport_lsp_down.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                            (self.local_interface is not None and self.local_interface.has_operation()) or
                                            (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                            (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                            (self.peer_id is not None and self.peer_id.has_operation()) or
                                            (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                            (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                            (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                            (self.statistics is not None and self.statistics.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ad_method.get_name_leafdata())
                                        if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                        if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                        if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                        if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_active.get_name_leafdata())
                                        if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                        if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                        if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                        if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                        if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                        if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                        if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                        if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.disable_never.get_name_leafdata())
                                        if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                        if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                        if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.forward_class.get_name_leafdata())
                                        if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                        if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                        if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interworking.get_name_leafdata())
                                        if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                        if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                        if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                        if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                        if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                        if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                        if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                        if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                        if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                        if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                        if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.load_balance.get_name_leafdata())
                                        if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                        if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                        if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                        if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                        if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                        if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                        if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                        if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                        if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                        if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                        if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                        if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                        if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())
                                        if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                        if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                        if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                        if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                        if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                        if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                        if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                        if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                        if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                        if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                        if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                        if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                        if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                        if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                        if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.required_bw.get_name_leafdata())
                                        if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                        if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                        if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                        if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                                        if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                        if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state.get_name_leafdata())
                                        if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                        if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                        if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_created.get_name_leafdata())
                                        if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                        if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                        if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                        if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "encapsulation-info"):
                                            if (self.encapsulation_info is None):
                                                self.encapsulation_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                                self.encapsulation_info.parent = self
                                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                            return self.encapsulation_info

                                        if (child_yang_name == "local-interface"):
                                            if (self.local_interface is None):
                                                self.local_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                                self.local_interface.parent = self
                                                self._children_name_map["local_interface"] = "local-interface"
                                            return self.local_interface

                                        if (child_yang_name == "local-signalling"):
                                            if (self.local_signalling is None):
                                                self.local_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                                self.local_signalling.parent = self
                                                self._children_name_map["local_signalling"] = "local-signalling"
                                            return self.local_signalling

                                        if (child_yang_name == "p2mp-pw"):
                                            if (self.p2mp_pw is None):
                                                self.p2mp_pw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                                self.p2mp_pw.parent = self
                                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                            return self.p2mp_pw

                                        if (child_yang_name == "peer-id"):
                                            if (self.peer_id is None):
                                                self.peer_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                                self.peer_id.parent = self
                                                self._children_name_map["peer_id"] = "peer-id"
                                            return self.peer_id

                                        if (child_yang_name == "preferred-path"):
                                            if (self.preferred_path is None):
                                                self.preferred_path = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                                self.preferred_path.parent = self
                                                self._children_name_map["preferred_path"] = "preferred-path"
                                            return self.preferred_path

                                        if (child_yang_name == "remote-interface"):
                                            if (self.remote_interface is None):
                                                self.remote_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                                self.remote_interface.parent = self
                                                self._children_name_map["remote_interface"] = "remote-interface"
                                            return self.remote_interface

                                        if (child_yang_name == "remote-signalling"):
                                            if (self.remote_signalling is None):
                                                self.remote_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                                self.remote_signalling.parent = self
                                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                            return self.remote_signalling

                                        if (child_yang_name == "statistics"):
                                            if (self.statistics is None):
                                                self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                                self.statistics.parent = self
                                                self._children_name_map["statistics"] = "statistics"
                                            return self.statistics

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ad-method"):
                                            self.ad_method = value
                                            self.ad_method.value_namespace = name_space
                                            self.ad_method.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ad-remote-down"):
                                            self.ad_remote_down = value
                                            self.ad_remote_down.value_namespace = name_space
                                            self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "admited-bw"):
                                            self.admited_bw = value
                                            self.admited_bw.value_namespace = name_space
                                            self.admited_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "auto-discovery"):
                                            self.auto_discovery = value
                                            self.auto_discovery.value_namespace = name_space
                                            self.auto_discovery.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-active"):
                                            self.backup_active = value
                                            self.backup_active.value_namespace = name_space
                                            self.backup_active.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-force-active"):
                                            self.backup_force_active = value
                                            self.backup_force_active.value_namespace = name_space
                                            self.backup_force_active.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-pw"):
                                            self.backup_pw = value
                                            self.backup_pw.value_namespace = name_space
                                            self.backup_pw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bitrate-mismatched"):
                                            self.bitrate_mismatched = value
                                            self.bitrate_mismatched.value_namespace = name_space
                                            self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bridge-pw-type-mismatch"):
                                            self.bridge_pw_type_mismatch = value
                                            self.bridge_pw_type_mismatch.value_namespace = name_space
                                            self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas-mismatched"):
                                            self.cas_mismatched = value
                                            self.cas_mismatched.value_namespace = name_space
                                            self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "diff-ts-mismatched"):
                                            self.diff_ts_mismatched = value
                                            self.diff_ts_mismatched.value_namespace = name_space
                                            self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable-delay"):
                                            self.disable_delay = value
                                            self.disable_delay.value_namespace = name_space
                                            self.disable_delay.value_namespace_prefix = name_space_prefix
                                        if(value_path == "disable-never"):
                                            self.disable_never = value
                                            self.disable_never.value_namespace = name_space
                                            self.disable_never.value_namespace_prefix = name_space_prefix
                                        if(value_path == "evpn-src-acid"):
                                            self.evpn_src_acid = value
                                            self.evpn_src_acid.value_namespace = name_space
                                            self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fe-ctype"):
                                            self.fe_ctype = value
                                            self.fe_ctype.value_namespace = name_space
                                            self.fe_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "forward-class"):
                                            self.forward_class = value
                                            self.forward_class.value_namespace = name_space
                                            self.forward_class.value_namespace_prefix = name_space_prefix
                                        if(value_path == "freq-mismatched"):
                                            self.freq_mismatched = value
                                            self.freq_mismatched.value_namespace = name_space
                                            self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "illegal-control-word"):
                                            self.illegal_control_word = value
                                            self.illegal_control_word.value_namespace = name_space
                                            self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                        if(value_path == "imposed-vlan-id"):
                                            self.imposed_vlan_id = value
                                            self.imposed_vlan_id.value_namespace = name_space
                                            self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interworking"):
                                            self.interworking = value
                                            self.interworking.value_namespace = name_space
                                            self.interworking.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-local-source-address"):
                                            self.ipv6_local_source_address = value
                                            self.ipv6_local_source_address.value_namespace = name_space
                                            self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-evpnvpws-type"):
                                            self.is_evpnvpws_type = value
                                            self.is_evpnvpws_type.value_namespace = name_space
                                            self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-flow-label-static"):
                                            self.is_flow_label_static = value
                                            self.is_flow_label_static.value_namespace = name_space
                                            self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-multi-segment-pseudowire"):
                                            self.is_multi_segment_pseudowire = value
                                            self.is_multi_segment_pseudowire.value_namespace = name_space
                                            self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-partially-programmed"):
                                            self.is_partially_programmed = value
                                            self.is_partially_programmed.value_namespace = name_space
                                            self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-pwr-type"):
                                            self.is_pwr_type = value
                                            self.is_pwr_type.value_namespace = name_space
                                            self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-vfi"):
                                            self.is_vfi = value
                                            self.is_vfi.value_namespace = name_space
                                            self.is_vfi.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-time-status-changed"):
                                            self.last_time_status_changed = value
                                            self.last_time_status_changed.value_namespace = name_space
                                            self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-time-status-down"):
                                            self.last_time_status_down = value
                                            self.last_time_status_down.value_namespace = name_space
                                            self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertise-failed"):
                                            self.ldp_label_advertise_failed = value
                                            self.ldp_label_advertise_failed.value_namespace = name_space
                                            self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "load-balance"):
                                            self.load_balance = value
                                            self.load_balance.value_namespace = name_space
                                            self.load_balance.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-control-word"):
                                            self.local_control_word = value
                                            self.local_control_word.value_namespace = name_space
                                            self.local_control_word.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label-failed"):
                                            self.local_label_failed = value
                                            self.local_label_failed.value_namespace = name_space
                                            self.local_label_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-pseudo-wire-type"):
                                            self.local_pseudo_wire_type = value
                                            self.local_pseudo_wire_type.value_namespace = name_space
                                            self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-source-address"):
                                            self.local_source_address = value
                                            self.local_source_address.value_namespace = name_space
                                            self.local_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-oper-down"):
                                            self.mac_limit_oper_down = value
                                            self.mac_limit_oper_down.value_namespace = name_space
                                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mtu-mismatched"):
                                            self.mtu_mismatched = value
                                            self.mtu_mismatched.value_namespace = name_space
                                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "not-supported-qinq"):
                                            self.not_supported_qinq = value
                                            self.not_supported_qinq.value_namespace = name_space
                                            self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "num-ma-cwithdraw-msg-received"):
                                            self.num_ma_cwithdraw_msg_received = value
                                            self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                            self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                        if(value_path == "number-ma-cwithdraw-message-sent"):
                                            self.number_ma_cwithdraw_message_sent = value
                                            self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                            self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                        if(value_path == "out-of-memory-state"):
                                            self.out_of_memory_state = value
                                            self.out_of_memory_state.value_namespace = name_space
                                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes-mismatched"):
                                            self.payload_bytes_mismatched = value
                                            self.payload_bytes_mismatched.value_namespace = name_space
                                            self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-type-mismatched"):
                                            self.payload_type_mismatched = value
                                            self.payload_type_mismatched.value_namespace = name_space
                                            self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "preferred-path-disable-fallback"):
                                            self.preferred_path_disable_fallback = value
                                            self.preferred_path_disable_fallback.value_namespace = name_space
                                            self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                        if(value_path == "primary-peer-id"):
                                            self.primary_peer_id = value
                                            self.primary_peer_id.value_namespace = name_space
                                            self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "primary-pseudo-wire-id"):
                                            self.primary_pseudo_wire_id = value
                                            self.primary_pseudo_wire_id.value_namespace = name_space
                                            self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "primary-pw"):
                                            self.primary_pw = value
                                            self.primary_pw.value_namespace = name_space
                                            self.primary_pw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pseudo-wire-id"):
                                            self.pseudo_wire_id = value
                                            self.pseudo_wire_id.value_namespace = name_space
                                            self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pseudo-wire-state"):
                                            self.pseudo_wire_state = value
                                            self.pseudo_wire_state.value_namespace = name_space
                                            self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pseudo-wire-type-mismatched"):
                                            self.pseudo_wire_type_mismatched = value
                                            self.pseudo_wire_type_mismatched.value_namespace = name_space
                                            self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-class-name"):
                                            self.pw_class_name = value
                                            self.pw_class_name.value_namespace = name_space
                                            self.pw_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flow-label-code17-disabled"):
                                            self.pw_flow_label_code17_disabled = value
                                            self.pw_flow_label_code17_disabled.value_namespace = name_space
                                            self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flow-label-type"):
                                            self.pw_flow_label_type = value
                                            self.pw_flow_label_type.value_namespace = name_space
                                            self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-flow-label-type-cfg"):
                                            self.pw_flow_label_type_cfg = value
                                            self.pw_flow_label_type_cfg.value_namespace = name_space
                                            self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-redundancy-initial-delay"):
                                            self.pw_redundancy_initial_delay = value
                                            self.pw_redundancy_initial_delay.value_namespace = name_space
                                            self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-redundancy-one-way"):
                                            self.pw_redundancy_one_way = value
                                            self.pw_redundancy_one_way.value_namespace = name_space
                                            self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-status-use"):
                                            self.pw_status_use = value
                                            self.pw_status_use.value_namespace = name_space
                                            self.pw_status_use.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pwlsd-rewrite-failed"):
                                            self.pwlsd_rewrite_failed = value
                                            self.pwlsd_rewrite_failed.value_namespace = name_space
                                            self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-control-word"):
                                            self.remote_control_word = value
                                            self.remote_control_word.value_namespace = name_space
                                            self.remote_control_word.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label-failed"):
                                            self.remote_label_failed = value
                                            self.remote_label_failed.value_namespace = name_space
                                            self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-pseudo-wire-type"):
                                            self.remote_pseudo_wire_type = value
                                            self.remote_pseudo_wire_type.value_namespace = name_space
                                            self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "required-bw"):
                                            self.required_bw = value
                                            self.required_bw.value_namespace = name_space
                                            self.required_bw.value_namespace_prefix = name_space_prefix
                                        if(value_path == "resync-enabled"):
                                            self.resync_enabled = value
                                            self.resync_enabled.value_namespace = name_space
                                            self.resync_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "resync-threshold"):
                                            self.resync_threshold = value
                                            self.resync_threshold.value_namespace = name_space
                                            self.resync_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-mismatched"):
                                            self.rtp_mismatched = value
                                            self.rtp_mismatched.value_namespace = name_space
                                            self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequencing-type"):
                                            self.sequencing_type = value
                                            self.sequencing_type.value_namespace = name_space
                                            self.sequencing_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "shutdown"):
                                            self.shutdown = value
                                            self.shutdown.value_namespace = name_space
                                            self.shutdown.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sig-pkts-mismatched"):
                                            self.sig_pkts_mismatched = value
                                            self.sig_pkts_mismatched.value_namespace = name_space
                                            self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc-mismatched"):
                                            self.ssrc_mismatched = value
                                            self.ssrc_mismatched.value_namespace = name_space
                                            self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state"):
                                            self.state = value
                                            self.state.value_namespace = name_space
                                            self.state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "table-policy-name"):
                                            self.table_policy_name = value
                                            self.table_policy_name.value_namespace = name_space
                                            self.table_policy_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tag-rewrite"):
                                            self.tag_rewrite = value
                                            self.tag_rewrite.value_namespace = name_space
                                            self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-created"):
                                            self.time_created = value
                                            self.time_created.value_namespace = name_space
                                            self.time_created.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-elapsed-creation"):
                                            self.time_elapsed_creation = value
                                            self.time_elapsed_creation.value_namespace = name_space
                                            self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-elapsed-status-changed"):
                                            self.time_elapsed_status_changed = value
                                            self.time_elapsed_status_changed.value_namespace = name_space
                                            self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-elapsed-status-down"):
                                            self.time_elapsed_status_down = value
                                            self.time_elapsed_status_down.value_namespace = name_space
                                            self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transport-lsp-down"):
                                            self.transport_lsp_down = value
                                            self.transport_lsp_down.value_namespace = name_space
                                            self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "bridge-pw"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                        self._children_yang_names.add("base")

                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dhcpv4_trust",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"

                                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                            self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                            self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                            self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                            self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                            self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                            self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                            self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                            self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                            self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                            self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                            self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                            self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                            self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                            self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                            self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                            self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                            self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                            self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                            self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                            self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                            self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                            self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                            self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                            self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                            self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                            self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                            self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                            self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                            self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                            self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                            self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._children_yang_names.add("storm-control")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("broadcast_storm_control_kb_ps",
                                                            "broadcast_storm_control_pps",
                                                            "broadcast_storm_control_rate_unit",
                                                            "dai_address_validation_mask",
                                                            "dhcpv4_profile_name",
                                                            "dhcpv4_snoop",
                                                            "flood_unknown_unicast_enabled",
                                                            "flood_uu_disabled_mac_limit_action",
                                                            "igm_pv4_disabled",
                                                            "igm_pv4_profile_name",
                                                            "is_dai_addr_validate_destination_mac_enabled",
                                                            "is_dai_addr_validate_ipv4_enabled",
                                                            "is_dai_addr_validate_source_mac_enabled",
                                                            "is_dai_enabled",
                                                            "is_dai_logging_enabled",
                                                            "is_ip_source_guard_enabled",
                                                            "is_ipsg_logging_enabled",
                                                            "is_mac_secure_accept_shutdown_enabled",
                                                            "is_mac_secure_enabled",
                                                            "is_mac_secure_logging_enabled",
                                                            "learn_disabled_mac_limit_action",
                                                            "mac_aging_mode",
                                                            "mac_aging_time",
                                                            "mac_flooding",
                                                            "mac_learning",
                                                            "mac_limit",
                                                            "mac_limit_action",
                                                            "mac_limit_notification",
                                                            "mac_limit_reached",
                                                            "mac_port_down_flush_enabled",
                                                            "mac_secure_action",
                                                            "mld_profile_name",
                                                            "mmrp_flood_optimization",
                                                            "multicast_storm_control_kb_ps",
                                                            "multicast_storm_control_pps",
                                                            "multicast_storm_control_rate_unit",
                                                            "split_horizon_group_id",
                                                            "unicast_storm_control_kb_ps",
                                                            "unicast_storm_control_pps",
                                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"

                                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                self.multicast = YLeaf(YType.boolean, "multicast")

                                                self.unicast = YLeaf(YType.boolean, "unicast")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bd_policer",
                                                                "broadcast",
                                                                "multicast",
                                                                "unicast") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bd_policer.is_set or
                                                    self.broadcast.is_set or
                                                    self.multicast.is_set or
                                                    self.unicast.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bd_policer.yfilter != YFilter.not_set or
                                                    self.broadcast.yfilter != YFilter.not_set or
                                                    self.multicast.yfilter != YFilter.not_set or
                                                    self.unicast.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "storm-control" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bd-policer"):
                                                    self.bd_policer = value
                                                    self.bd_policer.value_namespace = name_space
                                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast"):
                                                    self.broadcast = value
                                                    self.broadcast.value_namespace = name_space
                                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast"):
                                                    self.multicast = value
                                                    self.multicast.value_namespace = name_space
                                                    self.multicast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast"):
                                                    self.unicast = value
                                                    self.unicast.value_namespace = name_space
                                                    self.unicast.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.broadcast_storm_control_kb_ps.is_set or
                                                self.broadcast_storm_control_pps.is_set or
                                                self.broadcast_storm_control_rate_unit.is_set or
                                                self.dai_address_validation_mask.is_set or
                                                self.dhcpv4_profile_name.is_set or
                                                self.dhcpv4_snoop.is_set or
                                                self.flood_unknown_unicast_enabled.is_set or
                                                self.flood_uu_disabled_mac_limit_action.is_set or
                                                self.igm_pv4_disabled.is_set or
                                                self.igm_pv4_profile_name.is_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                                self.is_dai_addr_validate_ipv4_enabled.is_set or
                                                self.is_dai_addr_validate_source_mac_enabled.is_set or
                                                self.is_dai_enabled.is_set or
                                                self.is_dai_logging_enabled.is_set or
                                                self.is_ip_source_guard_enabled.is_set or
                                                self.is_ipsg_logging_enabled.is_set or
                                                self.is_mac_secure_accept_shutdown_enabled.is_set or
                                                self.is_mac_secure_enabled.is_set or
                                                self.is_mac_secure_logging_enabled.is_set or
                                                self.learn_disabled_mac_limit_action.is_set or
                                                self.mac_aging_mode.is_set or
                                                self.mac_aging_time.is_set or
                                                self.mac_flooding.is_set or
                                                self.mac_learning.is_set or
                                                self.mac_limit.is_set or
                                                self.mac_limit_action.is_set or
                                                self.mac_limit_notification.is_set or
                                                self.mac_limit_reached.is_set or
                                                self.mac_port_down_flush_enabled.is_set or
                                                self.mac_secure_action.is_set or
                                                self.mld_profile_name.is_set or
                                                self.mmrp_flood_optimization.is_set or
                                                self.multicast_storm_control_kb_ps.is_set or
                                                self.multicast_storm_control_pps.is_set or
                                                self.multicast_storm_control_rate_unit.is_set or
                                                self.split_horizon_group_id.is_set or
                                                self.unicast_storm_control_kb_ps.is_set or
                                                self.unicast_storm_control_pps.is_set or
                                                self.unicast_storm_control_rate_unit.is_set or
                                                (self.storm_control is not None and self.storm_control.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                                self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                                self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                                self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                                self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                                self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                                self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                                self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_aging_mode.yfilter != YFilter.not_set or
                                                self.mac_aging_time.yfilter != YFilter.not_set or
                                                self.mac_flooding.yfilter != YFilter.not_set or
                                                self.mac_learning.yfilter != YFilter.not_set or
                                                self.mac_limit.yfilter != YFilter.not_set or
                                                self.mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_limit_notification.yfilter != YFilter.not_set or
                                                self.mac_limit_reached.yfilter != YFilter.not_set or
                                                self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                                self.mac_secure_action.yfilter != YFilter.not_set or
                                                self.mld_profile_name.yfilter != YFilter.not_set or
                                                self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.split_horizon_group_id.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                (self.storm_control is not None and self.storm_control.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "base" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                            if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                            if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                            if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                            if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                            if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                            if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                            if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                            if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                            if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                            if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                            if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                            if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                            if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                            if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                            if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                            if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                            if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                            if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                            if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                            if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                            if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "storm-control"):
                                                if (self.storm_control is None):
                                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                                    self.storm_control.parent = self
                                                    self._children_name_map["storm_control"] = "storm-control"
                                                return self.storm_control

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "broadcast-storm-control-kb-ps"):
                                                self.broadcast_storm_control_kb_ps = value
                                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-pps"):
                                                self.broadcast_storm_control_pps = value
                                                self.broadcast_storm_control_pps.value_namespace = name_space
                                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-rate-unit"):
                                                self.broadcast_storm_control_rate_unit = value
                                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dai-address-validation-mask"):
                                                self.dai_address_validation_mask = value
                                                self.dai_address_validation_mask.value_namespace = name_space
                                                self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-profile-name"):
                                                self.dhcpv4_profile_name = value
                                                self.dhcpv4_profile_name.value_namespace = name_space
                                                self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-snoop"):
                                                self.dhcpv4_snoop = value
                                                self.dhcpv4_snoop.value_namespace = name_space
                                                self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-unknown-unicast-enabled"):
                                                self.flood_unknown_unicast_enabled = value
                                                self.flood_unknown_unicast_enabled.value_namespace = name_space
                                                self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-uu-disabled-mac-limit-action"):
                                                self.flood_uu_disabled_mac_limit_action = value
                                                self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                                self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-disabled"):
                                                self.igm_pv4_disabled = value
                                                self.igm_pv4_disabled.value_namespace = name_space
                                                self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-profile-name"):
                                                self.igm_pv4_profile_name = value
                                                self.igm_pv4_profile_name.value_namespace = name_space
                                                self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                                self.is_dai_addr_validate_destination_mac_enabled = value
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                                self.is_dai_addr_validate_ipv4_enabled = value
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                                self.is_dai_addr_validate_source_mac_enabled = value
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-enabled"):
                                                self.is_dai_enabled = value
                                                self.is_dai_enabled.value_namespace = name_space
                                                self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-logging-enabled"):
                                                self.is_dai_logging_enabled = value
                                                self.is_dai_logging_enabled.value_namespace = name_space
                                                self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ip-source-guard-enabled"):
                                                self.is_ip_source_guard_enabled = value
                                                self.is_ip_source_guard_enabled.value_namespace = name_space
                                                self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ipsg-logging-enabled"):
                                                self.is_ipsg_logging_enabled = value
                                                self.is_ipsg_logging_enabled.value_namespace = name_space
                                                self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                                self.is_mac_secure_accept_shutdown_enabled = value
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-enabled"):
                                                self.is_mac_secure_enabled = value
                                                self.is_mac_secure_enabled.value_namespace = name_space
                                                self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-logging-enabled"):
                                                self.is_mac_secure_logging_enabled = value
                                                self.is_mac_secure_logging_enabled.value_namespace = name_space
                                                self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "learn-disabled-mac-limit-action"):
                                                self.learn_disabled_mac_limit_action = value
                                                self.learn_disabled_mac_limit_action.value_namespace = name_space
                                                self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-mode"):
                                                self.mac_aging_mode = value
                                                self.mac_aging_mode.value_namespace = name_space
                                                self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-time"):
                                                self.mac_aging_time = value
                                                self.mac_aging_time.value_namespace = name_space
                                                self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-flooding"):
                                                self.mac_flooding = value
                                                self.mac_flooding.value_namespace = name_space
                                                self.mac_flooding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-learning"):
                                                self.mac_learning = value
                                                self.mac_learning.value_namespace = name_space
                                                self.mac_learning.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit"):
                                                self.mac_limit = value
                                                self.mac_limit.value_namespace = name_space
                                                self.mac_limit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-action"):
                                                self.mac_limit_action = value
                                                self.mac_limit_action.value_namespace = name_space
                                                self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-notification"):
                                                self.mac_limit_notification = value
                                                self.mac_limit_notification.value_namespace = name_space
                                                self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-reached"):
                                                self.mac_limit_reached = value
                                                self.mac_limit_reached.value_namespace = name_space
                                                self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-port-down-flush-enabled"):
                                                self.mac_port_down_flush_enabled = value
                                                self.mac_port_down_flush_enabled.value_namespace = name_space
                                                self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-secure-action"):
                                                self.mac_secure_action = value
                                                self.mac_secure_action.value_namespace = name_space
                                                self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mld-profile-name"):
                                                self.mld_profile_name = value
                                                self.mld_profile_name.value_namespace = name_space
                                                self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mmrp-flood-optimization"):
                                                self.mmrp_flood_optimization = value
                                                self.mmrp_flood_optimization.value_namespace = name_space
                                                self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-kb-ps"):
                                                self.multicast_storm_control_kb_ps = value
                                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-pps"):
                                                self.multicast_storm_control_pps = value
                                                self.multicast_storm_control_pps.value_namespace = name_space
                                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-rate-unit"):
                                                self.multicast_storm_control_rate_unit = value
                                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "split-horizon-group-id"):
                                                self.split_horizon_group_id = value
                                                self.split_horizon_group_id.value_namespace = name_space
                                                self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-kb-ps"):
                                                self.unicast_storm_control_kb_ps = value
                                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-pps"):
                                                self.unicast_storm_control_pps = value
                                                self.unicast_storm_control_pps.value_namespace = name_space
                                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-rate-unit"):
                                                self.unicast_storm_control_rate_unit = value
                                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dhcpv4_trust.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.base is not None and self.base.has_data()) or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dhcpv4_trust.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.base is not None and self.base.has_operation()) or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security-parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "base"):
                                            if (self.base is None):
                                                self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                                self.base.parent = self
                                                self._children_name_map["base"] = "base"
                                            return self.base

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-trust"):
                                            self.dhcpv4_trust = value
                                            self.dhcpv4_trust.value_namespace = name_space
                                            self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StaticMac(Entity):
                                    """
                                    Static MAC addresses
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                        self.yang_name = "static-mac"
                                        self.yang_parent_name = "bridge-pw"

                                        self.address = YLeaf(YType.str, "address")

                                        self.bmac = YLeaf(YType.str, "bmac")

                                        self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("address",
                                                        "bmac",
                                                        "next_hop_ip") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.address.is_set or
                                            self.bmac.is_set or
                                            self.next_hop_ip.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.address.yfilter != YFilter.not_set or
                                            self.bmac.yfilter != YFilter.not_set or
                                            self.next_hop_ip.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "static-mac" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.address.get_name_leafdata())
                                        if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bmac.get_name_leafdata())
                                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "address"):
                                            self.address = value
                                            self.address.value_namespace = name_space
                                            self.address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bmac"):
                                            self.bmac = value
                                            self.bmac.value_namespace = name_space
                                            self.bmac.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop-ip"):
                                            self.next_hop_ip = value
                                            self.next_hop_ip.value_namespace = name_space
                                            self.next_hop_ip.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.static_mac:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.is_access.is_set or
                                        self.neighbor.is_set or
                                        self.pseudowire_id.is_set or
                                        self.pw_type.is_set or
                                        self.ve_id_vpls_id_0_3.is_set or
                                        self.vpls_id_4_7.is_set or
                                        (self.pseudowire is not None and self.pseudowire.has_data()) or
                                        (self.security_parameters is not None and self.security_parameters.has_data()))

                                def has_operation(self):
                                    for c in self.static_mac:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_access.yfilter != YFilter.not_set or
                                        self.neighbor.yfilter != YFilter.not_set or
                                        self.pseudowire_id.yfilter != YFilter.not_set or
                                        self.pw_type.yfilter != YFilter.not_set or
                                        self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set or
                                        self.vpls_id_4_7.yfilter != YFilter.not_set or
                                        (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                        (self.security_parameters is not None and self.security_parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bridge-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_access.get_name_leafdata())
                                    if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.neighbor.get_name_leafdata())
                                    if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudowire_id.get_name_leafdata())
                                    if (self.pw_type.is_set or self.pw_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_type.get_name_leafdata())
                                    if (self.ve_id_vpls_id_0_3.is_set or self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ve_id_vpls_id_0_3.get_name_leafdata())
                                    if (self.vpls_id_4_7.is_set or self.vpls_id_4_7.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_4_7.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "pseudowire"):
                                        if (self.pseudowire is None):
                                            self.pseudowire = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                            self.pseudowire.parent = self
                                            self._children_name_map["pseudowire"] = "pseudowire"
                                        return self.pseudowire

                                    if (child_yang_name == "security-parameters"):
                                        if (self.security_parameters is None):
                                            self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                            self.security_parameters.parent = self
                                            self._children_name_map["security_parameters"] = "security-parameters"
                                        return self.security_parameters

                                    if (child_yang_name == "static-mac"):
                                        for c in self.static_mac:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.static_mac.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id" or name == "pw-type" or name == "ve-id-vpls-id-0-3" or name == "vpls-id-4-7"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-access"):
                                        self.is_access = value
                                        self.is_access.value_namespace = name_space
                                        self.is_access.value_namespace_prefix = name_space_prefix
                                    if(value_path == "neighbor"):
                                        self.neighbor = value
                                        self.neighbor.value_namespace = name_space
                                        self.neighbor.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudowire-id"):
                                        self.pseudowire_id = value
                                        self.pseudowire_id.value_namespace = name_space
                                        self.pseudowire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-type"):
                                        self.pw_type = value
                                        self.pw_type.value_namespace = name_space
                                        self.pw_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ve-id-vpls-id-0-3"):
                                        self.ve_id_vpls_id_0_3 = value
                                        self.ve_id_vpls_id_0_3.value_namespace = name_space
                                        self.ve_id_vpls_id_0_3.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpls-id-4-7"):
                                        self.vpls_id_4_7 = value
                                        self.vpls_id_4_7.value_namespace = name_space
                                        self.vpls_id_4_7.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.bridge_pw:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.bridge_pw:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bridge-pws" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bridge-pw"):
                                    for c in self.bridge_pw:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.bridge_pw.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bridge-pw"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.bridge_pws is not None and self.bridge_pws.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.bridge_pws is not None and self.bridge_pws.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-core-vfi-table" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bridge-pws"):
                                if (self.bridge_pws is None):
                                    self.bridge_pws = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                                    self.bridge_pws.parent = self
                                    self._children_name_map["bridge_pws"] = "bridge-pws"
                                return self.bridge_pws

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-pws"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BridgeAcs(Entity):
                        """
                        VPLS Bridge Domain Attachment Circuit Table
                        
                        .. attribute:: bridge_ac
                        
                        	VPLS Bridge Domain Attachment Circuit
                        	**type**\: list of    :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs, self).__init__()

                            self.yang_name = "bridge-acs"
                            self.yang_parent_name = "bridge-domain"

                            self.bridge_ac = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs, self).__setattr__(name, value)


                        class BridgeAc(Entity):
                            """
                            VPLS Bridge Domain Attachment Circuit
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: attachment_circuit
                            
                            	Attachment Circuit
                            	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                            
                            .. attribute:: bvi_mac_index
                            
                            	MyMac Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bvimac
                            
                            	BVI MAC addresses
                            	**type**\: list of    :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__init__()

                                self.yang_name = "bridge-ac"
                                self.yang_parent_name = "bridge-acs"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.bvi_mac_index = YLeaf(YType.uint16, "bvi-mac-index")

                                self.attachment_circuit = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                self._children_yang_names.add("attachment-circuit")

                                self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                                self.bvimac = YList(self)
                                self.static_mac = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "bvi_mac_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__setattr__(name, value)


                            class AttachmentCircuit(Entity):
                                """
                                Attachment Circuit
                                
                                .. attribute:: bvi_mac_conflict
                                
                                	BVI Mac Conflict
                                	**type**\:  bool
                                
                                .. attribute:: bvi_no_port_up
                                
                                	BVI no BP Up
                                	**type**\:  bool
                                
                                .. attribute:: control_word_mismatched
                                
                                	Control word mismatched
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_error
                                
                                	Encapsulation Error
                                	**type**\:  str
                                
                                .. attribute:: encapsulation_mismatched
                                
                                	Encapsulation mismatched
                                	**type**\:  bool
                                
                                .. attribute:: evpn_internal_label
                                
                                	EVPN Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface
                                
                                	Interface
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                                
                                .. attribute:: interface_handle
                                
                                	Interface Handler
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: internal_ms_ti
                                
                                	Internal MSTi
                                	**type**\:  str
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                                
                                .. attribute:: is_ac_partially_programmed
                                
                                	Is attachment\-circuit partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: l2vpn_protection
                                
                                	Protection object used for this segment
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection>`
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: ms_ti_mismatch
                                
                                	MSTi mismatch
                                	**type**\:  bool
                                
                                .. attribute:: msti
                                
                                	MSTi
                                	**type**\:  str
                                
                                .. attribute:: msti_mismatch_down
                                
                                	Oper down due to MSTI mismatch
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: node_id
                                
                                	Node ID
                                	**type**\:  str
                                
                                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_group_id
                                
                                	Redundancy Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_group_state
                                
                                	Redundancy Group State
                                	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                                
                                .. attribute:: redundancy_object_id
                                
                                	Redundancy Object ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                                
                                .. attribute:: tdm_media_mismatched
                                
                                	TDM media parms mismatched
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__init__()

                                    self.yang_name = "attachment-circuit"
                                    self.yang_parent_name = "bridge-ac"

                                    self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                                    self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                                    self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                                    self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                                    self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                                    self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                    self.interface_handle = YLeaf(YType.str, "interface-handle")

                                    self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                                    self.interworking = YLeaf(YType.enumeration, "interworking")

                                    self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                                    self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                    self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                                    self.msti = YLeaf(YType.str, "msti")

                                    self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                                    self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                    self.node_id = YLeaf(YType.str, "node-id")

                                    self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                    self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                    self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                                    self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                    self._children_yang_names.add("interface")

                                    self.l2vpn_protection = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    self._children_yang_names.add("l2vpn-protection")

                                    self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._children_yang_names.add("statistics")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bvi_mac_conflict",
                                                    "bvi_no_port_up",
                                                    "control_word_mismatched",
                                                    "encapsulation_error",
                                                    "encapsulation_mismatched",
                                                    "evpn_internal_label",
                                                    "interface_handle",
                                                    "internal_ms_ti",
                                                    "interworking",
                                                    "is_ac_partially_programmed",
                                                    "mac_limit_oper_down",
                                                    "ms_ti_mismatch",
                                                    "msti",
                                                    "msti_mismatch_down",
                                                    "mtu_mismatched",
                                                    "node_id",
                                                    "out_of_memory_state",
                                                    "redundancy_group_id",
                                                    "redundancy_group_state",
                                                    "redundancy_object_id",
                                                    "state",
                                                    "tdm_media_mismatched",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__setattr__(name, value)


                                class Interface(Entity):
                                    """
                                    Interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "attachment-circuit"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "attachment-circuit"

                                        self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        self._children_yang_names.add("dispostion-stats")

                                        self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                        self._children_yang_names.add("impostion-stats")

                                        self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._children_yang_names.add("sequence-number")


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                            self._children_yang_names.add("broadcast")

                                            self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            self._children_yang_names.add("imposition-mtu-drop")

                                            self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                            self._children_yang_names.add("imposition-stat")

                                            self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            self._children_yang_names.add("impostion-tail-drop")

                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            self._children_yang_names.add("l2fsbi-drop")

                                            self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                            self._children_yang_names.add("multicast")

                                            self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._children_yang_names.add("unknown-unicast")


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class L2FsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2fsbi-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast is not None and self.broadcast.has_data()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                (self.multicast is not None and self.multicast.has_data()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast is not None and self.broadcast.has_operation()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                (self.multicast is not None and self.multicast.has_operation()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast"):
                                                if (self.broadcast is None):
                                                    self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                                    self.broadcast.parent = self
                                                    self._children_name_map["broadcast"] = "broadcast"
                                                return self.broadcast

                                            if (child_yang_name == "imposition-mtu-drop"):
                                                if (self.imposition_mtu_drop is None):
                                                    self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                    self.imposition_mtu_drop.parent = self
                                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                return self.imposition_mtu_drop

                                            if (child_yang_name == "imposition-stat"):
                                                if (self.imposition_stat is None):
                                                    self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                                    self.imposition_stat.parent = self
                                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                                return self.imposition_stat

                                            if (child_yang_name == "impostion-tail-drop"):
                                                if (self.impostion_tail_drop is None):
                                                    self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                                    self.impostion_tail_drop.parent = self
                                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                return self.impostion_tail_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "l2fsbi-drop"):
                                                if (self.l2fsbi_drop is None):
                                                    self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                                    self.l2fsbi_drop.parent = self
                                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                return self.l2fsbi_drop

                                            if (child_yang_name == "multicast"):
                                                if (self.multicast is None):
                                                    self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                                    self.multicast.parent = self
                                                    self._children_name_map["multicast"] = "multicast"
                                                return self.multicast

                                            if (child_yang_name == "unknown-unicast"):
                                                if (self.unknown_unicast is None):
                                                    self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                                    self.unknown_unicast.parent = self
                                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                return self.unknown_unicast

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            self._children_yang_names.add("broadcast-drop")

                                            self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                            self._children_yang_names.add("dai-drop")

                                            self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            self._children_yang_names.add("disposition-mtu-drop")

                                            self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            self._children_yang_names.add("disposition-oo-o-drops")

                                            self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            self._children_yang_names.add("disposition-p2mp-stats")

                                            self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                            self._children_yang_names.add("disposition-stat")

                                            self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            self._children_yang_names.add("disposition-tail-drop")

                                            self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            self._children_yang_names.add("ipsg-drop")

                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._children_yang_names.add("mac-move")

                                            self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                            self._children_yang_names.add("multicast-drop")

                                            self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                            self._children_yang_names.add("received-drops")

                                            self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                            self._children_yang_names.add("unicast-drop")


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "received-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dai-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipsg-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-oo-o-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionP2MpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-p2mp-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mac-move" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.mac_move is not None and self.mac_move.has_data()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                (self.received_drops is not None and self.received_drops.has_data()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.mac_move is not None and self.mac_move.has_operation()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                (self.received_drops is not None and self.received_drops.has_operation()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dispostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast-drop"):
                                                if (self.broadcast_drop is None):
                                                    self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                                    self.broadcast_drop.parent = self
                                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                return self.broadcast_drop

                                            if (child_yang_name == "dai-drop"):
                                                if (self.dai_drop is None):
                                                    self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                                    self.dai_drop.parent = self
                                                    self._children_name_map["dai_drop"] = "dai-drop"
                                                return self.dai_drop

                                            if (child_yang_name == "disposition-mtu-drop"):
                                                if (self.disposition_mtu_drop is None):
                                                    self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                                    self.disposition_mtu_drop.parent = self
                                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                return self.disposition_mtu_drop

                                            if (child_yang_name == "disposition-oo-o-drops"):
                                                if (self.disposition_oo_o_drops is None):
                                                    self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                                    self.disposition_oo_o_drops.parent = self
                                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                return self.disposition_oo_o_drops

                                            if (child_yang_name == "disposition-p2mp-stats"):
                                                if (self.disposition_p2mp_stats is None):
                                                    self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                                    self.disposition_p2mp_stats.parent = self
                                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                return self.disposition_p2mp_stats

                                            if (child_yang_name == "disposition-stat"):
                                                if (self.disposition_stat is None):
                                                    self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                                    self.disposition_stat.parent = self
                                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                                return self.disposition_stat

                                            if (child_yang_name == "disposition-tail-drop"):
                                                if (self.disposition_tail_drop is None):
                                                    self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                                    self.disposition_tail_drop.parent = self
                                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                return self.disposition_tail_drop

                                            if (child_yang_name == "ipsg-drop"):
                                                if (self.ipsg_drop is None):
                                                    self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                                    self.ipsg_drop.parent = self
                                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                return self.ipsg_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "mac-move"):
                                                if (self.mac_move is None):
                                                    self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                                    self.mac_move.parent = self
                                                    self._children_name_map["mac_move"] = "mac-move"
                                                return self.mac_move

                                            if (child_yang_name == "multicast-drop"):
                                                if (self.multicast_drop is None):
                                                    self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                                    self.multicast_drop.parent = self
                                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                                return self.multicast_drop

                                            if (child_yang_name == "received-drops"):
                                                if (self.received_drops is None):
                                                    self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                                    self.received_drops.parent = self
                                                    self._children_name_map["received_drops"] = "received-drops"
                                                return self.received_drops

                                            if (child_yang_name == "unicast-drop"):
                                                if (self.unicast_drop is None):
                                                    self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                                    self.unicast_drop.parent = self
                                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                                return self.unicast_drop

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"

                                            self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                            self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                            self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                            self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bypassed_inbound_sequence_packet",
                                                            "bypassed_out_sequence_packet",
                                                            "sequence_number_expected",
                                                            "sequence_number_sent") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bypassed_inbound_sequence_packet.is_set or
                                                self.bypassed_out_sequence_packet.is_set or
                                                self.sequence_number_expected.is_set or
                                                self.sequence_number_sent.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                self.sequence_number_expected.yfilter != YFilter.not_set or
                                                self.sequence_number_sent.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sequence-number" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                            if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                            if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                            if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bypassed-inbound-sequence-packet"):
                                                self.bypassed_inbound_sequence_packet = value
                                                self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bypassed-out-sequence-packet"):
                                                self.bypassed_out_sequence_packet = value
                                                self.bypassed_out_sequence_packet.value_namespace = name_space
                                                self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-expected"):
                                                self.sequence_number_expected = value
                                                self.sequence_number_expected.value_namespace = name_space
                                                self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-sent"):
                                                self.sequence_number_sent = value
                                                self.sequence_number_sent.value_namespace = name_space
                                                self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                            (self.sequence_number is not None and self.sequence_number.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                            (self.sequence_number is not None and self.sequence_number.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "statistics" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dispostion-stats"):
                                            if (self.dispostion_stats is None):
                                                self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                                self.dispostion_stats.parent = self
                                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            return self.dispostion_stats

                                        if (child_yang_name == "impostion-stats"):
                                            if (self.impostion_stats is None):
                                                self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                                self.impostion_stats.parent = self
                                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                            return self.impostion_stats

                                        if (child_yang_name == "sequence-number"):
                                            if (self.sequence_number is None):
                                                self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                                self.sequence_number.parent = self
                                                self._children_name_map["sequence_number"] = "sequence-number"
                                            return self.sequence_number

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class L2VpnProtection(Entity):
                                    """
                                    Protection object used for this segment
                                    
                                    .. attribute:: active
                                    
                                    	Active
                                    	**type**\:  bool
                                    
                                    .. attribute:: protected_name
                                    
                                    	Name of the protected segment
                                    	**type**\:  str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: protection_configured
                                    
                                    	Protection configured
                                    	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                                    
                                    .. attribute:: protection_name
                                    
                                    	Name of the segment acting as backup
                                    	**type**\:  str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: protection_type
                                    
                                    	Type of the protection
                                    	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__init__()

                                        self.yang_name = "l2vpn-protection"
                                        self.yang_parent_name = "attachment-circuit"

                                        self.active = YLeaf(YType.boolean, "active")

                                        self.protected_name = YLeaf(YType.str, "protected-name")

                                        self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                        self.protection_name = YLeaf(YType.str, "protection-name")

                                        self.protection_type = YLeaf(YType.enumeration, "protection-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("active",
                                                        "protected_name",
                                                        "protection_configured",
                                                        "protection_name",
                                                        "protection_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.active.is_set or
                                            self.protected_name.is_set or
                                            self.protection_configured.is_set or
                                            self.protection_name.is_set or
                                            self.protection_type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.active.yfilter != YFilter.not_set or
                                            self.protected_name.yfilter != YFilter.not_set or
                                            self.protection_configured.yfilter != YFilter.not_set or
                                            self.protection_name.yfilter != YFilter.not_set or
                                            self.protection_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2vpn-protection" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.active.get_name_leafdata())
                                        if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protected_name.get_name_leafdata())
                                        if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                        if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protection_name.get_name_leafdata())
                                        if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protection_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "active"):
                                            self.active = value
                                            self.active.value_namespace = name_space
                                            self.active.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protected-name"):
                                            self.protected_name = value
                                            self.protected_name.value_namespace = name_space
                                            self.protected_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protection-configured"):
                                            self.protection_configured = value
                                            self.protection_configured.value_namespace = name_space
                                            self.protection_configured.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protection-name"):
                                            self.protection_name = value
                                            self.protection_name.value_namespace = name_space
                                            self.protection_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protection-type"):
                                            self.protection_type = value
                                            self.protection_type.value_namespace = name_space
                                            self.protection_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bvi_mac_conflict.is_set or
                                        self.bvi_no_port_up.is_set or
                                        self.control_word_mismatched.is_set or
                                        self.encapsulation_error.is_set or
                                        self.encapsulation_mismatched.is_set or
                                        self.evpn_internal_label.is_set or
                                        self.interface_handle.is_set or
                                        self.internal_ms_ti.is_set or
                                        self.interworking.is_set or
                                        self.is_ac_partially_programmed.is_set or
                                        self.mac_limit_oper_down.is_set or
                                        self.ms_ti_mismatch.is_set or
                                        self.msti.is_set or
                                        self.msti_mismatch_down.is_set or
                                        self.mtu_mismatched.is_set or
                                        self.node_id.is_set or
                                        self.out_of_memory_state.is_set or
                                        self.redundancy_group_id.is_set or
                                        self.redundancy_group_state.is_set or
                                        self.redundancy_object_id.is_set or
                                        self.state.is_set or
                                        self.tdm_media_mismatched.is_set or
                                        self.xconnect_id.is_set or
                                        (self.interface is not None and self.interface.has_data()) or
                                        (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                        (self.statistics is not None and self.statistics.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                        self.bvi_no_port_up.yfilter != YFilter.not_set or
                                        self.control_word_mismatched.yfilter != YFilter.not_set or
                                        self.encapsulation_error.yfilter != YFilter.not_set or
                                        self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                        self.evpn_internal_label.yfilter != YFilter.not_set or
                                        self.interface_handle.yfilter != YFilter.not_set or
                                        self.internal_ms_ti.yfilter != YFilter.not_set or
                                        self.interworking.yfilter != YFilter.not_set or
                                        self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                        self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                        self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                        self.msti.yfilter != YFilter.not_set or
                                        self.msti_mismatch_down.yfilter != YFilter.not_set or
                                        self.mtu_mismatched.yfilter != YFilter.not_set or
                                        self.node_id.yfilter != YFilter.not_set or
                                        self.out_of_memory_state.yfilter != YFilter.not_set or
                                        self.redundancy_group_id.yfilter != YFilter.not_set or
                                        self.redundancy_group_state.yfilter != YFilter.not_set or
                                        self.redundancy_object_id.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.interface is not None and self.interface.has_operation()) or
                                        (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                        (self.statistics is not None and self.statistics.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "attachment-circuit" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                                    if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                                    if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                                    if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                                    if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                                    if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                    if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                    if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                                    if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interworking.get_name_leafdata())
                                    if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                                    if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                    if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                                    if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.msti.get_name_leafdata())
                                    if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                                    if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                    if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.node_id.get_name_leafdata())
                                    if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                    if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                    if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                                    if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface"):
                                        if (self.interface is None):
                                            self.interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                            self.interface.parent = self
                                            self._children_name_map["interface"] = "interface"
                                        return self.interface

                                    if (child_yang_name == "l2vpn-protection"):
                                        if (self.l2vpn_protection is None):
                                            self.l2vpn_protection = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                                            self.l2vpn_protection.parent = self
                                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                        return self.l2vpn_protection

                                    if (child_yang_name == "statistics"):
                                        if (self.statistics is None):
                                            self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                            self.statistics.parent = self
                                            self._children_name_map["statistics"] = "statistics"
                                        return self.statistics

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bvi-mac-conflict"):
                                        self.bvi_mac_conflict = value
                                        self.bvi_mac_conflict.value_namespace = name_space
                                        self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bvi-no-port-up"):
                                        self.bvi_no_port_up = value
                                        self.bvi_no_port_up.value_namespace = name_space
                                        self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "control-word-mismatched"):
                                        self.control_word_mismatched = value
                                        self.control_word_mismatched.value_namespace = name_space
                                        self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "encapsulation-error"):
                                        self.encapsulation_error = value
                                        self.encapsulation_error.value_namespace = name_space
                                        self.encapsulation_error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "encapsulation-mismatched"):
                                        self.encapsulation_mismatched = value
                                        self.encapsulation_mismatched.value_namespace = name_space
                                        self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "evpn-internal-label"):
                                        self.evpn_internal_label = value
                                        self.evpn_internal_label.value_namespace = name_space
                                        self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-handle"):
                                        self.interface_handle = value
                                        self.interface_handle.value_namespace = name_space
                                        self.interface_handle.value_namespace_prefix = name_space_prefix
                                    if(value_path == "internal-ms-ti"):
                                        self.internal_ms_ti = value
                                        self.internal_ms_ti.value_namespace = name_space
                                        self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interworking"):
                                        self.interworking = value
                                        self.interworking.value_namespace = name_space
                                        self.interworking.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ac-partially-programmed"):
                                        self.is_ac_partially_programmed = value
                                        self.is_ac_partially_programmed.value_namespace = name_space
                                        self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-oper-down"):
                                        self.mac_limit_oper_down = value
                                        self.mac_limit_oper_down.value_namespace = name_space
                                        self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ms-ti-mismatch"):
                                        self.ms_ti_mismatch = value
                                        self.ms_ti_mismatch.value_namespace = name_space
                                        self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                                    if(value_path == "msti"):
                                        self.msti = value
                                        self.msti.value_namespace = name_space
                                        self.msti.value_namespace_prefix = name_space_prefix
                                    if(value_path == "msti-mismatch-down"):
                                        self.msti_mismatch_down = value
                                        self.msti_mismatch_down.value_namespace = name_space
                                        self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-mismatched"):
                                        self.mtu_mismatched = value
                                        self.mtu_mismatched.value_namespace = name_space
                                        self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "node-id"):
                                        self.node_id = value
                                        self.node_id.value_namespace = name_space
                                        self.node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "out-of-memory-state"):
                                        self.out_of_memory_state = value
                                        self.out_of_memory_state.value_namespace = name_space
                                        self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-group-id"):
                                        self.redundancy_group_id = value
                                        self.redundancy_group_id.value_namespace = name_space
                                        self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-group-state"):
                                        self.redundancy_group_state = value
                                        self.redundancy_group_state.value_namespace = name_space
                                        self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-object-id"):
                                        self.redundancy_object_id = value
                                        self.redundancy_object_id.value_namespace = name_space
                                        self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tdm-media-mismatched"):
                                        self.tdm_media_mismatched = value
                                        self.tdm_media_mismatched.value_namespace = name_space
                                        self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-ac"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-ac"

                                    self.address = YLeaf(YType.str, "address")

                                    self.bmac = YLeaf(YType.str, "bmac")

                                    self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "bmac",
                                                    "next_hop_ip") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.bmac.is_set or
                                        self.next_hop_ip.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.bmac.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "static-mac" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bmac.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bmac"):
                                        self.bmac = value
                                        self.bmac.value_namespace = name_space
                                        self.bmac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix


                            class Bvimac(Entity):
                                """
                                BVI MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__init__()

                                    self.yang_name = "bvimac"
                                    self.yang_parent_name = "bridge-ac"

                                    self.address = YLeaf(YType.str, "address")

                                    self.bmac = YLeaf(YType.str, "bmac")

                                    self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "bmac",
                                                    "next_hop_ip") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.bmac.is_set or
                                        self.next_hop_ip.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.bmac.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bvimac" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bmac.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bmac"):
                                        self.bmac = value
                                        self.bmac.value_namespace = name_space
                                        self.bmac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.bvimac:
                                    if (c.has_data()):
                                        return True
                                for c in self.static_mac:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.bvi_mac_index.is_set or
                                    (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                                    (self.security_parameters is not None and self.security_parameters.has_data()))

                            def has_operation(self):
                                for c in self.bvimac:
                                    if (c.has_operation()):
                                        return True
                                for c in self.static_mac:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.bvi_mac_index.yfilter != YFilter.not_set or
                                    (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bridge-ac" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.bvi_mac_index.is_set or self.bvi_mac_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bvi_mac_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "attachment-circuit"):
                                    if (self.attachment_circuit is None):
                                        self.attachment_circuit = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                                        self.attachment_circuit.parent = self
                                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                    return self.attachment_circuit

                                if (child_yang_name == "bvimac"):
                                    for c in self.bvimac:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.bvimac.append(c)
                                    return c

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                if (child_yang_name == "static-mac"):
                                    for c in self.static_mac:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.static_mac.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "attachment-circuit" or name == "bvimac" or name == "security-parameters" or name == "static-mac" or name == "interface-name" or name == "bvi-mac-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bvi-mac-index"):
                                    self.bvi_mac_index = value
                                    self.bvi_mac_index.value_namespace = name_space
                                    self.bvi_mac_index.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bridge_ac:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bridge_ac:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-acs" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bridge-ac"):
                                for c in self.bridge_ac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bridge_ac.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-ac"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BridgeAccessPws(Entity):
                        """
                        VPLS Bridge Domain Access Pseudowire Table
                        
                        .. attribute:: bridge_access_pw
                        
                        	VPLS Bridge Domain Access Pseudowire
                        	**type**\: list of    :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__init__()

                            self.yang_name = "bridge-access-pws"
                            self.yang_parent_name = "bridge-domain"

                            self.bridge_access_pw = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__setattr__(name, value)


                        class BridgeAccessPw(Entity):
                            """
                            VPLS Bridge Domain Access Pseudowire
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__init__()

                                self.yang_name = "bridge-access-pw"
                                self.yang_parent_name = "bridge-access-pws"

                                self.is_access = YLeaf(YType.boolean, "is-access")

                                self.neighbor = YLeaf(YType.str, "neighbor")

                                self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                                self.pseudowire = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"
                                self._children_yang_names.add("pseudowire")

                                self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                                self.static_mac = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_access",
                                                "neighbor",
                                                "pseudowire_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__setattr__(name, value)


                            class Pseudowire(Entity):
                                """
                                Pseudowire
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\:  bool
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\:  bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\:  bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\:  bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\:  bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\:  bool
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\:  bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\:  bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\:  bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\:  bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\:  bool
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_evpnvpws_type
                                
                                	is EVPN VPWS
                                	**type**\:  bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\:  bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\:  bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\:  bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\:  bool
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\:  bool
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\:  bool
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw>`
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\:  bool
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\:  bool
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\:  bool
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\:  bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\:  bool
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\:  bool
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\:  bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\:  bool
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\:  bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\:  bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\:  bool
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\:  str
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__init__()

                                    self.yang_name = "pseudowire"
                                    self.yang_parent_name = "bridge-access-pw"

                                    self.ad_method = YLeaf(YType.uint32, "ad-method")

                                    self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                    self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                    self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                    self.backup_active = YLeaf(YType.boolean, "backup-active")

                                    self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                    self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                    self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                    self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                    self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                    self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                    self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                    self.disable_never = YLeaf(YType.boolean, "disable-never")

                                    self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                    self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                    self.forward_class = YLeaf(YType.uint8, "forward-class")

                                    self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                    self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                    self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                    self.interworking = YLeaf(YType.enumeration, "interworking")

                                    self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                    self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                    self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                    self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                    self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                    self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                    self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                    self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                    self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                    self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                    self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                    self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                    self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                    self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                    self.local_source_address = YLeaf(YType.str, "local-source-address")

                                    self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                    self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                    self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                    self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                    self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                    self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                    self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                    self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                    self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                    self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                    self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                    self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                    self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                    self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                    self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                    self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                    self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                    self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                    self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                    self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                    self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                    self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                    self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                    self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                    self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                    self.required_bw = YLeaf(YType.uint32, "required-bw")

                                    self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                    self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                    self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                    self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                    self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                    self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                    self.time_created = YLeaf(YType.str, "time-created")

                                    self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                    self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                    self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                    self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.encapsulation_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    self._children_yang_names.add("encapsulation-info")

                                    self.local_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                    self._children_yang_names.add("local-interface")

                                    self.local_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                    self._children_yang_names.add("local-signalling")

                                    self.p2mp_pw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    self._children_yang_names.add("p2mp-pw")

                                    self.peer_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                    self._children_yang_names.add("peer-id")

                                    self.preferred_path = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                    self._children_yang_names.add("preferred-path")

                                    self.remote_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                    self._children_yang_names.add("remote-interface")

                                    self.remote_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                    self._children_yang_names.add("remote-signalling")

                                    self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._children_yang_names.add("statistics")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ad_method",
                                                    "ad_remote_down",
                                                    "admited_bw",
                                                    "auto_discovery",
                                                    "backup_active",
                                                    "backup_force_active",
                                                    "backup_pw",
                                                    "bitrate_mismatched",
                                                    "bridge_pw_type_mismatch",
                                                    "cas_mismatched",
                                                    "diff_ts_mismatched",
                                                    "disable_delay",
                                                    "disable_never",
                                                    "evpn_src_acid",
                                                    "fe_ctype",
                                                    "forward_class",
                                                    "freq_mismatched",
                                                    "illegal_control_word",
                                                    "imposed_vlan_id",
                                                    "interworking",
                                                    "ipv6_local_source_address",
                                                    "is_evpnvpws_type",
                                                    "is_flow_label_static",
                                                    "is_multi_segment_pseudowire",
                                                    "is_partially_programmed",
                                                    "is_pwr_type",
                                                    "is_vfi",
                                                    "last_time_status_changed",
                                                    "last_time_status_down",
                                                    "ldp_label_advertise_failed",
                                                    "load_balance",
                                                    "local_control_word",
                                                    "local_label_failed",
                                                    "local_pseudo_wire_type",
                                                    "local_source_address",
                                                    "mac_limit_oper_down",
                                                    "mtu_mismatched",
                                                    "not_supported_qinq",
                                                    "num_ma_cwithdraw_msg_received",
                                                    "number_ma_cwithdraw_message_sent",
                                                    "out_of_memory_state",
                                                    "payload_bytes_mismatched",
                                                    "payload_type_mismatched",
                                                    "preferred_path_disable_fallback",
                                                    "primary_peer_id",
                                                    "primary_pseudo_wire_id",
                                                    "primary_pw",
                                                    "protocol",
                                                    "pseudo_wire_id",
                                                    "pseudo_wire_state",
                                                    "pseudo_wire_type_mismatched",
                                                    "pw_class_name",
                                                    "pw_flow_label_code17_disabled",
                                                    "pw_flow_label_type",
                                                    "pw_flow_label_type_cfg",
                                                    "pw_redundancy_initial_delay",
                                                    "pw_redundancy_one_way",
                                                    "pw_status_use",
                                                    "pwlsd_rewrite_failed",
                                                    "remote_control_word",
                                                    "remote_label_failed",
                                                    "remote_pseudo_wire_type",
                                                    "required_bw",
                                                    "resync_enabled",
                                                    "resync_threshold",
                                                    "rtp_mismatched",
                                                    "sequencing_type",
                                                    "shutdown",
                                                    "sig_pkts_mismatched",
                                                    "ssrc_mismatched",
                                                    "state",
                                                    "table_policy_name",
                                                    "tag_rewrite",
                                                    "time_created",
                                                    "time_elapsed_creation",
                                                    "time_elapsed_status_changed",
                                                    "time_elapsed_status_down",
                                                    "transport_lsp_down",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__setattr__(name, value)


                                class PeerId(Entity):
                                    """
                                    Peer
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__init__()

                                        self.yang_name = "peer-id"
                                        self.yang_parent_name = "pseudowire"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                        self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                        self.type = YLeaf(YType.enumeration, "type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "ipv4_peer_id",
                                                        "ipv6_peer_id",
                                                        "type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.ipv4_peer_id.is_set or
                                            self.ipv6_peer_id.is_set or
                                            self.type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.ipv4_peer_id.yfilter != YFilter.not_set or
                                            self.ipv6_peer_id.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "peer-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                        if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-peer-id"):
                                            self.ipv4_peer_id = value
                                            self.ipv4_peer_id.value_namespace = name_space
                                            self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-peer-id"):
                                            self.ipv6_peer_id = value
                                            self.ipv6_peer_id.value_namespace = name_space
                                            self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix


                                class EncapsulationInfo(Entity):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__init__()

                                        self.yang_name = "encapsulation-info"
                                        self.yang_parent_name = "pseudowire"

                                        self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                        self.atom = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                        self._children_yang_names.add("atom")

                                        self.l2tpv3 = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                        self._children_yang_names.add("l2tpv3")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                    class Atom(Entity):
                                        """
                                        atom
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                            self.yang_name = "atom"
                                            self.yang_parent_name = "encapsulation-info"

                                            self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                            self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                            self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                            self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                            self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                            self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                            self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                            self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                            self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                            self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                            self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                            self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                            self.local_veid = YLeaf(YType.uint32, "local-veid")

                                            self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                            self.rem_saii = YLeaf(YType.str, "rem-saii")

                                            self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                            self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                            self.rem_taii = YLeaf(YType.str, "rem-taii")

                                            self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                            self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                            self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                            self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                            self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                            self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                                            self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                            self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                            self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                            self.saii = YLeaf(YType.str, "saii")

                                            self.source_address = YLeaf(YType.str, "source-address")

                                            self.taii = YLeaf(YType.str, "taii")

                                            self.local_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                            self._children_yang_names.add("local-agi")

                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            self._children_yang_names.add("multi-segment-pseudowire-stats")

                                            self.remote_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                            self._children_yang_names.add("remote-agi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("is_pseudowire_headend",
                                                            "is_sai_itype2",
                                                            "is_tai_itype2",
                                                            "ldp_label_advertisment_failed",
                                                            "local_c_ctype",
                                                            "local_ceid",
                                                            "local_cv_type",
                                                            "local_group_id",
                                                            "local_label",
                                                            "local_ldp_id",
                                                            "local_saii_gbl_id",
                                                            "local_saiiac_id",
                                                            "local_taii_gbl_id",
                                                            "local_taiiac_id",
                                                            "local_veid",
                                                            "lsd_rewrite_failed",
                                                            "rem_saii",
                                                            "rem_saii_gbl_id",
                                                            "rem_saiiac_id",
                                                            "rem_taii",
                                                            "rem_taii_gbl_id",
                                                            "rem_taiiac_id",
                                                            "remote_c_ctype",
                                                            "remote_ceid",
                                                            "remote_cv_type",
                                                            "remote_group_id",
                                                            "remote_label",
                                                            "remote_ldp_id",
                                                            "remote_source_address",
                                                            "remote_veid",
                                                            "saii",
                                                            "source_address",
                                                            "taii") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                        class LocalAgi(Entity):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                self.yang_name = "local-agi"
                                                self.yang_parent_name = "atom"

                                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                                self._children_yang_names.add("auto")

                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                                self._children_yang_names.add("two-byte-as")

                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._children_yang_names.add("v4-addr")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vpls_id_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "local-agi"

                                                    self.asn = YLeaf(YType.uint16, "asn")

                                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("asn",
                                                                    "vpn_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.asn.is_set or
                                                        self.vpn_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.asn.yfilter != YFilter.not_set or
                                                        self.vpn_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "auto" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "asn" or name == "vpn-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "asn"):
                                                        self.asn = value
                                                        self.asn.value_namespace = name_space
                                                        self.asn.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpn-id"):
                                                        self.vpn_id = value
                                                        self.vpn_id.value_namespace = name_space
                                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "local-agi"

                                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("four_byte_index",
                                                                    "two_byte_as") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.four_byte_index.is_set or
                                                        self.two_byte_as.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.four_byte_index.yfilter != YFilter.not_set or
                                                        self.two_byte_as.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "two-byte-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "four-byte-index"):
                                                        self.four_byte_index = value
                                                        self.four_byte_index.value_namespace = name_space
                                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-as"):
                                                        self.two_byte_as = value
                                                        self.two_byte_as.value_namespace = name_space
                                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "local-agi"

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ipv4_address",
                                                                    "two_byte_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ipv4_address.is_set or
                                                        self.two_byte_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ipv4_address.yfilter != YFilter.not_set or
                                                        self.two_byte_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "v4-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ipv4-address"):
                                                        self.ipv4_address = value
                                                        self.ipv4_address.value_namespace = name_space
                                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-index"):
                                                        self.two_byte_index = value
                                                        self.two_byte_index.value_namespace = name_space
                                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.vpls_id_type.is_set or
                                                    (self.auto is not None and self.auto.has_data()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                                    (self.auto is not None and self.auto.has_operation()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "local-agi" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "auto"):
                                                    if (self.auto is None):
                                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                        self.auto.parent = self
                                                        self._children_name_map["auto"] = "auto"
                                                    return self.auto

                                                if (child_yang_name == "two-byte-as"):
                                                    if (self.two_byte_as is None):
                                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                        self.two_byte_as.parent = self
                                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    return self.two_byte_as

                                                if (child_yang_name == "v4-addr"):
                                                    if (self.v4_addr is None):
                                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                        self.v4_addr.parent = self
                                                        self._children_name_map["v4_addr"] = "v4-addr"
                                                    return self.v4_addr

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vpls-id-type"):
                                                    self.vpls_id_type = value
                                                    self.vpls_id_type.value_namespace = name_space
                                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                        class RemoteAgi(Entity):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                self.yang_name = "remote-agi"
                                                self.yang_parent_name = "atom"

                                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                                self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                                self._children_yang_names.add("auto")

                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                                self._children_yang_names.add("two-byte-as")

                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._children_yang_names.add("v4-addr")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("vpls_id_type") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.asn = YLeaf(YType.uint16, "asn")

                                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("asn",
                                                                    "vpn_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.asn.is_set or
                                                        self.vpn_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.asn.yfilter != YFilter.not_set or
                                                        self.vpn_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "auto" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "asn" or name == "vpn-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "asn"):
                                                        self.asn = value
                                                        self.asn.value_namespace = name_space
                                                        self.asn.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vpn-id"):
                                                        self.vpn_id = value
                                                        self.vpn_id.value_namespace = name_space
                                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("four_byte_index",
                                                                    "two_byte_as") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.four_byte_index.is_set or
                                                        self.two_byte_as.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.four_byte_index.yfilter != YFilter.not_set or
                                                        self.two_byte_as.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "two-byte-as" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "four-byte-index"):
                                                        self.four_byte_index = value
                                                        self.four_byte_index.value_namespace = name_space
                                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-as"):
                                                        self.two_byte_as = value
                                                        self.two_byte_as.value_namespace = name_space
                                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "remote-agi"

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("ipv4_address",
                                                                    "two_byte_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.ipv4_address.is_set or
                                                        self.two_byte_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.ipv4_address.yfilter != YFilter.not_set or
                                                        self.two_byte_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "v4-addr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "ipv4-address"):
                                                        self.ipv4_address = value
                                                        self.ipv4_address.value_namespace = name_space
                                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "two-byte-index"):
                                                        self.two_byte_index = value
                                                        self.two_byte_index.value_namespace = name_space
                                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.vpls_id_type.is_set or
                                                    (self.auto is not None and self.auto.has_data()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                                    (self.auto is not None and self.auto.has_operation()) or
                                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-agi" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "auto"):
                                                    if (self.auto is None):
                                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                        self.auto.parent = self
                                                        self._children_name_map["auto"] = "auto"
                                                    return self.auto

                                                if (child_yang_name == "two-byte-as"):
                                                    if (self.two_byte_as is None):
                                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                        self.two_byte_as.parent = self
                                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                                    return self.two_byte_as

                                                if (child_yang_name == "v4-addr"):
                                                    if (self.v4_addr is None):
                                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                        self.v4_addr.parent = self
                                                        self._children_name_map["v4_addr"] = "v4-addr"
                                                    return self.v4_addr

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "vpls-id-type"):
                                                    self.vpls_id_type = value
                                                    self.vpls_id_type.value_namespace = name_space
                                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                        class MultiSegmentPseudowireStats(Entity):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                self.yang_name = "multi-segment-pseudowire-stats"
                                                self.yang_parent_name = "atom"

                                                self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                                self.received_packets = YLeaf(YType.uint64, "received-packets")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("received_bytes",
                                                                "received_packets") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.received_bytes.is_set or
                                                    self.received_packets.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.received_bytes.yfilter != YFilter.not_set or
                                                    self.received_packets.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                                if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.received_packets.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "received-bytes" or name == "received-packets"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "received-bytes"):
                                                    self.received_bytes = value
                                                    self.received_bytes.value_namespace = name_space
                                                    self.received_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "received-packets"):
                                                    self.received_packets = value
                                                    self.received_packets.value_namespace = name_space
                                                    self.received_packets.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.is_pseudowire_headend.is_set or
                                                self.is_sai_itype2.is_set or
                                                self.is_tai_itype2.is_set or
                                                self.ldp_label_advertisment_failed.is_set or
                                                self.local_c_ctype.is_set or
                                                self.local_ceid.is_set or
                                                self.local_cv_type.is_set or
                                                self.local_group_id.is_set or
                                                self.local_label.is_set or
                                                self.local_ldp_id.is_set or
                                                self.local_saii_gbl_id.is_set or
                                                self.local_saiiac_id.is_set or
                                                self.local_taii_gbl_id.is_set or
                                                self.local_taiiac_id.is_set or
                                                self.local_veid.is_set or
                                                self.lsd_rewrite_failed.is_set or
                                                self.rem_saii.is_set or
                                                self.rem_saii_gbl_id.is_set or
                                                self.rem_saiiac_id.is_set or
                                                self.rem_taii.is_set or
                                                self.rem_taii_gbl_id.is_set or
                                                self.rem_taiiac_id.is_set or
                                                self.remote_c_ctype.is_set or
                                                self.remote_ceid.is_set or
                                                self.remote_cv_type.is_set or
                                                self.remote_group_id.is_set or
                                                self.remote_label.is_set or
                                                self.remote_ldp_id.is_set or
                                                self.remote_source_address.is_set or
                                                self.remote_veid.is_set or
                                                self.saii.is_set or
                                                self.source_address.is_set or
                                                self.taii.is_set or
                                                (self.local_agi is not None and self.local_agi.has_data()) or
                                                (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                                (self.remote_agi is not None and self.remote_agi.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                                self.is_sai_itype2.yfilter != YFilter.not_set or
                                                self.is_tai_itype2.yfilter != YFilter.not_set or
                                                self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                                self.local_c_ctype.yfilter != YFilter.not_set or
                                                self.local_ceid.yfilter != YFilter.not_set or
                                                self.local_cv_type.yfilter != YFilter.not_set or
                                                self.local_group_id.yfilter != YFilter.not_set or
                                                self.local_label.yfilter != YFilter.not_set or
                                                self.local_ldp_id.yfilter != YFilter.not_set or
                                                self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                                self.local_saiiac_id.yfilter != YFilter.not_set or
                                                self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                                self.local_taiiac_id.yfilter != YFilter.not_set or
                                                self.local_veid.yfilter != YFilter.not_set or
                                                self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                                self.rem_saii.yfilter != YFilter.not_set or
                                                self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                                self.rem_saiiac_id.yfilter != YFilter.not_set or
                                                self.rem_taii.yfilter != YFilter.not_set or
                                                self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                                self.rem_taiiac_id.yfilter != YFilter.not_set or
                                                self.remote_c_ctype.yfilter != YFilter.not_set or
                                                self.remote_ceid.yfilter != YFilter.not_set or
                                                self.remote_cv_type.yfilter != YFilter.not_set or
                                                self.remote_group_id.yfilter != YFilter.not_set or
                                                self.remote_label.yfilter != YFilter.not_set or
                                                self.remote_ldp_id.yfilter != YFilter.not_set or
                                                self.remote_source_address.yfilter != YFilter.not_set or
                                                self.remote_veid.yfilter != YFilter.not_set or
                                                self.saii.yfilter != YFilter.not_set or
                                                self.source_address.yfilter != YFilter.not_set or
                                                self.taii.yfilter != YFilter.not_set or
                                                (self.local_agi is not None and self.local_agi.has_operation()) or
                                                (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                                (self.remote_agi is not None and self.remote_agi.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atom" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                            if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                            if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                            if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                            if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                            if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                            if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                            if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_label.get_name_leafdata())
                                            if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                            if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                            if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                            if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                            if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                            if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_veid.get_name_leafdata())
                                            if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                            if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                            if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                            if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                            if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                            if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                            if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                            if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                            if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                            if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                            if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                                            if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                            if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                            if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                            if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.saii.get_name_leafdata())
                                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.source_address.get_name_leafdata())
                                            if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.taii.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "local-agi"):
                                                if (self.local_agi is None):
                                                    self.local_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                    self.local_agi.parent = self
                                                    self._children_name_map["local_agi"] = "local-agi"
                                                return self.local_agi

                                            if (child_yang_name == "multi-segment-pseudowire-stats"):
                                                if (self.multi_segment_pseudowire_stats is None):
                                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                    self.multi_segment_pseudowire_stats.parent = self
                                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                return self.multi_segment_pseudowire_stats

                                            if (child_yang_name == "remote-agi"):
                                                if (self.remote_agi is None):
                                                    self.remote_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                    self.remote_agi.parent = self
                                                    self._children_name_map["remote_agi"] = "remote-agi"
                                                return self.remote_agi

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "is-pseudowire-headend"):
                                                self.is_pseudowire_headend = value
                                                self.is_pseudowire_headend.value_namespace = name_space
                                                self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-sai-itype2"):
                                                self.is_sai_itype2 = value
                                                self.is_sai_itype2.value_namespace = name_space
                                                self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-tai-itype2"):
                                                self.is_tai_itype2 = value
                                                self.is_tai_itype2.value_namespace = name_space
                                                self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ldp-label-advertisment-failed"):
                                                self.ldp_label_advertisment_failed = value
                                                self.ldp_label_advertisment_failed.value_namespace = name_space
                                                self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-c-ctype"):
                                                self.local_c_ctype = value
                                                self.local_c_ctype.value_namespace = name_space
                                                self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ceid"):
                                                self.local_ceid = value
                                                self.local_ceid.value_namespace = name_space
                                                self.local_ceid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cv-type"):
                                                self.local_cv_type = value
                                                self.local_cv_type.value_namespace = name_space
                                                self.local_cv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-group-id"):
                                                self.local_group_id = value
                                                self.local_group_id.value_namespace = name_space
                                                self.local_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-label"):
                                                self.local_label = value
                                                self.local_label.value_namespace = name_space
                                                self.local_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-ldp-id"):
                                                self.local_ldp_id = value
                                                self.local_ldp_id.value_namespace = name_space
                                                self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-saii-gbl-id"):
                                                self.local_saii_gbl_id = value
                                                self.local_saii_gbl_id.value_namespace = name_space
                                                self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-saiiac-id"):
                                                self.local_saiiac_id = value
                                                self.local_saiiac_id.value_namespace = name_space
                                                self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-taii-gbl-id"):
                                                self.local_taii_gbl_id = value
                                                self.local_taii_gbl_id.value_namespace = name_space
                                                self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-taiiac-id"):
                                                self.local_taiiac_id = value
                                                self.local_taiiac_id.value_namespace = name_space
                                                self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-veid"):
                                                self.local_veid = value
                                                self.local_veid.value_namespace = name_space
                                                self.local_veid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "lsd-rewrite-failed"):
                                                self.lsd_rewrite_failed = value
                                                self.lsd_rewrite_failed.value_namespace = name_space
                                                self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saii"):
                                                self.rem_saii = value
                                                self.rem_saii.value_namespace = name_space
                                                self.rem_saii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saii-gbl-id"):
                                                self.rem_saii_gbl_id = value
                                                self.rem_saii_gbl_id.value_namespace = name_space
                                                self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-saiiac-id"):
                                                self.rem_saiiac_id = value
                                                self.rem_saiiac_id.value_namespace = name_space
                                                self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taii"):
                                                self.rem_taii = value
                                                self.rem_taii.value_namespace = name_space
                                                self.rem_taii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taii-gbl-id"):
                                                self.rem_taii_gbl_id = value
                                                self.rem_taii_gbl_id.value_namespace = name_space
                                                self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rem-taiiac-id"):
                                                self.rem_taiiac_id = value
                                                self.rem_taiiac_id.value_namespace = name_space
                                                self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-c-ctype"):
                                                self.remote_c_ctype = value
                                                self.remote_c_ctype.value_namespace = name_space
                                                self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ceid"):
                                                self.remote_ceid = value
                                                self.remote_ceid.value_namespace = name_space
                                                self.remote_ceid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cv-type"):
                                                self.remote_cv_type = value
                                                self.remote_cv_type.value_namespace = name_space
                                                self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-group-id"):
                                                self.remote_group_id = value
                                                self.remote_group_id.value_namespace = name_space
                                                self.remote_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-label"):
                                                self.remote_label = value
                                                self.remote_label.value_namespace = name_space
                                                self.remote_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-ldp-id"):
                                                self.remote_ldp_id = value
                                                self.remote_ldp_id.value_namespace = name_space
                                                self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-source-address"):
                                                self.remote_source_address = value
                                                self.remote_source_address.value_namespace = name_space
                                                self.remote_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-veid"):
                                                self.remote_veid = value
                                                self.remote_veid.value_namespace = name_space
                                                self.remote_veid.value_namespace_prefix = name_space_prefix
                                            if(value_path == "saii"):
                                                self.saii = value
                                                self.saii.value_namespace = name_space
                                                self.saii.value_namespace_prefix = name_space_prefix
                                            if(value_path == "source-address"):
                                                self.source_address = value
                                                self.source_address.value_namespace = name_space
                                                self.source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "taii"):
                                                self.taii = value
                                                self.taii.value_namespace = name_space
                                                self.taii.value_namespace_prefix = name_space_prefix


                                    class L2Tpv3(Entity):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\:  bool
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\:  str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                            self.yang_name = "l2tpv3"
                                            self.yang_parent_name = "encapsulation-info"

                                            self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                            self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                            self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                            self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                            self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                            self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                            self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                            self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                            self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                            self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                            self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                            self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                            self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                            self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                            self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                            self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                            self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                            self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                            self.tos = YLeaf(YType.uint8, "tos")

                                            self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                            self.ttl = YLeaf(YType.uint8, "ttl")

                                            self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dont_fragment_bit",
                                                            "ipv4_source_address",
                                                            "ipv6_source_address",
                                                            "l2tp_class_name",
                                                            "local_cookie_high_value",
                                                            "local_cookie_low_value",
                                                            "local_cookie_size",
                                                            "local_secondary_cookie_high_value",
                                                            "local_secondary_cookie_low_value",
                                                            "local_secondary_cookie_size",
                                                            "local_session_id",
                                                            "path_mtu_enabled",
                                                            "path_mtu_max_value",
                                                            "remote_circuit_status_up",
                                                            "remote_cookie_high_value",
                                                            "remote_cookie_low_value",
                                                            "remote_cookie_size",
                                                            "remote_session_id",
                                                            "tos",
                                                            "tos_mode",
                                                            "ttl",
                                                            "tunnel_state") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dont_fragment_bit.is_set or
                                                self.ipv4_source_address.is_set or
                                                self.ipv6_source_address.is_set or
                                                self.l2tp_class_name.is_set or
                                                self.local_cookie_high_value.is_set or
                                                self.local_cookie_low_value.is_set or
                                                self.local_cookie_size.is_set or
                                                self.local_secondary_cookie_high_value.is_set or
                                                self.local_secondary_cookie_low_value.is_set or
                                                self.local_secondary_cookie_size.is_set or
                                                self.local_session_id.is_set or
                                                self.path_mtu_enabled.is_set or
                                                self.path_mtu_max_value.is_set or
                                                self.remote_circuit_status_up.is_set or
                                                self.remote_cookie_high_value.is_set or
                                                self.remote_cookie_low_value.is_set or
                                                self.remote_cookie_size.is_set or
                                                self.remote_session_id.is_set or
                                                self.tos.is_set or
                                                self.tos_mode.is_set or
                                                self.ttl.is_set or
                                                self.tunnel_state.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dont_fragment_bit.yfilter != YFilter.not_set or
                                                self.ipv4_source_address.yfilter != YFilter.not_set or
                                                self.ipv6_source_address.yfilter != YFilter.not_set or
                                                self.l2tp_class_name.yfilter != YFilter.not_set or
                                                self.local_cookie_high_value.yfilter != YFilter.not_set or
                                                self.local_cookie_low_value.yfilter != YFilter.not_set or
                                                self.local_cookie_size.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                                self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                                self.local_session_id.yfilter != YFilter.not_set or
                                                self.path_mtu_enabled.yfilter != YFilter.not_set or
                                                self.path_mtu_max_value.yfilter != YFilter.not_set or
                                                self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                                self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                                self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                                self.remote_cookie_size.yfilter != YFilter.not_set or
                                                self.remote_session_id.yfilter != YFilter.not_set or
                                                self.tos.yfilter != YFilter.not_set or
                                                self.tos_mode.yfilter != YFilter.not_set or
                                                self.ttl.yfilter != YFilter.not_set or
                                                self.tunnel_state.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2tpv3" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                            if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                            if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                            if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                            if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                            if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                            if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                            if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                            if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                            if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                            if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                            if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                            if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                            if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                            if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                            if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                            if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                            if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                            if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos.get_name_leafdata())
                                            if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                            if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ttl.get_name_leafdata())
                                            if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dont-fragment-bit"):
                                                self.dont_fragment_bit = value
                                                self.dont_fragment_bit.value_namespace = name_space
                                                self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-source-address"):
                                                self.ipv4_source_address = value
                                                self.ipv4_source_address.value_namespace = name_space
                                                self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-source-address"):
                                                self.ipv6_source_address = value
                                                self.ipv6_source_address.value_namespace = name_space
                                                self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "l2tp-class-name"):
                                                self.l2tp_class_name = value
                                                self.l2tp_class_name.value_namespace = name_space
                                                self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-high-value"):
                                                self.local_cookie_high_value = value
                                                self.local_cookie_high_value.value_namespace = name_space
                                                self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-low-value"):
                                                self.local_cookie_low_value = value
                                                self.local_cookie_low_value.value_namespace = name_space
                                                self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-cookie-size"):
                                                self.local_cookie_size = value
                                                self.local_cookie_size.value_namespace = name_space
                                                self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-high-value"):
                                                self.local_secondary_cookie_high_value = value
                                                self.local_secondary_cookie_high_value.value_namespace = name_space
                                                self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-low-value"):
                                                self.local_secondary_cookie_low_value = value
                                                self.local_secondary_cookie_low_value.value_namespace = name_space
                                                self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-secondary-cookie-size"):
                                                self.local_secondary_cookie_size = value
                                                self.local_secondary_cookie_size.value_namespace = name_space
                                                self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-session-id"):
                                                self.local_session_id = value
                                                self.local_session_id.value_namespace = name_space
                                                self.local_session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "path-mtu-enabled"):
                                                self.path_mtu_enabled = value
                                                self.path_mtu_enabled.value_namespace = name_space
                                                self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "path-mtu-max-value"):
                                                self.path_mtu_max_value = value
                                                self.path_mtu_max_value.value_namespace = name_space
                                                self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-circuit-status-up"):
                                                self.remote_circuit_status_up = value
                                                self.remote_circuit_status_up.value_namespace = name_space
                                                self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-high-value"):
                                                self.remote_cookie_high_value = value
                                                self.remote_cookie_high_value.value_namespace = name_space
                                                self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-low-value"):
                                                self.remote_cookie_low_value = value
                                                self.remote_cookie_low_value.value_namespace = name_space
                                                self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-cookie-size"):
                                                self.remote_cookie_size = value
                                                self.remote_cookie_size.value_namespace = name_space
                                                self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-session-id"):
                                                self.remote_session_id = value
                                                self.remote_session_id.value_namespace = name_space
                                                self.remote_session_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos"):
                                                self.tos = value
                                                self.tos.value_namespace = name_space
                                                self.tos.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tos-mode"):
                                                self.tos_mode = value
                                                self.tos_mode.value_namespace = name_space
                                                self.tos_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ttl"):
                                                self.ttl = value
                                                self.ttl.value_namespace = name_space
                                                self.ttl.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel-state"):
                                                self.tunnel_state = value
                                                self.tunnel_state.value_namespace = name_space
                                                self.tunnel_state.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.encapsulation.is_set or
                                            (self.atom is not None and self.atom.has_data()) or
                                            (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation.yfilter != YFilter.not_set or
                                            (self.atom is not None and self.atom.has_operation()) or
                                            (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "encapsulation-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atom"):
                                            if (self.atom is None):
                                                self.atom = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                                self.atom.parent = self
                                                self._children_name_map["atom"] = "atom"
                                            return self.atom

                                        if (child_yang_name == "l2tpv3"):
                                            if (self.l2tpv3 is None):
                                                self.l2tpv3 = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                                self.l2tpv3.parent = self
                                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                            return self.l2tpv3

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation"):
                                            self.encapsulation = value
                                            self.encapsulation.value_namespace = name_space
                                            self.encapsulation.value_namespace_prefix = name_space_prefix


                                class LocalInterface(Entity):
                                    """
                                    Local interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__init__()

                                        self.yang_name = "local-interface"
                                        self.yang_parent_name = "pseudowire"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "local-interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class RemoteInterface(Entity):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__init__()

                                        self.yang_name = "remote-interface"
                                        self.yang_parent_name = "pseudowire"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "remote-interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class PreferredPath(Entity):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__init__()

                                        self.yang_name = "preferred-path"
                                        self.yang_parent_name = "pseudowire"

                                        self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                        self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                        self.option = YLeaf(YType.enumeration, "option")

                                        self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                        self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ip_tunnel_interface_number",
                                                        "next_hop_ip",
                                                        "option",
                                                        "te_tunnel_interface_number",
                                                        "tp_tunnel_interface_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ip_tunnel_interface_number.is_set or
                                            self.next_hop_ip.is_set or
                                            self.option.is_set or
                                            self.te_tunnel_interface_number.is_set or
                                            self.tp_tunnel_interface_number.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                            self.next_hop_ip.yfilter != YFilter.not_set or
                                            self.option.yfilter != YFilter.not_set or
                                            self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                            self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "preferred-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                        if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.option.get_name_leafdata())
                                        if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                        if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ip-tunnel-interface-number"):
                                            self.ip_tunnel_interface_number = value
                                            self.ip_tunnel_interface_number.value_namespace = name_space
                                            self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-hop-ip"):
                                            self.next_hop_ip = value
                                            self.next_hop_ip.value_namespace = name_space
                                            self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                        if(value_path == "option"):
                                            self.option = value
                                            self.option.value_namespace = name_space
                                            self.option.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-tunnel-interface-number"):
                                            self.te_tunnel_interface_number = value
                                            self.te_tunnel_interface_number.value_namespace = name_space
                                            self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tp-tunnel-interface-number"):
                                            self.tp_tunnel_interface_number = value
                                            self.tp_tunnel_interface_number.value_namespace = name_space
                                            self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                                class LocalSignalling(Entity):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__init__()

                                        self.yang_name = "local-signalling"
                                        self.yang_parent_name = "pseudowire"

                                        self.pw_status = YLeaf(YType.uint32, "pw-status")

                                        self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                        self._children_yang_names.add("status-tlv")

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "local-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "status-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "local-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.pw_status.is_set or
                                            (self.status_tlv is not None and self.status_tlv.has_data()))

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_status.yfilter != YFilter.not_set or
                                            (self.status_tlv is not None and self.status_tlv.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-signalling" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "status-tlv"):
                                            if (self.status_tlv is None):
                                                self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                                self.status_tlv.parent = self
                                                self._children_name_map["status_tlv"] = "status-tlv"
                                            return self.status_tlv

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-status"):
                                            self.pw_status = value
                                            self.pw_status.value_namespace = name_space
                                            self.pw_status.value_namespace_prefix = name_space_prefix


                                class RemoteSignalling(Entity):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__init__()

                                        self.yang_name = "remote-signalling"
                                        self.yang_parent_name = "pseudowire"

                                        self.pw_status = YLeaf(YType.uint32, "pw-status")

                                        self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                        self._children_yang_names.add("status-tlv")

                                        self.tlv = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pw_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "remote-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "status-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "remote-signalling"

                                            self.description = YLeaf(YType.str, "description")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.pw_id = YLeaf(YType.uint32, "pw-id")

                                            self.remote_address = YLeaf(YType.str, "remote-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("description",
                                                            "local_address",
                                                            "pw_id",
                                                            "remote_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.description.is_set or
                                                self.local_address.is_set or
                                                self.pw_id.is_set or
                                                self.remote_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.description.yfilter != YFilter.not_set or
                                                self.local_address.yfilter != YFilter.not_set or
                                                self.pw_id.yfilter != YFilter.not_set or
                                                self.remote_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.description.get_name_leafdata())
                                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.local_address.get_name_leafdata())
                                            if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.pw_id.get_name_leafdata())
                                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.remote_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "description"):
                                                self.description = value
                                                self.description.value_namespace = name_space
                                                self.description.value_namespace_prefix = name_space_prefix
                                            if(value_path == "local-address"):
                                                self.local_address = value
                                                self.local_address.value_namespace = name_space
                                                self.local_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "pw-id"):
                                                self.pw_id = value
                                                self.pw_id.value_namespace = name_space
                                                self.pw_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "remote-address"):
                                                self.remote_address = value
                                                self.remote_address.value_namespace = name_space
                                                self.remote_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.tlv:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.pw_status.is_set or
                                            (self.status_tlv is not None and self.status_tlv.has_data()))

                                    def has_operation(self):
                                        for c in self.tlv:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pw_status.yfilter != YFilter.not_set or
                                            (self.status_tlv is not None and self.status_tlv.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-signalling" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "status-tlv"):
                                            if (self.status_tlv is None):
                                                self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                                self.status_tlv.parent = self
                                                self._children_name_map["status_tlv"] = "status-tlv"
                                            return self.status_tlv

                                        if (child_yang_name == "tlv"):
                                            for c in self.tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.tlv.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pw-status"):
                                            self.pw_status = value
                                            self.pw_status.value_namespace = name_space
                                            self.pw_status.value_namespace_prefix = name_space_prefix


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "pseudowire"

                                        self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        self._children_yang_names.add("dispostion-stats")

                                        self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                        self._children_yang_names.add("impostion-stats")

                                        self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._children_yang_names.add("sequence-number")


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                            self._children_yang_names.add("broadcast")

                                            self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            self._children_yang_names.add("imposition-mtu-drop")

                                            self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                            self._children_yang_names.add("imposition-stat")

                                            self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            self._children_yang_names.add("impostion-tail-drop")

                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            self._children_yang_names.add("l2fsbi-drop")

                                            self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                            self._children_yang_names.add("multicast")

                                            self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._children_yang_names.add("unknown-unicast")


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class L2FsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2fsbi-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast is not None and self.broadcast.has_data()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                (self.multicast is not None and self.multicast.has_data()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast is not None and self.broadcast.has_operation()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                (self.multicast is not None and self.multicast.has_operation()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast"):
                                                if (self.broadcast is None):
                                                    self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                    self.broadcast.parent = self
                                                    self._children_name_map["broadcast"] = "broadcast"
                                                return self.broadcast

                                            if (child_yang_name == "imposition-mtu-drop"):
                                                if (self.imposition_mtu_drop is None):
                                                    self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                    self.imposition_mtu_drop.parent = self
                                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                return self.imposition_mtu_drop

                                            if (child_yang_name == "imposition-stat"):
                                                if (self.imposition_stat is None):
                                                    self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                    self.imposition_stat.parent = self
                                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                                return self.imposition_stat

                                            if (child_yang_name == "impostion-tail-drop"):
                                                if (self.impostion_tail_drop is None):
                                                    self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                    self.impostion_tail_drop.parent = self
                                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                return self.impostion_tail_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "l2fsbi-drop"):
                                                if (self.l2fsbi_drop is None):
                                                    self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                    self.l2fsbi_drop.parent = self
                                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                return self.l2fsbi_drop

                                            if (child_yang_name == "multicast"):
                                                if (self.multicast is None):
                                                    self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                    self.multicast.parent = self
                                                    self._children_name_map["multicast"] = "multicast"
                                                return self.multicast

                                            if (child_yang_name == "unknown-unicast"):
                                                if (self.unknown_unicast is None):
                                                    self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                    self.unknown_unicast.parent = self
                                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                return self.unknown_unicast

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            self._children_yang_names.add("broadcast-drop")

                                            self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                            self._children_yang_names.add("dai-drop")

                                            self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            self._children_yang_names.add("disposition-mtu-drop")

                                            self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            self._children_yang_names.add("disposition-oo-o-drops")

                                            self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            self._children_yang_names.add("disposition-p2mp-stats")

                                            self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                            self._children_yang_names.add("disposition-stat")

                                            self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            self._children_yang_names.add("disposition-tail-drop")

                                            self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            self._children_yang_names.add("ipsg-drop")

                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._children_yang_names.add("mac-move")

                                            self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                            self._children_yang_names.add("multicast-drop")

                                            self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                            self._children_yang_names.add("received-drops")

                                            self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                            self._children_yang_names.add("unicast-drop")


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "received-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dai-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipsg-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-oo-o-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionP2MpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-p2mp-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mac-move" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.mac_move is not None and self.mac_move.has_data()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                (self.received_drops is not None and self.received_drops.has_data()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.mac_move is not None and self.mac_move.has_operation()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                (self.received_drops is not None and self.received_drops.has_operation()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dispostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast-drop"):
                                                if (self.broadcast_drop is None):
                                                    self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                    self.broadcast_drop.parent = self
                                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                return self.broadcast_drop

                                            if (child_yang_name == "dai-drop"):
                                                if (self.dai_drop is None):
                                                    self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                    self.dai_drop.parent = self
                                                    self._children_name_map["dai_drop"] = "dai-drop"
                                                return self.dai_drop

                                            if (child_yang_name == "disposition-mtu-drop"):
                                                if (self.disposition_mtu_drop is None):
                                                    self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                    self.disposition_mtu_drop.parent = self
                                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                return self.disposition_mtu_drop

                                            if (child_yang_name == "disposition-oo-o-drops"):
                                                if (self.disposition_oo_o_drops is None):
                                                    self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                    self.disposition_oo_o_drops.parent = self
                                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                return self.disposition_oo_o_drops

                                            if (child_yang_name == "disposition-p2mp-stats"):
                                                if (self.disposition_p2mp_stats is None):
                                                    self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                    self.disposition_p2mp_stats.parent = self
                                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                return self.disposition_p2mp_stats

                                            if (child_yang_name == "disposition-stat"):
                                                if (self.disposition_stat is None):
                                                    self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                    self.disposition_stat.parent = self
                                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                                return self.disposition_stat

                                            if (child_yang_name == "disposition-tail-drop"):
                                                if (self.disposition_tail_drop is None):
                                                    self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                    self.disposition_tail_drop.parent = self
                                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                return self.disposition_tail_drop

                                            if (child_yang_name == "ipsg-drop"):
                                                if (self.ipsg_drop is None):
                                                    self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                    self.ipsg_drop.parent = self
                                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                return self.ipsg_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "mac-move"):
                                                if (self.mac_move is None):
                                                    self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                    self.mac_move.parent = self
                                                    self._children_name_map["mac_move"] = "mac-move"
                                                return self.mac_move

                                            if (child_yang_name == "multicast-drop"):
                                                if (self.multicast_drop is None):
                                                    self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                    self.multicast_drop.parent = self
                                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                                return self.multicast_drop

                                            if (child_yang_name == "received-drops"):
                                                if (self.received_drops is None):
                                                    self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                    self.received_drops.parent = self
                                                    self._children_name_map["received_drops"] = "received-drops"
                                                return self.received_drops

                                            if (child_yang_name == "unicast-drop"):
                                                if (self.unicast_drop is None):
                                                    self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                    self.unicast_drop.parent = self
                                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                                return self.unicast_drop

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"

                                            self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                            self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                            self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                            self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bypassed_inbound_sequence_packet",
                                                            "bypassed_out_sequence_packet",
                                                            "sequence_number_expected",
                                                            "sequence_number_sent") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bypassed_inbound_sequence_packet.is_set or
                                                self.bypassed_out_sequence_packet.is_set or
                                                self.sequence_number_expected.is_set or
                                                self.sequence_number_sent.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                self.sequence_number_expected.yfilter != YFilter.not_set or
                                                self.sequence_number_sent.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sequence-number" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                            if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                            if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                            if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bypassed-inbound-sequence-packet"):
                                                self.bypassed_inbound_sequence_packet = value
                                                self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bypassed-out-sequence-packet"):
                                                self.bypassed_out_sequence_packet = value
                                                self.bypassed_out_sequence_packet.value_namespace = name_space
                                                self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-expected"):
                                                self.sequence_number_expected = value
                                                self.sequence_number_expected.value_namespace = name_space
                                                self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-sent"):
                                                self.sequence_number_sent = value
                                                self.sequence_number_sent.value_namespace = name_space
                                                self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                            (self.sequence_number is not None and self.sequence_number.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                            (self.sequence_number is not None and self.sequence_number.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "statistics" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dispostion-stats"):
                                            if (self.dispostion_stats is None):
                                                self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                                self.dispostion_stats.parent = self
                                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            return self.dispostion_stats

                                        if (child_yang_name == "impostion-stats"):
                                            if (self.impostion_stats is None):
                                                self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                                self.impostion_stats.parent = self
                                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                            return self.impostion_stats

                                        if (child_yang_name == "sequence-number"):
                                            if (self.sequence_number is None):
                                                self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                                self.sequence_number.parent = self
                                                self._children_name_map["sequence_number"] = "sequence-number"
                                            return self.sequence_number

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class P2MpPw(Entity):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__init__()

                                        self.yang_name = "p2mp-pw"
                                        self.yang_parent_name = "pseudowire"

                                        self.local_available = YLeaf(YType.boolean, "local-available")

                                        self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                        self.local_flags = YLeaf(YType.uint8, "local-flags")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                        self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                        self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                        self.remote_available = YLeaf(YType.boolean, "remote-available")

                                        self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                        self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                        self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                        self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_available",
                                                        "local_extended_tunnel_id",
                                                        "local_flags",
                                                        "local_label",
                                                        "local_p2mp_id",
                                                        "local_ptree_type",
                                                        "local_tunnel_id",
                                                        "remote_available",
                                                        "remote_extended_tunnel_id",
                                                        "remote_flags",
                                                        "remote_label",
                                                        "remote_p2mp_id",
                                                        "remote_ptree_type",
                                                        "remote_tunnel_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_available.is_set or
                                            self.local_extended_tunnel_id.is_set or
                                            self.local_flags.is_set or
                                            self.local_label.is_set or
                                            self.local_p2mp_id.is_set or
                                            self.local_ptree_type.is_set or
                                            self.local_tunnel_id.is_set or
                                            self.remote_available.is_set or
                                            self.remote_extended_tunnel_id.is_set or
                                            self.remote_flags.is_set or
                                            self.remote_label.is_set or
                                            self.remote_p2mp_id.is_set or
                                            self.remote_ptree_type.is_set or
                                            self.remote_tunnel_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_available.yfilter != YFilter.not_set or
                                            self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                            self.local_flags.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_p2mp_id.yfilter != YFilter.not_set or
                                            self.local_ptree_type.yfilter != YFilter.not_set or
                                            self.local_tunnel_id.yfilter != YFilter.not_set or
                                            self.remote_available.yfilter != YFilter.not_set or
                                            self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                            self.remote_flags.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_p2mp_id.yfilter != YFilter.not_set or
                                            self.remote_ptree_type.yfilter != YFilter.not_set or
                                            self.remote_tunnel_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "p2mp-pw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_available.get_name_leafdata())
                                        if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                        if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_flags.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                        if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                        if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                        if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_available.get_name_leafdata())
                                        if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                        if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                        if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                        if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-available"):
                                            self.local_available = value
                                            self.local_available.value_namespace = name_space
                                            self.local_available.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-extended-tunnel-id"):
                                            self.local_extended_tunnel_id = value
                                            self.local_extended_tunnel_id.value_namespace = name_space
                                            self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-flags"):
                                            self.local_flags = value
                                            self.local_flags.value_namespace = name_space
                                            self.local_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-p2mp-id"):
                                            self.local_p2mp_id = value
                                            self.local_p2mp_id.value_namespace = name_space
                                            self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ptree-type"):
                                            self.local_ptree_type = value
                                            self.local_ptree_type.value_namespace = name_space
                                            self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-tunnel-id"):
                                            self.local_tunnel_id = value
                                            self.local_tunnel_id.value_namespace = name_space
                                            self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-available"):
                                            self.remote_available = value
                                            self.remote_available.value_namespace = name_space
                                            self.remote_available.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-extended-tunnel-id"):
                                            self.remote_extended_tunnel_id = value
                                            self.remote_extended_tunnel_id.value_namespace = name_space
                                            self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-flags"):
                                            self.remote_flags = value
                                            self.remote_flags.value_namespace = name_space
                                            self.remote_flags.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-p2mp-id"):
                                            self.remote_p2mp_id = value
                                            self.remote_p2mp_id.value_namespace = name_space
                                            self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ptree-type"):
                                            self.remote_ptree_type = value
                                            self.remote_ptree_type.value_namespace = name_space
                                            self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-tunnel-id"):
                                            self.remote_tunnel_id = value
                                            self.remote_tunnel_id.value_namespace = name_space
                                            self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.ad_method.is_set or
                                        self.ad_remote_down.is_set or
                                        self.admited_bw.is_set or
                                        self.auto_discovery.is_set or
                                        self.backup_active.is_set or
                                        self.backup_force_active.is_set or
                                        self.backup_pw.is_set or
                                        self.bitrate_mismatched.is_set or
                                        self.bridge_pw_type_mismatch.is_set or
                                        self.cas_mismatched.is_set or
                                        self.diff_ts_mismatched.is_set or
                                        self.disable_delay.is_set or
                                        self.disable_never.is_set or
                                        self.evpn_src_acid.is_set or
                                        self.fe_ctype.is_set or
                                        self.forward_class.is_set or
                                        self.freq_mismatched.is_set or
                                        self.illegal_control_word.is_set or
                                        self.imposed_vlan_id.is_set or
                                        self.interworking.is_set or
                                        self.ipv6_local_source_address.is_set or
                                        self.is_evpnvpws_type.is_set or
                                        self.is_flow_label_static.is_set or
                                        self.is_multi_segment_pseudowire.is_set or
                                        self.is_partially_programmed.is_set or
                                        self.is_pwr_type.is_set or
                                        self.is_vfi.is_set or
                                        self.last_time_status_changed.is_set or
                                        self.last_time_status_down.is_set or
                                        self.ldp_label_advertise_failed.is_set or
                                        self.load_balance.is_set or
                                        self.local_control_word.is_set or
                                        self.local_label_failed.is_set or
                                        self.local_pseudo_wire_type.is_set or
                                        self.local_source_address.is_set or
                                        self.mac_limit_oper_down.is_set or
                                        self.mtu_mismatched.is_set or
                                        self.not_supported_qinq.is_set or
                                        self.num_ma_cwithdraw_msg_received.is_set or
                                        self.number_ma_cwithdraw_message_sent.is_set or
                                        self.out_of_memory_state.is_set or
                                        self.payload_bytes_mismatched.is_set or
                                        self.payload_type_mismatched.is_set or
                                        self.preferred_path_disable_fallback.is_set or
                                        self.primary_peer_id.is_set or
                                        self.primary_pseudo_wire_id.is_set or
                                        self.primary_pw.is_set or
                                        self.protocol.is_set or
                                        self.pseudo_wire_id.is_set or
                                        self.pseudo_wire_state.is_set or
                                        self.pseudo_wire_type_mismatched.is_set or
                                        self.pw_class_name.is_set or
                                        self.pw_flow_label_code17_disabled.is_set or
                                        self.pw_flow_label_type.is_set or
                                        self.pw_flow_label_type_cfg.is_set or
                                        self.pw_redundancy_initial_delay.is_set or
                                        self.pw_redundancy_one_way.is_set or
                                        self.pw_status_use.is_set or
                                        self.pwlsd_rewrite_failed.is_set or
                                        self.remote_control_word.is_set or
                                        self.remote_label_failed.is_set or
                                        self.remote_pseudo_wire_type.is_set or
                                        self.required_bw.is_set or
                                        self.resync_enabled.is_set or
                                        self.resync_threshold.is_set or
                                        self.rtp_mismatched.is_set or
                                        self.sequencing_type.is_set or
                                        self.shutdown.is_set or
                                        self.sig_pkts_mismatched.is_set or
                                        self.ssrc_mismatched.is_set or
                                        self.state.is_set or
                                        self.table_policy_name.is_set or
                                        self.tag_rewrite.is_set or
                                        self.time_created.is_set or
                                        self.time_elapsed_creation.is_set or
                                        self.time_elapsed_status_changed.is_set or
                                        self.time_elapsed_status_down.is_set or
                                        self.transport_lsp_down.is_set or
                                        self.xconnect_id.is_set or
                                        (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                        (self.local_interface is not None and self.local_interface.has_data()) or
                                        (self.local_signalling is not None and self.local_signalling.has_data()) or
                                        (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                        (self.peer_id is not None and self.peer_id.has_data()) or
                                        (self.preferred_path is not None and self.preferred_path.has_data()) or
                                        (self.remote_interface is not None and self.remote_interface.has_data()) or
                                        (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                        (self.statistics is not None and self.statistics.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ad_method.yfilter != YFilter.not_set or
                                        self.ad_remote_down.yfilter != YFilter.not_set or
                                        self.admited_bw.yfilter != YFilter.not_set or
                                        self.auto_discovery.yfilter != YFilter.not_set or
                                        self.backup_active.yfilter != YFilter.not_set or
                                        self.backup_force_active.yfilter != YFilter.not_set or
                                        self.backup_pw.yfilter != YFilter.not_set or
                                        self.bitrate_mismatched.yfilter != YFilter.not_set or
                                        self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                        self.cas_mismatched.yfilter != YFilter.not_set or
                                        self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                        self.disable_delay.yfilter != YFilter.not_set or
                                        self.disable_never.yfilter != YFilter.not_set or
                                        self.evpn_src_acid.yfilter != YFilter.not_set or
                                        self.fe_ctype.yfilter != YFilter.not_set or
                                        self.forward_class.yfilter != YFilter.not_set or
                                        self.freq_mismatched.yfilter != YFilter.not_set or
                                        self.illegal_control_word.yfilter != YFilter.not_set or
                                        self.imposed_vlan_id.yfilter != YFilter.not_set or
                                        self.interworking.yfilter != YFilter.not_set or
                                        self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                        self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                        self.is_flow_label_static.yfilter != YFilter.not_set or
                                        self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                        self.is_partially_programmed.yfilter != YFilter.not_set or
                                        self.is_pwr_type.yfilter != YFilter.not_set or
                                        self.is_vfi.yfilter != YFilter.not_set or
                                        self.last_time_status_changed.yfilter != YFilter.not_set or
                                        self.last_time_status_down.yfilter != YFilter.not_set or
                                        self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                        self.load_balance.yfilter != YFilter.not_set or
                                        self.local_control_word.yfilter != YFilter.not_set or
                                        self.local_label_failed.yfilter != YFilter.not_set or
                                        self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                        self.local_source_address.yfilter != YFilter.not_set or
                                        self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                        self.mtu_mismatched.yfilter != YFilter.not_set or
                                        self.not_supported_qinq.yfilter != YFilter.not_set or
                                        self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                        self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                        self.out_of_memory_state.yfilter != YFilter.not_set or
                                        self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                        self.payload_type_mismatched.yfilter != YFilter.not_set or
                                        self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                        self.primary_peer_id.yfilter != YFilter.not_set or
                                        self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.primary_pw.yfilter != YFilter.not_set or
                                        self.protocol.yfilter != YFilter.not_set or
                                        self.pseudo_wire_id.yfilter != YFilter.not_set or
                                        self.pseudo_wire_state.yfilter != YFilter.not_set or
                                        self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                        self.pw_class_name.yfilter != YFilter.not_set or
                                        self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                        self.pw_flow_label_type.yfilter != YFilter.not_set or
                                        self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                        self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                        self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                        self.pw_status_use.yfilter != YFilter.not_set or
                                        self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.remote_control_word.yfilter != YFilter.not_set or
                                        self.remote_label_failed.yfilter != YFilter.not_set or
                                        self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                        self.required_bw.yfilter != YFilter.not_set or
                                        self.resync_enabled.yfilter != YFilter.not_set or
                                        self.resync_threshold.yfilter != YFilter.not_set or
                                        self.rtp_mismatched.yfilter != YFilter.not_set or
                                        self.sequencing_type.yfilter != YFilter.not_set or
                                        self.shutdown.yfilter != YFilter.not_set or
                                        self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                        self.ssrc_mismatched.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.table_policy_name.yfilter != YFilter.not_set or
                                        self.tag_rewrite.yfilter != YFilter.not_set or
                                        self.time_created.yfilter != YFilter.not_set or
                                        self.time_elapsed_creation.yfilter != YFilter.not_set or
                                        self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                        self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                        self.transport_lsp_down.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                        (self.local_interface is not None and self.local_interface.has_operation()) or
                                        (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                        (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                        (self.peer_id is not None and self.peer_id.has_operation()) or
                                        (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                        (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                        (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                        (self.statistics is not None and self.statistics.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_method.get_name_leafdata())
                                    if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                    if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                    if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                    if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_active.get_name_leafdata())
                                    if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                    if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                    if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                    if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                    if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                    if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                    if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                    if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.disable_never.get_name_leafdata())
                                    if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                    if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                    if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.forward_class.get_name_leafdata())
                                    if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                    if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                    if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                    if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interworking.get_name_leafdata())
                                    if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                    if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                    if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                    if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                    if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                    if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                    if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                    if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                    if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                    if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                    if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.load_balance.get_name_leafdata())
                                    if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                    if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                    if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                    if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                    if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                    if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                    if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                    if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                    if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                    if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                    if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                    if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                    if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                    if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                    if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                    if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol.get_name_leafdata())
                                    if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                    if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                    if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                    if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                    if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                    if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                    if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                    if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                    if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                    if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                    if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                    if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                    if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                    if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                    if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.required_bw.get_name_leafdata())
                                    if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                    if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                    if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                    if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                                    if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                    if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                    if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                    if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_created.get_name_leafdata())
                                    if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                    if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                    if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                    if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "encapsulation-info"):
                                        if (self.encapsulation_info is None):
                                            self.encapsulation_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                            self.encapsulation_info.parent = self
                                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                        return self.encapsulation_info

                                    if (child_yang_name == "local-interface"):
                                        if (self.local_interface is None):
                                            self.local_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                            self.local_interface.parent = self
                                            self._children_name_map["local_interface"] = "local-interface"
                                        return self.local_interface

                                    if (child_yang_name == "local-signalling"):
                                        if (self.local_signalling is None):
                                            self.local_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                            self.local_signalling.parent = self
                                            self._children_name_map["local_signalling"] = "local-signalling"
                                        return self.local_signalling

                                    if (child_yang_name == "p2mp-pw"):
                                        if (self.p2mp_pw is None):
                                            self.p2mp_pw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                                            self.p2mp_pw.parent = self
                                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                        return self.p2mp_pw

                                    if (child_yang_name == "peer-id"):
                                        if (self.peer_id is None):
                                            self.peer_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                            self.peer_id.parent = self
                                            self._children_name_map["peer_id"] = "peer-id"
                                        return self.peer_id

                                    if (child_yang_name == "preferred-path"):
                                        if (self.preferred_path is None):
                                            self.preferred_path = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                            self.preferred_path.parent = self
                                            self._children_name_map["preferred_path"] = "preferred-path"
                                        return self.preferred_path

                                    if (child_yang_name == "remote-interface"):
                                        if (self.remote_interface is None):
                                            self.remote_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                            self.remote_interface.parent = self
                                            self._children_name_map["remote_interface"] = "remote-interface"
                                        return self.remote_interface

                                    if (child_yang_name == "remote-signalling"):
                                        if (self.remote_signalling is None):
                                            self.remote_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                            self.remote_signalling.parent = self
                                            self._children_name_map["remote_signalling"] = "remote-signalling"
                                        return self.remote_signalling

                                    if (child_yang_name == "statistics"):
                                        if (self.statistics is None):
                                            self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                            self.statistics.parent = self
                                            self._children_name_map["statistics"] = "statistics"
                                        return self.statistics

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ad-method"):
                                        self.ad_method = value
                                        self.ad_method.value_namespace = name_space
                                        self.ad_method.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ad-remote-down"):
                                        self.ad_remote_down = value
                                        self.ad_remote_down.value_namespace = name_space
                                        self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "admited-bw"):
                                        self.admited_bw = value
                                        self.admited_bw.value_namespace = name_space
                                        self.admited_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "auto-discovery"):
                                        self.auto_discovery = value
                                        self.auto_discovery.value_namespace = name_space
                                        self.auto_discovery.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-active"):
                                        self.backup_active = value
                                        self.backup_active.value_namespace = name_space
                                        self.backup_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-force-active"):
                                        self.backup_force_active = value
                                        self.backup_force_active.value_namespace = name_space
                                        self.backup_force_active.value_namespace_prefix = name_space_prefix
                                    if(value_path == "backup-pw"):
                                        self.backup_pw = value
                                        self.backup_pw.value_namespace = name_space
                                        self.backup_pw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bitrate-mismatched"):
                                        self.bitrate_mismatched = value
                                        self.bitrate_mismatched.value_namespace = name_space
                                        self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bridge-pw-type-mismatch"):
                                        self.bridge_pw_type_mismatch = value
                                        self.bridge_pw_type_mismatch.value_namespace = name_space
                                        self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cas-mismatched"):
                                        self.cas_mismatched = value
                                        self.cas_mismatched.value_namespace = name_space
                                        self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "diff-ts-mismatched"):
                                        self.diff_ts_mismatched = value
                                        self.diff_ts_mismatched.value_namespace = name_space
                                        self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-delay"):
                                        self.disable_delay = value
                                        self.disable_delay.value_namespace = name_space
                                        self.disable_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "disable-never"):
                                        self.disable_never = value
                                        self.disable_never.value_namespace = name_space
                                        self.disable_never.value_namespace_prefix = name_space_prefix
                                    if(value_path == "evpn-src-acid"):
                                        self.evpn_src_acid = value
                                        self.evpn_src_acid.value_namespace = name_space
                                        self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fe-ctype"):
                                        self.fe_ctype = value
                                        self.fe_ctype.value_namespace = name_space
                                        self.fe_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "forward-class"):
                                        self.forward_class = value
                                        self.forward_class.value_namespace = name_space
                                        self.forward_class.value_namespace_prefix = name_space_prefix
                                    if(value_path == "freq-mismatched"):
                                        self.freq_mismatched = value
                                        self.freq_mismatched.value_namespace = name_space
                                        self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "illegal-control-word"):
                                        self.illegal_control_word = value
                                        self.illegal_control_word.value_namespace = name_space
                                        self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "imposed-vlan-id"):
                                        self.imposed_vlan_id = value
                                        self.imposed_vlan_id.value_namespace = name_space
                                        self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interworking"):
                                        self.interworking = value
                                        self.interworking.value_namespace = name_space
                                        self.interworking.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-local-source-address"):
                                        self.ipv6_local_source_address = value
                                        self.ipv6_local_source_address.value_namespace = name_space
                                        self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-evpnvpws-type"):
                                        self.is_evpnvpws_type = value
                                        self.is_evpnvpws_type.value_namespace = name_space
                                        self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-flow-label-static"):
                                        self.is_flow_label_static = value
                                        self.is_flow_label_static.value_namespace = name_space
                                        self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-multi-segment-pseudowire"):
                                        self.is_multi_segment_pseudowire = value
                                        self.is_multi_segment_pseudowire.value_namespace = name_space
                                        self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-partially-programmed"):
                                        self.is_partially_programmed = value
                                        self.is_partially_programmed.value_namespace = name_space
                                        self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-pwr-type"):
                                        self.is_pwr_type = value
                                        self.is_pwr_type.value_namespace = name_space
                                        self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-vfi"):
                                        self.is_vfi = value
                                        self.is_vfi.value_namespace = name_space
                                        self.is_vfi.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-time-status-changed"):
                                        self.last_time_status_changed = value
                                        self.last_time_status_changed.value_namespace = name_space
                                        self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-time-status-down"):
                                        self.last_time_status_down = value
                                        self.last_time_status_down.value_namespace = name_space
                                        self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertise-failed"):
                                        self.ldp_label_advertise_failed = value
                                        self.ldp_label_advertise_failed.value_namespace = name_space
                                        self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "load-balance"):
                                        self.load_balance = value
                                        self.load_balance.value_namespace = name_space
                                        self.load_balance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-control-word"):
                                        self.local_control_word = value
                                        self.local_control_word.value_namespace = name_space
                                        self.local_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label-failed"):
                                        self.local_label_failed = value
                                        self.local_label_failed.value_namespace = name_space
                                        self.local_label_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-pseudo-wire-type"):
                                        self.local_pseudo_wire_type = value
                                        self.local_pseudo_wire_type.value_namespace = name_space
                                        self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-source-address"):
                                        self.local_source_address = value
                                        self.local_source_address.value_namespace = name_space
                                        self.local_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-oper-down"):
                                        self.mac_limit_oper_down = value
                                        self.mac_limit_oper_down.value_namespace = name_space
                                        self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-mismatched"):
                                        self.mtu_mismatched = value
                                        self.mtu_mismatched.value_namespace = name_space
                                        self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "not-supported-qinq"):
                                        self.not_supported_qinq = value
                                        self.not_supported_qinq.value_namespace = name_space
                                        self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                    if(value_path == "num-ma-cwithdraw-msg-received"):
                                        self.num_ma_cwithdraw_msg_received = value
                                        self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                        self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                    if(value_path == "number-ma-cwithdraw-message-sent"):
                                        self.number_ma_cwithdraw_message_sent = value
                                        self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                        self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                    if(value_path == "out-of-memory-state"):
                                        self.out_of_memory_state = value
                                        self.out_of_memory_state.value_namespace = name_space
                                        self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes-mismatched"):
                                        self.payload_bytes_mismatched = value
                                        self.payload_bytes_mismatched.value_namespace = name_space
                                        self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-type-mismatched"):
                                        self.payload_type_mismatched = value
                                        self.payload_type_mismatched.value_namespace = name_space
                                        self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "preferred-path-disable-fallback"):
                                        self.preferred_path_disable_fallback = value
                                        self.preferred_path_disable_fallback.value_namespace = name_space
                                        self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-peer-id"):
                                        self.primary_peer_id = value
                                        self.primary_peer_id.value_namespace = name_space
                                        self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-pseudo-wire-id"):
                                        self.primary_pseudo_wire_id = value
                                        self.primary_pseudo_wire_id.value_namespace = name_space
                                        self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "primary-pw"):
                                        self.primary_pw = value
                                        self.primary_pw.value_namespace = name_space
                                        self.primary_pw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol"):
                                        self.protocol = value
                                        self.protocol.value_namespace = name_space
                                        self.protocol.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-id"):
                                        self.pseudo_wire_id = value
                                        self.pseudo_wire_id.value_namespace = name_space
                                        self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-state"):
                                        self.pseudo_wire_state = value
                                        self.pseudo_wire_state.value_namespace = name_space
                                        self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pseudo-wire-type-mismatched"):
                                        self.pseudo_wire_type_mismatched = value
                                        self.pseudo_wire_type_mismatched.value_namespace = name_space
                                        self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-class-name"):
                                        self.pw_class_name = value
                                        self.pw_class_name.value_namespace = name_space
                                        self.pw_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-code17-disabled"):
                                        self.pw_flow_label_code17_disabled = value
                                        self.pw_flow_label_code17_disabled.value_namespace = name_space
                                        self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-type"):
                                        self.pw_flow_label_type = value
                                        self.pw_flow_label_type.value_namespace = name_space
                                        self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-flow-label-type-cfg"):
                                        self.pw_flow_label_type_cfg = value
                                        self.pw_flow_label_type_cfg.value_namespace = name_space
                                        self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-redundancy-initial-delay"):
                                        self.pw_redundancy_initial_delay = value
                                        self.pw_redundancy_initial_delay.value_namespace = name_space
                                        self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-redundancy-one-way"):
                                        self.pw_redundancy_one_way = value
                                        self.pw_redundancy_one_way.value_namespace = name_space
                                        self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-status-use"):
                                        self.pw_status_use = value
                                        self.pw_status_use.value_namespace = name_space
                                        self.pw_status_use.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pwlsd-rewrite-failed"):
                                        self.pwlsd_rewrite_failed = value
                                        self.pwlsd_rewrite_failed.value_namespace = name_space
                                        self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-control-word"):
                                        self.remote_control_word = value
                                        self.remote_control_word.value_namespace = name_space
                                        self.remote_control_word.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label-failed"):
                                        self.remote_label_failed = value
                                        self.remote_label_failed.value_namespace = name_space
                                        self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-pseudo-wire-type"):
                                        self.remote_pseudo_wire_type = value
                                        self.remote_pseudo_wire_type.value_namespace = name_space
                                        self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "required-bw"):
                                        self.required_bw = value
                                        self.required_bw.value_namespace = name_space
                                        self.required_bw.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resync-enabled"):
                                        self.resync_enabled = value
                                        self.resync_enabled.value_namespace = name_space
                                        self.resync_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "resync-threshold"):
                                        self.resync_threshold = value
                                        self.resync_threshold.value_namespace = name_space
                                        self.resync_threshold.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rtp-mismatched"):
                                        self.rtp_mismatched = value
                                        self.rtp_mismatched.value_namespace = name_space
                                        self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequencing-type"):
                                        self.sequencing_type = value
                                        self.sequencing_type.value_namespace = name_space
                                        self.sequencing_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "shutdown"):
                                        self.shutdown = value
                                        self.shutdown.value_namespace = name_space
                                        self.shutdown.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sig-pkts-mismatched"):
                                        self.sig_pkts_mismatched = value
                                        self.sig_pkts_mismatched.value_namespace = name_space
                                        self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ssrc-mismatched"):
                                        self.ssrc_mismatched = value
                                        self.ssrc_mismatched.value_namespace = name_space
                                        self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "table-policy-name"):
                                        self.table_policy_name = value
                                        self.table_policy_name.value_namespace = name_space
                                        self.table_policy_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tag-rewrite"):
                                        self.tag_rewrite = value
                                        self.tag_rewrite.value_namespace = name_space
                                        self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-created"):
                                        self.time_created = value
                                        self.time_created.value_namespace = name_space
                                        self.time_created.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-creation"):
                                        self.time_elapsed_creation = value
                                        self.time_elapsed_creation.value_namespace = name_space
                                        self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-status-changed"):
                                        self.time_elapsed_status_changed = value
                                        self.time_elapsed_status_changed.value_namespace = name_space
                                        self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-elapsed-status-down"):
                                        self.time_elapsed_status_down = value
                                        self.time_elapsed_status_down.value_namespace = name_space
                                        self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transport-lsp-down"):
                                        self.transport_lsp_down = value
                                        self.transport_lsp_down.value_namespace = name_space
                                        self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-access-pw"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-access-pw"

                                    self.address = YLeaf(YType.str, "address")

                                    self.bmac = YLeaf(YType.str, "bmac")

                                    self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "bmac",
                                                    "next_hop_ip") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.bmac.is_set or
                                        self.next_hop_ip.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.bmac.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "static-mac" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bmac.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bmac"):
                                        self.bmac = value
                                        self.bmac.value_namespace = name_space
                                        self.bmac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.static_mac:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.is_access.is_set or
                                    self.neighbor.is_set or
                                    self.pseudowire_id.is_set or
                                    (self.pseudowire is not None and self.pseudowire.has_data()) or
                                    (self.security_parameters is not None and self.security_parameters.has_data()))

                            def has_operation(self):
                                for c in self.static_mac:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_access.yfilter != YFilter.not_set or
                                    self.neighbor.yfilter != YFilter.not_set or
                                    self.pseudowire_id.yfilter != YFilter.not_set or
                                    (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bridge-access-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_access.get_name_leafdata())
                                if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor.get_name_leafdata())
                                if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudowire_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "pseudowire"):
                                    if (self.pseudowire is None):
                                        self.pseudowire = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                                        self.pseudowire.parent = self
                                        self._children_name_map["pseudowire"] = "pseudowire"
                                    return self.pseudowire

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                if (child_yang_name == "static-mac"):
                                    for c in self.static_mac:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.static_mac.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-access"):
                                    self.is_access = value
                                    self.is_access.value_namespace = name_space
                                    self.is_access.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor"):
                                    self.neighbor = value
                                    self.neighbor.value_namespace = name_space
                                    self.neighbor.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudowire-id"):
                                    self.pseudowire_id = value
                                    self.pseudowire_id.value_namespace = name_space
                                    self.pseudowire_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bridge_access_pw:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bridge_access_pw:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-access-pws" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bridge-access-pw"):
                                for c in self.bridge_access_pw:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bridge_access_pw.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-access-pw"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BridgeDomainInfo(Entity):
                        """
                        VPLS Bridge Domain Information
                        
                        .. attribute:: acpwup
                        
                        	Number of bridge ports (AC,PW) which are up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_
                        
                        	BGP AS number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_access_vfi
                        
                        	Access Virtual Forwarding Interfaces
                        	**type**\: list of    :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                        
                        .. attribute:: bridge_coupled_state
                        
                        	Bridge\-domain coupled state
                        	**type**\:   :py:class:`L2VpnBridgeCoupledState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeCoupledState>`
                        
                        .. attribute:: bridge_description
                        
                        	Human\-readable bridge\-domain description
                        	**type**\:  str
                        
                        .. attribute:: bridge_domain_id
                        
                        	Identification number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_internal_msti
                        
                        	Bridge\-domain internal msti
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_msti
                        
                        	Bridge\-domain msti
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_mtu
                        
                        	Maximum transmission unit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_name
                        
                        	Bridge\-domain name
                        	**type**\:  str
                        
                        .. attribute:: bridge_shg_id
                        
                        	Bridge\-domain shgid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_state
                        
                        	Bridge\-domain state
                        	**type**\:   :py:class:`L2VpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeState>`
                        
                        .. attribute:: bridge_type
                        
                        	Bridge\-domain type
                        	**type**\:   :py:class:`L2VpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridge>`
                        
                        .. attribute:: bridge_vfi
                        
                        	Virtual Forwarding Interfaces
                        	**type**\: list of    :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                        
                        .. attribute:: configured
                        
                        	Bridge\-domain is configured
                        	**type**\:  bool
                        
                        .. attribute:: disposition_bytecount
                        
                        	EVPN Disposition Byte Count
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: disposition_pkt_count
                        
                        	EVPN Disposition Packet Count
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: evi
                        
                        	E\-VPN id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_parameters
                        
                        	EVPN parameters
                        	**type**\:   :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                        
                        .. attribute:: flodd_group_id_down
                        
                        	Oper down because no FGID
                        	**type**\:  bool
                        
                        .. attribute:: group_name
                        
                        	Group name
                        	**type**\:  str
                        
                        .. attribute:: imposition_byte_count
                        
                        	EVPN Imposition Byte Count
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: imposition_pkt_count
                        
                        	EVPN Imposition Packet Count
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_bridge_partially_programmed
                        
                        	Bridge is partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_rd_configured
                        
                        	Config or Auto
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the bridge domain status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: mac_filter
                        
                        	MAC addresses for filtering
                        	**type**\: list of    :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                        
                        .. attribute:: mac_limit_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mac_withdraw
                        
                        	MAC withdraw enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_withdraw_access
                        
                        	MAC Access PW withdraw enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_withdraw_option
                        
                        	Event on which MAC withdraw is sent
                        	**type**\:   :py:class:`L2VpnBagMacWithdrawOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacWithdrawOption>`
                        
                        .. attribute:: mac_withdraw_relay
                        
                        	MAC Access PW withdraw relaying from access to access enabled
                        	**type**\:  bool
                        
                        .. attribute:: num_vn_is
                        
                        	Number of VNIs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_vn_is_up
                        
                        	Number of VNIs up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_a_cs
                        
                        	Number of attachment circuits
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_a_cs_up
                        
                        	Number of attachment circuits up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_access_vf_is
                        
                        	Number of Access VFIs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_p_ws_up
                        
                        	Number of pseudowires up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pb_bs
                        
                        	Number of pbbs
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: number_pb_bs_up
                        
                        	Number of pbbs up
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_vf_is
                        
                        	Number of virtual forwarding interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                        
                        	nV Satellite Offload IPv4 Multicast Disabled
                        	**type**\:  bool
                        
                        .. attribute:: p2mp_enabled
                        
                        	P2MP Enabled on this Bridge Domain
                        	**type**\:  bool
                        
                        .. attribute:: partially_programmed_a_cs
                        
                        	Number of attachment circuits partially programmed
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: partially_programmed_pseudowires
                        
                        	Number of pseudowires partially programmed
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pbb_parameters
                        
                        	PBB parameters
                        	**type**\:   :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                        
                        .. attribute:: rd
                        
                        	Route Distinguisher
                        	**type**\:   :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                        
                        .. attribute:: security_parameters
                        
                        	Security parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                        
                        .. attribute:: shutdown
                        
                        	Administratively disabled
                        	**type**\:  bool
                        
                        .. attribute:: standby_pseudowires
                        
                        	Number of pseudowires standby
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the bridge domain was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: vine_fsm_state
                        
                        	VNI, IRB, Native\-Evpn state
                        	**type**\:  str
                        
                        .. attribute:: vni_parameters
                        
                        	VNI parameters
                        	**type**\:   :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__init__()

                            self.yang_name = "bridge-domain-info"
                            self.yang_parent_name = "bridge-domain"

                            self.acpwup = YLeaf(YType.uint32, "acpwup")

                            self.as_ = YLeaf(YType.uint32, "as")

                            self.bridge_coupled_state = YLeaf(YType.enumeration, "bridge-coupled-state")

                            self.bridge_description = YLeaf(YType.str, "bridge-description")

                            self.bridge_domain_id = YLeaf(YType.uint32, "bridge-domain-id")

                            self.bridge_internal_msti = YLeaf(YType.uint32, "bridge-internal-msti")

                            self.bridge_msti = YLeaf(YType.uint32, "bridge-msti")

                            self.bridge_mtu = YLeaf(YType.uint32, "bridge-mtu")

                            self.bridge_name = YLeaf(YType.str, "bridge-name")

                            self.bridge_shg_id = YLeaf(YType.uint32, "bridge-shg-id")

                            self.bridge_state = YLeaf(YType.enumeration, "bridge-state")

                            self.bridge_type = YLeaf(YType.enumeration, "bridge-type")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.disposition_bytecount = YLeaf(YType.uint64, "disposition-bytecount")

                            self.disposition_pkt_count = YLeaf(YType.uint64, "disposition-pkt-count")

                            self.evi = YLeaf(YType.uint32, "evi")

                            self.flodd_group_id_down = YLeaf(YType.boolean, "flodd-group-id-down")

                            self.group_name = YLeaf(YType.str, "group-name")

                            self.imposition_byte_count = YLeaf(YType.uint64, "imposition-byte-count")

                            self.imposition_pkt_count = YLeaf(YType.uint64, "imposition-pkt-count")

                            self.is_bridge_partially_programmed = YLeaf(YType.boolean, "is-bridge-partially-programmed")

                            self.is_rd_configured = YLeaf(YType.boolean, "is-rd-configured")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.mac_limit_down = YLeaf(YType.boolean, "mac-limit-down")

                            self.mac_withdraw = YLeaf(YType.boolean, "mac-withdraw")

                            self.mac_withdraw_access = YLeaf(YType.boolean, "mac-withdraw-access")

                            self.mac_withdraw_option = YLeaf(YType.enumeration, "mac-withdraw-option")

                            self.mac_withdraw_relay = YLeaf(YType.boolean, "mac-withdraw-relay")

                            self.num_vn_is = YLeaf(YType.uint32, "num-vn-is")

                            self.num_vn_is_up = YLeaf(YType.uint32, "num-vn-is-up")

                            self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                            self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                            self.number_access_vf_is = YLeaf(YType.uint32, "number-access-vf-is")

                            self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                            self.number_pb_bs = YLeaf(YType.uint8, "number-pb-bs")

                            self.number_pb_bs_up = YLeaf(YType.uint8, "number-pb-bs-up")

                            self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                            self.number_vf_is = YLeaf(YType.uint32, "number-vf-is")

                            self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                            self.p2mp_enabled = YLeaf(YType.boolean, "p2mp-enabled")

                            self.partially_programmed_a_cs = YLeaf(YType.uint32, "partially-programmed-a-cs")

                            self.partially_programmed_pseudowires = YLeaf(YType.uint32, "partially-programmed-pseudowires")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.standby_pseudowires = YLeaf(YType.uint32, "standby-pseudowires")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.vine_fsm_state = YLeaf(YType.str, "vine-fsm-state")

                            self.evpn_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                            self.evpn_parameters.parent = self
                            self._children_name_map["evpn_parameters"] = "evpn-parameters"
                            self._children_yang_names.add("evpn-parameters")

                            self.pbb_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                            self.pbb_parameters.parent = self
                            self._children_name_map["pbb_parameters"] = "pbb-parameters"
                            self._children_yang_names.add("pbb-parameters")

                            self.rd = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                            self.rd.parent = self
                            self._children_name_map["rd"] = "rd"
                            self._children_yang_names.add("rd")

                            self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                            self._children_yang_names.add("security-parameters")

                            self.vni_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                            self.vni_parameters.parent = self
                            self._children_name_map["vni_parameters"] = "vni-parameters"
                            self._children_yang_names.add("vni-parameters")

                            self.bridge_access_vfi = YList(self)
                            self.bridge_vfi = YList(self)
                            self.mac_filter = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("acpwup",
                                            "as_",
                                            "bridge_coupled_state",
                                            "bridge_description",
                                            "bridge_domain_id",
                                            "bridge_internal_msti",
                                            "bridge_msti",
                                            "bridge_mtu",
                                            "bridge_name",
                                            "bridge_shg_id",
                                            "bridge_state",
                                            "bridge_type",
                                            "configured",
                                            "disposition_bytecount",
                                            "disposition_pkt_count",
                                            "evi",
                                            "flodd_group_id_down",
                                            "group_name",
                                            "imposition_byte_count",
                                            "imposition_pkt_count",
                                            "is_bridge_partially_programmed",
                                            "is_rd_configured",
                                            "last_time_status_changed",
                                            "load_balance",
                                            "mac_limit_down",
                                            "mac_withdraw",
                                            "mac_withdraw_access",
                                            "mac_withdraw_option",
                                            "mac_withdraw_relay",
                                            "num_vn_is",
                                            "num_vn_is_up",
                                            "number_a_cs",
                                            "number_a_cs_up",
                                            "number_access_vf_is",
                                            "number_p_ws_up",
                                            "number_pb_bs",
                                            "number_pb_bs_up",
                                            "number_pseudowires",
                                            "number_vf_is",
                                            "nv_satellite_offload_ipv4_multicast_disabled",
                                            "p2mp_enabled",
                                            "partially_programmed_a_cs",
                                            "partially_programmed_pseudowires",
                                            "shutdown",
                                            "standby_pseudowires",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "vine_fsm_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__setattr__(name, value)


                        class SecurityParameters(Entity):
                            """
                            Security parameters
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dai_address_validation_mask
                            
                            	DAI Address Validation mask
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dhcpv4_profile_name
                            
                            	DHCPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: dhcpv4_snoop
                            
                            	DHCPv4 Snoop Status
                            	**type**\:  bool
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Flooding unknown unicast enabled
                            	**type**\:  bool
                            
                            .. attribute:: flood_uu_disabled_mac_limit_action
                            
                            	Flooding of unknown\-unicast disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_disabled
                            
                            	IGMPv4 Disabled
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_profile_name
                            
                            	IGMPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                            
                            	Is DAI Dstination MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                            
                            	Is DAI IPv4 Addr Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_source_guard_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                            
                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: learn_disabled_mac_limit_action
                            
                            	Learning disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_mode
                            
                            	MAC Aging Mode
                            	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: mac_flooding
                            
                            	MAC flooding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning
                            
                            	MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC address limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                            
                            .. attribute:: mac_limit_notification
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                            
                            .. attribute:: mac_limit_reached
                            
                            	MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mac_port_down_flush_enabled
                            
                            	MAC Flush when port goes down
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC Secure Action
                            	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                            
                            .. attribute:: mld_profile_name
                            
                            	MLD Profile Name
                            	**type**\:  str
                            
                            .. attribute:: mmrp_flood_optimization
                            
                            	MMRP Flood Optimization Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: split_horizon_group_id
                            
                            	Split Horizon Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-domain-info"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dai_address_validation_mask",
                                                "dhcpv4_profile_name",
                                                "dhcpv4_snoop",
                                                "flood_unknown_unicast_enabled",
                                                "flood_uu_disabled_mac_limit_action",
                                                "igm_pv4_disabled",
                                                "igm_pv4_profile_name",
                                                "is_dai_addr_validate_destination_mac_enabled",
                                                "is_dai_addr_validate_ipv4_enabled",
                                                "is_dai_addr_validate_source_mac_enabled",
                                                "is_dai_enabled",
                                                "is_dai_logging_enabled",
                                                "is_ip_source_guard_enabled",
                                                "is_ipsg_logging_enabled",
                                                "is_mac_secure_accept_shutdown_enabled",
                                                "is_mac_secure_enabled",
                                                "is_mac_secure_logging_enabled",
                                                "learn_disabled_mac_limit_action",
                                                "mac_aging_mode",
                                                "mac_aging_time",
                                                "mac_flooding",
                                                "mac_learning",
                                                "mac_limit",
                                                "mac_limit_action",
                                                "mac_limit_notification",
                                                "mac_limit_reached",
                                                "mac_port_down_flush_enabled",
                                                "mac_secure_action",
                                                "mld_profile_name",
                                                "mmrp_flood_optimization",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "split_horizon_group_id",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__setattr__(name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dai_address_validation_mask.is_set or
                                    self.dhcpv4_profile_name.is_set or
                                    self.dhcpv4_snoop.is_set or
                                    self.flood_unknown_unicast_enabled.is_set or
                                    self.flood_uu_disabled_mac_limit_action.is_set or
                                    self.igm_pv4_disabled.is_set or
                                    self.igm_pv4_profile_name.is_set or
                                    self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                    self.is_dai_addr_validate_ipv4_enabled.is_set or
                                    self.is_dai_addr_validate_source_mac_enabled.is_set or
                                    self.is_dai_enabled.is_set or
                                    self.is_dai_logging_enabled.is_set or
                                    self.is_ip_source_guard_enabled.is_set or
                                    self.is_ipsg_logging_enabled.is_set or
                                    self.is_mac_secure_accept_shutdown_enabled.is_set or
                                    self.is_mac_secure_enabled.is_set or
                                    self.is_mac_secure_logging_enabled.is_set or
                                    self.learn_disabled_mac_limit_action.is_set or
                                    self.mac_aging_mode.is_set or
                                    self.mac_aging_time.is_set or
                                    self.mac_flooding.is_set or
                                    self.mac_learning.is_set or
                                    self.mac_limit.is_set or
                                    self.mac_limit_action.is_set or
                                    self.mac_limit_notification.is_set or
                                    self.mac_limit_reached.is_set or
                                    self.mac_port_down_flush_enabled.is_set or
                                    self.mac_secure_action.is_set or
                                    self.mld_profile_name.is_set or
                                    self.mmrp_flood_optimization.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.split_horizon_group_id.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                    self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                    self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                    self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                    self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                    self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                    self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                    self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                    self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                    self.mac_aging_mode.yfilter != YFilter.not_set or
                                    self.mac_aging_time.yfilter != YFilter.not_set or
                                    self.mac_flooding.yfilter != YFilter.not_set or
                                    self.mac_learning.yfilter != YFilter.not_set or
                                    self.mac_limit.yfilter != YFilter.not_set or
                                    self.mac_limit_action.yfilter != YFilter.not_set or
                                    self.mac_limit_notification.yfilter != YFilter.not_set or
                                    self.mac_limit_reached.yfilter != YFilter.not_set or
                                    self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                    self.mac_secure_action.yfilter != YFilter.not_set or
                                    self.mld_profile_name.yfilter != YFilter.not_set or
                                    self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.split_horizon_group_id.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dai-address-validation-mask"):
                                    self.dai_address_validation_mask = value
                                    self.dai_address_validation_mask.value_namespace = name_space
                                    self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-profile-name"):
                                    self.dhcpv4_profile_name = value
                                    self.dhcpv4_profile_name.value_namespace = name_space
                                    self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-snoop"):
                                    self.dhcpv4_snoop = value
                                    self.dhcpv4_snoop.value_namespace = name_space
                                    self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-unknown-unicast-enabled"):
                                    self.flood_unknown_unicast_enabled = value
                                    self.flood_unknown_unicast_enabled.value_namespace = name_space
                                    self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-uu-disabled-mac-limit-action"):
                                    self.flood_uu_disabled_mac_limit_action = value
                                    self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                    self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "igm-pv4-disabled"):
                                    self.igm_pv4_disabled = value
                                    self.igm_pv4_disabled.value_namespace = name_space
                                    self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igm-pv4-profile-name"):
                                    self.igm_pv4_profile_name = value
                                    self.igm_pv4_profile_name.value_namespace = name_space
                                    self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                    self.is_dai_addr_validate_destination_mac_enabled = value
                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                    self.is_dai_addr_validate_ipv4_enabled = value
                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                    self.is_dai_addr_validate_source_mac_enabled = value
                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-enabled"):
                                    self.is_dai_enabled = value
                                    self.is_dai_enabled.value_namespace = name_space
                                    self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-logging-enabled"):
                                    self.is_dai_logging_enabled = value
                                    self.is_dai_logging_enabled.value_namespace = name_space
                                    self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ip-source-guard-enabled"):
                                    self.is_ip_source_guard_enabled = value
                                    self.is_ip_source_guard_enabled.value_namespace = name_space
                                    self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ipsg-logging-enabled"):
                                    self.is_ipsg_logging_enabled = value
                                    self.is_ipsg_logging_enabled.value_namespace = name_space
                                    self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                    self.is_mac_secure_accept_shutdown_enabled = value
                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-enabled"):
                                    self.is_mac_secure_enabled = value
                                    self.is_mac_secure_enabled.value_namespace = name_space
                                    self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-logging-enabled"):
                                    self.is_mac_secure_logging_enabled = value
                                    self.is_mac_secure_logging_enabled.value_namespace = name_space
                                    self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "learn-disabled-mac-limit-action"):
                                    self.learn_disabled_mac_limit_action = value
                                    self.learn_disabled_mac_limit_action.value_namespace = name_space
                                    self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-mode"):
                                    self.mac_aging_mode = value
                                    self.mac_aging_mode.value_namespace = name_space
                                    self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-time"):
                                    self.mac_aging_time = value
                                    self.mac_aging_time.value_namespace = name_space
                                    self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-flooding"):
                                    self.mac_flooding = value
                                    self.mac_flooding.value_namespace = name_space
                                    self.mac_flooding.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-learning"):
                                    self.mac_learning = value
                                    self.mac_learning.value_namespace = name_space
                                    self.mac_learning.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit"):
                                    self.mac_limit = value
                                    self.mac_limit.value_namespace = name_space
                                    self.mac_limit.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-action"):
                                    self.mac_limit_action = value
                                    self.mac_limit_action.value_namespace = name_space
                                    self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-notification"):
                                    self.mac_limit_notification = value
                                    self.mac_limit_notification.value_namespace = name_space
                                    self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-reached"):
                                    self.mac_limit_reached = value
                                    self.mac_limit_reached.value_namespace = name_space
                                    self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-port-down-flush-enabled"):
                                    self.mac_port_down_flush_enabled = value
                                    self.mac_port_down_flush_enabled.value_namespace = name_space
                                    self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-secure-action"):
                                    self.mac_secure_action = value
                                    self.mac_secure_action.value_namespace = name_space
                                    self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-profile-name"):
                                    self.mld_profile_name = value
                                    self.mld_profile_name.value_namespace = name_space
                                    self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "mmrp-flood-optimization"):
                                    self.mmrp_flood_optimization = value
                                    self.mmrp_flood_optimization.value_namespace = name_space
                                    self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "split-horizon-group-id"):
                                    self.split_horizon_group_id = value
                                    self.split_horizon_group_id.value_namespace = name_space
                                    self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class PbbParameters(Entity):
                            """
                            PBB parameters
                            
                            .. attribute:: pbb_core
                            
                            	PBB Core
                            	**type**\:   :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                            
                            .. attribute:: pbb_edge
                            
                            	PBB Edge
                            	**type**\:   :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridge>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__init__()

                                self.yang_name = "pbb-parameters"
                                self.yang_parent_name = "bridge-domain-info"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.pbb_core = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                                self.pbb_core.parent = self
                                self._children_name_map["pbb_core"] = "pbb-core"
                                self._children_yang_names.add("pbb-core")

                                self.pbb_edge = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                                self.pbb_edge.parent = self
                                self._children_name_map["pbb_edge"] = "pbb-edge"
                                self._children_yang_names.add("pbb-edge")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__setattr__(name, value)


                            class PbbEdge(Entity):
                                """
                                PBB Edge
                                
                                .. attribute:: core_bridge_name
                                
                                	Core Bridge Domain Name
                                	**type**\:  str
                                
                                .. attribute:: core_bridge_state
                                
                                	Core Bridge State
                                	**type**\:   :py:class:`L2VpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeState>`
                                
                                .. attribute:: edge_port
                                
                                	PBB Edge Port
                                	**type**\:   :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                                
                                .. attribute:: i_sid
                                
                                	SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mirp_lite_protocol
                                
                                	MIRP\-lite protocol info
                                	**type**\:   :py:class:`L2VpnMirpLiteProtocolInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteProtocolInfo>`
                                
                                .. attribute:: mirp_lite_status
                                
                                	MIRP\-lite Status
                                	**type**\:   :py:class:`L2VpnMirpLiteStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteStatus>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__init__()

                                    self.yang_name = "pbb-edge"
                                    self.yang_parent_name = "pbb-parameters"

                                    self.core_bridge_name = YLeaf(YType.str, "core-bridge-name")

                                    self.core_bridge_state = YLeaf(YType.enumeration, "core-bridge-state")

                                    self.i_sid = YLeaf(YType.uint32, "i-sid")

                                    self.mirp_lite_protocol = YLeaf(YType.enumeration, "mirp-lite-protocol")

                                    self.mirp_lite_status = YLeaf(YType.enumeration, "mirp-lite-status")

                                    self.edge_port = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                    self.edge_port.parent = self
                                    self._children_name_map["edge_port"] = "edge-port"
                                    self._children_yang_names.add("edge-port")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("core_bridge_name",
                                                    "core_bridge_state",
                                                    "i_sid",
                                                    "mirp_lite_protocol",
                                                    "mirp_lite_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__setattr__(name, value)


                                class EdgePort(Entity):
                                    """
                                    PBB Edge Port
                                    
                                    .. attribute:: bmac_mapping
                                    
                                    	CMAC to BMAC Mapping
                                    	**type**\: list of    :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                                    
                                    .. attribute:: edge_port_state
                                    
                                    	PBB Edge Port State
                                    	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                                    
                                    .. attribute:: security_parameters
                                    
                                    	Security Parameters
                                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                                    
                                    .. attribute:: statistics
                                    
                                    	Statistics
                                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                                    
                                    .. attribute:: unknown_unicast_mac
                                    
                                    	Unknown Unicast MAC
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: unknown_unicast_mac_set
                                    
                                    	Unknown Unicast MAC Configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__init__()

                                        self.yang_name = "edge-port"
                                        self.yang_parent_name = "pbb-edge"

                                        self.edge_port_state = YLeaf(YType.enumeration, "edge-port-state")

                                        self.unknown_unicast_mac = YLeaf(YType.str, "unknown-unicast-mac")

                                        self.unknown_unicast_mac_set = YLeaf(YType.boolean, "unknown-unicast-mac-set")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                        self._children_yang_names.add("security-parameters")

                                        self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                        self._children_yang_names.add("statistics")

                                        self.bmac_mapping = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("edge_port_state",
                                                        "unknown_unicast_mac",
                                                        "unknown_unicast_mac_set",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__setattr__(name, value)


                                    class SecurityParameters(Entity):
                                        """
                                        Security Parameters
                                        
                                        .. attribute:: base
                                        
                                        	Basic Security Parameters
                                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: dhcpv4_trust
                                        
                                        	DHCPv4 Trust Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__init__()

                                            self.yang_name = "security-parameters"
                                            self.yang_parent_name = "edge-port"

                                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                            self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                            self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                            self._children_yang_names.add("base")

                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._children_yang_names.add("storm-control")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("broadcast_storm_control_kb_ps",
                                                            "broadcast_storm_control_pps",
                                                            "broadcast_storm_control_rate_unit",
                                                            "dhcpv4_trust",
                                                            "multicast_storm_control_kb_ps",
                                                            "multicast_storm_control_pps",
                                                            "multicast_storm_control_rate_unit",
                                                            "unicast_storm_control_kb_ps",
                                                            "unicast_storm_control_pps",
                                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__setattr__(name, value)


                                        class Base(Entity):
                                            """
                                            Basic Security Parameters
                                            
                                            .. attribute:: broadcast_storm_control_kb_ps
                                            
                                            	Broadcast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: broadcast_storm_control_pps
                                            
                                            	Broadcast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: broadcast_storm_control_rate_unit
                                            
                                            	Broadcast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                            
                                            .. attribute:: dai_address_validation_mask
                                            
                                            	DAI Address Validation mask
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: dhcpv4_profile_name
                                            
                                            	DHCPv4 Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: dhcpv4_snoop
                                            
                                            	DHCPv4 Snoop Status
                                            	**type**\:  bool
                                            
                                            .. attribute:: flood_unknown_unicast_enabled
                                            
                                            	Flooding unknown unicast enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: flood_uu_disabled_mac_limit_action
                                            
                                            	Flooding of unknown\-unicast disabled due to MAC limit action
                                            	**type**\:  bool
                                            
                                            .. attribute:: igm_pv4_disabled
                                            
                                            	IGMPv4 Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: igm_pv4_profile_name
                                            
                                            	IGMPv4 Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                            
                                            	Is DAI Dstination MAC Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                                            
                                            	Is DAI IPv4 Addr Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                                            
                                            	Is DAI Source MAC Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_enabled
                                            
                                            	Is Dynamic ARP Inspection Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_logging_enabled
                                            
                                            	Is DAI Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ip_source_guard_enabled
                                            
                                            	Is IP Source Guard Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ipsg_logging_enabled
                                            
                                            	Is IP Source Guard Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                                            
                                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_enabled
                                            
                                            	Is MAC Secure Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_logging_enabled
                                            
                                            	Is MAC Secure Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: learn_disabled_mac_limit_action
                                            
                                            	Learning disabled due to MAC limit action
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_aging_mode
                                            
                                            	MAC Aging Mode
                                            	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                            
                                            .. attribute:: mac_aging_time
                                            
                                            	MAC aging time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: mac_flooding
                                            
                                            	MAC flooding enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_learning
                                            
                                            	MAC learning enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_limit
                                            
                                            	MAC address limit
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mac_limit_action
                                            
                                            	MAC limit action
                                            	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                            
                                            .. attribute:: mac_limit_notification
                                            
                                            	MAC limit notification
                                            	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                            
                                            .. attribute:: mac_limit_reached
                                            
                                            	MAC limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_port_down_flush_enabled
                                            
                                            	MAC Flush when port goes down
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_secure_action
                                            
                                            	MAC Secure Action
                                            	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                            
                                            .. attribute:: mld_profile_name
                                            
                                            	MLD Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: mmrp_flood_optimization
                                            
                                            	MMRP Flood Optimization Status
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast_storm_control_kb_ps
                                            
                                            	Multicast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: multicast_storm_control_pps
                                            
                                            	Multicast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: multicast_storm_control_rate_unit
                                            
                                            	Multicast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                            
                                            .. attribute:: split_horizon_group_id
                                            
                                            	Split Horizon Group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: storm_control
                                            
                                            	Storm Control Configuration
                                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                            
                                            .. attribute:: unicast_storm_control_kb_ps
                                            
                                            	Unicast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: unicast_storm_control_pps
                                            
                                            	Unicast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: unicast_storm_control_rate_unit
                                            
                                            	Unicast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__init__()

                                                self.yang_name = "base"
                                                self.yang_parent_name = "security-parameters"

                                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                                self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                                self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                                self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                                self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                                self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                                self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                                self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                                self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                                self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                                self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                                self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                                self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                                self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                                self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                                self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                                self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                                self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                                self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                                self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                                self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                                self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                                self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                                self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                                self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                                self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                                self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                                self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                                self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                                self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                                self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                                self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                                self._children_yang_names.add("storm-control")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("broadcast_storm_control_kb_ps",
                                                                "broadcast_storm_control_pps",
                                                                "broadcast_storm_control_rate_unit",
                                                                "dai_address_validation_mask",
                                                                "dhcpv4_profile_name",
                                                                "dhcpv4_snoop",
                                                                "flood_unknown_unicast_enabled",
                                                                "flood_uu_disabled_mac_limit_action",
                                                                "igm_pv4_disabled",
                                                                "igm_pv4_profile_name",
                                                                "is_dai_addr_validate_destination_mac_enabled",
                                                                "is_dai_addr_validate_ipv4_enabled",
                                                                "is_dai_addr_validate_source_mac_enabled",
                                                                "is_dai_enabled",
                                                                "is_dai_logging_enabled",
                                                                "is_ip_source_guard_enabled",
                                                                "is_ipsg_logging_enabled",
                                                                "is_mac_secure_accept_shutdown_enabled",
                                                                "is_mac_secure_enabled",
                                                                "is_mac_secure_logging_enabled",
                                                                "learn_disabled_mac_limit_action",
                                                                "mac_aging_mode",
                                                                "mac_aging_time",
                                                                "mac_flooding",
                                                                "mac_learning",
                                                                "mac_limit",
                                                                "mac_limit_action",
                                                                "mac_limit_notification",
                                                                "mac_limit_reached",
                                                                "mac_port_down_flush_enabled",
                                                                "mac_secure_action",
                                                                "mld_profile_name",
                                                                "mmrp_flood_optimization",
                                                                "multicast_storm_control_kb_ps",
                                                                "multicast_storm_control_pps",
                                                                "multicast_storm_control_rate_unit",
                                                                "split_horizon_group_id",
                                                                "unicast_storm_control_kb_ps",
                                                                "unicast_storm_control_pps",
                                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__setattr__(name, value)


                                            class StormControl(Entity):
                                                """
                                                Storm Control Configuration
                                                
                                                .. attribute:: bd_policer
                                                
                                                	Bridge Domain Policer
                                                	**type**\:  bool
                                                
                                                .. attribute:: broadcast
                                                
                                                	Broadcast Storm Control
                                                	**type**\:  bool
                                                
                                                .. attribute:: multicast
                                                
                                                	Multicast Storm Control
                                                	**type**\:  bool
                                                
                                                .. attribute:: unicast
                                                
                                                	Unknown\-unicast Storm Control
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__init__()

                                                    self.yang_name = "storm-control"
                                                    self.yang_parent_name = "base"

                                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bd_policer",
                                                                    "broadcast",
                                                                    "multicast",
                                                                    "unicast") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bd_policer.is_set or
                                                        self.broadcast.is_set or
                                                        self.multicast.is_set or
                                                        self.unicast.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bd_policer.yfilter != YFilter.not_set or
                                                        self.broadcast.yfilter != YFilter.not_set or
                                                        self.multicast.yfilter != YFilter.not_set or
                                                        self.unicast.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "storm-control" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bd-policer"):
                                                        self.bd_policer = value
                                                        self.bd_policer.value_namespace = name_space
                                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "broadcast"):
                                                        self.broadcast = value
                                                        self.broadcast.value_namespace = name_space
                                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "multicast"):
                                                        self.multicast = value
                                                        self.multicast.value_namespace = name_space
                                                        self.multicast.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "unicast"):
                                                        self.unicast = value
                                                        self.unicast.value_namespace = name_space
                                                        self.unicast.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.broadcast_storm_control_kb_ps.is_set or
                                                    self.broadcast_storm_control_pps.is_set or
                                                    self.broadcast_storm_control_rate_unit.is_set or
                                                    self.dai_address_validation_mask.is_set or
                                                    self.dhcpv4_profile_name.is_set or
                                                    self.dhcpv4_snoop.is_set or
                                                    self.flood_unknown_unicast_enabled.is_set or
                                                    self.flood_uu_disabled_mac_limit_action.is_set or
                                                    self.igm_pv4_disabled.is_set or
                                                    self.igm_pv4_profile_name.is_set or
                                                    self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                                    self.is_dai_addr_validate_ipv4_enabled.is_set or
                                                    self.is_dai_addr_validate_source_mac_enabled.is_set or
                                                    self.is_dai_enabled.is_set or
                                                    self.is_dai_logging_enabled.is_set or
                                                    self.is_ip_source_guard_enabled.is_set or
                                                    self.is_ipsg_logging_enabled.is_set or
                                                    self.is_mac_secure_accept_shutdown_enabled.is_set or
                                                    self.is_mac_secure_enabled.is_set or
                                                    self.is_mac_secure_logging_enabled.is_set or
                                                    self.learn_disabled_mac_limit_action.is_set or
                                                    self.mac_aging_mode.is_set or
                                                    self.mac_aging_time.is_set or
                                                    self.mac_flooding.is_set or
                                                    self.mac_learning.is_set or
                                                    self.mac_limit.is_set or
                                                    self.mac_limit_action.is_set or
                                                    self.mac_limit_notification.is_set or
                                                    self.mac_limit_reached.is_set or
                                                    self.mac_port_down_flush_enabled.is_set or
                                                    self.mac_secure_action.is_set or
                                                    self.mld_profile_name.is_set or
                                                    self.mmrp_flood_optimization.is_set or
                                                    self.multicast_storm_control_kb_ps.is_set or
                                                    self.multicast_storm_control_pps.is_set or
                                                    self.multicast_storm_control_rate_unit.is_set or
                                                    self.split_horizon_group_id.is_set or
                                                    self.unicast_storm_control_kb_ps.is_set or
                                                    self.unicast_storm_control_pps.is_set or
                                                    self.unicast_storm_control_rate_unit.is_set or
                                                    (self.storm_control is not None and self.storm_control.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                    self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                                    self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                                    self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                                    self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                                    self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                    self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                                    self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                                    self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                                    self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                                    self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                                    self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                                    self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                                    self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                                    self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                    self.mac_aging_mode.yfilter != YFilter.not_set or
                                                    self.mac_aging_time.yfilter != YFilter.not_set or
                                                    self.mac_flooding.yfilter != YFilter.not_set or
                                                    self.mac_learning.yfilter != YFilter.not_set or
                                                    self.mac_limit.yfilter != YFilter.not_set or
                                                    self.mac_limit_action.yfilter != YFilter.not_set or
                                                    self.mac_limit_notification.yfilter != YFilter.not_set or
                                                    self.mac_limit_reached.yfilter != YFilter.not_set or
                                                    self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                                    self.mac_secure_action.yfilter != YFilter.not_set or
                                                    self.mld_profile_name.yfilter != YFilter.not_set or
                                                    self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                    self.split_horizon_group_id.yfilter != YFilter.not_set or
                                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                    (self.storm_control is not None and self.storm_control.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "base" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                                if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                                if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                                if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                                if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                                if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                                if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                                if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                                if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                                if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                                if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                                if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                                if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                                if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                                if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                                if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                                if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                                if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                                if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                                if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                                if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                                if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                                if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                                if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                                if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                                if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                                if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                                if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                                if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                                if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                                if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                                if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "storm-control"):
                                                    if (self.storm_control is None):
                                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                                        self.storm_control.parent = self
                                                        self._children_name_map["storm_control"] = "storm-control"
                                                    return self.storm_control

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "broadcast-storm-control-kb-ps"):
                                                    self.broadcast_storm_control_kb_ps = value
                                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast-storm-control-pps"):
                                                    self.broadcast_storm_control_pps = value
                                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast-storm-control-rate-unit"):
                                                    self.broadcast_storm_control_rate_unit = value
                                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dai-address-validation-mask"):
                                                    self.dai_address_validation_mask = value
                                                    self.dai_address_validation_mask.value_namespace = name_space
                                                    self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dhcpv4-profile-name"):
                                                    self.dhcpv4_profile_name = value
                                                    self.dhcpv4_profile_name.value_namespace = name_space
                                                    self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dhcpv4-snoop"):
                                                    self.dhcpv4_snoop = value
                                                    self.dhcpv4_snoop.value_namespace = name_space
                                                    self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flood-unknown-unicast-enabled"):
                                                    self.flood_unknown_unicast_enabled = value
                                                    self.flood_unknown_unicast_enabled.value_namespace = name_space
                                                    self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flood-uu-disabled-mac-limit-action"):
                                                    self.flood_uu_disabled_mac_limit_action = value
                                                    self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                                    self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                                if(value_path == "igm-pv4-disabled"):
                                                    self.igm_pv4_disabled = value
                                                    self.igm_pv4_disabled.value_namespace = name_space
                                                    self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "igm-pv4-profile-name"):
                                                    self.igm_pv4_profile_name = value
                                                    self.igm_pv4_profile_name.value_namespace = name_space
                                                    self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                                    self.is_dai_addr_validate_destination_mac_enabled = value
                                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                                    self.is_dai_addr_validate_ipv4_enabled = value
                                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                                    self.is_dai_addr_validate_source_mac_enabled = value
                                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-enabled"):
                                                    self.is_dai_enabled = value
                                                    self.is_dai_enabled.value_namespace = name_space
                                                    self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-logging-enabled"):
                                                    self.is_dai_logging_enabled = value
                                                    self.is_dai_logging_enabled.value_namespace = name_space
                                                    self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-ip-source-guard-enabled"):
                                                    self.is_ip_source_guard_enabled = value
                                                    self.is_ip_source_guard_enabled.value_namespace = name_space
                                                    self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-ipsg-logging-enabled"):
                                                    self.is_ipsg_logging_enabled = value
                                                    self.is_ipsg_logging_enabled.value_namespace = name_space
                                                    self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                                    self.is_mac_secure_accept_shutdown_enabled = value
                                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-mac-secure-enabled"):
                                                    self.is_mac_secure_enabled = value
                                                    self.is_mac_secure_enabled.value_namespace = name_space
                                                    self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-mac-secure-logging-enabled"):
                                                    self.is_mac_secure_logging_enabled = value
                                                    self.is_mac_secure_logging_enabled.value_namespace = name_space
                                                    self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "learn-disabled-mac-limit-action"):
                                                    self.learn_disabled_mac_limit_action = value
                                                    self.learn_disabled_mac_limit_action.value_namespace = name_space
                                                    self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-aging-mode"):
                                                    self.mac_aging_mode = value
                                                    self.mac_aging_mode.value_namespace = name_space
                                                    self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-aging-time"):
                                                    self.mac_aging_time = value
                                                    self.mac_aging_time.value_namespace = name_space
                                                    self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-flooding"):
                                                    self.mac_flooding = value
                                                    self.mac_flooding.value_namespace = name_space
                                                    self.mac_flooding.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-learning"):
                                                    self.mac_learning = value
                                                    self.mac_learning.value_namespace = name_space
                                                    self.mac_learning.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit"):
                                                    self.mac_limit = value
                                                    self.mac_limit.value_namespace = name_space
                                                    self.mac_limit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit-action"):
                                                    self.mac_limit_action = value
                                                    self.mac_limit_action.value_namespace = name_space
                                                    self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit-notification"):
                                                    self.mac_limit_notification = value
                                                    self.mac_limit_notification.value_namespace = name_space
                                                    self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit-reached"):
                                                    self.mac_limit_reached = value
                                                    self.mac_limit_reached.value_namespace = name_space
                                                    self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-port-down-flush-enabled"):
                                                    self.mac_port_down_flush_enabled = value
                                                    self.mac_port_down_flush_enabled.value_namespace = name_space
                                                    self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-secure-action"):
                                                    self.mac_secure_action = value
                                                    self.mac_secure_action.value_namespace = name_space
                                                    self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mld-profile-name"):
                                                    self.mld_profile_name = value
                                                    self.mld_profile_name.value_namespace = name_space
                                                    self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mmrp-flood-optimization"):
                                                    self.mmrp_flood_optimization = value
                                                    self.mmrp_flood_optimization.value_namespace = name_space
                                                    self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast-storm-control-kb-ps"):
                                                    self.multicast_storm_control_kb_ps = value
                                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast-storm-control-pps"):
                                                    self.multicast_storm_control_pps = value
                                                    self.multicast_storm_control_pps.value_namespace = name_space
                                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast-storm-control-rate-unit"):
                                                    self.multicast_storm_control_rate_unit = value
                                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "split-horizon-group-id"):
                                                    self.split_horizon_group_id = value
                                                    self.split_horizon_group_id.value_namespace = name_space
                                                    self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast-storm-control-kb-ps"):
                                                    self.unicast_storm_control_kb_ps = value
                                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast-storm-control-pps"):
                                                    self.unicast_storm_control_pps = value
                                                    self.unicast_storm_control_pps.value_namespace = name_space
                                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast-storm-control-rate-unit"):
                                                    self.unicast_storm_control_rate_unit = value
                                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "security-parameters"

                                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                self.multicast = YLeaf(YType.boolean, "multicast")

                                                self.unicast = YLeaf(YType.boolean, "unicast")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bd_policer",
                                                                "broadcast",
                                                                "multicast",
                                                                "unicast") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bd_policer.is_set or
                                                    self.broadcast.is_set or
                                                    self.multicast.is_set or
                                                    self.unicast.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bd_policer.yfilter != YFilter.not_set or
                                                    self.broadcast.yfilter != YFilter.not_set or
                                                    self.multicast.yfilter != YFilter.not_set or
                                                    self.unicast.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "storm-control" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bd-policer"):
                                                    self.bd_policer = value
                                                    self.bd_policer.value_namespace = name_space
                                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast"):
                                                    self.broadcast = value
                                                    self.broadcast.value_namespace = name_space
                                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast"):
                                                    self.multicast = value
                                                    self.multicast.value_namespace = name_space
                                                    self.multicast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast"):
                                                    self.unicast = value
                                                    self.unicast.value_namespace = name_space
                                                    self.unicast.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.broadcast_storm_control_kb_ps.is_set or
                                                self.broadcast_storm_control_pps.is_set or
                                                self.broadcast_storm_control_rate_unit.is_set or
                                                self.dhcpv4_trust.is_set or
                                                self.multicast_storm_control_kb_ps.is_set or
                                                self.multicast_storm_control_pps.is_set or
                                                self.multicast_storm_control_rate_unit.is_set or
                                                self.unicast_storm_control_kb_ps.is_set or
                                                self.unicast_storm_control_pps.is_set or
                                                self.unicast_storm_control_rate_unit.is_set or
                                                (self.base is not None and self.base.has_data()) or
                                                (self.storm_control is not None and self.storm_control.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.dhcpv4_trust.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                (self.base is not None and self.base.has_operation()) or
                                                (self.storm_control is not None and self.storm_control.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "security-parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "base"):
                                                if (self.base is None):
                                                    self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                                    self.base.parent = self
                                                    self._children_name_map["base"] = "base"
                                                return self.base

                                            if (child_yang_name == "storm-control"):
                                                if (self.storm_control is None):
                                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                                    self.storm_control.parent = self
                                                    self._children_name_map["storm_control"] = "storm-control"
                                                return self.storm_control

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "broadcast-storm-control-kb-ps"):
                                                self.broadcast_storm_control_kb_ps = value
                                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-pps"):
                                                self.broadcast_storm_control_pps = value
                                                self.broadcast_storm_control_pps.value_namespace = name_space
                                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-rate-unit"):
                                                self.broadcast_storm_control_rate_unit = value
                                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-trust"):
                                                self.dhcpv4_trust = value
                                                self.dhcpv4_trust.value_namespace = name_space
                                                self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-kb-ps"):
                                                self.multicast_storm_control_kb_ps = value
                                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-pps"):
                                                self.multicast_storm_control_pps = value
                                                self.multicast_storm_control_pps.value_namespace = name_space
                                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-rate-unit"):
                                                self.multicast_storm_control_rate_unit = value
                                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-kb-ps"):
                                                self.unicast_storm_control_kb_ps = value
                                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-pps"):
                                                self.unicast_storm_control_pps = value
                                                self.unicast_storm_control_pps.value_namespace = name_space
                                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-rate-unit"):
                                                self.unicast_storm_control_rate_unit = value
                                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                    class Statistics(Entity):
                                        """
                                        Statistics
                                        
                                        .. attribute:: dispostion_stats
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                        
                                        .. attribute:: impostion_stats
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                        
                                        .. attribute:: sequence_number
                                        
                                        	sequence numbers
                                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics, self).__init__()

                                            self.yang_name = "statistics"
                                            self.yang_parent_name = "edge-port"

                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            self._children_yang_names.add("dispostion-stats")

                                            self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                            self._children_yang_names.add("impostion-stats")

                                            self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                            self._children_yang_names.add("sequence-number")


                                        class ImpostionStats(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast
                                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                            
                                            .. attribute:: imposition_mtu_drop
                                            
                                            	imposition mtu drop stats
                                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                            
                                            .. attribute:: imposition_stat
                                            
                                            	imposition stats
                                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                            
                                            .. attribute:: impostion_tail_drop
                                            
                                            	imposition tail drop stats
                                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                            
                                            .. attribute:: l2fsbi_drop
                                            
                                            	rx discards
                                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop>`
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast
                                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Unknown Unicast
                                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats, self).__init__()

                                                self.yang_name = "impostion-stats"
                                                self.yang_parent_name = "statistics"

                                                self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                                self._children_yang_names.add("broadcast")

                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                self._children_yang_names.add("imposition-mtu-drop")

                                                self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                                self._children_yang_names.add("imposition-stat")

                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                self._children_yang_names.add("impostion-tail-drop")

                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                                self._children_yang_names.add("known-unicast")

                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                self._children_yang_names.add("l2fsbi-drop")

                                                self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                                self._children_yang_names.add("multicast")

                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                self._children_yang_names.add("unknown-unicast")


                                            class ImpositionStat(Entity):
                                                """
                                                imposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                    self.yang_name = "imposition-stat"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "imposition-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class ImpositionMtuDrop(Entity):
                                                """
                                                imposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                    self.yang_name = "imposition-mtu-drop"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class ImpostionTailDrop(Entity):
                                                """
                                                imposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                    self.yang_name = "impostion-tail-drop"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "impostion-tail-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class L2FsbiDrop(Entity):
                                                """
                                                rx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                    self.yang_name = "l2fsbi-drop"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "l2fsbi-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class Multicast(Entity):
                                                """
                                                Multicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__init__()

                                                    self.yang_name = "multicast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class Broadcast(Entity):
                                                """
                                                Broadcast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                    self.yang_name = "broadcast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "broadcast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "known-unicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class UnknownUnicast(Entity):
                                                """
                                                Unknown Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                    self.yang_name = "unknown-unicast"
                                                    self.yang_parent_name = "impostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unknown-unicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                    (self.multicast is not None and self.multicast.has_data()) or
                                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                    (self.multicast is not None and self.multicast.has_operation()) or
                                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "broadcast"):
                                                    if (self.broadcast is None):
                                                        self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                                        self.broadcast.parent = self
                                                        self._children_name_map["broadcast"] = "broadcast"
                                                    return self.broadcast

                                                if (child_yang_name == "imposition-mtu-drop"):
                                                    if (self.imposition_mtu_drop is None):
                                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                        self.imposition_mtu_drop.parent = self
                                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                    return self.imposition_mtu_drop

                                                if (child_yang_name == "imposition-stat"):
                                                    if (self.imposition_stat is None):
                                                        self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                                        self.imposition_stat.parent = self
                                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                                    return self.imposition_stat

                                                if (child_yang_name == "impostion-tail-drop"):
                                                    if (self.impostion_tail_drop is None):
                                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                                        self.impostion_tail_drop.parent = self
                                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                    return self.impostion_tail_drop

                                                if (child_yang_name == "known-unicast"):
                                                    if (self.known_unicast is None):
                                                        self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                                        self.known_unicast.parent = self
                                                        self._children_name_map["known_unicast"] = "known-unicast"
                                                    return self.known_unicast

                                                if (child_yang_name == "l2fsbi-drop"):
                                                    if (self.l2fsbi_drop is None):
                                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                                        self.l2fsbi_drop.parent = self
                                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                    return self.l2fsbi_drop

                                                if (child_yang_name == "multicast"):
                                                    if (self.multicast is None):
                                                        self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                                        self.multicast.parent = self
                                                        self._children_name_map["multicast"] = "multicast"
                                                    return self.multicast

                                                if (child_yang_name == "unknown-unicast"):
                                                    if (self.unknown_unicast is None):
                                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                                        self.unknown_unicast.parent = self
                                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                    return self.unknown_unicast

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class DispostionStats(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: broadcast_drop
                                            
                                            	disposition storm control broadcast drop stats
                                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                            
                                            .. attribute:: dai_drop
                                            
                                            	Disposition dynamic ARP inspection drop statistics
                                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                            
                                            .. attribute:: disposition_mtu_drop
                                            
                                            	disposition mtu drop stats
                                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                            
                                            .. attribute:: disposition_oo_o_drops
                                            
                                            	Disposition Out\-of\-Order Drops
                                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                            
                                            .. attribute:: disposition_p2mp_stats
                                            
                                            	Disposition P2MP Stats
                                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats>`
                                            
                                            .. attribute:: disposition_stat
                                            
                                            	disposition stats
                                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                            
                                            .. attribute:: disposition_tail_drop
                                            
                                            	disposition tail drop stats
                                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                            
                                            .. attribute:: ipsg_drop
                                            
                                            	disposition IP source guard drop statistics
                                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                            
                                            .. attribute:: mac_move
                                            
                                            	MAC Move
                                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                            
                                            .. attribute:: multicast_drop
                                            
                                            	disposition storm control multicast drop stats
                                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                            
                                            .. attribute:: received_drops
                                            
                                            	tx discards
                                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                            
                                            .. attribute:: unicast_drop
                                            
                                            	disposition storm control unknown unicast drop stats
                                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats, self).__init__()

                                                self.yang_name = "dispostion-stats"
                                                self.yang_parent_name = "statistics"

                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                self._children_yang_names.add("broadcast-drop")

                                                self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                                self._children_yang_names.add("dai-drop")

                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                self._children_yang_names.add("disposition-mtu-drop")

                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                self._children_yang_names.add("disposition-oo-o-drops")

                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                self._children_yang_names.add("disposition-p2mp-stats")

                                                self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                                self._children_yang_names.add("disposition-stat")

                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                self._children_yang_names.add("disposition-tail-drop")

                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                self._children_yang_names.add("ipsg-drop")

                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                                self._children_yang_names.add("known-unicast")

                                                self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                                self._children_yang_names.add("mac-move")

                                                self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                                self._children_yang_names.add("multicast-drop")

                                                self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                                self._children_yang_names.add("received-drops")

                                                self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                                self._children_yang_names.add("unicast-drop")


                                            class DispositionStat(Entity):
                                                """
                                                disposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                    self.yang_name = "disposition-stat"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionMtuDrop(Entity):
                                                """
                                                disposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                    self.yang_name = "disposition-mtu-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionTailDrop(Entity):
                                                """
                                                disposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                    self.yang_name = "disposition-tail-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-tail-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class MulticastDrop(Entity):
                                                """
                                                disposition storm control multicast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                    self.yang_name = "multicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multicast-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class UnicastDrop(Entity):
                                                """
                                                disposition storm control unknown unicast drop
                                                stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                    self.yang_name = "unicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unicast-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class BroadcastDrop(Entity):
                                                """
                                                disposition storm control broadcast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                    self.yang_name = "broadcast-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "broadcast-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class ReceivedDrops(Entity):
                                                """
                                                tx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                    self.yang_name = "received-drops"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "received-drops" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DaiDrop(Entity):
                                                """
                                                Disposition dynamic ARP inspection drop
                                                statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                    self.yang_name = "dai-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dai-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class IpsgDrop(Entity):
                                                """
                                                disposition IP source guard drop statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                    self.yang_name = "ipsg-drop"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ipsg-drop" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionOoODrops(Entity):
                                                """
                                                Disposition Out\-of\-Order Drops
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                    self.yang_name = "disposition-oo-o-drops"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class DispositionP2MpStats(Entity):
                                                """
                                                Disposition P2MP Stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                    self.yang_name = "disposition-p2mp-stats"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "known-unicast" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                                            class MacMove(Entity):
                                                """
                                                MAC Move
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__init__()

                                                    self.yang_name = "mac-move"
                                                    self.yang_parent_name = "dispostion-stats"

                                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("byte_counts",
                                                                    "packet_counts") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.byte_counts.is_set or
                                                        self.packet_counts.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.byte_counts.yfilter != YFilter.not_set or
                                                        self.packet_counts.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "mac-move" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "byte-counts" or name == "packet-counts"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "byte-counts"):
                                                        self.byte_counts = value
                                                        self.byte_counts.value_namespace = name_space
                                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "packet-counts"):
                                                        self.packet_counts = value
                                                        self.packet_counts.value_namespace = name_space
                                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dispostion-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "broadcast-drop"):
                                                    if (self.broadcast_drop is None):
                                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                                        self.broadcast_drop.parent = self
                                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                    return self.broadcast_drop

                                                if (child_yang_name == "dai-drop"):
                                                    if (self.dai_drop is None):
                                                        self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                                        self.dai_drop.parent = self
                                                        self._children_name_map["dai_drop"] = "dai-drop"
                                                    return self.dai_drop

                                                if (child_yang_name == "disposition-mtu-drop"):
                                                    if (self.disposition_mtu_drop is None):
                                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                                        self.disposition_mtu_drop.parent = self
                                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                    return self.disposition_mtu_drop

                                                if (child_yang_name == "disposition-oo-o-drops"):
                                                    if (self.disposition_oo_o_drops is None):
                                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                                        self.disposition_oo_o_drops.parent = self
                                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                    return self.disposition_oo_o_drops

                                                if (child_yang_name == "disposition-p2mp-stats"):
                                                    if (self.disposition_p2mp_stats is None):
                                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                                        self.disposition_p2mp_stats.parent = self
                                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                    return self.disposition_p2mp_stats

                                                if (child_yang_name == "disposition-stat"):
                                                    if (self.disposition_stat is None):
                                                        self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                                        self.disposition_stat.parent = self
                                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                                    return self.disposition_stat

                                                if (child_yang_name == "disposition-tail-drop"):
                                                    if (self.disposition_tail_drop is None):
                                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                                        self.disposition_tail_drop.parent = self
                                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                    return self.disposition_tail_drop

                                                if (child_yang_name == "ipsg-drop"):
                                                    if (self.ipsg_drop is None):
                                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                                        self.ipsg_drop.parent = self
                                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                    return self.ipsg_drop

                                                if (child_yang_name == "known-unicast"):
                                                    if (self.known_unicast is None):
                                                        self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                                        self.known_unicast.parent = self
                                                        self._children_name_map["known_unicast"] = "known-unicast"
                                                    return self.known_unicast

                                                if (child_yang_name == "mac-move"):
                                                    if (self.mac_move is None):
                                                        self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                                        self.mac_move.parent = self
                                                        self._children_name_map["mac_move"] = "mac-move"
                                                    return self.mac_move

                                                if (child_yang_name == "multicast-drop"):
                                                    if (self.multicast_drop is None):
                                                        self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                                        self.multicast_drop.parent = self
                                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                                    return self.multicast_drop

                                                if (child_yang_name == "received-drops"):
                                                    if (self.received_drops is None):
                                                        self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                                        self.received_drops.parent = self
                                                        self._children_name_map["received_drops"] = "received-drops"
                                                    return self.received_drops

                                                if (child_yang_name == "unicast-drop"):
                                                    if (self.unicast_drop is None):
                                                        self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                                        self.unicast_drop.parent = self
                                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                                    return self.unicast_drop

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class SequenceNumber(Entity):
                                            """
                                            sequence numbers
                                            
                                            .. attribute:: bypassed_inbound_sequence_packet
                                            
                                            	Bypassed inbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bypassed_out_sequence_packet
                                            
                                            	Bypassed outbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: sequence_number_expected
                                            
                                            	sequence number expected
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sequence_number_sent
                                            
                                            	sequence number sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__init__()

                                                self.yang_name = "sequence-number"
                                                self.yang_parent_name = "statistics"

                                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bypassed_inbound_sequence_packet",
                                                                "bypassed_out_sequence_packet",
                                                                "sequence_number_expected",
                                                                "sequence_number_sent") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bypassed_inbound_sequence_packet.is_set or
                                                    self.bypassed_out_sequence_packet.is_set or
                                                    self.sequence_number_expected.is_set or
                                                    self.sequence_number_sent.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sequence-number" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bypassed-inbound-sequence-packet"):
                                                    self.bypassed_inbound_sequence_packet = value
                                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bypassed-out-sequence-packet"):
                                                    self.bypassed_out_sequence_packet = value
                                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sequence-number-expected"):
                                                    self.sequence_number_expected = value
                                                    self.sequence_number_expected.value_namespace = name_space
                                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sequence-number-sent"):
                                                    self.sequence_number_sent = value
                                                    self.sequence_number_sent.value_namespace = name_space
                                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                                (self.sequence_number is not None and self.sequence_number.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "statistics" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dispostion-stats"):
                                                if (self.dispostion_stats is None):
                                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                                    self.dispostion_stats.parent = self
                                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                                return self.dispostion_stats

                                            if (child_yang_name == "impostion-stats"):
                                                if (self.impostion_stats is None):
                                                    self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                                    self.impostion_stats.parent = self
                                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                                return self.impostion_stats

                                            if (child_yang_name == "sequence-number"):
                                                if (self.sequence_number is None):
                                                    self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                                    self.sequence_number.parent = self
                                                    self._children_name_map["sequence_number"] = "sequence-number"
                                                return self.sequence_number

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class BmacMapping(Entity):
                                        """
                                        CMAC to BMAC Mapping
                                        
                                        .. attribute:: address
                                        
                                        	MAC address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: bmac
                                        
                                        	Backbone MAC address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: next_hop_ip
                                        
                                        	Next Hop IP
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__init__()

                                            self.yang_name = "bmac-mapping"
                                            self.yang_parent_name = "edge-port"

                                            self.address = YLeaf(YType.str, "address")

                                            self.bmac = YLeaf(YType.str, "bmac")

                                            self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("address",
                                                            "bmac",
                                                            "next_hop_ip") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.address.is_set or
                                                self.bmac.is_set or
                                                self.next_hop_ip.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.address.yfilter != YFilter.not_set or
                                                self.bmac.yfilter != YFilter.not_set or
                                                self.next_hop_ip.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bmac-mapping" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.address.get_name_leafdata())
                                            if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bmac.get_name_leafdata())
                                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "address"):
                                                self.address = value
                                                self.address.value_namespace = name_space
                                                self.address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bmac"):
                                                self.bmac = value
                                                self.bmac.value_namespace = name_space
                                                self.bmac.value_namespace_prefix = name_space_prefix
                                            if(value_path == "next-hop-ip"):
                                                self.next_hop_ip = value
                                                self.next_hop_ip.value_namespace = name_space
                                                self.next_hop_ip.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.bmac_mapping:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.edge_port_state.is_set or
                                            self.unknown_unicast_mac.is_set or
                                            self.unknown_unicast_mac_set.is_set or
                                            self.xconnect_id.is_set or
                                            (self.security_parameters is not None and self.security_parameters.has_data()) or
                                            (self.statistics is not None and self.statistics.has_data()))

                                    def has_operation(self):
                                        for c in self.bmac_mapping:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.edge_port_state.yfilter != YFilter.not_set or
                                            self.unknown_unicast_mac.yfilter != YFilter.not_set or
                                            self.unknown_unicast_mac_set.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                            (self.statistics is not None and self.statistics.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "edge-port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.edge_port_state.is_set or self.edge_port_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.edge_port_state.get_name_leafdata())
                                        if (self.unknown_unicast_mac.is_set or self.unknown_unicast_mac.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unknown_unicast_mac.get_name_leafdata())
                                        if (self.unknown_unicast_mac_set.is_set or self.unknown_unicast_mac_set.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unknown_unicast_mac_set.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "bmac-mapping"):
                                            for c in self.bmac_mapping:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.bmac_mapping.append(c)
                                            return c

                                        if (child_yang_name == "security-parameters"):
                                            if (self.security_parameters is None):
                                                self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                                self.security_parameters.parent = self
                                                self._children_name_map["security_parameters"] = "security-parameters"
                                            return self.security_parameters

                                        if (child_yang_name == "statistics"):
                                            if (self.statistics is None):
                                                self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                                self.statistics.parent = self
                                                self._children_name_map["statistics"] = "statistics"
                                            return self.statistics

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bmac-mapping" or name == "security-parameters" or name == "statistics" or name == "edge-port-state" or name == "unknown-unicast-mac" or name == "unknown-unicast-mac-set" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "edge-port-state"):
                                            self.edge_port_state = value
                                            self.edge_port_state.value_namespace = name_space
                                            self.edge_port_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unknown-unicast-mac"):
                                            self.unknown_unicast_mac = value
                                            self.unknown_unicast_mac.value_namespace = name_space
                                            self.unknown_unicast_mac.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unknown-unicast-mac-set"):
                                            self.unknown_unicast_mac_set = value
                                            self.unknown_unicast_mac_set.value_namespace = name_space
                                            self.unknown_unicast_mac_set.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.core_bridge_name.is_set or
                                        self.core_bridge_state.is_set or
                                        self.i_sid.is_set or
                                        self.mirp_lite_protocol.is_set or
                                        self.mirp_lite_status.is_set or
                                        (self.edge_port is not None and self.edge_port.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.core_bridge_name.yfilter != YFilter.not_set or
                                        self.core_bridge_state.yfilter != YFilter.not_set or
                                        self.i_sid.yfilter != YFilter.not_set or
                                        self.mirp_lite_protocol.yfilter != YFilter.not_set or
                                        self.mirp_lite_status.yfilter != YFilter.not_set or
                                        (self.edge_port is not None and self.edge_port.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pbb-edge" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.core_bridge_name.is_set or self.core_bridge_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.core_bridge_name.get_name_leafdata())
                                    if (self.core_bridge_state.is_set or self.core_bridge_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.core_bridge_state.get_name_leafdata())
                                    if (self.i_sid.is_set or self.i_sid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.i_sid.get_name_leafdata())
                                    if (self.mirp_lite_protocol.is_set or self.mirp_lite_protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mirp_lite_protocol.get_name_leafdata())
                                    if (self.mirp_lite_status.is_set or self.mirp_lite_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mirp_lite_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "edge-port"):
                                        if (self.edge_port is None):
                                            self.edge_port = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                            self.edge_port.parent = self
                                            self._children_name_map["edge_port"] = "edge-port"
                                        return self.edge_port

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "edge-port" or name == "core-bridge-name" or name == "core-bridge-state" or name == "i-sid" or name == "mirp-lite-protocol" or name == "mirp-lite-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "core-bridge-name"):
                                        self.core_bridge_name = value
                                        self.core_bridge_name.value_namespace = name_space
                                        self.core_bridge_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "core-bridge-state"):
                                        self.core_bridge_state = value
                                        self.core_bridge_state.value_namespace = name_space
                                        self.core_bridge_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "i-sid"):
                                        self.i_sid = value
                                        self.i_sid.value_namespace = name_space
                                        self.i_sid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mirp-lite-protocol"):
                                        self.mirp_lite_protocol = value
                                        self.mirp_lite_protocol.value_namespace = name_space
                                        self.mirp_lite_protocol.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mirp-lite-status"):
                                        self.mirp_lite_status = value
                                        self.mirp_lite_status.value_namespace = name_space
                                        self.mirp_lite_status.value_namespace_prefix = name_space_prefix


                            class PbbCore(Entity):
                                """
                                PBB Core
                                
                                .. attribute:: core_port
                                
                                	PBB Core Port
                                	**type**\:   :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                                
                                .. attribute:: num_ass_edge
                                
                                	Number of Associated PBB Edges
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__init__()

                                    self.yang_name = "pbb-core"
                                    self.yang_parent_name = "pbb-parameters"

                                    self.num_ass_edge = YLeaf(YType.uint32, "num-ass-edge")

                                    self.core_port = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                    self.core_port.parent = self
                                    self._children_name_map["core_port"] = "core-port"
                                    self._children_yang_names.add("core-port")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("num_ass_edge") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__setattr__(name, value)


                                class CorePort(Entity):
                                    """
                                    PBB Core Port
                                    
                                    .. attribute:: core_port_state
                                    
                                    	PBB Core Port State
                                    	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                                    
                                    .. attribute:: security_parameters
                                    
                                    	Security Parameters
                                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                                    
                                    .. attribute:: vlan_id
                                    
                                    	Vlan ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__init__()

                                        self.yang_name = "core-port"
                                        self.yang_parent_name = "pbb-core"

                                        self.core_port_state = YLeaf(YType.enumeration, "core-port-state")

                                        self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                        self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                        self._children_yang_names.add("security-parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("core_port_state",
                                                        "vlan_id",
                                                        "xconnect_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__setattr__(name, value)


                                    class SecurityParameters(Entity):
                                        """
                                        Security Parameters
                                        
                                        .. attribute:: base
                                        
                                        	Basic Security Parameters
                                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: dhcpv4_trust
                                        
                                        	DHCPv4 Trust Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__init__()

                                            self.yang_name = "security-parameters"
                                            self.yang_parent_name = "core-port"

                                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                            self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                            self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                            self._children_yang_names.add("base")

                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._children_yang_names.add("storm-control")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("broadcast_storm_control_kb_ps",
                                                            "broadcast_storm_control_pps",
                                                            "broadcast_storm_control_rate_unit",
                                                            "dhcpv4_trust",
                                                            "multicast_storm_control_kb_ps",
                                                            "multicast_storm_control_pps",
                                                            "multicast_storm_control_rate_unit",
                                                            "unicast_storm_control_kb_ps",
                                                            "unicast_storm_control_pps",
                                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__setattr__(name, value)


                                        class Base(Entity):
                                            """
                                            Basic Security Parameters
                                            
                                            .. attribute:: broadcast_storm_control_kb_ps
                                            
                                            	Broadcast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: broadcast_storm_control_pps
                                            
                                            	Broadcast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: broadcast_storm_control_rate_unit
                                            
                                            	Broadcast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                            
                                            .. attribute:: dai_address_validation_mask
                                            
                                            	DAI Address Validation mask
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: dhcpv4_profile_name
                                            
                                            	DHCPv4 Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: dhcpv4_snoop
                                            
                                            	DHCPv4 Snoop Status
                                            	**type**\:  bool
                                            
                                            .. attribute:: flood_unknown_unicast_enabled
                                            
                                            	Flooding unknown unicast enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: flood_uu_disabled_mac_limit_action
                                            
                                            	Flooding of unknown\-unicast disabled due to MAC limit action
                                            	**type**\:  bool
                                            
                                            .. attribute:: igm_pv4_disabled
                                            
                                            	IGMPv4 Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: igm_pv4_profile_name
                                            
                                            	IGMPv4 Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                            
                                            	Is DAI Dstination MAC Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                                            
                                            	Is DAI IPv4 Addr Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                                            
                                            	Is DAI Source MAC Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_enabled
                                            
                                            	Is Dynamic ARP Inspection Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_logging_enabled
                                            
                                            	Is DAI Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ip_source_guard_enabled
                                            
                                            	Is IP Source Guard Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ipsg_logging_enabled
                                            
                                            	Is IP Source Guard Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                                            
                                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_enabled
                                            
                                            	Is MAC Secure Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_logging_enabled
                                            
                                            	Is MAC Secure Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: learn_disabled_mac_limit_action
                                            
                                            	Learning disabled due to MAC limit action
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_aging_mode
                                            
                                            	MAC Aging Mode
                                            	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                            
                                            .. attribute:: mac_aging_time
                                            
                                            	MAC aging time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: mac_flooding
                                            
                                            	MAC flooding enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_learning
                                            
                                            	MAC learning enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_limit
                                            
                                            	MAC address limit
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mac_limit_action
                                            
                                            	MAC limit action
                                            	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                            
                                            .. attribute:: mac_limit_notification
                                            
                                            	MAC limit notification
                                            	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                            
                                            .. attribute:: mac_limit_reached
                                            
                                            	MAC limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_port_down_flush_enabled
                                            
                                            	MAC Flush when port goes down
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_secure_action
                                            
                                            	MAC Secure Action
                                            	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                            
                                            .. attribute:: mld_profile_name
                                            
                                            	MLD Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: mmrp_flood_optimization
                                            
                                            	MMRP Flood Optimization Status
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast_storm_control_kb_ps
                                            
                                            	Multicast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: multicast_storm_control_pps
                                            
                                            	Multicast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: multicast_storm_control_rate_unit
                                            
                                            	Multicast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                            
                                            .. attribute:: split_horizon_group_id
                                            
                                            	Split Horizon Group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: storm_control
                                            
                                            	Storm Control Configuration
                                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                            
                                            .. attribute:: unicast_storm_control_kb_ps
                                            
                                            	Unicast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: unicast_storm_control_pps
                                            
                                            	Unicast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: unicast_storm_control_rate_unit
                                            
                                            	Unicast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__init__()

                                                self.yang_name = "base"
                                                self.yang_parent_name = "security-parameters"

                                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                                self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                                self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                                self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                                self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                                self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                                self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                                self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                                self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                                self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                                self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                                self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                                self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                                self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                                self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                                self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                                self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                                self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                                self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                                self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                                self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                                self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                                self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                                self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                                self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                                self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                                self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                                self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                                self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                                self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                                self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                                self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                                self._children_yang_names.add("storm-control")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("broadcast_storm_control_kb_ps",
                                                                "broadcast_storm_control_pps",
                                                                "broadcast_storm_control_rate_unit",
                                                                "dai_address_validation_mask",
                                                                "dhcpv4_profile_name",
                                                                "dhcpv4_snoop",
                                                                "flood_unknown_unicast_enabled",
                                                                "flood_uu_disabled_mac_limit_action",
                                                                "igm_pv4_disabled",
                                                                "igm_pv4_profile_name",
                                                                "is_dai_addr_validate_destination_mac_enabled",
                                                                "is_dai_addr_validate_ipv4_enabled",
                                                                "is_dai_addr_validate_source_mac_enabled",
                                                                "is_dai_enabled",
                                                                "is_dai_logging_enabled",
                                                                "is_ip_source_guard_enabled",
                                                                "is_ipsg_logging_enabled",
                                                                "is_mac_secure_accept_shutdown_enabled",
                                                                "is_mac_secure_enabled",
                                                                "is_mac_secure_logging_enabled",
                                                                "learn_disabled_mac_limit_action",
                                                                "mac_aging_mode",
                                                                "mac_aging_time",
                                                                "mac_flooding",
                                                                "mac_learning",
                                                                "mac_limit",
                                                                "mac_limit_action",
                                                                "mac_limit_notification",
                                                                "mac_limit_reached",
                                                                "mac_port_down_flush_enabled",
                                                                "mac_secure_action",
                                                                "mld_profile_name",
                                                                "mmrp_flood_optimization",
                                                                "multicast_storm_control_kb_ps",
                                                                "multicast_storm_control_pps",
                                                                "multicast_storm_control_rate_unit",
                                                                "split_horizon_group_id",
                                                                "unicast_storm_control_kb_ps",
                                                                "unicast_storm_control_pps",
                                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__setattr__(name, value)


                                            class StormControl(Entity):
                                                """
                                                Storm Control Configuration
                                                
                                                .. attribute:: bd_policer
                                                
                                                	Bridge Domain Policer
                                                	**type**\:  bool
                                                
                                                .. attribute:: broadcast
                                                
                                                	Broadcast Storm Control
                                                	**type**\:  bool
                                                
                                                .. attribute:: multicast
                                                
                                                	Multicast Storm Control
                                                	**type**\:  bool
                                                
                                                .. attribute:: unicast
                                                
                                                	Unknown\-unicast Storm Control
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__init__()

                                                    self.yang_name = "storm-control"
                                                    self.yang_parent_name = "base"

                                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bd_policer",
                                                                    "broadcast",
                                                                    "multicast",
                                                                    "unicast") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bd_policer.is_set or
                                                        self.broadcast.is_set or
                                                        self.multicast.is_set or
                                                        self.unicast.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bd_policer.yfilter != YFilter.not_set or
                                                        self.broadcast.yfilter != YFilter.not_set or
                                                        self.multicast.yfilter != YFilter.not_set or
                                                        self.unicast.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "storm-control" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bd-policer"):
                                                        self.bd_policer = value
                                                        self.bd_policer.value_namespace = name_space
                                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "broadcast"):
                                                        self.broadcast = value
                                                        self.broadcast.value_namespace = name_space
                                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "multicast"):
                                                        self.multicast = value
                                                        self.multicast.value_namespace = name_space
                                                        self.multicast.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "unicast"):
                                                        self.unicast = value
                                                        self.unicast.value_namespace = name_space
                                                        self.unicast.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.broadcast_storm_control_kb_ps.is_set or
                                                    self.broadcast_storm_control_pps.is_set or
                                                    self.broadcast_storm_control_rate_unit.is_set or
                                                    self.dai_address_validation_mask.is_set or
                                                    self.dhcpv4_profile_name.is_set or
                                                    self.dhcpv4_snoop.is_set or
                                                    self.flood_unknown_unicast_enabled.is_set or
                                                    self.flood_uu_disabled_mac_limit_action.is_set or
                                                    self.igm_pv4_disabled.is_set or
                                                    self.igm_pv4_profile_name.is_set or
                                                    self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                                    self.is_dai_addr_validate_ipv4_enabled.is_set or
                                                    self.is_dai_addr_validate_source_mac_enabled.is_set or
                                                    self.is_dai_enabled.is_set or
                                                    self.is_dai_logging_enabled.is_set or
                                                    self.is_ip_source_guard_enabled.is_set or
                                                    self.is_ipsg_logging_enabled.is_set or
                                                    self.is_mac_secure_accept_shutdown_enabled.is_set or
                                                    self.is_mac_secure_enabled.is_set or
                                                    self.is_mac_secure_logging_enabled.is_set or
                                                    self.learn_disabled_mac_limit_action.is_set or
                                                    self.mac_aging_mode.is_set or
                                                    self.mac_aging_time.is_set or
                                                    self.mac_flooding.is_set or
                                                    self.mac_learning.is_set or
                                                    self.mac_limit.is_set or
                                                    self.mac_limit_action.is_set or
                                                    self.mac_limit_notification.is_set or
                                                    self.mac_limit_reached.is_set or
                                                    self.mac_port_down_flush_enabled.is_set or
                                                    self.mac_secure_action.is_set or
                                                    self.mld_profile_name.is_set or
                                                    self.mmrp_flood_optimization.is_set or
                                                    self.multicast_storm_control_kb_ps.is_set or
                                                    self.multicast_storm_control_pps.is_set or
                                                    self.multicast_storm_control_rate_unit.is_set or
                                                    self.split_horizon_group_id.is_set or
                                                    self.unicast_storm_control_kb_ps.is_set or
                                                    self.unicast_storm_control_pps.is_set or
                                                    self.unicast_storm_control_rate_unit.is_set or
                                                    (self.storm_control is not None and self.storm_control.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                    self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                                    self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                                    self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                                    self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                                    self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                    self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                                    self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                                    self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_enabled.yfilter != YFilter.not_set or
                                                    self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                                    self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                                    self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                                    self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                                    self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                                    self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                                    self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                    self.mac_aging_mode.yfilter != YFilter.not_set or
                                                    self.mac_aging_time.yfilter != YFilter.not_set or
                                                    self.mac_flooding.yfilter != YFilter.not_set or
                                                    self.mac_learning.yfilter != YFilter.not_set or
                                                    self.mac_limit.yfilter != YFilter.not_set or
                                                    self.mac_limit_action.yfilter != YFilter.not_set or
                                                    self.mac_limit_notification.yfilter != YFilter.not_set or
                                                    self.mac_limit_reached.yfilter != YFilter.not_set or
                                                    self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                                    self.mac_secure_action.yfilter != YFilter.not_set or
                                                    self.mld_profile_name.yfilter != YFilter.not_set or
                                                    self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                    self.split_horizon_group_id.yfilter != YFilter.not_set or
                                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                    (self.storm_control is not None and self.storm_control.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "base" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                                if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                                if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                                if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                                if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                                if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                                if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                                if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                                if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                                if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                                if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                                if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                                if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                                if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                                if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                                if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                                if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                                if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                                if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                                if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                                if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                                if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                                if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                                if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                                if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                                if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                                if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                                if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                                if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                                if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                                if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                                if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "storm-control"):
                                                    if (self.storm_control is None):
                                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                                        self.storm_control.parent = self
                                                        self._children_name_map["storm_control"] = "storm-control"
                                                    return self.storm_control

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "broadcast-storm-control-kb-ps"):
                                                    self.broadcast_storm_control_kb_ps = value
                                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast-storm-control-pps"):
                                                    self.broadcast_storm_control_pps = value
                                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast-storm-control-rate-unit"):
                                                    self.broadcast_storm_control_rate_unit = value
                                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dai-address-validation-mask"):
                                                    self.dai_address_validation_mask = value
                                                    self.dai_address_validation_mask.value_namespace = name_space
                                                    self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dhcpv4-profile-name"):
                                                    self.dhcpv4_profile_name = value
                                                    self.dhcpv4_profile_name.value_namespace = name_space
                                                    self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "dhcpv4-snoop"):
                                                    self.dhcpv4_snoop = value
                                                    self.dhcpv4_snoop.value_namespace = name_space
                                                    self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flood-unknown-unicast-enabled"):
                                                    self.flood_unknown_unicast_enabled = value
                                                    self.flood_unknown_unicast_enabled.value_namespace = name_space
                                                    self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "flood-uu-disabled-mac-limit-action"):
                                                    self.flood_uu_disabled_mac_limit_action = value
                                                    self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                                    self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                                if(value_path == "igm-pv4-disabled"):
                                                    self.igm_pv4_disabled = value
                                                    self.igm_pv4_disabled.value_namespace = name_space
                                                    self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "igm-pv4-profile-name"):
                                                    self.igm_pv4_profile_name = value
                                                    self.igm_pv4_profile_name.value_namespace = name_space
                                                    self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                                    self.is_dai_addr_validate_destination_mac_enabled = value
                                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                                    self.is_dai_addr_validate_ipv4_enabled = value
                                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                                    self.is_dai_addr_validate_source_mac_enabled = value
                                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-enabled"):
                                                    self.is_dai_enabled = value
                                                    self.is_dai_enabled.value_namespace = name_space
                                                    self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-dai-logging-enabled"):
                                                    self.is_dai_logging_enabled = value
                                                    self.is_dai_logging_enabled.value_namespace = name_space
                                                    self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-ip-source-guard-enabled"):
                                                    self.is_ip_source_guard_enabled = value
                                                    self.is_ip_source_guard_enabled.value_namespace = name_space
                                                    self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-ipsg-logging-enabled"):
                                                    self.is_ipsg_logging_enabled = value
                                                    self.is_ipsg_logging_enabled.value_namespace = name_space
                                                    self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                                    self.is_mac_secure_accept_shutdown_enabled = value
                                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-mac-secure-enabled"):
                                                    self.is_mac_secure_enabled = value
                                                    self.is_mac_secure_enabled.value_namespace = name_space
                                                    self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-mac-secure-logging-enabled"):
                                                    self.is_mac_secure_logging_enabled = value
                                                    self.is_mac_secure_logging_enabled.value_namespace = name_space
                                                    self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "learn-disabled-mac-limit-action"):
                                                    self.learn_disabled_mac_limit_action = value
                                                    self.learn_disabled_mac_limit_action.value_namespace = name_space
                                                    self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-aging-mode"):
                                                    self.mac_aging_mode = value
                                                    self.mac_aging_mode.value_namespace = name_space
                                                    self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-aging-time"):
                                                    self.mac_aging_time = value
                                                    self.mac_aging_time.value_namespace = name_space
                                                    self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-flooding"):
                                                    self.mac_flooding = value
                                                    self.mac_flooding.value_namespace = name_space
                                                    self.mac_flooding.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-learning"):
                                                    self.mac_learning = value
                                                    self.mac_learning.value_namespace = name_space
                                                    self.mac_learning.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit"):
                                                    self.mac_limit = value
                                                    self.mac_limit.value_namespace = name_space
                                                    self.mac_limit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit-action"):
                                                    self.mac_limit_action = value
                                                    self.mac_limit_action.value_namespace = name_space
                                                    self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit-notification"):
                                                    self.mac_limit_notification = value
                                                    self.mac_limit_notification.value_namespace = name_space
                                                    self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-limit-reached"):
                                                    self.mac_limit_reached = value
                                                    self.mac_limit_reached.value_namespace = name_space
                                                    self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-port-down-flush-enabled"):
                                                    self.mac_port_down_flush_enabled = value
                                                    self.mac_port_down_flush_enabled.value_namespace = name_space
                                                    self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mac-secure-action"):
                                                    self.mac_secure_action = value
                                                    self.mac_secure_action.value_namespace = name_space
                                                    self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mld-profile-name"):
                                                    self.mld_profile_name = value
                                                    self.mld_profile_name.value_namespace = name_space
                                                    self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "mmrp-flood-optimization"):
                                                    self.mmrp_flood_optimization = value
                                                    self.mmrp_flood_optimization.value_namespace = name_space
                                                    self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast-storm-control-kb-ps"):
                                                    self.multicast_storm_control_kb_ps = value
                                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast-storm-control-pps"):
                                                    self.multicast_storm_control_pps = value
                                                    self.multicast_storm_control_pps.value_namespace = name_space
                                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast-storm-control-rate-unit"):
                                                    self.multicast_storm_control_rate_unit = value
                                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                                if(value_path == "split-horizon-group-id"):
                                                    self.split_horizon_group_id = value
                                                    self.split_horizon_group_id.value_namespace = name_space
                                                    self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast-storm-control-kb-ps"):
                                                    self.unicast_storm_control_kb_ps = value
                                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast-storm-control-pps"):
                                                    self.unicast_storm_control_pps = value
                                                    self.unicast_storm_control_pps.value_namespace = name_space
                                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast-storm-control-rate-unit"):
                                                    self.unicast_storm_control_rate_unit = value
                                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "security-parameters"

                                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                self.multicast = YLeaf(YType.boolean, "multicast")

                                                self.unicast = YLeaf(YType.boolean, "unicast")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bd_policer",
                                                                "broadcast",
                                                                "multicast",
                                                                "unicast") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bd_policer.is_set or
                                                    self.broadcast.is_set or
                                                    self.multicast.is_set or
                                                    self.unicast.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bd_policer.yfilter != YFilter.not_set or
                                                    self.broadcast.yfilter != YFilter.not_set or
                                                    self.multicast.yfilter != YFilter.not_set or
                                                    self.unicast.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "storm-control" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bd-policer"):
                                                    self.bd_policer = value
                                                    self.bd_policer.value_namespace = name_space
                                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast"):
                                                    self.broadcast = value
                                                    self.broadcast.value_namespace = name_space
                                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast"):
                                                    self.multicast = value
                                                    self.multicast.value_namespace = name_space
                                                    self.multicast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast"):
                                                    self.unicast = value
                                                    self.unicast.value_namespace = name_space
                                                    self.unicast.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.broadcast_storm_control_kb_ps.is_set or
                                                self.broadcast_storm_control_pps.is_set or
                                                self.broadcast_storm_control_rate_unit.is_set or
                                                self.dhcpv4_trust.is_set or
                                                self.multicast_storm_control_kb_ps.is_set or
                                                self.multicast_storm_control_pps.is_set or
                                                self.multicast_storm_control_rate_unit.is_set or
                                                self.unicast_storm_control_kb_ps.is_set or
                                                self.unicast_storm_control_pps.is_set or
                                                self.unicast_storm_control_rate_unit.is_set or
                                                (self.base is not None and self.base.has_data()) or
                                                (self.storm_control is not None and self.storm_control.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.dhcpv4_trust.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                (self.base is not None and self.base.has_operation()) or
                                                (self.storm_control is not None and self.storm_control.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "security-parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "base"):
                                                if (self.base is None):
                                                    self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                                    self.base.parent = self
                                                    self._children_name_map["base"] = "base"
                                                return self.base

                                            if (child_yang_name == "storm-control"):
                                                if (self.storm_control is None):
                                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                                    self.storm_control.parent = self
                                                    self._children_name_map["storm_control"] = "storm-control"
                                                return self.storm_control

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "broadcast-storm-control-kb-ps"):
                                                self.broadcast_storm_control_kb_ps = value
                                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-pps"):
                                                self.broadcast_storm_control_pps = value
                                                self.broadcast_storm_control_pps.value_namespace = name_space
                                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-rate-unit"):
                                                self.broadcast_storm_control_rate_unit = value
                                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-trust"):
                                                self.dhcpv4_trust = value
                                                self.dhcpv4_trust.value_namespace = name_space
                                                self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-kb-ps"):
                                                self.multicast_storm_control_kb_ps = value
                                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-pps"):
                                                self.multicast_storm_control_pps = value
                                                self.multicast_storm_control_pps.value_namespace = name_space
                                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-rate-unit"):
                                                self.multicast_storm_control_rate_unit = value
                                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-kb-ps"):
                                                self.unicast_storm_control_kb_ps = value
                                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-pps"):
                                                self.unicast_storm_control_pps = value
                                                self.unicast_storm_control_pps.value_namespace = name_space
                                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-rate-unit"):
                                                self.unicast_storm_control_rate_unit = value
                                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.core_port_state.is_set or
                                            self.vlan_id.is_set or
                                            self.xconnect_id.is_set or
                                            (self.security_parameters is not None and self.security_parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.core_port_state.yfilter != YFilter.not_set or
                                            self.vlan_id.yfilter != YFilter.not_set or
                                            self.xconnect_id.yfilter != YFilter.not_set or
                                            (self.security_parameters is not None and self.security_parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "core-port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.core_port_state.is_set or self.core_port_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.core_port_state.get_name_leafdata())
                                        if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_id.get_name_leafdata())
                                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "security-parameters"):
                                            if (self.security_parameters is None):
                                                self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                                self.security_parameters.parent = self
                                                self._children_name_map["security_parameters"] = "security-parameters"
                                            return self.security_parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "security-parameters" or name == "core-port-state" or name == "vlan-id" or name == "xconnect-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "core-port-state"):
                                            self.core_port_state = value
                                            self.core_port_state.value_namespace = name_space
                                            self.core_port_state.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-id"):
                                            self.vlan_id = value
                                            self.vlan_id.value_namespace = name_space
                                            self.vlan_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-id"):
                                            self.xconnect_id = value
                                            self.xconnect_id.value_namespace = name_space
                                            self.xconnect_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.num_ass_edge.is_set or
                                        (self.core_port is not None and self.core_port.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.num_ass_edge.yfilter != YFilter.not_set or
                                        (self.core_port is not None and self.core_port.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pbb-core" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.num_ass_edge.is_set or self.num_ass_edge.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.num_ass_edge.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "core-port"):
                                        if (self.core_port is None):
                                            self.core_port = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                            self.core_port.parent = self
                                            self._children_name_map["core_port"] = "core-port"
                                        return self.core_port

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "core-port" or name == "num-ass-edge"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "num-ass-edge"):
                                        self.num_ass_edge = value
                                        self.num_ass_edge.value_namespace = name_space
                                        self.num_ass_edge.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.pbb_core is not None and self.pbb_core.has_data()) or
                                    (self.pbb_edge is not None and self.pbb_edge.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.pbb_core is not None and self.pbb_core.has_operation()) or
                                    (self.pbb_edge is not None and self.pbb_edge.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pbb-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "pbb-core"):
                                    if (self.pbb_core is None):
                                        self.pbb_core = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                                        self.pbb_core.parent = self
                                        self._children_name_map["pbb_core"] = "pbb-core"
                                    return self.pbb_core

                                if (child_yang_name == "pbb-edge"):
                                    if (self.pbb_edge is None):
                                        self.pbb_edge = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                                        self.pbb_edge.parent = self
                                        self._children_name_map["pbb_edge"] = "pbb-edge"
                                    return self.pbb_edge

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pbb-core" or name == "pbb-edge" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EvpnParameters(Entity):
                            """
                            EVPN parameters
                            
                            .. attribute:: evi
                            
                            	E\-VPN id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: evpn_port
                            
                            	EVPN Port
                            	**type**\:   :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__init__()

                                self.yang_name = "evpn-parameters"
                                self.yang_parent_name = "bridge-domain-info"

                                self.evi = YLeaf(YType.uint32, "evi")

                                self.evpn_port = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                                self.evpn_port.parent = self
                                self._children_name_map["evpn_port"] = "evpn-port"
                                self._children_yang_names.add("evpn-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("evi") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__setattr__(name, value)


                            class EvpnPort(Entity):
                                """
                                EVPN Port
                                
                                .. attribute:: evpn_port_state
                                
                                	EVPN Port State
                                	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__init__()

                                    self.yang_name = "evpn-port"
                                    self.yang_parent_name = "evpn-parameters"

                                    self.evpn_port_state = YLeaf(YType.enumeration, "evpn-port-state")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                    self._children_yang_names.add("security-parameters")

                                    self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._children_yang_names.add("statistics")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("evpn_port_state",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__setattr__(name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "evpn-port"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                        self._children_yang_names.add("base")

                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dhcpv4_trust",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__setattr__(name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"

                                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                            self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                            self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                            self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                            self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                            self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                            self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                            self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                            self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                            self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                            self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                            self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                            self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                            self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                            self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                            self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                            self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                            self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                            self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                            self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                            self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                            self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                            self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                            self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                            self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                            self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                            self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                            self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                            self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                            self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                            self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                            self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._children_yang_names.add("storm-control")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("broadcast_storm_control_kb_ps",
                                                            "broadcast_storm_control_pps",
                                                            "broadcast_storm_control_rate_unit",
                                                            "dai_address_validation_mask",
                                                            "dhcpv4_profile_name",
                                                            "dhcpv4_snoop",
                                                            "flood_unknown_unicast_enabled",
                                                            "flood_uu_disabled_mac_limit_action",
                                                            "igm_pv4_disabled",
                                                            "igm_pv4_profile_name",
                                                            "is_dai_addr_validate_destination_mac_enabled",
                                                            "is_dai_addr_validate_ipv4_enabled",
                                                            "is_dai_addr_validate_source_mac_enabled",
                                                            "is_dai_enabled",
                                                            "is_dai_logging_enabled",
                                                            "is_ip_source_guard_enabled",
                                                            "is_ipsg_logging_enabled",
                                                            "is_mac_secure_accept_shutdown_enabled",
                                                            "is_mac_secure_enabled",
                                                            "is_mac_secure_logging_enabled",
                                                            "learn_disabled_mac_limit_action",
                                                            "mac_aging_mode",
                                                            "mac_aging_time",
                                                            "mac_flooding",
                                                            "mac_learning",
                                                            "mac_limit",
                                                            "mac_limit_action",
                                                            "mac_limit_notification",
                                                            "mac_limit_reached",
                                                            "mac_port_down_flush_enabled",
                                                            "mac_secure_action",
                                                            "mld_profile_name",
                                                            "mmrp_flood_optimization",
                                                            "multicast_storm_control_kb_ps",
                                                            "multicast_storm_control_pps",
                                                            "multicast_storm_control_rate_unit",
                                                            "split_horizon_group_id",
                                                            "unicast_storm_control_kb_ps",
                                                            "unicast_storm_control_pps",
                                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__setattr__(name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"

                                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                                self.multicast = YLeaf(YType.boolean, "multicast")

                                                self.unicast = YLeaf(YType.boolean, "unicast")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bd_policer",
                                                                "broadcast",
                                                                "multicast",
                                                                "unicast") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bd_policer.is_set or
                                                    self.broadcast.is_set or
                                                    self.multicast.is_set or
                                                    self.unicast.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bd_policer.yfilter != YFilter.not_set or
                                                    self.broadcast.yfilter != YFilter.not_set or
                                                    self.multicast.yfilter != YFilter.not_set or
                                                    self.unicast.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "storm-control" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bd-policer"):
                                                    self.bd_policer = value
                                                    self.bd_policer.value_namespace = name_space
                                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                                if(value_path == "broadcast"):
                                                    self.broadcast = value
                                                    self.broadcast.value_namespace = name_space
                                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "multicast"):
                                                    self.multicast = value
                                                    self.multicast.value_namespace = name_space
                                                    self.multicast.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unicast"):
                                                    self.unicast = value
                                                    self.unicast.value_namespace = name_space
                                                    self.unicast.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.broadcast_storm_control_kb_ps.is_set or
                                                self.broadcast_storm_control_pps.is_set or
                                                self.broadcast_storm_control_rate_unit.is_set or
                                                self.dai_address_validation_mask.is_set or
                                                self.dhcpv4_profile_name.is_set or
                                                self.dhcpv4_snoop.is_set or
                                                self.flood_unknown_unicast_enabled.is_set or
                                                self.flood_uu_disabled_mac_limit_action.is_set or
                                                self.igm_pv4_disabled.is_set or
                                                self.igm_pv4_profile_name.is_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                                self.is_dai_addr_validate_ipv4_enabled.is_set or
                                                self.is_dai_addr_validate_source_mac_enabled.is_set or
                                                self.is_dai_enabled.is_set or
                                                self.is_dai_logging_enabled.is_set or
                                                self.is_ip_source_guard_enabled.is_set or
                                                self.is_ipsg_logging_enabled.is_set or
                                                self.is_mac_secure_accept_shutdown_enabled.is_set or
                                                self.is_mac_secure_enabled.is_set or
                                                self.is_mac_secure_logging_enabled.is_set or
                                                self.learn_disabled_mac_limit_action.is_set or
                                                self.mac_aging_mode.is_set or
                                                self.mac_aging_time.is_set or
                                                self.mac_flooding.is_set or
                                                self.mac_learning.is_set or
                                                self.mac_limit.is_set or
                                                self.mac_limit_action.is_set or
                                                self.mac_limit_notification.is_set or
                                                self.mac_limit_reached.is_set or
                                                self.mac_port_down_flush_enabled.is_set or
                                                self.mac_secure_action.is_set or
                                                self.mld_profile_name.is_set or
                                                self.mmrp_flood_optimization.is_set or
                                                self.multicast_storm_control_kb_ps.is_set or
                                                self.multicast_storm_control_pps.is_set or
                                                self.multicast_storm_control_rate_unit.is_set or
                                                self.split_horizon_group_id.is_set or
                                                self.unicast_storm_control_kb_ps.is_set or
                                                self.unicast_storm_control_pps.is_set or
                                                self.unicast_storm_control_rate_unit.is_set or
                                                (self.storm_control is not None and self.storm_control.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                                self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                                self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                                self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                                self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                                self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_enabled.yfilter != YFilter.not_set or
                                                self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                                self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                                self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                                self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_aging_mode.yfilter != YFilter.not_set or
                                                self.mac_aging_time.yfilter != YFilter.not_set or
                                                self.mac_flooding.yfilter != YFilter.not_set or
                                                self.mac_learning.yfilter != YFilter.not_set or
                                                self.mac_limit.yfilter != YFilter.not_set or
                                                self.mac_limit_action.yfilter != YFilter.not_set or
                                                self.mac_limit_notification.yfilter != YFilter.not_set or
                                                self.mac_limit_reached.yfilter != YFilter.not_set or
                                                self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                                self.mac_secure_action.yfilter != YFilter.not_set or
                                                self.mld_profile_name.yfilter != YFilter.not_set or
                                                self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                self.split_horizon_group_id.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                                (self.storm_control is not None and self.storm_control.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "base" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                            if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                            if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                            if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                            if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                            if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                            if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                            if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                            if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                            if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                            if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                            if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                            if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                            if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                            if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                            if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                            if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                            if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                            if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                            if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                            if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                            if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                            if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                            if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                            if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                            if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                            if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "storm-control"):
                                                if (self.storm_control is None):
                                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                                    self.storm_control.parent = self
                                                    self._children_name_map["storm_control"] = "storm-control"
                                                return self.storm_control

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "broadcast-storm-control-kb-ps"):
                                                self.broadcast_storm_control_kb_ps = value
                                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-pps"):
                                                self.broadcast_storm_control_pps = value
                                                self.broadcast_storm_control_pps.value_namespace = name_space
                                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast-storm-control-rate-unit"):
                                                self.broadcast_storm_control_rate_unit = value
                                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dai-address-validation-mask"):
                                                self.dai_address_validation_mask = value
                                                self.dai_address_validation_mask.value_namespace = name_space
                                                self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-profile-name"):
                                                self.dhcpv4_profile_name = value
                                                self.dhcpv4_profile_name.value_namespace = name_space
                                                self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "dhcpv4-snoop"):
                                                self.dhcpv4_snoop = value
                                                self.dhcpv4_snoop.value_namespace = name_space
                                                self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-unknown-unicast-enabled"):
                                                self.flood_unknown_unicast_enabled = value
                                                self.flood_unknown_unicast_enabled.value_namespace = name_space
                                                self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "flood-uu-disabled-mac-limit-action"):
                                                self.flood_uu_disabled_mac_limit_action = value
                                                self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                                self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-disabled"):
                                                self.igm_pv4_disabled = value
                                                self.igm_pv4_disabled.value_namespace = name_space
                                                self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "igm-pv4-profile-name"):
                                                self.igm_pv4_profile_name = value
                                                self.igm_pv4_profile_name.value_namespace = name_space
                                                self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                                self.is_dai_addr_validate_destination_mac_enabled = value
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                                self.is_dai_addr_validate_ipv4_enabled = value
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                                self.is_dai_addr_validate_source_mac_enabled = value
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                                self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-enabled"):
                                                self.is_dai_enabled = value
                                                self.is_dai_enabled.value_namespace = name_space
                                                self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-dai-logging-enabled"):
                                                self.is_dai_logging_enabled = value
                                                self.is_dai_logging_enabled.value_namespace = name_space
                                                self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ip-source-guard-enabled"):
                                                self.is_ip_source_guard_enabled = value
                                                self.is_ip_source_guard_enabled.value_namespace = name_space
                                                self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-ipsg-logging-enabled"):
                                                self.is_ipsg_logging_enabled = value
                                                self.is_ipsg_logging_enabled.value_namespace = name_space
                                                self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                                self.is_mac_secure_accept_shutdown_enabled = value
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                                self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-enabled"):
                                                self.is_mac_secure_enabled = value
                                                self.is_mac_secure_enabled.value_namespace = name_space
                                                self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-mac-secure-logging-enabled"):
                                                self.is_mac_secure_logging_enabled = value
                                                self.is_mac_secure_logging_enabled.value_namespace = name_space
                                                self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "learn-disabled-mac-limit-action"):
                                                self.learn_disabled_mac_limit_action = value
                                                self.learn_disabled_mac_limit_action.value_namespace = name_space
                                                self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-mode"):
                                                self.mac_aging_mode = value
                                                self.mac_aging_mode.value_namespace = name_space
                                                self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-aging-time"):
                                                self.mac_aging_time = value
                                                self.mac_aging_time.value_namespace = name_space
                                                self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-flooding"):
                                                self.mac_flooding = value
                                                self.mac_flooding.value_namespace = name_space
                                                self.mac_flooding.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-learning"):
                                                self.mac_learning = value
                                                self.mac_learning.value_namespace = name_space
                                                self.mac_learning.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit"):
                                                self.mac_limit = value
                                                self.mac_limit.value_namespace = name_space
                                                self.mac_limit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-action"):
                                                self.mac_limit_action = value
                                                self.mac_limit_action.value_namespace = name_space
                                                self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-notification"):
                                                self.mac_limit_notification = value
                                                self.mac_limit_notification.value_namespace = name_space
                                                self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-limit-reached"):
                                                self.mac_limit_reached = value
                                                self.mac_limit_reached.value_namespace = name_space
                                                self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-port-down-flush-enabled"):
                                                self.mac_port_down_flush_enabled = value
                                                self.mac_port_down_flush_enabled.value_namespace = name_space
                                                self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mac-secure-action"):
                                                self.mac_secure_action = value
                                                self.mac_secure_action.value_namespace = name_space
                                                self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mld-profile-name"):
                                                self.mld_profile_name = value
                                                self.mld_profile_name.value_namespace = name_space
                                                self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "mmrp-flood-optimization"):
                                                self.mmrp_flood_optimization = value
                                                self.mmrp_flood_optimization.value_namespace = name_space
                                                self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-kb-ps"):
                                                self.multicast_storm_control_kb_ps = value
                                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-pps"):
                                                self.multicast_storm_control_pps = value
                                                self.multicast_storm_control_pps.value_namespace = name_space
                                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-storm-control-rate-unit"):
                                                self.multicast_storm_control_rate_unit = value
                                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                            if(value_path == "split-horizon-group-id"):
                                                self.split_horizon_group_id = value
                                                self.split_horizon_group_id.value_namespace = name_space
                                                self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-kb-ps"):
                                                self.unicast_storm_control_kb_ps = value
                                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-pps"):
                                                self.unicast_storm_control_pps = value
                                                self.unicast_storm_control_pps.value_namespace = name_space
                                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast-storm-control-rate-unit"):
                                                self.unicast_storm_control_rate_unit = value
                                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dhcpv4_trust.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.base is not None and self.base.has_data()) or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dhcpv4_trust.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.base is not None and self.base.has_operation()) or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security-parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "base"):
                                            if (self.base is None):
                                                self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                                self.base.parent = self
                                                self._children_name_map["base"] = "base"
                                            return self.base

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-trust"):
                                            self.dhcpv4_trust = value
                                            self.dhcpv4_trust.value_namespace = name_space
                                            self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "evpn-port"

                                        self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        self._children_yang_names.add("dispostion-stats")

                                        self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                        self._children_yang_names.add("impostion-stats")

                                        self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._children_yang_names.add("sequence-number")


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                            self._children_yang_names.add("broadcast")

                                            self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            self._children_yang_names.add("imposition-mtu-drop")

                                            self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                            self._children_yang_names.add("imposition-stat")

                                            self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            self._children_yang_names.add("impostion-tail-drop")

                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            self._children_yang_names.add("l2fsbi-drop")

                                            self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                            self._children_yang_names.add("multicast")

                                            self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._children_yang_names.add("unknown-unicast")


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class L2FsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2fsbi-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast is not None and self.broadcast.has_data()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                (self.multicast is not None and self.multicast.has_data()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast is not None and self.broadcast.has_operation()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                (self.multicast is not None and self.multicast.has_operation()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast"):
                                                if (self.broadcast is None):
                                                    self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                                    self.broadcast.parent = self
                                                    self._children_name_map["broadcast"] = "broadcast"
                                                return self.broadcast

                                            if (child_yang_name == "imposition-mtu-drop"):
                                                if (self.imposition_mtu_drop is None):
                                                    self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                    self.imposition_mtu_drop.parent = self
                                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                return self.imposition_mtu_drop

                                            if (child_yang_name == "imposition-stat"):
                                                if (self.imposition_stat is None):
                                                    self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                                    self.imposition_stat.parent = self
                                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                                return self.imposition_stat

                                            if (child_yang_name == "impostion-tail-drop"):
                                                if (self.impostion_tail_drop is None):
                                                    self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                                    self.impostion_tail_drop.parent = self
                                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                return self.impostion_tail_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "l2fsbi-drop"):
                                                if (self.l2fsbi_drop is None):
                                                    self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                                    self.l2fsbi_drop.parent = self
                                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                return self.l2fsbi_drop

                                            if (child_yang_name == "multicast"):
                                                if (self.multicast is None):
                                                    self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                                    self.multicast.parent = self
                                                    self._children_name_map["multicast"] = "multicast"
                                                return self.multicast

                                            if (child_yang_name == "unknown-unicast"):
                                                if (self.unknown_unicast is None):
                                                    self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                                    self.unknown_unicast.parent = self
                                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                return self.unknown_unicast

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            self._children_yang_names.add("broadcast-drop")

                                            self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                            self._children_yang_names.add("dai-drop")

                                            self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            self._children_yang_names.add("disposition-mtu-drop")

                                            self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            self._children_yang_names.add("disposition-oo-o-drops")

                                            self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            self._children_yang_names.add("disposition-p2mp-stats")

                                            self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                            self._children_yang_names.add("disposition-stat")

                                            self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            self._children_yang_names.add("disposition-tail-drop")

                                            self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            self._children_yang_names.add("ipsg-drop")

                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._children_yang_names.add("mac-move")

                                            self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                            self._children_yang_names.add("multicast-drop")

                                            self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                            self._children_yang_names.add("received-drops")

                                            self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                            self._children_yang_names.add("unicast-drop")


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "received-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dai-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipsg-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-oo-o-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionP2MpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-p2mp-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mac-move" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.mac_move is not None and self.mac_move.has_data()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                (self.received_drops is not None and self.received_drops.has_data()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.mac_move is not None and self.mac_move.has_operation()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                (self.received_drops is not None and self.received_drops.has_operation()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dispostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast-drop"):
                                                if (self.broadcast_drop is None):
                                                    self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                                    self.broadcast_drop.parent = self
                                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                return self.broadcast_drop

                                            if (child_yang_name == "dai-drop"):
                                                if (self.dai_drop is None):
                                                    self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                                    self.dai_drop.parent = self
                                                    self._children_name_map["dai_drop"] = "dai-drop"
                                                return self.dai_drop

                                            if (child_yang_name == "disposition-mtu-drop"):
                                                if (self.disposition_mtu_drop is None):
                                                    self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                                    self.disposition_mtu_drop.parent = self
                                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                return self.disposition_mtu_drop

                                            if (child_yang_name == "disposition-oo-o-drops"):
                                                if (self.disposition_oo_o_drops is None):
                                                    self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                                    self.disposition_oo_o_drops.parent = self
                                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                return self.disposition_oo_o_drops

                                            if (child_yang_name == "disposition-p2mp-stats"):
                                                if (self.disposition_p2mp_stats is None):
                                                    self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                                    self.disposition_p2mp_stats.parent = self
                                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                return self.disposition_p2mp_stats

                                            if (child_yang_name == "disposition-stat"):
                                                if (self.disposition_stat is None):
                                                    self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                                    self.disposition_stat.parent = self
                                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                                return self.disposition_stat

                                            if (child_yang_name == "disposition-tail-drop"):
                                                if (self.disposition_tail_drop is None):
                                                    self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                                    self.disposition_tail_drop.parent = self
                                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                return self.disposition_tail_drop

                                            if (child_yang_name == "ipsg-drop"):
                                                if (self.ipsg_drop is None):
                                                    self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                                    self.ipsg_drop.parent = self
                                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                return self.ipsg_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "mac-move"):
                                                if (self.mac_move is None):
                                                    self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                                    self.mac_move.parent = self
                                                    self._children_name_map["mac_move"] = "mac-move"
                                                return self.mac_move

                                            if (child_yang_name == "multicast-drop"):
                                                if (self.multicast_drop is None):
                                                    self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                                    self.multicast_drop.parent = self
                                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                                return self.multicast_drop

                                            if (child_yang_name == "received-drops"):
                                                if (self.received_drops is None):
                                                    self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                                    self.received_drops.parent = self
                                                    self._children_name_map["received_drops"] = "received-drops"
                                                return self.received_drops

                                            if (child_yang_name == "unicast-drop"):
                                                if (self.unicast_drop is None):
                                                    self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                                    self.unicast_drop.parent = self
                                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                                return self.unicast_drop

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"

                                            self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                            self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                            self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                            self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bypassed_inbound_sequence_packet",
                                                            "bypassed_out_sequence_packet",
                                                            "sequence_number_expected",
                                                            "sequence_number_sent") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bypassed_inbound_sequence_packet.is_set or
                                                self.bypassed_out_sequence_packet.is_set or
                                                self.sequence_number_expected.is_set or
                                                self.sequence_number_sent.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                self.sequence_number_expected.yfilter != YFilter.not_set or
                                                self.sequence_number_sent.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sequence-number" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                            if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                            if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                            if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bypassed-inbound-sequence-packet"):
                                                self.bypassed_inbound_sequence_packet = value
                                                self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bypassed-out-sequence-packet"):
                                                self.bypassed_out_sequence_packet = value
                                                self.bypassed_out_sequence_packet.value_namespace = name_space
                                                self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-expected"):
                                                self.sequence_number_expected = value
                                                self.sequence_number_expected.value_namespace = name_space
                                                self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-sent"):
                                                self.sequence_number_sent = value
                                                self.sequence_number_sent.value_namespace = name_space
                                                self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                            (self.sequence_number is not None and self.sequence_number.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                            (self.sequence_number is not None and self.sequence_number.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "statistics" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dispostion-stats"):
                                            if (self.dispostion_stats is None):
                                                self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                                self.dispostion_stats.parent = self
                                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            return self.dispostion_stats

                                        if (child_yang_name == "impostion-stats"):
                                            if (self.impostion_stats is None):
                                                self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                                self.impostion_stats.parent = self
                                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                            return self.impostion_stats

                                        if (child_yang_name == "sequence-number"):
                                            if (self.sequence_number is None):
                                                self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                                self.sequence_number.parent = self
                                                self._children_name_map["sequence_number"] = "sequence-number"
                                            return self.sequence_number

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.evpn_port_state.is_set or
                                        self.xconnect_id.is_set or
                                        (self.security_parameters is not None and self.security_parameters.has_data()) or
                                        (self.statistics is not None and self.statistics.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.evpn_port_state.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                        (self.statistics is not None and self.statistics.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "evpn-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.evpn_port_state.is_set or self.evpn_port_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.evpn_port_state.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "security-parameters"):
                                        if (self.security_parameters is None):
                                            self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                            self.security_parameters.parent = self
                                            self._children_name_map["security_parameters"] = "security-parameters"
                                        return self.security_parameters

                                    if (child_yang_name == "statistics"):
                                        if (self.statistics is None):
                                            self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                            self.statistics.parent = self
                                            self._children_name_map["statistics"] = "statistics"
                                        return self.statistics

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "security-parameters" or name == "statistics" or name == "evpn-port-state" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "evpn-port-state"):
                                        self.evpn_port_state = value
                                        self.evpn_port_state.value_namespace = name_space
                                        self.evpn_port_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.evi.is_set or
                                    (self.evpn_port is not None and self.evpn_port.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.evi.yfilter != YFilter.not_set or
                                    (self.evpn_port is not None and self.evpn_port.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "evpn-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evi.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "evpn-port"):
                                    if (self.evpn_port is None):
                                        self.evpn_port = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                                        self.evpn_port.parent = self
                                        self._children_name_map["evpn_port"] = "evpn-port"
                                    return self.evpn_port

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "evpn-port" or name == "evi"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "evi"):
                                    self.evi = value
                                    self.evi.value_namespace = name_space
                                    self.evi.value_namespace_prefix = name_space_prefix


                        class VniParameters(Entity):
                            """
                            VNI parameters
                            
                            .. attribute:: anycast_mcast_group_addr
                            
                            	Anycast Multicast Group Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_vtep_ip_addr
                            
                            	Anycast VTEP IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: multicast_group_addr
                            
                            	Multicast Group Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: overlay
                            
                            	NVE Overlay
                            	**type**\:  str
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                            
                            .. attribute:: source_ip_addr
                            
                            	Source IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vni
                            
                            	VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vni_encap_type
                            
                            	VNI Encapsulation Type
                            	**type**\:   :py:class:`L2VpnVniEncaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniEncaps>`
                            
                            .. attribute:: vni_mode
                            
                            	VNI Mode
                            	**type**\:   :py:class:`L2VpnVniMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniMode>`
                            
                            .. attribute:: vni_port_state
                            
                            	VNI Port State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__init__()

                                self.yang_name = "vni-parameters"
                                self.yang_parent_name = "bridge-domain-info"

                                self.anycast_mcast_group_addr = YLeaf(YType.str, "anycast-mcast-group-addr")

                                self.anycast_vtep_ip_addr = YLeaf(YType.str, "anycast-vtep-ip-addr")

                                self.multicast_group_addr = YLeaf(YType.str, "multicast-group-addr")

                                self.overlay = YLeaf(YType.str, "overlay")

                                self.source_ip_addr = YLeaf(YType.str, "source-ip-addr")

                                self.udp_port = YLeaf(YType.uint32, "udp-port")

                                self.vni = YLeaf(YType.uint32, "vni")

                                self.vni_encap_type = YLeaf(YType.enumeration, "vni-encap-type")

                                self.vni_mode = YLeaf(YType.enumeration, "vni-mode")

                                self.vni_port_state = YLeaf(YType.enumeration, "vni-port-state")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                                self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                                self.static_mac = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("anycast_mcast_group_addr",
                                                "anycast_vtep_ip_addr",
                                                "multicast_group_addr",
                                                "overlay",
                                                "source_ip_addr",
                                                "udp_port",
                                                "vni",
                                                "vni_encap_type",
                                                "vni_mode",
                                                "vni_port_state",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__setattr__(name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "vni-parameters"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "vni-parameters"

                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "vni-parameters"

                                    self.address = YLeaf(YType.str, "address")

                                    self.bmac = YLeaf(YType.str, "bmac")

                                    self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "bmac",
                                                    "next_hop_ip") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.bmac.is_set or
                                        self.next_hop_ip.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.bmac.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "static-mac" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bmac.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bmac"):
                                        self.bmac = value
                                        self.bmac.value_namespace = name_space
                                        self.bmac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.static_mac:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.anycast_mcast_group_addr.is_set or
                                    self.anycast_vtep_ip_addr.is_set or
                                    self.multicast_group_addr.is_set or
                                    self.overlay.is_set or
                                    self.source_ip_addr.is_set or
                                    self.udp_port.is_set or
                                    self.vni.is_set or
                                    self.vni_encap_type.is_set or
                                    self.vni_mode.is_set or
                                    self.vni_port_state.is_set or
                                    self.xconnect_id.is_set or
                                    (self.security_parameters is not None and self.security_parameters.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                for c in self.static_mac:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.anycast_mcast_group_addr.yfilter != YFilter.not_set or
                                    self.anycast_vtep_ip_addr.yfilter != YFilter.not_set or
                                    self.multicast_group_addr.yfilter != YFilter.not_set or
                                    self.overlay.yfilter != YFilter.not_set or
                                    self.source_ip_addr.yfilter != YFilter.not_set or
                                    self.udp_port.yfilter != YFilter.not_set or
                                    self.vni.yfilter != YFilter.not_set or
                                    self.vni_encap_type.yfilter != YFilter.not_set or
                                    self.vni_mode.yfilter != YFilter.not_set or
                                    self.vni_port_state.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vni-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.anycast_mcast_group_addr.is_set or self.anycast_mcast_group_addr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.anycast_mcast_group_addr.get_name_leafdata())
                                if (self.anycast_vtep_ip_addr.is_set or self.anycast_vtep_ip_addr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.anycast_vtep_ip_addr.get_name_leafdata())
                                if (self.multicast_group_addr.is_set or self.multicast_group_addr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_group_addr.get_name_leafdata())
                                if (self.overlay.is_set or self.overlay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.overlay.get_name_leafdata())
                                if (self.source_ip_addr.is_set or self.source_ip_addr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_ip_addr.get_name_leafdata())
                                if (self.udp_port.is_set or self.udp_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.udp_port.get_name_leafdata())
                                if (self.vni.is_set or self.vni.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vni.get_name_leafdata())
                                if (self.vni_encap_type.is_set or self.vni_encap_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vni_encap_type.get_name_leafdata())
                                if (self.vni_mode.is_set or self.vni_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vni_mode.get_name_leafdata())
                                if (self.vni_port_state.is_set or self.vni_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vni_port_state.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                if (child_yang_name == "static-mac"):
                                    for c in self.static_mac:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.static_mac.append(c)
                                    return c

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "security-parameters" or name == "static-mac" or name == "statistics" or name == "anycast-mcast-group-addr" or name == "anycast-vtep-ip-addr" or name == "multicast-group-addr" or name == "overlay" or name == "source-ip-addr" or name == "udp-port" or name == "vni" or name == "vni-encap-type" or name == "vni-mode" or name == "vni-port-state" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "anycast-mcast-group-addr"):
                                    self.anycast_mcast_group_addr = value
                                    self.anycast_mcast_group_addr.value_namespace = name_space
                                    self.anycast_mcast_group_addr.value_namespace_prefix = name_space_prefix
                                if(value_path == "anycast-vtep-ip-addr"):
                                    self.anycast_vtep_ip_addr = value
                                    self.anycast_vtep_ip_addr.value_namespace = name_space
                                    self.anycast_vtep_ip_addr.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-group-addr"):
                                    self.multicast_group_addr = value
                                    self.multicast_group_addr.value_namespace = name_space
                                    self.multicast_group_addr.value_namespace_prefix = name_space_prefix
                                if(value_path == "overlay"):
                                    self.overlay = value
                                    self.overlay.value_namespace = name_space
                                    self.overlay.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-ip-addr"):
                                    self.source_ip_addr = value
                                    self.source_ip_addr.value_namespace = name_space
                                    self.source_ip_addr.value_namespace_prefix = name_space_prefix
                                if(value_path == "udp-port"):
                                    self.udp_port = value
                                    self.udp_port.value_namespace = name_space
                                    self.udp_port.value_namespace_prefix = name_space_prefix
                                if(value_path == "vni"):
                                    self.vni = value
                                    self.vni.value_namespace = name_space
                                    self.vni.value_namespace_prefix = name_space_prefix
                                if(value_path == "vni-encap-type"):
                                    self.vni_encap_type = value
                                    self.vni_encap_type.value_namespace = name_space
                                    self.vni_encap_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "vni-mode"):
                                    self.vni_mode = value
                                    self.vni_mode.value_namespace = name_space
                                    self.vni_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "vni-port-state"):
                                    self.vni_port_state = value
                                    self.vni_port_state.value_namespace = name_space
                                    self.vni_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class Rd(Entity):
                            """
                            Route Distinguisher
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                            
                            .. attribute:: rd
                            
                            	RD
                            	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__init__()

                                self.yang_name = "rd"
                                self.yang_parent_name = "bridge-domain-info"

                                self.rd = YLeaf(YType.enumeration, "rd")

                                self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                                self._children_yang_names.add("auto")

                                self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                self._children_yang_names.add("four-byte-as")

                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rd") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__setattr__(name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: auto_index
                                
                                	Auto\-generated Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: router_id
                                
                                	BGP Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "rd"

                                    self.auto_index = YLeaf(YType.uint16, "auto-index")

                                    self.router_id = YLeaf(YType.str, "router-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("auto_index",
                                                    "router_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.auto_index.is_set or
                                        self.router_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.auto_index.yfilter != YFilter.not_set or
                                        self.router_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "auto" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.auto_index.get_name_leafdata())
                                    if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto-index" or name == "router-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "auto-index"):
                                        self.auto_index = value
                                        self.auto_index.value_namespace = name_space
                                        self.auto_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router-id"):
                                        self.router_id = value
                                        self.router_id.value_namespace = name_space
                                        self.router_id.value_namespace_prefix = name_space_prefix


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "rd"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "rd"

                                    self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_as",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_as.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_as.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "four-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-as" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-as"):
                                        self.four_byte_as = value
                                        self.four_byte_as.value_namespace = name_space
                                        self.four_byte_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "rd"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rd.is_set or
                                    (self.auto is not None and self.auto.has_data()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rd.yfilter != YFilter.not_set or
                                    (self.auto is not None and self.auto.has_operation()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rd" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rd.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "auto"):
                                    if (self.auto is None):
                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                    return self.auto

                                if (child_yang_name == "four-byte-as"):
                                    if (self.four_byte_as is None):
                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                    return self.four_byte_as

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rd"):
                                    self.rd = value
                                    self.rd.value_namespace = name_space
                                    self.rd.value_namespace_prefix = name_space_prefix


                        class MacFilter(Entity):
                            """
                            MAC addresses for filtering
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__init__()

                                self.yang_name = "mac-filter"
                                self.yang_parent_name = "bridge-domain-info"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mac-filter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix


                        class BridgeVfi(Entity):
                            """
                            Virtual Forwarding Interfaces
                            
                            .. attribute:: access
                            
                            	VFI is an Access VFI
                            	**type**\:  bool
                            
                            .. attribute:: discovery_information
                            
                            	Auto Discovery information
                            	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                            
                            .. attribute:: number_pseudowires
                            
                            	Number of Pseudowires
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_information
                            
                            	Multicast P2MP information
                            	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: vfi_name
                            
                            	Virtual forwarding instance name
                            	**type**\:  str
                            
                            .. attribute:: vfi_state
                            
                            	VFI state
                            	**type**\:   :py:class:`L2VpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__init__()

                                self.yang_name = "bridge-vfi"
                                self.yang_parent_name = "bridge-domain-info"

                                self.access = YLeaf(YType.boolean, "access")

                                self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.vfi_name = YLeaf(YType.str, "vfi-name")

                                self.vfi_state = YLeaf(YType.enumeration, "vfi-state")

                                self.discovery_information = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                                self.discovery_information.parent = self
                                self._children_name_map["discovery_information"] = "discovery-information"
                                self._children_yang_names.add("discovery-information")

                                self.p2mp_information = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("access",
                                                "number_pseudowires",
                                                "shutdown",
                                                "vfi_name",
                                                "vfi_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__setattr__(name, value)


                            class DiscoveryInformation(Entity):
                                """
                                Auto Discovery information
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_signalling_method
                                
                                	Signaling protocol
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_number
                                
                                	Autonomous System Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: export_route_policy
                                
                                	Export Route Policy
                                	**type**\:  str
                                
                                .. attribute:: export_rt
                                
                                	List of export route targets
                                	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                                
                                .. attribute:: import_rt
                                
                                	List of import route targets
                                	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                                
                                .. attribute:: l2vpn_router_id
                                
                                	L2PVN Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: provisioned_ve_id
                                
                                	Provisioned VPLS edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rd_value
                                
                                	Route Distinguisher
                                	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                                
                                .. attribute:: service_connected
                                
                                	Is the BGP service connected?
                                	**type**\:  bool
                                
                                .. attribute:: ve_id
                                
                                	VPLS Edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ve_range
                                
                                	VE range
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpls_id
                                
                                	VPLS ID
                                	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                                
                                .. attribute:: vpls_id_conflict
                                
                                	VPLS\-ID Conflict
                                	**type**\:  bool
                                
                                .. attribute:: vpn_added
                                
                                	Is VPN id configured
                                	**type**\:  bool
                                
                                .. attribute:: vpn_id
                                
                                	Vpn ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__init__()

                                    self.yang_name = "discovery-information"
                                    self.yang_parent_name = "bridge-vfi"

                                    self.ad_method = YLeaf(YType.uint32, "ad-method")

                                    self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                                    self.as_number = YLeaf(YType.uint32, "as-number")

                                    self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                                    self.l2vpn_router_id = YLeaf(YType.str, "l2vpn-router-id")

                                    self.provisioned_ve_id = YLeaf(YType.uint32, "provisioned-ve-id")

                                    self.service_connected = YLeaf(YType.boolean, "service-connected")

                                    self.ve_id = YLeaf(YType.uint32, "ve-id")

                                    self.ve_range = YLeaf(YType.uint16, "ve-range")

                                    self.vpls_id_conflict = YLeaf(YType.boolean, "vpls-id-conflict")

                                    self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    self.rd_value = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                    self.rd_value.parent = self
                                    self._children_name_map["rd_value"] = "rd-value"
                                    self._children_yang_names.add("rd-value")

                                    self.vpls_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                    self.vpls_id.parent = self
                                    self._children_name_map["vpls_id"] = "vpls-id"
                                    self._children_yang_names.add("vpls-id")

                                    self.export_rt = YList(self)
                                    self.import_rt = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ad_method",
                                                    "ad_signalling_method",
                                                    "as_number",
                                                    "export_route_policy",
                                                    "l2vpn_router_id",
                                                    "provisioned_ve_id",
                                                    "service_connected",
                                                    "ve_id",
                                                    "ve_range",
                                                    "vpls_id_conflict",
                                                    "vpn_added",
                                                    "vpn_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__setattr__(name, value)


                                class RdValue(Entity):
                                    """
                                    Route Distinguisher
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                    
                                    .. attribute:: rd
                                    
                                    	RD
                                    	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__init__()

                                        self.yang_name = "rd-value"
                                        self.yang_parent_name = "discovery-information"

                                        self.rd = YLeaf(YType.enumeration, "rd")

                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                        self._children_yang_names.add("four-byte-as")

                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("rd") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: auto_index
                                        
                                        	Auto\-generated Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: router_id
                                        
                                        	BGP Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "rd-value"

                                            self.auto_index = YLeaf(YType.uint16, "auto-index")

                                            self.router_id = YLeaf(YType.str, "router-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("auto_index",
                                                            "router_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.auto_index.is_set or
                                                self.router_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.auto_index.yfilter != YFilter.not_set or
                                                self.router_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.auto_index.get_name_leafdata())
                                            if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.router_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto-index" or name == "router-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "auto-index"):
                                                self.auto_index = value
                                                self.auto_index.value_namespace = name_space
                                                self.auto_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "router-id"):
                                                self.router_id = value
                                                self.router_id.value_namespace = name_space
                                                self.router_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "rd-value"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "rd-value"

                                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_as",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_as.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_as.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "four-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-as" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-as"):
                                                self.four_byte_as = value
                                                self.four_byte_as.value_namespace = name_space
                                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "rd-value"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.rd.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.rd.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rd-value" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rd.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "four-byte-as"):
                                            if (self.four_byte_as is None):
                                                self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                                self.four_byte_as.parent = self
                                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                            return self.four_byte_as

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "rd"):
                                            self.rd = value
                                            self.rd.value_namespace = name_space
                                            self.rd.value_namespace_prefix = name_space_prefix


                                class VplsId(Entity):
                                    """
                                    VPLS ID
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__init__()

                                        self.yang_name = "vpls-id"
                                        self.yang_parent_name = "discovery-information"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "vpls-id"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "vpls-id"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "vpls-id"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vpls-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class ImportRt(Entity):
                                    """
                                    List of import route targets
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__init__()

                                        self.yang_name = "import-rt"
                                        self.yang_parent_name = "discovery-information"

                                        self.rt = YLeaf(YType.enumeration, "rt")

                                        self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                        self._children_yang_names.add("es-import")

                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                        self._children_yang_names.add("four-byte-as")

                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("rt") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "import-rt"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "import-rt"

                                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_as",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_as.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_as.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "four-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-as" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-as"):
                                                self.four_byte_as = value
                                                self.four_byte_as.value_namespace = name_space
                                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "import-rt"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                                    class EsImport(Entity):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                            self.yang_name = "es-import"
                                            self.yang_parent_name = "import-rt"

                                            self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                            self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("high_bytes",
                                                            "low_bytes") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.high_bytes.is_set or
                                                self.low_bytes.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.high_bytes.yfilter != YFilter.not_set or
                                                self.low_bytes.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "es-import" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                            if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "high-bytes" or name == "low-bytes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "high-bytes"):
                                                self.high_bytes = value
                                                self.high_bytes.value_namespace = name_space
                                                self.high_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "low-bytes"):
                                                self.low_bytes = value
                                                self.low_bytes.value_namespace = name_space
                                                self.low_bytes.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.rt.is_set or
                                            (self.es_import is not None and self.es_import.has_data()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.rt.yfilter != YFilter.not_set or
                                            (self.es_import is not None and self.es_import.has_operation()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "import-rt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rt.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "es-import"):
                                            if (self.es_import is None):
                                                self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                                self.es_import.parent = self
                                                self._children_name_map["es_import"] = "es-import"
                                            return self.es_import

                                        if (child_yang_name == "four-byte-as"):
                                            if (self.four_byte_as is None):
                                                self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                                self.four_byte_as.parent = self
                                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                            return self.four_byte_as

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "rt"):
                                            self.rt = value
                                            self.rt.value_namespace = name_space
                                            self.rt.value_namespace_prefix = name_space_prefix


                                class ExportRt(Entity):
                                    """
                                    List of export route targets
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__init__()

                                        self.yang_name = "export-rt"
                                        self.yang_parent_name = "discovery-information"

                                        self.rt = YLeaf(YType.enumeration, "rt")

                                        self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                        self._children_yang_names.add("es-import")

                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                        self._children_yang_names.add("four-byte-as")

                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("rt") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "export-rt"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "export-rt"

                                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_as",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_as.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_as.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "four-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-as" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-as"):
                                                self.four_byte_as = value
                                                self.four_byte_as.value_namespace = name_space
                                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "export-rt"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                                    class EsImport(Entity):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                            self.yang_name = "es-import"
                                            self.yang_parent_name = "export-rt"

                                            self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                            self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("high_bytes",
                                                            "low_bytes") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.high_bytes.is_set or
                                                self.low_bytes.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.high_bytes.yfilter != YFilter.not_set or
                                                self.low_bytes.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "es-import" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                            if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "high-bytes" or name == "low-bytes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "high-bytes"):
                                                self.high_bytes = value
                                                self.high_bytes.value_namespace = name_space
                                                self.high_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "low-bytes"):
                                                self.low_bytes = value
                                                self.low_bytes.value_namespace = name_space
                                                self.low_bytes.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.rt.is_set or
                                            (self.es_import is not None and self.es_import.has_data()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.rt.yfilter != YFilter.not_set or
                                            (self.es_import is not None and self.es_import.has_operation()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "export-rt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rt.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "es-import"):
                                            if (self.es_import is None):
                                                self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                                self.es_import.parent = self
                                                self._children_name_map["es_import"] = "es-import"
                                            return self.es_import

                                        if (child_yang_name == "four-byte-as"):
                                            if (self.four_byte_as is None):
                                                self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                                self.four_byte_as.parent = self
                                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                            return self.four_byte_as

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "rt"):
                                            self.rt = value
                                            self.rt.value_namespace = name_space
                                            self.rt.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.export_rt:
                                        if (c.has_data()):
                                            return True
                                    for c in self.import_rt:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.ad_method.is_set or
                                        self.ad_signalling_method.is_set or
                                        self.as_number.is_set or
                                        self.export_route_policy.is_set or
                                        self.l2vpn_router_id.is_set or
                                        self.provisioned_ve_id.is_set or
                                        self.service_connected.is_set or
                                        self.ve_id.is_set or
                                        self.ve_range.is_set or
                                        self.vpls_id_conflict.is_set or
                                        self.vpn_added.is_set or
                                        self.vpn_id.is_set or
                                        (self.rd_value is not None and self.rd_value.has_data()) or
                                        (self.vpls_id is not None and self.vpls_id.has_data()))

                                def has_operation(self):
                                    for c in self.export_rt:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.import_rt:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ad_method.yfilter != YFilter.not_set or
                                        self.ad_signalling_method.yfilter != YFilter.not_set or
                                        self.as_number.yfilter != YFilter.not_set or
                                        self.export_route_policy.yfilter != YFilter.not_set or
                                        self.l2vpn_router_id.yfilter != YFilter.not_set or
                                        self.provisioned_ve_id.yfilter != YFilter.not_set or
                                        self.service_connected.yfilter != YFilter.not_set or
                                        self.ve_id.yfilter != YFilter.not_set or
                                        self.ve_range.yfilter != YFilter.not_set or
                                        self.vpls_id_conflict.yfilter != YFilter.not_set or
                                        self.vpn_added.yfilter != YFilter.not_set or
                                        self.vpn_id.yfilter != YFilter.not_set or
                                        (self.rd_value is not None and self.rd_value.has_operation()) or
                                        (self.vpls_id is not None and self.vpls_id.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "discovery-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_method.get_name_leafdata())
                                    if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                                    if (self.as_number.is_set or self.as_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_number.get_name_leafdata())
                                    if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                                    if (self.l2vpn_router_id.is_set or self.l2vpn_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2vpn_router_id.get_name_leafdata())
                                    if (self.provisioned_ve_id.is_set or self.provisioned_ve_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.provisioned_ve_id.get_name_leafdata())
                                    if (self.service_connected.is_set or self.service_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.service_connected.get_name_leafdata())
                                    if (self.ve_id.is_set or self.ve_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ve_id.get_name_leafdata())
                                    if (self.ve_range.is_set or self.ve_range.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ve_range.get_name_leafdata())
                                    if (self.vpls_id_conflict.is_set or self.vpls_id_conflict.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_conflict.get_name_leafdata())
                                    if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpn_added.get_name_leafdata())
                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "export-rt"):
                                        for c in self.export_rt:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.export_rt.append(c)
                                        return c

                                    if (child_yang_name == "import-rt"):
                                        for c in self.import_rt:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.import_rt.append(c)
                                        return c

                                    if (child_yang_name == "rd-value"):
                                        if (self.rd_value is None):
                                            self.rd_value = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                            self.rd_value.parent = self
                                            self._children_name_map["rd_value"] = "rd-value"
                                        return self.rd_value

                                    if (child_yang_name == "vpls-id"):
                                        if (self.vpls_id is None):
                                            self.vpls_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                            self.vpls_id.parent = self
                                            self._children_name_map["vpls_id"] = "vpls-id"
                                        return self.vpls_id

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "vpls-id" or name == "ad-method" or name == "ad-signalling-method" or name == "as-number" or name == "export-route-policy" or name == "l2vpn-router-id" or name == "provisioned-ve-id" or name == "service-connected" or name == "ve-id" or name == "ve-range" or name == "vpls-id-conflict" or name == "vpn-added" or name == "vpn-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ad-method"):
                                        self.ad_method = value
                                        self.ad_method.value_namespace = name_space
                                        self.ad_method.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ad-signalling-method"):
                                        self.ad_signalling_method = value
                                        self.ad_signalling_method.value_namespace = name_space
                                        self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-number"):
                                        self.as_number = value
                                        self.as_number.value_namespace = name_space
                                        self.as_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "export-route-policy"):
                                        self.export_route_policy = value
                                        self.export_route_policy.value_namespace = name_space
                                        self.export_route_policy.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2vpn-router-id"):
                                        self.l2vpn_router_id = value
                                        self.l2vpn_router_id.value_namespace = name_space
                                        self.l2vpn_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "provisioned-ve-id"):
                                        self.provisioned_ve_id = value
                                        self.provisioned_ve_id.value_namespace = name_space
                                        self.provisioned_ve_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "service-connected"):
                                        self.service_connected = value
                                        self.service_connected.value_namespace = name_space
                                        self.service_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ve-id"):
                                        self.ve_id = value
                                        self.ve_id.value_namespace = name_space
                                        self.ve_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ve-range"):
                                        self.ve_range = value
                                        self.ve_range.value_namespace = name_space
                                        self.ve_range.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpls-id-conflict"):
                                        self.vpls_id_conflict = value
                                        self.vpls_id_conflict.value_namespace = name_space
                                        self.vpls_id_conflict.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpn-added"):
                                        self.vpn_added = value
                                        self.vpn_added.value_namespace = name_space
                                        self.vpn_added.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpn-id"):
                                        self.vpn_id = value
                                        self.vpn_id.value_namespace = name_space
                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                            class P2MpInformation(Entity):
                                """
                                Multicast P2MP information
                                
                                .. attribute:: attribute_set_name
                                
                                	TE Attribute Set Name
                                	**type**\:  str
                                
                                .. attribute:: local_label
                                
                                	P2MP Tunnel Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ptree_id
                                
                                	PTree ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: signaling
                                
                                	P2MP signaling
                                	**type**\:   :py:class:`L2VpnVfiP2MpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignaling>`
                                
                                .. attribute:: transport
                                
                                	P2MP transport
                                	**type**\:   :py:class:`L2VpnVfiP2MpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransport>`
                                
                                .. attribute:: transport_status
                                
                                	Transport Status
                                	**type**\:   :py:class:`P2MpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportState>`
                                
                                .. attribute:: tunnel_interface
                                
                                	P2MP Tunnel Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__init__()

                                    self.yang_name = "p2mp-information"
                                    self.yang_parent_name = "bridge-vfi"

                                    self.attribute_set_name = YLeaf(YType.str, "attribute-set-name")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.ptree_id = YLeaf(YType.uint32, "ptree-id")

                                    self.signaling = YLeaf(YType.enumeration, "signaling")

                                    self.transport = YLeaf(YType.enumeration, "transport")

                                    self.transport_status = YLeaf(YType.enumeration, "transport-status")

                                    self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("attribute_set_name",
                                                    "local_label",
                                                    "ptree_id",
                                                    "signaling",
                                                    "transport",
                                                    "transport_status",
                                                    "tunnel_interface") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.attribute_set_name.is_set or
                                        self.local_label.is_set or
                                        self.ptree_id.is_set or
                                        self.signaling.is_set or
                                        self.transport.is_set or
                                        self.transport_status.is_set or
                                        self.tunnel_interface.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.attribute_set_name.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.ptree_id.yfilter != YFilter.not_set or
                                        self.signaling.yfilter != YFilter.not_set or
                                        self.transport.yfilter != YFilter.not_set or
                                        self.transport_status.yfilter != YFilter.not_set or
                                        self.tunnel_interface.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.attribute_set_name.is_set or self.attribute_set_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.attribute_set_name.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.ptree_id.is_set or self.ptree_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ptree_id.get_name_leafdata())
                                    if (self.signaling.is_set or self.signaling.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.signaling.get_name_leafdata())
                                    if (self.transport.is_set or self.transport.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transport.get_name_leafdata())
                                    if (self.transport_status.is_set or self.transport_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transport_status.get_name_leafdata())
                                    if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_interface.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "attribute-set-name" or name == "local-label" or name == "ptree-id" or name == "signaling" or name == "transport" or name == "transport-status" or name == "tunnel-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "attribute-set-name"):
                                        self.attribute_set_name = value
                                        self.attribute_set_name.value_namespace = name_space
                                        self.attribute_set_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ptree-id"):
                                        self.ptree_id = value
                                        self.ptree_id.value_namespace = name_space
                                        self.ptree_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "signaling"):
                                        self.signaling = value
                                        self.signaling.value_namespace = name_space
                                        self.signaling.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transport"):
                                        self.transport = value
                                        self.transport.value_namespace = name_space
                                        self.transport.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transport-status"):
                                        self.transport_status = value
                                        self.transport_status.value_namespace = name_space
                                        self.transport_status.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-interface"):
                                        self.tunnel_interface = value
                                        self.tunnel_interface.value_namespace = name_space
                                        self.tunnel_interface.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.p2mp_information:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.access.is_set or
                                    self.number_pseudowires.is_set or
                                    self.shutdown.is_set or
                                    self.vfi_name.is_set or
                                    self.vfi_state.is_set or
                                    (self.discovery_information is not None and self.discovery_information.has_data()))

                            def has_operation(self):
                                for c in self.p2mp_information:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.access.yfilter != YFilter.not_set or
                                    self.number_pseudowires.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.vfi_name.yfilter != YFilter.not_set or
                                    self.vfi_state.yfilter != YFilter.not_set or
                                    (self.discovery_information is not None and self.discovery_information.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bridge-vfi" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.access.is_set or self.access.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.access.get_name_leafdata())
                                if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.vfi_name.is_set or self.vfi_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vfi_name.get_name_leafdata())
                                if (self.vfi_state.is_set or self.vfi_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vfi_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "discovery-information"):
                                    if (self.discovery_information is None):
                                        self.discovery_information = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                                        self.discovery_information.parent = self
                                        self._children_name_map["discovery_information"] = "discovery-information"
                                    return self.discovery_information

                                if (child_yang_name == "p2mp-information"):
                                    for c in self.p2mp_information:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.p2mp_information.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "discovery-information" or name == "p2mp-information" or name == "access" or name == "number-pseudowires" or name == "shutdown" or name == "vfi-name" or name == "vfi-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "access"):
                                    self.access = value
                                    self.access.value_namespace = name_space
                                    self.access.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-pseudowires"):
                                    self.number_pseudowires = value
                                    self.number_pseudowires.value_namespace = name_space
                                    self.number_pseudowires.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "vfi-name"):
                                    self.vfi_name = value
                                    self.vfi_name.value_namespace = name_space
                                    self.vfi_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "vfi-state"):
                                    self.vfi_state = value
                                    self.vfi_state.value_namespace = name_space
                                    self.vfi_state.value_namespace_prefix = name_space_prefix


                        class BridgeAccessVfi(Entity):
                            """
                            Access Virtual Forwarding Interfaces
                            
                            .. attribute:: access
                            
                            	VFI is an Access VFI
                            	**type**\:  bool
                            
                            .. attribute:: discovery_information
                            
                            	Auto Discovery information
                            	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                            
                            .. attribute:: number_pseudowires
                            
                            	Number of Pseudowires
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_information
                            
                            	Multicast P2MP information
                            	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: vfi_name
                            
                            	Virtual forwarding instance name
                            	**type**\:  str
                            
                            .. attribute:: vfi_state
                            
                            	VFI state
                            	**type**\:   :py:class:`L2VpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__init__()

                                self.yang_name = "bridge-access-vfi"
                                self.yang_parent_name = "bridge-domain-info"

                                self.access = YLeaf(YType.boolean, "access")

                                self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.vfi_name = YLeaf(YType.str, "vfi-name")

                                self.vfi_state = YLeaf(YType.enumeration, "vfi-state")

                                self.discovery_information = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                                self.discovery_information.parent = self
                                self._children_name_map["discovery_information"] = "discovery-information"
                                self._children_yang_names.add("discovery-information")

                                self.p2mp_information = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("access",
                                                "number_pseudowires",
                                                "shutdown",
                                                "vfi_name",
                                                "vfi_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__setattr__(name, value)


                            class DiscoveryInformation(Entity):
                                """
                                Auto Discovery information
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_signalling_method
                                
                                	Signaling protocol
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_number
                                
                                	Autonomous System Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: export_route_policy
                                
                                	Export Route Policy
                                	**type**\:  str
                                
                                .. attribute:: export_rt
                                
                                	List of export route targets
                                	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                                
                                .. attribute:: import_rt
                                
                                	List of import route targets
                                	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                                
                                .. attribute:: l2vpn_router_id
                                
                                	L2PVN Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: provisioned_ve_id
                                
                                	Provisioned VPLS edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rd_value
                                
                                	Route Distinguisher
                                	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                                
                                .. attribute:: service_connected
                                
                                	Is the BGP service connected?
                                	**type**\:  bool
                                
                                .. attribute:: ve_id
                                
                                	VPLS Edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ve_range
                                
                                	VE range
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpls_id
                                
                                	VPLS ID
                                	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                                
                                .. attribute:: vpls_id_conflict
                                
                                	VPLS\-ID Conflict
                                	**type**\:  bool
                                
                                .. attribute:: vpn_added
                                
                                	Is VPN id configured
                                	**type**\:  bool
                                
                                .. attribute:: vpn_id
                                
                                	Vpn ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__init__()

                                    self.yang_name = "discovery-information"
                                    self.yang_parent_name = "bridge-access-vfi"

                                    self.ad_method = YLeaf(YType.uint32, "ad-method")

                                    self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                                    self.as_number = YLeaf(YType.uint32, "as-number")

                                    self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                                    self.l2vpn_router_id = YLeaf(YType.str, "l2vpn-router-id")

                                    self.provisioned_ve_id = YLeaf(YType.uint32, "provisioned-ve-id")

                                    self.service_connected = YLeaf(YType.boolean, "service-connected")

                                    self.ve_id = YLeaf(YType.uint32, "ve-id")

                                    self.ve_range = YLeaf(YType.uint16, "ve-range")

                                    self.vpls_id_conflict = YLeaf(YType.boolean, "vpls-id-conflict")

                                    self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    self.rd_value = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                    self.rd_value.parent = self
                                    self._children_name_map["rd_value"] = "rd-value"
                                    self._children_yang_names.add("rd-value")

                                    self.vpls_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                    self.vpls_id.parent = self
                                    self._children_name_map["vpls_id"] = "vpls-id"
                                    self._children_yang_names.add("vpls-id")

                                    self.export_rt = YList(self)
                                    self.import_rt = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ad_method",
                                                    "ad_signalling_method",
                                                    "as_number",
                                                    "export_route_policy",
                                                    "l2vpn_router_id",
                                                    "provisioned_ve_id",
                                                    "service_connected",
                                                    "ve_id",
                                                    "ve_range",
                                                    "vpls_id_conflict",
                                                    "vpn_added",
                                                    "vpn_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__setattr__(name, value)


                                class RdValue(Entity):
                                    """
                                    Route Distinguisher
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                    
                                    .. attribute:: rd
                                    
                                    	RD
                                    	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__init__()

                                        self.yang_name = "rd-value"
                                        self.yang_parent_name = "discovery-information"

                                        self.rd = YLeaf(YType.enumeration, "rd")

                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                        self._children_yang_names.add("four-byte-as")

                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("rd") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: auto_index
                                        
                                        	Auto\-generated Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: router_id
                                        
                                        	BGP Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "rd-value"

                                            self.auto_index = YLeaf(YType.uint16, "auto-index")

                                            self.router_id = YLeaf(YType.str, "router-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("auto_index",
                                                            "router_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.auto_index.is_set or
                                                self.router_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.auto_index.yfilter != YFilter.not_set or
                                                self.router_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.auto_index.get_name_leafdata())
                                            if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.router_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto-index" or name == "router-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "auto-index"):
                                                self.auto_index = value
                                                self.auto_index.value_namespace = name_space
                                                self.auto_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "router-id"):
                                                self.router_id = value
                                                self.router_id.value_namespace = name_space
                                                self.router_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "rd-value"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "rd-value"

                                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_as",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_as.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_as.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "four-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-as" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-as"):
                                                self.four_byte_as = value
                                                self.four_byte_as.value_namespace = name_space
                                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "rd-value"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.rd.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.rd.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rd-value" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rd.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "four-byte-as"):
                                            if (self.four_byte_as is None):
                                                self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                                self.four_byte_as.parent = self
                                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                            return self.four_byte_as

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "rd"):
                                            self.rd = value
                                            self.rd.value_namespace = name_space
                                            self.rd.value_namespace_prefix = name_space_prefix


                                class VplsId(Entity):
                                    """
                                    VPLS ID
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__init__()

                                        self.yang_name = "vpls-id"
                                        self.yang_parent_name = "discovery-information"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "vpls-id"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "vpls-id"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "vpls-id"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vpls-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class ImportRt(Entity):
                                    """
                                    List of import route targets
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__init__()

                                        self.yang_name = "import-rt"
                                        self.yang_parent_name = "discovery-information"

                                        self.rt = YLeaf(YType.enumeration, "rt")

                                        self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                        self._children_yang_names.add("es-import")

                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                        self._children_yang_names.add("four-byte-as")

                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("rt") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "import-rt"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "import-rt"

                                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_as",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_as.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_as.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "four-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-as" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-as"):
                                                self.four_byte_as = value
                                                self.four_byte_as.value_namespace = name_space
                                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "import-rt"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                                    class EsImport(Entity):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                            self.yang_name = "es-import"
                                            self.yang_parent_name = "import-rt"

                                            self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                            self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("high_bytes",
                                                            "low_bytes") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.high_bytes.is_set or
                                                self.low_bytes.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.high_bytes.yfilter != YFilter.not_set or
                                                self.low_bytes.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "es-import" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                            if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "high-bytes" or name == "low-bytes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "high-bytes"):
                                                self.high_bytes = value
                                                self.high_bytes.value_namespace = name_space
                                                self.high_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "low-bytes"):
                                                self.low_bytes = value
                                                self.low_bytes.value_namespace = name_space
                                                self.low_bytes.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.rt.is_set or
                                            (self.es_import is not None and self.es_import.has_data()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.rt.yfilter != YFilter.not_set or
                                            (self.es_import is not None and self.es_import.has_operation()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "import-rt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rt.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "es-import"):
                                            if (self.es_import is None):
                                                self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                                self.es_import.parent = self
                                                self._children_name_map["es_import"] = "es-import"
                                            return self.es_import

                                        if (child_yang_name == "four-byte-as"):
                                            if (self.four_byte_as is None):
                                                self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                                self.four_byte_as.parent = self
                                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                            return self.four_byte_as

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "rt"):
                                            self.rt = value
                                            self.rt.value_namespace = name_space
                                            self.rt.value_namespace_prefix = name_space_prefix


                                class ExportRt(Entity):
                                    """
                                    List of export route targets
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__init__()

                                        self.yang_name = "export-rt"
                                        self.yang_parent_name = "discovery-information"

                                        self.rt = YLeaf(YType.enumeration, "rt")

                                        self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                        self._children_yang_names.add("es-import")

                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                        self._children_yang_names.add("four-byte-as")

                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("rt") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "export-rt"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "export-rt"

                                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_as",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_as.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_as.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "four-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-as" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-as"):
                                                self.four_byte_as = value
                                                self.four_byte_as.value_namespace = name_space
                                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "export-rt"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                                    class EsImport(Entity):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                            self.yang_name = "es-import"
                                            self.yang_parent_name = "export-rt"

                                            self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                            self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("high_bytes",
                                                            "low_bytes") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.high_bytes.is_set or
                                                self.low_bytes.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.high_bytes.yfilter != YFilter.not_set or
                                                self.low_bytes.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "es-import" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                            if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "high-bytes" or name == "low-bytes"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "high-bytes"):
                                                self.high_bytes = value
                                                self.high_bytes.value_namespace = name_space
                                                self.high_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "low-bytes"):
                                                self.low_bytes = value
                                                self.low_bytes.value_namespace = name_space
                                                self.low_bytes.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.rt.is_set or
                                            (self.es_import is not None and self.es_import.has_data()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.rt.yfilter != YFilter.not_set or
                                            (self.es_import is not None and self.es_import.has_operation()) or
                                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "export-rt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rt.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "es-import"):
                                            if (self.es_import is None):
                                                self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                                self.es_import.parent = self
                                                self._children_name_map["es_import"] = "es-import"
                                            return self.es_import

                                        if (child_yang_name == "four-byte-as"):
                                            if (self.four_byte_as is None):
                                                self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                                self.four_byte_as.parent = self
                                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                            return self.four_byte_as

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "rt"):
                                            self.rt = value
                                            self.rt.value_namespace = name_space
                                            self.rt.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.export_rt:
                                        if (c.has_data()):
                                            return True
                                    for c in self.import_rt:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.ad_method.is_set or
                                        self.ad_signalling_method.is_set or
                                        self.as_number.is_set or
                                        self.export_route_policy.is_set or
                                        self.l2vpn_router_id.is_set or
                                        self.provisioned_ve_id.is_set or
                                        self.service_connected.is_set or
                                        self.ve_id.is_set or
                                        self.ve_range.is_set or
                                        self.vpls_id_conflict.is_set or
                                        self.vpn_added.is_set or
                                        self.vpn_id.is_set or
                                        (self.rd_value is not None and self.rd_value.has_data()) or
                                        (self.vpls_id is not None and self.vpls_id.has_data()))

                                def has_operation(self):
                                    for c in self.export_rt:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.import_rt:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ad_method.yfilter != YFilter.not_set or
                                        self.ad_signalling_method.yfilter != YFilter.not_set or
                                        self.as_number.yfilter != YFilter.not_set or
                                        self.export_route_policy.yfilter != YFilter.not_set or
                                        self.l2vpn_router_id.yfilter != YFilter.not_set or
                                        self.provisioned_ve_id.yfilter != YFilter.not_set or
                                        self.service_connected.yfilter != YFilter.not_set or
                                        self.ve_id.yfilter != YFilter.not_set or
                                        self.ve_range.yfilter != YFilter.not_set or
                                        self.vpls_id_conflict.yfilter != YFilter.not_set or
                                        self.vpn_added.yfilter != YFilter.not_set or
                                        self.vpn_id.yfilter != YFilter.not_set or
                                        (self.rd_value is not None and self.rd_value.has_operation()) or
                                        (self.vpls_id is not None and self.vpls_id.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "discovery-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_method.get_name_leafdata())
                                    if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                                    if (self.as_number.is_set or self.as_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_number.get_name_leafdata())
                                    if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                                    if (self.l2vpn_router_id.is_set or self.l2vpn_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2vpn_router_id.get_name_leafdata())
                                    if (self.provisioned_ve_id.is_set or self.provisioned_ve_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.provisioned_ve_id.get_name_leafdata())
                                    if (self.service_connected.is_set or self.service_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.service_connected.get_name_leafdata())
                                    if (self.ve_id.is_set or self.ve_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ve_id.get_name_leafdata())
                                    if (self.ve_range.is_set or self.ve_range.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ve_range.get_name_leafdata())
                                    if (self.vpls_id_conflict.is_set or self.vpls_id_conflict.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_conflict.get_name_leafdata())
                                    if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpn_added.get_name_leafdata())
                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "export-rt"):
                                        for c in self.export_rt:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.export_rt.append(c)
                                        return c

                                    if (child_yang_name == "import-rt"):
                                        for c in self.import_rt:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.import_rt.append(c)
                                        return c

                                    if (child_yang_name == "rd-value"):
                                        if (self.rd_value is None):
                                            self.rd_value = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                            self.rd_value.parent = self
                                            self._children_name_map["rd_value"] = "rd-value"
                                        return self.rd_value

                                    if (child_yang_name == "vpls-id"):
                                        if (self.vpls_id is None):
                                            self.vpls_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                            self.vpls_id.parent = self
                                            self._children_name_map["vpls_id"] = "vpls-id"
                                        return self.vpls_id

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "vpls-id" or name == "ad-method" or name == "ad-signalling-method" or name == "as-number" or name == "export-route-policy" or name == "l2vpn-router-id" or name == "provisioned-ve-id" or name == "service-connected" or name == "ve-id" or name == "ve-range" or name == "vpls-id-conflict" or name == "vpn-added" or name == "vpn-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ad-method"):
                                        self.ad_method = value
                                        self.ad_method.value_namespace = name_space
                                        self.ad_method.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ad-signalling-method"):
                                        self.ad_signalling_method = value
                                        self.ad_signalling_method.value_namespace = name_space
                                        self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-number"):
                                        self.as_number = value
                                        self.as_number.value_namespace = name_space
                                        self.as_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "export-route-policy"):
                                        self.export_route_policy = value
                                        self.export_route_policy.value_namespace = name_space
                                        self.export_route_policy.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2vpn-router-id"):
                                        self.l2vpn_router_id = value
                                        self.l2vpn_router_id.value_namespace = name_space
                                        self.l2vpn_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "provisioned-ve-id"):
                                        self.provisioned_ve_id = value
                                        self.provisioned_ve_id.value_namespace = name_space
                                        self.provisioned_ve_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "service-connected"):
                                        self.service_connected = value
                                        self.service_connected.value_namespace = name_space
                                        self.service_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ve-id"):
                                        self.ve_id = value
                                        self.ve_id.value_namespace = name_space
                                        self.ve_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ve-range"):
                                        self.ve_range = value
                                        self.ve_range.value_namespace = name_space
                                        self.ve_range.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpls-id-conflict"):
                                        self.vpls_id_conflict = value
                                        self.vpls_id_conflict.value_namespace = name_space
                                        self.vpls_id_conflict.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpn-added"):
                                        self.vpn_added = value
                                        self.vpn_added.value_namespace = name_space
                                        self.vpn_added.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpn-id"):
                                        self.vpn_id = value
                                        self.vpn_id.value_namespace = name_space
                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                            class P2MpInformation(Entity):
                                """
                                Multicast P2MP information
                                
                                .. attribute:: attribute_set_name
                                
                                	TE Attribute Set Name
                                	**type**\:  str
                                
                                .. attribute:: local_label
                                
                                	P2MP Tunnel Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ptree_id
                                
                                	PTree ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: signaling
                                
                                	P2MP signaling
                                	**type**\:   :py:class:`L2VpnVfiP2MpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignaling>`
                                
                                .. attribute:: transport
                                
                                	P2MP transport
                                	**type**\:   :py:class:`L2VpnVfiP2MpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransport>`
                                
                                .. attribute:: transport_status
                                
                                	Transport Status
                                	**type**\:   :py:class:`P2MpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportState>`
                                
                                .. attribute:: tunnel_interface
                                
                                	P2MP Tunnel Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__init__()

                                    self.yang_name = "p2mp-information"
                                    self.yang_parent_name = "bridge-access-vfi"

                                    self.attribute_set_name = YLeaf(YType.str, "attribute-set-name")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.ptree_id = YLeaf(YType.uint32, "ptree-id")

                                    self.signaling = YLeaf(YType.enumeration, "signaling")

                                    self.transport = YLeaf(YType.enumeration, "transport")

                                    self.transport_status = YLeaf(YType.enumeration, "transport-status")

                                    self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("attribute_set_name",
                                                    "local_label",
                                                    "ptree_id",
                                                    "signaling",
                                                    "transport",
                                                    "transport_status",
                                                    "tunnel_interface") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.attribute_set_name.is_set or
                                        self.local_label.is_set or
                                        self.ptree_id.is_set or
                                        self.signaling.is_set or
                                        self.transport.is_set or
                                        self.transport_status.is_set or
                                        self.tunnel_interface.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.attribute_set_name.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.ptree_id.yfilter != YFilter.not_set or
                                        self.signaling.yfilter != YFilter.not_set or
                                        self.transport.yfilter != YFilter.not_set or
                                        self.transport_status.yfilter != YFilter.not_set or
                                        self.tunnel_interface.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.attribute_set_name.is_set or self.attribute_set_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.attribute_set_name.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.ptree_id.is_set or self.ptree_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ptree_id.get_name_leafdata())
                                    if (self.signaling.is_set or self.signaling.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.signaling.get_name_leafdata())
                                    if (self.transport.is_set or self.transport.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transport.get_name_leafdata())
                                    if (self.transport_status.is_set or self.transport_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transport_status.get_name_leafdata())
                                    if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_interface.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "attribute-set-name" or name == "local-label" or name == "ptree-id" or name == "signaling" or name == "transport" or name == "transport-status" or name == "tunnel-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "attribute-set-name"):
                                        self.attribute_set_name = value
                                        self.attribute_set_name.value_namespace = name_space
                                        self.attribute_set_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ptree-id"):
                                        self.ptree_id = value
                                        self.ptree_id.value_namespace = name_space
                                        self.ptree_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "signaling"):
                                        self.signaling = value
                                        self.signaling.value_namespace = name_space
                                        self.signaling.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transport"):
                                        self.transport = value
                                        self.transport.value_namespace = name_space
                                        self.transport.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transport-status"):
                                        self.transport_status = value
                                        self.transport_status.value_namespace = name_space
                                        self.transport_status.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-interface"):
                                        self.tunnel_interface = value
                                        self.tunnel_interface.value_namespace = name_space
                                        self.tunnel_interface.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.p2mp_information:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.access.is_set or
                                    self.number_pseudowires.is_set or
                                    self.shutdown.is_set or
                                    self.vfi_name.is_set or
                                    self.vfi_state.is_set or
                                    (self.discovery_information is not None and self.discovery_information.has_data()))

                            def has_operation(self):
                                for c in self.p2mp_information:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.access.yfilter != YFilter.not_set or
                                    self.number_pseudowires.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.vfi_name.yfilter != YFilter.not_set or
                                    self.vfi_state.yfilter != YFilter.not_set or
                                    (self.discovery_information is not None and self.discovery_information.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bridge-access-vfi" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.access.is_set or self.access.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.access.get_name_leafdata())
                                if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.vfi_name.is_set or self.vfi_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vfi_name.get_name_leafdata())
                                if (self.vfi_state.is_set or self.vfi_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vfi_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "discovery-information"):
                                    if (self.discovery_information is None):
                                        self.discovery_information = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                                        self.discovery_information.parent = self
                                        self._children_name_map["discovery_information"] = "discovery-information"
                                    return self.discovery_information

                                if (child_yang_name == "p2mp-information"):
                                    for c in self.p2mp_information:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.p2mp_information.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "discovery-information" or name == "p2mp-information" or name == "access" or name == "number-pseudowires" or name == "shutdown" or name == "vfi-name" or name == "vfi-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "access"):
                                    self.access = value
                                    self.access.value_namespace = name_space
                                    self.access.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-pseudowires"):
                                    self.number_pseudowires = value
                                    self.number_pseudowires.value_namespace = name_space
                                    self.number_pseudowires.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "vfi-name"):
                                    self.vfi_name = value
                                    self.vfi_name.value_namespace = name_space
                                    self.vfi_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "vfi-state"):
                                    self.vfi_state = value
                                    self.vfi_state.value_namespace = name_space
                                    self.vfi_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bridge_access_vfi:
                                if (c.has_data()):
                                    return True
                            for c in self.bridge_vfi:
                                if (c.has_data()):
                                    return True
                            for c in self.mac_filter:
                                if (c.has_data()):
                                    return True
                            return (
                                self.acpwup.is_set or
                                self.as_.is_set or
                                self.bridge_coupled_state.is_set or
                                self.bridge_description.is_set or
                                self.bridge_domain_id.is_set or
                                self.bridge_internal_msti.is_set or
                                self.bridge_msti.is_set or
                                self.bridge_mtu.is_set or
                                self.bridge_name.is_set or
                                self.bridge_shg_id.is_set or
                                self.bridge_state.is_set or
                                self.bridge_type.is_set or
                                self.configured.is_set or
                                self.disposition_bytecount.is_set or
                                self.disposition_pkt_count.is_set or
                                self.evi.is_set or
                                self.flodd_group_id_down.is_set or
                                self.group_name.is_set or
                                self.imposition_byte_count.is_set or
                                self.imposition_pkt_count.is_set or
                                self.is_bridge_partially_programmed.is_set or
                                self.is_rd_configured.is_set or
                                self.last_time_status_changed.is_set or
                                self.load_balance.is_set or
                                self.mac_limit_down.is_set or
                                self.mac_withdraw.is_set or
                                self.mac_withdraw_access.is_set or
                                self.mac_withdraw_option.is_set or
                                self.mac_withdraw_relay.is_set or
                                self.num_vn_is.is_set or
                                self.num_vn_is_up.is_set or
                                self.number_a_cs.is_set or
                                self.number_a_cs_up.is_set or
                                self.number_access_vf_is.is_set or
                                self.number_p_ws_up.is_set or
                                self.number_pb_bs.is_set or
                                self.number_pb_bs_up.is_set or
                                self.number_pseudowires.is_set or
                                self.number_vf_is.is_set or
                                self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                                self.p2mp_enabled.is_set or
                                self.partially_programmed_a_cs.is_set or
                                self.partially_programmed_pseudowires.is_set or
                                self.shutdown.is_set or
                                self.standby_pseudowires.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.vine_fsm_state.is_set or
                                (self.evpn_parameters is not None and self.evpn_parameters.has_data()) or
                                (self.pbb_parameters is not None and self.pbb_parameters.has_data()) or
                                (self.rd is not None and self.rd.has_data()) or
                                (self.security_parameters is not None and self.security_parameters.has_data()) or
                                (self.vni_parameters is not None and self.vni_parameters.has_data()))

                        def has_operation(self):
                            for c in self.bridge_access_vfi:
                                if (c.has_operation()):
                                    return True
                            for c in self.bridge_vfi:
                                if (c.has_operation()):
                                    return True
                            for c in self.mac_filter:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.acpwup.yfilter != YFilter.not_set or
                                self.as_.yfilter != YFilter.not_set or
                                self.bridge_coupled_state.yfilter != YFilter.not_set or
                                self.bridge_description.yfilter != YFilter.not_set or
                                self.bridge_domain_id.yfilter != YFilter.not_set or
                                self.bridge_internal_msti.yfilter != YFilter.not_set or
                                self.bridge_msti.yfilter != YFilter.not_set or
                                self.bridge_mtu.yfilter != YFilter.not_set or
                                self.bridge_name.yfilter != YFilter.not_set or
                                self.bridge_shg_id.yfilter != YFilter.not_set or
                                self.bridge_state.yfilter != YFilter.not_set or
                                self.bridge_type.yfilter != YFilter.not_set or
                                self.configured.yfilter != YFilter.not_set or
                                self.disposition_bytecount.yfilter != YFilter.not_set or
                                self.disposition_pkt_count.yfilter != YFilter.not_set or
                                self.evi.yfilter != YFilter.not_set or
                                self.flodd_group_id_down.yfilter != YFilter.not_set or
                                self.group_name.yfilter != YFilter.not_set or
                                self.imposition_byte_count.yfilter != YFilter.not_set or
                                self.imposition_pkt_count.yfilter != YFilter.not_set or
                                self.is_bridge_partially_programmed.yfilter != YFilter.not_set or
                                self.is_rd_configured.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.mac_limit_down.yfilter != YFilter.not_set or
                                self.mac_withdraw.yfilter != YFilter.not_set or
                                self.mac_withdraw_access.yfilter != YFilter.not_set or
                                self.mac_withdraw_option.yfilter != YFilter.not_set or
                                self.mac_withdraw_relay.yfilter != YFilter.not_set or
                                self.num_vn_is.yfilter != YFilter.not_set or
                                self.num_vn_is_up.yfilter != YFilter.not_set or
                                self.number_a_cs.yfilter != YFilter.not_set or
                                self.number_a_cs_up.yfilter != YFilter.not_set or
                                self.number_access_vf_is.yfilter != YFilter.not_set or
                                self.number_p_ws_up.yfilter != YFilter.not_set or
                                self.number_pb_bs.yfilter != YFilter.not_set or
                                self.number_pb_bs_up.yfilter != YFilter.not_set or
                                self.number_pseudowires.yfilter != YFilter.not_set or
                                self.number_vf_is.yfilter != YFilter.not_set or
                                self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                                self.p2mp_enabled.yfilter != YFilter.not_set or
                                self.partially_programmed_a_cs.yfilter != YFilter.not_set or
                                self.partially_programmed_pseudowires.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.standby_pseudowires.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.vine_fsm_state.yfilter != YFilter.not_set or
                                (self.evpn_parameters is not None and self.evpn_parameters.has_operation()) or
                                (self.pbb_parameters is not None and self.pbb_parameters.has_operation()) or
                                (self.rd is not None and self.rd.has_operation()) or
                                (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                (self.vni_parameters is not None and self.vni_parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-domain-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.acpwup.is_set or self.acpwup.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.acpwup.get_name_leafdata())
                            if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_.get_name_leafdata())
                            if (self.bridge_coupled_state.is_set or self.bridge_coupled_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_coupled_state.get_name_leafdata())
                            if (self.bridge_description.is_set or self.bridge_description.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_description.get_name_leafdata())
                            if (self.bridge_domain_id.is_set or self.bridge_domain_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_domain_id.get_name_leafdata())
                            if (self.bridge_internal_msti.is_set or self.bridge_internal_msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_internal_msti.get_name_leafdata())
                            if (self.bridge_msti.is_set or self.bridge_msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_msti.get_name_leafdata())
                            if (self.bridge_mtu.is_set or self.bridge_mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_mtu.get_name_leafdata())
                            if (self.bridge_name.is_set or self.bridge_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_name.get_name_leafdata())
                            if (self.bridge_shg_id.is_set or self.bridge_shg_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_shg_id.get_name_leafdata())
                            if (self.bridge_state.is_set or self.bridge_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_state.get_name_leafdata())
                            if (self.bridge_type.is_set or self.bridge_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_type.get_name_leafdata())
                            if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured.get_name_leafdata())
                            if (self.disposition_bytecount.is_set or self.disposition_bytecount.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disposition_bytecount.get_name_leafdata())
                            if (self.disposition_pkt_count.is_set or self.disposition_pkt_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disposition_pkt_count.get_name_leafdata())
                            if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evi.get_name_leafdata())
                            if (self.flodd_group_id_down.is_set or self.flodd_group_id_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flodd_group_id_down.get_name_leafdata())
                            if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_name.get_name_leafdata())
                            if (self.imposition_byte_count.is_set or self.imposition_byte_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposition_byte_count.get_name_leafdata())
                            if (self.imposition_pkt_count.is_set or self.imposition_pkt_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposition_pkt_count.get_name_leafdata())
                            if (self.is_bridge_partially_programmed.is_set or self.is_bridge_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bridge_partially_programmed.get_name_leafdata())
                            if (self.is_rd_configured.is_set or self.is_rd_configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rd_configured.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.mac_limit_down.is_set or self.mac_limit_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_down.get_name_leafdata())
                            if (self.mac_withdraw.is_set or self.mac_withdraw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_withdraw.get_name_leafdata())
                            if (self.mac_withdraw_access.is_set or self.mac_withdraw_access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_withdraw_access.get_name_leafdata())
                            if (self.mac_withdraw_option.is_set or self.mac_withdraw_option.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_withdraw_option.get_name_leafdata())
                            if (self.mac_withdraw_relay.is_set or self.mac_withdraw_relay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_withdraw_relay.get_name_leafdata())
                            if (self.num_vn_is.is_set or self.num_vn_is.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_vn_is.get_name_leafdata())
                            if (self.num_vn_is_up.is_set or self.num_vn_is_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_vn_is_up.get_name_leafdata())
                            if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                            if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                            if (self.number_access_vf_is.is_set or self.number_access_vf_is.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_access_vf_is.get_name_leafdata())
                            if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                            if (self.number_pb_bs.is_set or self.number_pb_bs.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pb_bs.get_name_leafdata())
                            if (self.number_pb_bs_up.is_set or self.number_pb_bs_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pb_bs_up.get_name_leafdata())
                            if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                            if (self.number_vf_is.is_set or self.number_vf_is.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_vf_is.get_name_leafdata())
                            if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                            if (self.p2mp_enabled.is_set or self.p2mp_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_enabled.get_name_leafdata())
                            if (self.partially_programmed_a_cs.is_set or self.partially_programmed_a_cs.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partially_programmed_a_cs.get_name_leafdata())
                            if (self.partially_programmed_pseudowires.is_set or self.partially_programmed_pseudowires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partially_programmed_pseudowires.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.standby_pseudowires.is_set or self.standby_pseudowires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.standby_pseudowires.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.vine_fsm_state.is_set or self.vine_fsm_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vine_fsm_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bridge-access-vfi"):
                                for c in self.bridge_access_vfi:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bridge_access_vfi.append(c)
                                return c

                            if (child_yang_name == "bridge-vfi"):
                                for c in self.bridge_vfi:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bridge_vfi.append(c)
                                return c

                            if (child_yang_name == "evpn-parameters"):
                                if (self.evpn_parameters is None):
                                    self.evpn_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                                    self.evpn_parameters.parent = self
                                    self._children_name_map["evpn_parameters"] = "evpn-parameters"
                                return self.evpn_parameters

                            if (child_yang_name == "mac-filter"):
                                for c in self.mac_filter:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.mac_filter.append(c)
                                return c

                            if (child_yang_name == "pbb-parameters"):
                                if (self.pbb_parameters is None):
                                    self.pbb_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                                    self.pbb_parameters.parent = self
                                    self._children_name_map["pbb_parameters"] = "pbb-parameters"
                                return self.pbb_parameters

                            if (child_yang_name == "rd"):
                                if (self.rd is None):
                                    self.rd = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                                    self.rd.parent = self
                                    self._children_name_map["rd"] = "rd"
                                return self.rd

                            if (child_yang_name == "security-parameters"):
                                if (self.security_parameters is None):
                                    self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                return self.security_parameters

                            if (child_yang_name == "vni-parameters"):
                                if (self.vni_parameters is None):
                                    self.vni_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                                    self.vni_parameters.parent = self
                                    self._children_name_map["vni_parameters"] = "vni-parameters"
                                return self.vni_parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bridge-access-vfi" or name == "bridge-vfi" or name == "evpn-parameters" or name == "mac-filter" or name == "pbb-parameters" or name == "rd" or name == "security-parameters" or name == "vni-parameters" or name == "acpwup" or name == "as" or name == "bridge-coupled-state" or name == "bridge-description" or name == "bridge-domain-id" or name == "bridge-internal-msti" or name == "bridge-msti" or name == "bridge-mtu" or name == "bridge-name" or name == "bridge-shg-id" or name == "bridge-state" or name == "bridge-type" or name == "configured" or name == "disposition-bytecount" or name == "disposition-pkt-count" or name == "evi" or name == "flodd-group-id-down" or name == "group-name" or name == "imposition-byte-count" or name == "imposition-pkt-count" or name == "is-bridge-partially-programmed" or name == "is-rd-configured" or name == "last-time-status-changed" or name == "load-balance" or name == "mac-limit-down" or name == "mac-withdraw" or name == "mac-withdraw-access" or name == "mac-withdraw-option" or name == "mac-withdraw-relay" or name == "num-vn-is" or name == "num-vn-is-up" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-access-vf-is" or name == "number-p-ws-up" or name == "number-pb-bs" or name == "number-pb-bs-up" or name == "number-pseudowires" or name == "number-vf-is" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "p2mp-enabled" or name == "partially-programmed-a-cs" or name == "partially-programmed-pseudowires" or name == "shutdown" or name == "standby-pseudowires" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "vine-fsm-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "acpwup"):
                                self.acpwup = value
                                self.acpwup.value_namespace = name_space
                                self.acpwup.value_namespace_prefix = name_space_prefix
                            if(value_path == "as"):
                                self.as_ = value
                                self.as_.value_namespace = name_space
                                self.as_.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-coupled-state"):
                                self.bridge_coupled_state = value
                                self.bridge_coupled_state.value_namespace = name_space
                                self.bridge_coupled_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-description"):
                                self.bridge_description = value
                                self.bridge_description.value_namespace = name_space
                                self.bridge_description.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-domain-id"):
                                self.bridge_domain_id = value
                                self.bridge_domain_id.value_namespace = name_space
                                self.bridge_domain_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-internal-msti"):
                                self.bridge_internal_msti = value
                                self.bridge_internal_msti.value_namespace = name_space
                                self.bridge_internal_msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-msti"):
                                self.bridge_msti = value
                                self.bridge_msti.value_namespace = name_space
                                self.bridge_msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-mtu"):
                                self.bridge_mtu = value
                                self.bridge_mtu.value_namespace = name_space
                                self.bridge_mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-name"):
                                self.bridge_name = value
                                self.bridge_name.value_namespace = name_space
                                self.bridge_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-shg-id"):
                                self.bridge_shg_id = value
                                self.bridge_shg_id.value_namespace = name_space
                                self.bridge_shg_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-state"):
                                self.bridge_state = value
                                self.bridge_state.value_namespace = name_space
                                self.bridge_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-type"):
                                self.bridge_type = value
                                self.bridge_type.value_namespace = name_space
                                self.bridge_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured"):
                                self.configured = value
                                self.configured.value_namespace = name_space
                                self.configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "disposition-bytecount"):
                                self.disposition_bytecount = value
                                self.disposition_bytecount.value_namespace = name_space
                                self.disposition_bytecount.value_namespace_prefix = name_space_prefix
                            if(value_path == "disposition-pkt-count"):
                                self.disposition_pkt_count = value
                                self.disposition_pkt_count.value_namespace = name_space
                                self.disposition_pkt_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "evi"):
                                self.evi = value
                                self.evi.value_namespace = name_space
                                self.evi.value_namespace_prefix = name_space_prefix
                            if(value_path == "flodd-group-id-down"):
                                self.flodd_group_id_down = value
                                self.flodd_group_id_down.value_namespace = name_space
                                self.flodd_group_id_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-name"):
                                self.group_name = value
                                self.group_name.value_namespace = name_space
                                self.group_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposition-byte-count"):
                                self.imposition_byte_count = value
                                self.imposition_byte_count.value_namespace = name_space
                                self.imposition_byte_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposition-pkt-count"):
                                self.imposition_pkt_count = value
                                self.imposition_pkt_count.value_namespace = name_space
                                self.imposition_pkt_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bridge-partially-programmed"):
                                self.is_bridge_partially_programmed = value
                                self.is_bridge_partially_programmed.value_namespace = name_space
                                self.is_bridge_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rd-configured"):
                                self.is_rd_configured = value
                                self.is_rd_configured.value_namespace = name_space
                                self.is_rd_configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-down"):
                                self.mac_limit_down = value
                                self.mac_limit_down.value_namespace = name_space
                                self.mac_limit_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-withdraw"):
                                self.mac_withdraw = value
                                self.mac_withdraw.value_namespace = name_space
                                self.mac_withdraw.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-withdraw-access"):
                                self.mac_withdraw_access = value
                                self.mac_withdraw_access.value_namespace = name_space
                                self.mac_withdraw_access.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-withdraw-option"):
                                self.mac_withdraw_option = value
                                self.mac_withdraw_option.value_namespace = name_space
                                self.mac_withdraw_option.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-withdraw-relay"):
                                self.mac_withdraw_relay = value
                                self.mac_withdraw_relay.value_namespace = name_space
                                self.mac_withdraw_relay.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-vn-is"):
                                self.num_vn_is = value
                                self.num_vn_is.value_namespace = name_space
                                self.num_vn_is.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-vn-is-up"):
                                self.num_vn_is_up = value
                                self.num_vn_is_up.value_namespace = name_space
                                self.num_vn_is_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-a-cs"):
                                self.number_a_cs = value
                                self.number_a_cs.value_namespace = name_space
                                self.number_a_cs.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-a-cs-up"):
                                self.number_a_cs_up = value
                                self.number_a_cs_up.value_namespace = name_space
                                self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-access-vf-is"):
                                self.number_access_vf_is = value
                                self.number_access_vf_is.value_namespace = name_space
                                self.number_access_vf_is.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-p-ws-up"):
                                self.number_p_ws_up = value
                                self.number_p_ws_up.value_namespace = name_space
                                self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pb-bs"):
                                self.number_pb_bs = value
                                self.number_pb_bs.value_namespace = name_space
                                self.number_pb_bs.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pb-bs-up"):
                                self.number_pb_bs_up = value
                                self.number_pb_bs_up.value_namespace = name_space
                                self.number_pb_bs_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-pseudowires"):
                                self.number_pseudowires = value
                                self.number_pseudowires.value_namespace = name_space
                                self.number_pseudowires.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-vf-is"):
                                self.number_vf_is = value
                                self.number_vf_is.value_namespace = name_space
                                self.number_vf_is.value_namespace_prefix = name_space_prefix
                            if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                                self.nv_satellite_offload_ipv4_multicast_disabled = value
                                self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                                self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-enabled"):
                                self.p2mp_enabled = value
                                self.p2mp_enabled.value_namespace = name_space
                                self.p2mp_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "partially-programmed-a-cs"):
                                self.partially_programmed_a_cs = value
                                self.partially_programmed_a_cs.value_namespace = name_space
                                self.partially_programmed_a_cs.value_namespace_prefix = name_space_prefix
                            if(value_path == "partially-programmed-pseudowires"):
                                self.partially_programmed_pseudowires = value
                                self.partially_programmed_pseudowires.value_namespace = name_space
                                self.partially_programmed_pseudowires.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "standby-pseudowires"):
                                self.standby_pseudowires = value
                                self.standby_pseudowires.value_namespace = name_space
                                self.standby_pseudowires.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "vine-fsm-state"):
                                self.vine_fsm_state = value
                                self.vine_fsm_state.value_namespace = name_space
                                self.vine_fsm_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bridge_domain_group_name.is_set or
                            self.bridge_domain_name.is_set or
                            (self.bridge_access_pws is not None and self.bridge_access_pws.has_data()) or
                            (self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table.has_data()) or
                            (self.bridge_acs is not None and self.bridge_acs.has_data()) or
                            (self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table.has_data()) or
                            (self.bridge_domain_info is not None and self.bridge_domain_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bridge_domain_group_name.yfilter != YFilter.not_set or
                            self.bridge_domain_name.yfilter != YFilter.not_set or
                            (self.bridge_access_pws is not None and self.bridge_access_pws.has_operation()) or
                            (self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table.has_operation()) or
                            (self.bridge_acs is not None and self.bridge_acs.has_operation()) or
                            (self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table.has_operation()) or
                            (self.bridge_domain_info is not None and self.bridge_domain_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-domain" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bridge_domain_group_name.is_set or self.bridge_domain_group_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_group_name.get_name_leafdata())
                        if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-access-pws"):
                            if (self.bridge_access_pws is None):
                                self.bridge_access_pws = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws()
                                self.bridge_access_pws.parent = self
                                self._children_name_map["bridge_access_pws"] = "bridge-access-pws"
                            return self.bridge_access_pws

                        if (child_yang_name == "bridge-access-vfi-table"):
                            if (self.bridge_access_vfi_table is None):
                                self.bridge_access_vfi_table = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                                self.bridge_access_vfi_table.parent = self
                                self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"
                            return self.bridge_access_vfi_table

                        if (child_yang_name == "bridge-acs"):
                            if (self.bridge_acs is None):
                                self.bridge_acs = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs()
                                self.bridge_acs.parent = self
                                self._children_name_map["bridge_acs"] = "bridge-acs"
                            return self.bridge_acs

                        if (child_yang_name == "bridge-core-vfi-table"):
                            if (self.bridge_core_vfi_table is None):
                                self.bridge_core_vfi_table = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                                self.bridge_core_vfi_table.parent = self
                                self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"
                            return self.bridge_core_vfi_table

                        if (child_yang_name == "bridge-domain-info"):
                            if (self.bridge_domain_info is None):
                                self.bridge_domain_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                                self.bridge_domain_info.parent = self
                                self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                            return self.bridge_domain_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-access-pws" or name == "bridge-access-vfi-table" or name == "bridge-acs" or name == "bridge-core-vfi-table" or name == "bridge-domain-info" or name == "bridge-domain-group-name" or name == "bridge-domain-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bridge-domain-group-name"):
                            self.bridge_domain_group_name = value
                            self.bridge_domain_group_name.value_namespace = name_space
                            self.bridge_domain_group_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-domain-name"):
                            self.bridge_domain_name = value
                            self.bridge_domain_name.value_namespace = name_space
                            self.bridge_domain_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bridge_domain:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bridge_domain:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bridge-domains" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bridge-domain"):
                        for c in self.bridge_domain:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bridge_domain.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bridge-domain"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class DiscoverySummary(Entity):
                """
                Discovery summary information
                
                .. attribute:: bgp_current_node_id
                
                	BGP current node id
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: bgp_ipc_transport_mode
                
                	IPC Transport mode with BGP
                	**type**\:   :py:class:`L2VpnIpcTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIpcTransportMode>`
                
                .. attribute:: bgp_stateon_active_rp
                
                	BGP state on the active RP
                	**type**\:  bool
                
                .. attribute:: bgp_stateon_standby_rp
                
                	BGP state on standby RP
                	**type**\:  bool
                
                .. attribute:: number_bridge_domainvpns
                
                	Number of BDs registered
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_local_edges_bridge_domain
                
                	Number of local Edges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_local_edges_xconnect
                
                	Number of local Edges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2m_pxconnect_vpns
                
                	Number of XCs registered
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_nlri_bridge_domain
                
                	Number of NLRI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_nlri_xconnect
                
                	Number of NLRI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_remote_edges_bridge_domain
                
                	Number of Remote Edges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_remote_edges_xconnect
                
                	Number of Remote Edges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpls_registered
                
                	Is the VPLS service registered
                	**type**\:  bool
                
                .. attribute:: vpws_registered
                
                	Is the VPWS service registered
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.DiscoverySummary, self).__init__()

                    self.yang_name = "discovery-summary"
                    self.yang_parent_name = "node"

                    self.bgp_current_node_id = YLeaf(YType.str, "bgp-current-node-id")

                    self.bgp_ipc_transport_mode = YLeaf(YType.enumeration, "bgp-ipc-transport-mode")

                    self.bgp_stateon_active_rp = YLeaf(YType.boolean, "bgp-stateon-active-rp")

                    self.bgp_stateon_standby_rp = YLeaf(YType.boolean, "bgp-stateon-standby-rp")

                    self.number_bridge_domainvpns = YLeaf(YType.uint32, "number-bridge-domainvpns")

                    self.number_local_edges_bridge_domain = YLeaf(YType.uint32, "number-local-edges-bridge-domain")

                    self.number_local_edges_xconnect = YLeaf(YType.uint32, "number-local-edges-xconnect")

                    self.number_mp2m_pxconnect_vpns = YLeaf(YType.uint32, "number-mp2m-pxconnect-vpns")

                    self.number_nlri_bridge_domain = YLeaf(YType.uint32, "number-nlri-bridge-domain")

                    self.number_nlri_xconnect = YLeaf(YType.uint32, "number-nlri-xconnect")

                    self.number_remote_edges_bridge_domain = YLeaf(YType.uint32, "number-remote-edges-bridge-domain")

                    self.number_remote_edges_xconnect = YLeaf(YType.uint32, "number-remote-edges-xconnect")

                    self.vpls_registered = YLeaf(YType.boolean, "vpls-registered")

                    self.vpws_registered = YLeaf(YType.boolean, "vpws-registered")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bgp_current_node_id",
                                    "bgp_ipc_transport_mode",
                                    "bgp_stateon_active_rp",
                                    "bgp_stateon_standby_rp",
                                    "number_bridge_domainvpns",
                                    "number_local_edges_bridge_domain",
                                    "number_local_edges_xconnect",
                                    "number_mp2m_pxconnect_vpns",
                                    "number_nlri_bridge_domain",
                                    "number_nlri_xconnect",
                                    "number_remote_edges_bridge_domain",
                                    "number_remote_edges_xconnect",
                                    "vpls_registered",
                                    "vpws_registered") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.DiscoverySummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.DiscoverySummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bgp_current_node_id.is_set or
                        self.bgp_ipc_transport_mode.is_set or
                        self.bgp_stateon_active_rp.is_set or
                        self.bgp_stateon_standby_rp.is_set or
                        self.number_bridge_domainvpns.is_set or
                        self.number_local_edges_bridge_domain.is_set or
                        self.number_local_edges_xconnect.is_set or
                        self.number_mp2m_pxconnect_vpns.is_set or
                        self.number_nlri_bridge_domain.is_set or
                        self.number_nlri_xconnect.is_set or
                        self.number_remote_edges_bridge_domain.is_set or
                        self.number_remote_edges_xconnect.is_set or
                        self.vpls_registered.is_set or
                        self.vpws_registered.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bgp_current_node_id.yfilter != YFilter.not_set or
                        self.bgp_ipc_transport_mode.yfilter != YFilter.not_set or
                        self.bgp_stateon_active_rp.yfilter != YFilter.not_set or
                        self.bgp_stateon_standby_rp.yfilter != YFilter.not_set or
                        self.number_bridge_domainvpns.yfilter != YFilter.not_set or
                        self.number_local_edges_bridge_domain.yfilter != YFilter.not_set or
                        self.number_local_edges_xconnect.yfilter != YFilter.not_set or
                        self.number_mp2m_pxconnect_vpns.yfilter != YFilter.not_set or
                        self.number_nlri_bridge_domain.yfilter != YFilter.not_set or
                        self.number_nlri_xconnect.yfilter != YFilter.not_set or
                        self.number_remote_edges_bridge_domain.yfilter != YFilter.not_set or
                        self.number_remote_edges_xconnect.yfilter != YFilter.not_set or
                        self.vpls_registered.yfilter != YFilter.not_set or
                        self.vpws_registered.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "discovery-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bgp_current_node_id.is_set or self.bgp_current_node_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_current_node_id.get_name_leafdata())
                    if (self.bgp_ipc_transport_mode.is_set or self.bgp_ipc_transport_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_ipc_transport_mode.get_name_leafdata())
                    if (self.bgp_stateon_active_rp.is_set or self.bgp_stateon_active_rp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_stateon_active_rp.get_name_leafdata())
                    if (self.bgp_stateon_standby_rp.is_set or self.bgp_stateon_standby_rp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_stateon_standby_rp.get_name_leafdata())
                    if (self.number_bridge_domainvpns.is_set or self.number_bridge_domainvpns.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_bridge_domainvpns.get_name_leafdata())
                    if (self.number_local_edges_bridge_domain.is_set or self.number_local_edges_bridge_domain.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_local_edges_bridge_domain.get_name_leafdata())
                    if (self.number_local_edges_xconnect.is_set or self.number_local_edges_xconnect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_local_edges_xconnect.get_name_leafdata())
                    if (self.number_mp2m_pxconnect_vpns.is_set or self.number_mp2m_pxconnect_vpns.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_mp2m_pxconnect_vpns.get_name_leafdata())
                    if (self.number_nlri_bridge_domain.is_set or self.number_nlri_bridge_domain.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_nlri_bridge_domain.get_name_leafdata())
                    if (self.number_nlri_xconnect.is_set or self.number_nlri_xconnect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_nlri_xconnect.get_name_leafdata())
                    if (self.number_remote_edges_bridge_domain.is_set or self.number_remote_edges_bridge_domain.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_remote_edges_bridge_domain.get_name_leafdata())
                    if (self.number_remote_edges_xconnect.is_set or self.number_remote_edges_xconnect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_remote_edges_xconnect.get_name_leafdata())
                    if (self.vpls_registered.is_set or self.vpls_registered.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpls_registered.get_name_leafdata())
                    if (self.vpws_registered.is_set or self.vpws_registered.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpws_registered.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bgp-current-node-id" or name == "bgp-ipc-transport-mode" or name == "bgp-stateon-active-rp" or name == "bgp-stateon-standby-rp" or name == "number-bridge-domainvpns" or name == "number-local-edges-bridge-domain" or name == "number-local-edges-xconnect" or name == "number-mp2m-pxconnect-vpns" or name == "number-nlri-bridge-domain" or name == "number-nlri-xconnect" or name == "number-remote-edges-bridge-domain" or name == "number-remote-edges-xconnect" or name == "vpls-registered" or name == "vpws-registered"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bgp-current-node-id"):
                        self.bgp_current_node_id = value
                        self.bgp_current_node_id.value_namespace = name_space
                        self.bgp_current_node_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-ipc-transport-mode"):
                        self.bgp_ipc_transport_mode = value
                        self.bgp_ipc_transport_mode.value_namespace = name_space
                        self.bgp_ipc_transport_mode.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-stateon-active-rp"):
                        self.bgp_stateon_active_rp = value
                        self.bgp_stateon_active_rp.value_namespace = name_space
                        self.bgp_stateon_active_rp.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-stateon-standby-rp"):
                        self.bgp_stateon_standby_rp = value
                        self.bgp_stateon_standby_rp.value_namespace = name_space
                        self.bgp_stateon_standby_rp.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-bridge-domainvpns"):
                        self.number_bridge_domainvpns = value
                        self.number_bridge_domainvpns.value_namespace = name_space
                        self.number_bridge_domainvpns.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-local-edges-bridge-domain"):
                        self.number_local_edges_bridge_domain = value
                        self.number_local_edges_bridge_domain.value_namespace = name_space
                        self.number_local_edges_bridge_domain.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-local-edges-xconnect"):
                        self.number_local_edges_xconnect = value
                        self.number_local_edges_xconnect.value_namespace = name_space
                        self.number_local_edges_xconnect.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-mp2m-pxconnect-vpns"):
                        self.number_mp2m_pxconnect_vpns = value
                        self.number_mp2m_pxconnect_vpns.value_namespace = name_space
                        self.number_mp2m_pxconnect_vpns.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-nlri-bridge-domain"):
                        self.number_nlri_bridge_domain = value
                        self.number_nlri_bridge_domain.value_namespace = name_space
                        self.number_nlri_bridge_domain.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-nlri-xconnect"):
                        self.number_nlri_xconnect = value
                        self.number_nlri_xconnect.value_namespace = name_space
                        self.number_nlri_xconnect.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-remote-edges-bridge-domain"):
                        self.number_remote_edges_bridge_domain = value
                        self.number_remote_edges_bridge_domain.value_namespace = name_space
                        self.number_remote_edges_bridge_domain.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-remote-edges-xconnect"):
                        self.number_remote_edges_xconnect = value
                        self.number_remote_edges_xconnect.value_namespace = name_space
                        self.number_remote_edges_xconnect.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpls-registered"):
                        self.vpls_registered = value
                        self.vpls_registered.value_namespace = name_space
                        self.vpls_registered.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpws-registered"):
                        self.vpws_registered = value
                        self.vpws_registered.value_namespace = name_space
                        self.vpws_registered.value_namespace_prefix = name_space_prefix


            class G8032(Entity):
                """
                G8032 information
                
                .. attribute:: g8032_rings
                
                	G8032 Ring table
                	**type**\:   :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.G8032, self).__init__()

                    self.yang_name = "g8032"
                    self.yang_parent_name = "node"

                    self.g8032_rings = L2Vpnv2.Nodes.Node.G8032.G8032Rings()
                    self.g8032_rings.parent = self
                    self._children_name_map["g8032_rings"] = "g8032-rings"
                    self._children_yang_names.add("g8032-rings")


                class G8032Rings(Entity):
                    """
                    G8032 Ring table
                    
                    .. attribute:: g8032_ring
                    
                    	G8032 Ring
                    	**type**\: list of    :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.G8032.G8032Rings, self).__init__()

                        self.yang_name = "g8032-rings"
                        self.yang_parent_name = "g8032"

                        self.g8032_ring = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.G8032.G8032Rings, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.G8032.G8032Rings, self).__setattr__(name, value)


                    class G8032Ring(Entity):
                        """
                        G8032 Ring
                        
                        .. attribute:: ring_name  <key>
                        
                        	Ring Name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: g8032_ring_detail
                        
                        	G8032 Ring detailed information
                        	**type**\:   :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                        
                        .. attribute:: g8032_ring_instance_details
                        
                        	G8032 Ring Instance detail table
                        	**type**\:   :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                        
                        .. attribute:: g8032_ring_instance_summaries
                        
                        	G8032 Ring Instance summary table
                        	**type**\:   :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                        
                        .. attribute:: g8032_ring_summary
                        
                        	G8032 Ring summary information
                        	**type**\:   :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring, self).__init__()

                            self.yang_name = "g8032-ring"
                            self.yang_parent_name = "g8032-rings"

                            self.ring_name = YLeaf(YType.str, "ring-name")

                            self.g8032_ring_detail = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                            self.g8032_ring_detail.parent = self
                            self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"
                            self._children_yang_names.add("g8032-ring-detail")

                            self.g8032_ring_instance_details = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                            self.g8032_ring_instance_details.parent = self
                            self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                            self._children_yang_names.add("g8032-ring-instance-details")

                            self.g8032_ring_instance_summaries = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                            self.g8032_ring_instance_summaries.parent = self
                            self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"
                            self._children_yang_names.add("g8032-ring-instance-summaries")

                            self.g8032_ring_summary = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                            self.g8032_ring_summary.parent = self
                            self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"
                            self._children_yang_names.add("g8032-ring-summary")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ring_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring, self).__setattr__(name, value)


                        class G8032RingDetail(Entity):
                            """
                            G8032 Ring detailed information
                            
                            .. attribute:: excluded_vlan_id
                            
                            	Exclusion Vlan ids list 
                            	**type**\:  list of int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_open_ring
                            
                            	Flag open ring
                            	**type**\:  bool
                            
                            .. attribute:: is_provider_bridge
                            
                            	Operating mode Customer/Provider 
                            	**type**\:  bool
                            
                            .. attribute:: monitor0
                            
                            	Monitor port 0
                            	**type**\:  str
                            
                            .. attribute:: monitor1
                            
                            	Monitor port 1
                            	**type**\:  str
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\:  str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\:  str
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\:  str
                            
                            .. attribute:: tcn_propagation
                            
                            	Global TCN propagation
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__init__()

                                self.yang_name = "g8032-ring-detail"
                                self.yang_parent_name = "g8032-ring"

                                self.excluded_vlan_id = YLeafList(YType.uint16, "excluded-vlan-id")

                                self.is_open_ring = YLeaf(YType.boolean, "is-open-ring")

                                self.is_provider_bridge = YLeaf(YType.boolean, "is-provider-bridge")

                                self.monitor0 = YLeaf(YType.str, "monitor0")

                                self.monitor1 = YLeaf(YType.str, "monitor1")

                                self.port0 = YLeaf(YType.str, "port0")

                                self.port1 = YLeaf(YType.str, "port1")

                                self.ring_name = YLeaf(YType.str, "ring-name")

                                self.tcn_propagation = YLeaf(YType.boolean, "tcn-propagation")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("excluded_vlan_id",
                                                "is_open_ring",
                                                "is_provider_bridge",
                                                "monitor0",
                                                "monitor1",
                                                "port0",
                                                "port1",
                                                "ring_name",
                                                "tcn_propagation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.excluded_vlan_id.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.is_open_ring.is_set or
                                    self.is_provider_bridge.is_set or
                                    self.monitor0.is_set or
                                    self.monitor1.is_set or
                                    self.port0.is_set or
                                    self.port1.is_set or
                                    self.ring_name.is_set or
                                    self.tcn_propagation.is_set)

                            def has_operation(self):
                                for leaf in self.excluded_vlan_id.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.excluded_vlan_id.yfilter != YFilter.not_set or
                                    self.is_open_ring.yfilter != YFilter.not_set or
                                    self.is_provider_bridge.yfilter != YFilter.not_set or
                                    self.monitor0.yfilter != YFilter.not_set or
                                    self.monitor1.yfilter != YFilter.not_set or
                                    self.port0.yfilter != YFilter.not_set or
                                    self.port1.yfilter != YFilter.not_set or
                                    self.ring_name.yfilter != YFilter.not_set or
                                    self.tcn_propagation.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g8032-ring-detail" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_open_ring.is_set or self.is_open_ring.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_open_ring.get_name_leafdata())
                                if (self.is_provider_bridge.is_set or self.is_provider_bridge.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_provider_bridge.get_name_leafdata())
                                if (self.monitor0.is_set or self.monitor0.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor0.get_name_leafdata())
                                if (self.monitor1.is_set or self.monitor1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.monitor1.get_name_leafdata())
                                if (self.port0.is_set or self.port0.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port0.get_name_leafdata())
                                if (self.port1.is_set or self.port1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port1.get_name_leafdata())
                                if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_name.get_name_leafdata())
                                if (self.tcn_propagation.is_set or self.tcn_propagation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tcn_propagation.get_name_leafdata())

                                leaf_name_data.extend(self.excluded_vlan_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "excluded-vlan-id" or name == "is-open-ring" or name == "is-provider-bridge" or name == "monitor0" or name == "monitor1" or name == "port0" or name == "port1" or name == "ring-name" or name == "tcn-propagation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "excluded-vlan-id"):
                                    self.excluded_vlan_id.append(value)
                                if(value_path == "is-open-ring"):
                                    self.is_open_ring = value
                                    self.is_open_ring.value_namespace = name_space
                                    self.is_open_ring.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-provider-bridge"):
                                    self.is_provider_bridge = value
                                    self.is_provider_bridge.value_namespace = name_space
                                    self.is_provider_bridge.value_namespace_prefix = name_space_prefix
                                if(value_path == "monitor0"):
                                    self.monitor0 = value
                                    self.monitor0.value_namespace = name_space
                                    self.monitor0.value_namespace_prefix = name_space_prefix
                                if(value_path == "monitor1"):
                                    self.monitor1 = value
                                    self.monitor1.value_namespace = name_space
                                    self.monitor1.value_namespace_prefix = name_space_prefix
                                if(value_path == "port0"):
                                    self.port0 = value
                                    self.port0.value_namespace = name_space
                                    self.port0.value_namespace_prefix = name_space_prefix
                                if(value_path == "port1"):
                                    self.port1 = value
                                    self.port1.value_namespace = name_space
                                    self.port1.value_namespace_prefix = name_space_prefix
                                if(value_path == "ring-name"):
                                    self.ring_name = value
                                    self.ring_name.value_namespace = name_space
                                    self.ring_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "tcn-propagation"):
                                    self.tcn_propagation = value
                                    self.tcn_propagation.value_namespace = name_space
                                    self.tcn_propagation.value_namespace_prefix = name_space_prefix


                        class G8032RingInstanceSummaries(Entity):
                            """
                            G8032 Ring Instance summary table
                            
                            .. attribute:: g8032_ring_instance_summary
                            
                            	G8032 Ring Instance summary information
                            	**type**\: list of    :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__init__()

                                self.yang_name = "g8032-ring-instance-summaries"
                                self.yang_parent_name = "g8032-ring"

                                self.g8032_ring_instance_summary = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__setattr__(name, value)


                            class G8032RingInstanceSummary(Entity):
                                """
                                G8032 Ring Instance summary information
                                
                                .. attribute:: instance  <key>
                                
                                	Instance
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: config_state
                                
                                	State of the instance
                                	**type**\:  bool
                                
                                .. attribute:: included_vlan_id
                                
                                	Inclusion list Vlan Ids
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__init__()

                                    self.yang_name = "g8032-ring-instance-summary"
                                    self.yang_parent_name = "g8032-ring-instance-summaries"

                                    self.instance = YLeaf(YType.int32, "instance")

                                    self.aps_port0 = YLeaf(YType.str, "aps-port0")

                                    self.aps_port1 = YLeaf(YType.str, "aps-port1")

                                    self.config_state = YLeaf(YType.boolean, "config-state")

                                    self.included_vlan_id = YLeafList(YType.uint16, "included-vlan-id")

                                    self.ring_instance = YLeaf(YType.uint32, "ring-instance")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("instance",
                                                    "aps_port0",
                                                    "aps_port1",
                                                    "config_state",
                                                    "included_vlan_id",
                                                    "ring_instance") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__setattr__(name, value)

                                def has_data(self):
                                    for leaf in self.included_vlan_id.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.instance.is_set or
                                        self.aps_port0.is_set or
                                        self.aps_port1.is_set or
                                        self.config_state.is_set or
                                        self.ring_instance.is_set)

                                def has_operation(self):
                                    for leaf in self.included_vlan_id.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.instance.yfilter != YFilter.not_set or
                                        self.aps_port0.yfilter != YFilter.not_set or
                                        self.aps_port1.yfilter != YFilter.not_set or
                                        self.config_state.yfilter != YFilter.not_set or
                                        self.included_vlan_id.yfilter != YFilter.not_set or
                                        self.ring_instance.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "g8032-ring-instance-summary" + "[instance='" + self.instance.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                    if (self.aps_port0.is_set or self.aps_port0.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_port0.get_name_leafdata())
                                    if (self.aps_port1.is_set or self.aps_port1.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_port1.get_name_leafdata())
                                    if (self.config_state.is_set or self.config_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.config_state.get_name_leafdata())
                                    if (self.ring_instance.is_set or self.ring_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ring_instance.get_name_leafdata())

                                    leaf_name_data.extend(self.included_vlan_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "instance" or name == "aps-port0" or name == "aps-port1" or name == "config-state" or name == "included-vlan-id" or name == "ring-instance"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "instance"):
                                        self.instance = value
                                        self.instance.value_namespace = name_space
                                        self.instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-port0"):
                                        self.aps_port0 = value
                                        self.aps_port0.value_namespace = name_space
                                        self.aps_port0.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-port1"):
                                        self.aps_port1 = value
                                        self.aps_port1.value_namespace = name_space
                                        self.aps_port1.value_namespace_prefix = name_space_prefix
                                    if(value_path == "config-state"):
                                        self.config_state = value
                                        self.config_state.value_namespace = name_space
                                        self.config_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "included-vlan-id"):
                                        self.included_vlan_id.append(value)
                                    if(value_path == "ring-instance"):
                                        self.ring_instance = value
                                        self.ring_instance.value_namespace = name_space
                                        self.ring_instance.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.g8032_ring_instance_summary:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.g8032_ring_instance_summary:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g8032-ring-instance-summaries" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "g8032-ring-instance-summary"):
                                    for c in self.g8032_ring_instance_summary:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.g8032_ring_instance_summary.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "g8032-ring-instance-summary"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class G8032RingSummary(Entity):
                            """
                            G8032 Ring summary information
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\:  str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\:  str
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__init__()

                                self.yang_name = "g8032-ring-summary"
                                self.yang_parent_name = "g8032-ring"

                                self.port0 = YLeaf(YType.str, "port0")

                                self.port1 = YLeaf(YType.str, "port1")

                                self.ring_name = YLeaf(YType.str, "ring-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("port0",
                                                "port1",
                                                "ring_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.port0.is_set or
                                    self.port1.is_set or
                                    self.ring_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.port0.yfilter != YFilter.not_set or
                                    self.port1.yfilter != YFilter.not_set or
                                    self.ring_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g8032-ring-summary" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.port0.is_set or self.port0.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port0.get_name_leafdata())
                                if (self.port1.is_set or self.port1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port1.get_name_leafdata())
                                if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ring_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port0" or name == "port1" or name == "ring-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "port0"):
                                    self.port0 = value
                                    self.port0.value_namespace = name_space
                                    self.port0.value_namespace_prefix = name_space_prefix
                                if(value_path == "port1"):
                                    self.port1 = value
                                    self.port1.value_namespace = name_space
                                    self.port1.value_namespace_prefix = name_space_prefix
                                if(value_path == "ring-name"):
                                    self.ring_name = value
                                    self.ring_name.value_namespace = name_space
                                    self.ring_name.value_namespace_prefix = name_space_prefix


                        class G8032RingInstanceDetails(Entity):
                            """
                            G8032 Ring Instance detail table
                            
                            .. attribute:: g8032_ring_instance_detail
                            
                            	G8032 Ring Instance detailed information
                            	**type**\: list of    :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__init__()

                                self.yang_name = "g8032-ring-instance-details"
                                self.yang_parent_name = "g8032-ring"

                                self.g8032_ring_instance_detail = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__setattr__(name, value)


                            class G8032RingInstanceDetail(Entity):
                                """
                                G8032 Ring Instance detailed information
                                
                                .. attribute:: instance  <key>
                                
                                	Instance
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: aps_channel_level
                                
                                	APS channel level
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: config_state
                                
                                	State of the instance
                                	**type**\:  bool
                                
                                .. attribute:: included_vlan_id
                                
                                	Inclusion list Vlan Ids
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ring_description
                                
                                	Ring description
                                	**type**\:  str
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ring_profile
                                
                                	Ring Profile
                                	**type**\:  str
                                
                                .. attribute:: rpl
                                
                                	RPL
                                	**type**\:   :py:class:`L2VpnG8032Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032Rpl>`
                                
                                .. attribute:: unresolved_reason
                                
                                	Reason of unresolved state state
                                	**type**\:   :py:class:`L2VpnG8032UncfgReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032UncfgReason>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__init__()

                                    self.yang_name = "g8032-ring-instance-detail"
                                    self.yang_parent_name = "g8032-ring-instance-details"

                                    self.instance = YLeaf(YType.int32, "instance")

                                    self.aps_channel_level = YLeaf(YType.uint32, "aps-channel-level")

                                    self.aps_port0 = YLeaf(YType.str, "aps-port0")

                                    self.aps_port1 = YLeaf(YType.str, "aps-port1")

                                    self.config_state = YLeaf(YType.boolean, "config-state")

                                    self.included_vlan_id = YLeafList(YType.uint16, "included-vlan-id")

                                    self.ring_description = YLeaf(YType.str, "ring-description")

                                    self.ring_instance = YLeaf(YType.uint32, "ring-instance")

                                    self.ring_profile = YLeaf(YType.str, "ring-profile")

                                    self.rpl = YLeaf(YType.enumeration, "rpl")

                                    self.unresolved_reason = YLeaf(YType.enumeration, "unresolved-reason")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("instance",
                                                    "aps_channel_level",
                                                    "aps_port0",
                                                    "aps_port1",
                                                    "config_state",
                                                    "included_vlan_id",
                                                    "ring_description",
                                                    "ring_instance",
                                                    "ring_profile",
                                                    "rpl",
                                                    "unresolved_reason") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__setattr__(name, value)

                                def has_data(self):
                                    for leaf in self.included_vlan_id.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.instance.is_set or
                                        self.aps_channel_level.is_set or
                                        self.aps_port0.is_set or
                                        self.aps_port1.is_set or
                                        self.config_state.is_set or
                                        self.ring_description.is_set or
                                        self.ring_instance.is_set or
                                        self.ring_profile.is_set or
                                        self.rpl.is_set or
                                        self.unresolved_reason.is_set)

                                def has_operation(self):
                                    for leaf in self.included_vlan_id.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.instance.yfilter != YFilter.not_set or
                                        self.aps_channel_level.yfilter != YFilter.not_set or
                                        self.aps_port0.yfilter != YFilter.not_set or
                                        self.aps_port1.yfilter != YFilter.not_set or
                                        self.config_state.yfilter != YFilter.not_set or
                                        self.included_vlan_id.yfilter != YFilter.not_set or
                                        self.ring_description.yfilter != YFilter.not_set or
                                        self.ring_instance.yfilter != YFilter.not_set or
                                        self.ring_profile.yfilter != YFilter.not_set or
                                        self.rpl.yfilter != YFilter.not_set or
                                        self.unresolved_reason.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "g8032-ring-instance-detail" + "[instance='" + self.instance.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance.get_name_leafdata())
                                    if (self.aps_channel_level.is_set or self.aps_channel_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_channel_level.get_name_leafdata())
                                    if (self.aps_port0.is_set or self.aps_port0.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_port0.get_name_leafdata())
                                    if (self.aps_port1.is_set or self.aps_port1.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aps_port1.get_name_leafdata())
                                    if (self.config_state.is_set or self.config_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.config_state.get_name_leafdata())
                                    if (self.ring_description.is_set or self.ring_description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ring_description.get_name_leafdata())
                                    if (self.ring_instance.is_set or self.ring_instance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ring_instance.get_name_leafdata())
                                    if (self.ring_profile.is_set or self.ring_profile.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ring_profile.get_name_leafdata())
                                    if (self.rpl.is_set or self.rpl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpl.get_name_leafdata())
                                    if (self.unresolved_reason.is_set or self.unresolved_reason.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unresolved_reason.get_name_leafdata())

                                    leaf_name_data.extend(self.included_vlan_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "instance" or name == "aps-channel-level" or name == "aps-port0" or name == "aps-port1" or name == "config-state" or name == "included-vlan-id" or name == "ring-description" or name == "ring-instance" or name == "ring-profile" or name == "rpl" or name == "unresolved-reason"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "instance"):
                                        self.instance = value
                                        self.instance.value_namespace = name_space
                                        self.instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-channel-level"):
                                        self.aps_channel_level = value
                                        self.aps_channel_level.value_namespace = name_space
                                        self.aps_channel_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-port0"):
                                        self.aps_port0 = value
                                        self.aps_port0.value_namespace = name_space
                                        self.aps_port0.value_namespace_prefix = name_space_prefix
                                    if(value_path == "aps-port1"):
                                        self.aps_port1 = value
                                        self.aps_port1.value_namespace = name_space
                                        self.aps_port1.value_namespace_prefix = name_space_prefix
                                    if(value_path == "config-state"):
                                        self.config_state = value
                                        self.config_state.value_namespace = name_space
                                        self.config_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "included-vlan-id"):
                                        self.included_vlan_id.append(value)
                                    if(value_path == "ring-description"):
                                        self.ring_description = value
                                        self.ring_description.value_namespace = name_space
                                        self.ring_description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ring-instance"):
                                        self.ring_instance = value
                                        self.ring_instance.value_namespace = name_space
                                        self.ring_instance.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ring-profile"):
                                        self.ring_profile = value
                                        self.ring_profile.value_namespace = name_space
                                        self.ring_profile.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpl"):
                                        self.rpl = value
                                        self.rpl.value_namespace = name_space
                                        self.rpl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unresolved-reason"):
                                        self.unresolved_reason = value
                                        self.unresolved_reason.value_namespace = name_space
                                        self.unresolved_reason.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.g8032_ring_instance_detail:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.g8032_ring_instance_detail:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g8032-ring-instance-details" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "g8032-ring-instance-detail"):
                                    for c in self.g8032_ring_instance_detail:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.g8032_ring_instance_detail.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "g8032-ring-instance-detail"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.ring_name.is_set or
                                (self.g8032_ring_detail is not None and self.g8032_ring_detail.has_data()) or
                                (self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details.has_data()) or
                                (self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries.has_data()) or
                                (self.g8032_ring_summary is not None and self.g8032_ring_summary.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ring_name.yfilter != YFilter.not_set or
                                (self.g8032_ring_detail is not None and self.g8032_ring_detail.has_operation()) or
                                (self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details.has_operation()) or
                                (self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries.has_operation()) or
                                (self.g8032_ring_summary is not None and self.g8032_ring_summary.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring" + "[ring-name='" + self.ring_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ring_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "g8032-ring-detail"):
                                if (self.g8032_ring_detail is None):
                                    self.g8032_ring_detail = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                                    self.g8032_ring_detail.parent = self
                                    self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"
                                return self.g8032_ring_detail

                            if (child_yang_name == "g8032-ring-instance-details"):
                                if (self.g8032_ring_instance_details is None):
                                    self.g8032_ring_instance_details = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                                    self.g8032_ring_instance_details.parent = self
                                    self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                                return self.g8032_ring_instance_details

                            if (child_yang_name == "g8032-ring-instance-summaries"):
                                if (self.g8032_ring_instance_summaries is None):
                                    self.g8032_ring_instance_summaries = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                                    self.g8032_ring_instance_summaries.parent = self
                                    self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"
                                return self.g8032_ring_instance_summaries

                            if (child_yang_name == "g8032-ring-summary"):
                                if (self.g8032_ring_summary is None):
                                    self.g8032_ring_summary = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                                    self.g8032_ring_summary.parent = self
                                    self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"
                                return self.g8032_ring_summary

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "g8032-ring-detail" or name == "g8032-ring-instance-details" or name == "g8032-ring-instance-summaries" or name == "g8032-ring-summary" or name == "ring-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ring-name"):
                                self.ring_name = value
                                self.ring_name.value_namespace = name_space
                                self.ring_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.g8032_ring:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.g8032_ring:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g8032-rings" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "g8032-ring"):
                            for c in self.g8032_ring:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.g8032_ring.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "g8032-ring"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.g8032_rings is not None and self.g8032_rings.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.g8032_rings is not None and self.g8032_rings.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "g8032" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g8032-rings"):
                        if (self.g8032_rings is None):
                            self.g8032_rings = L2Vpnv2.Nodes.Node.G8032.G8032Rings()
                            self.g8032_rings.parent = self
                            self._children_name_map["g8032_rings"] = "g8032-rings"
                        return self.g8032_rings

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g8032-rings"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class PseudowireClasses(Entity):
                """
                List of pseudowire classes
                
                .. attribute:: pseudowire_class
                
                	Pseudowire class information
                	**type**\: list of    :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.PseudowireClasses, self).__init__()

                    self.yang_name = "pseudowire-classes"
                    self.yang_parent_name = "node"

                    self.pseudowire_class = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.PseudowireClasses, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.PseudowireClasses, self).__setattr__(name, value)


                class PseudowireClass(Entity):
                    """
                    Pseudowire class information
                    
                    .. attribute:: pseudowire_class_name  <key>
                    
                    	Pseudowire Class Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: backup_mac_withdraw
                    
                    	TRUE if MAC withdraw message is sent
                    	**type**\:  bool
                    
                    .. attribute:: control_word
                    
                    	Control word
                    	**type**\:   :py:class:`L2VpnPwClassControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwClassControlWord>`
                    
                    .. attribute:: disable_delay
                    
                    	Disable Deley
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                    
                    .. attribute:: local_source_address
                    
                    	Local source address
                    	**type**\:   :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	PreferredPathDisableFallback
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                    
                    .. attribute:: tag_rewrite
                    
                    	Static tag rewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transport_mode
                    
                    	Transport mode
                    	**type**\:   :py:class:`L2VpnTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTransportMode>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass, self).__init__()

                        self.yang_name = "pseudowire-class"
                        self.yang_parent_name = "pseudowire-classes"

                        self.pseudowire_class_name = YLeaf(YType.str, "pseudowire-class-name")

                        self.backup_mac_withdraw = YLeaf(YType.boolean, "backup-mac-withdraw")

                        self.control_word = YLeaf(YType.enumeration, "control-word")

                        self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                        self.disable_never = YLeaf(YType.boolean, "disable-never")

                        self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                        self.load_balance = YLeaf(YType.enumeration, "load-balance")

                        self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                        self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                        self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                        self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                        self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                        self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                        self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                        self.transport_mode = YLeaf(YType.enumeration, "transport-mode")

                        self.encapsulation_info = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                        self._children_yang_names.add("encapsulation-info")

                        self.local_source_address = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                        self.local_source_address.parent = self
                        self._children_name_map["local_source_address"] = "local-source-address"
                        self._children_yang_names.add("local-source-address")

                        self.preferred_path = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath()
                        self.preferred_path.parent = self
                        self._children_name_map["preferred_path"] = "preferred-path"
                        self._children_yang_names.add("preferred-path")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("pseudowire_class_name",
                                        "backup_mac_withdraw",
                                        "control_word",
                                        "disable_delay",
                                        "disable_never",
                                        "is_flow_label_static",
                                        "load_balance",
                                        "preferred_path_disable_fallback",
                                        "protocol",
                                        "pw_class_name",
                                        "pw_flow_label_code17_disabled",
                                        "pw_flow_label_type_cfg",
                                        "resync_enabled",
                                        "resync_threshold",
                                        "sequencing_type",
                                        "tag_rewrite",
                                        "transport_mode") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass, self).__setattr__(name, value)


                    class EncapsulationInfo(Entity):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__init__()

                            self.yang_name = "encapsulation-info"
                            self.yang_parent_name = "pseudowire-class"

                            self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                            self.l2tpv3 = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self
                            self._children_name_map["l2tpv3"] = "l2tpv3"
                            self._children_yang_names.add("l2tpv3")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("encapsulation") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__setattr__(name, value)


                        class L2Tpv3(Entity):
                            """
                            l2tpv3
                            
                            .. attribute:: cookie_size
                            
                            	Cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__init__()

                                self.yang_name = "l2tpv3"
                                self.yang_parent_name = "encapsulation-info"

                                self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                                self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                self.tos = YLeaf(YType.uint8, "tos")

                                self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                self.ttl = YLeaf(YType.uint8, "ttl")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("cookie_size",
                                                "dont_fragment_bit",
                                                "ipv4_source_address",
                                                "l2tp_class_name",
                                                "path_mtu_enabled",
                                                "path_mtu_max_value",
                                                "tos",
                                                "tos_mode",
                                                "ttl") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.cookie_size.is_set or
                                    self.dont_fragment_bit.is_set or
                                    self.ipv4_source_address.is_set or
                                    self.l2tp_class_name.is_set or
                                    self.path_mtu_enabled.is_set or
                                    self.path_mtu_max_value.is_set or
                                    self.tos.is_set or
                                    self.tos_mode.is_set or
                                    self.ttl.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.cookie_size.yfilter != YFilter.not_set or
                                    self.dont_fragment_bit.yfilter != YFilter.not_set or
                                    self.ipv4_source_address.yfilter != YFilter.not_set or
                                    self.l2tp_class_name.yfilter != YFilter.not_set or
                                    self.path_mtu_enabled.yfilter != YFilter.not_set or
                                    self.path_mtu_max_value.yfilter != YFilter.not_set or
                                    self.tos.yfilter != YFilter.not_set or
                                    self.tos_mode.yfilter != YFilter.not_set or
                                    self.ttl.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2tpv3" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cookie_size.get_name_leafdata())
                                if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos.get_name_leafdata())
                                if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ttl.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "cookie-size" or name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "l2tp-class-name" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "tos" or name == "tos-mode" or name == "ttl"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "cookie-size"):
                                    self.cookie_size = value
                                    self.cookie_size.value_namespace = name_space
                                    self.cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "dont-fragment-bit"):
                                    self.dont_fragment_bit = value
                                    self.dont_fragment_bit.value_namespace = name_space
                                    self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-source-address"):
                                    self.ipv4_source_address = value
                                    self.ipv4_source_address.value_namespace = name_space
                                    self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "l2tp-class-name"):
                                    self.l2tp_class_name = value
                                    self.l2tp_class_name.value_namespace = name_space
                                    self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-enabled"):
                                    self.path_mtu_enabled = value
                                    self.path_mtu_enabled.value_namespace = name_space
                                    self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-max-value"):
                                    self.path_mtu_max_value = value
                                    self.path_mtu_max_value.value_namespace = name_space
                                    self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos"):
                                    self.tos = value
                                    self.tos.value_namespace = name_space
                                    self.tos.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos-mode"):
                                    self.tos_mode = value
                                    self.tos_mode.value_namespace = name_space
                                    self.tos_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "ttl"):
                                    self.ttl = value
                                    self.ttl.value_namespace = name_space
                                    self.ttl.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.encapsulation.is_set or
                                (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.encapsulation.yfilter != YFilter.not_set or
                                (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "encapsulation-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "l2tpv3"):
                                if (self.l2tpv3 is None):
                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                return self.l2tpv3

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "l2tpv3" or name == "encapsulation"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "encapsulation"):
                                self.encapsulation = value
                                self.encapsulation.value_namespace = name_space
                                self.encapsulation.value_namespace_prefix = name_space_prefix


                    class PreferredPath(Entity):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath, self).__init__()

                            self.yang_name = "preferred-path"
                            self.yang_parent_name = "pseudowire-class"

                            self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                            self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                            self.option = YLeaf(YType.enumeration, "option")

                            self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                            self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ip_tunnel_interface_number",
                                            "next_hop_ip",
                                            "option",
                                            "te_tunnel_interface_number",
                                            "tp_tunnel_interface_number") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ip_tunnel_interface_number.is_set or
                                self.next_hop_ip.is_set or
                                self.option.is_set or
                                self.te_tunnel_interface_number.is_set or
                                self.tp_tunnel_interface_number.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set or
                                self.option.yfilter != YFilter.not_set or
                                self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "preferred-path" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                            if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.option.get_name_leafdata())
                            if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                            if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ip-tunnel-interface-number"):
                                self.ip_tunnel_interface_number = value
                                self.ip_tunnel_interface_number.value_namespace = name_space
                                self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix
                            if(value_path == "option"):
                                self.option = value
                                self.option.value_namespace = name_space
                                self.option.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-tunnel-interface-number"):
                                self.te_tunnel_interface_number = value
                                self.te_tunnel_interface_number.value_namespace = name_space
                                self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "tp-tunnel-interface-number"):
                                self.tp_tunnel_interface_number = value
                                self.tp_tunnel_interface_number.value_namespace = name_space
                                self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                    class LocalSourceAddress(Entity):
                        """
                        Local source address
                        
                        .. attribute:: address
                        
                        	Local source address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: configuration
                        
                        	Configuration
                        	**type**\:   :py:class:`L2VpnSrcAddressSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSrcAddressSet>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__init__()

                            self.yang_name = "local-source-address"
                            self.yang_parent_name = "pseudowire-class"

                            self.address = YLeaf(YType.str, "address")

                            self.configuration = YLeaf(YType.enumeration, "configuration")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "configuration") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.configuration.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.configuration.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.configuration.is_set or self.configuration.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "configuration"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration"):
                                self.configuration = value
                                self.configuration.value_namespace = name_space
                                self.configuration.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.pseudowire_class_name.is_set or
                            self.backup_mac_withdraw.is_set or
                            self.control_word.is_set or
                            self.disable_delay.is_set or
                            self.disable_never.is_set or
                            self.is_flow_label_static.is_set or
                            self.load_balance.is_set or
                            self.preferred_path_disable_fallback.is_set or
                            self.protocol.is_set or
                            self.pw_class_name.is_set or
                            self.pw_flow_label_code17_disabled.is_set or
                            self.pw_flow_label_type_cfg.is_set or
                            self.resync_enabled.is_set or
                            self.resync_threshold.is_set or
                            self.sequencing_type.is_set or
                            self.tag_rewrite.is_set or
                            self.transport_mode.is_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                            (self.local_source_address is not None and self.local_source_address.has_data()) or
                            (self.preferred_path is not None and self.preferred_path.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.pseudowire_class_name.yfilter != YFilter.not_set or
                            self.backup_mac_withdraw.yfilter != YFilter.not_set or
                            self.control_word.yfilter != YFilter.not_set or
                            self.disable_delay.yfilter != YFilter.not_set or
                            self.disable_never.yfilter != YFilter.not_set or
                            self.is_flow_label_static.yfilter != YFilter.not_set or
                            self.load_balance.yfilter != YFilter.not_set or
                            self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.pw_class_name.yfilter != YFilter.not_set or
                            self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                            self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                            self.resync_enabled.yfilter != YFilter.not_set or
                            self.resync_threshold.yfilter != YFilter.not_set or
                            self.sequencing_type.yfilter != YFilter.not_set or
                            self.tag_rewrite.yfilter != YFilter.not_set or
                            self.transport_mode.yfilter != YFilter.not_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                            (self.local_source_address is not None and self.local_source_address.has_operation()) or
                            (self.preferred_path is not None and self.preferred_path.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pseudowire-class" + "[pseudowire-class-name='" + self.pseudowire_class_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.pseudowire_class_name.is_set or self.pseudowire_class_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudowire_class_name.get_name_leafdata())
                        if (self.backup_mac_withdraw.is_set or self.backup_mac_withdraw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_mac_withdraw.get_name_leafdata())
                        if (self.control_word.is_set or self.control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.control_word.get_name_leafdata())
                        if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_delay.get_name_leafdata())
                        if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_never.get_name_leafdata())
                        if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                        if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance.get_name_leafdata())
                        if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                        if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                        if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                        if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                        if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                        if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                        if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                        if (self.transport_mode.is_set or self.transport_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transport_mode.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "encapsulation-info"):
                            if (self.encapsulation_info is None):
                                self.encapsulation_info = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            return self.encapsulation_info

                        if (child_yang_name == "local-source-address"):
                            if (self.local_source_address is None):
                                self.local_source_address = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                                self.local_source_address.parent = self
                                self._children_name_map["local_source_address"] = "local-source-address"
                            return self.local_source_address

                        if (child_yang_name == "preferred-path"):
                            if (self.preferred_path is None):
                                self.preferred_path = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                            return self.preferred_path

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "encapsulation-info" or name == "local-source-address" or name == "preferred-path" or name == "pseudowire-class-name" or name == "backup-mac-withdraw" or name == "control-word" or name == "disable-delay" or name == "disable-never" or name == "is-flow-label-static" or name == "load-balance" or name == "preferred-path-disable-fallback" or name == "protocol" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type-cfg" or name == "resync-enabled" or name == "resync-threshold" or name == "sequencing-type" or name == "tag-rewrite" or name == "transport-mode"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "pseudowire-class-name"):
                            self.pseudowire_class_name = value
                            self.pseudowire_class_name.value_namespace = name_space
                            self.pseudowire_class_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-mac-withdraw"):
                            self.backup_mac_withdraw = value
                            self.backup_mac_withdraw.value_namespace = name_space
                            self.backup_mac_withdraw.value_namespace_prefix = name_space_prefix
                        if(value_path == "control-word"):
                            self.control_word = value
                            self.control_word.value_namespace = name_space
                            self.control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-delay"):
                            self.disable_delay = value
                            self.disable_delay.value_namespace = name_space
                            self.disable_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-never"):
                            self.disable_never = value
                            self.disable_never.value_namespace = name_space
                            self.disable_never.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-flow-label-static"):
                            self.is_flow_label_static = value
                            self.is_flow_label_static.value_namespace = name_space
                            self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance"):
                            self.load_balance = value
                            self.load_balance.value_namespace = name_space
                            self.load_balance.value_namespace_prefix = name_space_prefix
                        if(value_path == "preferred-path-disable-fallback"):
                            self.preferred_path_disable_fallback = value
                            self.preferred_path_disable_fallback.value_namespace = name_space
                            self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-class-name"):
                            self.pw_class_name = value
                            self.pw_class_name.value_namespace = name_space
                            self.pw_class_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-code17-disabled"):
                            self.pw_flow_label_code17_disabled = value
                            self.pw_flow_label_code17_disabled.value_namespace = name_space
                            self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type-cfg"):
                            self.pw_flow_label_type_cfg = value
                            self.pw_flow_label_type_cfg.value_namespace = name_space
                            self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-enabled"):
                            self.resync_enabled = value
                            self.resync_enabled.value_namespace = name_space
                            self.resync_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-threshold"):
                            self.resync_threshold = value
                            self.resync_threshold.value_namespace = name_space
                            self.resync_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "sequencing-type"):
                            self.sequencing_type = value
                            self.sequencing_type.value_namespace = name_space
                            self.sequencing_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "tag-rewrite"):
                            self.tag_rewrite = value
                            self.tag_rewrite.value_namespace = name_space
                            self.tag_rewrite.value_namespace_prefix = name_space_prefix
                        if(value_path == "transport-mode"):
                            self.transport_mode = value
                            self.transport_mode.value_namespace = name_space
                            self.transport_mode.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.pseudowire_class:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.pseudowire_class:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pseudowire-classes" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pseudowire-class"):
                        for c in self.pseudowire_class:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.pseudowire_class.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pseudowire-class"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2VpnCollaborators(Entity):
                """
                L2VPN collaborator information
                
                .. attribute:: collaborator_statistics
                
                	Collaborator Statistics
                	**type**\:   :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.L2VpnCollaborators, self).__init__()

                    self.yang_name = "l2vpn-collaborators"
                    self.yang_parent_name = "node"

                    self.collaborator_statistics = L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics()
                    self.collaborator_statistics.parent = self
                    self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
                    self._children_yang_names.add("collaborator-statistics")


                class CollaboratorStatistics(Entity):
                    """
                    Collaborator Statistics
                    
                    .. attribute:: count
                    
                    	count
                    	**type**\: list of    :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics.Count>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics, self).__init__()

                        self.yang_name = "collaborator-statistics"
                        self.yang_parent_name = "l2vpn-collaborators"

                        self.count = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics, self).__setattr__(name, value)


                    class Count(Entity):
                        """
                        count
                        
                        .. attribute:: collaborator_name
                        
                        	Collaborator Name
                        	**type**\:  str
                        
                        .. attribute:: down
                        
                        	Down
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_up
                        
                        	Is up
                        	**type**\:  bool
                        
                        .. attribute:: up
                        
                        	Up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics.Count, self).__init__()

                            self.yang_name = "count"
                            self.yang_parent_name = "collaborator-statistics"

                            self.collaborator_name = YLeaf(YType.str, "collaborator-name")

                            self.down = YLeaf(YType.uint32, "down")

                            self.is_up = YLeaf(YType.boolean, "is-up")

                            self.up = YLeaf(YType.uint32, "up")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("collaborator_name",
                                            "down",
                                            "is_up",
                                            "up") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics.Count, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics.Count, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.collaborator_name.is_set or
                                self.down.is_set or
                                self.is_up.is_set or
                                self.up.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.collaborator_name.yfilter != YFilter.not_set or
                                self.down.yfilter != YFilter.not_set or
                                self.is_up.yfilter != YFilter.not_set or
                                self.up.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "count" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.collaborator_name.is_set or self.collaborator_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.collaborator_name.get_name_leafdata())
                            if (self.down.is_set or self.down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.down.get_name_leafdata())
                            if (self.is_up.is_set or self.is_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_up.get_name_leafdata())
                            if (self.up.is_set or self.up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.up.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "collaborator-name" or name == "down" or name == "is-up" or name == "up"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "collaborator-name"):
                                self.collaborator_name = value
                                self.collaborator_name.value_namespace = name_space
                                self.collaborator_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "down"):
                                self.down = value
                                self.down.value_namespace = name_space
                                self.down.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-up"):
                                self.is_up = value
                                self.is_up.value_namespace = name_space
                                self.is_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "up"):
                                self.up = value
                                self.up.value_namespace = name_space
                                self.up.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.count:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.count:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "collaborator-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "count"):
                            for c in self.count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics.Count()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.count.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.collaborator_statistics is not None and self.collaborator_statistics.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.collaborator_statistics is not None and self.collaborator_statistics.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2vpn-collaborators" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "collaborator-statistics"):
                        if (self.collaborator_statistics is None):
                            self.collaborator_statistics = L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics()
                            self.collaborator_statistics.parent = self
                            self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
                        return self.collaborator_statistics

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "collaborator-statistics"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Mvrp(Entity):
                """
                MVRP
                
                .. attribute:: mvrp_main_ports
                
                	MVRP Main Port Table
                	**type**\:   :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "node"

                    self.mvrp_main_ports = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts()
                    self.mvrp_main_ports.parent = self
                    self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
                    self._children_yang_names.add("mvrp-main-ports")


                class MvrpMainPorts(Entity):
                    """
                    MVRP Main Port Table
                    
                    .. attribute:: mvrp_main_port
                    
                    	MVRP Main Port
                    	**type**\: list of    :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts, self).__init__()

                        self.yang_name = "mvrp-main-ports"
                        self.yang_parent_name = "mvrp"

                        self.mvrp_main_port = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts, self).__setattr__(name, value)


                    class MvrpMainPort(Entity):
                        """
                        MVRP Main Port
                        
                        .. attribute:: main_port_interface_name  <key>
                        
                        	Main Port interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mvrp_bridge_ports
                        
                        	MVRP Bridge Port Table
                        	**type**\:   :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                        
                        .. attribute:: mvrp_main_port_info
                        
                        	MVRP Main Port Information
                        	**type**\:   :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort, self).__init__()

                            self.yang_name = "mvrp-main-port"
                            self.yang_parent_name = "mvrp-main-ports"

                            self.main_port_interface_name = YLeaf(YType.str, "main-port-interface-name")

                            self.mvrp_bridge_ports = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                            self.mvrp_bridge_ports.parent = self
                            self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                            self._children_yang_names.add("mvrp-bridge-ports")

                            self.mvrp_main_port_info = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                            self.mvrp_main_port_info.parent = self
                            self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"
                            self._children_yang_names.add("mvrp-main-port-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("main_port_interface_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort, self).__setattr__(name, value)


                        class MvrpMainPortInfo(Entity):
                            """
                            MVRP Main Port Information
                            
                            .. attribute:: default_bridge_port
                            
                            	Trunk or default Bridge Port
                            	**type**\:   :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                            
                            .. attribute:: is_default_encap
                            
                            	Is default encap set
                            	**type**\:  bool
                            
                            .. attribute:: is_trunk
                            
                            	Is main port a trunk
                            	**type**\:  bool
                            
                            .. attribute:: main_port_interface_name
                            
                            	Main Port Interface name
                            	**type**\:  str
                            
                            .. attribute:: number_of_bridge_ports
                            
                            	Number of Bridge Ports
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__init__()

                                self.yang_name = "mvrp-main-port-info"
                                self.yang_parent_name = "mvrp-main-port"

                                self.is_default_encap = YLeaf(YType.boolean, "is-default-encap")

                                self.is_trunk = YLeaf(YType.boolean, "is-trunk")

                                self.main_port_interface_name = YLeaf(YType.str, "main-port-interface-name")

                                self.number_of_bridge_ports = YLeaf(YType.uint32, "number-of-bridge-ports")

                                self.default_bridge_port = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                                self.default_bridge_port.parent = self
                                self._children_name_map["default_bridge_port"] = "default-bridge-port"
                                self._children_yang_names.add("default-bridge-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_default_encap",
                                                "is_trunk",
                                                "main_port_interface_name",
                                                "number_of_bridge_ports") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__setattr__(name, value)


                            class DefaultBridgePort(Entity):
                                """
                                Trunk or default Bridge Port
                                
                                .. attribute:: bridge_port_interface_name
                                
                                	Bridge port Interface name
                                	**type**\:  str
                                
                                .. attribute:: bridge_port_xconnect_id
                                
                                	Bridge port XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mvrp_sequence_number
                                
                                	MVRP Sequence Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan_range
                                
                                	VLAN IDs
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__init__()

                                    self.yang_name = "default-bridge-port"
                                    self.yang_parent_name = "mvrp-main-port-info"

                                    self.bridge_port_interface_name = YLeaf(YType.str, "bridge-port-interface-name")

                                    self.bridge_port_xconnect_id = YLeaf(YType.uint32, "bridge-port-xconnect-id")

                                    self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bridge_port_interface_name",
                                                    "bridge_port_xconnect_id",
                                                    "mvrp_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    VLAN IDs
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "default-bridge-port"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.bridge_port_interface_name.is_set or
                                        self.bridge_port_xconnect_id.is_set or
                                        self.mvrp_sequence_number.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bridge_port_interface_name.yfilter != YFilter.not_set or
                                        self.bridge_port_xconnect_id.yfilter != YFilter.not_set or
                                        self.mvrp_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "default-bridge-port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bridge_port_interface_name.is_set or self.bridge_port_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_interface_name.get_name_leafdata())
                                    if (self.bridge_port_xconnect_id.is_set or self.bridge_port_xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_xconnect_id.get_name_leafdata())
                                    if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "bridge-port-interface-name" or name == "bridge-port-xconnect-id" or name == "mvrp-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bridge-port-interface-name"):
                                        self.bridge_port_interface_name = value
                                        self.bridge_port_interface_name.value_namespace = name_space
                                        self.bridge_port_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bridge-port-xconnect-id"):
                                        self.bridge_port_xconnect_id = value
                                        self.bridge_port_xconnect_id.value_namespace = name_space
                                        self.bridge_port_xconnect_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mvrp-sequence-number"):
                                        self.mvrp_sequence_number = value
                                        self.mvrp_sequence_number.value_namespace = name_space
                                        self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.is_default_encap.is_set or
                                    self.is_trunk.is_set or
                                    self.main_port_interface_name.is_set or
                                    self.number_of_bridge_ports.is_set or
                                    (self.default_bridge_port is not None and self.default_bridge_port.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_default_encap.yfilter != YFilter.not_set or
                                    self.is_trunk.yfilter != YFilter.not_set or
                                    self.main_port_interface_name.yfilter != YFilter.not_set or
                                    self.number_of_bridge_ports.yfilter != YFilter.not_set or
                                    (self.default_bridge_port is not None and self.default_bridge_port.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mvrp-main-port-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_default_encap.is_set or self.is_default_encap.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_default_encap.get_name_leafdata())
                                if (self.is_trunk.is_set or self.is_trunk.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_trunk.get_name_leafdata())
                                if (self.main_port_interface_name.is_set or self.main_port_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.main_port_interface_name.get_name_leafdata())
                                if (self.number_of_bridge_ports.is_set or self.number_of_bridge_ports.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_of_bridge_ports.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "default-bridge-port"):
                                    if (self.default_bridge_port is None):
                                        self.default_bridge_port = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                                        self.default_bridge_port.parent = self
                                        self._children_name_map["default_bridge_port"] = "default-bridge-port"
                                    return self.default_bridge_port

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "default-bridge-port" or name == "is-default-encap" or name == "is-trunk" or name == "main-port-interface-name" or name == "number-of-bridge-ports"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-default-encap"):
                                    self.is_default_encap = value
                                    self.is_default_encap.value_namespace = name_space
                                    self.is_default_encap.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-trunk"):
                                    self.is_trunk = value
                                    self.is_trunk.value_namespace = name_space
                                    self.is_trunk.value_namespace_prefix = name_space_prefix
                                if(value_path == "main-port-interface-name"):
                                    self.main_port_interface_name = value
                                    self.main_port_interface_name.value_namespace = name_space
                                    self.main_port_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-of-bridge-ports"):
                                    self.number_of_bridge_ports = value
                                    self.number_of_bridge_ports.value_namespace = name_space
                                    self.number_of_bridge_ports.value_namespace_prefix = name_space_prefix


                        class MvrpBridgePorts(Entity):
                            """
                            MVRP Bridge Port Table
                            
                            .. attribute:: mvrp_bridge_port
                            
                            	MVRP Bridge Port Information
                            	**type**\: list of    :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__init__()

                                self.yang_name = "mvrp-bridge-ports"
                                self.yang_parent_name = "mvrp-main-port"

                                self.mvrp_bridge_port = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__setattr__(name, value)


                            class MvrpBridgePort(Entity):
                                """
                                MVRP Bridge Port Information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Bridge Port Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: bridge_port_interface_name
                                
                                	Bridge port Interface name
                                	**type**\:  str
                                
                                .. attribute:: bridge_port_xconnect_id
                                
                                	Bridge port XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mvrp_sequence_number
                                
                                	MVRP Sequence Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan_range
                                
                                	VLAN IDs
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__init__()

                                    self.yang_name = "mvrp-bridge-port"
                                    self.yang_parent_name = "mvrp-bridge-ports"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.bridge_port_interface_name = YLeaf(YType.str, "bridge-port-interface-name")

                                    self.bridge_port_xconnect_id = YLeaf(YType.uint32, "bridge-port-xconnect-id")

                                    self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "bridge_port_interface_name",
                                                    "bridge_port_xconnect_id",
                                                    "mvrp_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    VLAN IDs
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "mvrp-bridge-port"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.interface_name.is_set or
                                        self.bridge_port_interface_name.is_set or
                                        self.bridge_port_xconnect_id.is_set or
                                        self.mvrp_sequence_number.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.bridge_port_interface_name.yfilter != YFilter.not_set or
                                        self.bridge_port_xconnect_id.yfilter != YFilter.not_set or
                                        self.mvrp_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mvrp-bridge-port" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.bridge_port_interface_name.is_set or self.bridge_port_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_interface_name.get_name_leafdata())
                                    if (self.bridge_port_xconnect_id.is_set or self.bridge_port_xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bridge_port_xconnect_id.get_name_leafdata())
                                    if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "interface-name" or name == "bridge-port-interface-name" or name == "bridge-port-xconnect-id" or name == "mvrp-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bridge-port-interface-name"):
                                        self.bridge_port_interface_name = value
                                        self.bridge_port_interface_name.value_namespace = name_space
                                        self.bridge_port_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bridge-port-xconnect-id"):
                                        self.bridge_port_xconnect_id = value
                                        self.bridge_port_xconnect_id.value_namespace = name_space
                                        self.bridge_port_xconnect_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mvrp-sequence-number"):
                                        self.mvrp_sequence_number = value
                                        self.mvrp_sequence_number.value_namespace = name_space
                                        self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.mvrp_bridge_port:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.mvrp_bridge_port:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mvrp-bridge-ports" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mvrp-bridge-port"):
                                    for c in self.mvrp_bridge_port:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mvrp_bridge_port.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mvrp-bridge-port"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.main_port_interface_name.is_set or
                                (self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports.has_data()) or
                                (self.mvrp_main_port_info is not None and self.mvrp_main_port_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.main_port_interface_name.yfilter != YFilter.not_set or
                                (self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports.has_operation()) or
                                (self.mvrp_main_port_info is not None and self.mvrp_main_port_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mvrp-main-port" + "[main-port-interface-name='" + self.main_port_interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.main_port_interface_name.is_set or self.main_port_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.main_port_interface_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mvrp-bridge-ports"):
                                if (self.mvrp_bridge_ports is None):
                                    self.mvrp_bridge_ports = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                                    self.mvrp_bridge_ports.parent = self
                                    self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                                return self.mvrp_bridge_ports

                            if (child_yang_name == "mvrp-main-port-info"):
                                if (self.mvrp_main_port_info is None):
                                    self.mvrp_main_port_info = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                                    self.mvrp_main_port_info.parent = self
                                    self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"
                                return self.mvrp_main_port_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mvrp-bridge-ports" or name == "mvrp-main-port-info" or name == "main-port-interface-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "main-port-interface-name"):
                                self.main_port_interface_name = value
                                self.main_port_interface_name.value_namespace = name_space
                                self.main_port_interface_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.mvrp_main_port:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.mvrp_main_port:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mvrp-main-ports" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mvrp-main-port"):
                            for c in self.mvrp_main_port:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mvrp_main_port.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mvrp-main-port"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.mvrp_main_ports is not None and self.mvrp_main_ports.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.mvrp_main_ports is not None and self.mvrp_main_ports.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mvrp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mvrp-main-ports"):
                        if (self.mvrp_main_ports is None):
                            self.mvrp_main_ports = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts()
                            self.mvrp_main_ports.parent = self
                            self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
                        return self.mvrp_main_ports

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mvrp-main-ports"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GenericInterfaces(Entity):
                """
                L2VPN generic interface list Table
                
                .. attribute:: generic_interface
                
                	Generic Interface List information
                	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.GenericInterfaces, self).__init__()

                    self.yang_name = "generic-interfaces"
                    self.yang_parent_name = "node"

                    self.generic_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.GenericInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.GenericInterfaces, self).__setattr__(name, value)


                class GenericInterface(Entity):
                    """
                    Generic Interface List information
                    
                    .. attribute:: interface_list_name  <key>
                    
                    	Generic Interface List Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface.Interface>`
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_list_name_xr
                    
                    	Interface\-list name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_interfaces
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface, self).__init__()

                        self.yang_name = "generic-interface"
                        self.yang_parent_name = "generic-interfaces"

                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                        self.interface_list_name_xr = YLeaf(YType.str, "interface-list-name-xr")

                        self.items = YLeaf(YType.uint32, "items")

                        self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_list_name",
                                        "interface_list_id",
                                        "interface_list_name_xr",
                                        "items",
                                        "number_of_interfaces") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "generic-interface"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                            self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                            self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "is_fib_downloaded",
                                            "not_supported_replications",
                                            "pending_replications") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.is_fib_downloaded.is_set or
                                self.not_supported_replications.is_set or
                                self.pending_replications.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_fib_downloaded.yfilter != YFilter.not_set or
                                self.not_supported_replications.yfilter != YFilter.not_set or
                                self.pending_replications.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                            if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                            if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pending_replications.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-fib-downloaded"):
                                self.is_fib_downloaded = value
                                self.is_fib_downloaded.value_namespace = name_space
                                self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-replications"):
                                self.not_supported_replications = value
                                self.not_supported_replications.value_namespace = name_space
                                self.not_supported_replications.value_namespace_prefix = name_space_prefix
                            if(value_path == "pending-replications"):
                                self.pending_replications = value
                                self.pending_replications.value_namespace = name_space
                                self.pending_replications.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_list_name.is_set or
                            self.interface_list_id.is_set or
                            self.interface_list_name_xr.is_set or
                            self.items.is_set or
                            self.number_of_interfaces.is_set)

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_list_name.yfilter != YFilter.not_set or
                            self.interface_list_id.yfilter != YFilter.not_set or
                            self.interface_list_name_xr.yfilter != YFilter.not_set or
                            self.items.yfilter != YFilter.not_set or
                            self.number_of_interfaces.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-interface" + "[interface-list-name='" + self.interface_list_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                        if (self.interface_list_name_xr.is_set or self.interface_list_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_list_name_xr.get_name_leafdata())
                        if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.items.get_name_leafdata())
                        if (self.number_of_interfaces.is_set or self.number_of_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_interfaces.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "interface-list-name" or name == "interface-list-id" or name == "interface-list-name-xr" or name == "items" or name == "number-of-interfaces"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-list-name"):
                            self.interface_list_name = value
                            self.interface_list_name.value_namespace = name_space
                            self.interface_list_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-list-id"):
                            self.interface_list_id = value
                            self.interface_list_id.value_namespace = name_space
                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-list-name-xr"):
                            self.interface_list_name_xr = value
                            self.interface_list_name_xr.value_namespace = name_space
                            self.interface_list_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "items"):
                            self.items = value
                            self.items.value_namespace = name_space
                            self.items.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-interfaces"):
                            self.number_of_interfaces = value
                            self.number_of_interfaces.value_namespace = name_space
                            self.number_of_interfaces.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.generic_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.generic_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "generic-interface"):
                        for c in self.generic_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.generic_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "generic-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MstpVlans(Entity):
                """
                L2VPN MSTP VLAN Table
                
                .. attribute:: mstp_vlan
                
                	L2VPN MSTP VLAN information
                	**type**\: list of    :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.MstpVlans, self).__init__()

                    self.yang_name = "mstp-vlans"
                    self.yang_parent_name = "node"

                    self.mstp_vlan = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.MstpVlans, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.MstpVlans, self).__setattr__(name, value)


                class MstpVlan(Entity):
                    """
                    L2VPN MSTP VLAN information
                    
                    .. attribute:: vlan_id  <key>
                    
                    	vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4098
                    
                    .. attribute:: msti_id
                    
                    	MSTI id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_count
                    
                    	Port Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sub_interface
                    
                    	Sub interfaces
                    	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface>`
                    
                    .. attribute:: vlan_id_xr
                    
                    	Vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan, self).__init__()

                        self.yang_name = "mstp-vlan"
                        self.yang_parent_name = "mstp-vlans"

                        self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                        self.msti_id = YLeaf(YType.uint32, "msti-id")

                        self.port_count = YLeaf(YType.uint32, "port-count")

                        self.vlan_id_xr = YLeaf(YType.uint32, "vlan-id-xr")

                        self.sub_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("vlan_id",
                                        "msti_id",
                                        "port_count",
                                        "vlan_id_xr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan, self).__setattr__(name, value)


                    class SubInterface(Entity):
                        """
                        Sub interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface, self).__init__()

                            self.yang_name = "sub-interface"
                            self.yang_parent_name = "mstp-vlan"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface, self).__setattr__(name, value)

                        def has_data(self):
                            return self.interface_name.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sub-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.sub_interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.vlan_id.is_set or
                            self.msti_id.is_set or
                            self.port_count.is_set or
                            self.vlan_id_xr.is_set)

                    def has_operation(self):
                        for c in self.sub_interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.vlan_id.yfilter != YFilter.not_set or
                            self.msti_id.yfilter != YFilter.not_set or
                            self.port_count.yfilter != YFilter.not_set or
                            self.vlan_id_xr.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mstp-vlan" + "[vlan-id='" + self.vlan_id.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vlan_id.get_name_leafdata())
                        if (self.msti_id.is_set or self.msti_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_id.get_name_leafdata())
                        if (self.port_count.is_set or self.port_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port_count.get_name_leafdata())
                        if (self.vlan_id_xr.is_set or self.vlan_id_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vlan_id_xr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sub-interface"):
                            for c in self.sub_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.sub_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sub-interface" or name == "vlan-id" or name == "msti-id" or name == "port-count" or name == "vlan-id-xr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "vlan-id"):
                            self.vlan_id = value
                            self.vlan_id.value_namespace = name_space
                            self.vlan_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-id"):
                            self.msti_id = value
                            self.msti_id.value_namespace = name_space
                            self.msti_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "port-count"):
                            self.port_count = value
                            self.port_count.value_namespace = name_space
                            self.port_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "vlan-id-xr"):
                            self.vlan_id_xr = value
                            self.vlan_id_xr.value_namespace = name_space
                            self.vlan_id_xr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.mstp_vlan:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.mstp_vlan:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mstp-vlans" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mstp-vlan"):
                        for c in self.mstp_vlan:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.mstp_vlan.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mstp-vlan"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class L2VpnPbbBsa(Entity):
                """
                L2VPN PBB Backbone Source MAC information
                
                .. attribute:: bmac_sa
                
                	BMAC SA
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: chassis_is_provisioned
                
                	Chassis MAC is configured
                	**type**\:  bool
                
                .. attribute:: chassis_mac
                
                	Chassis MAC
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: provisioned
                
                	BMAC SA configured
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.L2VpnPbbBsa, self).__init__()

                    self.yang_name = "l2vpn-pbb-bsa"
                    self.yang_parent_name = "node"

                    self.bmac_sa = YLeaf(YType.str, "bmac-sa")

                    self.chassis_is_provisioned = YLeaf(YType.boolean, "chassis-is-provisioned")

                    self.chassis_mac = YLeaf(YType.str, "chassis-mac")

                    self.provisioned = YLeaf(YType.boolean, "provisioned")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bmac_sa",
                                    "chassis_is_provisioned",
                                    "chassis_mac",
                                    "provisioned") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.L2VpnPbbBsa, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.L2VpnPbbBsa, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bmac_sa.is_set or
                        self.chassis_is_provisioned.is_set or
                        self.chassis_mac.is_set or
                        self.provisioned.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bmac_sa.yfilter != YFilter.not_set or
                        self.chassis_is_provisioned.yfilter != YFilter.not_set or
                        self.chassis_mac.yfilter != YFilter.not_set or
                        self.provisioned.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "l2vpn-pbb-bsa" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bmac_sa.is_set or self.bmac_sa.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bmac_sa.get_name_leafdata())
                    if (self.chassis_is_provisioned.is_set or self.chassis_is_provisioned.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.chassis_is_provisioned.get_name_leafdata())
                    if (self.chassis_mac.is_set or self.chassis_mac.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.chassis_mac.get_name_leafdata())
                    if (self.provisioned.is_set or self.provisioned.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.provisioned.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bmac-sa" or name == "chassis-is-provisioned" or name == "chassis-mac" or name == "provisioned"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bmac-sa"):
                        self.bmac_sa = value
                        self.bmac_sa.value_namespace = name_space
                        self.bmac_sa.value_namespace_prefix = name_space_prefix
                    if(value_path == "chassis-is-provisioned"):
                        self.chassis_is_provisioned = value
                        self.chassis_is_provisioned.value_namespace = name_space
                        self.chassis_is_provisioned.value_namespace_prefix = name_space_prefix
                    if(value_path == "chassis-mac"):
                        self.chassis_mac = value
                        self.chassis_mac.value_namespace = name_space
                        self.chassis_mac.value_namespace_prefix = name_space_prefix
                    if(value_path == "provisioned"):
                        self.provisioned = value
                        self.provisioned.value_namespace = name_space
                        self.provisioned.value_namespace_prefix = name_space_prefix


            class FlexibleXconnectServices(Entity):
                """
                Flexible XConnect Service Table
                
                .. attribute:: flexible_xconnect_service
                
                	Flexible XConnect Service Information
                	**type**\: list of    :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices, self).__init__()

                    self.yang_name = "flexible-xconnect-services"
                    self.yang_parent_name = "node"

                    self.flexible_xconnect_service = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices, self).__setattr__(name, value)


                class FlexibleXconnectService(Entity):
                    """
                    Flexible XConnect Service Information
                    
                    .. attribute:: name  <key>
                    
                    	Flexible XConnect Service Name
                    	**type**\:  str
                    
                    	**length:** 1..23
                    
                    .. attribute:: flexible_xconnect_service_acs
                    
                    	Flexible XConnect Service Attachment Circuit Table
                    	**type**\:   :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
                    
                    .. attribute:: flexible_xconnect_service_info
                    
                    	Flexible XConnect Service Information
                    	**type**\:   :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService, self).__init__()

                        self.yang_name = "flexible-xconnect-service"
                        self.yang_parent_name = "flexible-xconnect-services"

                        self.name = YLeaf(YType.str, "name")

                        self.flexible_xconnect_service_acs = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                        self.flexible_xconnect_service_acs.parent = self
                        self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"
                        self._children_yang_names.add("flexible-xconnect-service-acs")

                        self.flexible_xconnect_service_info = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                        self.flexible_xconnect_service_info.parent = self
                        self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                        self._children_yang_names.add("flexible-xconnect-service-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService, self).__setattr__(name, value)


                    class FlexibleXconnectServiceAcs(Entity):
                        """
                        Flexible XConnect Service Attachment Circuit
                        Table
                        
                        .. attribute:: flexible_xconnect_service_ac
                        
                        	Flexible XConnect Service Attachment Circuit
                        	**type**\: list of    :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__init__()

                            self.yang_name = "flexible-xconnect-service-acs"
                            self.yang_parent_name = "flexible-xconnect-service"

                            self.flexible_xconnect_service_ac = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__setattr__(name, value)


                        class FlexibleXconnectServiceAc(Entity):
                            """
                            Flexible XConnect Service Attachment Circuit
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: attachment_circuit
                            
                            	Flexible XConnect Service Attachment Circuit
                            	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__init__()

                                self.yang_name = "flexible-xconnect-service-ac"
                                self.yang_parent_name = "flexible-xconnect-service-acs"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.attachment_circuit = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                self._children_yang_names.add("attachment-circuit")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__setattr__(name, value)


                            class AttachmentCircuit(Entity):
                                """
                                Flexible XConnect Service Attachment Circuit
                                
                                .. attribute:: bvi_mac_conflict
                                
                                	BVI Mac Conflict
                                	**type**\:  bool
                                
                                .. attribute:: bvi_no_port_up
                                
                                	BVI no BP Up
                                	**type**\:  bool
                                
                                .. attribute:: control_word_mismatched
                                
                                	Control word mismatched
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_error
                                
                                	Encapsulation Error
                                	**type**\:  str
                                
                                .. attribute:: encapsulation_mismatched
                                
                                	Encapsulation mismatched
                                	**type**\:  bool
                                
                                .. attribute:: evpn_internal_label
                                
                                	EVPN Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface
                                
                                	Interface
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                                
                                .. attribute:: interface_handle
                                
                                	Interface Handler
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: internal_ms_ti
                                
                                	Internal MSTi
                                	**type**\:  str
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                                
                                .. attribute:: is_ac_partially_programmed
                                
                                	Is attachment\-circuit partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: l2vpn_protection
                                
                                	Protection object used for this segment
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection>`
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: ms_ti_mismatch
                                
                                	MSTi mismatch
                                	**type**\:  bool
                                
                                .. attribute:: msti
                                
                                	MSTi
                                	**type**\:  str
                                
                                .. attribute:: msti_mismatch_down
                                
                                	Oper down due to MSTI mismatch
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: node_id
                                
                                	Node ID
                                	**type**\:  str
                                
                                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_group_id
                                
                                	Redundancy Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_group_state
                                
                                	Redundancy Group State
                                	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                                
                                .. attribute:: redundancy_object_id
                                
                                	Redundancy Object ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                                
                                .. attribute:: tdm_media_mismatched
                                
                                	TDM media parms mismatched
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__init__()

                                    self.yang_name = "attachment-circuit"
                                    self.yang_parent_name = "flexible-xconnect-service-ac"

                                    self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                                    self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                                    self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                                    self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                                    self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                                    self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                                    self.interface_handle = YLeaf(YType.str, "interface-handle")

                                    self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                                    self.interworking = YLeaf(YType.enumeration, "interworking")

                                    self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                                    self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                    self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                                    self.msti = YLeaf(YType.str, "msti")

                                    self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                                    self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                    self.node_id = YLeaf(YType.str, "node-id")

                                    self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                    self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                                    self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                                    self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                    self.state = YLeaf(YType.enumeration, "state")

                                    self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                                    self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                    self.interface = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                    self._children_yang_names.add("interface")

                                    self.l2vpn_protection = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    self._children_yang_names.add("l2vpn-protection")

                                    self.statistics = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._children_yang_names.add("statistics")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bvi_mac_conflict",
                                                    "bvi_no_port_up",
                                                    "control_word_mismatched",
                                                    "encapsulation_error",
                                                    "encapsulation_mismatched",
                                                    "evpn_internal_label",
                                                    "interface_handle",
                                                    "internal_ms_ti",
                                                    "interworking",
                                                    "is_ac_partially_programmed",
                                                    "mac_limit_oper_down",
                                                    "ms_ti_mismatch",
                                                    "msti",
                                                    "msti_mismatch_down",
                                                    "mtu_mismatched",
                                                    "node_id",
                                                    "out_of_memory_state",
                                                    "redundancy_group_id",
                                                    "redundancy_group_state",
                                                    "redundancy_object_id",
                                                    "state",
                                                    "tdm_media_mismatched",
                                                    "xconnect_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__setattr__(name, value)


                                class Interface(Entity):
                                    """
                                    Interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "attachment-circuit"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.name = YLeaf(YType.str, "name")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.parameters = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._children_yang_names.add("parameters")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "name",
                                                        "payload_bytes") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__setattr__(name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "interface"

                                            self.type = YLeaf(YType.enumeration, "type")

                                            self.atm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                            self._children_yang_names.add("atm")

                                            self.ethernet = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                            self._children_yang_names.add("ethernet")

                                            self.fr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                            self._children_yang_names.add("fr")

                                            self.pseudowire_ether = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            self._children_yang_names.add("pseudowire-ether")

                                            self.pseudowire_iw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._children_yang_names.add("pseudowire-iw")

                                            self.tdm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                            self._children_yang_names.add("tdm")

                                            self.vlan = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                            self._children_yang_names.add("vlan")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.xconnect_tags.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"

                                                self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                                self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                                self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                                self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                                self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                                self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                                self.vlan_range = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("encapsulation_type",
                                                                "outer_tag",
                                                                "rewrite_tag",
                                                                "simple_efp",
                                                                "vlan_rewrite_tag",
                                                                "xconnect_tags") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"

                                                    self.lower = YLeaf(YType.uint16, "lower")

                                                    self.upper = YLeaf(YType.uint16, "upper")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("lower",
                                                                    "upper") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.lower.is_set or
                                                        self.upper.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.lower.yfilter != YFilter.not_set or
                                                        self.upper.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "vlan-range" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lower.get_name_leafdata())
                                                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.upper.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "lower" or name == "upper"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "lower"):
                                                        self.lower = value
                                                        self.lower.value_namespace = name_space
                                                        self.lower.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "upper"):
                                                        self.upper = value
                                                        self.upper.value_namespace = name_space
                                                        self.upper.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.vlan_range:
                                                    if (c.has_data()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.yfilter != YFilter.not_set):
                                                        return True
                                                return (
                                                    self.encapsulation_type.is_set or
                                                    self.outer_tag.is_set or
                                                    self.simple_efp.is_set or
                                                    self.vlan_rewrite_tag.is_set or
                                                    self.xconnect_tags.is_set)

                                            def has_operation(self):
                                                for c in self.vlan_range:
                                                    if (c.has_operation()):
                                                        return True
                                                for leaf in self.rewrite_tag.getYLeafs():
                                                    if (leaf.is_set):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.encapsulation_type.yfilter != YFilter.not_set or
                                                    self.outer_tag.yfilter != YFilter.not_set or
                                                    self.rewrite_tag.yfilter != YFilter.not_set or
                                                    self.simple_efp.yfilter != YFilter.not_set or
                                                    self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                    self.xconnect_tags.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                                if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                                if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                                if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                                if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                                leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "vlan-range"):
                                                    for c in self.vlan_range:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.vlan_range.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "encapsulation-type"):
                                                    self.encapsulation_type = value
                                                    self.encapsulation_type.value_namespace = name_space
                                                    self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "outer-tag"):
                                                    self.outer_tag = value
                                                    self.outer_tag.value_namespace = name_space
                                                    self.outer_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rewrite-tag"):
                                                    self.rewrite_tag.append(value)
                                                if(value_path == "simple-efp"):
                                                    self.simple_efp = value
                                                    self.simple_efp.value_namespace = name_space
                                                    self.simple_efp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vlan-rewrite-tag"):
                                                    self.vlan_rewrite_tag = value
                                                    self.vlan_rewrite_tag.value_namespace = name_space
                                                    self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "xconnect-tags"):
                                                    self.xconnect_tags = value
                                                    self.xconnect_tags.value_namespace = name_space
                                                    self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"

                                                self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                                self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                                self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                                self.tdm_options = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._children_yang_names.add("tdm-options")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tdm_mode",
                                                                "timeslot_group",
                                                                "timeslot_rate") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"

                                                    self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                    self.cas = YLeaf(YType.uint8, "cas")

                                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                    self.rtp = YLeaf(YType.enumeration, "rtp")

                                                    self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                    self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                    self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                    self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                    self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("bit_rate",
                                                                    "cas",
                                                                    "payload_bytes",
                                                                    "rtp",
                                                                    "rtp_header_payload_type",
                                                                    "signalling_packets",
                                                                    "ssrc",
                                                                    "timestamp_clock_freq",
                                                                    "timestamp_mode") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.bit_rate.is_set or
                                                        self.cas.is_set or
                                                        self.payload_bytes.is_set or
                                                        self.rtp.is_set or
                                                        self.rtp_header_payload_type.is_set or
                                                        self.signalling_packets.is_set or
                                                        self.ssrc.is_set or
                                                        self.timestamp_clock_freq.is_set or
                                                        self.timestamp_mode.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.bit_rate.yfilter != YFilter.not_set or
                                                        self.cas.yfilter != YFilter.not_set or
                                                        self.payload_bytes.yfilter != YFilter.not_set or
                                                        self.rtp.yfilter != YFilter.not_set or
                                                        self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                        self.signalling_packets.yfilter != YFilter.not_set or
                                                        self.ssrc.yfilter != YFilter.not_set or
                                                        self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                        self.timestamp_mode.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tdm-options" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                    if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.cas.get_name_leafdata())
                                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                    if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp.get_name_leafdata())
                                                    if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                    if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                    if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                    if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                    if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "bit-rate"):
                                                        self.bit_rate = value
                                                        self.bit_rate.value_namespace = name_space
                                                        self.bit_rate.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "cas"):
                                                        self.cas = value
                                                        self.cas.value_namespace = name_space
                                                        self.cas.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "payload-bytes"):
                                                        self.payload_bytes = value
                                                        self.payload_bytes.value_namespace = name_space
                                                        self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp"):
                                                        self.rtp = value
                                                        self.rtp.value_namespace = name_space
                                                        self.rtp.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rtp-header-payload-type"):
                                                        self.rtp_header_payload_type = value
                                                        self.rtp_header_payload_type.value_namespace = name_space
                                                        self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "signalling-packets"):
                                                        self.signalling_packets = value
                                                        self.signalling_packets.value_namespace = name_space
                                                        self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "ssrc"):
                                                        self.ssrc = value
                                                        self.ssrc.value_namespace = name_space
                                                        self.ssrc.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-clock-freq"):
                                                        self.timestamp_clock_freq = value
                                                        self.timestamp_clock_freq.value_namespace = name_space
                                                        self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "timestamp-mode"):
                                                        self.timestamp_mode = value
                                                        self.timestamp_mode.value_namespace = name_space
                                                        self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.tdm_mode.is_set or
                                                    self.timeslot_group.is_set or
                                                    self.timeslot_rate.is_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tdm_mode.yfilter != YFilter.not_set or
                                                    self.timeslot_group.yfilter != YFilter.not_set or
                                                    self.timeslot_rate.yfilter != YFilter.not_set or
                                                    (self.tdm_options is not None and self.tdm_options.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                                if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                                if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tdm-options"):
                                                    if (self.tdm_options is None):
                                                        self.tdm_options = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                        self.tdm_options.parent = self
                                                        self._children_name_map["tdm_options"] = "tdm-options"
                                                    return self.tdm_options

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tdm-mode"):
                                                    self.tdm_mode = value
                                                    self.tdm_mode.value_namespace = name_space
                                                    self.tdm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-group"):
                                                    self.timeslot_group = value
                                                    self.timeslot_group.value_namespace = name_space
                                                    self.timeslot_group.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timeslot-rate"):
                                                    self.timeslot_rate = value
                                                    self.timeslot_rate.value_namespace = name_space
                                                    self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"

                                                self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                                self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                                self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                                self.vci = YLeaf(YType.uint16, "vci")

                                                self.vpi = YLeaf(YType.uint16, "vpi")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("atm_mode",
                                                                "maximum_number_cells_packed",
                                                                "maximum_number_cells_un_packed",
                                                                "vci",
                                                                "vpi") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.atm_mode.is_set or
                                                    self.maximum_number_cells_packed.is_set or
                                                    self.maximum_number_cells_un_packed.is_set or
                                                    self.vci.is_set or
                                                    self.vpi.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.atm_mode.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                    self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                    self.vci.yfilter != YFilter.not_set or
                                                    self.vpi.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "atm" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                                if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                                if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                                if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vci.get_name_leafdata())
                                                if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpi.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "atm-mode"):
                                                    self.atm_mode = value
                                                    self.atm_mode.value_namespace = name_space
                                                    self.atm_mode.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-packed"):
                                                    self.maximum_number_cells_packed = value
                                                    self.maximum_number_cells_packed.value_namespace = name_space
                                                    self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "maximum-number-cells-un-packed"):
                                                    self.maximum_number_cells_un_packed = value
                                                    self.maximum_number_cells_un_packed.value_namespace = name_space
                                                    self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vci"):
                                                    self.vci = value
                                                    self.vci.value_namespace = name_space
                                                    self.vci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpi"):
                                                    self.vpi = value
                                                    self.vpi.value_namespace = name_space
                                                    self.vpi.value_namespace_prefix = name_space_prefix


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"

                                                self.dlci = YLeaf(YType.uint32, "dlci")

                                                self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("dlci",
                                                                "fr_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.dlci.is_set or
                                                    self.fr_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.dlci.yfilter != YFilter.not_set or
                                                    self.fr_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "fr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.dlci.get_name_leafdata())
                                                if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "dlci" or name == "fr-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "dlci"):
                                                    self.dlci = value
                                                    self.dlci.value_namespace = name_space
                                                    self.dlci.value_namespace_prefix = name_space_prefix
                                                if(value_path == "fr-mode"):
                                                    self.fr_mode = value
                                                    self.fr_mode.value_namespace = name_space
                                                    self.fr_mode.value_namespace_prefix = name_space_prefix


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-ether" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"

                                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                                self.is_valid = YLeaf(YType.boolean, "is-valid")

                                                self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._children_yang_names.add("interface-list")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("internal_label",
                                                                "is_valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"

                                                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                    self.interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_list_id",
                                                                    "interface_list_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name",
                                                                        "replicate_status") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.interface_name.is_set or
                                                            self.replicate_status.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set or
                                                            self.replicate_status.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "interface" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                        if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name" or name == "replicate-status"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "replicate-status"):
                                                            self.replicate_status = value
                                                            self.replicate_status.value_namespace = name_space
                                                            self.replicate_status.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.interface_list_id.is_set or
                                                        self.interface_list_name.is_set)

                                                def has_operation(self):
                                                    for c in self.interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_list_id.yfilter != YFilter.not_set or
                                                        self.interface_list_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface-list" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "interface"):
                                                        for c in self.interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-list-id"):
                                                        self.interface_list_id = value
                                                        self.interface_list_id.value_namespace = name_space
                                                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "interface-list-name"):
                                                        self.interface_list_name = value
                                                        self.interface_list_name.value_namespace = name_space
                                                        self.interface_list_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.internal_label.is_set or
                                                    self.is_valid.is_set or
                                                    (self.interface_list is not None and self.interface_list.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.internal_label.yfilter != YFilter.not_set or
                                                    self.is_valid.yfilter != YFilter.not_set or
                                                    (self.interface_list is not None and self.interface_list.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "pseudowire-iw" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                                if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface-list"):
                                                    if (self.interface_list is None):
                                                        self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                        self.interface_list.parent = self
                                                        self._children_name_map["interface_list"] = "interface-list"
                                                    return self.interface_list

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "internal-label"):
                                                    self.internal_label = value
                                                    self.internal_label.value_namespace = name_space
                                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-valid"):
                                                    self.is_valid = value
                                                    self.is_valid.value_namespace = name_space
                                                    self.is_valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.type.is_set or
                                                (self.atm is not None and self.atm.has_data()) or
                                                (self.ethernet is not None and self.ethernet.has_data()) or
                                                (self.fr is not None and self.fr.has_data()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                                (self.tdm is not None and self.tdm.has_data()) or
                                                (self.vlan is not None and self.vlan.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set or
                                                (self.atm is not None and self.atm.has_operation()) or
                                                (self.ethernet is not None and self.ethernet.has_operation()) or
                                                (self.fr is not None and self.fr.has_operation()) or
                                                (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                                (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                                (self.tdm is not None and self.tdm.has_operation()) or
                                                (self.vlan is not None and self.vlan.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "parameters" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "atm"):
                                                if (self.atm is None):
                                                    self.atm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                                    self.atm.parent = self
                                                    self._children_name_map["atm"] = "atm"
                                                return self.atm

                                            if (child_yang_name == "ethernet"):
                                                if (self.ethernet is None):
                                                    self.ethernet = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                                    self.ethernet.parent = self
                                                    self._children_name_map["ethernet"] = "ethernet"
                                                return self.ethernet

                                            if (child_yang_name == "fr"):
                                                if (self.fr is None):
                                                    self.fr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                                    self.fr.parent = self
                                                    self._children_name_map["fr"] = "fr"
                                                return self.fr

                                            if (child_yang_name == "pseudowire-ether"):
                                                if (self.pseudowire_ether is None):
                                                    self.pseudowire_ether = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                                    self.pseudowire_ether.parent = self
                                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                                return self.pseudowire_ether

                                            if (child_yang_name == "pseudowire-iw"):
                                                if (self.pseudowire_iw is None):
                                                    self.pseudowire_iw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                                    self.pseudowire_iw.parent = self
                                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                return self.pseudowire_iw

                                            if (child_yang_name == "tdm"):
                                                if (self.tdm is None):
                                                    self.tdm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                                    self.tdm.parent = self
                                                    self._children_name_map["tdm"] = "tdm"
                                                return self.tdm

                                            if (child_yang_name == "vlan"):
                                                if (self.vlan is None):
                                                    self.vlan = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                                    self.vlan.parent = self
                                                    self._children_name_map["vlan"] = "vlan"
                                                return self.vlan

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.name.is_set or
                                            self.payload_bytes.is_set or
                                            (self.parameters is not None and self.parameters.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.name.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            (self.parameters is not None and self.parameters.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.name.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "parameters"):
                                            if (self.parameters is None):
                                                self.parameters = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                                self.parameters.parent = self
                                                self._children_name_map["parameters"] = "parameters"
                                            return self.parameters

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "name"):
                                            self.name = value
                                            self.name.value_namespace = name_space
                                            self.name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "attachment-circuit"

                                        self.dispostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        self._children_yang_names.add("dispostion-stats")

                                        self.impostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                        self._children_yang_names.add("impostion-stats")

                                        self.sequence_number = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._children_yang_names.add("sequence-number")


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                            self._children_yang_names.add("broadcast")

                                            self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            self._children_yang_names.add("imposition-mtu-drop")

                                            self.imposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                            self._children_yang_names.add("imposition-stat")

                                            self.impostion_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            self._children_yang_names.add("impostion-tail-drop")

                                            self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.l2fsbi_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            self._children_yang_names.add("l2fsbi-drop")

                                            self.multicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                            self._children_yang_names.add("multicast")

                                            self.unknown_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._children_yang_names.add("unknown-unicast")


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "imposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "impostion-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class L2FsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "l2fsbi-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unknown-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast is not None and self.broadcast.has_data()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                                (self.multicast is not None and self.multicast.has_data()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast is not None and self.broadcast.has_operation()) or
                                                (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                                (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                                (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                                (self.multicast is not None and self.multicast.has_operation()) or
                                                (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast"):
                                                if (self.broadcast is None):
                                                    self.broadcast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                                    self.broadcast.parent = self
                                                    self._children_name_map["broadcast"] = "broadcast"
                                                return self.broadcast

                                            if (child_yang_name == "imposition-mtu-drop"):
                                                if (self.imposition_mtu_drop is None):
                                                    self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                    self.imposition_mtu_drop.parent = self
                                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                                return self.imposition_mtu_drop

                                            if (child_yang_name == "imposition-stat"):
                                                if (self.imposition_stat is None):
                                                    self.imposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                                    self.imposition_stat.parent = self
                                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                                return self.imposition_stat

                                            if (child_yang_name == "impostion-tail-drop"):
                                                if (self.impostion_tail_drop is None):
                                                    self.impostion_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                                    self.impostion_tail_drop.parent = self
                                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                                return self.impostion_tail_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "l2fsbi-drop"):
                                                if (self.l2fsbi_drop is None):
                                                    self.l2fsbi_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                                    self.l2fsbi_drop.parent = self
                                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                                return self.l2fsbi_drop

                                            if (child_yang_name == "multicast"):
                                                if (self.multicast is None):
                                                    self.multicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                                    self.multicast.parent = self
                                                    self._children_name_map["multicast"] = "multicast"
                                                return self.multicast

                                            if (child_yang_name == "unknown-unicast"):
                                                if (self.unknown_unicast is None):
                                                    self.unknown_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                                    self.unknown_unicast.parent = self
                                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                return self.unknown_unicast

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"

                                            self.broadcast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            self._children_yang_names.add("broadcast-drop")

                                            self.dai_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                            self._children_yang_names.add("dai-drop")

                                            self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            self._children_yang_names.add("disposition-mtu-drop")

                                            self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            self._children_yang_names.add("disposition-oo-o-drops")

                                            self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            self._children_yang_names.add("disposition-p2mp-stats")

                                            self.disposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                            self._children_yang_names.add("disposition-stat")

                                            self.disposition_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            self._children_yang_names.add("disposition-tail-drop")

                                            self.ipsg_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            self._children_yang_names.add("ipsg-drop")

                                            self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                            self._children_yang_names.add("known-unicast")

                                            self.mac_move = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._children_yang_names.add("mac-move")

                                            self.multicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                            self._children_yang_names.add("multicast-drop")

                                            self.received_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                            self._children_yang_names.add("received-drops")

                                            self.unicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                            self._children_yang_names.add("unicast-drop")


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-stat" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-mtu-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-tail-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "unicast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "broadcast-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "received-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dai-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ipsg-drop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-oo-o-drops" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class DispositionP2MpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "disposition-p2mp-stats" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "known-unicast" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"

                                                self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                                self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("byte_counts",
                                                                "packet_counts") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.byte_counts.is_set or
                                                    self.packet_counts.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.byte_counts.yfilter != YFilter.not_set or
                                                    self.packet_counts.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "mac-move" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                                if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "byte-counts" or name == "packet-counts"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "byte-counts"):
                                                    self.byte_counts = value
                                                    self.byte_counts.value_namespace = name_space
                                                    self.byte_counts.value_namespace_prefix = name_space_prefix
                                                if(value_path == "packet-counts"):
                                                    self.packet_counts = value
                                                    self.packet_counts.value_namespace = name_space
                                                    self.packet_counts.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                                (self.dai_drop is not None and self.dai_drop.has_data()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                                (self.known_unicast is not None and self.known_unicast.has_data()) or
                                                (self.mac_move is not None and self.mac_move.has_data()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                                (self.received_drops is not None and self.received_drops.has_data()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                                (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                                (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                                (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                                (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                                (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                                (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                                (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                                (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                                (self.mac_move is not None and self.mac_move.has_operation()) or
                                                (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                                (self.received_drops is not None and self.received_drops.has_operation()) or
                                                (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dispostion-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "broadcast-drop"):
                                                if (self.broadcast_drop is None):
                                                    self.broadcast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                                    self.broadcast_drop.parent = self
                                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                                return self.broadcast_drop

                                            if (child_yang_name == "dai-drop"):
                                                if (self.dai_drop is None):
                                                    self.dai_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                                    self.dai_drop.parent = self
                                                    self._children_name_map["dai_drop"] = "dai-drop"
                                                return self.dai_drop

                                            if (child_yang_name == "disposition-mtu-drop"):
                                                if (self.disposition_mtu_drop is None):
                                                    self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                                    self.disposition_mtu_drop.parent = self
                                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                                return self.disposition_mtu_drop

                                            if (child_yang_name == "disposition-oo-o-drops"):
                                                if (self.disposition_oo_o_drops is None):
                                                    self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                                    self.disposition_oo_o_drops.parent = self
                                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                                return self.disposition_oo_o_drops

                                            if (child_yang_name == "disposition-p2mp-stats"):
                                                if (self.disposition_p2mp_stats is None):
                                                    self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                                    self.disposition_p2mp_stats.parent = self
                                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                                return self.disposition_p2mp_stats

                                            if (child_yang_name == "disposition-stat"):
                                                if (self.disposition_stat is None):
                                                    self.disposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                                    self.disposition_stat.parent = self
                                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                                return self.disposition_stat

                                            if (child_yang_name == "disposition-tail-drop"):
                                                if (self.disposition_tail_drop is None):
                                                    self.disposition_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                                    self.disposition_tail_drop.parent = self
                                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                                return self.disposition_tail_drop

                                            if (child_yang_name == "ipsg-drop"):
                                                if (self.ipsg_drop is None):
                                                    self.ipsg_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                                    self.ipsg_drop.parent = self
                                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                                return self.ipsg_drop

                                            if (child_yang_name == "known-unicast"):
                                                if (self.known_unicast is None):
                                                    self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                                    self.known_unicast.parent = self
                                                    self._children_name_map["known_unicast"] = "known-unicast"
                                                return self.known_unicast

                                            if (child_yang_name == "mac-move"):
                                                if (self.mac_move is None):
                                                    self.mac_move = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                                    self.mac_move.parent = self
                                                    self._children_name_map["mac_move"] = "mac-move"
                                                return self.mac_move

                                            if (child_yang_name == "multicast-drop"):
                                                if (self.multicast_drop is None):
                                                    self.multicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                                    self.multicast_drop.parent = self
                                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                                return self.multicast_drop

                                            if (child_yang_name == "received-drops"):
                                                if (self.received_drops is None):
                                                    self.received_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                                    self.received_drops.parent = self
                                                    self._children_name_map["received_drops"] = "received-drops"
                                                return self.received_drops

                                            if (child_yang_name == "unicast-drop"):
                                                if (self.unicast_drop is None):
                                                    self.unicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                                    self.unicast_drop.parent = self
                                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                                return self.unicast_drop

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"

                                            self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                            self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                            self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                            self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bypassed_inbound_sequence_packet",
                                                            "bypassed_out_sequence_packet",
                                                            "sequence_number_expected",
                                                            "sequence_number_sent") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bypassed_inbound_sequence_packet.is_set or
                                                self.bypassed_out_sequence_packet.is_set or
                                                self.sequence_number_expected.is_set or
                                                self.sequence_number_sent.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                                self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                                self.sequence_number_expected.yfilter != YFilter.not_set or
                                                self.sequence_number_sent.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sequence-number" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                            if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                            if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                            if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bypassed-inbound-sequence-packet"):
                                                self.bypassed_inbound_sequence_packet = value
                                                self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                                self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "bypassed-out-sequence-packet"):
                                                self.bypassed_out_sequence_packet = value
                                                self.bypassed_out_sequence_packet.value_namespace = name_space
                                                self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-expected"):
                                                self.sequence_number_expected = value
                                                self.sequence_number_expected.value_namespace = name_space
                                                self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sequence-number-sent"):
                                                self.sequence_number_sent = value
                                                self.sequence_number_sent.value_namespace = name_space
                                                self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                            (self.sequence_number is not None and self.sequence_number.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                            (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                            (self.sequence_number is not None and self.sequence_number.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "statistics" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dispostion-stats"):
                                            if (self.dispostion_stats is None):
                                                self.dispostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                                self.dispostion_stats.parent = self
                                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                            return self.dispostion_stats

                                        if (child_yang_name == "impostion-stats"):
                                            if (self.impostion_stats is None):
                                                self.impostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                                self.impostion_stats.parent = self
                                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                            return self.impostion_stats

                                        if (child_yang_name == "sequence-number"):
                                            if (self.sequence_number is None):
                                                self.sequence_number = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                                self.sequence_number.parent = self
                                                self._children_name_map["sequence_number"] = "sequence-number"
                                            return self.sequence_number

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class L2VpnProtection(Entity):
                                    """
                                    Protection object used for this segment
                                    
                                    .. attribute:: active
                                    
                                    	Active
                                    	**type**\:  bool
                                    
                                    .. attribute:: protected_name
                                    
                                    	Name of the protected segment
                                    	**type**\:  str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: protection_configured
                                    
                                    	Protection configured
                                    	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                                    
                                    .. attribute:: protection_name
                                    
                                    	Name of the segment acting as backup
                                    	**type**\:  str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: protection_type
                                    
                                    	Type of the protection
                                    	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__init__()

                                        self.yang_name = "l2vpn-protection"
                                        self.yang_parent_name = "attachment-circuit"

                                        self.active = YLeaf(YType.boolean, "active")

                                        self.protected_name = YLeaf(YType.str, "protected-name")

                                        self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                        self.protection_name = YLeaf(YType.str, "protection-name")

                                        self.protection_type = YLeaf(YType.enumeration, "protection-type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("active",
                                                        "protected_name",
                                                        "protection_configured",
                                                        "protection_name",
                                                        "protection_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.active.is_set or
                                            self.protected_name.is_set or
                                            self.protection_configured.is_set or
                                            self.protection_name.is_set or
                                            self.protection_type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.active.yfilter != YFilter.not_set or
                                            self.protected_name.yfilter != YFilter.not_set or
                                            self.protection_configured.yfilter != YFilter.not_set or
                                            self.protection_name.yfilter != YFilter.not_set or
                                            self.protection_type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2vpn-protection" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.active.get_name_leafdata())
                                        if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protected_name.get_name_leafdata())
                                        if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                        if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protection_name.get_name_leafdata())
                                        if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protection_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "active"):
                                            self.active = value
                                            self.active.value_namespace = name_space
                                            self.active.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protected-name"):
                                            self.protected_name = value
                                            self.protected_name.value_namespace = name_space
                                            self.protected_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protection-configured"):
                                            self.protection_configured = value
                                            self.protection_configured.value_namespace = name_space
                                            self.protection_configured.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protection-name"):
                                            self.protection_name = value
                                            self.protection_name.value_namespace = name_space
                                            self.protection_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protection-type"):
                                            self.protection_type = value
                                            self.protection_type.value_namespace = name_space
                                            self.protection_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bvi_mac_conflict.is_set or
                                        self.bvi_no_port_up.is_set or
                                        self.control_word_mismatched.is_set or
                                        self.encapsulation_error.is_set or
                                        self.encapsulation_mismatched.is_set or
                                        self.evpn_internal_label.is_set or
                                        self.interface_handle.is_set or
                                        self.internal_ms_ti.is_set or
                                        self.interworking.is_set or
                                        self.is_ac_partially_programmed.is_set or
                                        self.mac_limit_oper_down.is_set or
                                        self.ms_ti_mismatch.is_set or
                                        self.msti.is_set or
                                        self.msti_mismatch_down.is_set or
                                        self.mtu_mismatched.is_set or
                                        self.node_id.is_set or
                                        self.out_of_memory_state.is_set or
                                        self.redundancy_group_id.is_set or
                                        self.redundancy_group_state.is_set or
                                        self.redundancy_object_id.is_set or
                                        self.state.is_set or
                                        self.tdm_media_mismatched.is_set or
                                        self.xconnect_id.is_set or
                                        (self.interface is not None and self.interface.has_data()) or
                                        (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                        (self.statistics is not None and self.statistics.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                        self.bvi_no_port_up.yfilter != YFilter.not_set or
                                        self.control_word_mismatched.yfilter != YFilter.not_set or
                                        self.encapsulation_error.yfilter != YFilter.not_set or
                                        self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                        self.evpn_internal_label.yfilter != YFilter.not_set or
                                        self.interface_handle.yfilter != YFilter.not_set or
                                        self.internal_ms_ti.yfilter != YFilter.not_set or
                                        self.interworking.yfilter != YFilter.not_set or
                                        self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                        self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                        self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                        self.msti.yfilter != YFilter.not_set or
                                        self.msti_mismatch_down.yfilter != YFilter.not_set or
                                        self.mtu_mismatched.yfilter != YFilter.not_set or
                                        self.node_id.yfilter != YFilter.not_set or
                                        self.out_of_memory_state.yfilter != YFilter.not_set or
                                        self.redundancy_group_id.yfilter != YFilter.not_set or
                                        self.redundancy_group_state.yfilter != YFilter.not_set or
                                        self.redundancy_object_id.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                        self.xconnect_id.yfilter != YFilter.not_set or
                                        (self.interface is not None and self.interface.has_operation()) or
                                        (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                        (self.statistics is not None and self.statistics.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "attachment-circuit" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                                    if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                                    if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                                    if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                                    if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                                    if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                                    if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                    if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                                    if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interworking.get_name_leafdata())
                                    if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                                    if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                    if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                                    if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.msti.get_name_leafdata())
                                    if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                                    if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                    if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.node_id.get_name_leafdata())
                                    if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                    if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                                    if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                                    if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())
                                    if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                                    if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface"):
                                        if (self.interface is None):
                                            self.interface = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                            self.interface.parent = self
                                            self._children_name_map["interface"] = "interface"
                                        return self.interface

                                    if (child_yang_name == "l2vpn-protection"):
                                        if (self.l2vpn_protection is None):
                                            self.l2vpn_protection = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                                            self.l2vpn_protection.parent = self
                                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                        return self.l2vpn_protection

                                    if (child_yang_name == "statistics"):
                                        if (self.statistics is None):
                                            self.statistics = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                            self.statistics.parent = self
                                            self._children_name_map["statistics"] = "statistics"
                                        return self.statistics

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bvi-mac-conflict"):
                                        self.bvi_mac_conflict = value
                                        self.bvi_mac_conflict.value_namespace = name_space
                                        self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bvi-no-port-up"):
                                        self.bvi_no_port_up = value
                                        self.bvi_no_port_up.value_namespace = name_space
                                        self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "control-word-mismatched"):
                                        self.control_word_mismatched = value
                                        self.control_word_mismatched.value_namespace = name_space
                                        self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "encapsulation-error"):
                                        self.encapsulation_error = value
                                        self.encapsulation_error.value_namespace = name_space
                                        self.encapsulation_error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "encapsulation-mismatched"):
                                        self.encapsulation_mismatched = value
                                        self.encapsulation_mismatched.value_namespace = name_space
                                        self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "evpn-internal-label"):
                                        self.evpn_internal_label = value
                                        self.evpn_internal_label.value_namespace = name_space
                                        self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-handle"):
                                        self.interface_handle = value
                                        self.interface_handle.value_namespace = name_space
                                        self.interface_handle.value_namespace_prefix = name_space_prefix
                                    if(value_path == "internal-ms-ti"):
                                        self.internal_ms_ti = value
                                        self.internal_ms_ti.value_namespace = name_space
                                        self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interworking"):
                                        self.interworking = value
                                        self.interworking.value_namespace = name_space
                                        self.interworking.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ac-partially-programmed"):
                                        self.is_ac_partially_programmed = value
                                        self.is_ac_partially_programmed.value_namespace = name_space
                                        self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-oper-down"):
                                        self.mac_limit_oper_down = value
                                        self.mac_limit_oper_down.value_namespace = name_space
                                        self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ms-ti-mismatch"):
                                        self.ms_ti_mismatch = value
                                        self.ms_ti_mismatch.value_namespace = name_space
                                        self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                                    if(value_path == "msti"):
                                        self.msti = value
                                        self.msti.value_namespace = name_space
                                        self.msti.value_namespace_prefix = name_space_prefix
                                    if(value_path == "msti-mismatch-down"):
                                        self.msti_mismatch_down = value
                                        self.msti_mismatch_down.value_namespace = name_space
                                        self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-mismatched"):
                                        self.mtu_mismatched = value
                                        self.mtu_mismatched.value_namespace = name_space
                                        self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "node-id"):
                                        self.node_id = value
                                        self.node_id.value_namespace = name_space
                                        self.node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "out-of-memory-state"):
                                        self.out_of_memory_state = value
                                        self.out_of_memory_state.value_namespace = name_space
                                        self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-group-id"):
                                        self.redundancy_group_id = value
                                        self.redundancy_group_id.value_namespace = name_space
                                        self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-group-state"):
                                        self.redundancy_group_state = value
                                        self.redundancy_group_state.value_namespace = name_space
                                        self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "redundancy-object-id"):
                                        self.redundancy_object_id = value
                                        self.redundancy_object_id.value_namespace = name_space
                                        self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tdm-media-mismatched"):
                                        self.tdm_media_mismatched = value
                                        self.tdm_media_mismatched.value_namespace = name_space
                                        self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-id"):
                                        self.xconnect_id = value
                                        self.xconnect_id.value_namespace = name_space
                                        self.xconnect_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.interface_name.is_set or
                                    (self.attachment_circuit is not None and self.attachment_circuit.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    (self.attachment_circuit is not None and self.attachment_circuit.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "flexible-xconnect-service-ac" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "attachment-circuit"):
                                    if (self.attachment_circuit is None):
                                        self.attachment_circuit = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                                        self.attachment_circuit.parent = self
                                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                    return self.attachment_circuit

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "attachment-circuit" or name == "interface-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.flexible_xconnect_service_ac:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.flexible_xconnect_service_ac:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "flexible-xconnect-service-acs" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "flexible-xconnect-service-ac"):
                                for c in self.flexible_xconnect_service_ac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.flexible_xconnect_service_ac.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flexible-xconnect-service-ac"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class FlexibleXconnectServiceInfo(Entity):
                        """
                        Flexible XConnect Service Information
                        
                        .. attribute:: fxc_id
                        
                        	Flexible XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Flexible XConnect Service Name
                        	**type**\:  str
                        
                        .. attribute:: num_p_ws
                        
                        	Number of Pseudowires in Pseudowire List
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pseudowire
                        
                        	Flexible XConnect Service Pseudowire List
                        	**type**\: list of    :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                        
                        .. attribute:: state
                        
                        	State of the Flexible XConnect Service
                        	**type**\:   :py:class:`L2VpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcState>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__init__()

                            self.yang_name = "flexible-xconnect-service-info"
                            self.yang_parent_name = "flexible-xconnect-service"

                            self.fxc_id = YLeaf(YType.uint32, "fxc-id")

                            self.name = YLeaf(YType.str, "name")

                            self.num_p_ws = YLeaf(YType.uint8, "num-p-ws")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.pseudowire = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("fxc_id",
                                            "name",
                                            "num_p_ws",
                                            "state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__setattr__(name, value)


                        class Pseudowire(Entity):
                            """
                            Flexible XConnect Service Pseudowire List
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__init__()

                                self.yang_name = "pseudowire"
                                self.yang_parent_name = "flexible-xconnect-service-info"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                self.backup_active = YLeaf(YType.boolean, "backup-active")

                                self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                self.disable_never = YLeaf(YType.boolean, "disable-never")

                                self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                self.local_source_address = YLeaf(YType.str, "local-source-address")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                self.required_bw = YLeaf(YType.uint32, "required-bw")

                                self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                self.time_created = YLeaf(YType.str, "time-created")

                                self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.encapsulation_info = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                self._children_yang_names.add("encapsulation-info")

                                self.local_interface = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                                self._children_yang_names.add("local-interface")

                                self.local_signalling = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                                self._children_yang_names.add("local-signalling")

                                self.p2mp_pw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._children_yang_names.add("p2mp-pw")

                                self.peer_id = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                                self._children_yang_names.add("peer-id")

                                self.preferred_path = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                                self._children_yang_names.add("preferred-path")

                                self.remote_interface = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                                self._children_yang_names.add("remote-interface")

                                self.remote_signalling = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                self._children_yang_names.add("remote-signalling")

                                self.statistics = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_remote_down",
                                                "admited_bw",
                                                "auto_discovery",
                                                "backup_active",
                                                "backup_force_active",
                                                "backup_pw",
                                                "bitrate_mismatched",
                                                "bridge_pw_type_mismatch",
                                                "cas_mismatched",
                                                "diff_ts_mismatched",
                                                "disable_delay",
                                                "disable_never",
                                                "evpn_src_acid",
                                                "fe_ctype",
                                                "forward_class",
                                                "freq_mismatched",
                                                "illegal_control_word",
                                                "imposed_vlan_id",
                                                "interworking",
                                                "ipv6_local_source_address",
                                                "is_evpnvpws_type",
                                                "is_flow_label_static",
                                                "is_multi_segment_pseudowire",
                                                "is_partially_programmed",
                                                "is_pwr_type",
                                                "is_vfi",
                                                "last_time_status_changed",
                                                "last_time_status_down",
                                                "ldp_label_advertise_failed",
                                                "load_balance",
                                                "local_control_word",
                                                "local_label_failed",
                                                "local_pseudo_wire_type",
                                                "local_source_address",
                                                "mac_limit_oper_down",
                                                "mtu_mismatched",
                                                "not_supported_qinq",
                                                "num_ma_cwithdraw_msg_received",
                                                "number_ma_cwithdraw_message_sent",
                                                "out_of_memory_state",
                                                "payload_bytes_mismatched",
                                                "payload_type_mismatched",
                                                "preferred_path_disable_fallback",
                                                "primary_peer_id",
                                                "primary_pseudo_wire_id",
                                                "primary_pw",
                                                "protocol",
                                                "pseudo_wire_id",
                                                "pseudo_wire_state",
                                                "pseudo_wire_type_mismatched",
                                                "pw_class_name",
                                                "pw_flow_label_code17_disabled",
                                                "pw_flow_label_type",
                                                "pw_flow_label_type_cfg",
                                                "pw_redundancy_initial_delay",
                                                "pw_redundancy_one_way",
                                                "pw_status_use",
                                                "pwlsd_rewrite_failed",
                                                "remote_control_word",
                                                "remote_label_failed",
                                                "remote_pseudo_wire_type",
                                                "required_bw",
                                                "resync_enabled",
                                                "resync_threshold",
                                                "rtp_mismatched",
                                                "sequencing_type",
                                                "shutdown",
                                                "sig_pkts_mismatched",
                                                "ssrc_mismatched",
                                                "state",
                                                "table_policy_name",
                                                "tag_rewrite",
                                                "time_created",
                                                "time_elapsed_creation",
                                                "time_elapsed_status_changed",
                                                "time_elapsed_status_down",
                                                "transport_lsp_down",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__setattr__(name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudowire"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                    self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                    self.type = YLeaf(YType.enumeration, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "ipv4_peer_id",
                                                    "ipv6_peer_id",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.ipv4_peer_id.is_set or
                                        self.ipv6_peer_id.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.ipv4_peer_id.yfilter != YFilter.not_set or
                                        self.ipv6_peer_id.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "peer-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                    if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-peer-id"):
                                        self.ipv4_peer_id = value
                                        self.ipv4_peer_id.value_namespace = name_space
                                        self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-peer-id"):
                                        self.ipv6_peer_id = value
                                        self.ipv6_peer_id.value_namespace = name_space
                                        self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudowire"

                                    self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                    self.atom = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._children_yang_names.add("l2tpv3")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                        self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                        self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                        self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                        self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                        self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                        self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                        self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                        self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                        self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                        self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                        self.local_veid = YLeaf(YType.uint32, "local-veid")

                                        self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                        self.rem_saii = YLeaf(YType.str, "rem-saii")

                                        self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                        self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                        self.rem_taii = YLeaf(YType.str, "rem-taii")

                                        self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                        self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                        self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                        self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                        self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                        self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                        self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                        self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                        self.saii = YLeaf(YType.str, "saii")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.taii = YLeaf(YType.str, "taii")

                                        self.local_agi = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                        self._children_yang_names.add("local-agi")

                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._children_yang_names.add("multi-segment-pseudowire-stats")

                                        self.remote_agi = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                        self._children_yang_names.add("remote-agi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_pseudowire_headend",
                                                        "is_sai_itype2",
                                                        "is_tai_itype2",
                                                        "ldp_label_advertisment_failed",
                                                        "local_c_ctype",
                                                        "local_ceid",
                                                        "local_cv_type",
                                                        "local_group_id",
                                                        "local_label",
                                                        "local_ldp_id",
                                                        "local_saii_gbl_id",
                                                        "local_saiiac_id",
                                                        "local_taii_gbl_id",
                                                        "local_taiiac_id",
                                                        "local_veid",
                                                        "lsd_rewrite_failed",
                                                        "rem_saii",
                                                        "rem_saii_gbl_id",
                                                        "rem_saiiac_id",
                                                        "rem_taii",
                                                        "rem_taii_gbl_id",
                                                        "rem_taiiac_id",
                                                        "remote_c_ctype",
                                                        "remote_ceid",
                                                        "remote_cv_type",
                                                        "remote_group_id",
                                                        "remote_label",
                                                        "remote_ldp_id",
                                                        "remote_source_address",
                                                        "remote_veid",
                                                        "saii",
                                                        "source_address",
                                                        "taii") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"

                                            self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                            self.received_packets = YLeaf(YType.uint64, "received-packets")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("received_bytes",
                                                            "received_packets") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.received_bytes.is_set or
                                                self.received_packets.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.received_bytes.yfilter != YFilter.not_set or
                                                self.received_packets.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                            if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_packets.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "received-bytes" or name == "received-packets"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "received-bytes"):
                                                self.received_bytes = value
                                                self.received_bytes.value_namespace = name_space
                                                self.received_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "received-packets"):
                                                self.received_packets = value
                                                self.received_packets.value_namespace = name_space
                                                self.received_packets.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_pseudowire_headend.is_set or
                                            self.is_sai_itype2.is_set or
                                            self.is_tai_itype2.is_set or
                                            self.ldp_label_advertisment_failed.is_set or
                                            self.local_c_ctype.is_set or
                                            self.local_ceid.is_set or
                                            self.local_cv_type.is_set or
                                            self.local_group_id.is_set or
                                            self.local_label.is_set or
                                            self.local_ldp_id.is_set or
                                            self.local_saii_gbl_id.is_set or
                                            self.local_saiiac_id.is_set or
                                            self.local_taii_gbl_id.is_set or
                                            self.local_taiiac_id.is_set or
                                            self.local_veid.is_set or
                                            self.lsd_rewrite_failed.is_set or
                                            self.rem_saii.is_set or
                                            self.rem_saii_gbl_id.is_set or
                                            self.rem_saiiac_id.is_set or
                                            self.rem_taii.is_set or
                                            self.rem_taii_gbl_id.is_set or
                                            self.rem_taiiac_id.is_set or
                                            self.remote_c_ctype.is_set or
                                            self.remote_ceid.is_set or
                                            self.remote_cv_type.is_set or
                                            self.remote_group_id.is_set or
                                            self.remote_label.is_set or
                                            self.remote_ldp_id.is_set or
                                            self.remote_source_address.is_set or
                                            self.remote_veid.is_set or
                                            self.saii.is_set or
                                            self.source_address.is_set or
                                            self.taii.is_set or
                                            (self.local_agi is not None and self.local_agi.has_data()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                            (self.remote_agi is not None and self.remote_agi.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                            self.is_sai_itype2.yfilter != YFilter.not_set or
                                            self.is_tai_itype2.yfilter != YFilter.not_set or
                                            self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                            self.local_c_ctype.yfilter != YFilter.not_set or
                                            self.local_ceid.yfilter != YFilter.not_set or
                                            self.local_cv_type.yfilter != YFilter.not_set or
                                            self.local_group_id.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_ldp_id.yfilter != YFilter.not_set or
                                            self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_saiiac_id.yfilter != YFilter.not_set or
                                            self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_taiiac_id.yfilter != YFilter.not_set or
                                            self.local_veid.yfilter != YFilter.not_set or
                                            self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.rem_saii.yfilter != YFilter.not_set or
                                            self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_saiiac_id.yfilter != YFilter.not_set or
                                            self.rem_taii.yfilter != YFilter.not_set or
                                            self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_taiiac_id.yfilter != YFilter.not_set or
                                            self.remote_c_ctype.yfilter != YFilter.not_set or
                                            self.remote_ceid.yfilter != YFilter.not_set or
                                            self.remote_cv_type.yfilter != YFilter.not_set or
                                            self.remote_group_id.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_ldp_id.yfilter != YFilter.not_set or
                                            self.remote_source_address.yfilter != YFilter.not_set or
                                            self.remote_veid.yfilter != YFilter.not_set or
                                            self.saii.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.taii.yfilter != YFilter.not_set or
                                            (self.local_agi is not None and self.local_agi.has_operation()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                            (self.remote_agi is not None and self.remote_agi.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                        if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                        if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                        if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                        if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                        if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                        if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                        if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                        if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                        if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                        if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                        if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                        if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_veid.get_name_leafdata())
                                        if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                        if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                        if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                        if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                        if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                        if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                        if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                        if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                        if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                        if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                        if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                        if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                        if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                        if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saii.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.taii.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local-agi"):
                                            if (self.local_agi is None):
                                                self.local_agi = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                            return self.local_agi

                                        if (child_yang_name == "multi-segment-pseudowire-stats"):
                                            if (self.multi_segment_pseudowire_stats is None):
                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            return self.multi_segment_pseudowire_stats

                                        if (child_yang_name == "remote-agi"):
                                            if (self.remote_agi is None):
                                                self.remote_agi = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                            return self.remote_agi

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-pseudowire-headend"):
                                            self.is_pseudowire_headend = value
                                            self.is_pseudowire_headend.value_namespace = name_space
                                            self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-sai-itype2"):
                                            self.is_sai_itype2 = value
                                            self.is_sai_itype2.value_namespace = name_space
                                            self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-tai-itype2"):
                                            self.is_tai_itype2 = value
                                            self.is_tai_itype2.value_namespace = name_space
                                            self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertisment-failed"):
                                            self.ldp_label_advertisment_failed = value
                                            self.ldp_label_advertisment_failed.value_namespace = name_space
                                            self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-c-ctype"):
                                            self.local_c_ctype = value
                                            self.local_c_ctype.value_namespace = name_space
                                            self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ceid"):
                                            self.local_ceid = value
                                            self.local_ceid.value_namespace = name_space
                                            self.local_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cv-type"):
                                            self.local_cv_type = value
                                            self.local_cv_type.value_namespace = name_space
                                            self.local_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-group-id"):
                                            self.local_group_id = value
                                            self.local_group_id.value_namespace = name_space
                                            self.local_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ldp-id"):
                                            self.local_ldp_id = value
                                            self.local_ldp_id.value_namespace = name_space
                                            self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saii-gbl-id"):
                                            self.local_saii_gbl_id = value
                                            self.local_saii_gbl_id.value_namespace = name_space
                                            self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saiiac-id"):
                                            self.local_saiiac_id = value
                                            self.local_saiiac_id.value_namespace = name_space
                                            self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taii-gbl-id"):
                                            self.local_taii_gbl_id = value
                                            self.local_taii_gbl_id.value_namespace = name_space
                                            self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taiiac-id"):
                                            self.local_taiiac_id = value
                                            self.local_taiiac_id.value_namespace = name_space
                                            self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-veid"):
                                            self.local_veid = value
                                            self.local_veid.value_namespace = name_space
                                            self.local_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsd-rewrite-failed"):
                                            self.lsd_rewrite_failed = value
                                            self.lsd_rewrite_failed.value_namespace = name_space
                                            self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii"):
                                            self.rem_saii = value
                                            self.rem_saii.value_namespace = name_space
                                            self.rem_saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii-gbl-id"):
                                            self.rem_saii_gbl_id = value
                                            self.rem_saii_gbl_id.value_namespace = name_space
                                            self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saiiac-id"):
                                            self.rem_saiiac_id = value
                                            self.rem_saiiac_id.value_namespace = name_space
                                            self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii"):
                                            self.rem_taii = value
                                            self.rem_taii.value_namespace = name_space
                                            self.rem_taii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii-gbl-id"):
                                            self.rem_taii_gbl_id = value
                                            self.rem_taii_gbl_id.value_namespace = name_space
                                            self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taiiac-id"):
                                            self.rem_taiiac_id = value
                                            self.rem_taiiac_id.value_namespace = name_space
                                            self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-c-ctype"):
                                            self.remote_c_ctype = value
                                            self.remote_c_ctype.value_namespace = name_space
                                            self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ceid"):
                                            self.remote_ceid = value
                                            self.remote_ceid.value_namespace = name_space
                                            self.remote_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cv-type"):
                                            self.remote_cv_type = value
                                            self.remote_cv_type.value_namespace = name_space
                                            self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-group-id"):
                                            self.remote_group_id = value
                                            self.remote_group_id.value_namespace = name_space
                                            self.remote_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ldp-id"):
                                            self.remote_ldp_id = value
                                            self.remote_ldp_id.value_namespace = name_space
                                            self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-source-address"):
                                            self.remote_source_address = value
                                            self.remote_source_address.value_namespace = name_space
                                            self.remote_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-veid"):
                                            self.remote_veid = value
                                            self.remote_veid.value_namespace = name_space
                                            self.remote_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saii"):
                                            self.saii = value
                                            self.saii.value_namespace = name_space
                                            self.saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "taii"):
                                            self.taii = value
                                            self.taii.value_namespace = name_space
                                            self.taii.value_namespace_prefix = name_space_prefix


                                class L2Tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                        self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                        self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                        self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                        self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                        self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                        self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                        self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                        self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                        self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                        self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                        self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                        self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                        self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                        self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                        self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                        self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                        self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                        self.tos = YLeaf(YType.uint8, "tos")

                                        self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dont_fragment_bit",
                                                        "ipv4_source_address",
                                                        "ipv6_source_address",
                                                        "l2tp_class_name",
                                                        "local_cookie_high_value",
                                                        "local_cookie_low_value",
                                                        "local_cookie_size",
                                                        "local_secondary_cookie_high_value",
                                                        "local_secondary_cookie_low_value",
                                                        "local_secondary_cookie_size",
                                                        "local_session_id",
                                                        "path_mtu_enabled",
                                                        "path_mtu_max_value",
                                                        "remote_circuit_status_up",
                                                        "remote_cookie_high_value",
                                                        "remote_cookie_low_value",
                                                        "remote_cookie_size",
                                                        "remote_session_id",
                                                        "tos",
                                                        "tos_mode",
                                                        "ttl",
                                                        "tunnel_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dont_fragment_bit.is_set or
                                            self.ipv4_source_address.is_set or
                                            self.ipv6_source_address.is_set or
                                            self.l2tp_class_name.is_set or
                                            self.local_cookie_high_value.is_set or
                                            self.local_cookie_low_value.is_set or
                                            self.local_cookie_size.is_set or
                                            self.local_secondary_cookie_high_value.is_set or
                                            self.local_secondary_cookie_low_value.is_set or
                                            self.local_secondary_cookie_size.is_set or
                                            self.local_session_id.is_set or
                                            self.path_mtu_enabled.is_set or
                                            self.path_mtu_max_value.is_set or
                                            self.remote_circuit_status_up.is_set or
                                            self.remote_cookie_high_value.is_set or
                                            self.remote_cookie_low_value.is_set or
                                            self.remote_cookie_size.is_set or
                                            self.remote_session_id.is_set or
                                            self.tos.is_set or
                                            self.tos_mode.is_set or
                                            self.ttl.is_set or
                                            self.tunnel_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dont_fragment_bit.yfilter != YFilter.not_set or
                                            self.ipv4_source_address.yfilter != YFilter.not_set or
                                            self.ipv6_source_address.yfilter != YFilter.not_set or
                                            self.l2tp_class_name.yfilter != YFilter.not_set or
                                            self.local_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_cookie_size.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                            self.local_session_id.yfilter != YFilter.not_set or
                                            self.path_mtu_enabled.yfilter != YFilter.not_set or
                                            self.path_mtu_max_value.yfilter != YFilter.not_set or
                                            self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                            self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_size.yfilter != YFilter.not_set or
                                            self.remote_session_id.yfilter != YFilter.not_set or
                                            self.tos.yfilter != YFilter.not_set or
                                            self.tos_mode.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.tunnel_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv3" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                        if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                        if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                        if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                        if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                        if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                        if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                        if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                        if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                        if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                        if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                        if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                        if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                        if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                        if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                        if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                        if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos.get_name_leafdata())
                                        if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dont-fragment-bit"):
                                            self.dont_fragment_bit = value
                                            self.dont_fragment_bit.value_namespace = name_space
                                            self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-source-address"):
                                            self.ipv4_source_address = value
                                            self.ipv4_source_address.value_namespace = name_space
                                            self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-source-address"):
                                            self.ipv6_source_address = value
                                            self.ipv6_source_address.value_namespace = name_space
                                            self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l2tp-class-name"):
                                            self.l2tp_class_name = value
                                            self.l2tp_class_name.value_namespace = name_space
                                            self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-high-value"):
                                            self.local_cookie_high_value = value
                                            self.local_cookie_high_value.value_namespace = name_space
                                            self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-low-value"):
                                            self.local_cookie_low_value = value
                                            self.local_cookie_low_value.value_namespace = name_space
                                            self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-size"):
                                            self.local_cookie_size = value
                                            self.local_cookie_size.value_namespace = name_space
                                            self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-high-value"):
                                            self.local_secondary_cookie_high_value = value
                                            self.local_secondary_cookie_high_value.value_namespace = name_space
                                            self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-low-value"):
                                            self.local_secondary_cookie_low_value = value
                                            self.local_secondary_cookie_low_value.value_namespace = name_space
                                            self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-size"):
                                            self.local_secondary_cookie_size = value
                                            self.local_secondary_cookie_size.value_namespace = name_space
                                            self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-session-id"):
                                            self.local_session_id = value
                                            self.local_session_id.value_namespace = name_space
                                            self.local_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-enabled"):
                                            self.path_mtu_enabled = value
                                            self.path_mtu_enabled.value_namespace = name_space
                                            self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-max-value"):
                                            self.path_mtu_max_value = value
                                            self.path_mtu_max_value.value_namespace = name_space
                                            self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-circuit-status-up"):
                                            self.remote_circuit_status_up = value
                                            self.remote_circuit_status_up.value_namespace = name_space
                                            self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-high-value"):
                                            self.remote_cookie_high_value = value
                                            self.remote_cookie_high_value.value_namespace = name_space
                                            self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-low-value"):
                                            self.remote_cookie_low_value = value
                                            self.remote_cookie_low_value.value_namespace = name_space
                                            self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-size"):
                                            self.remote_cookie_size = value
                                            self.remote_cookie_size.value_namespace = name_space
                                            self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-session-id"):
                                            self.remote_session_id = value
                                            self.remote_session_id.value_namespace = name_space
                                            self.remote_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos"):
                                            self.tos = value
                                            self.tos.value_namespace = name_space
                                            self.tos.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-mode"):
                                            self.tos_mode = value
                                            self.tos_mode.value_namespace = name_space
                                            self.tos_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tunnel-state"):
                                            self.tunnel_state = value
                                            self.tunnel_state.value_namespace = name_space
                                            self.tunnel_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.encapsulation.is_set or
                                        (self.atom is not None and self.atom.has_data()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "encapsulation-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    if (child_yang_name == "l2tpv3"):
                                        if (self.l2tpv3 is None):
                                            self.l2tpv3 = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                        return self.l2tpv3

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation"):
                                        self.encapsulation = value
                                        self.encapsulation.value_namespace = name_space
                                        self.encapsulation.value_namespace_prefix = name_space_prefix


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudowire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudowire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudowire"

                                    self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                    self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                    self.option = YLeaf(YType.enumeration, "option")

                                    self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                    self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ip_tunnel_interface_number",
                                                    "next_hop_ip",
                                                    "option",
                                                    "te_tunnel_interface_number",
                                                    "tp_tunnel_interface_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ip_tunnel_interface_number.is_set or
                                        self.next_hop_ip.is_set or
                                        self.option.is_set or
                                        self.te_tunnel_interface_number.is_set or
                                        self.tp_tunnel_interface_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set or
                                        self.option.yfilter != YFilter.not_set or
                                        self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "preferred-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                    if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.option.get_name_leafdata())
                                    if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                    if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ip-tunnel-interface-number"):
                                        self.ip_tunnel_interface_number = value
                                        self.ip_tunnel_interface_number.value_namespace = name_space
                                        self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                    if(value_path == "option"):
                                        self.option = value
                                        self.option.value_namespace = name_space
                                        self.option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-tunnel-interface-number"):
                                        self.te_tunnel_interface_number = value
                                        self.te_tunnel_interface_number.value_namespace = name_space
                                        self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tp-tunnel-interface-number"):
                                        self.tp_tunnel_interface_number = value
                                        self.tp_tunnel_interface_number.value_namespace = name_space
                                        self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudowire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudowire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudowire"

                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class P2MpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudowire"

                                    self.local_available = YLeaf(YType.boolean, "local-available")

                                    self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                    self.local_flags = YLeaf(YType.uint8, "local-flags")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                    self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                    self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                    self.remote_available = YLeaf(YType.boolean, "remote-available")

                                    self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                    self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                    self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                    self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_available",
                                                    "local_extended_tunnel_id",
                                                    "local_flags",
                                                    "local_label",
                                                    "local_p2mp_id",
                                                    "local_ptree_type",
                                                    "local_tunnel_id",
                                                    "remote_available",
                                                    "remote_extended_tunnel_id",
                                                    "remote_flags",
                                                    "remote_label",
                                                    "remote_p2mp_id",
                                                    "remote_ptree_type",
                                                    "remote_tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_available.is_set or
                                        self.local_extended_tunnel_id.is_set or
                                        self.local_flags.is_set or
                                        self.local_label.is_set or
                                        self.local_p2mp_id.is_set or
                                        self.local_ptree_type.is_set or
                                        self.local_tunnel_id.is_set or
                                        self.remote_available.is_set or
                                        self.remote_extended_tunnel_id.is_set or
                                        self.remote_flags.is_set or
                                        self.remote_label.is_set or
                                        self.remote_p2mp_id.is_set or
                                        self.remote_ptree_type.is_set or
                                        self.remote_tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_available.yfilter != YFilter.not_set or
                                        self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.local_flags.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_p2mp_id.yfilter != YFilter.not_set or
                                        self.local_ptree_type.yfilter != YFilter.not_set or
                                        self.local_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_available.yfilter != YFilter.not_set or
                                        self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_flags.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_p2mp_id.yfilter != YFilter.not_set or
                                        self.remote_ptree_type.yfilter != YFilter.not_set or
                                        self.remote_tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_available.get_name_leafdata())
                                    if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                    if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_flags.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                    if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                    if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                    if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_available.get_name_leafdata())
                                    if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                    if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                    if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                    if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-available"):
                                        self.local_available = value
                                        self.local_available.value_namespace = name_space
                                        self.local_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-extended-tunnel-id"):
                                        self.local_extended_tunnel_id = value
                                        self.local_extended_tunnel_id.value_namespace = name_space
                                        self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-flags"):
                                        self.local_flags = value
                                        self.local_flags.value_namespace = name_space
                                        self.local_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-p2mp-id"):
                                        self.local_p2mp_id = value
                                        self.local_p2mp_id.value_namespace = name_space
                                        self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ptree-type"):
                                        self.local_ptree_type = value
                                        self.local_ptree_type.value_namespace = name_space
                                        self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-tunnel-id"):
                                        self.local_tunnel_id = value
                                        self.local_tunnel_id.value_namespace = name_space
                                        self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-available"):
                                        self.remote_available = value
                                        self.remote_available.value_namespace = name_space
                                        self.remote_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-extended-tunnel-id"):
                                        self.remote_extended_tunnel_id = value
                                        self.remote_extended_tunnel_id.value_namespace = name_space
                                        self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-flags"):
                                        self.remote_flags = value
                                        self.remote_flags.value_namespace = name_space
                                        self.remote_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-p2mp-id"):
                                        self.remote_p2mp_id = value
                                        self.remote_p2mp_id.value_namespace = name_space
                                        self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ptree-type"):
                                        self.remote_ptree_type = value
                                        self.remote_ptree_type.value_namespace = name_space
                                        self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-tunnel-id"):
                                        self.remote_tunnel_id = value
                                        self.remote_tunnel_id.value_namespace = name_space
                                        self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ad_method.is_set or
                                    self.ad_remote_down.is_set or
                                    self.admited_bw.is_set or
                                    self.auto_discovery.is_set or
                                    self.backup_active.is_set or
                                    self.backup_force_active.is_set or
                                    self.backup_pw.is_set or
                                    self.bitrate_mismatched.is_set or
                                    self.bridge_pw_type_mismatch.is_set or
                                    self.cas_mismatched.is_set or
                                    self.diff_ts_mismatched.is_set or
                                    self.disable_delay.is_set or
                                    self.disable_never.is_set or
                                    self.evpn_src_acid.is_set or
                                    self.fe_ctype.is_set or
                                    self.forward_class.is_set or
                                    self.freq_mismatched.is_set or
                                    self.illegal_control_word.is_set or
                                    self.imposed_vlan_id.is_set or
                                    self.interworking.is_set or
                                    self.ipv6_local_source_address.is_set or
                                    self.is_evpnvpws_type.is_set or
                                    self.is_flow_label_static.is_set or
                                    self.is_multi_segment_pseudowire.is_set or
                                    self.is_partially_programmed.is_set or
                                    self.is_pwr_type.is_set or
                                    self.is_vfi.is_set or
                                    self.last_time_status_changed.is_set or
                                    self.last_time_status_down.is_set or
                                    self.ldp_label_advertise_failed.is_set or
                                    self.load_balance.is_set or
                                    self.local_control_word.is_set or
                                    self.local_label_failed.is_set or
                                    self.local_pseudo_wire_type.is_set or
                                    self.local_source_address.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.not_supported_qinq.is_set or
                                    self.num_ma_cwithdraw_msg_received.is_set or
                                    self.number_ma_cwithdraw_message_sent.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.payload_bytes_mismatched.is_set or
                                    self.payload_type_mismatched.is_set or
                                    self.preferred_path_disable_fallback.is_set or
                                    self.primary_peer_id.is_set or
                                    self.primary_pseudo_wire_id.is_set or
                                    self.primary_pw.is_set or
                                    self.protocol.is_set or
                                    self.pseudo_wire_id.is_set or
                                    self.pseudo_wire_state.is_set or
                                    self.pseudo_wire_type_mismatched.is_set or
                                    self.pw_class_name.is_set or
                                    self.pw_flow_label_code17_disabled.is_set or
                                    self.pw_flow_label_type.is_set or
                                    self.pw_flow_label_type_cfg.is_set or
                                    self.pw_redundancy_initial_delay.is_set or
                                    self.pw_redundancy_one_way.is_set or
                                    self.pw_status_use.is_set or
                                    self.pwlsd_rewrite_failed.is_set or
                                    self.remote_control_word.is_set or
                                    self.remote_label_failed.is_set or
                                    self.remote_pseudo_wire_type.is_set or
                                    self.required_bw.is_set or
                                    self.resync_enabled.is_set or
                                    self.resync_threshold.is_set or
                                    self.rtp_mismatched.is_set or
                                    self.sequencing_type.is_set or
                                    self.shutdown.is_set or
                                    self.sig_pkts_mismatched.is_set or
                                    self.ssrc_mismatched.is_set or
                                    self.state.is_set or
                                    self.table_policy_name.is_set or
                                    self.tag_rewrite.is_set or
                                    self.time_created.is_set or
                                    self.time_elapsed_creation.is_set or
                                    self.time_elapsed_status_changed.is_set or
                                    self.time_elapsed_status_down.is_set or
                                    self.transport_lsp_down.is_set or
                                    self.xconnect_id.is_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                    (self.local_interface is not None and self.local_interface.has_data()) or
                                    (self.local_signalling is not None and self.local_signalling.has_data()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                    (self.peer_id is not None and self.peer_id.has_data()) or
                                    (self.preferred_path is not None and self.preferred_path.has_data()) or
                                    (self.remote_interface is not None and self.remote_interface.has_data()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_remote_down.yfilter != YFilter.not_set or
                                    self.admited_bw.yfilter != YFilter.not_set or
                                    self.auto_discovery.yfilter != YFilter.not_set or
                                    self.backup_active.yfilter != YFilter.not_set or
                                    self.backup_force_active.yfilter != YFilter.not_set or
                                    self.backup_pw.yfilter != YFilter.not_set or
                                    self.bitrate_mismatched.yfilter != YFilter.not_set or
                                    self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                    self.cas_mismatched.yfilter != YFilter.not_set or
                                    self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                    self.disable_delay.yfilter != YFilter.not_set or
                                    self.disable_never.yfilter != YFilter.not_set or
                                    self.evpn_src_acid.yfilter != YFilter.not_set or
                                    self.fe_ctype.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.freq_mismatched.yfilter != YFilter.not_set or
                                    self.illegal_control_word.yfilter != YFilter.not_set or
                                    self.imposed_vlan_id.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                    self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                    self.is_flow_label_static.yfilter != YFilter.not_set or
                                    self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                    self.is_partially_programmed.yfilter != YFilter.not_set or
                                    self.is_pwr_type.yfilter != YFilter.not_set or
                                    self.is_vfi.yfilter != YFilter.not_set or
                                    self.last_time_status_changed.yfilter != YFilter.not_set or
                                    self.last_time_status_down.yfilter != YFilter.not_set or
                                    self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                    self.load_balance.yfilter != YFilter.not_set or
                                    self.local_control_word.yfilter != YFilter.not_set or
                                    self.local_label_failed.yfilter != YFilter.not_set or
                                    self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.local_source_address.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.not_supported_qinq.yfilter != YFilter.not_set or
                                    self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                    self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                    self.payload_type_mismatched.yfilter != YFilter.not_set or
                                    self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                    self.primary_peer_id.yfilter != YFilter.not_set or
                                    self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.primary_pw.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.pseudo_wire_state.yfilter != YFilter.not_set or
                                    self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                    self.pw_class_name.yfilter != YFilter.not_set or
                                    self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                    self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                    self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                    self.pw_status_use.yfilter != YFilter.not_set or
                                    self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.remote_control_word.yfilter != YFilter.not_set or
                                    self.remote_label_failed.yfilter != YFilter.not_set or
                                    self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.required_bw.yfilter != YFilter.not_set or
                                    self.resync_enabled.yfilter != YFilter.not_set or
                                    self.resync_threshold.yfilter != YFilter.not_set or
                                    self.rtp_mismatched.yfilter != YFilter.not_set or
                                    self.sequencing_type.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                    self.ssrc_mismatched.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.table_policy_name.yfilter != YFilter.not_set or
                                    self.tag_rewrite.yfilter != YFilter.not_set or
                                    self.time_created.yfilter != YFilter.not_set or
                                    self.time_elapsed_creation.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                    self.transport_lsp_down.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                    (self.local_interface is not None and self.local_interface.has_operation()) or
                                    (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                    (self.peer_id is not None and self.peer_id.has_operation()) or
                                    (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                    (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pseudowire" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_active.get_name_leafdata())
                                if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_never.get_name_leafdata())
                                if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance.get_name_leafdata())
                                if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())
                                if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.required_bw.get_name_leafdata())
                                if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_created.get_name_leafdata())
                                if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "encapsulation-info"):
                                    if (self.encapsulation_info is None):
                                        self.encapsulation_info = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    return self.encapsulation_info

                                if (child_yang_name == "local-interface"):
                                    if (self.local_interface is None):
                                        self.local_interface = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                    return self.local_interface

                                if (child_yang_name == "local-signalling"):
                                    if (self.local_signalling is None):
                                        self.local_signalling = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                    return self.local_signalling

                                if (child_yang_name == "p2mp-pw"):
                                    if (self.p2mp_pw is None):
                                        self.p2mp_pw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    return self.p2mp_pw

                                if (child_yang_name == "peer-id"):
                                    if (self.peer_id is None):
                                        self.peer_id = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                    return self.peer_id

                                if (child_yang_name == "preferred-path"):
                                    if (self.preferred_path is None):
                                        self.preferred_path = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                    return self.preferred_path

                                if (child_yang_name == "remote-interface"):
                                    if (self.remote_interface is None):
                                        self.remote_interface = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                    return self.remote_interface

                                if (child_yang_name == "remote-signalling"):
                                    if (self.remote_signalling is None):
                                        self.remote_signalling = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                    return self.remote_signalling

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-remote-down"):
                                    self.ad_remote_down = value
                                    self.ad_remote_down.value_namespace = name_space
                                    self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "admited-bw"):
                                    self.admited_bw = value
                                    self.admited_bw.value_namespace = name_space
                                    self.admited_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "auto-discovery"):
                                    self.auto_discovery = value
                                    self.auto_discovery.value_namespace = name_space
                                    self.auto_discovery.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-active"):
                                    self.backup_active = value
                                    self.backup_active.value_namespace = name_space
                                    self.backup_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-force-active"):
                                    self.backup_force_active = value
                                    self.backup_force_active.value_namespace = name_space
                                    self.backup_force_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-pw"):
                                    self.backup_pw = value
                                    self.backup_pw.value_namespace = name_space
                                    self.backup_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "bitrate-mismatched"):
                                    self.bitrate_mismatched = value
                                    self.bitrate_mismatched.value_namespace = name_space
                                    self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-pw-type-mismatch"):
                                    self.bridge_pw_type_mismatch = value
                                    self.bridge_pw_type_mismatch.value_namespace = name_space
                                    self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "cas-mismatched"):
                                    self.cas_mismatched = value
                                    self.cas_mismatched.value_namespace = name_space
                                    self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "diff-ts-mismatched"):
                                    self.diff_ts_mismatched = value
                                    self.diff_ts_mismatched.value_namespace = name_space
                                    self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-delay"):
                                    self.disable_delay = value
                                    self.disable_delay.value_namespace = name_space
                                    self.disable_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-never"):
                                    self.disable_never = value
                                    self.disable_never.value_namespace = name_space
                                    self.disable_never.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-src-acid"):
                                    self.evpn_src_acid = value
                                    self.evpn_src_acid.value_namespace = name_space
                                    self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                if(value_path == "fe-ctype"):
                                    self.fe_ctype = value
                                    self.fe_ctype.value_namespace = name_space
                                    self.fe_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "freq-mismatched"):
                                    self.freq_mismatched = value
                                    self.freq_mismatched.value_namespace = name_space
                                    self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-control-word"):
                                    self.illegal_control_word = value
                                    self.illegal_control_word.value_namespace = name_space
                                    self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "imposed-vlan-id"):
                                    self.imposed_vlan_id = value
                                    self.imposed_vlan_id.value_namespace = name_space
                                    self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-local-source-address"):
                                    self.ipv6_local_source_address = value
                                    self.ipv6_local_source_address.value_namespace = name_space
                                    self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpnvpws-type"):
                                    self.is_evpnvpws_type = value
                                    self.is_evpnvpws_type.value_namespace = name_space
                                    self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-flow-label-static"):
                                    self.is_flow_label_static = value
                                    self.is_flow_label_static.value_namespace = name_space
                                    self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-multi-segment-pseudowire"):
                                    self.is_multi_segment_pseudowire = value
                                    self.is_multi_segment_pseudowire.value_namespace = name_space
                                    self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-partially-programmed"):
                                    self.is_partially_programmed = value
                                    self.is_partially_programmed.value_namespace = name_space
                                    self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pwr-type"):
                                    self.is_pwr_type = value
                                    self.is_pwr_type.value_namespace = name_space
                                    self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vfi"):
                                    self.is_vfi = value
                                    self.is_vfi.value_namespace = name_space
                                    self.is_vfi.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-changed"):
                                    self.last_time_status_changed = value
                                    self.last_time_status_changed.value_namespace = name_space
                                    self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-down"):
                                    self.last_time_status_down = value
                                    self.last_time_status_down.value_namespace = name_space
                                    self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertise-failed"):
                                    self.ldp_label_advertise_failed = value
                                    self.ldp_label_advertise_failed.value_namespace = name_space
                                    self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance"):
                                    self.load_balance = value
                                    self.load_balance.value_namespace = name_space
                                    self.load_balance.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-control-word"):
                                    self.local_control_word = value
                                    self.local_control_word.value_namespace = name_space
                                    self.local_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label-failed"):
                                    self.local_label_failed = value
                                    self.local_label_failed.value_namespace = name_space
                                    self.local_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-pseudo-wire-type"):
                                    self.local_pseudo_wire_type = value
                                    self.local_pseudo_wire_type.value_namespace = name_space
                                    self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-source-address"):
                                    self.local_source_address = value
                                    self.local_source_address.value_namespace = name_space
                                    self.local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-supported-qinq"):
                                    self.not_supported_qinq = value
                                    self.not_supported_qinq.value_namespace = name_space
                                    self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                if(value_path == "num-ma-cwithdraw-msg-received"):
                                    self.num_ma_cwithdraw_msg_received = value
                                    self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                    self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-ma-cwithdraw-message-sent"):
                                    self.number_ma_cwithdraw_message_sent = value
                                    self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                    self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes-mismatched"):
                                    self.payload_bytes_mismatched = value
                                    self.payload_bytes_mismatched.value_namespace = name_space
                                    self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-type-mismatched"):
                                    self.payload_type_mismatched = value
                                    self.payload_type_mismatched.value_namespace = name_space
                                    self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "preferred-path-disable-fallback"):
                                    self.preferred_path_disable_fallback = value
                                    self.preferred_path_disable_fallback.value_namespace = name_space
                                    self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-peer-id"):
                                    self.primary_peer_id = value
                                    self.primary_peer_id.value_namespace = name_space
                                    self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pseudo-wire-id"):
                                    self.primary_pseudo_wire_id = value
                                    self.primary_pseudo_wire_id.value_namespace = name_space
                                    self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pw"):
                                    self.primary_pw = value
                                    self.primary_pw.value_namespace = name_space
                                    self.primary_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id"):
                                    self.pseudo_wire_id = value
                                    self.pseudo_wire_id.value_namespace = name_space
                                    self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-state"):
                                    self.pseudo_wire_state = value
                                    self.pseudo_wire_state.value_namespace = name_space
                                    self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-type-mismatched"):
                                    self.pseudo_wire_type_mismatched = value
                                    self.pseudo_wire_type_mismatched.value_namespace = name_space
                                    self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-class-name"):
                                    self.pw_class_name = value
                                    self.pw_class_name.value_namespace = name_space
                                    self.pw_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-code17-disabled"):
                                    self.pw_flow_label_code17_disabled = value
                                    self.pw_flow_label_code17_disabled.value_namespace = name_space
                                    self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type"):
                                    self.pw_flow_label_type = value
                                    self.pw_flow_label_type.value_namespace = name_space
                                    self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type-cfg"):
                                    self.pw_flow_label_type_cfg = value
                                    self.pw_flow_label_type_cfg.value_namespace = name_space
                                    self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-initial-delay"):
                                    self.pw_redundancy_initial_delay = value
                                    self.pw_redundancy_initial_delay.value_namespace = name_space
                                    self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-one-way"):
                                    self.pw_redundancy_one_way = value
                                    self.pw_redundancy_one_way.value_namespace = name_space
                                    self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-status-use"):
                                    self.pw_status_use = value
                                    self.pw_status_use.value_namespace = name_space
                                    self.pw_status_use.value_namespace_prefix = name_space_prefix
                                if(value_path == "pwlsd-rewrite-failed"):
                                    self.pwlsd_rewrite_failed = value
                                    self.pwlsd_rewrite_failed.value_namespace = name_space
                                    self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-control-word"):
                                    self.remote_control_word = value
                                    self.remote_control_word.value_namespace = name_space
                                    self.remote_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label-failed"):
                                    self.remote_label_failed = value
                                    self.remote_label_failed.value_namespace = name_space
                                    self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-pseudo-wire-type"):
                                    self.remote_pseudo_wire_type = value
                                    self.remote_pseudo_wire_type.value_namespace = name_space
                                    self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "required-bw"):
                                    self.required_bw = value
                                    self.required_bw.value_namespace = name_space
                                    self.required_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-enabled"):
                                    self.resync_enabled = value
                                    self.resync_enabled.value_namespace = name_space
                                    self.resync_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-threshold"):
                                    self.resync_threshold = value
                                    self.resync_threshold.value_namespace = name_space
                                    self.resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "rtp-mismatched"):
                                    self.rtp_mismatched = value
                                    self.rtp_mismatched.value_namespace = name_space
                                    self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequencing-type"):
                                    self.sequencing_type = value
                                    self.sequencing_type.value_namespace = name_space
                                    self.sequencing_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "sig-pkts-mismatched"):
                                    self.sig_pkts_mismatched = value
                                    self.sig_pkts_mismatched.value_namespace = name_space
                                    self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "ssrc-mismatched"):
                                    self.ssrc_mismatched = value
                                    self.ssrc_mismatched.value_namespace = name_space
                                    self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-policy-name"):
                                    self.table_policy_name = value
                                    self.table_policy_name.value_namespace = name_space
                                    self.table_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag-rewrite"):
                                    self.tag_rewrite = value
                                    self.tag_rewrite.value_namespace = name_space
                                    self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-created"):
                                    self.time_created = value
                                    self.time_created.value_namespace = name_space
                                    self.time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-creation"):
                                    self.time_elapsed_creation = value
                                    self.time_elapsed_creation.value_namespace = name_space
                                    self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-changed"):
                                    self.time_elapsed_status_changed = value
                                    self.time_elapsed_status_changed.value_namespace = name_space
                                    self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-down"):
                                    self.time_elapsed_status_down = value
                                    self.time_elapsed_status_down.value_namespace = name_space
                                    self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-lsp-down"):
                                    self.transport_lsp_down = value
                                    self.transport_lsp_down.value_namespace = name_space
                                    self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.pseudowire:
                                if (c.has_data()):
                                    return True
                            return (
                                self.fxc_id.is_set or
                                self.name.is_set or
                                self.num_p_ws.is_set or
                                self.state.is_set)

                        def has_operation(self):
                            for c in self.pseudowire:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.fxc_id.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.num_p_ws.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "flexible-xconnect-service-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.fxc_id.is_set or self.fxc_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fxc_id.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.num_p_ws.is_set or self.num_p_ws.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_p_ws.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "pseudowire"):
                                for c in self.pseudowire:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.pseudowire.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "pseudowire" or name == "fxc-id" or name == "name" or name == "num-p-ws" or name == "state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "fxc-id"):
                                self.fxc_id = value
                                self.fxc_id.value_namespace = name_space
                                self.fxc_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-p-ws"):
                                self.num_p_ws = value
                                self.num_p_ws.value_namespace = name_space
                                self.num_p_ws.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.name.is_set or
                            (self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs.has_data()) or
                            (self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.name.yfilter != YFilter.not_set or
                            (self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs.has_operation()) or
                            (self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flexible-xconnect-service" + "[name='" + self.name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "flexible-xconnect-service-acs"):
                            if (self.flexible_xconnect_service_acs is None):
                                self.flexible_xconnect_service_acs = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                                self.flexible_xconnect_service_acs.parent = self
                                self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"
                            return self.flexible_xconnect_service_acs

                        if (child_yang_name == "flexible-xconnect-service-info"):
                            if (self.flexible_xconnect_service_info is None):
                                self.flexible_xconnect_service_info = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                                self.flexible_xconnect_service_info.parent = self
                                self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                            return self.flexible_xconnect_service_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flexible-xconnect-service-acs" or name == "flexible-xconnect-service-info" or name == "name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "name"):
                            self.name = value
                            self.name.value_namespace = name_space
                            self.name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.flexible_xconnect_service:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.flexible_xconnect_service:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flexible-xconnect-services" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "flexible-xconnect-service"):
                        for c in self.flexible_xconnect_service:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.flexible_xconnect_service.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flexible-xconnect-service"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class XconnectBrief(Entity):
                """
                XConnect brief information
                
                .. attribute:: encapsulation_report_matrix
                
                	Encapsulation report counters matrix
                	**type**\: list of    :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix>`
                
                .. attribute:: encapsulation_total
                
                	Total summary
                	**type**\: list of    :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal>`
                
                .. attribute:: main_total_down
                
                	Total Number of non\-active Cross\-Conections with valid encaps
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: main_total_unresolved
                
                	Total Number of unresolved Cross\-Conections with valid encaps
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: main_total_up
                
                	Total Number of active Cross\-Conections with valid encaps
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: memory_state
                
                	L2VPN memory state
                	**type**\:   :py:class:`L2VpnMemoryState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMemoryState>`
                
                .. attribute:: undefined_xc
                
                	Undefined xc including PW\-PW
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpnv2.Nodes.Node.XconnectBrief, self).__init__()

                    self.yang_name = "xconnect-brief"
                    self.yang_parent_name = "node"

                    self.main_total_down = YLeaf(YType.uint32, "main-total-down")

                    self.main_total_unresolved = YLeaf(YType.uint32, "main-total-unresolved")

                    self.main_total_up = YLeaf(YType.uint32, "main-total-up")

                    self.memory_state = YLeaf(YType.enumeration, "memory-state")

                    self.undefined_xc = YLeaf(YType.uint32, "undefined-xc")

                    self.encapsulation_report_matrix = YList(self)
                    self.encapsulation_total = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("main_total_down",
                                    "main_total_unresolved",
                                    "main_total_up",
                                    "memory_state",
                                    "undefined_xc") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpnv2.Nodes.Node.XconnectBrief, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpnv2.Nodes.Node.XconnectBrief, self).__setattr__(name, value)


                class EncapsulationReportMatrix(Entity):
                    """
                    Encapsulation report counters matrix
                    
                    .. attribute:: ac1
                    
                    	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
                    	**type**\: list of    :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix, self).__init__()

                        self.yang_name = "encapsulation-report-matrix"
                        self.yang_parent_name = "xconnect-brief"

                        self.ac1 = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix, self).__setattr__(name, value)


                    class Ac1(Entity):
                        """
                        Array of l2vpn\_xc\_brief\_first layer indexed by
                        the AC1 encapsulation type
                        
                        .. attribute:: ac2
                        
                        	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                        	**type**\: list of    :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__init__()

                            self.yang_name = "ac1"
                            self.yang_parent_name = "encapsulation-report-matrix"

                            self.ac2 = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__setattr__(name, value)


                        class Ac2(Entity):
                            """
                            Array of l2vpn\_xc\_brief\_line indexed by the AC2
                            encapsulation type plus one type for PW
                            
                            .. attribute:: ac1_encapsulation
                            
                            	AC1 encapsulation
                            	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                            
                            .. attribute:: ac2_encapsulation
                            
                            	AC2 encapsulation
                            	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                            
                            .. attribute:: down_count
                            
                            	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: psn_type
                            
                            	PSN Type
                            	**type**\:   :py:class:`L2VpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBriefPsn>`
                            
                            .. attribute:: unresolved_count
                            
                            	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: up_count
                            
                            	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__init__()

                                self.yang_name = "ac2"
                                self.yang_parent_name = "ac1"

                                self.ac1_encapsulation = YLeaf(YType.enumeration, "ac1-encapsulation")

                                self.ac2_encapsulation = YLeaf(YType.enumeration, "ac2-encapsulation")

                                self.down_count = YLeafList(YType.uint32, "down-count")

                                self.psn_type = YLeaf(YType.enumeration, "psn-type")

                                self.unresolved_count = YLeafList(YType.uint32, "unresolved-count")

                                self.up_count = YLeafList(YType.uint32, "up-count")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ac1_encapsulation",
                                                "ac2_encapsulation",
                                                "down_count",
                                                "psn_type",
                                                "unresolved_count",
                                                "up_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.down_count.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                for leaf in self.unresolved_count.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                for leaf in self.up_count.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.ac1_encapsulation.is_set or
                                    self.ac2_encapsulation.is_set or
                                    self.psn_type.is_set)

                            def has_operation(self):
                                for leaf in self.down_count.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                for leaf in self.unresolved_count.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                for leaf in self.up_count.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ac1_encapsulation.yfilter != YFilter.not_set or
                                    self.ac2_encapsulation.yfilter != YFilter.not_set or
                                    self.down_count.yfilter != YFilter.not_set or
                                    self.psn_type.yfilter != YFilter.not_set or
                                    self.unresolved_count.yfilter != YFilter.not_set or
                                    self.up_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ac2" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ac1_encapsulation.is_set or self.ac1_encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac1_encapsulation.get_name_leafdata())
                                if (self.ac2_encapsulation.is_set or self.ac2_encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ac2_encapsulation.get_name_leafdata())
                                if (self.psn_type.is_set or self.psn_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.psn_type.get_name_leafdata())

                                leaf_name_data.extend(self.down_count.get_name_leafdata())

                                leaf_name_data.extend(self.unresolved_count.get_name_leafdata())

                                leaf_name_data.extend(self.up_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ac1-encapsulation" or name == "ac2-encapsulation" or name == "down-count" or name == "psn-type" or name == "unresolved-count" or name == "up-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ac1-encapsulation"):
                                    self.ac1_encapsulation = value
                                    self.ac1_encapsulation.value_namespace = name_space
                                    self.ac1_encapsulation.value_namespace_prefix = name_space_prefix
                                if(value_path == "ac2-encapsulation"):
                                    self.ac2_encapsulation = value
                                    self.ac2_encapsulation.value_namespace = name_space
                                    self.ac2_encapsulation.value_namespace_prefix = name_space_prefix
                                if(value_path == "down-count"):
                                    self.down_count.append(value)
                                if(value_path == "psn-type"):
                                    self.psn_type = value
                                    self.psn_type.value_namespace = name_space
                                    self.psn_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "unresolved-count"):
                                    self.unresolved_count.append(value)
                                if(value_path == "up-count"):
                                    self.up_count.append(value)

                        def has_data(self):
                            for c in self.ac2:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ac2:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ac1" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ac2"):
                                for c in self.ac2:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ac2.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ac2"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for c in self.ac1:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ac1:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "encapsulation-report-matrix" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ac1"):
                            for c in self.ac1:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ac1.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ac1"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class EncapsulationTotal(Entity):
                    """
                    Total summary
                    
                    .. attribute:: ac1_encapsulation
                    
                    	AC1 encapsulation
                    	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                    
                    .. attribute:: ac2_encapsulation
                    
                    	AC2 encapsulation
                    	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                    
                    .. attribute:: down_count
                    
                    	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: psn_type
                    
                    	PSN Type
                    	**type**\:   :py:class:`L2VpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBriefPsn>`
                    
                    .. attribute:: unresolved_count
                    
                    	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: up_count
                    
                    	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal, self).__init__()

                        self.yang_name = "encapsulation-total"
                        self.yang_parent_name = "xconnect-brief"

                        self.ac1_encapsulation = YLeaf(YType.enumeration, "ac1-encapsulation")

                        self.ac2_encapsulation = YLeaf(YType.enumeration, "ac2-encapsulation")

                        self.down_count = YLeafList(YType.uint32, "down-count")

                        self.psn_type = YLeaf(YType.enumeration, "psn-type")

                        self.unresolved_count = YLeafList(YType.uint32, "unresolved-count")

                        self.up_count = YLeafList(YType.uint32, "up-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ac1_encapsulation",
                                        "ac2_encapsulation",
                                        "down_count",
                                        "psn_type",
                                        "unresolved_count",
                                        "up_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal, self).__setattr__(name, value)

                    def has_data(self):
                        for leaf in self.down_count.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.unresolved_count.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.up_count.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.ac1_encapsulation.is_set or
                            self.ac2_encapsulation.is_set or
                            self.psn_type.is_set)

                    def has_operation(self):
                        for leaf in self.down_count.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.unresolved_count.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.up_count.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ac1_encapsulation.yfilter != YFilter.not_set or
                            self.ac2_encapsulation.yfilter != YFilter.not_set or
                            self.down_count.yfilter != YFilter.not_set or
                            self.psn_type.yfilter != YFilter.not_set or
                            self.unresolved_count.yfilter != YFilter.not_set or
                            self.up_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "encapsulation-total" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ac1_encapsulation.is_set or self.ac1_encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac1_encapsulation.get_name_leafdata())
                        if (self.ac2_encapsulation.is_set or self.ac2_encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac2_encapsulation.get_name_leafdata())
                        if (self.psn_type.is_set or self.psn_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.psn_type.get_name_leafdata())

                        leaf_name_data.extend(self.down_count.get_name_leafdata())

                        leaf_name_data.extend(self.unresolved_count.get_name_leafdata())

                        leaf_name_data.extend(self.up_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ac1-encapsulation" or name == "ac2-encapsulation" or name == "down-count" or name == "psn-type" or name == "unresolved-count" or name == "up-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ac1-encapsulation"):
                            self.ac1_encapsulation = value
                            self.ac1_encapsulation.value_namespace = name_space
                            self.ac1_encapsulation.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac2-encapsulation"):
                            self.ac2_encapsulation = value
                            self.ac2_encapsulation.value_namespace = name_space
                            self.ac2_encapsulation.value_namespace_prefix = name_space_prefix
                        if(value_path == "down-count"):
                            self.down_count.append(value)
                        if(value_path == "psn-type"):
                            self.psn_type = value
                            self.psn_type.value_namespace = name_space
                            self.psn_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "unresolved-count"):
                            self.unresolved_count.append(value)
                        if(value_path == "up-count"):
                            self.up_count.append(value)

                def has_data(self):
                    for c in self.encapsulation_report_matrix:
                        if (c.has_data()):
                            return True
                    for c in self.encapsulation_total:
                        if (c.has_data()):
                            return True
                    return (
                        self.main_total_down.is_set or
                        self.main_total_unresolved.is_set or
                        self.main_total_up.is_set or
                        self.memory_state.is_set or
                        self.undefined_xc.is_set)

                def has_operation(self):
                    for c in self.encapsulation_report_matrix:
                        if (c.has_operation()):
                            return True
                    for c in self.encapsulation_total:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.main_total_down.yfilter != YFilter.not_set or
                        self.main_total_unresolved.yfilter != YFilter.not_set or
                        self.main_total_up.yfilter != YFilter.not_set or
                        self.memory_state.yfilter != YFilter.not_set or
                        self.undefined_xc.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "xconnect-brief" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.main_total_down.is_set or self.main_total_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.main_total_down.get_name_leafdata())
                    if (self.main_total_unresolved.is_set or self.main_total_unresolved.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.main_total_unresolved.get_name_leafdata())
                    if (self.main_total_up.is_set or self.main_total_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.main_total_up.get_name_leafdata())
                    if (self.memory_state.is_set or self.memory_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.memory_state.get_name_leafdata())
                    if (self.undefined_xc.is_set or self.undefined_xc.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.undefined_xc.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "encapsulation-report-matrix"):
                        for c in self.encapsulation_report_matrix:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.encapsulation_report_matrix.append(c)
                        return c

                    if (child_yang_name == "encapsulation-total"):
                        for c in self.encapsulation_total:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.encapsulation_total.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "encapsulation-report-matrix" or name == "encapsulation-total" or name == "main-total-down" or name == "main-total-unresolved" or name == "main-total-up" or name == "memory-state" or name == "undefined-xc"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "main-total-down"):
                        self.main_total_down = value
                        self.main_total_down.value_namespace = name_space
                        self.main_total_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "main-total-unresolved"):
                        self.main_total_unresolved = value
                        self.main_total_unresolved.value_namespace = name_space
                        self.main_total_unresolved.value_namespace_prefix = name_space_prefix
                    if(value_path == "main-total-up"):
                        self.main_total_up = value
                        self.main_total_up.value_namespace = name_space
                        self.main_total_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "memory-state"):
                        self.memory_state = value
                        self.memory_state.value_namespace = name_space
                        self.memory_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "undefined-xc"):
                        self.undefined_xc = value
                        self.undefined_xc.value_namespace = name_space
                        self.undefined_xc.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.node_id.is_set or
                    (self.bridge_domains is not None and self.bridge_domains.has_data()) or
                    (self.bridge_summary is not None and self.bridge_summary.has_data()) or
                    (self.discoveries is not None and self.discoveries.has_data()) or
                    (self.discovery_summary is not None and self.discovery_summary.has_data()) or
                    (self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary.has_data()) or
                    (self.flexible_xconnect_services is not None and self.flexible_xconnect_services.has_data()) or
                    (self.g8032 is not None and self.g8032.has_data()) or
                    (self.generic_interface_list_details is not None and self.generic_interface_list_details.has_data()) or
                    (self.generic_interfaces is not None and self.generic_interfaces.has_data()) or
                    (self.global_settings is not None and self.global_settings.has_data()) or
                    (self.iccp_sm is not None and self.iccp_sm.has_data()) or
                    (self.indexes is not None and self.indexes.has_data()) or
                    (self.l2vpn_collaborators is not None and self.l2vpn_collaborators.has_data()) or
                    (self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa.has_data()) or
                    (self.l2vpn_resource_state is not None and self.l2vpn_resource_state.has_data()) or
                    (self.main_interfaces is not None and self.main_interfaces.has_data()) or
                    (self.mstp_ports is not None and self.mstp_ports.has_data()) or
                    (self.mstp_vlans is not None and self.mstp_vlans.has_data()) or
                    (self.mvrp is not None and self.mvrp.has_data()) or
                    (self.nsr is not None and self.nsr.has_data()) or
                    (self.proc_fsm is not None and self.proc_fsm.has_data()) or
                    (self.pseudowire_classes is not None and self.pseudowire_classes.has_data()) or
                    (self.pwr is not None and self.pwr.has_data()) or
                    (self.xconnect_brief is not None and self.xconnect_brief.has_data()) or
                    (self.xconnect_groups is not None and self.xconnect_groups.has_data()) or
                    (self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces.has_data()) or
                    (self.xconnect_mp2mps is not None and self.xconnect_mp2mps.has_data()) or
                    (self.xconnect_summary is not None and self.xconnect_summary.has_data()) or
                    (self.xconnects is not None and self.xconnects.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.node_id.yfilter != YFilter.not_set or
                    (self.bridge_domains is not None and self.bridge_domains.has_operation()) or
                    (self.bridge_summary is not None and self.bridge_summary.has_operation()) or
                    (self.discoveries is not None and self.discoveries.has_operation()) or
                    (self.discovery_summary is not None and self.discovery_summary.has_operation()) or
                    (self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary.has_operation()) or
                    (self.flexible_xconnect_services is not None and self.flexible_xconnect_services.has_operation()) or
                    (self.g8032 is not None and self.g8032.has_operation()) or
                    (self.generic_interface_list_details is not None and self.generic_interface_list_details.has_operation()) or
                    (self.generic_interfaces is not None and self.generic_interfaces.has_operation()) or
                    (self.global_settings is not None and self.global_settings.has_operation()) or
                    (self.iccp_sm is not None and self.iccp_sm.has_operation()) or
                    (self.indexes is not None and self.indexes.has_operation()) or
                    (self.l2vpn_collaborators is not None and self.l2vpn_collaborators.has_operation()) or
                    (self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa.has_operation()) or
                    (self.l2vpn_resource_state is not None and self.l2vpn_resource_state.has_operation()) or
                    (self.main_interfaces is not None and self.main_interfaces.has_operation()) or
                    (self.mstp_ports is not None and self.mstp_ports.has_operation()) or
                    (self.mstp_vlans is not None and self.mstp_vlans.has_operation()) or
                    (self.mvrp is not None and self.mvrp.has_operation()) or
                    (self.nsr is not None and self.nsr.has_operation()) or
                    (self.proc_fsm is not None and self.proc_fsm.has_operation()) or
                    (self.pseudowire_classes is not None and self.pseudowire_classes.has_operation()) or
                    (self.pwr is not None and self.pwr.has_operation()) or
                    (self.xconnect_brief is not None and self.xconnect_brief.has_operation()) or
                    (self.xconnect_groups is not None and self.xconnect_groups.has_operation()) or
                    (self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces.has_operation()) or
                    (self.xconnect_mp2mps is not None and self.xconnect_mp2mps.has_operation()) or
                    (self.xconnect_summary is not None and self.xconnect_summary.has_operation()) or
                    (self.xconnects is not None and self.xconnects.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "node" + "[node-id='" + self.node_id.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/nodes/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_id.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bridge-domains"):
                    if (self.bridge_domains is None):
                        self.bridge_domains = L2Vpnv2.Nodes.Node.BridgeDomains()
                        self.bridge_domains.parent = self
                        self._children_name_map["bridge_domains"] = "bridge-domains"
                    return self.bridge_domains

                if (child_yang_name == "bridge-summary"):
                    if (self.bridge_summary is None):
                        self.bridge_summary = L2Vpnv2.Nodes.Node.BridgeSummary()
                        self.bridge_summary.parent = self
                        self._children_name_map["bridge_summary"] = "bridge-summary"
                    return self.bridge_summary

                if (child_yang_name == "discoveries"):
                    if (self.discoveries is None):
                        self.discoveries = L2Vpnv2.Nodes.Node.Discoveries()
                        self.discoveries.parent = self
                        self._children_name_map["discoveries"] = "discoveries"
                    return self.discoveries

                if (child_yang_name == "discovery-summary"):
                    if (self.discovery_summary is None):
                        self.discovery_summary = L2Vpnv2.Nodes.Node.DiscoverySummary()
                        self.discovery_summary.parent = self
                        self._children_name_map["discovery_summary"] = "discovery-summary"
                    return self.discovery_summary

                if (child_yang_name == "flexible-xconnect-service-summary"):
                    if (self.flexible_xconnect_service_summary is None):
                        self.flexible_xconnect_service_summary = L2Vpnv2.Nodes.Node.FlexibleXconnectServiceSummary()
                        self.flexible_xconnect_service_summary.parent = self
                        self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"
                    return self.flexible_xconnect_service_summary

                if (child_yang_name == "flexible-xconnect-services"):
                    if (self.flexible_xconnect_services is None):
                        self.flexible_xconnect_services = L2Vpnv2.Nodes.Node.FlexibleXconnectServices()
                        self.flexible_xconnect_services.parent = self
                        self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"
                    return self.flexible_xconnect_services

                if (child_yang_name == "g8032"):
                    if (self.g8032 is None):
                        self.g8032 = L2Vpnv2.Nodes.Node.G8032()
                        self.g8032.parent = self
                        self._children_name_map["g8032"] = "g8032"
                    return self.g8032

                if (child_yang_name == "generic-interface-list-details"):
                    if (self.generic_interface_list_details is None):
                        self.generic_interface_list_details = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails()
                        self.generic_interface_list_details.parent = self
                        self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"
                    return self.generic_interface_list_details

                if (child_yang_name == "generic-interfaces"):
                    if (self.generic_interfaces is None):
                        self.generic_interfaces = L2Vpnv2.Nodes.Node.GenericInterfaces()
                        self.generic_interfaces.parent = self
                        self._children_name_map["generic_interfaces"] = "generic-interfaces"
                    return self.generic_interfaces

                if (child_yang_name == "global-settings"):
                    if (self.global_settings is None):
                        self.global_settings = L2Vpnv2.Nodes.Node.GlobalSettings()
                        self.global_settings.parent = self
                        self._children_name_map["global_settings"] = "global-settings"
                    return self.global_settings

                if (child_yang_name == "iccp-sm"):
                    if (self.iccp_sm is None):
                        self.iccp_sm = L2Vpnv2.Nodes.Node.IccpSm()
                        self.iccp_sm.parent = self
                        self._children_name_map["iccp_sm"] = "iccp-sm"
                    return self.iccp_sm

                if (child_yang_name == "indexes"):
                    if (self.indexes is None):
                        self.indexes = L2Vpnv2.Nodes.Node.Indexes()
                        self.indexes.parent = self
                        self._children_name_map["indexes"] = "indexes"
                    return self.indexes

                if (child_yang_name == "l2vpn-collaborators"):
                    if (self.l2vpn_collaborators is None):
                        self.l2vpn_collaborators = L2Vpnv2.Nodes.Node.L2VpnCollaborators()
                        self.l2vpn_collaborators.parent = self
                        self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"
                    return self.l2vpn_collaborators

                if (child_yang_name == "l2vpn-pbb-bsa"):
                    if (self.l2vpn_pbb_bsa is None):
                        self.l2vpn_pbb_bsa = L2Vpnv2.Nodes.Node.L2VpnPbbBsa()
                        self.l2vpn_pbb_bsa.parent = self
                        self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"
                    return self.l2vpn_pbb_bsa

                if (child_yang_name == "l2vpn-resource-state"):
                    if (self.l2vpn_resource_state is None):
                        self.l2vpn_resource_state = L2Vpnv2.Nodes.Node.L2VpnResourceState()
                        self.l2vpn_resource_state.parent = self
                        self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"
                    return self.l2vpn_resource_state

                if (child_yang_name == "main-interfaces"):
                    if (self.main_interfaces is None):
                        self.main_interfaces = L2Vpnv2.Nodes.Node.MainInterfaces()
                        self.main_interfaces.parent = self
                        self._children_name_map["main_interfaces"] = "main-interfaces"
                    return self.main_interfaces

                if (child_yang_name == "mstp-ports"):
                    if (self.mstp_ports is None):
                        self.mstp_ports = L2Vpnv2.Nodes.Node.MstpPorts()
                        self.mstp_ports.parent = self
                        self._children_name_map["mstp_ports"] = "mstp-ports"
                    return self.mstp_ports

                if (child_yang_name == "mstp-vlans"):
                    if (self.mstp_vlans is None):
                        self.mstp_vlans = L2Vpnv2.Nodes.Node.MstpVlans()
                        self.mstp_vlans.parent = self
                        self._children_name_map["mstp_vlans"] = "mstp-vlans"
                    return self.mstp_vlans

                if (child_yang_name == "mvrp"):
                    if (self.mvrp is None):
                        self.mvrp = L2Vpnv2.Nodes.Node.Mvrp()
                        self.mvrp.parent = self
                        self._children_name_map["mvrp"] = "mvrp"
                    return self.mvrp

                if (child_yang_name == "nsr"):
                    if (self.nsr is None):
                        self.nsr = L2Vpnv2.Nodes.Node.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                    return self.nsr

                if (child_yang_name == "proc-fsm"):
                    if (self.proc_fsm is None):
                        self.proc_fsm = L2Vpnv2.Nodes.Node.ProcFsm()
                        self.proc_fsm.parent = self
                        self._children_name_map["proc_fsm"] = "proc-fsm"
                    return self.proc_fsm

                if (child_yang_name == "pseudowire-classes"):
                    if (self.pseudowire_classes is None):
                        self.pseudowire_classes = L2Vpnv2.Nodes.Node.PseudowireClasses()
                        self.pseudowire_classes.parent = self
                        self._children_name_map["pseudowire_classes"] = "pseudowire-classes"
                    return self.pseudowire_classes

                if (child_yang_name == "pwr"):
                    if (self.pwr is None):
                        self.pwr = L2Vpnv2.Nodes.Node.Pwr()
                        self.pwr.parent = self
                        self._children_name_map["pwr"] = "pwr"
                    return self.pwr

                if (child_yang_name == "xconnect-brief"):
                    if (self.xconnect_brief is None):
                        self.xconnect_brief = L2Vpnv2.Nodes.Node.XconnectBrief()
                        self.xconnect_brief.parent = self
                        self._children_name_map["xconnect_brief"] = "xconnect-brief"
                    return self.xconnect_brief

                if (child_yang_name == "xconnect-groups"):
                    if (self.xconnect_groups is None):
                        self.xconnect_groups = L2Vpnv2.Nodes.Node.XconnectGroups()
                        self.xconnect_groups.parent = self
                        self._children_name_map["xconnect_groups"] = "xconnect-groups"
                    return self.xconnect_groups

                if (child_yang_name == "xconnect-mp2mp-ce2ces"):
                    if (self.xconnect_mp2mp_ce2ces is None):
                        self.xconnect_mp2mp_ce2ces = L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces()
                        self.xconnect_mp2mp_ce2ces.parent = self
                        self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"
                    return self.xconnect_mp2mp_ce2ces

                if (child_yang_name == "xconnect-mp2mps"):
                    if (self.xconnect_mp2mps is None):
                        self.xconnect_mp2mps = L2Vpnv2.Nodes.Node.XconnectMp2Mps()
                        self.xconnect_mp2mps.parent = self
                        self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"
                    return self.xconnect_mp2mps

                if (child_yang_name == "xconnect-summary"):
                    if (self.xconnect_summary is None):
                        self.xconnect_summary = L2Vpnv2.Nodes.Node.XconnectSummary()
                        self.xconnect_summary.parent = self
                        self._children_name_map["xconnect_summary"] = "xconnect-summary"
                    return self.xconnect_summary

                if (child_yang_name == "xconnects"):
                    if (self.xconnects is None):
                        self.xconnects = L2Vpnv2.Nodes.Node.Xconnects()
                        self.xconnects.parent = self
                        self._children_name_map["xconnects"] = "xconnects"
                    return self.xconnects

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bridge-domains" or name == "bridge-summary" or name == "discoveries" or name == "discovery-summary" or name == "flexible-xconnect-service-summary" or name == "flexible-xconnect-services" or name == "g8032" or name == "generic-interface-list-details" or name == "generic-interfaces" or name == "global-settings" or name == "iccp-sm" or name == "indexes" or name == "l2vpn-collaborators" or name == "l2vpn-pbb-bsa" or name == "l2vpn-resource-state" or name == "main-interfaces" or name == "mstp-ports" or name == "mstp-vlans" or name == "mvrp" or name == "nsr" or name == "proc-fsm" or name == "pseudowire-classes" or name == "pwr" or name == "xconnect-brief" or name == "xconnect-groups" or name == "xconnect-mp2mp-ce2ces" or name == "xconnect-mp2mps" or name == "xconnect-summary" or name == "xconnects" or name == "node-id"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "node-id"):
                    self.node_id = value
                    self.node_id.value_namespace = name_space
                    self.node_id.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.node:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.node:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "nodes" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "node"):
                for c in self.node:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpnv2.Nodes.Node()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.node.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "node"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.active is not None and self.active.has_data()) or
            (self.nodes is not None and self.nodes.has_data()) or
            (self.standby is not None and self.standby.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.active is not None and self.active.has_operation()) or
            (self.nodes is not None and self.nodes.has_operation()) or
            (self.standby is not None and self.standby.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpnv2" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "active"):
            if (self.active is None):
                self.active = L2Vpnv2.Active()
                self.active.parent = self
                self._children_name_map["active"] = "active"
            return self.active

        if (child_yang_name == "nodes"):
            if (self.nodes is None):
                self.nodes = L2Vpnv2.Nodes()
                self.nodes.parent = self
                self._children_name_map["nodes"] = "nodes"
            return self.nodes

        if (child_yang_name == "standby"):
            if (self.standby is None):
                self.standby = L2Vpnv2.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"
            return self.standby

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "active" or name == "nodes" or name == "standby"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = L2Vpnv2()
        return self._top_entity

class L2Vpn(Entity):
    """
    l2vpn
    
    .. attribute:: bridge_domains
    
    	VPLS Bridge Domain Information
    	**type**\:   :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains>`
    
    .. attribute:: bridge_summary
    
    	Bridge Domain summary information
    	**type**\:   :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeSummary>`
    
    .. attribute:: discoveries
    
    	Discovery Table
    	**type**\:   :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries>`
    
    .. attribute:: discovery_summary
    
    	Discovery summary information
    	**type**\:   :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.DiscoverySummary>`
    
    .. attribute:: flexible_xconnect_service_summary
    
    	Flexible XConnect Service summary information
    	**type**\:   :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServiceSummary>`
    
    .. attribute:: flexible_xconnect_services
    
    	Flexible XConnect Service Table
    	**type**\:   :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices>`
    
    .. attribute:: g8032
    
    	G8032 information
    	**type**\:   :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032>`
    
    .. attribute:: generic_interface_list_details
    
    	L2VPN generic interface list Detail Table
    	**type**\:   :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails>`
    
    .. attribute:: generic_interfaces
    
    	L2VPN generic interface list Table
    	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaces>`
    
    .. attribute:: global_settings
    
    	L2VPN global settings
    	**type**\:   :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GlobalSettings>`
    
    .. attribute:: iccp_sm
    
    	ICCP\-based Service Multi\-homing operational data
    	**type**\:   :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm>`
    
    .. attribute:: indexes
    
    	ID Manager Index Table
    	**type**\:   :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Indexes>`
    
    .. attribute:: l2vpn_collaborators
    
    	L2VPN collaborator information
    	**type**\:   :py:class:`L2VpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.L2VpnCollaborators>`
    
    .. attribute:: l2vpn_pbb_bsa
    
    	L2VPN PBB Backbone Source MAC information
    	**type**\:   :py:class:`L2VpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.L2VpnPbbBsa>`
    
    .. attribute:: l2vpn_resource_state
    
    	L2VPN resource state information
    	**type**\:   :py:class:`L2VpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.L2VpnResourceState>`
    
    .. attribute:: main_interfaces
    
    	Main Interface
    	**type**\:   :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces>`
    
    .. attribute:: mstp_ports
    
    	L2VPN MSTP Port Table
    	**type**\:   :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpPorts>`
    
    .. attribute:: mstp_vlans
    
    	L2VPN MSTP VLAN Table
    	**type**\:   :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpVlans>`
    
    .. attribute:: mvrp
    
    	MVRP
    	**type**\:   :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp>`
    
    .. attribute:: nsr
    
    	L2VPN NSR information
    	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr>`
    
    .. attribute:: proc_fsm
    
    	L2VPN Process FSM information
    	**type**\:   :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm>`
    
    .. attribute:: pseudowire_classes
    
    	List of pseudowire classes
    	**type**\:   :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses>`
    
    .. attribute:: pseudowire_headend
    
    	Pseudowire Headend related operational data
    	**type**\:   :py:class:`PseudowireHeadend <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend>`
    
    .. attribute:: pwr
    
    	Pseudowire Routing Table
    	**type**\:   :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr>`
    
    .. attribute:: xconnect_brief
    
    	XConnect brief information
    	**type**\:   :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectBrief>`
    
    .. attribute:: xconnect_groups
    
    	XConnect group Table
    	**type**\:   :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectGroups>`
    
    .. attribute:: xconnect_mp2mp_ce2ces
    
    	XConnect MP2MP CE2CE Table
    	**type**\:   :py:class:`XconnectMp2MpCe2Ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2MpCe2Ces>`
    
    .. attribute:: xconnect_mp2mps
    
    	XConnect MP2MP Table
    	**type**\:   :py:class:`XconnectMp2Mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps>`
    
    .. attribute:: xconnect_summary
    
    	XConnect summary information
    	**type**\:   :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectSummary>`
    
    .. attribute:: xconnects
    
    	XConnect Table
    	**type**\:   :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(L2Vpn, self).__init__()
        self._top_entity = None

        self.yang_name = "l2vpn"
        self.yang_parent_name = "Cisco-IOS-XR-l2vpn-oper"

        self.bridge_domains = L2Vpn.BridgeDomains()
        self.bridge_domains.parent = self
        self._children_name_map["bridge_domains"] = "bridge-domains"
        self._children_yang_names.add("bridge-domains")

        self.bridge_summary = L2Vpn.BridgeSummary()
        self.bridge_summary.parent = self
        self._children_name_map["bridge_summary"] = "bridge-summary"
        self._children_yang_names.add("bridge-summary")

        self.discoveries = L2Vpn.Discoveries()
        self.discoveries.parent = self
        self._children_name_map["discoveries"] = "discoveries"
        self._children_yang_names.add("discoveries")

        self.discovery_summary = L2Vpn.DiscoverySummary()
        self.discovery_summary.parent = self
        self._children_name_map["discovery_summary"] = "discovery-summary"
        self._children_yang_names.add("discovery-summary")

        self.flexible_xconnect_service_summary = L2Vpn.FlexibleXconnectServiceSummary()
        self.flexible_xconnect_service_summary.parent = self
        self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"
        self._children_yang_names.add("flexible-xconnect-service-summary")

        self.flexible_xconnect_services = L2Vpn.FlexibleXconnectServices()
        self.flexible_xconnect_services.parent = self
        self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"
        self._children_yang_names.add("flexible-xconnect-services")

        self.g8032 = L2Vpn.G8032()
        self.g8032.parent = self
        self._children_name_map["g8032"] = "g8032"
        self._children_yang_names.add("g8032")

        self.generic_interface_list_details = L2Vpn.GenericInterfaceListDetails()
        self.generic_interface_list_details.parent = self
        self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"
        self._children_yang_names.add("generic-interface-list-details")

        self.generic_interfaces = L2Vpn.GenericInterfaces()
        self.generic_interfaces.parent = self
        self._children_name_map["generic_interfaces"] = "generic-interfaces"
        self._children_yang_names.add("generic-interfaces")

        self.global_settings = L2Vpn.GlobalSettings()
        self.global_settings.parent = self
        self._children_name_map["global_settings"] = "global-settings"
        self._children_yang_names.add("global-settings")

        self.iccp_sm = L2Vpn.IccpSm()
        self.iccp_sm.parent = self
        self._children_name_map["iccp_sm"] = "iccp-sm"
        self._children_yang_names.add("iccp-sm")

        self.indexes = L2Vpn.Indexes()
        self.indexes.parent = self
        self._children_name_map["indexes"] = "indexes"
        self._children_yang_names.add("indexes")

        self.l2vpn_collaborators = L2Vpn.L2VpnCollaborators()
        self.l2vpn_collaborators.parent = self
        self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"
        self._children_yang_names.add("l2vpn-collaborators")

        self.l2vpn_pbb_bsa = L2Vpn.L2VpnPbbBsa()
        self.l2vpn_pbb_bsa.parent = self
        self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"
        self._children_yang_names.add("l2vpn-pbb-bsa")

        self.l2vpn_resource_state = L2Vpn.L2VpnResourceState()
        self.l2vpn_resource_state.parent = self
        self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"
        self._children_yang_names.add("l2vpn-resource-state")

        self.main_interfaces = L2Vpn.MainInterfaces()
        self.main_interfaces.parent = self
        self._children_name_map["main_interfaces"] = "main-interfaces"
        self._children_yang_names.add("main-interfaces")

        self.mstp_ports = L2Vpn.MstpPorts()
        self.mstp_ports.parent = self
        self._children_name_map["mstp_ports"] = "mstp-ports"
        self._children_yang_names.add("mstp-ports")

        self.mstp_vlans = L2Vpn.MstpVlans()
        self.mstp_vlans.parent = self
        self._children_name_map["mstp_vlans"] = "mstp-vlans"
        self._children_yang_names.add("mstp-vlans")

        self.mvrp = L2Vpn.Mvrp()
        self.mvrp.parent = self
        self._children_name_map["mvrp"] = "mvrp"
        self._children_yang_names.add("mvrp")

        self.nsr = L2Vpn.Nsr()
        self.nsr.parent = self
        self._children_name_map["nsr"] = "nsr"
        self._children_yang_names.add("nsr")

        self.proc_fsm = L2Vpn.ProcFsm()
        self.proc_fsm.parent = self
        self._children_name_map["proc_fsm"] = "proc-fsm"
        self._children_yang_names.add("proc-fsm")

        self.pseudowire_classes = L2Vpn.PseudowireClasses()
        self.pseudowire_classes.parent = self
        self._children_name_map["pseudowire_classes"] = "pseudowire-classes"
        self._children_yang_names.add("pseudowire-classes")

        self.pseudowire_headend = L2Vpn.PseudowireHeadend()
        self.pseudowire_headend.parent = self
        self._children_name_map["pseudowire_headend"] = "pseudowire-headend"
        self._children_yang_names.add("pseudowire-headend")

        self.pwr = L2Vpn.Pwr()
        self.pwr.parent = self
        self._children_name_map["pwr"] = "pwr"
        self._children_yang_names.add("pwr")

        self.xconnect_brief = L2Vpn.XconnectBrief()
        self.xconnect_brief.parent = self
        self._children_name_map["xconnect_brief"] = "xconnect-brief"
        self._children_yang_names.add("xconnect-brief")

        self.xconnect_groups = L2Vpn.XconnectGroups()
        self.xconnect_groups.parent = self
        self._children_name_map["xconnect_groups"] = "xconnect-groups"
        self._children_yang_names.add("xconnect-groups")

        self.xconnect_mp2mp_ce2ces = L2Vpn.XconnectMp2MpCe2Ces()
        self.xconnect_mp2mp_ce2ces.parent = self
        self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"
        self._children_yang_names.add("xconnect-mp2mp-ce2ces")

        self.xconnect_mp2mps = L2Vpn.XconnectMp2Mps()
        self.xconnect_mp2mps.parent = self
        self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"
        self._children_yang_names.add("xconnect-mp2mps")

        self.xconnect_summary = L2Vpn.XconnectSummary()
        self.xconnect_summary.parent = self
        self._children_name_map["xconnect_summary"] = "xconnect-summary"
        self._children_yang_names.add("xconnect-summary")

        self.xconnects = L2Vpn.Xconnects()
        self.xconnects.parent = self
        self._children_name_map["xconnects"] = "xconnects"
        self._children_yang_names.add("xconnects")


    class PseudowireHeadend(Entity):
        """
        Pseudowire Headend related operational data
        
        .. attribute:: detail_interfaces
        
        	PW\-HE Interfaces
        	**type**\:   :py:class:`DetailInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces>`
        
        .. attribute:: summary
        
        	PW\-HE interface summary
        	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.Summary>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.PseudowireHeadend, self).__init__()

            self.yang_name = "pseudowire-headend"
            self.yang_parent_name = "l2vpn"

            self.detail_interfaces = L2Vpn.PseudowireHeadend.DetailInterfaces()
            self.detail_interfaces.parent = self
            self._children_name_map["detail_interfaces"] = "detail-interfaces"
            self._children_yang_names.add("detail-interfaces")

            self.summary = L2Vpn.PseudowireHeadend.Summary()
            self.summary.parent = self
            self._children_name_map["summary"] = "summary"
            self._children_yang_names.add("summary")


        class DetailInterfaces(Entity):
            """
            PW\-HE Interfaces
            
            .. attribute:: detail_interface
            
            	PW\-HE Interface detail
            	**type**\: list of    :py:class:`DetailInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.PseudowireHeadend.DetailInterfaces, self).__init__()

                self.yang_name = "detail-interfaces"
                self.yang_parent_name = "pseudowire-headend"

                self.detail_interface = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.PseudowireHeadend.DetailInterfaces, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.PseudowireHeadend.DetailInterfaces, self).__setattr__(name, value)


            class DetailInterface(Entity):
                """
                PW\-HE Interface detail
                
                .. attribute:: interface_name  <key>
                
                	PWHE Interface name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: admin_state
                
                	Interface Admin Status
                	**type**\:   :py:class:`PwhePortImState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.PwhePortImState>`
                
                .. attribute:: bandwidth
                
                	Bandwidth (Kbps)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: kbit/s
                
                .. attribute:: control_word
                
                	Control Word
                	**type**\:  bool
                
                .. attribute:: generic_interface_list
                
                	Generic Interface List
                	**type**\:   :py:class:`GenericInterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList>`
                
                .. attribute:: interface_state
                
                	Interface Status
                	**type**\:   :py:class:`PwhePortImState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.PwhePortImState>`
                
                .. attribute:: l2_address
                
                	Layer2 Address
                	**type**\:   :py:class:`L2Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address>`
                
                .. attribute:: l2_overhead
                
                	L2 Overhead
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: label
                
                	Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mtu
                
                	MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vctype
                
                	VC Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface, self).__init__()

                    self.yang_name = "detail-interface"
                    self.yang_parent_name = "detail-interfaces"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.admin_state = YLeaf(YType.enumeration, "admin-state")

                    self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                    self.control_word = YLeaf(YType.boolean, "control-word")

                    self.interface_state = YLeaf(YType.enumeration, "interface-state")

                    self.l2_overhead = YLeaf(YType.uint32, "l2-overhead")

                    self.label = YLeaf(YType.uint32, "label")

                    self.mtu = YLeaf(YType.uint32, "mtu")

                    self.vctype = YLeaf(YType.uint32, "vctype")

                    self.generic_interface_list = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList()
                    self.generic_interface_list.parent = self
                    self._children_name_map["generic_interface_list"] = "generic-interface-list"
                    self._children_yang_names.add("generic-interface-list")

                    self.l2_address = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address()
                    self.l2_address.parent = self
                    self._children_name_map["l2_address"] = "l2-address"
                    self._children_yang_names.add("l2-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "admin_state",
                                    "bandwidth",
                                    "control_word",
                                    "interface_state",
                                    "l2_overhead",
                                    "label",
                                    "mtu",
                                    "vctype") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface, self).__setattr__(name, value)


                class L2Address(Entity):
                    """
                    Layer2 Address
                    
                    .. attribute:: interface_type
                    
                    	InterfaceType
                    	**type**\:   :py:class:`L2VpnPwheIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwheIntf>`
                    
                    .. attribute:: mac_address
                    
                    	MAC address
                    	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address.MacAddress>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address, self).__init__()

                        self.yang_name = "l2-address"
                        self.yang_parent_name = "detail-interface"

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.mac_address = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"
                        self._children_yang_names.add("mac-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address, self).__setattr__(name, value)


                    class MacAddress(Entity):
                        """
                        MAC address
                        
                        .. attribute:: mac_address
                        
                        	MAC Address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "l2-address"

                            self.mac_address = YLeaf(YType.str, "mac-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mac_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address.MacAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address.MacAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return self.mac_address.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mac_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mac-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mac_address.is_set or self.mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mac-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mac-address"):
                                self.mac_address = value
                                self.mac_address.value_namespace = name_space
                                self.mac_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_type.is_set or
                            (self.mac_address is not None and self.mac_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_type.yfilter != YFilter.not_set or
                            (self.mac_address is not None and self.mac_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mac-address"):
                            if (self.mac_address is None):
                                self.mac_address = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                            return self.mac_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mac-address" or name == "interface-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-type"):
                            self.interface_type = value
                            self.interface_type.value_namespace = name_space
                            self.interface_type.value_namespace_prefix = name_space_prefix


                class GenericInterfaceList(Entity):
                    """
                    Generic Interface List
                    
                    .. attribute:: generic_interface_list_name
                    
                    	Generic interface list name
                    	**type**\:  str
                    
                    .. attribute:: id
                    
                    	Generic interface list ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_detail
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`InterfaceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList.InterfaceDetail>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList, self).__init__()

                        self.yang_name = "generic-interface-list"
                        self.yang_parent_name = "detail-interface"

                        self.generic_interface_list_name = YLeaf(YType.str, "generic-interface-list-name")

                        self.id = YLeaf(YType.uint32, "id")

                        self.interface_detail = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_interface_list_name",
                                        "id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList, self).__setattr__(name, value)


                    class InterfaceDetail(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: bundle_interface_name
                        
                        	Bundle Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_state
                        
                        	Interface Status
                        	**type**\:   :py:class:`PwhePortImState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.PwhePortImState>`
                        
                        .. attribute:: misconfigured
                        
                        	Interface misconfigured
                        	**type**\:  bool
                        
                        .. attribute:: replicate_state
                        
                        	Replication status
                        	**type**\:   :py:class:`L2VpnPwheIflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwheIflistRepStatus>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList.InterfaceDetail, self).__init__()

                            self.yang_name = "interface-detail"
                            self.yang_parent_name = "generic-interface-list"

                            self.bundle_interface_name = YLeaf(YType.str, "bundle-interface-name")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_state = YLeaf(YType.enumeration, "interface-state")

                            self.misconfigured = YLeaf(YType.boolean, "misconfigured")

                            self.replicate_state = YLeaf(YType.enumeration, "replicate-state")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bundle_interface_name",
                                            "interface_name",
                                            "interface_state",
                                            "misconfigured",
                                            "replicate_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList.InterfaceDetail, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList.InterfaceDetail, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bundle_interface_name.is_set or
                                self.interface_name.is_set or
                                self.interface_state.is_set or
                                self.misconfigured.is_set or
                                self.replicate_state.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bundle_interface_name.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_state.yfilter != YFilter.not_set or
                                self.misconfigured.yfilter != YFilter.not_set or
                                self.replicate_state.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-detail" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bundle_interface_name.is_set or self.bundle_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_interface_name.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_state.is_set or self.interface_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_state.get_name_leafdata())
                            if (self.misconfigured.is_set or self.misconfigured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.misconfigured.get_name_leafdata())
                            if (self.replicate_state.is_set or self.replicate_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.replicate_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-interface-name" or name == "interface-name" or name == "interface-state" or name == "misconfigured" or name == "replicate-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bundle-interface-name"):
                                self.bundle_interface_name = value
                                self.bundle_interface_name.value_namespace = name_space
                                self.bundle_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-state"):
                                self.interface_state = value
                                self.interface_state.value_namespace = name_space
                                self.interface_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "misconfigured"):
                                self.misconfigured = value
                                self.misconfigured.value_namespace = name_space
                                self.misconfigured.value_namespace_prefix = name_space_prefix
                            if(value_path == "replicate-state"):
                                self.replicate_state = value
                                self.replicate_state.value_namespace = name_space
                                self.replicate_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_detail:
                            if (c.has_data()):
                                return True
                        return (
                            self.generic_interface_list_name.is_set or
                            self.id.is_set)

                    def has_operation(self):
                        for c in self.interface_detail:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_interface_list_name.yfilter != YFilter.not_set or
                            self.id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-interface-list" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_interface_list_name.is_set or self.generic_interface_list_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_interface_list_name.get_name_leafdata())
                        if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-detail"):
                            for c in self.interface_detail:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList.InterfaceDetail()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_detail.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-detail" or name == "generic-interface-list-name" or name == "id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-interface-list-name"):
                            self.generic_interface_list_name = value
                            self.generic_interface_list_name.value_namespace = name_space
                            self.generic_interface_list_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "id"):
                            self.id = value
                            self.id.value_namespace = name_space
                            self.id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.admin_state.is_set or
                        self.bandwidth.is_set or
                        self.control_word.is_set or
                        self.interface_state.is_set or
                        self.l2_overhead.is_set or
                        self.label.is_set or
                        self.mtu.is_set or
                        self.vctype.is_set or
                        (self.generic_interface_list is not None and self.generic_interface_list.has_data()) or
                        (self.l2_address is not None and self.l2_address.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.admin_state.yfilter != YFilter.not_set or
                        self.bandwidth.yfilter != YFilter.not_set or
                        self.control_word.yfilter != YFilter.not_set or
                        self.interface_state.yfilter != YFilter.not_set or
                        self.l2_overhead.yfilter != YFilter.not_set or
                        self.label.yfilter != YFilter.not_set or
                        self.mtu.yfilter != YFilter.not_set or
                        self.vctype.yfilter != YFilter.not_set or
                        (self.generic_interface_list is not None and self.generic_interface_list.has_operation()) or
                        (self.l2_address is not None and self.l2_address.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "detail-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pseudowire-headend/detail-interfaces/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.admin_state.is_set or self.admin_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.admin_state.get_name_leafdata())
                    if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bandwidth.get_name_leafdata())
                    if (self.control_word.is_set or self.control_word.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.control_word.get_name_leafdata())
                    if (self.interface_state.is_set or self.interface_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_state.get_name_leafdata())
                    if (self.l2_overhead.is_set or self.l2_overhead.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.l2_overhead.get_name_leafdata())
                    if (self.label.is_set or self.label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.label.get_name_leafdata())
                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mtu.get_name_leafdata())
                    if (self.vctype.is_set or self.vctype.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vctype.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "generic-interface-list"):
                        if (self.generic_interface_list is None):
                            self.generic_interface_list = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList()
                            self.generic_interface_list.parent = self
                            self._children_name_map["generic_interface_list"] = "generic-interface-list"
                        return self.generic_interface_list

                    if (child_yang_name == "l2-address"):
                        if (self.l2_address is None):
                            self.l2_address = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address()
                            self.l2_address.parent = self
                            self._children_name_map["l2_address"] = "l2-address"
                        return self.l2_address

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "generic-interface-list" or name == "l2-address" or name == "interface-name" or name == "admin-state" or name == "bandwidth" or name == "control-word" or name == "interface-state" or name == "l2-overhead" or name == "label" or name == "mtu" or name == "vctype"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "admin-state"):
                        self.admin_state = value
                        self.admin_state.value_namespace = name_space
                        self.admin_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "bandwidth"):
                        self.bandwidth = value
                        self.bandwidth.value_namespace = name_space
                        self.bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "control-word"):
                        self.control_word = value
                        self.control_word.value_namespace = name_space
                        self.control_word.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-state"):
                        self.interface_state = value
                        self.interface_state.value_namespace = name_space
                        self.interface_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "l2-overhead"):
                        self.l2_overhead = value
                        self.l2_overhead.value_namespace = name_space
                        self.l2_overhead.value_namespace_prefix = name_space_prefix
                    if(value_path == "label"):
                        self.label = value
                        self.label.value_namespace = name_space
                        self.label.value_namespace_prefix = name_space_prefix
                    if(value_path == "mtu"):
                        self.mtu = value
                        self.mtu.value_namespace = name_space
                        self.mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "vctype"):
                        self.vctype = value
                        self.vctype.value_namespace = name_space
                        self.vctype.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.detail_interface:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.detail_interface:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "detail-interfaces" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pseudowire-headend/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "detail-interface"):
                    for c in self.detail_interface:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.detail_interface.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "detail-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Summary(Entity):
            """
            PW\-HE interface summary
            
            .. attribute:: admin_down_interfaces
            
            	Number of interfaces admin down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_pseudowire_ether_interfaces
            
            	Number of PW\-Ether interfaces admin down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_pseudowire_iw_interfaces
            
            	Number of PW\-IW interfaces admin down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_interfaces
            
            	Number of interfaces down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_pseudowire_ether_interfaces
            
            	Number of PW\-Ether interfaces down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_pseudowire_iw_interfaces
            
            	Number of PW\-IW interfaces down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interfaces
            
            	Number of PW\-HE interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pseudowire_iw_interfaces
            
            	Number of PW\-IW interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: psuedowire_ether_interfaces
            
            	Number of PW\-Ether interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_interfaces
            
            	Number of interfaces up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_pseudowire_iw_interfaces
            
            	Number of PW\-IW interfaces up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_psuedowire_ether_interfaces
            
            	Number of PW\-Ether interfaces up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.PseudowireHeadend.Summary, self).__init__()

                self.yang_name = "summary"
                self.yang_parent_name = "pseudowire-headend"

                self.admin_down_interfaces = YLeaf(YType.uint32, "admin-down-interfaces")

                self.admin_down_pseudowire_ether_interfaces = YLeaf(YType.uint32, "admin-down-pseudowire-ether-interfaces")

                self.admin_down_pseudowire_iw_interfaces = YLeaf(YType.uint32, "admin-down-pseudowire-iw-interfaces")

                self.down_interfaces = YLeaf(YType.uint32, "down-interfaces")

                self.down_pseudowire_ether_interfaces = YLeaf(YType.uint32, "down-pseudowire-ether-interfaces")

                self.down_pseudowire_iw_interfaces = YLeaf(YType.uint32, "down-pseudowire-iw-interfaces")

                self.interfaces = YLeaf(YType.uint32, "interfaces")

                self.pseudowire_iw_interfaces = YLeaf(YType.uint32, "pseudowire-iw-interfaces")

                self.psuedowire_ether_interfaces = YLeaf(YType.uint32, "psuedowire-ether-interfaces")

                self.up_interfaces = YLeaf(YType.uint32, "up-interfaces")

                self.up_pseudowire_iw_interfaces = YLeaf(YType.uint32, "up-pseudowire-iw-interfaces")

                self.up_psuedowire_ether_interfaces = YLeaf(YType.uint32, "up-psuedowire-ether-interfaces")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("admin_down_interfaces",
                                "admin_down_pseudowire_ether_interfaces",
                                "admin_down_pseudowire_iw_interfaces",
                                "down_interfaces",
                                "down_pseudowire_ether_interfaces",
                                "down_pseudowire_iw_interfaces",
                                "interfaces",
                                "pseudowire_iw_interfaces",
                                "psuedowire_ether_interfaces",
                                "up_interfaces",
                                "up_pseudowire_iw_interfaces",
                                "up_psuedowire_ether_interfaces") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.PseudowireHeadend.Summary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.PseudowireHeadend.Summary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.admin_down_interfaces.is_set or
                    self.admin_down_pseudowire_ether_interfaces.is_set or
                    self.admin_down_pseudowire_iw_interfaces.is_set or
                    self.down_interfaces.is_set or
                    self.down_pseudowire_ether_interfaces.is_set or
                    self.down_pseudowire_iw_interfaces.is_set or
                    self.interfaces.is_set or
                    self.pseudowire_iw_interfaces.is_set or
                    self.psuedowire_ether_interfaces.is_set or
                    self.up_interfaces.is_set or
                    self.up_pseudowire_iw_interfaces.is_set or
                    self.up_psuedowire_ether_interfaces.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.admin_down_interfaces.yfilter != YFilter.not_set or
                    self.admin_down_pseudowire_ether_interfaces.yfilter != YFilter.not_set or
                    self.admin_down_pseudowire_iw_interfaces.yfilter != YFilter.not_set or
                    self.down_interfaces.yfilter != YFilter.not_set or
                    self.down_pseudowire_ether_interfaces.yfilter != YFilter.not_set or
                    self.down_pseudowire_iw_interfaces.yfilter != YFilter.not_set or
                    self.interfaces.yfilter != YFilter.not_set or
                    self.pseudowire_iw_interfaces.yfilter != YFilter.not_set or
                    self.psuedowire_ether_interfaces.yfilter != YFilter.not_set or
                    self.up_interfaces.yfilter != YFilter.not_set or
                    self.up_pseudowire_iw_interfaces.yfilter != YFilter.not_set or
                    self.up_psuedowire_ether_interfaces.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pseudowire-headend/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.admin_down_interfaces.is_set or self.admin_down_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.admin_down_interfaces.get_name_leafdata())
                if (self.admin_down_pseudowire_ether_interfaces.is_set or self.admin_down_pseudowire_ether_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.admin_down_pseudowire_ether_interfaces.get_name_leafdata())
                if (self.admin_down_pseudowire_iw_interfaces.is_set or self.admin_down_pseudowire_iw_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.admin_down_pseudowire_iw_interfaces.get_name_leafdata())
                if (self.down_interfaces.is_set or self.down_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.down_interfaces.get_name_leafdata())
                if (self.down_pseudowire_ether_interfaces.is_set or self.down_pseudowire_ether_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.down_pseudowire_ether_interfaces.get_name_leafdata())
                if (self.down_pseudowire_iw_interfaces.is_set or self.down_pseudowire_iw_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.down_pseudowire_iw_interfaces.get_name_leafdata())
                if (self.interfaces.is_set or self.interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interfaces.get_name_leafdata())
                if (self.pseudowire_iw_interfaces.is_set or self.pseudowire_iw_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pseudowire_iw_interfaces.get_name_leafdata())
                if (self.psuedowire_ether_interfaces.is_set or self.psuedowire_ether_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.psuedowire_ether_interfaces.get_name_leafdata())
                if (self.up_interfaces.is_set or self.up_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.up_interfaces.get_name_leafdata())
                if (self.up_pseudowire_iw_interfaces.is_set or self.up_pseudowire_iw_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.up_pseudowire_iw_interfaces.get_name_leafdata())
                if (self.up_psuedowire_ether_interfaces.is_set or self.up_psuedowire_ether_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.up_psuedowire_ether_interfaces.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "admin-down-interfaces" or name == "admin-down-pseudowire-ether-interfaces" or name == "admin-down-pseudowire-iw-interfaces" or name == "down-interfaces" or name == "down-pseudowire-ether-interfaces" or name == "down-pseudowire-iw-interfaces" or name == "interfaces" or name == "pseudowire-iw-interfaces" or name == "psuedowire-ether-interfaces" or name == "up-interfaces" or name == "up-pseudowire-iw-interfaces" or name == "up-psuedowire-ether-interfaces"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "admin-down-interfaces"):
                    self.admin_down_interfaces = value
                    self.admin_down_interfaces.value_namespace = name_space
                    self.admin_down_interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "admin-down-pseudowire-ether-interfaces"):
                    self.admin_down_pseudowire_ether_interfaces = value
                    self.admin_down_pseudowire_ether_interfaces.value_namespace = name_space
                    self.admin_down_pseudowire_ether_interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "admin-down-pseudowire-iw-interfaces"):
                    self.admin_down_pseudowire_iw_interfaces = value
                    self.admin_down_pseudowire_iw_interfaces.value_namespace = name_space
                    self.admin_down_pseudowire_iw_interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "down-interfaces"):
                    self.down_interfaces = value
                    self.down_interfaces.value_namespace = name_space
                    self.down_interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "down-pseudowire-ether-interfaces"):
                    self.down_pseudowire_ether_interfaces = value
                    self.down_pseudowire_ether_interfaces.value_namespace = name_space
                    self.down_pseudowire_ether_interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "down-pseudowire-iw-interfaces"):
                    self.down_pseudowire_iw_interfaces = value
                    self.down_pseudowire_iw_interfaces.value_namespace = name_space
                    self.down_pseudowire_iw_interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "interfaces"):
                    self.interfaces = value
                    self.interfaces.value_namespace = name_space
                    self.interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "pseudowire-iw-interfaces"):
                    self.pseudowire_iw_interfaces = value
                    self.pseudowire_iw_interfaces.value_namespace = name_space
                    self.pseudowire_iw_interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "psuedowire-ether-interfaces"):
                    self.psuedowire_ether_interfaces = value
                    self.psuedowire_ether_interfaces.value_namespace = name_space
                    self.psuedowire_ether_interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "up-interfaces"):
                    self.up_interfaces = value
                    self.up_interfaces.value_namespace = name_space
                    self.up_interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "up-pseudowire-iw-interfaces"):
                    self.up_pseudowire_iw_interfaces = value
                    self.up_pseudowire_iw_interfaces.value_namespace = name_space
                    self.up_pseudowire_iw_interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "up-psuedowire-ether-interfaces"):
                    self.up_psuedowire_ether_interfaces = value
                    self.up_psuedowire_ether_interfaces.value_namespace = name_space
                    self.up_psuedowire_ether_interfaces.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                (self.detail_interfaces is not None and self.detail_interfaces.has_data()) or
                (self.summary is not None and self.summary.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.detail_interfaces is not None and self.detail_interfaces.has_operation()) or
                (self.summary is not None and self.summary.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "pseudowire-headend" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "detail-interfaces"):
                if (self.detail_interfaces is None):
                    self.detail_interfaces = L2Vpn.PseudowireHeadend.DetailInterfaces()
                    self.detail_interfaces.parent = self
                    self._children_name_map["detail_interfaces"] = "detail-interfaces"
                return self.detail_interfaces

            if (child_yang_name == "summary"):
                if (self.summary is None):
                    self.summary = L2Vpn.PseudowireHeadend.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                return self.summary

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "detail-interfaces" or name == "summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Discoveries(Entity):
        """
        Discovery Table
        
        .. attribute:: discovery
        
        	VPLS Discovery information
        	**type**\: list of    :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.Discoveries, self).__init__()

            self.yang_name = "discoveries"
            self.yang_parent_name = "l2vpn"

            self.discovery = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.Discoveries, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.Discoveries, self).__setattr__(name, value)


        class Discovery(Entity):
            """
            VPLS Discovery information
            
            .. attribute:: group_name
            
            	Group Name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: group_name_xr
            
            	Group name
            	**type**\:  str
            
            .. attribute:: is_service_connected
            
            	Is the service connected
            	**type**\:  bool
            
            .. attribute:: mtu_mismatch_ignore
            
            	Ignore MTU Mismatch
            	**type**\:  bool
            
            .. attribute:: number_vpn
            
            	Number of vpns
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: service_name
            
            	Service type
            	**type**\:   :py:class:`L2VpnService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnService>`
            
            .. attribute:: service_name_xr
            
            	Service Type
            	**type**\:  str
            
            .. attribute:: signalling_info
            
            	Info about signalling protocol
            	**type**\:   :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo>`
            
            .. attribute:: vpn_id
            
            	VPN id
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: vpn_name
            
            	VPN Name
            	**type**\:  str
            
            	**length:** 1..27
            
            .. attribute:: vpn_name_xr
            
            	VPN instance name
            	**type**\:  str
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Discoveries.Discovery, self).__init__()

                self.yang_name = "discovery"
                self.yang_parent_name = "discoveries"

                self.group_name = YLeaf(YType.str, "group-name")

                self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                self.is_service_connected = YLeaf(YType.boolean, "is-service-connected")

                self.mtu_mismatch_ignore = YLeaf(YType.boolean, "mtu-mismatch-ignore")

                self.number_vpn = YLeaf(YType.uint32, "number-vpn")

                self.service_name = YLeaf(YType.enumeration, "service-name")

                self.service_name_xr = YLeaf(YType.str, "service-name-xr")

                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                self.vpn_name = YLeaf(YType.str, "vpn-name")

                self.vpn_name_xr = YLeaf(YType.str, "vpn-name-xr")

                self.signalling_info = L2Vpn.Discoveries.Discovery.SignallingInfo()
                self.signalling_info.parent = self
                self._children_name_map["signalling_info"] = "signalling-info"
                self._children_yang_names.add("signalling-info")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("group_name",
                                "group_name_xr",
                                "is_service_connected",
                                "mtu_mismatch_ignore",
                                "number_vpn",
                                "service_name",
                                "service_name_xr",
                                "vpn_id",
                                "vpn_name",
                                "vpn_name_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Discoveries.Discovery, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Discoveries.Discovery, self).__setattr__(name, value)


            class SignallingInfo(Entity):
                """
                Info about signalling protocol
                
                .. attribute:: ad_signalling_method
                
                	ADSignallingMethod
                	**type**\:   :py:class:`L2VpnAdSigMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdSigMethod>`
                
                .. attribute:: bgp_sig_info
                
                	bgp sig info
                	**type**\:   :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                
                .. attribute:: ldp_sig_info
                
                	ldp sig info
                	**type**\:   :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Discoveries.Discovery.SignallingInfo, self).__init__()

                    self.yang_name = "signalling-info"
                    self.yang_parent_name = "discovery"

                    self.ad_signalling_method = YLeaf(YType.enumeration, "ad-signalling-method")

                    self.bgp_sig_info = L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                    self.bgp_sig_info.parent = self
                    self._children_name_map["bgp_sig_info"] = "bgp-sig-info"
                    self._children_yang_names.add("bgp-sig-info")

                    self.ldp_sig_info = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                    self.ldp_sig_info.parent = self
                    self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                    self._children_yang_names.add("ldp-sig-info")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ad_signalling_method") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Discoveries.Discovery.SignallingInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Discoveries.Discovery.SignallingInfo, self).__setattr__(name, value)


                class BgpSigInfo(Entity):
                    """
                    bgp sig info
                    
                    .. attribute:: edge
                    
                    	List of edge ids
                    	**type**\: list of    :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                    
                    .. attribute:: number_edges
                    
                    	Number of Edges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_remote_edges
                    
                    	Number of remote Edges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redge
                    
                    	List of edge ids
                    	**type**\: list of    :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__init__()

                        self.yang_name = "bgp-sig-info"
                        self.yang_parent_name = "signalling-info"

                        self.number_edges = YLeaf(YType.uint32, "number-edges")

                        self.number_remote_edges = YLeaf(YType.uint32, "number-remote-edges")

                        self.edge = YList(self)
                        self.redge = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("number_edges",
                                        "number_remote_edges") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__setattr__(name, value)


                    class Edge(Entity):
                        """
                        List of edge ids
                        
                        .. attribute:: edge_id
                        
                        	Edge ids
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: label_block
                        
                        	List of label blocks
                        	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                        
                        .. attribute:: label_count
                        
                        	Number of label blocks
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__init__()

                            self.yang_name = "edge"
                            self.yang_parent_name = "bgp-sig-info"

                            self.edge_id = YLeaf(YType.uint32, "edge-id")

                            self.label_count = YLeaf(YType.uint32, "label-count")

                            self.label_block = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("edge_id",
                                            "label_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__setattr__(name, value)


                        class LabelBlock(Entity):
                            """
                            List of label blocks
                            
                            .. attribute:: block_offset
                            
                            	Block offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: block_size
                            
                            	Block size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_base
                            
                            	Label Base
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_error
                            
                            	Label Error
                            	**type**\:   :py:class:`L2VpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErr>`
                            
                            .. attribute:: label_time_created
                            
                            	Creation time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_edge_id
                            
                            	Local edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop
                            
                            	 Peer id
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: status_vector
                            
                            	Status Vector
                            	**type**\:  list of int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__init__()

                                self.yang_name = "label-block"
                                self.yang_parent_name = "edge"

                                self.block_offset = YLeaf(YType.uint32, "block-offset")

                                self.block_size = YLeaf(YType.uint32, "block-size")

                                self.label_base = YLeaf(YType.uint32, "label-base")

                                self.label_error = YLeaf(YType.enumeration, "label-error")

                                self.label_time_created = YLeaf(YType.uint32, "label-time-created")

                                self.local_edge_id = YLeaf(YType.uint32, "local-edge-id")

                                self.next_hop = YLeaf(YType.str, "next-hop")

                                self.status_vector = YLeafList(YType.uint8, "status-vector")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("block_offset",
                                                "block_size",
                                                "label_base",
                                                "label_error",
                                                "label_time_created",
                                                "local_edge_id",
                                                "next_hop",
                                                "status_vector") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.status_vector.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.block_offset.is_set or
                                    self.block_size.is_set or
                                    self.label_base.is_set or
                                    self.label_error.is_set or
                                    self.label_time_created.is_set or
                                    self.local_edge_id.is_set or
                                    self.next_hop.is_set)

                            def has_operation(self):
                                for leaf in self.status_vector.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.block_offset.yfilter != YFilter.not_set or
                                    self.block_size.yfilter != YFilter.not_set or
                                    self.label_base.yfilter != YFilter.not_set or
                                    self.label_error.yfilter != YFilter.not_set or
                                    self.label_time_created.yfilter != YFilter.not_set or
                                    self.local_edge_id.yfilter != YFilter.not_set or
                                    self.next_hop.yfilter != YFilter.not_set or
                                    self.status_vector.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "label-block" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/bgp-sig-info/edge/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.block_offset.is_set or self.block_offset.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.block_offset.get_name_leafdata())
                                if (self.block_size.is_set or self.block_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.block_size.get_name_leafdata())
                                if (self.label_base.is_set or self.label_base.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label_base.get_name_leafdata())
                                if (self.label_error.is_set or self.label_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label_error.get_name_leafdata())
                                if (self.label_time_created.is_set or self.label_time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label_time_created.get_name_leafdata())
                                if (self.local_edge_id.is_set or self.local_edge_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_edge_id.get_name_leafdata())
                                if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop.get_name_leafdata())

                                leaf_name_data.extend(self.status_vector.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "block-offset" or name == "block-size" or name == "label-base" or name == "label-error" or name == "label-time-created" or name == "local-edge-id" or name == "next-hop" or name == "status-vector"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "block-offset"):
                                    self.block_offset = value
                                    self.block_offset.value_namespace = name_space
                                    self.block_offset.value_namespace_prefix = name_space_prefix
                                if(value_path == "block-size"):
                                    self.block_size = value
                                    self.block_size.value_namespace = name_space
                                    self.block_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "label-base"):
                                    self.label_base = value
                                    self.label_base.value_namespace = name_space
                                    self.label_base.value_namespace_prefix = name_space_prefix
                                if(value_path == "label-error"):
                                    self.label_error = value
                                    self.label_error.value_namespace = name_space
                                    self.label_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "label-time-created"):
                                    self.label_time_created = value
                                    self.label_time_created.value_namespace = name_space
                                    self.label_time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-edge-id"):
                                    self.local_edge_id = value
                                    self.local_edge_id.value_namespace = name_space
                                    self.local_edge_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop"):
                                    self.next_hop = value
                                    self.next_hop.value_namespace = name_space
                                    self.next_hop.value_namespace_prefix = name_space_prefix
                                if(value_path == "status-vector"):
                                    self.status_vector.append(value)

                        def has_data(self):
                            for c in self.label_block:
                                if (c.has_data()):
                                    return True
                            return (
                                self.edge_id.is_set or
                                self.label_count.is_set)

                        def has_operation(self):
                            for c in self.label_block:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.edge_id.yfilter != YFilter.not_set or
                                self.label_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "edge" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/bgp-sig-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.edge_id.is_set or self.edge_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.edge_id.get_name_leafdata())
                            if (self.label_count.is_set or self.label_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.label_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "label-block"):
                                for c in self.label_block:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.label_block.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "label-block" or name == "edge-id" or name == "label-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "edge-id"):
                                self.edge_id = value
                                self.edge_id.value_namespace = name_space
                                self.edge_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "label-count"):
                                self.label_count = value
                                self.label_count.value_namespace = name_space
                                self.label_count.value_namespace_prefix = name_space_prefix


                    class Redge(Entity):
                        """
                        List of edge ids
                        
                        .. attribute:: edge_id
                        
                        	Edge ids
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: label_block
                        
                        	List of label blocks
                        	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                        
                        .. attribute:: label_count
                        
                        	Number of label blocks
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__init__()

                            self.yang_name = "redge"
                            self.yang_parent_name = "bgp-sig-info"

                            self.edge_id = YLeaf(YType.uint32, "edge-id")

                            self.label_count = YLeaf(YType.uint32, "label-count")

                            self.label_block = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("edge_id",
                                            "label_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__setattr__(name, value)


                        class LabelBlock(Entity):
                            """
                            List of label blocks
                            
                            .. attribute:: block_offset
                            
                            	Block offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: block_size
                            
                            	Block size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_base
                            
                            	Label Base
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_error
                            
                            	Label Error
                            	**type**\:   :py:class:`L2VpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErr>`
                            
                            .. attribute:: label_time_created
                            
                            	Creation time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_edge_id
                            
                            	Local edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop
                            
                            	 Peer id
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: status_vector
                            
                            	Status Vector
                            	**type**\:  list of int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__init__()

                                self.yang_name = "label-block"
                                self.yang_parent_name = "redge"

                                self.block_offset = YLeaf(YType.uint32, "block-offset")

                                self.block_size = YLeaf(YType.uint32, "block-size")

                                self.label_base = YLeaf(YType.uint32, "label-base")

                                self.label_error = YLeaf(YType.enumeration, "label-error")

                                self.label_time_created = YLeaf(YType.uint32, "label-time-created")

                                self.local_edge_id = YLeaf(YType.uint32, "local-edge-id")

                                self.next_hop = YLeaf(YType.str, "next-hop")

                                self.status_vector = YLeafList(YType.uint8, "status-vector")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("block_offset",
                                                "block_size",
                                                "label_base",
                                                "label_error",
                                                "label_time_created",
                                                "local_edge_id",
                                                "next_hop",
                                                "status_vector") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.status_vector.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.block_offset.is_set or
                                    self.block_size.is_set or
                                    self.label_base.is_set or
                                    self.label_error.is_set or
                                    self.label_time_created.is_set or
                                    self.local_edge_id.is_set or
                                    self.next_hop.is_set)

                            def has_operation(self):
                                for leaf in self.status_vector.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.block_offset.yfilter != YFilter.not_set or
                                    self.block_size.yfilter != YFilter.not_set or
                                    self.label_base.yfilter != YFilter.not_set or
                                    self.label_error.yfilter != YFilter.not_set or
                                    self.label_time_created.yfilter != YFilter.not_set or
                                    self.local_edge_id.yfilter != YFilter.not_set or
                                    self.next_hop.yfilter != YFilter.not_set or
                                    self.status_vector.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "label-block" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/bgp-sig-info/redge/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.block_offset.is_set or self.block_offset.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.block_offset.get_name_leafdata())
                                if (self.block_size.is_set or self.block_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.block_size.get_name_leafdata())
                                if (self.label_base.is_set or self.label_base.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label_base.get_name_leafdata())
                                if (self.label_error.is_set or self.label_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label_error.get_name_leafdata())
                                if (self.label_time_created.is_set or self.label_time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label_time_created.get_name_leafdata())
                                if (self.local_edge_id.is_set or self.local_edge_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_edge_id.get_name_leafdata())
                                if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop.get_name_leafdata())

                                leaf_name_data.extend(self.status_vector.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "block-offset" or name == "block-size" or name == "label-base" or name == "label-error" or name == "label-time-created" or name == "local-edge-id" or name == "next-hop" or name == "status-vector"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "block-offset"):
                                    self.block_offset = value
                                    self.block_offset.value_namespace = name_space
                                    self.block_offset.value_namespace_prefix = name_space_prefix
                                if(value_path == "block-size"):
                                    self.block_size = value
                                    self.block_size.value_namespace = name_space
                                    self.block_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "label-base"):
                                    self.label_base = value
                                    self.label_base.value_namespace = name_space
                                    self.label_base.value_namespace_prefix = name_space_prefix
                                if(value_path == "label-error"):
                                    self.label_error = value
                                    self.label_error.value_namespace = name_space
                                    self.label_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "label-time-created"):
                                    self.label_time_created = value
                                    self.label_time_created.value_namespace = name_space
                                    self.label_time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-edge-id"):
                                    self.local_edge_id = value
                                    self.local_edge_id.value_namespace = name_space
                                    self.local_edge_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop"):
                                    self.next_hop = value
                                    self.next_hop.value_namespace = name_space
                                    self.next_hop.value_namespace_prefix = name_space_prefix
                                if(value_path == "status-vector"):
                                    self.status_vector.append(value)

                        def has_data(self):
                            for c in self.label_block:
                                if (c.has_data()):
                                    return True
                            return (
                                self.edge_id.is_set or
                                self.label_count.is_set)

                        def has_operation(self):
                            for c in self.label_block:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.edge_id.yfilter != YFilter.not_set or
                                self.label_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redge" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/bgp-sig-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.edge_id.is_set or self.edge_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.edge_id.get_name_leafdata())
                            if (self.label_count.is_set or self.label_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.label_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "label-block"):
                                for c in self.label_block:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.label_block.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "label-block" or name == "edge-id" or name == "label-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "edge-id"):
                                self.edge_id = value
                                self.edge_id.value_namespace = name_space
                                self.edge_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "label-count"):
                                self.label_count = value
                                self.label_count.value_namespace = name_space
                                self.label_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.edge:
                            if (c.has_data()):
                                return True
                        for c in self.redge:
                            if (c.has_data()):
                                return True
                        return (
                            self.number_edges.is_set or
                            self.number_remote_edges.is_set)

                    def has_operation(self):
                        for c in self.edge:
                            if (c.has_operation()):
                                return True
                        for c in self.redge:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.number_edges.yfilter != YFilter.not_set or
                            self.number_remote_edges.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-sig-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.number_edges.is_set or self.number_edges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_edges.get_name_leafdata())
                        if (self.number_remote_edges.is_set or self.number_remote_edges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_remote_edges.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "edge"):
                            for c in self.edge:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.edge.append(c)
                            return c

                        if (child_yang_name == "redge"):
                            for c in self.redge:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.redge.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "edge" or name == "redge" or name == "number-edges" or name == "number-remote-edges"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "number-edges"):
                            self.number_edges = value
                            self.number_edges.value_namespace = name_space
                            self.number_edges.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-remote-edges"):
                            self.number_remote_edges = value
                            self.number_remote_edges.value_namespace = name_space
                            self.number_remote_edges.value_namespace_prefix = name_space_prefix


                class LdpSigInfo(Entity):
                    """
                    ldp sig info
                    
                    .. attribute:: local_l2_router_id
                    
                    	Local L2VPN Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: local_vpls_id
                    
                    	Local VPLS\-ID
                    	**type**\:   :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                    
                    .. attribute:: number_remote_edges
                    
                    	Number of remote Edges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_nlri
                    
                    	List of NLRIs
                    	**type**\: list of    :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__init__()

                        self.yang_name = "ldp-sig-info"
                        self.yang_parent_name = "signalling-info"

                        self.local_l2_router_id = YLeaf(YType.str, "local-l2-router-id")

                        self.number_remote_edges = YLeaf(YType.uint32, "number-remote-edges")

                        self.local_vpls_id = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                        self.local_vpls_id.parent = self
                        self._children_name_map["local_vpls_id"] = "local-vpls-id"
                        self._children_yang_names.add("local-vpls-id")

                        self.remote_nlri = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("local_l2_router_id",
                                        "number_remote_edges") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__setattr__(name, value)


                    class LocalVplsId(Entity):
                        """
                        Local VPLS\-ID
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                        
                        .. attribute:: vpls_id_type
                        
                        	VPLS ID TYPE
                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__init__()

                            self.yang_name = "local-vpls-id"
                            self.yang_parent_name = "ldp-sig-info"

                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                            self.auto = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"
                            self._children_yang_names.add("auto")

                            self.two_byte_as = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                            self._children_yang_names.add("two-byte-as")

                            self.v4_addr = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._children_yang_names.add("v4-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("vpls_id_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__setattr__(name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: asn
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vpn_id
                            
                            	VPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "local-vpls-id"

                                self.asn = YLeaf(YType.uint16, "asn")

                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("asn",
                                                "vpn_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.asn.is_set or
                                    self.vpn_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.asn.yfilter != YFilter.not_set or
                                    self.vpn_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "auto" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "asn" or name == "vpn-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "asn"):
                                    self.asn = value
                                    self.asn.value_namespace = name_space
                                    self.asn.value_namespace_prefix = name_space_prefix
                                if(value_path == "vpn-id"):
                                    self.vpn_id = value
                                    self.vpn_id.value_namespace = name_space
                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "local-vpls-id"

                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("four_byte_index",
                                                "two_byte_as") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.four_byte_index.is_set or
                                    self.two_byte_as.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.four_byte_index.yfilter != YFilter.not_set or
                                    self.two_byte_as.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "two-byte-as" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "four-byte-index" or name == "two-byte-as"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "four-byte-index"):
                                    self.four_byte_index = value
                                    self.four_byte_index.value_namespace = name_space
                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-as"):
                                    self.two_byte_as = value
                                    self.two_byte_as.value_namespace = name_space
                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "local-vpls-id"

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ipv4_address",
                                                "two_byte_index") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ipv4_address.is_set or
                                    self.two_byte_index.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.two_byte_index.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "v4-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-address" or name == "two-byte-index"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "two-byte-index"):
                                    self.two_byte_index = value
                                    self.two_byte_index.value_namespace = name_space
                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.vpls_id_type.is_set or
                                (self.auto is not None and self.auto.has_data()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                (self.v4_addr is not None and self.v4_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.vpls_id_type.yfilter != YFilter.not_set or
                                (self.auto is not None and self.auto.has_operation()) or
                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-vpls-id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/ldp-sig-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "auto"):
                                if (self.auto is None):
                                    self.auto = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                return self.auto

                            if (child_yang_name == "two-byte-as"):
                                if (self.two_byte_as is None):
                                    self.two_byte_as = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                return self.two_byte_as

                            if (child_yang_name == "v4-addr"):
                                if (self.v4_addr is None):
                                    self.v4_addr = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                return self.v4_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "vpls-id-type"):
                                self.vpls_id_type = value
                                self.vpls_id_type.value_namespace = name_space
                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                    class RemoteNlri(Entity):
                        """
                        List of NLRIs
                        
                        .. attribute:: local_address
                        
                        	Local BGP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nlri_time_created
                        
                        	NLRI creation time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_address
                        
                        	Remote BGP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_l2_router_id
                        
                        	Remote L2VPN Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__init__()

                            self.yang_name = "remote-nlri"
                            self.yang_parent_name = "ldp-sig-info"

                            self.local_address = YLeaf(YType.str, "local-address")

                            self.nlri_time_created = YLeaf(YType.uint32, "nlri-time-created")

                            self.remote_address = YLeaf(YType.str, "remote-address")

                            self.remote_l2_router_id = YLeaf(YType.str, "remote-l2-router-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("local_address",
                                            "nlri_time_created",
                                            "remote_address",
                                            "remote_l2_router_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.local_address.is_set or
                                self.nlri_time_created.is_set or
                                self.remote_address.is_set or
                                self.remote_l2_router_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.local_address.yfilter != YFilter.not_set or
                                self.nlri_time_created.yfilter != YFilter.not_set or
                                self.remote_address.yfilter != YFilter.not_set or
                                self.remote_l2_router_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-nlri" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/ldp-sig-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_address.get_name_leafdata())
                            if (self.nlri_time_created.is_set or self.nlri_time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nlri_time_created.get_name_leafdata())
                            if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_address.get_name_leafdata())
                            if (self.remote_l2_router_id.is_set or self.remote_l2_router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_l2_router_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-address" or name == "nlri-time-created" or name == "remote-address" or name == "remote-l2-router-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "local-address"):
                                self.local_address = value
                                self.local_address.value_namespace = name_space
                                self.local_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "nlri-time-created"):
                                self.nlri_time_created = value
                                self.nlri_time_created.value_namespace = name_space
                                self.nlri_time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-address"):
                                self.remote_address = value
                                self.remote_address.value_namespace = name_space
                                self.remote_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-l2-router-id"):
                                self.remote_l2_router_id = value
                                self.remote_l2_router_id.value_namespace = name_space
                                self.remote_l2_router_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.remote_nlri:
                            if (c.has_data()):
                                return True
                        return (
                            self.local_l2_router_id.is_set or
                            self.number_remote_edges.is_set or
                            (self.local_vpls_id is not None and self.local_vpls_id.has_data()))

                    def has_operation(self):
                        for c in self.remote_nlri:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.local_l2_router_id.yfilter != YFilter.not_set or
                            self.number_remote_edges.yfilter != YFilter.not_set or
                            (self.local_vpls_id is not None and self.local_vpls_id.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ldp-sig-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/signalling-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.local_l2_router_id.is_set or self.local_l2_router_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_l2_router_id.get_name_leafdata())
                        if (self.number_remote_edges.is_set or self.number_remote_edges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_remote_edges.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "local-vpls-id"):
                            if (self.local_vpls_id is None):
                                self.local_vpls_id = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                                self.local_vpls_id.parent = self
                                self._children_name_map["local_vpls_id"] = "local-vpls-id"
                            return self.local_vpls_id

                        if (child_yang_name == "remote-nlri"):
                            for c in self.remote_nlri:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.remote_nlri.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "local-vpls-id" or name == "remote-nlri" or name == "local-l2-router-id" or name == "number-remote-edges"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "local-l2-router-id"):
                            self.local_l2_router_id = value
                            self.local_l2_router_id.value_namespace = name_space
                            self.local_l2_router_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-remote-edges"):
                            self.number_remote_edges = value
                            self.number_remote_edges.value_namespace = name_space
                            self.number_remote_edges.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.ad_signalling_method.is_set or
                        (self.bgp_sig_info is not None and self.bgp_sig_info.has_data()) or
                        (self.ldp_sig_info is not None and self.ldp_sig_info.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ad_signalling_method.yfilter != YFilter.not_set or
                        (self.bgp_sig_info is not None and self.bgp_sig_info.has_operation()) or
                        (self.ldp_sig_info is not None and self.ldp_sig_info.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "signalling-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/discovery/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bgp-sig-info"):
                        if (self.bgp_sig_info is None):
                            self.bgp_sig_info = L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                            self.bgp_sig_info.parent = self
                            self._children_name_map["bgp_sig_info"] = "bgp-sig-info"
                        return self.bgp_sig_info

                    if (child_yang_name == "ldp-sig-info"):
                        if (self.ldp_sig_info is None):
                            self.ldp_sig_info = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                            self.ldp_sig_info.parent = self
                            self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                        return self.ldp_sig_info

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bgp-sig-info" or name == "ldp-sig-info" or name == "ad-signalling-method"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ad-signalling-method"):
                        self.ad_signalling_method = value
                        self.ad_signalling_method.value_namespace = name_space
                        self.ad_signalling_method.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.group_name.is_set or
                    self.group_name_xr.is_set or
                    self.is_service_connected.is_set or
                    self.mtu_mismatch_ignore.is_set or
                    self.number_vpn.is_set or
                    self.service_name.is_set or
                    self.service_name_xr.is_set or
                    self.vpn_id.is_set or
                    self.vpn_name.is_set or
                    self.vpn_name_xr.is_set or
                    (self.signalling_info is not None and self.signalling_info.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.group_name.yfilter != YFilter.not_set or
                    self.group_name_xr.yfilter != YFilter.not_set or
                    self.is_service_connected.yfilter != YFilter.not_set or
                    self.mtu_mismatch_ignore.yfilter != YFilter.not_set or
                    self.number_vpn.yfilter != YFilter.not_set or
                    self.service_name.yfilter != YFilter.not_set or
                    self.service_name_xr.yfilter != YFilter.not_set or
                    self.vpn_id.yfilter != YFilter.not_set or
                    self.vpn_name.yfilter != YFilter.not_set or
                    self.vpn_name_xr.yfilter != YFilter.not_set or
                    (self.signalling_info is not None and self.signalling_info.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "discovery" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/discoveries/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.group_name.get_name_leafdata())
                if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                if (self.is_service_connected.is_set or self.is_service_connected.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_service_connected.get_name_leafdata())
                if (self.mtu_mismatch_ignore.is_set or self.mtu_mismatch_ignore.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mtu_mismatch_ignore.get_name_leafdata())
                if (self.number_vpn.is_set or self.number_vpn.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_vpn.get_name_leafdata())
                if (self.service_name.is_set or self.service_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.service_name.get_name_leafdata())
                if (self.service_name_xr.is_set or self.service_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.service_name_xr.get_name_leafdata())
                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vpn_id.get_name_leafdata())
                if (self.vpn_name.is_set or self.vpn_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vpn_name.get_name_leafdata())
                if (self.vpn_name_xr.is_set or self.vpn_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vpn_name_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "signalling-info"):
                    if (self.signalling_info is None):
                        self.signalling_info = L2Vpn.Discoveries.Discovery.SignallingInfo()
                        self.signalling_info.parent = self
                        self._children_name_map["signalling_info"] = "signalling-info"
                    return self.signalling_info

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "signalling-info" or name == "group-name" or name == "group-name-xr" or name == "is-service-connected" or name == "mtu-mismatch-ignore" or name == "number-vpn" or name == "service-name" or name == "service-name-xr" or name == "vpn-id" or name == "vpn-name" or name == "vpn-name-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "group-name"):
                    self.group_name = value
                    self.group_name.value_namespace = name_space
                    self.group_name.value_namespace_prefix = name_space_prefix
                if(value_path == "group-name-xr"):
                    self.group_name_xr = value
                    self.group_name_xr.value_namespace = name_space
                    self.group_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "is-service-connected"):
                    self.is_service_connected = value
                    self.is_service_connected.value_namespace = name_space
                    self.is_service_connected.value_namespace_prefix = name_space_prefix
                if(value_path == "mtu-mismatch-ignore"):
                    self.mtu_mismatch_ignore = value
                    self.mtu_mismatch_ignore.value_namespace = name_space
                    self.mtu_mismatch_ignore.value_namespace_prefix = name_space_prefix
                if(value_path == "number-vpn"):
                    self.number_vpn = value
                    self.number_vpn.value_namespace = name_space
                    self.number_vpn.value_namespace_prefix = name_space_prefix
                if(value_path == "service-name"):
                    self.service_name = value
                    self.service_name.value_namespace = name_space
                    self.service_name.value_namespace_prefix = name_space_prefix
                if(value_path == "service-name-xr"):
                    self.service_name_xr = value
                    self.service_name_xr.value_namespace = name_space
                    self.service_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "vpn-id"):
                    self.vpn_id = value
                    self.vpn_id.value_namespace = name_space
                    self.vpn_id.value_namespace_prefix = name_space_prefix
                if(value_path == "vpn-name"):
                    self.vpn_name = value
                    self.vpn_name.value_namespace = name_space
                    self.vpn_name.value_namespace_prefix = name_space_prefix
                if(value_path == "vpn-name-xr"):
                    self.vpn_name_xr = value
                    self.vpn_name_xr.value_namespace = name_space
                    self.vpn_name_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.discovery:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.discovery:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "discoveries" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "discovery"):
                for c in self.discovery:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.Discoveries.Discovery()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.discovery.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "discovery"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class FlexibleXconnectServiceSummary(Entity):
        """
        Flexible XConnect Service summary information
        
        .. attribute:: number_fxc
        
        	Number of flexible xconnect services
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_fxc_down
        
        	Number of flexible xconnect services whose state is down
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_fxc_up
        
        	Number of flexible xconnect services whose state is up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.FlexibleXconnectServiceSummary, self).__init__()

            self.yang_name = "flexible-xconnect-service-summary"
            self.yang_parent_name = "l2vpn"

            self.number_fxc = YLeaf(YType.uint32, "number-fxc")

            self.number_fxc_down = YLeaf(YType.uint32, "number-fxc-down")

            self.number_fxc_up = YLeaf(YType.uint32, "number-fxc-up")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("number_fxc",
                            "number_fxc_down",
                            "number_fxc_up") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.FlexibleXconnectServiceSummary, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.FlexibleXconnectServiceSummary, self).__setattr__(name, value)

        def has_data(self):
            return (
                self.number_fxc.is_set or
                self.number_fxc_down.is_set or
                self.number_fxc_up.is_set)

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.number_fxc.yfilter != YFilter.not_set or
                self.number_fxc_down.yfilter != YFilter.not_set or
                self.number_fxc_up.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "flexible-xconnect-service-summary" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.number_fxc.is_set or self.number_fxc.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_fxc.get_name_leafdata())
            if (self.number_fxc_down.is_set or self.number_fxc_down.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_fxc_down.get_name_leafdata())
            if (self.number_fxc_up.is_set or self.number_fxc_up.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_fxc_up.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "number-fxc" or name == "number-fxc-down" or name == "number-fxc-up"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "number-fxc"):
                self.number_fxc = value
                self.number_fxc.value_namespace = name_space
                self.number_fxc.value_namespace_prefix = name_space_prefix
            if(value_path == "number-fxc-down"):
                self.number_fxc_down = value
                self.number_fxc_down.value_namespace = name_space
                self.number_fxc_down.value_namespace_prefix = name_space_prefix
            if(value_path == "number-fxc-up"):
                self.number_fxc_up = value
                self.number_fxc_up.value_namespace = name_space
                self.number_fxc_up.value_namespace_prefix = name_space_prefix


    class MainInterfaces(Entity):
        """
        Main Interface
        
        .. attribute:: main_interface
        
        	Main Interface Table
        	**type**\: list of    :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.MainInterfaces, self).__init__()

            self.yang_name = "main-interfaces"
            self.yang_parent_name = "l2vpn"

            self.main_interface = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.MainInterfaces, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.MainInterfaces, self).__setattr__(name, value)


        class MainInterface(Entity):
            """
            Main Interface Table
            
            .. attribute:: interface_name  <key>
            
            	Main interface
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: main_interface_info
            
            	Main Interface info
            	**type**\:   :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInfo>`
            
            .. attribute:: main_interface_instances
            
            	Main Interface Instance table
            	**type**\:   :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.MainInterfaces.MainInterface, self).__init__()

                self.yang_name = "main-interface"
                self.yang_parent_name = "main-interfaces"

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.main_interface_info = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInfo()
                self.main_interface_info.parent = self
                self._children_name_map["main_interface_info"] = "main-interface-info"
                self._children_yang_names.add("main-interface-info")

                self.main_interface_instances = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances()
                self.main_interface_instances.parent = self
                self._children_name_map["main_interface_instances"] = "main-interface-instances"
                self._children_yang_names.add("main-interface-instances")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("interface_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.MainInterfaces.MainInterface, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.MainInterfaces.MainInterface, self).__setattr__(name, value)


            class MainInterfaceInstances(Entity):
                """
                Main Interface Instance table
                
                .. attribute:: main_interface_instance
                
                	Main Interface Instance
                	**type**\: list of    :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances, self).__init__()

                    self.yang_name = "main-interface-instances"
                    self.yang_parent_name = "main-interface"

                    self.main_interface_instance = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances, self).__setattr__(name, value)


                class MainInterfaceInstance(Entity):
                    """
                    Main Interface Instance
                    
                    .. attribute:: instance  <key>
                    
                    	Instance
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: main_interface_instance_bridge_ports
                    
                    	Main Interface Instance Bridge Port table
                    	**type**\:   :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                    
                    .. attribute:: main_interface_instance_info
                    
                    	Main Interface Instance info
                    	**type**\:   :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__init__()

                        self.yang_name = "main-interface-instance"
                        self.yang_parent_name = "main-interface-instances"

                        self.instance = YLeaf(YType.int32, "instance")

                        self.main_interface_instance_bridge_ports = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                        self.main_interface_instance_bridge_ports.parent = self
                        self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                        self._children_yang_names.add("main-interface-instance-bridge-ports")

                        self.main_interface_instance_info = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                        self.main_interface_instance_info.parent = self
                        self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"
                        self._children_yang_names.add("main-interface-instance-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("instance") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__setattr__(name, value)


                    class MainInterfaceInstanceInfo(Entity):
                        """
                        Main Interface Instance info
                        
                        .. attribute:: configured_instance
                        
                        	Configured Instance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flush_count
                        
                        	Flush count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instance_flags
                        
                        	Instance Flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instance_id
                        
                        	Instance ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instance_state
                        
                        	Instance State
                        	**type**\:   :py:class:`L2VpnMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfInstanceState>`
                        
                        .. attribute:: interface_count
                        
                        	Interface count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__init__()

                            self.yang_name = "main-interface-instance-info"
                            self.yang_parent_name = "main-interface-instance"

                            self.configured_instance = YLeaf(YType.uint32, "configured-instance")

                            self.flush_count = YLeaf(YType.uint32, "flush-count")

                            self.instance_flags = YLeaf(YType.uint32, "instance-flags")

                            self.instance_id = YLeaf(YType.uint32, "instance-id")

                            self.instance_state = YLeaf(YType.enumeration, "instance-state")

                            self.interface_count = YLeaf(YType.uint32, "interface-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("configured_instance",
                                            "flush_count",
                                            "instance_flags",
                                            "instance_id",
                                            "instance_state",
                                            "interface_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.configured_instance.is_set or
                                self.flush_count.is_set or
                                self.instance_flags.is_set or
                                self.instance_id.is_set or
                                self.instance_state.is_set or
                                self.interface_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.configured_instance.yfilter != YFilter.not_set or
                                self.flush_count.yfilter != YFilter.not_set or
                                self.instance_flags.yfilter != YFilter.not_set or
                                self.instance_id.yfilter != YFilter.not_set or
                                self.instance_state.yfilter != YFilter.not_set or
                                self.interface_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "main-interface-instance-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.configured_instance.is_set or self.configured_instance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_instance.get_name_leafdata())
                            if (self.flush_count.is_set or self.flush_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flush_count.get_name_leafdata())
                            if (self.instance_flags.is_set or self.instance_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.instance_flags.get_name_leafdata())
                            if (self.instance_id.is_set or self.instance_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.instance_id.get_name_leafdata())
                            if (self.instance_state.is_set or self.instance_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.instance_state.get_name_leafdata())
                            if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "configured-instance" or name == "flush-count" or name == "instance-flags" or name == "instance-id" or name == "instance-state" or name == "interface-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "configured-instance"):
                                self.configured_instance = value
                                self.configured_instance.value_namespace = name_space
                                self.configured_instance.value_namespace_prefix = name_space_prefix
                            if(value_path == "flush-count"):
                                self.flush_count = value
                                self.flush_count.value_namespace = name_space
                                self.flush_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "instance-flags"):
                                self.instance_flags = value
                                self.instance_flags.value_namespace = name_space
                                self.instance_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "instance-id"):
                                self.instance_id = value
                                self.instance_id.value_namespace = name_space
                                self.instance_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "instance-state"):
                                self.instance_state = value
                                self.instance_state.value_namespace = name_space
                                self.instance_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-count"):
                                self.interface_count = value
                                self.interface_count.value_namespace = name_space
                                self.interface_count.value_namespace_prefix = name_space_prefix


                    class MainInterfaceInstanceBridgePorts(Entity):
                        """
                        Main Interface Instance Bridge Port table
                        
                        .. attribute:: main_interface_instance_bridge_port
                        
                        	Main Interface Bridge Port info
                        	**type**\: list of    :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__init__()

                            self.yang_name = "main-interface-instance-bridge-ports"
                            self.yang_parent_name = "main-interface-instance"

                            self.main_interface_instance_bridge_port = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__setattr__(name, value)


                        class MainInterfaceInstanceBridgePort(Entity):
                            """
                            Main Interface Bridge Port info
                            
                            .. attribute:: bridge_port  <key>
                            
                            	Bridge Port
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: bridge_port_xr
                            
                            	Bridge port ifhandle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: instance_id
                            
                            	Instance ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__init__()

                                self.yang_name = "main-interface-instance-bridge-port"
                                self.yang_parent_name = "main-interface-instance-bridge-ports"

                                self.bridge_port = YLeaf(YType.str, "bridge-port")

                                self.bridge_port_xr = YLeaf(YType.str, "bridge-port-xr")

                                self.instance_id = YLeaf(YType.uint32, "instance-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bridge_port",
                                                "bridge_port_xr",
                                                "instance_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bridge_port.is_set or
                                    self.bridge_port_xr.is_set or
                                    self.instance_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bridge_port.yfilter != YFilter.not_set or
                                    self.bridge_port_xr.yfilter != YFilter.not_set or
                                    self.instance_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "main-interface-instance-bridge-port" + "[bridge-port='" + self.bridge_port.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bridge_port.is_set or self.bridge_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_port.get_name_leafdata())
                                if (self.bridge_port_xr.is_set or self.bridge_port_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_port_xr.get_name_leafdata())
                                if (self.instance_id.is_set or self.instance_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.instance_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bridge-port" or name == "bridge-port-xr" or name == "instance-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bridge-port"):
                                    self.bridge_port = value
                                    self.bridge_port.value_namespace = name_space
                                    self.bridge_port.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-port-xr"):
                                    self.bridge_port_xr = value
                                    self.bridge_port_xr.value_namespace = name_space
                                    self.bridge_port_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "instance-id"):
                                    self.instance_id = value
                                    self.instance_id.value_namespace = name_space
                                    self.instance_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.main_interface_instance_bridge_port:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.main_interface_instance_bridge_port:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "main-interface-instance-bridge-ports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "main-interface-instance-bridge-port"):
                                for c in self.main_interface_instance_bridge_port:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.main_interface_instance_bridge_port.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "main-interface-instance-bridge-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.instance.is_set or
                            (self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports.has_data()) or
                            (self.main_interface_instance_info is not None and self.main_interface_instance_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.instance.yfilter != YFilter.not_set or
                            (self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports.has_operation()) or
                            (self.main_interface_instance_info is not None and self.main_interface_instance_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "main-interface-instance" + "[instance='" + self.instance.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.instance.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "main-interface-instance-bridge-ports"):
                            if (self.main_interface_instance_bridge_ports is None):
                                self.main_interface_instance_bridge_ports = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                                self.main_interface_instance_bridge_ports.parent = self
                                self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                            return self.main_interface_instance_bridge_ports

                        if (child_yang_name == "main-interface-instance-info"):
                            if (self.main_interface_instance_info is None):
                                self.main_interface_instance_info = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                                self.main_interface_instance_info.parent = self
                                self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"
                            return self.main_interface_instance_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "main-interface-instance-bridge-ports" or name == "main-interface-instance-info" or name == "instance"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "instance"):
                            self.instance = value
                            self.instance.value_namespace = name_space
                            self.instance.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.main_interface_instance:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.main_interface_instance:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "main-interface-instances" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "main-interface-instance"):
                        for c in self.main_interface_instance:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.main_interface_instance.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "main-interface-instance"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MainInterfaceInfo(Entity):
                """
                Main Interface info
                
                .. attribute:: interface_count
                
                	Sub Interface Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: main_interface_handle
                
                	Main Interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: protected
                
                	Protected
                	**type**\:   :py:class:`L2VpnMainIfProtectected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfProtectected>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInfo, self).__init__()

                    self.yang_name = "main-interface-info"
                    self.yang_parent_name = "main-interface"

                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                    self.main_interface_handle = YLeaf(YType.str, "main-interface-handle")

                    self.protected = YLeaf(YType.enumeration, "protected")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_count",
                                    "main_interface_handle",
                                    "protected") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.MainInterfaces.MainInterface.MainInterfaceInfo, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_count.is_set or
                        self.main_interface_handle.is_set or
                        self.protected.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_count.yfilter != YFilter.not_set or
                        self.main_interface_handle.yfilter != YFilter.not_set or
                        self.protected.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "main-interface-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_count.get_name_leafdata())
                    if (self.main_interface_handle.is_set or self.main_interface_handle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.main_interface_handle.get_name_leafdata())
                    if (self.protected.is_set or self.protected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.protected.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-count" or name == "main-interface-handle" or name == "protected"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-count"):
                        self.interface_count = value
                        self.interface_count.value_namespace = name_space
                        self.interface_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "main-interface-handle"):
                        self.main_interface_handle = value
                        self.main_interface_handle.value_namespace = name_space
                        self.main_interface_handle.value_namespace_prefix = name_space_prefix
                    if(value_path == "protected"):
                        self.protected = value
                        self.protected.value_namespace = name_space
                        self.protected.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.interface_name.is_set or
                    (self.main_interface_info is not None and self.main_interface_info.has_data()) or
                    (self.main_interface_instances is not None and self.main_interface_instances.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    (self.main_interface_info is not None and self.main_interface_info.has_operation()) or
                    (self.main_interface_instances is not None and self.main_interface_instances.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "main-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/main-interfaces/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "main-interface-info"):
                    if (self.main_interface_info is None):
                        self.main_interface_info = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInfo()
                        self.main_interface_info.parent = self
                        self._children_name_map["main_interface_info"] = "main-interface-info"
                    return self.main_interface_info

                if (child_yang_name == "main-interface-instances"):
                    if (self.main_interface_instances is None):
                        self.main_interface_instances = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances()
                        self.main_interface_instances.parent = self
                        self._children_name_map["main_interface_instances"] = "main-interface-instances"
                    return self.main_interface_instances

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "main-interface-info" or name == "main-interface-instances" or name == "interface-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.main_interface:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.main_interface:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "main-interfaces" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "main-interface"):
                for c in self.main_interface:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.MainInterfaces.MainInterface()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.main_interface.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "main-interface"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class IccpSm(Entity):
        """
        ICCP\-based Service Multi\-homing operational data
        
        .. attribute:: iccp_groups
        
        	ICCP Group Table
        	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups>`
        
        .. attribute:: iccp_sm_summary
        
        	ICCP\-based Service Multi\-homing database summary
        	**type**\:   :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpSmSummary>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.IccpSm, self).__init__()

            self.yang_name = "iccp-sm"
            self.yang_parent_name = "l2vpn"

            self.iccp_groups = L2Vpn.IccpSm.IccpGroups()
            self.iccp_groups.parent = self
            self._children_name_map["iccp_groups"] = "iccp-groups"
            self._children_yang_names.add("iccp-groups")

            self.iccp_sm_summary = L2Vpn.IccpSm.IccpSmSummary()
            self.iccp_sm_summary.parent = self
            self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"
            self._children_yang_names.add("iccp-sm-summary")


        class IccpSmSummary(Entity):
            """
            ICCP\-based Service Multi\-homing database
            summary
            
            .. attribute:: connected_groups
            
            	Number of Connected Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: connecting_groups
            
            	Number of Connecting Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: failed_ports
            
            	Number of Failed Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: groups
            
            	Total Number of Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: operational_ports
            
            	Number of Operational Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ports
            
            	Total Number of Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: provisioned_groups
            
            	Number of Provisioned Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: reverting_ports
            
            	Number of Reverting Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: synchronized_groups
            
            	Number of Synchronized Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: synchronizing_groups
            
            	Number of Synchronizing Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unconfigured_ports
            
            	Number of Unconfigured Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unknown_ports
            
            	Number of Unknown Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_groups
            
            	Number of Unresolved Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unsynchronized_ports
            
            	Number of Unsynchronized Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.IccpSm.IccpSmSummary, self).__init__()

                self.yang_name = "iccp-sm-summary"
                self.yang_parent_name = "iccp-sm"

                self.connected_groups = YLeaf(YType.uint32, "connected-groups")

                self.connecting_groups = YLeaf(YType.uint32, "connecting-groups")

                self.failed_ports = YLeaf(YType.uint32, "failed-ports")

                self.groups = YLeaf(YType.uint32, "groups")

                self.operational_ports = YLeaf(YType.uint32, "operational-ports")

                self.ports = YLeaf(YType.uint32, "ports")

                self.provisioned_groups = YLeaf(YType.uint32, "provisioned-groups")

                self.reverting_ports = YLeaf(YType.uint32, "reverting-ports")

                self.synchronized_groups = YLeaf(YType.uint32, "synchronized-groups")

                self.synchronizing_groups = YLeaf(YType.uint32, "synchronizing-groups")

                self.unconfigured_ports = YLeaf(YType.uint32, "unconfigured-ports")

                self.unknown_ports = YLeaf(YType.uint32, "unknown-ports")

                self.unresolved_groups = YLeaf(YType.uint32, "unresolved-groups")

                self.unsynchronized_ports = YLeaf(YType.uint32, "unsynchronized-ports")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("connected_groups",
                                "connecting_groups",
                                "failed_ports",
                                "groups",
                                "operational_ports",
                                "ports",
                                "provisioned_groups",
                                "reverting_ports",
                                "synchronized_groups",
                                "synchronizing_groups",
                                "unconfigured_ports",
                                "unknown_ports",
                                "unresolved_groups",
                                "unsynchronized_ports") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.IccpSm.IccpSmSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.IccpSm.IccpSmSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.connected_groups.is_set or
                    self.connecting_groups.is_set or
                    self.failed_ports.is_set or
                    self.groups.is_set or
                    self.operational_ports.is_set or
                    self.ports.is_set or
                    self.provisioned_groups.is_set or
                    self.reverting_ports.is_set or
                    self.synchronized_groups.is_set or
                    self.synchronizing_groups.is_set or
                    self.unconfigured_ports.is_set or
                    self.unknown_ports.is_set or
                    self.unresolved_groups.is_set or
                    self.unsynchronized_ports.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.connected_groups.yfilter != YFilter.not_set or
                    self.connecting_groups.yfilter != YFilter.not_set or
                    self.failed_ports.yfilter != YFilter.not_set or
                    self.groups.yfilter != YFilter.not_set or
                    self.operational_ports.yfilter != YFilter.not_set or
                    self.ports.yfilter != YFilter.not_set or
                    self.provisioned_groups.yfilter != YFilter.not_set or
                    self.reverting_ports.yfilter != YFilter.not_set or
                    self.synchronized_groups.yfilter != YFilter.not_set or
                    self.synchronizing_groups.yfilter != YFilter.not_set or
                    self.unconfigured_ports.yfilter != YFilter.not_set or
                    self.unknown_ports.yfilter != YFilter.not_set or
                    self.unresolved_groups.yfilter != YFilter.not_set or
                    self.unsynchronized_ports.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "iccp-sm-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/iccp-sm/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.connected_groups.is_set or self.connected_groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.connected_groups.get_name_leafdata())
                if (self.connecting_groups.is_set or self.connecting_groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.connecting_groups.get_name_leafdata())
                if (self.failed_ports.is_set or self.failed_ports.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.failed_ports.get_name_leafdata())
                if (self.groups.is_set or self.groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.groups.get_name_leafdata())
                if (self.operational_ports.is_set or self.operational_ports.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.operational_ports.get_name_leafdata())
                if (self.ports.is_set or self.ports.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ports.get_name_leafdata())
                if (self.provisioned_groups.is_set or self.provisioned_groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.provisioned_groups.get_name_leafdata())
                if (self.reverting_ports.is_set or self.reverting_ports.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reverting_ports.get_name_leafdata())
                if (self.synchronized_groups.is_set or self.synchronized_groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.synchronized_groups.get_name_leafdata())
                if (self.synchronizing_groups.is_set or self.synchronizing_groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.synchronizing_groups.get_name_leafdata())
                if (self.unconfigured_ports.is_set or self.unconfigured_ports.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unconfigured_ports.get_name_leafdata())
                if (self.unknown_ports.is_set or self.unknown_ports.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unknown_ports.get_name_leafdata())
                if (self.unresolved_groups.is_set or self.unresolved_groups.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unresolved_groups.get_name_leafdata())
                if (self.unsynchronized_ports.is_set or self.unsynchronized_ports.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.unsynchronized_ports.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "connected-groups" or name == "connecting-groups" or name == "failed-ports" or name == "groups" or name == "operational-ports" or name == "ports" or name == "provisioned-groups" or name == "reverting-ports" or name == "synchronized-groups" or name == "synchronizing-groups" or name == "unconfigured-ports" or name == "unknown-ports" or name == "unresolved-groups" or name == "unsynchronized-ports"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "connected-groups"):
                    self.connected_groups = value
                    self.connected_groups.value_namespace = name_space
                    self.connected_groups.value_namespace_prefix = name_space_prefix
                if(value_path == "connecting-groups"):
                    self.connecting_groups = value
                    self.connecting_groups.value_namespace = name_space
                    self.connecting_groups.value_namespace_prefix = name_space_prefix
                if(value_path == "failed-ports"):
                    self.failed_ports = value
                    self.failed_ports.value_namespace = name_space
                    self.failed_ports.value_namespace_prefix = name_space_prefix
                if(value_path == "groups"):
                    self.groups = value
                    self.groups.value_namespace = name_space
                    self.groups.value_namespace_prefix = name_space_prefix
                if(value_path == "operational-ports"):
                    self.operational_ports = value
                    self.operational_ports.value_namespace = name_space
                    self.operational_ports.value_namespace_prefix = name_space_prefix
                if(value_path == "ports"):
                    self.ports = value
                    self.ports.value_namespace = name_space
                    self.ports.value_namespace_prefix = name_space_prefix
                if(value_path == "provisioned-groups"):
                    self.provisioned_groups = value
                    self.provisioned_groups.value_namespace = name_space
                    self.provisioned_groups.value_namespace_prefix = name_space_prefix
                if(value_path == "reverting-ports"):
                    self.reverting_ports = value
                    self.reverting_ports.value_namespace = name_space
                    self.reverting_ports.value_namespace_prefix = name_space_prefix
                if(value_path == "synchronized-groups"):
                    self.synchronized_groups = value
                    self.synchronized_groups.value_namespace = name_space
                    self.synchronized_groups.value_namespace_prefix = name_space_prefix
                if(value_path == "synchronizing-groups"):
                    self.synchronizing_groups = value
                    self.synchronizing_groups.value_namespace = name_space
                    self.synchronizing_groups.value_namespace_prefix = name_space_prefix
                if(value_path == "unconfigured-ports"):
                    self.unconfigured_ports = value
                    self.unconfigured_ports.value_namespace = name_space
                    self.unconfigured_ports.value_namespace_prefix = name_space_prefix
                if(value_path == "unknown-ports"):
                    self.unknown_ports = value
                    self.unknown_ports.value_namespace = name_space
                    self.unknown_ports.value_namespace_prefix = name_space_prefix
                if(value_path == "unresolved-groups"):
                    self.unresolved_groups = value
                    self.unresolved_groups.value_namespace = name_space
                    self.unresolved_groups.value_namespace_prefix = name_space_prefix
                if(value_path == "unsynchronized-ports"):
                    self.unsynchronized_ports = value
                    self.unsynchronized_ports.value_namespace = name_space
                    self.unsynchronized_ports.value_namespace_prefix = name_space_prefix


        class IccpGroups(Entity):
            """
            ICCP Group Table
            
            .. attribute:: iccp_group
            
            	ICCP Group
            	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.IccpSm.IccpGroups, self).__init__()

                self.yang_name = "iccp-groups"
                self.yang_parent_name = "iccp-sm"

                self.iccp_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.IccpSm.IccpGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.IccpSm.IccpGroups, self).__setattr__(name, value)


            class IccpGroup(Entity):
                """
                ICCP Group
                
                .. attribute:: group_id  <key>
                
                	Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: iccp_group_info
                
                	ICCP Group Information
                	**type**\:   :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                
                .. attribute:: iccp_ports
                
                	ICCP Port Table
                	**type**\:   :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.IccpSm.IccpGroups.IccpGroup, self).__init__()

                    self.yang_name = "iccp-group"
                    self.yang_parent_name = "iccp-groups"

                    self.group_id = YLeaf(YType.uint32, "group-id")

                    self.iccp_group_info = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                    self.iccp_group_info.parent = self
                    self._children_name_map["iccp_group_info"] = "iccp-group-info"
                    self._children_yang_names.add("iccp-group-info")

                    self.iccp_ports = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                    self.iccp_ports.parent = self
                    self._children_name_map["iccp_ports"] = "iccp-ports"
                    self._children_yang_names.add("iccp-ports")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.IccpSm.IccpGroups.IccpGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.IccpSm.IccpGroups.IccpGroup, self).__setattr__(name, value)


                class IccpGroupInfo(Entity):
                    """
                    ICCP Group Information
                    
                    .. attribute:: group_id
                    
                    	Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: iccp_member_up
                    
                    	ICCP Member Up
                    	**type**\:  bool
                    
                    .. attribute:: iccp_transport_up
                    
                    	ICCP Transport Up
                    	**type**\:  bool
                    
                    .. attribute:: local_node_id
                    
                    	Local Node ID
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ports
                    
                    	List of ports in the group
                    	**type**\: list of    :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                    
                    .. attribute:: remote_node_id
                    
                    	Remote Node ID
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`IccpSmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmState>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__init__()

                        self.yang_name = "iccp-group-info"
                        self.yang_parent_name = "iccp-group"

                        self.group_id = YLeaf(YType.uint32, "group-id")

                        self.iccp_member_up = YLeaf(YType.boolean, "iccp-member-up")

                        self.iccp_transport_up = YLeaf(YType.boolean, "iccp-transport-up")

                        self.local_node_id = YLeaf(YType.uint8, "local-node-id")

                        self.remote_node_id = YLeaf(YType.uint8, "remote-node-id")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.ports = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_id",
                                        "iccp_member_up",
                                        "iccp_transport_up",
                                        "local_node_id",
                                        "remote_node_id",
                                        "state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__setattr__(name, value)


                    class Ports(Entity):
                        """
                        List of ports in the group
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: local_port
                        
                        	Local port info
                        	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                        
                        .. attribute:: mac_flush_tcn
                        
                        	Is MAC flush through STP\-TCN?
                        	**type**\:  bool
                        
                        .. attribute:: remote_port
                        
                        	Remote port info
                        	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__init__()

                            self.yang_name = "ports"
                            self.yang_parent_name = "iccp-group-info"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.mac_flush_tcn = YLeaf(YType.boolean, "mac-flush-tcn")

                            self.local_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                            self.local_port.parent = self
                            self._children_name_map["local_port"] = "local-port"
                            self._children_yang_names.add("local-port")

                            self.remote_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                            self.remote_port.parent = self
                            self._children_name_map["remote_port"] = "remote-port"
                            self._children_yang_names.add("remote-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "mac_flush_tcn") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__setattr__(name, value)


                        class LocalPort(Entity):
                            """
                            Local port info
                            
                            .. attribute:: fsm_state
                            
                            	FSM state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_fail_code
                            
                            	Port fail code
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_state
                            
                            	Port state
                            	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                            
                            .. attribute:: reversion_time
                            
                            	Reversion Time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reversion_time_remaining
                            
                            	Reversion Time Remaining
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vlan_state
                            
                            	VLAN state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vlan_vector
                            
                            	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__init__()

                                self.yang_name = "local-port"
                                self.yang_parent_name = "ports"

                                self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                self.port_state = YLeaf(YType.enumeration, "port-state")

                                self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fsm_state",
                                                "port_fail_code",
                                                "port_state",
                                                "reversion_time",
                                                "reversion_time_remaining",
                                                "vlan_state",
                                                "vlan_vector") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fsm_state.is_set or
                                    self.port_fail_code.is_set or
                                    self.port_state.is_set or
                                    self.reversion_time.is_set or
                                    self.reversion_time_remaining.is_set or
                                    self.vlan_state.is_set or
                                    self.vlan_vector.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fsm_state.yfilter != YFilter.not_set or
                                    self.port_fail_code.yfilter != YFilter.not_set or
                                    self.port_state.yfilter != YFilter.not_set or
                                    self.reversion_time.yfilter != YFilter.not_set or
                                    self.reversion_time_remaining.yfilter != YFilter.not_set or
                                    self.vlan_state.yfilter != YFilter.not_set or
                                    self.vlan_vector.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-port" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_state.get_name_leafdata())
                                if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fsm-state"):
                                    self.fsm_state = value
                                    self.fsm_state.value_namespace = name_space
                                    self.fsm_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-fail-code"):
                                    self.port_fail_code = value
                                    self.port_fail_code.value_namespace = name_space
                                    self.port_fail_code.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-state"):
                                    self.port_state = value
                                    self.port_state.value_namespace = name_space
                                    self.port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "reversion-time"):
                                    self.reversion_time = value
                                    self.reversion_time.value_namespace = name_space
                                    self.reversion_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "reversion-time-remaining"):
                                    self.reversion_time_remaining = value
                                    self.reversion_time_remaining.value_namespace = name_space
                                    self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                if(value_path == "vlan-state"):
                                    self.vlan_state = value
                                    self.vlan_state.value_namespace = name_space
                                    self.vlan_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "vlan-vector"):
                                    self.vlan_vector = value
                                    self.vlan_vector.value_namespace = name_space
                                    self.vlan_vector.value_namespace_prefix = name_space_prefix


                        class RemotePort(Entity):
                            """
                            Remote port info
                            
                            .. attribute:: fsm_state
                            
                            	FSM state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_fail_code
                            
                            	Port fail code
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_state
                            
                            	Port state
                            	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                            
                            .. attribute:: reversion_time
                            
                            	Reversion Time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reversion_time_remaining
                            
                            	Reversion Time Remaining
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vlan_state
                            
                            	VLAN state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vlan_vector
                            
                            	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__init__()

                                self.yang_name = "remote-port"
                                self.yang_parent_name = "ports"

                                self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                self.port_state = YLeaf(YType.enumeration, "port-state")

                                self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fsm_state",
                                                "port_fail_code",
                                                "port_state",
                                                "reversion_time",
                                                "reversion_time_remaining",
                                                "vlan_state",
                                                "vlan_vector") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fsm_state.is_set or
                                    self.port_fail_code.is_set or
                                    self.port_state.is_set or
                                    self.reversion_time.is_set or
                                    self.reversion_time_remaining.is_set or
                                    self.vlan_state.is_set or
                                    self.vlan_vector.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fsm_state.yfilter != YFilter.not_set or
                                    self.port_fail_code.yfilter != YFilter.not_set or
                                    self.port_state.yfilter != YFilter.not_set or
                                    self.reversion_time.yfilter != YFilter.not_set or
                                    self.reversion_time_remaining.yfilter != YFilter.not_set or
                                    self.vlan_state.yfilter != YFilter.not_set or
                                    self.vlan_vector.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-port" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_state.get_name_leafdata())
                                if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fsm-state"):
                                    self.fsm_state = value
                                    self.fsm_state.value_namespace = name_space
                                    self.fsm_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-fail-code"):
                                    self.port_fail_code = value
                                    self.port_fail_code.value_namespace = name_space
                                    self.port_fail_code.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-state"):
                                    self.port_state = value
                                    self.port_state.value_namespace = name_space
                                    self.port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "reversion-time"):
                                    self.reversion_time = value
                                    self.reversion_time.value_namespace = name_space
                                    self.reversion_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "reversion-time-remaining"):
                                    self.reversion_time_remaining = value
                                    self.reversion_time_remaining.value_namespace = name_space
                                    self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                if(value_path == "vlan-state"):
                                    self.vlan_state = value
                                    self.vlan_state.value_namespace = name_space
                                    self.vlan_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "vlan-vector"):
                                    self.vlan_vector = value
                                    self.vlan_vector.value_namespace = name_space
                                    self.vlan_vector.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.mac_flush_tcn.is_set or
                                (self.local_port is not None and self.local_port.has_data()) or
                                (self.remote_port is not None and self.remote_port.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.mac_flush_tcn.yfilter != YFilter.not_set or
                                (self.local_port is not None and self.local_port.has_operation()) or
                                (self.remote_port is not None and self.remote_port.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ports" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.mac_flush_tcn.is_set or self.mac_flush_tcn.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_flush_tcn.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "local-port"):
                                if (self.local_port is None):
                                    self.local_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                    self.local_port.parent = self
                                    self._children_name_map["local_port"] = "local-port"
                                return self.local_port

                            if (child_yang_name == "remote-port"):
                                if (self.remote_port is None):
                                    self.remote_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                    self.remote_port.parent = self
                                    self._children_name_map["remote_port"] = "remote-port"
                                return self.remote_port

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-port" or name == "remote-port" or name == "interface-name" or name == "mac-flush-tcn"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-flush-tcn"):
                                self.mac_flush_tcn = value
                                self.mac_flush_tcn.value_namespace = name_space
                                self.mac_flush_tcn.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ports:
                            if (c.has_data()):
                                return True
                        return (
                            self.group_id.is_set or
                            self.iccp_member_up.is_set or
                            self.iccp_transport_up.is_set or
                            self.local_node_id.is_set or
                            self.remote_node_id.is_set or
                            self.state.is_set)

                    def has_operation(self):
                        for c in self.ports:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_id.yfilter != YFilter.not_set or
                            self.iccp_member_up.yfilter != YFilter.not_set or
                            self.iccp_transport_up.yfilter != YFilter.not_set or
                            self.local_node_id.yfilter != YFilter.not_set or
                            self.remote_node_id.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-group-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_id.get_name_leafdata())
                        if (self.iccp_member_up.is_set or self.iccp_member_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_member_up.get_name_leafdata())
                        if (self.iccp_transport_up.is_set or self.iccp_transport_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_transport_up.get_name_leafdata())
                        if (self.local_node_id.is_set or self.local_node_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_node_id.get_name_leafdata())
                        if (self.remote_node_id.is_set or self.remote_node_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_node_id.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ports"):
                            for c in self.ports:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ports.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ports" or name == "group-id" or name == "iccp-member-up" or name == "iccp-transport-up" or name == "local-node-id" or name == "remote-node-id" or name == "state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-id"):
                            self.group_id = value
                            self.group_id.value_namespace = name_space
                            self.group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "iccp-member-up"):
                            self.iccp_member_up = value
                            self.iccp_member_up.value_namespace = name_space
                            self.iccp_member_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "iccp-transport-up"):
                            self.iccp_transport_up = value
                            self.iccp_transport_up.value_namespace = name_space
                            self.iccp_transport_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-node-id"):
                            self.local_node_id = value
                            self.local_node_id.value_namespace = name_space
                            self.local_node_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-node-id"):
                            self.remote_node_id = value
                            self.remote_node_id.value_namespace = name_space
                            self.remote_node_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix


                class IccpPorts(Entity):
                    """
                    ICCP Port Table
                    
                    .. attribute:: iccp_port
                    
                    	ICCP Port
                    	**type**\: list of    :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__init__()

                        self.yang_name = "iccp-ports"
                        self.yang_parent_name = "iccp-group"

                        self.iccp_port = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__setattr__(name, value)


                    class IccpPort(Entity):
                        """
                        ICCP Port
                        
                        .. attribute:: interface  <key>
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: local_port
                        
                        	Local port info
                        	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                        
                        .. attribute:: mac_flush_tcn
                        
                        	Is MAC flush through STP\-TCN?
                        	**type**\:  bool
                        
                        .. attribute:: remote_port
                        
                        	Remote port info
                        	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__init__()

                            self.yang_name = "iccp-port"
                            self.yang_parent_name = "iccp-ports"

                            self.interface = YLeaf(YType.str, "interface")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.mac_flush_tcn = YLeaf(YType.boolean, "mac-flush-tcn")

                            self.local_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                            self.local_port.parent = self
                            self._children_name_map["local_port"] = "local-port"
                            self._children_yang_names.add("local-port")

                            self.remote_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                            self.remote_port.parent = self
                            self._children_name_map["remote_port"] = "remote-port"
                            self._children_yang_names.add("remote-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface",
                                            "interface_name",
                                            "mac_flush_tcn") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__setattr__(name, value)


                        class LocalPort(Entity):
                            """
                            Local port info
                            
                            .. attribute:: fsm_state
                            
                            	FSM state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_fail_code
                            
                            	Port fail code
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_state
                            
                            	Port state
                            	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                            
                            .. attribute:: reversion_time
                            
                            	Reversion Time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reversion_time_remaining
                            
                            	Reversion Time Remaining
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vlan_state
                            
                            	VLAN state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vlan_vector
                            
                            	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__init__()

                                self.yang_name = "local-port"
                                self.yang_parent_name = "iccp-port"

                                self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                self.port_state = YLeaf(YType.enumeration, "port-state")

                                self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fsm_state",
                                                "port_fail_code",
                                                "port_state",
                                                "reversion_time",
                                                "reversion_time_remaining",
                                                "vlan_state",
                                                "vlan_vector") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fsm_state.is_set or
                                    self.port_fail_code.is_set or
                                    self.port_state.is_set or
                                    self.reversion_time.is_set or
                                    self.reversion_time_remaining.is_set or
                                    self.vlan_state.is_set or
                                    self.vlan_vector.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fsm_state.yfilter != YFilter.not_set or
                                    self.port_fail_code.yfilter != YFilter.not_set or
                                    self.port_state.yfilter != YFilter.not_set or
                                    self.reversion_time.yfilter != YFilter.not_set or
                                    self.reversion_time_remaining.yfilter != YFilter.not_set or
                                    self.vlan_state.yfilter != YFilter.not_set or
                                    self.vlan_vector.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-port" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_state.get_name_leafdata())
                                if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fsm-state"):
                                    self.fsm_state = value
                                    self.fsm_state.value_namespace = name_space
                                    self.fsm_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-fail-code"):
                                    self.port_fail_code = value
                                    self.port_fail_code.value_namespace = name_space
                                    self.port_fail_code.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-state"):
                                    self.port_state = value
                                    self.port_state.value_namespace = name_space
                                    self.port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "reversion-time"):
                                    self.reversion_time = value
                                    self.reversion_time.value_namespace = name_space
                                    self.reversion_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "reversion-time-remaining"):
                                    self.reversion_time_remaining = value
                                    self.reversion_time_remaining.value_namespace = name_space
                                    self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                if(value_path == "vlan-state"):
                                    self.vlan_state = value
                                    self.vlan_state.value_namespace = name_space
                                    self.vlan_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "vlan-vector"):
                                    self.vlan_vector = value
                                    self.vlan_vector.value_namespace = name_space
                                    self.vlan_vector.value_namespace_prefix = name_space_prefix


                        class RemotePort(Entity):
                            """
                            Remote port info
                            
                            .. attribute:: fsm_state
                            
                            	FSM state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_fail_code
                            
                            	Port fail code
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_state
                            
                            	Port state
                            	**type**\:   :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                            
                            .. attribute:: reversion_time
                            
                            	Reversion Time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reversion_time_remaining
                            
                            	Reversion Time Remaining
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vlan_state
                            
                            	VLAN state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vlan_vector
                            
                            	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__init__()

                                self.yang_name = "remote-port"
                                self.yang_parent_name = "iccp-port"

                                self.fsm_state = YLeaf(YType.uint8, "fsm-state")

                                self.port_fail_code = YLeaf(YType.uint8, "port-fail-code")

                                self.port_state = YLeaf(YType.enumeration, "port-state")

                                self.reversion_time = YLeaf(YType.uint32, "reversion-time")

                                self.reversion_time_remaining = YLeaf(YType.uint32, "reversion-time-remaining")

                                self.vlan_state = YLeaf(YType.uint8, "vlan-state")

                                self.vlan_vector = YLeaf(YType.str, "vlan-vector")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fsm_state",
                                                "port_fail_code",
                                                "port_state",
                                                "reversion_time",
                                                "reversion_time_remaining",
                                                "vlan_state",
                                                "vlan_vector") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.fsm_state.is_set or
                                    self.port_fail_code.is_set or
                                    self.port_state.is_set or
                                    self.reversion_time.is_set or
                                    self.reversion_time_remaining.is_set or
                                    self.vlan_state.is_set or
                                    self.vlan_vector.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fsm_state.yfilter != YFilter.not_set or
                                    self.port_fail_code.yfilter != YFilter.not_set or
                                    self.port_state.yfilter != YFilter.not_set or
                                    self.reversion_time.yfilter != YFilter.not_set or
                                    self.reversion_time_remaining.yfilter != YFilter.not_set or
                                    self.vlan_state.yfilter != YFilter.not_set or
                                    self.vlan_vector.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-port" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fsm_state.is_set or self.fsm_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fsm_state.get_name_leafdata())
                                if (self.port_fail_code.is_set or self.port_fail_code.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_fail_code.get_name_leafdata())
                                if (self.port_state.is_set or self.port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_state.get_name_leafdata())
                                if (self.reversion_time.is_set or self.reversion_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reversion_time.get_name_leafdata())
                                if (self.reversion_time_remaining.is_set or self.reversion_time_remaining.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reversion_time_remaining.get_name_leafdata())
                                if (self.vlan_state.is_set or self.vlan_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vlan_state.get_name_leafdata())
                                if (self.vlan_vector.is_set or self.vlan_vector.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vlan_vector.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "fsm-state" or name == "port-fail-code" or name == "port-state" or name == "reversion-time" or name == "reversion-time-remaining" or name == "vlan-state" or name == "vlan-vector"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fsm-state"):
                                    self.fsm_state = value
                                    self.fsm_state.value_namespace = name_space
                                    self.fsm_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-fail-code"):
                                    self.port_fail_code = value
                                    self.port_fail_code.value_namespace = name_space
                                    self.port_fail_code.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-state"):
                                    self.port_state = value
                                    self.port_state.value_namespace = name_space
                                    self.port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "reversion-time"):
                                    self.reversion_time = value
                                    self.reversion_time.value_namespace = name_space
                                    self.reversion_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "reversion-time-remaining"):
                                    self.reversion_time_remaining = value
                                    self.reversion_time_remaining.value_namespace = name_space
                                    self.reversion_time_remaining.value_namespace_prefix = name_space_prefix
                                if(value_path == "vlan-state"):
                                    self.vlan_state = value
                                    self.vlan_state.value_namespace = name_space
                                    self.vlan_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "vlan-vector"):
                                    self.vlan_vector = value
                                    self.vlan_vector.value_namespace = name_space
                                    self.vlan_vector.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface.is_set or
                                self.interface_name.is_set or
                                self.mac_flush_tcn.is_set or
                                (self.local_port is not None and self.local_port.has_data()) or
                                (self.remote_port is not None and self.remote_port.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.mac_flush_tcn.yfilter != YFilter.not_set or
                                (self.local_port is not None and self.local_port.has_operation()) or
                                (self.remote_port is not None and self.remote_port.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-port" + "[interface='" + self.interface.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.mac_flush_tcn.is_set or self.mac_flush_tcn.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_flush_tcn.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "local-port"):
                                if (self.local_port is None):
                                    self.local_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                    self.local_port.parent = self
                                    self._children_name_map["local_port"] = "local-port"
                                return self.local_port

                            if (child_yang_name == "remote-port"):
                                if (self.remote_port is None):
                                    self.remote_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                    self.remote_port.parent = self
                                    self._children_name_map["remote_port"] = "remote-port"
                                return self.remote_port

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-port" or name == "remote-port" or name == "interface" or name == "interface-name" or name == "mac-flush-tcn"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface"):
                                self.interface = value
                                self.interface.value_namespace = name_space
                                self.interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-flush-tcn"):
                                self.mac_flush_tcn = value
                                self.mac_flush_tcn.value_namespace = name_space
                                self.mac_flush_tcn.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.iccp_port:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.iccp_port:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-ports" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-port"):
                            for c in self.iccp_port:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.iccp_port.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-port"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.group_id.is_set or
                        (self.iccp_group_info is not None and self.iccp_group_info.has_data()) or
                        (self.iccp_ports is not None and self.iccp_ports.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_id.yfilter != YFilter.not_set or
                        (self.iccp_group_info is not None and self.iccp_group_info.has_operation()) or
                        (self.iccp_ports is not None and self.iccp_ports.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "iccp-group" + "[group-id='" + self.group_id.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/iccp-sm/iccp-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_id.is_set or self.group_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "iccp-group-info"):
                        if (self.iccp_group_info is None):
                            self.iccp_group_info = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                            self.iccp_group_info.parent = self
                            self._children_name_map["iccp_group_info"] = "iccp-group-info"
                        return self.iccp_group_info

                    if (child_yang_name == "iccp-ports"):
                        if (self.iccp_ports is None):
                            self.iccp_ports = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                            self.iccp_ports.parent = self
                            self._children_name_map["iccp_ports"] = "iccp-ports"
                        return self.iccp_ports

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "iccp-group-info" or name == "iccp-ports" or name == "group-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-id"):
                        self.group_id = value
                        self.group_id.value_namespace = name_space
                        self.group_id.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.iccp_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.iccp_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "iccp-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/iccp-sm/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "iccp-group"):
                    for c in self.iccp_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.IccpSm.IccpGroups.IccpGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.iccp_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "iccp-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.iccp_groups is not None and self.iccp_groups.has_data()) or
                (self.iccp_sm_summary is not None and self.iccp_sm_summary.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.iccp_groups is not None and self.iccp_groups.has_operation()) or
                (self.iccp_sm_summary is not None and self.iccp_sm_summary.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "iccp-sm" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "iccp-groups"):
                if (self.iccp_groups is None):
                    self.iccp_groups = L2Vpn.IccpSm.IccpGroups()
                    self.iccp_groups.parent = self
                    self._children_name_map["iccp_groups"] = "iccp-groups"
                return self.iccp_groups

            if (child_yang_name == "iccp-sm-summary"):
                if (self.iccp_sm_summary is None):
                    self.iccp_sm_summary = L2Vpn.IccpSm.IccpSmSummary()
                    self.iccp_sm_summary.parent = self
                    self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"
                return self.iccp_sm_summary

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "iccp-groups" or name == "iccp-sm-summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class BridgeSummary(Entity):
        """
        Bridge Domain summary information
        
        .. attribute:: num_vn_is
        
        	Number of VNIs
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: num_vn_is_down
        
        	Number of VNIs down
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: num_vn_is_unresolved
        
        	Number of VNIs unresolved
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: num_vn_is_up
        
        	Number of VNIs up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_a_cs
        
        	Number of attachment circuits
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_a_cs_up
        
        	Number of attachment circuits whose state is up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_bridge_domains
        
        	Number of bridge\-domains
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_bridge_domains_shut
        
        	Number of bridge\-domains admin disabled
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_bridge_domains_up
        
        	Number of bridge\-domains up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_default_bridge_doamins
        
        	Number of default bridge\-domains
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_groups
        
        	Number of groups
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_p2mp
        
        	Number of P2MPs
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_p2mp_down
        
        	Number of P2MPs whose state is down
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_p2mp_up
        
        	Number of P2MPs whose state is up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_p_ws_up
        
        	Number of pseudowires whose state is up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_pbb_core
        
        	Number of PBB Core
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_pbb_edge
        
        	Number of PBB Edge
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_pseudowires
        
        	Number of pseudowires
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: out_of_memory_state
        
        	L2VPN Out of memory state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: partially_programmed_a_cs
        
        	Number of partially programmed attachment circuits
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: partially_programmed_bridges
        
        	Number of partially programmed bridge\-domains
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: partially_programmed_pseudowires
        
        	Number of partially programmed pseudowires
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: standby_pseudowires
        
        	Number of pseudowires whose state is standby
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.BridgeSummary, self).__init__()

            self.yang_name = "bridge-summary"
            self.yang_parent_name = "l2vpn"

            self.num_vn_is = YLeaf(YType.uint32, "num-vn-is")

            self.num_vn_is_down = YLeaf(YType.uint32, "num-vn-is-down")

            self.num_vn_is_unresolved = YLeaf(YType.uint32, "num-vn-is-unresolved")

            self.num_vn_is_up = YLeaf(YType.uint32, "num-vn-is-up")

            self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

            self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

            self.number_bridge_domains = YLeaf(YType.uint32, "number-bridge-domains")

            self.number_bridge_domains_shut = YLeaf(YType.uint32, "number-bridge-domains-shut")

            self.number_bridge_domains_up = YLeaf(YType.uint32, "number-bridge-domains-up")

            self.number_default_bridge_doamins = YLeaf(YType.uint32, "number-default-bridge-doamins")

            self.number_groups = YLeaf(YType.uint32, "number-groups")

            self.number_p2mp = YLeaf(YType.uint32, "number-p2mp")

            self.number_p2mp_down = YLeaf(YType.uint32, "number-p2mp-down")

            self.number_p2mp_up = YLeaf(YType.uint32, "number-p2mp-up")

            self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

            self.number_pbb_core = YLeaf(YType.uint32, "number-pbb-core")

            self.number_pbb_edge = YLeaf(YType.uint32, "number-pbb-edge")

            self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

            self.partially_programmed_a_cs = YLeaf(YType.uint32, "partially-programmed-a-cs")

            self.partially_programmed_bridges = YLeaf(YType.uint32, "partially-programmed-bridges")

            self.partially_programmed_pseudowires = YLeaf(YType.uint32, "partially-programmed-pseudowires")

            self.standby_pseudowires = YLeaf(YType.uint32, "standby-pseudowires")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("num_vn_is",
                            "num_vn_is_down",
                            "num_vn_is_unresolved",
                            "num_vn_is_up",
                            "number_a_cs",
                            "number_a_cs_up",
                            "number_bridge_domains",
                            "number_bridge_domains_shut",
                            "number_bridge_domains_up",
                            "number_default_bridge_doamins",
                            "number_groups",
                            "number_p2mp",
                            "number_p2mp_down",
                            "number_p2mp_up",
                            "number_p_ws_up",
                            "number_pbb_core",
                            "number_pbb_edge",
                            "number_pseudowires",
                            "out_of_memory_state",
                            "partially_programmed_a_cs",
                            "partially_programmed_bridges",
                            "partially_programmed_pseudowires",
                            "standby_pseudowires") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.BridgeSummary, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.BridgeSummary, self).__setattr__(name, value)

        def has_data(self):
            return (
                self.num_vn_is.is_set or
                self.num_vn_is_down.is_set or
                self.num_vn_is_unresolved.is_set or
                self.num_vn_is_up.is_set or
                self.number_a_cs.is_set or
                self.number_a_cs_up.is_set or
                self.number_bridge_domains.is_set or
                self.number_bridge_domains_shut.is_set or
                self.number_bridge_domains_up.is_set or
                self.number_default_bridge_doamins.is_set or
                self.number_groups.is_set or
                self.number_p2mp.is_set or
                self.number_p2mp_down.is_set or
                self.number_p2mp_up.is_set or
                self.number_p_ws_up.is_set or
                self.number_pbb_core.is_set or
                self.number_pbb_edge.is_set or
                self.number_pseudowires.is_set or
                self.out_of_memory_state.is_set or
                self.partially_programmed_a_cs.is_set or
                self.partially_programmed_bridges.is_set or
                self.partially_programmed_pseudowires.is_set or
                self.standby_pseudowires.is_set)

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.num_vn_is.yfilter != YFilter.not_set or
                self.num_vn_is_down.yfilter != YFilter.not_set or
                self.num_vn_is_unresolved.yfilter != YFilter.not_set or
                self.num_vn_is_up.yfilter != YFilter.not_set or
                self.number_a_cs.yfilter != YFilter.not_set or
                self.number_a_cs_up.yfilter != YFilter.not_set or
                self.number_bridge_domains.yfilter != YFilter.not_set or
                self.number_bridge_domains_shut.yfilter != YFilter.not_set or
                self.number_bridge_domains_up.yfilter != YFilter.not_set or
                self.number_default_bridge_doamins.yfilter != YFilter.not_set or
                self.number_groups.yfilter != YFilter.not_set or
                self.number_p2mp.yfilter != YFilter.not_set or
                self.number_p2mp_down.yfilter != YFilter.not_set or
                self.number_p2mp_up.yfilter != YFilter.not_set or
                self.number_p_ws_up.yfilter != YFilter.not_set or
                self.number_pbb_core.yfilter != YFilter.not_set or
                self.number_pbb_edge.yfilter != YFilter.not_set or
                self.number_pseudowires.yfilter != YFilter.not_set or
                self.out_of_memory_state.yfilter != YFilter.not_set or
                self.partially_programmed_a_cs.yfilter != YFilter.not_set or
                self.partially_programmed_bridges.yfilter != YFilter.not_set or
                self.partially_programmed_pseudowires.yfilter != YFilter.not_set or
                self.standby_pseudowires.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "bridge-summary" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.num_vn_is.is_set or self.num_vn_is.yfilter != YFilter.not_set):
                leaf_name_data.append(self.num_vn_is.get_name_leafdata())
            if (self.num_vn_is_down.is_set or self.num_vn_is_down.yfilter != YFilter.not_set):
                leaf_name_data.append(self.num_vn_is_down.get_name_leafdata())
            if (self.num_vn_is_unresolved.is_set or self.num_vn_is_unresolved.yfilter != YFilter.not_set):
                leaf_name_data.append(self.num_vn_is_unresolved.get_name_leafdata())
            if (self.num_vn_is_up.is_set or self.num_vn_is_up.yfilter != YFilter.not_set):
                leaf_name_data.append(self.num_vn_is_up.get_name_leafdata())
            if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_a_cs.get_name_leafdata())
            if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
            if (self.number_bridge_domains.is_set or self.number_bridge_domains.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_bridge_domains.get_name_leafdata())
            if (self.number_bridge_domains_shut.is_set or self.number_bridge_domains_shut.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_bridge_domains_shut.get_name_leafdata())
            if (self.number_bridge_domains_up.is_set or self.number_bridge_domains_up.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_bridge_domains_up.get_name_leafdata())
            if (self.number_default_bridge_doamins.is_set or self.number_default_bridge_doamins.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_default_bridge_doamins.get_name_leafdata())
            if (self.number_groups.is_set or self.number_groups.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_groups.get_name_leafdata())
            if (self.number_p2mp.is_set or self.number_p2mp.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_p2mp.get_name_leafdata())
            if (self.number_p2mp_down.is_set or self.number_p2mp_down.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_p2mp_down.get_name_leafdata())
            if (self.number_p2mp_up.is_set or self.number_p2mp_up.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_p2mp_up.get_name_leafdata())
            if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
            if (self.number_pbb_core.is_set or self.number_pbb_core.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_pbb_core.get_name_leafdata())
            if (self.number_pbb_edge.is_set or self.number_pbb_edge.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_pbb_edge.get_name_leafdata())
            if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
            if (self.partially_programmed_a_cs.is_set or self.partially_programmed_a_cs.yfilter != YFilter.not_set):
                leaf_name_data.append(self.partially_programmed_a_cs.get_name_leafdata())
            if (self.partially_programmed_bridges.is_set or self.partially_programmed_bridges.yfilter != YFilter.not_set):
                leaf_name_data.append(self.partially_programmed_bridges.get_name_leafdata())
            if (self.partially_programmed_pseudowires.is_set or self.partially_programmed_pseudowires.yfilter != YFilter.not_set):
                leaf_name_data.append(self.partially_programmed_pseudowires.get_name_leafdata())
            if (self.standby_pseudowires.is_set or self.standby_pseudowires.yfilter != YFilter.not_set):
                leaf_name_data.append(self.standby_pseudowires.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "num-vn-is" or name == "num-vn-is-down" or name == "num-vn-is-unresolved" or name == "num-vn-is-up" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-bridge-domains" or name == "number-bridge-domains-shut" or name == "number-bridge-domains-up" or name == "number-default-bridge-doamins" or name == "number-groups" or name == "number-p2mp" or name == "number-p2mp-down" or name == "number-p2mp-up" or name == "number-p-ws-up" or name == "number-pbb-core" or name == "number-pbb-edge" or name == "number-pseudowires" or name == "out-of-memory-state" or name == "partially-programmed-a-cs" or name == "partially-programmed-bridges" or name == "partially-programmed-pseudowires" or name == "standby-pseudowires"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "num-vn-is"):
                self.num_vn_is = value
                self.num_vn_is.value_namespace = name_space
                self.num_vn_is.value_namespace_prefix = name_space_prefix
            if(value_path == "num-vn-is-down"):
                self.num_vn_is_down = value
                self.num_vn_is_down.value_namespace = name_space
                self.num_vn_is_down.value_namespace_prefix = name_space_prefix
            if(value_path == "num-vn-is-unresolved"):
                self.num_vn_is_unresolved = value
                self.num_vn_is_unresolved.value_namespace = name_space
                self.num_vn_is_unresolved.value_namespace_prefix = name_space_prefix
            if(value_path == "num-vn-is-up"):
                self.num_vn_is_up = value
                self.num_vn_is_up.value_namespace = name_space
                self.num_vn_is_up.value_namespace_prefix = name_space_prefix
            if(value_path == "number-a-cs"):
                self.number_a_cs = value
                self.number_a_cs.value_namespace = name_space
                self.number_a_cs.value_namespace_prefix = name_space_prefix
            if(value_path == "number-a-cs-up"):
                self.number_a_cs_up = value
                self.number_a_cs_up.value_namespace = name_space
                self.number_a_cs_up.value_namespace_prefix = name_space_prefix
            if(value_path == "number-bridge-domains"):
                self.number_bridge_domains = value
                self.number_bridge_domains.value_namespace = name_space
                self.number_bridge_domains.value_namespace_prefix = name_space_prefix
            if(value_path == "number-bridge-domains-shut"):
                self.number_bridge_domains_shut = value
                self.number_bridge_domains_shut.value_namespace = name_space
                self.number_bridge_domains_shut.value_namespace_prefix = name_space_prefix
            if(value_path == "number-bridge-domains-up"):
                self.number_bridge_domains_up = value
                self.number_bridge_domains_up.value_namespace = name_space
                self.number_bridge_domains_up.value_namespace_prefix = name_space_prefix
            if(value_path == "number-default-bridge-doamins"):
                self.number_default_bridge_doamins = value
                self.number_default_bridge_doamins.value_namespace = name_space
                self.number_default_bridge_doamins.value_namespace_prefix = name_space_prefix
            if(value_path == "number-groups"):
                self.number_groups = value
                self.number_groups.value_namespace = name_space
                self.number_groups.value_namespace_prefix = name_space_prefix
            if(value_path == "number-p2mp"):
                self.number_p2mp = value
                self.number_p2mp.value_namespace = name_space
                self.number_p2mp.value_namespace_prefix = name_space_prefix
            if(value_path == "number-p2mp-down"):
                self.number_p2mp_down = value
                self.number_p2mp_down.value_namespace = name_space
                self.number_p2mp_down.value_namespace_prefix = name_space_prefix
            if(value_path == "number-p2mp-up"):
                self.number_p2mp_up = value
                self.number_p2mp_up.value_namespace = name_space
                self.number_p2mp_up.value_namespace_prefix = name_space_prefix
            if(value_path == "number-p-ws-up"):
                self.number_p_ws_up = value
                self.number_p_ws_up.value_namespace = name_space
                self.number_p_ws_up.value_namespace_prefix = name_space_prefix
            if(value_path == "number-pbb-core"):
                self.number_pbb_core = value
                self.number_pbb_core.value_namespace = name_space
                self.number_pbb_core.value_namespace_prefix = name_space_prefix
            if(value_path == "number-pbb-edge"):
                self.number_pbb_edge = value
                self.number_pbb_edge.value_namespace = name_space
                self.number_pbb_edge.value_namespace_prefix = name_space_prefix
            if(value_path == "number-pseudowires"):
                self.number_pseudowires = value
                self.number_pseudowires.value_namespace = name_space
                self.number_pseudowires.value_namespace_prefix = name_space_prefix
            if(value_path == "out-of-memory-state"):
                self.out_of_memory_state = value
                self.out_of_memory_state.value_namespace = name_space
                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
            if(value_path == "partially-programmed-a-cs"):
                self.partially_programmed_a_cs = value
                self.partially_programmed_a_cs.value_namespace = name_space
                self.partially_programmed_a_cs.value_namespace_prefix = name_space_prefix
            if(value_path == "partially-programmed-bridges"):
                self.partially_programmed_bridges = value
                self.partially_programmed_bridges.value_namespace = name_space
                self.partially_programmed_bridges.value_namespace_prefix = name_space_prefix
            if(value_path == "partially-programmed-pseudowires"):
                self.partially_programmed_pseudowires = value
                self.partially_programmed_pseudowires.value_namespace = name_space
                self.partially_programmed_pseudowires.value_namespace_prefix = name_space_prefix
            if(value_path == "standby-pseudowires"):
                self.standby_pseudowires = value
                self.standby_pseudowires.value_namespace = name_space
                self.standby_pseudowires.value_namespace_prefix = name_space_prefix


    class Nsr(Entity):
        """
        L2VPN NSR information
        
        .. attribute:: event_history
        
        	L2VPN Process event history
        	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.EventHistory>`
        
        .. attribute:: failover_status
        
        	L2VPN failover status
        	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.FailoverStatus>`
        
        .. attribute:: issu_status
        
        	L2VPN ISSU Status and timestamp
        	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.IssuStatus>`
        
        .. attribute:: nsr_status
        
        	L2VPN NSR status and timestamp
        	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.NsrStatus>`
        
        .. attribute:: process_role
        
        	Current Process Role
        	**type**\:  int
        
        	**range:** 0..255
        
        .. attribute:: process_state
        
        	Current Process State
        	**type**\:  int
        
        	**range:** 0..255
        
        .. attribute:: report_card
        
        	L2VPN Collaborator report card
        	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.ReportCard>`
        
        .. attribute:: state_transition_time
        
        	Transition time for all states
        	**type**\:  list of int
        
        	**range:** 0..4294967295
        
        .. attribute:: sw_install_in_progress
        
        	Is s/w install currently in progress?
        	**type**\:  bool
        
        .. attribute:: sync_flags
        
        	Sync complete flags
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: xid_info
        
        	XID information
        	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.XidInfo>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.Nsr, self).__init__()

            self.yang_name = "nsr"
            self.yang_parent_name = "l2vpn"

            self.process_role = YLeaf(YType.uint8, "process-role")

            self.process_state = YLeaf(YType.uint8, "process-state")

            self.state_transition_time = YLeafList(YType.uint32, "state-transition-time")

            self.sw_install_in_progress = YLeaf(YType.boolean, "sw-install-in-progress")

            self.sync_flags = YLeaf(YType.uint32, "sync-flags")

            self.failover_status = L2Vpn.Nsr.FailoverStatus()
            self.failover_status.parent = self
            self._children_name_map["failover_status"] = "failover-status"
            self._children_yang_names.add("failover-status")

            self.issu_status = L2Vpn.Nsr.IssuStatus()
            self.issu_status.parent = self
            self._children_name_map["issu_status"] = "issu-status"
            self._children_yang_names.add("issu-status")

            self.nsr_status = L2Vpn.Nsr.NsrStatus()
            self.nsr_status.parent = self
            self._children_name_map["nsr_status"] = "nsr-status"
            self._children_yang_names.add("nsr-status")

            self.event_history = YList(self)
            self.report_card = YList(self)
            self.xid_info = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("process_role",
                            "process_state",
                            "state_transition_time",
                            "sw_install_in_progress",
                            "sync_flags") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.Nsr, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.Nsr, self).__setattr__(name, value)


        class FailoverStatus(Entity):
            """
            L2VPN failover status
            
            .. attribute:: master_time
            
            	Master time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: start_time
            
            	Start time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: triggered_time
            
            	Triggered time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Nsr.FailoverStatus, self).__init__()

                self.yang_name = "failover-status"
                self.yang_parent_name = "nsr"

                self.master_time = YLeaf(YType.uint32, "master-time")

                self.start_time = YLeaf(YType.uint32, "start-time")

                self.triggered_time = YLeaf(YType.uint32, "triggered-time")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("master_time",
                                "start_time",
                                "triggered_time") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Nsr.FailoverStatus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Nsr.FailoverStatus, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.master_time.is_set or
                    self.start_time.is_set or
                    self.triggered_time.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.master_time.yfilter != YFilter.not_set or
                    self.start_time.yfilter != YFilter.not_set or
                    self.triggered_time.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "failover-status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/nsr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.master_time.is_set or self.master_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.master_time.get_name_leafdata())
                if (self.start_time.is_set or self.start_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.start_time.get_name_leafdata())
                if (self.triggered_time.is_set or self.triggered_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.triggered_time.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "master-time" or name == "start-time" or name == "triggered-time"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "master-time"):
                    self.master_time = value
                    self.master_time.value_namespace = name_space
                    self.master_time.value_namespace_prefix = name_space_prefix
                if(value_path == "start-time"):
                    self.start_time = value
                    self.start_time.value_namespace = name_space
                    self.start_time.value_namespace_prefix = name_space_prefix
                if(value_path == "triggered-time"):
                    self.triggered_time = value
                    self.triggered_time.value_namespace = name_space
                    self.triggered_time.value_namespace_prefix = name_space_prefix


        class NsrStatus(Entity):
            """
            L2VPN NSR status and timestamp
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.NsrStatus.IdtStatus>`
            
            .. attribute:: previ_ous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.NsrStatus.PreviOusIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Nsr.NsrStatus, self).__init__()

                self.yang_name = "nsr-status"
                self.yang_parent_name = "nsr"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = L2Vpn.Nsr.NsrStatus.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previ_ous_idt_status = L2Vpn.Nsr.NsrStatus.PreviOusIdtStatus()
                self.previ_ous_idt_status.parent = self
                self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                self._children_yang_names.add("previ-ous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Nsr.NsrStatus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Nsr.NsrStatus, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Nsr.NsrStatus.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "nsr-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Nsr.NsrStatus.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Nsr.NsrStatus.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/nsr/nsr-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviOusIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Nsr.NsrStatus.PreviOusIdtStatus, self).__init__()

                    self.yang_name = "previ-ous-idt-status"
                    self.yang_parent_name = "nsr-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Nsr.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Nsr.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previ-ous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/nsr/nsr-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "nsr-status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/nsr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = L2Vpn.Nsr.NsrStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previ-ous-idt-status"):
                    if (self.previ_ous_idt_status is None):
                        self.previ_ous_idt_status = L2Vpn.Nsr.NsrStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    return self.previ_ous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix


        class IssuStatus(Entity):
            """
            L2VPN ISSU Status and timestamp
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.IssuStatus.IdtStatus>`
            
            .. attribute:: previ_ous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.IssuStatus.PreviOusIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Nsr.IssuStatus, self).__init__()

                self.yang_name = "issu-status"
                self.yang_parent_name = "nsr"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = L2Vpn.Nsr.IssuStatus.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previ_ous_idt_status = L2Vpn.Nsr.IssuStatus.PreviOusIdtStatus()
                self.previ_ous_idt_status.parent = self
                self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                self._children_yang_names.add("previ-ous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Nsr.IssuStatus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Nsr.IssuStatus, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Nsr.IssuStatus.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "issu-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Nsr.IssuStatus.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Nsr.IssuStatus.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/nsr/issu-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviOusIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Nsr.IssuStatus.PreviOusIdtStatus, self).__init__()

                    self.yang_name = "previ-ous-idt-status"
                    self.yang_parent_name = "issu-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Nsr.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Nsr.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previ-ous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/nsr/issu-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "issu-status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/nsr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = L2Vpn.Nsr.IssuStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previ-ous-idt-status"):
                    if (self.previ_ous_idt_status is None):
                        self.previ_ous_idt_status = L2Vpn.Nsr.IssuStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    return self.previ_ous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix


        class XidInfo(Entity):
            """
            XID information
            
            .. attribute:: app_type
            
            	App type
            	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
            
            .. attribute:: sent_ids
            
            	Number of XIDs transferred
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Nsr.XidInfo, self).__init__()

                self.yang_name = "xid-info"
                self.yang_parent_name = "nsr"

                self.app_type = YLeaf(YType.enumeration, "app-type")

                self.sent_ids = YLeaf(YType.uint32, "sent-ids")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("app_type",
                                "sent_ids") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Nsr.XidInfo, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Nsr.XidInfo, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.app_type.is_set or
                    self.sent_ids.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.app_type.yfilter != YFilter.not_set or
                    self.sent_ids.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xid-info" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/nsr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.app_type.is_set or self.app_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.app_type.get_name_leafdata())
                if (self.sent_ids.is_set or self.sent_ids.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sent_ids.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "app-type" or name == "sent-ids"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "app-type"):
                    self.app_type = value
                    self.app_type.value_namespace = name_space
                    self.app_type.value_namespace_prefix = name_space_prefix
                if(value_path == "sent-ids"):
                    self.sent_ids = value
                    self.sent_ids.value_namespace = name_space
                    self.sent_ids.value_namespace_prefix = name_space_prefix


        class ReportCard(Entity):
            """
            L2VPN Collaborator report card
            
            .. attribute:: collaborator_idt_done
            
            	Is IDT done for this collaborator
            	**type**\:  bool
            
            .. attribute:: collaborator_is_connected
            
            	Is the collaborator connected
            	**type**\:  bool
            
            .. attribute:: collaborator_skipped
            
            	Was this collaborator skipped for not connecting in time
            	**type**\:  bool
            
            .. attribute:: connection_change_time
            
            	Time when connection state (UP/DOWN) changed
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: idt_time
            
            	Time when IDT was done
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Nsr.ReportCard, self).__init__()

                self.yang_name = "report-card"
                self.yang_parent_name = "nsr"

                self.collaborator_idt_done = YLeaf(YType.boolean, "collaborator-idt-done")

                self.collaborator_is_connected = YLeaf(YType.boolean, "collaborator-is-connected")

                self.collaborator_skipped = YLeaf(YType.boolean, "collaborator-skipped")

                self.connection_change_time = YLeaf(YType.uint32, "connection-change-time")

                self.idt_time = YLeaf(YType.uint32, "idt-time")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("collaborator_idt_done",
                                "collaborator_is_connected",
                                "collaborator_skipped",
                                "connection_change_time",
                                "idt_time") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Nsr.ReportCard, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Nsr.ReportCard, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.collaborator_idt_done.is_set or
                    self.collaborator_is_connected.is_set or
                    self.collaborator_skipped.is_set or
                    self.connection_change_time.is_set or
                    self.idt_time.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.collaborator_idt_done.yfilter != YFilter.not_set or
                    self.collaborator_is_connected.yfilter != YFilter.not_set or
                    self.collaborator_skipped.yfilter != YFilter.not_set or
                    self.connection_change_time.yfilter != YFilter.not_set or
                    self.idt_time.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "report-card" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/nsr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.collaborator_idt_done.is_set or self.collaborator_idt_done.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.collaborator_idt_done.get_name_leafdata())
                if (self.collaborator_is_connected.is_set or self.collaborator_is_connected.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.collaborator_is_connected.get_name_leafdata())
                if (self.collaborator_skipped.is_set or self.collaborator_skipped.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.collaborator_skipped.get_name_leafdata())
                if (self.connection_change_time.is_set or self.connection_change_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.connection_change_time.get_name_leafdata())
                if (self.idt_time.is_set or self.idt_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.idt_time.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "collaborator-idt-done" or name == "collaborator-is-connected" or name == "collaborator-skipped" or name == "connection-change-time" or name == "idt-time"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "collaborator-idt-done"):
                    self.collaborator_idt_done = value
                    self.collaborator_idt_done.value_namespace = name_space
                    self.collaborator_idt_done.value_namespace_prefix = name_space_prefix
                if(value_path == "collaborator-is-connected"):
                    self.collaborator_is_connected = value
                    self.collaborator_is_connected.value_namespace = name_space
                    self.collaborator_is_connected.value_namespace_prefix = name_space_prefix
                if(value_path == "collaborator-skipped"):
                    self.collaborator_skipped = value
                    self.collaborator_skipped.value_namespace = name_space
                    self.collaborator_skipped.value_namespace_prefix = name_space_prefix
                if(value_path == "connection-change-time"):
                    self.connection_change_time = value
                    self.connection_change_time.value_namespace = name_space
                    self.connection_change_time.value_namespace_prefix = name_space_prefix
                if(value_path == "idt-time"):
                    self.idt_time = value
                    self.idt_time.value_namespace = name_space
                    self.idt_time.value_namespace_prefix = name_space_prefix


        class EventHistory(Entity):
            """
            L2VPN Process event history
            
            .. attribute:: event_timestamp
            
            	Event timestamp
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: new_state
            
            	New state
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: previous_state
            
            	Previous state
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_collaborator
            
            	Process collaborator
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: process_event
            
            	Process event
            	**type**\:  int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Nsr.EventHistory, self).__init__()

                self.yang_name = "event-history"
                self.yang_parent_name = "nsr"

                self.event_timestamp = YLeaf(YType.uint32, "event-timestamp")

                self.new_state = YLeaf(YType.uint8, "new-state")

                self.previous_state = YLeaf(YType.uint8, "previous-state")

                self.process_collaborator = YLeaf(YType.uint16, "process-collaborator")

                self.process_event = YLeaf(YType.uint16, "process-event")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("event_timestamp",
                                "new_state",
                                "previous_state",
                                "process_collaborator",
                                "process_event") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Nsr.EventHistory, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Nsr.EventHistory, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.event_timestamp.is_set or
                    self.new_state.is_set or
                    self.previous_state.is_set or
                    self.process_collaborator.is_set or
                    self.process_event.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.event_timestamp.yfilter != YFilter.not_set or
                    self.new_state.yfilter != YFilter.not_set or
                    self.previous_state.yfilter != YFilter.not_set or
                    self.process_collaborator.yfilter != YFilter.not_set or
                    self.process_event.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "event-history" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/nsr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.event_timestamp.is_set or self.event_timestamp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.event_timestamp.get_name_leafdata())
                if (self.new_state.is_set or self.new_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.new_state.get_name_leafdata())
                if (self.previous_state.is_set or self.previous_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.previous_state.get_name_leafdata())
                if (self.process_collaborator.is_set or self.process_collaborator.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_collaborator.get_name_leafdata())
                if (self.process_event.is_set or self.process_event.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_event.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "event-timestamp" or name == "new-state" or name == "previous-state" or name == "process-collaborator" or name == "process-event"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "event-timestamp"):
                    self.event_timestamp = value
                    self.event_timestamp.value_namespace = name_space
                    self.event_timestamp.value_namespace_prefix = name_space_prefix
                if(value_path == "new-state"):
                    self.new_state = value
                    self.new_state.value_namespace = name_space
                    self.new_state.value_namespace_prefix = name_space_prefix
                if(value_path == "previous-state"):
                    self.previous_state = value
                    self.previous_state.value_namespace = name_space
                    self.previous_state.value_namespace_prefix = name_space_prefix
                if(value_path == "process-collaborator"):
                    self.process_collaborator = value
                    self.process_collaborator.value_namespace = name_space
                    self.process_collaborator.value_namespace_prefix = name_space_prefix
                if(value_path == "process-event"):
                    self.process_event = value
                    self.process_event.value_namespace = name_space
                    self.process_event.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.event_history:
                if (c.has_data()):
                    return True
            for c in self.report_card:
                if (c.has_data()):
                    return True
            for c in self.xid_info:
                if (c.has_data()):
                    return True
            for leaf in self.state_transition_time.getYLeafs():
                if (leaf.yfilter != YFilter.not_set):
                    return True
            return (
                self.process_role.is_set or
                self.process_state.is_set or
                self.sw_install_in_progress.is_set or
                self.sync_flags.is_set or
                (self.failover_status is not None and self.failover_status.has_data()) or
                (self.issu_status is not None and self.issu_status.has_data()) or
                (self.nsr_status is not None and self.nsr_status.has_data()))

        def has_operation(self):
            for c in self.event_history:
                if (c.has_operation()):
                    return True
            for c in self.report_card:
                if (c.has_operation()):
                    return True
            for c in self.xid_info:
                if (c.has_operation()):
                    return True
            for leaf in self.state_transition_time.getYLeafs():
                if (leaf.is_set):
                    return True
            return (
                self.yfilter != YFilter.not_set or
                self.process_role.yfilter != YFilter.not_set or
                self.process_state.yfilter != YFilter.not_set or
                self.state_transition_time.yfilter != YFilter.not_set or
                self.sw_install_in_progress.yfilter != YFilter.not_set or
                self.sync_flags.yfilter != YFilter.not_set or
                (self.failover_status is not None and self.failover_status.has_operation()) or
                (self.issu_status is not None and self.issu_status.has_operation()) or
                (self.nsr_status is not None and self.nsr_status.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "nsr" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.process_role.is_set or self.process_role.yfilter != YFilter.not_set):
                leaf_name_data.append(self.process_role.get_name_leafdata())
            if (self.process_state.is_set or self.process_state.yfilter != YFilter.not_set):
                leaf_name_data.append(self.process_state.get_name_leafdata())
            if (self.sw_install_in_progress.is_set or self.sw_install_in_progress.yfilter != YFilter.not_set):
                leaf_name_data.append(self.sw_install_in_progress.get_name_leafdata())
            if (self.sync_flags.is_set or self.sync_flags.yfilter != YFilter.not_set):
                leaf_name_data.append(self.sync_flags.get_name_leafdata())

            leaf_name_data.extend(self.state_transition_time.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "event-history"):
                for c in self.event_history:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.Nsr.EventHistory()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.event_history.append(c)
                return c

            if (child_yang_name == "failover-status"):
                if (self.failover_status is None):
                    self.failover_status = L2Vpn.Nsr.FailoverStatus()
                    self.failover_status.parent = self
                    self._children_name_map["failover_status"] = "failover-status"
                return self.failover_status

            if (child_yang_name == "issu-status"):
                if (self.issu_status is None):
                    self.issu_status = L2Vpn.Nsr.IssuStatus()
                    self.issu_status.parent = self
                    self._children_name_map["issu_status"] = "issu-status"
                return self.issu_status

            if (child_yang_name == "nsr-status"):
                if (self.nsr_status is None):
                    self.nsr_status = L2Vpn.Nsr.NsrStatus()
                    self.nsr_status.parent = self
                    self._children_name_map["nsr_status"] = "nsr-status"
                return self.nsr_status

            if (child_yang_name == "report-card"):
                for c in self.report_card:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.Nsr.ReportCard()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.report_card.append(c)
                return c

            if (child_yang_name == "xid-info"):
                for c in self.xid_info:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.Nsr.XidInfo()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.xid_info.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "event-history" or name == "failover-status" or name == "issu-status" or name == "nsr-status" or name == "report-card" or name == "xid-info" or name == "process-role" or name == "process-state" or name == "state-transition-time" or name == "sw-install-in-progress" or name == "sync-flags"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "process-role"):
                self.process_role = value
                self.process_role.value_namespace = name_space
                self.process_role.value_namespace_prefix = name_space_prefix
            if(value_path == "process-state"):
                self.process_state = value
                self.process_state.value_namespace = name_space
                self.process_state.value_namespace_prefix = name_space_prefix
            if(value_path == "state-transition-time"):
                self.state_transition_time.append(value)
            if(value_path == "sw-install-in-progress"):
                self.sw_install_in_progress = value
                self.sw_install_in_progress.value_namespace = name_space
                self.sw_install_in_progress.value_namespace_prefix = name_space_prefix
            if(value_path == "sync-flags"):
                self.sync_flags = value
                self.sync_flags.value_namespace = name_space
                self.sync_flags.value_namespace_prefix = name_space_prefix


    class GlobalSettings(Entity):
        """
        L2VPN global settings
        
        .. attribute:: going_active
        
        	transitioning to Active functional role
        	**type**\:  bool
        
        .. attribute:: ha_role
        
        	Node redundancy role
        	**type**\:  str
        
        .. attribute:: issu_role
        
        	Node ISSU role
        	**type**\:  str
        
        .. attribute:: logging_bd_enabled
        
        	Logging BD state changes enabled
        	**type**\:  bool
        
        .. attribute:: logging_df_election_enabled
        
        	Logging EVPN Designated Forwarder changes enabled
        	**type**\:  bool
        
        .. attribute:: logging_nsr_enabled
        
        	Logging NSR state changes enabled
        	**type**\:  bool
        
        .. attribute:: logging_pw_enabled
        
        	Logging PW enabled
        	**type**\:  bool
        
        .. attribute:: logging_vfi_enabled
        
        	Logging VFI state changes enabled
        	**type**\:  bool
        
        .. attribute:: process_fsm
        
        	Current L2VPN FSM role
        	**type**\:  str
        
        .. attribute:: pw_grouping_enabled
        
        	PW Grouping enabled
        	**type**\:  bool
        
        .. attribute:: pw_oam_refresh_transmit_time
        
        	PW OAM refresh transmit (seconds)
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: second
        
        .. attribute:: pw_status_enabled
        
        	PW Status enabled
        	**type**\:  bool
        
        .. attribute:: tcn_propagation_enabled
        
        	TCN propagation enabled
        	**type**\:  bool
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.GlobalSettings, self).__init__()

            self.yang_name = "global-settings"
            self.yang_parent_name = "l2vpn"

            self.going_active = YLeaf(YType.boolean, "going-active")

            self.ha_role = YLeaf(YType.str, "ha-role")

            self.issu_role = YLeaf(YType.str, "issu-role")

            self.logging_bd_enabled = YLeaf(YType.boolean, "logging-bd-enabled")

            self.logging_df_election_enabled = YLeaf(YType.boolean, "logging-df-election-enabled")

            self.logging_nsr_enabled = YLeaf(YType.boolean, "logging-nsr-enabled")

            self.logging_pw_enabled = YLeaf(YType.boolean, "logging-pw-enabled")

            self.logging_vfi_enabled = YLeaf(YType.boolean, "logging-vfi-enabled")

            self.process_fsm = YLeaf(YType.str, "process-fsm")

            self.pw_grouping_enabled = YLeaf(YType.boolean, "pw-grouping-enabled")

            self.pw_oam_refresh_transmit_time = YLeaf(YType.uint32, "pw-oam-refresh-transmit-time")

            self.pw_status_enabled = YLeaf(YType.boolean, "pw-status-enabled")

            self.tcn_propagation_enabled = YLeaf(YType.boolean, "tcn-propagation-enabled")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("going_active",
                            "ha_role",
                            "issu_role",
                            "logging_bd_enabled",
                            "logging_df_election_enabled",
                            "logging_nsr_enabled",
                            "logging_pw_enabled",
                            "logging_vfi_enabled",
                            "process_fsm",
                            "pw_grouping_enabled",
                            "pw_oam_refresh_transmit_time",
                            "pw_status_enabled",
                            "tcn_propagation_enabled") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.GlobalSettings, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.GlobalSettings, self).__setattr__(name, value)

        def has_data(self):
            return (
                self.going_active.is_set or
                self.ha_role.is_set or
                self.issu_role.is_set or
                self.logging_bd_enabled.is_set or
                self.logging_df_election_enabled.is_set or
                self.logging_nsr_enabled.is_set or
                self.logging_pw_enabled.is_set or
                self.logging_vfi_enabled.is_set or
                self.process_fsm.is_set or
                self.pw_grouping_enabled.is_set or
                self.pw_oam_refresh_transmit_time.is_set or
                self.pw_status_enabled.is_set or
                self.tcn_propagation_enabled.is_set)

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.going_active.yfilter != YFilter.not_set or
                self.ha_role.yfilter != YFilter.not_set or
                self.issu_role.yfilter != YFilter.not_set or
                self.logging_bd_enabled.yfilter != YFilter.not_set or
                self.logging_df_election_enabled.yfilter != YFilter.not_set or
                self.logging_nsr_enabled.yfilter != YFilter.not_set or
                self.logging_pw_enabled.yfilter != YFilter.not_set or
                self.logging_vfi_enabled.yfilter != YFilter.not_set or
                self.process_fsm.yfilter != YFilter.not_set or
                self.pw_grouping_enabled.yfilter != YFilter.not_set or
                self.pw_oam_refresh_transmit_time.yfilter != YFilter.not_set or
                self.pw_status_enabled.yfilter != YFilter.not_set or
                self.tcn_propagation_enabled.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "global-settings" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.going_active.is_set or self.going_active.yfilter != YFilter.not_set):
                leaf_name_data.append(self.going_active.get_name_leafdata())
            if (self.ha_role.is_set or self.ha_role.yfilter != YFilter.not_set):
                leaf_name_data.append(self.ha_role.get_name_leafdata())
            if (self.issu_role.is_set or self.issu_role.yfilter != YFilter.not_set):
                leaf_name_data.append(self.issu_role.get_name_leafdata())
            if (self.logging_bd_enabled.is_set or self.logging_bd_enabled.yfilter != YFilter.not_set):
                leaf_name_data.append(self.logging_bd_enabled.get_name_leafdata())
            if (self.logging_df_election_enabled.is_set or self.logging_df_election_enabled.yfilter != YFilter.not_set):
                leaf_name_data.append(self.logging_df_election_enabled.get_name_leafdata())
            if (self.logging_nsr_enabled.is_set or self.logging_nsr_enabled.yfilter != YFilter.not_set):
                leaf_name_data.append(self.logging_nsr_enabled.get_name_leafdata())
            if (self.logging_pw_enabled.is_set or self.logging_pw_enabled.yfilter != YFilter.not_set):
                leaf_name_data.append(self.logging_pw_enabled.get_name_leafdata())
            if (self.logging_vfi_enabled.is_set or self.logging_vfi_enabled.yfilter != YFilter.not_set):
                leaf_name_data.append(self.logging_vfi_enabled.get_name_leafdata())
            if (self.process_fsm.is_set or self.process_fsm.yfilter != YFilter.not_set):
                leaf_name_data.append(self.process_fsm.get_name_leafdata())
            if (self.pw_grouping_enabled.is_set or self.pw_grouping_enabled.yfilter != YFilter.not_set):
                leaf_name_data.append(self.pw_grouping_enabled.get_name_leafdata())
            if (self.pw_oam_refresh_transmit_time.is_set or self.pw_oam_refresh_transmit_time.yfilter != YFilter.not_set):
                leaf_name_data.append(self.pw_oam_refresh_transmit_time.get_name_leafdata())
            if (self.pw_status_enabled.is_set or self.pw_status_enabled.yfilter != YFilter.not_set):
                leaf_name_data.append(self.pw_status_enabled.get_name_leafdata())
            if (self.tcn_propagation_enabled.is_set or self.tcn_propagation_enabled.yfilter != YFilter.not_set):
                leaf_name_data.append(self.tcn_propagation_enabled.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "going-active" or name == "ha-role" or name == "issu-role" or name == "logging-bd-enabled" or name == "logging-df-election-enabled" or name == "logging-nsr-enabled" or name == "logging-pw-enabled" or name == "logging-vfi-enabled" or name == "process-fsm" or name == "pw-grouping-enabled" or name == "pw-oam-refresh-transmit-time" or name == "pw-status-enabled" or name == "tcn-propagation-enabled"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "going-active"):
                self.going_active = value
                self.going_active.value_namespace = name_space
                self.going_active.value_namespace_prefix = name_space_prefix
            if(value_path == "ha-role"):
                self.ha_role = value
                self.ha_role.value_namespace = name_space
                self.ha_role.value_namespace_prefix = name_space_prefix
            if(value_path == "issu-role"):
                self.issu_role = value
                self.issu_role.value_namespace = name_space
                self.issu_role.value_namespace_prefix = name_space_prefix
            if(value_path == "logging-bd-enabled"):
                self.logging_bd_enabled = value
                self.logging_bd_enabled.value_namespace = name_space
                self.logging_bd_enabled.value_namespace_prefix = name_space_prefix
            if(value_path == "logging-df-election-enabled"):
                self.logging_df_election_enabled = value
                self.logging_df_election_enabled.value_namespace = name_space
                self.logging_df_election_enabled.value_namespace_prefix = name_space_prefix
            if(value_path == "logging-nsr-enabled"):
                self.logging_nsr_enabled = value
                self.logging_nsr_enabled.value_namespace = name_space
                self.logging_nsr_enabled.value_namespace_prefix = name_space_prefix
            if(value_path == "logging-pw-enabled"):
                self.logging_pw_enabled = value
                self.logging_pw_enabled.value_namespace = name_space
                self.logging_pw_enabled.value_namespace_prefix = name_space_prefix
            if(value_path == "logging-vfi-enabled"):
                self.logging_vfi_enabled = value
                self.logging_vfi_enabled.value_namespace = name_space
                self.logging_vfi_enabled.value_namespace_prefix = name_space_prefix
            if(value_path == "process-fsm"):
                self.process_fsm = value
                self.process_fsm.value_namespace = name_space
                self.process_fsm.value_namespace_prefix = name_space_prefix
            if(value_path == "pw-grouping-enabled"):
                self.pw_grouping_enabled = value
                self.pw_grouping_enabled.value_namespace = name_space
                self.pw_grouping_enabled.value_namespace_prefix = name_space_prefix
            if(value_path == "pw-oam-refresh-transmit-time"):
                self.pw_oam_refresh_transmit_time = value
                self.pw_oam_refresh_transmit_time.value_namespace = name_space
                self.pw_oam_refresh_transmit_time.value_namespace_prefix = name_space_prefix
            if(value_path == "pw-status-enabled"):
                self.pw_status_enabled = value
                self.pw_status_enabled.value_namespace = name_space
                self.pw_status_enabled.value_namespace_prefix = name_space_prefix
            if(value_path == "tcn-propagation-enabled"):
                self.tcn_propagation_enabled = value
                self.tcn_propagation_enabled.value_namespace = name_space
                self.tcn_propagation_enabled.value_namespace_prefix = name_space_prefix


    class Pwr(Entity):
        """
        Pseudowire Routing Table
        
        .. attribute:: summary
        
        	L2VPN Pseudowire Routing Summary
        	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.Pwr, self).__init__()

            self.yang_name = "pwr"
            self.yang_parent_name = "l2vpn"

            self.summary = L2Vpn.Pwr.Summary()
            self.summary.parent = self
            self._children_name_map["summary"] = "summary"
            self._children_yang_names.add("summary")


        class Summary(Entity):
            """
            L2VPN Pseudowire Routing Summary
            
            .. attribute:: bgp_as
            
            	BGP AS number
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: bgp_router_id
            
            	BGP Router ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: cfg_global_id
            
            	Configured Global ID
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: cfg_router_id
            
            	Configured Router ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: l2vpn_has_bgp_eod
            
            	L2VPN got BGP EOD
            	**type**\:  bool
            
            .. attribute:: rd_auto
            
            	Automatic Route Distingtuisher
            	**type**\:   :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdAuto>`
            
            .. attribute:: rd_configured
            
            	Configured Route Distinguisher
            	**type**\:   :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdConfigured>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Pwr.Summary, self).__init__()

                self.yang_name = "summary"
                self.yang_parent_name = "pwr"

                self.bgp_as = YLeaf(YType.uint32, "bgp-as")

                self.bgp_router_id = YLeaf(YType.str, "bgp-router-id")

                self.cfg_global_id = YLeaf(YType.uint32, "cfg-global-id")

                self.cfg_router_id = YLeaf(YType.str, "cfg-router-id")

                self.l2vpn_has_bgp_eod = YLeaf(YType.boolean, "l2vpn-has-bgp-eod")

                self.rd_auto = L2Vpn.Pwr.Summary.RdAuto()
                self.rd_auto.parent = self
                self._children_name_map["rd_auto"] = "rd-auto"
                self._children_yang_names.add("rd-auto")

                self.rd_configured = L2Vpn.Pwr.Summary.RdConfigured()
                self.rd_configured.parent = self
                self._children_name_map["rd_configured"] = "rd-configured"
                self._children_yang_names.add("rd-configured")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("bgp_as",
                                "bgp_router_id",
                                "cfg_global_id",
                                "cfg_router_id",
                                "l2vpn_has_bgp_eod") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Pwr.Summary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Pwr.Summary, self).__setattr__(name, value)


            class RdAuto(Entity):
                """
                Automatic Route Distingtuisher
                
                .. attribute:: auto
                
                	auto
                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdAuto.Auto>`
                
                .. attribute:: four_byte_as
                
                	four byte as
                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdAuto.FourByteAs>`
                
                .. attribute:: rd
                
                	RD
                	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                
                .. attribute:: two_byte_as
                
                	two byte as
                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdAuto.TwoByteAs>`
                
                .. attribute:: v4_addr
                
                	v4 addr
                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdAuto.V4Addr>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Pwr.Summary.RdAuto, self).__init__()

                    self.yang_name = "rd-auto"
                    self.yang_parent_name = "summary"

                    self.rd = YLeaf(YType.enumeration, "rd")

                    self.auto = L2Vpn.Pwr.Summary.RdAuto.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._children_yang_names.add("auto")

                    self.four_byte_as = L2Vpn.Pwr.Summary.RdAuto.FourByteAs()
                    self.four_byte_as.parent = self
                    self._children_name_map["four_byte_as"] = "four-byte-as"
                    self._children_yang_names.add("four-byte-as")

                    self.two_byte_as = L2Vpn.Pwr.Summary.RdAuto.TwoByteAs()
                    self.two_byte_as.parent = self
                    self._children_name_map["two_byte_as"] = "two-byte-as"
                    self._children_yang_names.add("two-byte-as")

                    self.v4_addr = L2Vpn.Pwr.Summary.RdAuto.V4Addr()
                    self.v4_addr.parent = self
                    self._children_name_map["v4_addr"] = "v4-addr"
                    self._children_yang_names.add("v4-addr")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("rd") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Pwr.Summary.RdAuto, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Pwr.Summary.RdAuto, self).__setattr__(name, value)


                class Auto(Entity):
                    """
                    auto
                    
                    .. attribute:: auto_index
                    
                    	Auto\-generated Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: router_id
                    
                    	BGP Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Pwr.Summary.RdAuto.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "rd-auto"

                        self.auto_index = YLeaf(YType.uint16, "auto-index")

                        self.router_id = YLeaf(YType.str, "router-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("auto_index",
                                        "router_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Pwr.Summary.RdAuto.Auto, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Pwr.Summary.RdAuto.Auto, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.auto_index.is_set or
                            self.router_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.auto_index.yfilter != YFilter.not_set or
                            self.router_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "auto" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/summary/rd-auto/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auto_index.get_name_leafdata())
                        if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auto-index" or name == "router-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "auto-index"):
                            self.auto_index = value
                            self.auto_index.value_namespace = name_space
                            self.auto_index.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-id"):
                            self.router_id = value
                            self.router_id.value_namespace = name_space
                            self.router_id.value_namespace_prefix = name_space_prefix


                class TwoByteAs(Entity):
                    """
                    two byte as
                    
                    .. attribute:: four_byte_index
                    
                    	4 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: two_byte_as
                    
                    	2 Byte AS Number
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Pwr.Summary.RdAuto.TwoByteAs, self).__init__()

                        self.yang_name = "two-byte-as"
                        self.yang_parent_name = "rd-auto"

                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("four_byte_index",
                                        "two_byte_as") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Pwr.Summary.RdAuto.TwoByteAs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Pwr.Summary.RdAuto.TwoByteAs, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.four_byte_index.is_set or
                            self.two_byte_as.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.four_byte_index.yfilter != YFilter.not_set or
                            self.two_byte_as.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "two-byte-as" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/summary/rd-auto/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "four-byte-index" or name == "two-byte-as"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "four-byte-index"):
                            self.four_byte_index = value
                            self.four_byte_index.value_namespace = name_space
                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                        if(value_path == "two-byte-as"):
                            self.two_byte_as = value
                            self.two_byte_as.value_namespace = name_space
                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                class FourByteAs(Entity):
                    """
                    four byte as
                    
                    .. attribute:: four_byte_as
                    
                    	4 Byte AS Number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: two_byte_index
                    
                    	2 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Pwr.Summary.RdAuto.FourByteAs, self).__init__()

                        self.yang_name = "four-byte-as"
                        self.yang_parent_name = "rd-auto"

                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("four_byte_as",
                                        "two_byte_index") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Pwr.Summary.RdAuto.FourByteAs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Pwr.Summary.RdAuto.FourByteAs, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.four_byte_as.is_set or
                            self.two_byte_index.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.four_byte_as.yfilter != YFilter.not_set or
                            self.two_byte_index.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "four-byte-as" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/summary/rd-auto/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "four-byte-as" or name == "two-byte-index"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "four-byte-as"):
                            self.four_byte_as = value
                            self.four_byte_as.value_namespace = name_space
                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                        if(value_path == "two-byte-index"):
                            self.two_byte_index = value
                            self.two_byte_index.value_namespace = name_space
                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                class V4Addr(Entity):
                    """
                    v4 addr
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: two_byte_index
                    
                    	2 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Pwr.Summary.RdAuto.V4Addr, self).__init__()

                        self.yang_name = "v4-addr"
                        self.yang_parent_name = "rd-auto"

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ipv4_address",
                                        "two_byte_index") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Pwr.Summary.RdAuto.V4Addr, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Pwr.Summary.RdAuto.V4Addr, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ipv4_address.is_set or
                            self.two_byte_index.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ipv4_address.yfilter != YFilter.not_set or
                            self.two_byte_index.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "v4-addr" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/summary/rd-auto/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4-address" or name == "two-byte-index"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ipv4-address"):
                            self.ipv4_address = value
                            self.ipv4_address.value_namespace = name_space
                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "two-byte-index"):
                            self.two_byte_index = value
                            self.two_byte_index.value_namespace = name_space
                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.rd.is_set or
                        (self.auto is not None and self.auto.has_data()) or
                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                        (self.v4_addr is not None and self.v4_addr.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.rd.yfilter != YFilter.not_set or
                        (self.auto is not None and self.auto.has_operation()) or
                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rd-auto" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/summary/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rd.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "auto"):
                        if (self.auto is None):
                            self.auto = L2Vpn.Pwr.Summary.RdAuto.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"
                        return self.auto

                    if (child_yang_name == "four-byte-as"):
                        if (self.four_byte_as is None):
                            self.four_byte_as = L2Vpn.Pwr.Summary.RdAuto.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                        return self.four_byte_as

                    if (child_yang_name == "two-byte-as"):
                        if (self.two_byte_as is None):
                            self.two_byte_as = L2Vpn.Pwr.Summary.RdAuto.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                        return self.two_byte_as

                    if (child_yang_name == "v4-addr"):
                        if (self.v4_addr is None):
                            self.v4_addr = L2Vpn.Pwr.Summary.RdAuto.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                        return self.v4_addr

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "rd"):
                        self.rd = value
                        self.rd.value_namespace = name_space
                        self.rd.value_namespace_prefix = name_space_prefix


            class RdConfigured(Entity):
                """
                Configured Route Distinguisher
                
                .. attribute:: auto
                
                	auto
                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdConfigured.Auto>`
                
                .. attribute:: four_byte_as
                
                	four byte as
                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdConfigured.FourByteAs>`
                
                .. attribute:: rd
                
                	RD
                	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                
                .. attribute:: two_byte_as
                
                	two byte as
                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdConfigured.TwoByteAs>`
                
                .. attribute:: v4_addr
                
                	v4 addr
                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdConfigured.V4Addr>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Pwr.Summary.RdConfigured, self).__init__()

                    self.yang_name = "rd-configured"
                    self.yang_parent_name = "summary"

                    self.rd = YLeaf(YType.enumeration, "rd")

                    self.auto = L2Vpn.Pwr.Summary.RdConfigured.Auto()
                    self.auto.parent = self
                    self._children_name_map["auto"] = "auto"
                    self._children_yang_names.add("auto")

                    self.four_byte_as = L2Vpn.Pwr.Summary.RdConfigured.FourByteAs()
                    self.four_byte_as.parent = self
                    self._children_name_map["four_byte_as"] = "four-byte-as"
                    self._children_yang_names.add("four-byte-as")

                    self.two_byte_as = L2Vpn.Pwr.Summary.RdConfigured.TwoByteAs()
                    self.two_byte_as.parent = self
                    self._children_name_map["two_byte_as"] = "two-byte-as"
                    self._children_yang_names.add("two-byte-as")

                    self.v4_addr = L2Vpn.Pwr.Summary.RdConfigured.V4Addr()
                    self.v4_addr.parent = self
                    self._children_name_map["v4_addr"] = "v4-addr"
                    self._children_yang_names.add("v4-addr")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("rd") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Pwr.Summary.RdConfigured, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Pwr.Summary.RdConfigured, self).__setattr__(name, value)


                class Auto(Entity):
                    """
                    auto
                    
                    .. attribute:: auto_index
                    
                    	Auto\-generated Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: router_id
                    
                    	BGP Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Pwr.Summary.RdConfigured.Auto, self).__init__()

                        self.yang_name = "auto"
                        self.yang_parent_name = "rd-configured"

                        self.auto_index = YLeaf(YType.uint16, "auto-index")

                        self.router_id = YLeaf(YType.str, "router-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("auto_index",
                                        "router_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Pwr.Summary.RdConfigured.Auto, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Pwr.Summary.RdConfigured.Auto, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.auto_index.is_set or
                            self.router_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.auto_index.yfilter != YFilter.not_set or
                            self.router_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "auto" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/summary/rd-configured/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auto_index.get_name_leafdata())
                        if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auto-index" or name == "router-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "auto-index"):
                            self.auto_index = value
                            self.auto_index.value_namespace = name_space
                            self.auto_index.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-id"):
                            self.router_id = value
                            self.router_id.value_namespace = name_space
                            self.router_id.value_namespace_prefix = name_space_prefix


                class TwoByteAs(Entity):
                    """
                    two byte as
                    
                    .. attribute:: four_byte_index
                    
                    	4 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: two_byte_as
                    
                    	2 Byte AS Number
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Pwr.Summary.RdConfigured.TwoByteAs, self).__init__()

                        self.yang_name = "two-byte-as"
                        self.yang_parent_name = "rd-configured"

                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("four_byte_index",
                                        "two_byte_as") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Pwr.Summary.RdConfigured.TwoByteAs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Pwr.Summary.RdConfigured.TwoByteAs, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.four_byte_index.is_set or
                            self.two_byte_as.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.four_byte_index.yfilter != YFilter.not_set or
                            self.two_byte_as.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "two-byte-as" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/summary/rd-configured/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "four-byte-index" or name == "two-byte-as"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "four-byte-index"):
                            self.four_byte_index = value
                            self.four_byte_index.value_namespace = name_space
                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                        if(value_path == "two-byte-as"):
                            self.two_byte_as = value
                            self.two_byte_as.value_namespace = name_space
                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                class FourByteAs(Entity):
                    """
                    four byte as
                    
                    .. attribute:: four_byte_as
                    
                    	4 Byte AS Number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: two_byte_index
                    
                    	2 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Pwr.Summary.RdConfigured.FourByteAs, self).__init__()

                        self.yang_name = "four-byte-as"
                        self.yang_parent_name = "rd-configured"

                        self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("four_byte_as",
                                        "two_byte_index") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Pwr.Summary.RdConfigured.FourByteAs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Pwr.Summary.RdConfigured.FourByteAs, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.four_byte_as.is_set or
                            self.two_byte_index.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.four_byte_as.yfilter != YFilter.not_set or
                            self.two_byte_index.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "four-byte-as" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/summary/rd-configured/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "four-byte-as" or name == "two-byte-index"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "four-byte-as"):
                            self.four_byte_as = value
                            self.four_byte_as.value_namespace = name_space
                            self.four_byte_as.value_namespace_prefix = name_space_prefix
                        if(value_path == "two-byte-index"):
                            self.two_byte_index = value
                            self.two_byte_index.value_namespace = name_space
                            self.two_byte_index.value_namespace_prefix = name_space_prefix


                class V4Addr(Entity):
                    """
                    v4 addr
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: two_byte_index
                    
                    	2 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Pwr.Summary.RdConfigured.V4Addr, self).__init__()

                        self.yang_name = "v4-addr"
                        self.yang_parent_name = "rd-configured"

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ipv4_address",
                                        "two_byte_index") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Pwr.Summary.RdConfigured.V4Addr, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Pwr.Summary.RdConfigured.V4Addr, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ipv4_address.is_set or
                            self.two_byte_index.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ipv4_address.yfilter != YFilter.not_set or
                            self.two_byte_index.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "v4-addr" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/summary/rd-configured/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4-address" or name == "two-byte-index"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ipv4-address"):
                            self.ipv4_address = value
                            self.ipv4_address.value_namespace = name_space
                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "two-byte-index"):
                            self.two_byte_index = value
                            self.two_byte_index.value_namespace = name_space
                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.rd.is_set or
                        (self.auto is not None and self.auto.has_data()) or
                        (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                        (self.v4_addr is not None and self.v4_addr.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.rd.yfilter != YFilter.not_set or
                        (self.auto is not None and self.auto.has_operation()) or
                        (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rd-configured" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/summary/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rd.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "auto"):
                        if (self.auto is None):
                            self.auto = L2Vpn.Pwr.Summary.RdConfigured.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"
                        return self.auto

                    if (child_yang_name == "four-byte-as"):
                        if (self.four_byte_as is None):
                            self.four_byte_as = L2Vpn.Pwr.Summary.RdConfigured.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"
                        return self.four_byte_as

                    if (child_yang_name == "two-byte-as"):
                        if (self.two_byte_as is None):
                            self.two_byte_as = L2Vpn.Pwr.Summary.RdConfigured.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"
                        return self.two_byte_as

                    if (child_yang_name == "v4-addr"):
                        if (self.v4_addr is None):
                            self.v4_addr = L2Vpn.Pwr.Summary.RdConfigured.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                        return self.v4_addr

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "rd"):
                        self.rd = value
                        self.rd.value_namespace = name_space
                        self.rd.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.bgp_as.is_set or
                    self.bgp_router_id.is_set or
                    self.cfg_global_id.is_set or
                    self.cfg_router_id.is_set or
                    self.l2vpn_has_bgp_eod.is_set or
                    (self.rd_auto is not None and self.rd_auto.has_data()) or
                    (self.rd_configured is not None and self.rd_configured.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.bgp_as.yfilter != YFilter.not_set or
                    self.bgp_router_id.yfilter != YFilter.not_set or
                    self.cfg_global_id.yfilter != YFilter.not_set or
                    self.cfg_router_id.yfilter != YFilter.not_set or
                    self.l2vpn_has_bgp_eod.yfilter != YFilter.not_set or
                    (self.rd_auto is not None and self.rd_auto.has_operation()) or
                    (self.rd_configured is not None and self.rd_configured.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pwr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.bgp_as.is_set or self.bgp_as.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bgp_as.get_name_leafdata())
                if (self.bgp_router_id.is_set or self.bgp_router_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bgp_router_id.get_name_leafdata())
                if (self.cfg_global_id.is_set or self.cfg_global_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.cfg_global_id.get_name_leafdata())
                if (self.cfg_router_id.is_set or self.cfg_router_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.cfg_router_id.get_name_leafdata())
                if (self.l2vpn_has_bgp_eod.is_set or self.l2vpn_has_bgp_eod.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.l2vpn_has_bgp_eod.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "rd-auto"):
                    if (self.rd_auto is None):
                        self.rd_auto = L2Vpn.Pwr.Summary.RdAuto()
                        self.rd_auto.parent = self
                        self._children_name_map["rd_auto"] = "rd-auto"
                    return self.rd_auto

                if (child_yang_name == "rd-configured"):
                    if (self.rd_configured is None):
                        self.rd_configured = L2Vpn.Pwr.Summary.RdConfigured()
                        self.rd_configured.parent = self
                        self._children_name_map["rd_configured"] = "rd-configured"
                    return self.rd_configured

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "rd-auto" or name == "rd-configured" or name == "bgp-as" or name == "bgp-router-id" or name == "cfg-global-id" or name == "cfg-router-id" or name == "l2vpn-has-bgp-eod"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "bgp-as"):
                    self.bgp_as = value
                    self.bgp_as.value_namespace = name_space
                    self.bgp_as.value_namespace_prefix = name_space_prefix
                if(value_path == "bgp-router-id"):
                    self.bgp_router_id = value
                    self.bgp_router_id.value_namespace = name_space
                    self.bgp_router_id.value_namespace_prefix = name_space_prefix
                if(value_path == "cfg-global-id"):
                    self.cfg_global_id = value
                    self.cfg_global_id.value_namespace = name_space
                    self.cfg_global_id.value_namespace_prefix = name_space_prefix
                if(value_path == "cfg-router-id"):
                    self.cfg_router_id = value
                    self.cfg_router_id.value_namespace = name_space
                    self.cfg_router_id.value_namespace_prefix = name_space_prefix
                if(value_path == "l2vpn-has-bgp-eod"):
                    self.l2vpn_has_bgp_eod = value
                    self.l2vpn_has_bgp_eod.value_namespace = name_space
                    self.l2vpn_has_bgp_eod.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (self.summary is not None and self.summary.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.summary is not None and self.summary.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "pwr" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "summary"):
                if (self.summary is None):
                    self.summary = L2Vpn.Pwr.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                return self.summary

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class XconnectMp2MpCe2Ces(Entity):
        """
        XConnect MP2MP CE2CE Table
        
        .. attribute:: xconnect_mp2mp_ce2ce
        
        	XConnect MP2MP CE2CE information
        	**type**\: list of    :py:class:`XconnectMp2MpCe2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.XconnectMp2MpCe2Ces, self).__init__()

            self.yang_name = "xconnect-mp2mp-ce2ces"
            self.yang_parent_name = "l2vpn"

            self.xconnect_mp2mp_ce2ce = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.XconnectMp2MpCe2Ces, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.XconnectMp2MpCe2Ces, self).__setattr__(name, value)


        class XconnectMp2MpCe2Ce(Entity):
            """
            XConnect MP2MP CE2CE information
            
            .. attribute:: ce_added
            
            	CE2CE Advertised
            	**type**\:  bool
            
            .. attribute:: group_name
            
            	XConnect Group
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: local_ceid
            
            	Local CE ID
            	**type**\:  int
            
            	**range:** 1..4294967295
            
            .. attribute:: local_customer_edge_id
            
            	Local CE ID
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: mp2_mp_name
            
            	Mp2Mp Name
            	**type**\:  str
            
            	**length:** 1..26
            
            .. attribute:: remote_ceid
            
            	Remote CE ID
            	**type**\:  int
            
            	**range:** 1..4294967295
            
            .. attribute:: remote_customer_edge_id
            
            	Remote CE ID
            	**type**\:  int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__init__()

                self.yang_name = "xconnect-mp2mp-ce2ce"
                self.yang_parent_name = "xconnect-mp2mp-ce2ces"

                self.ce_added = YLeaf(YType.boolean, "ce-added")

                self.group_name = YLeaf(YType.str, "group-name")

                self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                self.local_customer_edge_id = YLeaf(YType.uint16, "local-customer-edge-id")

                self.mp2_mp_name = YLeaf(YType.str, "mp2-mp-name")

                self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                self.remote_customer_edge_id = YLeaf(YType.uint16, "remote-customer-edge-id")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("ce_added",
                                "group_name",
                                "local_ceid",
                                "local_customer_edge_id",
                                "mp2_mp_name",
                                "remote_ceid",
                                "remote_customer_edge_id") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.ce_added.is_set or
                    self.group_name.is_set or
                    self.local_ceid.is_set or
                    self.local_customer_edge_id.is_set or
                    self.mp2_mp_name.is_set or
                    self.remote_ceid.is_set or
                    self.remote_customer_edge_id.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.ce_added.yfilter != YFilter.not_set or
                    self.group_name.yfilter != YFilter.not_set or
                    self.local_ceid.yfilter != YFilter.not_set or
                    self.local_customer_edge_id.yfilter != YFilter.not_set or
                    self.mp2_mp_name.yfilter != YFilter.not_set or
                    self.remote_ceid.yfilter != YFilter.not_set or
                    self.remote_customer_edge_id.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-mp2mp-ce2ce" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mp-ce2ces/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.ce_added.is_set or self.ce_added.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ce_added.get_name_leafdata())
                if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.group_name.get_name_leafdata())
                if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.local_ceid.get_name_leafdata())
                if (self.local_customer_edge_id.is_set or self.local_customer_edge_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.local_customer_edge_id.get_name_leafdata())
                if (self.mp2_mp_name.is_set or self.mp2_mp_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mp2_mp_name.get_name_leafdata())
                if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                if (self.remote_customer_edge_id.is_set or self.remote_customer_edge_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.remote_customer_edge_id.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ce-added" or name == "group-name" or name == "local-ceid" or name == "local-customer-edge-id" or name == "mp2-mp-name" or name == "remote-ceid" or name == "remote-customer-edge-id"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "ce-added"):
                    self.ce_added = value
                    self.ce_added.value_namespace = name_space
                    self.ce_added.value_namespace_prefix = name_space_prefix
                if(value_path == "group-name"):
                    self.group_name = value
                    self.group_name.value_namespace = name_space
                    self.group_name.value_namespace_prefix = name_space_prefix
                if(value_path == "local-ceid"):
                    self.local_ceid = value
                    self.local_ceid.value_namespace = name_space
                    self.local_ceid.value_namespace_prefix = name_space_prefix
                if(value_path == "local-customer-edge-id"):
                    self.local_customer_edge_id = value
                    self.local_customer_edge_id.value_namespace = name_space
                    self.local_customer_edge_id.value_namespace_prefix = name_space_prefix
                if(value_path == "mp2-mp-name"):
                    self.mp2_mp_name = value
                    self.mp2_mp_name.value_namespace = name_space
                    self.mp2_mp_name.value_namespace_prefix = name_space_prefix
                if(value_path == "remote-ceid"):
                    self.remote_ceid = value
                    self.remote_ceid.value_namespace = name_space
                    self.remote_ceid.value_namespace_prefix = name_space_prefix
                if(value_path == "remote-customer-edge-id"):
                    self.remote_customer_edge_id = value
                    self.remote_customer_edge_id.value_namespace = name_space
                    self.remote_customer_edge_id.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.xconnect_mp2mp_ce2ce:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.xconnect_mp2mp_ce2ce:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "xconnect-mp2mp-ce2ces" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "xconnect-mp2mp-ce2ce"):
                for c in self.xconnect_mp2mp_ce2ce:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.xconnect_mp2mp_ce2ce.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "xconnect-mp2mp-ce2ce"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Xconnects(Entity):
        """
        XConnect Table
        
        .. attribute:: xconnect
        
        	XConnect information
        	**type**\: list of    :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.Xconnects, self).__init__()

            self.yang_name = "xconnects"
            self.yang_parent_name = "l2vpn"

            self.xconnect = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.Xconnects, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.Xconnects, self).__setattr__(name, value)


        class Xconnect(Entity):
            """
            XConnect information
            
            .. attribute:: backup
            
            	LCR backup
            	**type**\:   :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup>`
            
            .. attribute:: backup_segment
            
            	Backup Segment
            	**type**\: list of    :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment>`
            
            .. attribute:: ce2ce
            
            	CE2CE
            	**type**\:   :py:class:`Ce2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Ce2Ce>`
            
            .. attribute:: description
            
            	P2P Description
            	**type**\:  str
            
            .. attribute:: diag_mask
            
            	Mask indicating what if anything is missing before the XC can be provisioned
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: group_name
            
            	XConnect Group
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: group_name_xr
            
            	Group name
            	**type**\:  str
            
            .. attribute:: interworking
            
            	Interworking type
            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
            
            .. attribute:: is_mp2mp
            
            	xconnect is mp2mp
            	**type**\:  bool
            
            .. attribute:: number_of_backup_p_ws
            
            	Number of backups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: segment1
            
            	Segment 1
            	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1>`
            
            .. attribute:: segment2
            
            	Segment 2
            	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2>`
            
            .. attribute:: state
            
            	State of the xconnect
            	**type**\:   :py:class:`L2VpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcState>`
            
            .. attribute:: xconnect_name
            
            	XConnect Name
            	**type**\:  str
            
            	**length:** 1..38
            
            .. attribute:: xconnect_name_xr
            
            	XConnect name
            	**type**\:  str
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Xconnects.Xconnect, self).__init__()

                self.yang_name = "xconnect"
                self.yang_parent_name = "xconnects"

                self.description = YLeaf(YType.str, "description")

                self.diag_mask = YLeaf(YType.uint32, "diag-mask")

                self.group_name = YLeaf(YType.str, "group-name")

                self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                self.interworking = YLeaf(YType.enumeration, "interworking")

                self.is_mp2mp = YLeaf(YType.boolean, "is-mp2mp")

                self.number_of_backup_p_ws = YLeaf(YType.uint32, "number-of-backup-p-ws")

                self.state = YLeaf(YType.enumeration, "state")

                self.xconnect_name = YLeaf(YType.str, "xconnect-name")

                self.xconnect_name_xr = YLeaf(YType.str, "xconnect-name-xr")

                self.backup = L2Vpn.Xconnects.Xconnect.Backup()
                self.backup.parent = self
                self._children_name_map["backup"] = "backup"
                self._children_yang_names.add("backup")

                self.ce2ce = L2Vpn.Xconnects.Xconnect.Ce2Ce()
                self.ce2ce.parent = self
                self._children_name_map["ce2ce"] = "ce2ce"
                self._children_yang_names.add("ce2ce")

                self.segment1 = L2Vpn.Xconnects.Xconnect.Segment1()
                self.segment1.parent = self
                self._children_name_map["segment1"] = "segment1"
                self._children_yang_names.add("segment1")

                self.segment2 = L2Vpn.Xconnects.Xconnect.Segment2()
                self.segment2.parent = self
                self._children_name_map["segment2"] = "segment2"
                self._children_yang_names.add("segment2")

                self.backup_segment = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("description",
                                "diag_mask",
                                "group_name",
                                "group_name_xr",
                                "interworking",
                                "is_mp2mp",
                                "number_of_backup_p_ws",
                                "state",
                                "xconnect_name",
                                "xconnect_name_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Xconnects.Xconnect, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Xconnects.Xconnect, self).__setattr__(name, value)


            class Backup(Entity):
                """
                LCR backup
                
                .. attribute:: attachment_circuit
                
                	Attachment Circuit
                	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                
                .. attribute:: pseudo_wire
                
                	Pseudowire
                	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire>`
                
                .. attribute:: segment_type
                
                	SegmentType
                	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Xconnects.Xconnect.Backup, self).__init__()

                    self.yang_name = "backup"
                    self.yang_parent_name = "xconnect"

                    self.segment_type = YLeaf(YType.enumeration, "segment-type")

                    self.attachment_circuit = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit()
                    self.attachment_circuit.parent = self
                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                    self._children_yang_names.add("attachment-circuit")

                    self.pseudo_wire = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire()
                    self.pseudo_wire.parent = self
                    self._children_name_map["pseudo_wire"] = "pseudo-wire"
                    self._children_yang_names.add("pseudo-wire")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("segment_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Xconnects.Xconnect.Backup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Xconnects.Xconnect.Backup, self).__setattr__(name, value)


                class AttachmentCircuit(Entity):
                    """
                    Attachment Circuit
                    
                    .. attribute:: bvi_mac_conflict
                    
                    	BVI Mac Conflict
                    	**type**\:  bool
                    
                    .. attribute:: bvi_no_port_up
                    
                    	BVI no BP Up
                    	**type**\:  bool
                    
                    .. attribute:: control_word_mismatched
                    
                    	Control word mismatched
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_error
                    
                    	Encapsulation Error
                    	**type**\:  str
                    
                    .. attribute:: encapsulation_mismatched
                    
                    	Encapsulation mismatched
                    	**type**\:  bool
                    
                    .. attribute:: evpn_internal_label
                    
                    	EVPN Internal Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interface
                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                    
                    .. attribute:: interface_handle
                    
                    	Interface Handler
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: internal_ms_ti
                    
                    	Internal MSTi
                    	**type**\:  str
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                    
                    .. attribute:: is_ac_partially_programmed
                    
                    	Is attachment\-circuit partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: l2vpn_protection
                    
                    	Protection object used for this segment
                    	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection>`
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: ms_ti_mismatch
                    
                    	MSTi mismatch
                    	**type**\:  bool
                    
                    .. attribute:: msti
                    
                    	MSTi
                    	**type**\:  str
                    
                    .. attribute:: msti_mismatch_down
                    
                    	Oper down due to MSTI mismatch
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Node ID
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_id
                    
                    	Redundancy Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_state
                    
                    	Redundancy Group State
                    	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                    
                    .. attribute:: redundancy_object_id
                    
                    	Redundancy Object ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                    
                    .. attribute:: tdm_media_mismatched
                    
                    	TDM media parms mismatched
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__init__()

                        self.yang_name = "attachment-circuit"
                        self.yang_parent_name = "backup"

                        self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                        self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                        self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                        self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                        self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                        self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                        self.interface_handle = YLeaf(YType.str, "interface-handle")

                        self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                        self.interworking = YLeaf(YType.enumeration, "interworking")

                        self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                        self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                        self.msti = YLeaf(YType.str, "msti")

                        self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                        self.node_id = YLeaf(YType.str, "node-id")

                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                        self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                        self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                        self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                        self.interface = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._children_yang_names.add("interface")

                        self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                        self.l2vpn_protection.parent = self
                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                        self._children_yang_names.add("l2vpn-protection")

                        self.statistics = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bvi_mac_conflict",
                                        "bvi_no_port_up",
                                        "control_word_mismatched",
                                        "encapsulation_error",
                                        "encapsulation_mismatched",
                                        "evpn_internal_label",
                                        "interface_handle",
                                        "internal_ms_ti",
                                        "interworking",
                                        "is_ac_partially_programmed",
                                        "mac_limit_oper_down",
                                        "ms_ti_mismatch",
                                        "msti",
                                        "msti_mismatch_down",
                                        "mtu_mismatched",
                                        "node_id",
                                        "out_of_memory_state",
                                        "redundancy_group_id",
                                        "redundancy_group_state",
                                        "redundancy_object_id",
                                        "state",
                                        "tdm_media_mismatched",
                                        "xconnect_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "attachment-circuit"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "attachment-circuit"

                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                            self._children_yang_names.add("dispostion-stats")

                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self._children_name_map["impostion_stats"] = "impostion-stats"
                            self._children_yang_names.add("impostion-stats")

                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                            self.sequence_number.parent = self
                            self._children_name_map["sequence_number"] = "sequence-number"
                            self._children_yang_names.add("sequence-number")


                        class ImpostionStats(Entity):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                self.yang_name = "impostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self._children_name_map["broadcast"] = "broadcast"
                                self._children_yang_names.add("broadcast")

                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                self._children_yang_names.add("imposition-mtu-drop")

                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                self._children_yang_names.add("imposition-stat")

                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                self._children_yang_names.add("impostion-tail-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                self._children_yang_names.add("l2fsbi-drop")

                                self.multicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                                self._children_yang_names.add("multicast")

                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self
                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                self._children_yang_names.add("unknown-unicast")


                            class ImpositionStat(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                    self.yang_name = "imposition-stat"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpositionMtuDrop(Entity):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                    self.yang_name = "imposition-mtu-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpostionTailDrop(Entity):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                    self.yang_name = "impostion-tail-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class L2FsbiDrop(Entity):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                    self.yang_name = "l2fsbi-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fsbi-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Multicast(Entity):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Broadcast(Entity):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                    self.yang_name = "broadcast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnknownUnicast(Entity):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                    self.yang_name = "unknown-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unknown-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                    (self.multicast is not None and self.multicast.has_data()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                    (self.multicast is not None and self.multicast.has_operation()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "impostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast"):
                                    if (self.broadcast is None):
                                        self.broadcast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                    return self.broadcast

                                if (child_yang_name == "imposition-mtu-drop"):
                                    if (self.imposition_mtu_drop is None):
                                        self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    return self.imposition_mtu_drop

                                if (child_yang_name == "imposition-stat"):
                                    if (self.imposition_stat is None):
                                        self.imposition_stat = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                    return self.imposition_stat

                                if (child_yang_name == "impostion-tail-drop"):
                                    if (self.impostion_tail_drop is None):
                                        self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    return self.impostion_tail_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "l2fsbi-drop"):
                                    if (self.l2fsbi_drop is None):
                                        self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    return self.l2fsbi_drop

                                if (child_yang_name == "multicast"):
                                    if (self.multicast is None):
                                        self.multicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                    return self.multicast

                                if (child_yang_name == "unknown-unicast"):
                                    if (self.unknown_unicast is None):
                                        self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    return self.unknown_unicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DispostionStats(Entity):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                self.yang_name = "dispostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                self._children_yang_names.add("broadcast-drop")

                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self._children_name_map["dai_drop"] = "dai-drop"
                                self._children_yang_names.add("dai-drop")

                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                self._children_yang_names.add("disposition-mtu-drop")

                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                self._children_yang_names.add("disposition-oo-o-drops")

                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                self._children_yang_names.add("disposition-p2mp-stats")

                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                self._children_yang_names.add("disposition-stat")

                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                self._children_yang_names.add("disposition-tail-drop")

                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                self._children_yang_names.add("ipsg-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.mac_move = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self._children_name_map["mac_move"] = "mac-move"
                                self._children_yang_names.add("mac-move")

                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                self._children_yang_names.add("multicast-drop")

                                self.received_drops = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self._children_name_map["received_drops"] = "received-drops"
                                self._children_yang_names.add("received-drops")

                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self
                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                self._children_yang_names.add("unicast-drop")


                            class DispositionStat(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                    self.yang_name = "disposition-stat"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionMtuDrop(Entity):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                    self.yang_name = "disposition-mtu-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionTailDrop(Entity):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                    self.yang_name = "disposition-tail-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MulticastDrop(Entity):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                    self.yang_name = "multicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnicastDrop(Entity):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                    self.yang_name = "unicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class BroadcastDrop(Entity):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                    self.yang_name = "broadcast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ReceivedDrops(Entity):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                    self.yang_name = "received-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DaiDrop(Entity):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                    self.yang_name = "dai-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dai-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class IpsgDrop(Entity):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                    self.yang_name = "ipsg-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipsg-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionOoODrops(Entity):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                    self.yang_name = "disposition-oo-o-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionP2MpStats(Entity):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                    self.yang_name = "disposition-p2mp-stats"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MacMove(Entity):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                    self.yang_name = "mac-move"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-move" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dispostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast-drop"):
                                    if (self.broadcast_drop is None):
                                        self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    return self.broadcast_drop

                                if (child_yang_name == "dai-drop"):
                                    if (self.dai_drop is None):
                                        self.dai_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                    return self.dai_drop

                                if (child_yang_name == "disposition-mtu-drop"):
                                    if (self.disposition_mtu_drop is None):
                                        self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    return self.disposition_mtu_drop

                                if (child_yang_name == "disposition-oo-o-drops"):
                                    if (self.disposition_oo_o_drops is None):
                                        self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    return self.disposition_oo_o_drops

                                if (child_yang_name == "disposition-p2mp-stats"):
                                    if (self.disposition_p2mp_stats is None):
                                        self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    return self.disposition_p2mp_stats

                                if (child_yang_name == "disposition-stat"):
                                    if (self.disposition_stat is None):
                                        self.disposition_stat = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                    return self.disposition_stat

                                if (child_yang_name == "disposition-tail-drop"):
                                    if (self.disposition_tail_drop is None):
                                        self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    return self.disposition_tail_drop

                                if (child_yang_name == "ipsg-drop"):
                                    if (self.ipsg_drop is None):
                                        self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    return self.ipsg_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "mac-move"):
                                    if (self.mac_move is None):
                                        self.mac_move = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                    return self.mac_move

                                if (child_yang_name == "multicast-drop"):
                                    if (self.multicast_drop is None):
                                        self.multicast_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                    return self.multicast_drop

                                if (child_yang_name == "received-drops"):
                                    if (self.received_drops is None):
                                        self.received_drops = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                    return self.received_drops

                                if (child_yang_name == "unicast-drop"):
                                    if (self.unicast_drop is None):
                                        self.unicast_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                    return self.unicast_drop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SequenceNumber(Entity):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                self.yang_name = "sequence-number"
                                self.yang_parent_name = "statistics"

                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bypassed_inbound_sequence_packet",
                                                "bypassed_out_sequence_packet",
                                                "sequence_number_expected",
                                                "sequence_number_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bypassed_inbound_sequence_packet.is_set or
                                    self.bypassed_out_sequence_packet.is_set or
                                    self.sequence_number_expected.is_set or
                                    self.sequence_number_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sequence-number" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bypassed-inbound-sequence-packet"):
                                    self.bypassed_inbound_sequence_packet = value
                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "bypassed-out-sequence-packet"):
                                    self.bypassed_out_sequence_packet = value
                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-expected"):
                                    self.sequence_number_expected = value
                                    self.sequence_number_expected.value_namespace = name_space
                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-sent"):
                                    self.sequence_number_sent = value
                                    self.sequence_number_sent.value_namespace = name_space
                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                (self.sequence_number is not None and self.sequence_number.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dispostion-stats"):
                                if (self.dispostion_stats is None):
                                    self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                return self.dispostion_stats

                            if (child_yang_name == "impostion-stats"):
                                if (self.impostion_stats is None):
                                    self.impostion_stats = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                return self.impostion_stats

                            if (child_yang_name == "sequence-number"):
                                if (self.sequence_number is None):
                                    self.sequence_number = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                return self.sequence_number

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class L2VpnProtection(Entity):
                        """
                        Protection object used for this segment
                        
                        .. attribute:: active
                        
                        	Active
                        	**type**\:  bool
                        
                        .. attribute:: protected_name
                        
                        	Name of the protected segment
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_configured
                        
                        	Protection configured
                        	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                        
                        .. attribute:: protection_name
                        
                        	Name of the segment acting as backup
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_type
                        
                        	Type of the protection
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__init__()

                            self.yang_name = "l2vpn-protection"
                            self.yang_parent_name = "attachment-circuit"

                            self.active = YLeaf(YType.boolean, "active")

                            self.protected_name = YLeaf(YType.str, "protected-name")

                            self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                            self.protection_name = YLeaf(YType.str, "protection-name")

                            self.protection_type = YLeaf(YType.enumeration, "protection-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active",
                                            "protected_name",
                                            "protection_configured",
                                            "protection_name",
                                            "protection_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active.is_set or
                                self.protected_name.is_set or
                                self.protection_configured.is_set or
                                self.protection_name.is_set or
                                self.protection_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active.yfilter != YFilter.not_set or
                                self.protected_name.yfilter != YFilter.not_set or
                                self.protection_configured.yfilter != YFilter.not_set or
                                self.protection_name.yfilter != YFilter.not_set or
                                self.protection_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2vpn-protection" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active.get_name_leafdata())
                            if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protected_name.get_name_leafdata())
                            if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_configured.get_name_leafdata())
                            if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_name.get_name_leafdata())
                            if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active"):
                                self.active = value
                                self.active.value_namespace = name_space
                                self.active.value_namespace_prefix = name_space_prefix
                            if(value_path == "protected-name"):
                                self.protected_name = value
                                self.protected_name.value_namespace = name_space
                                self.protected_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-configured"):
                                self.protection_configured = value
                                self.protection_configured.value_namespace = name_space
                                self.protection_configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-name"):
                                self.protection_name = value
                                self.protection_name.value_namespace = name_space
                                self.protection_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-type"):
                                self.protection_type = value
                                self.protection_type.value_namespace = name_space
                                self.protection_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bvi_mac_conflict.is_set or
                            self.bvi_no_port_up.is_set or
                            self.control_word_mismatched.is_set or
                            self.encapsulation_error.is_set or
                            self.encapsulation_mismatched.is_set or
                            self.evpn_internal_label.is_set or
                            self.interface_handle.is_set or
                            self.internal_ms_ti.is_set or
                            self.interworking.is_set or
                            self.is_ac_partially_programmed.is_set or
                            self.mac_limit_oper_down.is_set or
                            self.ms_ti_mismatch.is_set or
                            self.msti.is_set or
                            self.msti_mismatch_down.is_set or
                            self.mtu_mismatched.is_set or
                            self.node_id.is_set or
                            self.out_of_memory_state.is_set or
                            self.redundancy_group_id.is_set or
                            self.redundancy_group_state.is_set or
                            self.redundancy_object_id.is_set or
                            self.state.is_set or
                            self.tdm_media_mismatched.is_set or
                            self.xconnect_id.is_set or
                            (self.interface is not None and self.interface.has_data()) or
                            (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bvi_mac_conflict.yfilter != YFilter.not_set or
                            self.bvi_no_port_up.yfilter != YFilter.not_set or
                            self.control_word_mismatched.yfilter != YFilter.not_set or
                            self.encapsulation_error.yfilter != YFilter.not_set or
                            self.encapsulation_mismatched.yfilter != YFilter.not_set or
                            self.evpn_internal_label.yfilter != YFilter.not_set or
                            self.interface_handle.yfilter != YFilter.not_set or
                            self.internal_ms_ti.yfilter != YFilter.not_set or
                            self.interworking.yfilter != YFilter.not_set or
                            self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                            self.ms_ti_mismatch.yfilter != YFilter.not_set or
                            self.msti.yfilter != YFilter.not_set or
                            self.msti_mismatch_down.yfilter != YFilter.not_set or
                            self.mtu_mismatched.yfilter != YFilter.not_set or
                            self.node_id.yfilter != YFilter.not_set or
                            self.out_of_memory_state.yfilter != YFilter.not_set or
                            self.redundancy_group_id.yfilter != YFilter.not_set or
                            self.redundancy_group_state.yfilter != YFilter.not_set or
                            self.redundancy_object_id.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.tdm_media_mismatched.yfilter != YFilter.not_set or
                            self.xconnect_id.yfilter != YFilter.not_set or
                            (self.interface is not None and self.interface.has_operation()) or
                            (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "attachment-circuit" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                        if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                        if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                        if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                        if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                        if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                        if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_handle.get_name_leafdata())
                        if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interworking.get_name_leafdata())
                        if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                        if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti.get_name_leafdata())
                        if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                        if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_id.get_name_leafdata())
                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                        if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                        if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                        if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            if (self.interface is None):
                                self.interface = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                            return self.interface

                        if (child_yang_name == "l2vpn-protection"):
                            if (self.l2vpn_protection is None):
                                self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            return self.l2vpn_protection

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bvi-mac-conflict"):
                            self.bvi_mac_conflict = value
                            self.bvi_mac_conflict.value_namespace = name_space
                            self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                        if(value_path == "bvi-no-port-up"):
                            self.bvi_no_port_up = value
                            self.bvi_no_port_up.value_namespace = name_space
                            self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "control-word-mismatched"):
                            self.control_word_mismatched = value
                            self.control_word_mismatched.value_namespace = name_space
                            self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "encapsulation-error"):
                            self.encapsulation_error = value
                            self.encapsulation_error.value_namespace = name_space
                            self.encapsulation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "encapsulation-mismatched"):
                            self.encapsulation_mismatched = value
                            self.encapsulation_mismatched.value_namespace = name_space
                            self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-internal-label"):
                            self.evpn_internal_label = value
                            self.evpn_internal_label.value_namespace = name_space
                            self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-handle"):
                            self.interface_handle = value
                            self.interface_handle.value_namespace = name_space
                            self.interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "internal-ms-ti"):
                            self.internal_ms_ti = value
                            self.internal_ms_ti.value_namespace = name_space
                            self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                        if(value_path == "interworking"):
                            self.interworking = value
                            self.interworking.value_namespace = name_space
                            self.interworking.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ac-partially-programmed"):
                            self.is_ac_partially_programmed = value
                            self.is_ac_partially_programmed.value_namespace = name_space
                            self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-oper-down"):
                            self.mac_limit_oper_down = value
                            self.mac_limit_oper_down.value_namespace = name_space
                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "ms-ti-mismatch"):
                            self.ms_ti_mismatch = value
                            self.ms_ti_mismatch.value_namespace = name_space
                            self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti"):
                            self.msti = value
                            self.msti.value_namespace = name_space
                            self.msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-mismatch-down"):
                            self.msti_mismatch_down = value
                            self.msti_mismatch_down.value_namespace = name_space
                            self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-mismatched"):
                            self.mtu_mismatched = value
                            self.mtu_mismatched.value_namespace = name_space
                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-id"):
                            self.node_id = value
                            self.node_id.value_namespace = name_space
                            self.node_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-of-memory-state"):
                            self.out_of_memory_state = value
                            self.out_of_memory_state.value_namespace = name_space
                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-group-id"):
                            self.redundancy_group_id = value
                            self.redundancy_group_id.value_namespace = name_space
                            self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-group-state"):
                            self.redundancy_group_state = value
                            self.redundancy_group_state.value_namespace = name_space
                            self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-object-id"):
                            self.redundancy_object_id = value
                            self.redundancy_object_id.value_namespace = name_space
                            self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "tdm-media-mismatched"):
                            self.tdm_media_mismatched = value
                            self.tdm_media_mismatched.value_namespace = name_space
                            self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-id"):
                            self.xconnect_id = value
                            self.xconnect_id.value_namespace = name_space
                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                class PseudoWire(Entity):
                    """
                    Pseudowire
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_remote_down
                    
                    	Auto\-Discovered PW remote state down
                    	**type**\:  bool
                    
                    .. attribute:: admited_bw
                    
                    	Admited Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: auto_discovery
                    
                    	Is autodiscovery
                    	**type**\:  bool
                    
                    .. attribute:: backup_active
                    
                    	TRUE if backup is active
                    	**type**\:  bool
                    
                    .. attribute:: backup_force_active
                    
                    	TRUE if backup is active due to switchover
                    	**type**\:  bool
                    
                    .. attribute:: backup_pw
                    
                    	TRUE if PW is a backup PW
                    	**type**\:  bool
                    
                    .. attribute:: bitrate_mismatched
                    
                    	Bitrate mismatched
                    	**type**\:  bool
                    
                    .. attribute:: bridge_pw_type_mismatch
                    
                    	Oper down because Bridge has mismatched PW Types
                    	**type**\:  bool
                    
                    .. attribute:: cas_mismatched
                    
                    	CAS mismatched
                    	**type**\:  bool
                    
                    .. attribute:: diff_ts_mismatched
                    
                    	Differential timestamp mismatched
                    	**type**\:  bool
                    
                    .. attribute:: disable_delay
                    
                    	Backup disable delay
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                    
                    .. attribute:: evpn_src_acid
                    
                    	EVPN VPWS Source AC ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fe_ctype
                    
                    	Pseudowire FEC type
                    	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                    
                    .. attribute:: forward_class
                    
                    	Forward Class attribute
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: freq_mismatched
                    
                    	Frequency mismatched
                    	**type**\:  bool
                    
                    .. attribute:: illegal_control_word
                    
                    	Illegal control word
                    	**type**\:  bool
                    
                    .. attribute:: imposed_vlan_id
                    
                    	Imposed vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                    
                    .. attribute:: ipv6_local_source_address
                    
                    	Local IPv6 Source Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_evpnvpws_type
                    
                    	is EVPN VPWS
                    	**type**\:  bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: is_multi_segment_pseudowire
                    
                    	Is Multi\-Segment Pseudowire
                    	**type**\:  bool
                    
                    .. attribute:: is_partially_programmed
                    
                    	Is Pseudowire partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_pwr_type
                    
                    	is Pseudowire\-routed
                    	**type**\:  bool
                    
                    .. attribute:: is_vfi
                    
                    	Is VFI interface
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the pseudowire status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_down
                    
                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: ldp_label_advertise_failed
                    
                    	LDP label advertisment failed
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                    
                    .. attribute:: local_control_word
                    
                    	Local control word
                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                    
                    .. attribute:: local_label_failed
                    
                    	Failed to set BGP advertised local label
                    	**type**\:  bool
                    
                    .. attribute:: local_pseudo_wire_type
                    
                    	Local pseudowire type
                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                    
                    .. attribute:: local_signalling
                    
                    	Local signalling
                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                    
                    .. attribute:: local_source_address
                    
                    	Local Source Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_qinq
                    
                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                    	**type**\:  bool
                    
                    .. attribute:: num_ma_cwithdraw_msg_received
                    
                    	Num MW messages received over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ma_cwithdraw_message_sent
                    
                    	Num MW messages sent over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_pw
                    
                    	P2MP Pseudowire Information
                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw>`
                    
                    .. attribute:: payload_bytes_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: payload_type_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: peer_id
                    
                    	Peer
                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	Prefpath fallback enable/disable
                    	**type**\:  bool
                    
                    .. attribute:: primary_peer_id
                    
                    	Primary Peer IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: primary_pseudo_wire_id
                    
                    	Primary Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: primary_pw
                    
                    	TRUE if PW is a primary PW
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                    
                    .. attribute:: pseudo_wire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: pseudo_wire_state
                    
                    	Pseudowire state
                    	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                    
                    .. attribute:: pseudo_wire_type_mismatched
                    
                    	Pseudowire type mismatched
                    	**type**\:  bool
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type
                    
                    	Negotiated pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label Type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: pw_redundancy_initial_delay
                    
                    	Initial delay for redundant PW in seconds
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    .. attribute:: pw_redundancy_one_way
                    
                    	Force one\-way PW redundancy behaviour in Redundancy Group
                    	**type**\:  bool
                    
                    .. attribute:: pw_status_use
                    
                    	PW status in use
                    	**type**\:  bool
                    
                    .. attribute:: pwlsd_rewrite_failed
                    
                    	LSD rewrite failed
                    	**type**\:  bool
                    
                    .. attribute:: remote_control_word
                    
                    	Remote control word
                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                    
                    .. attribute:: remote_interface
                    
                    	Remote interface
                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                    
                    .. attribute:: remote_label_failed
                    
                    	Failed to set BGP advertised remote label
                    	**type**\:  bool
                    
                    .. attribute:: remote_pseudo_wire_type
                    
                    	Remote pseudowire type
                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                    
                    .. attribute:: remote_signalling
                    
                    	Remote signalling
                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                    
                    .. attribute:: required_bw
                    
                    	Required Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rtp_mismatched
                    
                    	RTP mismatched
                    	**type**\:  bool
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: sig_pkts_mismatched
                    
                    	Signalling packets mismatched
                    	**type**\:  bool
                    
                    .. attribute:: ssrc_mismatched
                    
                    	SSRC mismatched
                    	**type**\:  bool
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                    
                    .. attribute:: table_policy_name
                    
                    	Table\-policy Name
                    	**type**\:  str
                    
                    .. attribute:: tag_rewrite
                    
                    	StaticTagRewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: time_created
                    
                    	Time when the pseudowire was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_down
                    
                    	Time elapsed since last status down in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: transport_lsp_down
                    
                    	Oper down due to Transport LSP down
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire, self).__init__()

                        self.yang_name = "pseudo-wire"
                        self.yang_parent_name = "backup"

                        self.ad_method = YLeaf(YType.uint32, "ad-method")

                        self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                        self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                        self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                        self.backup_active = YLeaf(YType.boolean, "backup-active")

                        self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                        self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                        self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                        self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                        self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                        self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                        self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                        self.disable_never = YLeaf(YType.boolean, "disable-never")

                        self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                        self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                        self.forward_class = YLeaf(YType.uint8, "forward-class")

                        self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                        self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                        self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                        self.interworking = YLeaf(YType.enumeration, "interworking")

                        self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                        self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                        self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                        self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                        self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                        self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                        self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                        self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                        self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                        self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                        self.load_balance = YLeaf(YType.enumeration, "load-balance")

                        self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                        self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                        self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                        self.local_source_address = YLeaf(YType.str, "local-source-address")

                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                        self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                        self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                        self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                        self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                        self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                        self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                        self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                        self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                        self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                        self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                        self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                        self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                        self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                        self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                        self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                        self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                        self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                        self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                        self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                        self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                        self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                        self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                        self.required_bw = YLeaf(YType.uint32, "required-bw")

                        self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                        self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                        self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                        self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                        self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                        self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                        self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                        self.time_created = YLeaf(YType.str, "time-created")

                        self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                        self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                        self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                        self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                        self.encapsulation_info = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                        self._children_yang_names.add("encapsulation-info")

                        self.local_interface = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                        self.local_interface.parent = self
                        self._children_name_map["local_interface"] = "local-interface"
                        self._children_yang_names.add("local-interface")

                        self.local_signalling = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                        self.local_signalling.parent = self
                        self._children_name_map["local_signalling"] = "local-signalling"
                        self._children_yang_names.add("local-signalling")

                        self.p2mp_pw = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                        self.p2mp_pw.parent = self
                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                        self._children_yang_names.add("p2mp-pw")

                        self.peer_id = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                        self.peer_id.parent = self
                        self._children_name_map["peer_id"] = "peer-id"
                        self._children_yang_names.add("peer-id")

                        self.preferred_path = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                        self.preferred_path.parent = self
                        self._children_name_map["preferred_path"] = "preferred-path"
                        self._children_yang_names.add("preferred-path")

                        self.remote_interface = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                        self.remote_interface.parent = self
                        self._children_name_map["remote_interface"] = "remote-interface"
                        self._children_yang_names.add("remote-interface")

                        self.remote_signalling = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                        self.remote_signalling.parent = self
                        self._children_name_map["remote_signalling"] = "remote-signalling"
                        self._children_yang_names.add("remote-signalling")

                        self.statistics = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ad_method",
                                        "ad_remote_down",
                                        "admited_bw",
                                        "auto_discovery",
                                        "backup_active",
                                        "backup_force_active",
                                        "backup_pw",
                                        "bitrate_mismatched",
                                        "bridge_pw_type_mismatch",
                                        "cas_mismatched",
                                        "diff_ts_mismatched",
                                        "disable_delay",
                                        "disable_never",
                                        "evpn_src_acid",
                                        "fe_ctype",
                                        "forward_class",
                                        "freq_mismatched",
                                        "illegal_control_word",
                                        "imposed_vlan_id",
                                        "interworking",
                                        "ipv6_local_source_address",
                                        "is_evpnvpws_type",
                                        "is_flow_label_static",
                                        "is_multi_segment_pseudowire",
                                        "is_partially_programmed",
                                        "is_pwr_type",
                                        "is_vfi",
                                        "last_time_status_changed",
                                        "last_time_status_down",
                                        "ldp_label_advertise_failed",
                                        "load_balance",
                                        "local_control_word",
                                        "local_label_failed",
                                        "local_pseudo_wire_type",
                                        "local_source_address",
                                        "mac_limit_oper_down",
                                        "mtu_mismatched",
                                        "not_supported_qinq",
                                        "num_ma_cwithdraw_msg_received",
                                        "number_ma_cwithdraw_message_sent",
                                        "out_of_memory_state",
                                        "payload_bytes_mismatched",
                                        "payload_type_mismatched",
                                        "preferred_path_disable_fallback",
                                        "primary_peer_id",
                                        "primary_pseudo_wire_id",
                                        "primary_pw",
                                        "protocol",
                                        "pseudo_wire_id",
                                        "pseudo_wire_state",
                                        "pseudo_wire_type_mismatched",
                                        "pw_class_name",
                                        "pw_flow_label_code17_disabled",
                                        "pw_flow_label_type",
                                        "pw_flow_label_type_cfg",
                                        "pw_redundancy_initial_delay",
                                        "pw_redundancy_one_way",
                                        "pw_status_use",
                                        "pwlsd_rewrite_failed",
                                        "remote_control_word",
                                        "remote_label_failed",
                                        "remote_pseudo_wire_type",
                                        "required_bw",
                                        "resync_enabled",
                                        "resync_threshold",
                                        "rtp_mismatched",
                                        "sequencing_type",
                                        "shutdown",
                                        "sig_pkts_mismatched",
                                        "ssrc_mismatched",
                                        "state",
                                        "table_policy_name",
                                        "tag_rewrite",
                                        "time_created",
                                        "time_elapsed_creation",
                                        "time_elapsed_status_changed",
                                        "time_elapsed_status_down",
                                        "transport_lsp_down",
                                        "xconnect_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire, self).__setattr__(name, value)


                    class PeerId(Entity):
                        """
                        Peer
                        
                        .. attribute:: internal_label
                        
                        	Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_peer_id
                        
                        	Peer IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_peer_id
                        
                        	Peer IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: type
                        
                        	type
                        	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__init__()

                            self.yang_name = "peer-id"
                            self.yang_parent_name = "pseudo-wire"

                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                            self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                            self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                            self.type = YLeaf(YType.enumeration, "type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("internal_label",
                                            "ipv4_peer_id",
                                            "ipv6_peer_id",
                                            "type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.internal_label.is_set or
                                self.ipv4_peer_id.is_set or
                                self.ipv6_peer_id.is_set or
                                self.type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.internal_label.yfilter != YFilter.not_set or
                                self.ipv4_peer_id.yfilter != YFilter.not_set or
                                self.ipv6_peer_id.yfilter != YFilter.not_set or
                                self.type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "peer-id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                            if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                            if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "internal-label"):
                                self.internal_label = value
                                self.internal_label.value_namespace = name_space
                                self.internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-peer-id"):
                                self.ipv4_peer_id = value
                                self.ipv4_peer_id.value_namespace = name_space
                                self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-peer-id"):
                                self.ipv6_peer_id = value
                                self.ipv6_peer_id.value_namespace = name_space
                                self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "type"):
                                self.type = value
                                self.type.value_namespace = name_space
                                self.type.value_namespace_prefix = name_space_prefix


                    class EncapsulationInfo(Entity):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: atom
                        
                        	atom
                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__init__()

                            self.yang_name = "encapsulation-info"
                            self.yang_parent_name = "pseudo-wire"

                            self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                            self.atom = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                            self.atom.parent = self
                            self._children_name_map["atom"] = "atom"
                            self._children_yang_names.add("atom")

                            self.l2tpv3 = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self
                            self._children_name_map["l2tpv3"] = "l2tpv3"
                            self._children_yang_names.add("l2tpv3")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("encapsulation") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                        class Atom(Entity):
                            """
                            atom
                            
                            .. attribute:: is_pseudowire_headend
                            
                            	Is this connected to a PW\-HE AC
                            	**type**\:  bool
                            
                            .. attribute:: is_sai_itype2
                            
                            	Is SAII FEC129 Type 2
                            	**type**\:  bool
                            
                            .. attribute:: is_tai_itype2
                            
                            	Is TAII type 2
                            	**type**\:  bool
                            
                            .. attribute:: ldp_label_advertisment_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: local_agi
                            
                            	Local Attachment Group Identifier
                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                            
                            .. attribute:: local_c_ctype
                            
                            	Local VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_ceid
                            
                            	Local CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cv_type
                            
                            	Local VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_group_id
                            
                            	Local group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ldp_id
                            
                            	Local LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_saii_gbl_id
                            
                            	Local SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_saiiac_id
                            
                            	Local SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taii_gbl_id
                            
                            	Local TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taiiac_id
                            
                            	Local TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_veid
                            
                            	Local VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: multi_segment_pseudowire_stats
                            
                            	Multisegment pseudowire statistics
                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                            
                            .. attribute:: rem_saii
                            
                            	Remote Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_saii_gbl_id
                            
                            	Remote SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_saiiac_id
                            
                            	Remote SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taii
                            
                            	Remote Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_taii_gbl_id
                            
                            	Remote TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taiiac_id
                            
                            	Remote TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_agi
                            
                            	Remote Attachment Group Identifier
                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                            
                            .. attribute:: remote_c_ctype
                            
                            	Remote VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_ceid
                            
                            	Remote CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cv_type
                            
                            	Remote VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_group_id
                            
                            	Remote group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_label
                            
                            	Remote label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ldp_id
                            
                            	Remote LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_source_address
                            
                            	Remote BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_veid
                            
                            	Remote VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_address
                            
                            	Local BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                self.yang_name = "atom"
                                self.yang_parent_name = "encapsulation-info"

                                self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                self.local_veid = YLeaf(YType.uint32, "local-veid")

                                self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                self.rem_saii = YLeaf(YType.str, "rem-saii")

                                self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                self.rem_taii = YLeaf(YType.str, "rem-taii")

                                self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                self.saii = YLeaf(YType.str, "saii")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.taii = YLeaf(YType.str, "taii")

                                self.local_agi = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                self.local_agi.parent = self
                                self._children_name_map["local_agi"] = "local-agi"
                                self._children_yang_names.add("local-agi")

                                self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                self.multi_segment_pseudowire_stats.parent = self
                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                self._children_yang_names.add("multi-segment-pseudowire-stats")

                                self.remote_agi = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                self.remote_agi.parent = self
                                self._children_name_map["remote_agi"] = "remote-agi"
                                self._children_yang_names.add("remote-agi")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_pseudowire_headend",
                                                "is_sai_itype2",
                                                "is_tai_itype2",
                                                "ldp_label_advertisment_failed",
                                                "local_c_ctype",
                                                "local_ceid",
                                                "local_cv_type",
                                                "local_group_id",
                                                "local_label",
                                                "local_ldp_id",
                                                "local_saii_gbl_id",
                                                "local_saiiac_id",
                                                "local_taii_gbl_id",
                                                "local_taiiac_id",
                                                "local_veid",
                                                "lsd_rewrite_failed",
                                                "rem_saii",
                                                "rem_saii_gbl_id",
                                                "rem_saiiac_id",
                                                "rem_taii",
                                                "rem_taii_gbl_id",
                                                "rem_taiiac_id",
                                                "remote_c_ctype",
                                                "remote_ceid",
                                                "remote_cv_type",
                                                "remote_group_id",
                                                "remote_label",
                                                "remote_ldp_id",
                                                "remote_source_address",
                                                "remote_veid",
                                                "saii",
                                                "source_address",
                                                "taii") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                            class LocalAgi(Entity):
                                """
                                Local Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                    self.yang_name = "local-agi"
                                    self.yang_parent_name = "atom"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "local-agi"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "local-agi"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "local-agi"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-agi" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class RemoteAgi(Entity):
                                """
                                Remote Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                    self.yang_name = "remote-agi"
                                    self.yang_parent_name = "atom"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "remote-agi"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "remote-agi"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "remote-agi"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-agi" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class MultiSegmentPseudowireStats(Entity):
                                """
                                Multisegment pseudowire statistics
                                
                                .. attribute:: received_bytes
                                
                                	Bytes received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: received_packets
                                
                                	Packets received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                    self.yang_name = "multi-segment-pseudowire-stats"
                                    self.yang_parent_name = "atom"

                                    self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                    self.received_packets = YLeaf(YType.uint64, "received-packets")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("received_bytes",
                                                    "received_packets") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.received_bytes.is_set or
                                        self.received_packets.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.received_bytes.yfilter != YFilter.not_set or
                                        self.received_packets.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                    if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_packets.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-bytes" or name == "received-packets"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "received-bytes"):
                                        self.received_bytes = value
                                        self.received_bytes.value_namespace = name_space
                                        self.received_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-packets"):
                                        self.received_packets = value
                                        self.received_packets.value_namespace = name_space
                                        self.received_packets.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.is_pseudowire_headend.is_set or
                                    self.is_sai_itype2.is_set or
                                    self.is_tai_itype2.is_set or
                                    self.ldp_label_advertisment_failed.is_set or
                                    self.local_c_ctype.is_set or
                                    self.local_ceid.is_set or
                                    self.local_cv_type.is_set or
                                    self.local_group_id.is_set or
                                    self.local_label.is_set or
                                    self.local_ldp_id.is_set or
                                    self.local_saii_gbl_id.is_set or
                                    self.local_saiiac_id.is_set or
                                    self.local_taii_gbl_id.is_set or
                                    self.local_taiiac_id.is_set or
                                    self.local_veid.is_set or
                                    self.lsd_rewrite_failed.is_set or
                                    self.rem_saii.is_set or
                                    self.rem_saii_gbl_id.is_set or
                                    self.rem_saiiac_id.is_set or
                                    self.rem_taii.is_set or
                                    self.rem_taii_gbl_id.is_set or
                                    self.rem_taiiac_id.is_set or
                                    self.remote_c_ctype.is_set or
                                    self.remote_ceid.is_set or
                                    self.remote_cv_type.is_set or
                                    self.remote_group_id.is_set or
                                    self.remote_label.is_set or
                                    self.remote_ldp_id.is_set or
                                    self.remote_source_address.is_set or
                                    self.remote_veid.is_set or
                                    self.saii.is_set or
                                    self.source_address.is_set or
                                    self.taii.is_set or
                                    (self.local_agi is not None and self.local_agi.has_data()) or
                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                    (self.remote_agi is not None and self.remote_agi.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                    self.is_sai_itype2.yfilter != YFilter.not_set or
                                    self.is_tai_itype2.yfilter != YFilter.not_set or
                                    self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                    self.local_c_ctype.yfilter != YFilter.not_set or
                                    self.local_ceid.yfilter != YFilter.not_set or
                                    self.local_cv_type.yfilter != YFilter.not_set or
                                    self.local_group_id.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_ldp_id.yfilter != YFilter.not_set or
                                    self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                    self.local_saiiac_id.yfilter != YFilter.not_set or
                                    self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                    self.local_taiiac_id.yfilter != YFilter.not_set or
                                    self.local_veid.yfilter != YFilter.not_set or
                                    self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.rem_saii.yfilter != YFilter.not_set or
                                    self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                    self.rem_saiiac_id.yfilter != YFilter.not_set or
                                    self.rem_taii.yfilter != YFilter.not_set or
                                    self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                    self.rem_taiiac_id.yfilter != YFilter.not_set or
                                    self.remote_c_ctype.yfilter != YFilter.not_set or
                                    self.remote_ceid.yfilter != YFilter.not_set or
                                    self.remote_cv_type.yfilter != YFilter.not_set or
                                    self.remote_group_id.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_ldp_id.yfilter != YFilter.not_set or
                                    self.remote_source_address.yfilter != YFilter.not_set or
                                    self.remote_veid.yfilter != YFilter.not_set or
                                    self.saii.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.taii.yfilter != YFilter.not_set or
                                    (self.local_agi is not None and self.local_agi.has_operation()) or
                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                    (self.remote_agi is not None and self.remote_agi.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "atom" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_veid.get_name_leafdata())
                                if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.saii.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.taii.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-agi"):
                                    if (self.local_agi is None):
                                        self.local_agi = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                    return self.local_agi

                                if (child_yang_name == "multi-segment-pseudowire-stats"):
                                    if (self.multi_segment_pseudowire_stats is None):
                                        self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    return self.multi_segment_pseudowire_stats

                                if (child_yang_name == "remote-agi"):
                                    if (self.remote_agi is None):
                                        self.remote_agi = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                    return self.remote_agi

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-pseudowire-headend"):
                                    self.is_pseudowire_headend = value
                                    self.is_pseudowire_headend.value_namespace = name_space
                                    self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-sai-itype2"):
                                    self.is_sai_itype2 = value
                                    self.is_sai_itype2.value_namespace = name_space
                                    self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-tai-itype2"):
                                    self.is_tai_itype2 = value
                                    self.is_tai_itype2.value_namespace = name_space
                                    self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertisment-failed"):
                                    self.ldp_label_advertisment_failed = value
                                    self.ldp_label_advertisment_failed.value_namespace = name_space
                                    self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-c-ctype"):
                                    self.local_c_ctype = value
                                    self.local_c_ctype.value_namespace = name_space
                                    self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ceid"):
                                    self.local_ceid = value
                                    self.local_ceid.value_namespace = name_space
                                    self.local_ceid.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cv-type"):
                                    self.local_cv_type = value
                                    self.local_cv_type.value_namespace = name_space
                                    self.local_cv_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-group-id"):
                                    self.local_group_id = value
                                    self.local_group_id.value_namespace = name_space
                                    self.local_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ldp-id"):
                                    self.local_ldp_id = value
                                    self.local_ldp_id.value_namespace = name_space
                                    self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-saii-gbl-id"):
                                    self.local_saii_gbl_id = value
                                    self.local_saii_gbl_id.value_namespace = name_space
                                    self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-saiiac-id"):
                                    self.local_saiiac_id = value
                                    self.local_saiiac_id.value_namespace = name_space
                                    self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-taii-gbl-id"):
                                    self.local_taii_gbl_id = value
                                    self.local_taii_gbl_id.value_namespace = name_space
                                    self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-taiiac-id"):
                                    self.local_taiiac_id = value
                                    self.local_taiiac_id.value_namespace = name_space
                                    self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-veid"):
                                    self.local_veid = value
                                    self.local_veid.value_namespace = name_space
                                    self.local_veid.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsd-rewrite-failed"):
                                    self.lsd_rewrite_failed = value
                                    self.lsd_rewrite_failed.value_namespace = name_space
                                    self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saii"):
                                    self.rem_saii = value
                                    self.rem_saii.value_namespace = name_space
                                    self.rem_saii.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saii-gbl-id"):
                                    self.rem_saii_gbl_id = value
                                    self.rem_saii_gbl_id.value_namespace = name_space
                                    self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saiiac-id"):
                                    self.rem_saiiac_id = value
                                    self.rem_saiiac_id.value_namespace = name_space
                                    self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taii"):
                                    self.rem_taii = value
                                    self.rem_taii.value_namespace = name_space
                                    self.rem_taii.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taii-gbl-id"):
                                    self.rem_taii_gbl_id = value
                                    self.rem_taii_gbl_id.value_namespace = name_space
                                    self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taiiac-id"):
                                    self.rem_taiiac_id = value
                                    self.rem_taiiac_id.value_namespace = name_space
                                    self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-c-ctype"):
                                    self.remote_c_ctype = value
                                    self.remote_c_ctype.value_namespace = name_space
                                    self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ceid"):
                                    self.remote_ceid = value
                                    self.remote_ceid.value_namespace = name_space
                                    self.remote_ceid.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cv-type"):
                                    self.remote_cv_type = value
                                    self.remote_cv_type.value_namespace = name_space
                                    self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-group-id"):
                                    self.remote_group_id = value
                                    self.remote_group_id.value_namespace = name_space
                                    self.remote_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ldp-id"):
                                    self.remote_ldp_id = value
                                    self.remote_ldp_id.value_namespace = name_space
                                    self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-source-address"):
                                    self.remote_source_address = value
                                    self.remote_source_address.value_namespace = name_space
                                    self.remote_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-veid"):
                                    self.remote_veid = value
                                    self.remote_veid.value_namespace = name_space
                                    self.remote_veid.value_namespace_prefix = name_space_prefix
                                if(value_path == "saii"):
                                    self.saii = value
                                    self.saii.value_namespace = name_space
                                    self.saii.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "taii"):
                                    self.taii = value
                                    self.taii.value_namespace = name_space
                                    self.taii.value_namespace_prefix = name_space_prefix


                        class L2Tpv3(Entity):
                            """
                            l2tpv3
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_source_address
                            
                            	IPv6 source address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: local_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_size
                            
                            	Local cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_secondary_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_size
                            
                            	Local secondary cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_session_id
                            
                            	Local session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: remote_circuit_status_up
                            
                            	RemoteCircuitStatusUp
                            	**type**\:  bool
                            
                            .. attribute:: remote_cookie_high_value
                            
                            	Upper 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_low_value
                            
                            	Lower 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_size
                            
                            	Remote cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_session_id
                            
                            	Remote session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_state
                            
                            	L2TP tunnel state
                            	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                self.yang_name = "l2tpv3"
                                self.yang_parent_name = "encapsulation-info"

                                self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                self.tos = YLeaf(YType.uint8, "tos")

                                self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                self.ttl = YLeaf(YType.uint8, "ttl")

                                self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dont_fragment_bit",
                                                "ipv4_source_address",
                                                "ipv6_source_address",
                                                "l2tp_class_name",
                                                "local_cookie_high_value",
                                                "local_cookie_low_value",
                                                "local_cookie_size",
                                                "local_secondary_cookie_high_value",
                                                "local_secondary_cookie_low_value",
                                                "local_secondary_cookie_size",
                                                "local_session_id",
                                                "path_mtu_enabled",
                                                "path_mtu_max_value",
                                                "remote_circuit_status_up",
                                                "remote_cookie_high_value",
                                                "remote_cookie_low_value",
                                                "remote_cookie_size",
                                                "remote_session_id",
                                                "tos",
                                                "tos_mode",
                                                "ttl",
                                                "tunnel_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dont_fragment_bit.is_set or
                                    self.ipv4_source_address.is_set or
                                    self.ipv6_source_address.is_set or
                                    self.l2tp_class_name.is_set or
                                    self.local_cookie_high_value.is_set or
                                    self.local_cookie_low_value.is_set or
                                    self.local_cookie_size.is_set or
                                    self.local_secondary_cookie_high_value.is_set or
                                    self.local_secondary_cookie_low_value.is_set or
                                    self.local_secondary_cookie_size.is_set or
                                    self.local_session_id.is_set or
                                    self.path_mtu_enabled.is_set or
                                    self.path_mtu_max_value.is_set or
                                    self.remote_circuit_status_up.is_set or
                                    self.remote_cookie_high_value.is_set or
                                    self.remote_cookie_low_value.is_set or
                                    self.remote_cookie_size.is_set or
                                    self.remote_session_id.is_set or
                                    self.tos.is_set or
                                    self.tos_mode.is_set or
                                    self.ttl.is_set or
                                    self.tunnel_state.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dont_fragment_bit.yfilter != YFilter.not_set or
                                    self.ipv4_source_address.yfilter != YFilter.not_set or
                                    self.ipv6_source_address.yfilter != YFilter.not_set or
                                    self.l2tp_class_name.yfilter != YFilter.not_set or
                                    self.local_cookie_high_value.yfilter != YFilter.not_set or
                                    self.local_cookie_low_value.yfilter != YFilter.not_set or
                                    self.local_cookie_size.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                    self.local_session_id.yfilter != YFilter.not_set or
                                    self.path_mtu_enabled.yfilter != YFilter.not_set or
                                    self.path_mtu_max_value.yfilter != YFilter.not_set or
                                    self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                    self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                    self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                    self.remote_cookie_size.yfilter != YFilter.not_set or
                                    self.remote_session_id.yfilter != YFilter.not_set or
                                    self.tos.yfilter != YFilter.not_set or
                                    self.tos_mode.yfilter != YFilter.not_set or
                                    self.ttl.yfilter != YFilter.not_set or
                                    self.tunnel_state.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2tpv3" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos.get_name_leafdata())
                                if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ttl.get_name_leafdata())
                                if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dont-fragment-bit"):
                                    self.dont_fragment_bit = value
                                    self.dont_fragment_bit.value_namespace = name_space
                                    self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-source-address"):
                                    self.ipv4_source_address = value
                                    self.ipv4_source_address.value_namespace = name_space
                                    self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-source-address"):
                                    self.ipv6_source_address = value
                                    self.ipv6_source_address.value_namespace = name_space
                                    self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "l2tp-class-name"):
                                    self.l2tp_class_name = value
                                    self.l2tp_class_name.value_namespace = name_space
                                    self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-high-value"):
                                    self.local_cookie_high_value = value
                                    self.local_cookie_high_value.value_namespace = name_space
                                    self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-low-value"):
                                    self.local_cookie_low_value = value
                                    self.local_cookie_low_value.value_namespace = name_space
                                    self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-size"):
                                    self.local_cookie_size = value
                                    self.local_cookie_size.value_namespace = name_space
                                    self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-high-value"):
                                    self.local_secondary_cookie_high_value = value
                                    self.local_secondary_cookie_high_value.value_namespace = name_space
                                    self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-low-value"):
                                    self.local_secondary_cookie_low_value = value
                                    self.local_secondary_cookie_low_value.value_namespace = name_space
                                    self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-size"):
                                    self.local_secondary_cookie_size = value
                                    self.local_secondary_cookie_size.value_namespace = name_space
                                    self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-session-id"):
                                    self.local_session_id = value
                                    self.local_session_id.value_namespace = name_space
                                    self.local_session_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-enabled"):
                                    self.path_mtu_enabled = value
                                    self.path_mtu_enabled.value_namespace = name_space
                                    self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-max-value"):
                                    self.path_mtu_max_value = value
                                    self.path_mtu_max_value.value_namespace = name_space
                                    self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-circuit-status-up"):
                                    self.remote_circuit_status_up = value
                                    self.remote_circuit_status_up.value_namespace = name_space
                                    self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-high-value"):
                                    self.remote_cookie_high_value = value
                                    self.remote_cookie_high_value.value_namespace = name_space
                                    self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-low-value"):
                                    self.remote_cookie_low_value = value
                                    self.remote_cookie_low_value.value_namespace = name_space
                                    self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-size"):
                                    self.remote_cookie_size = value
                                    self.remote_cookie_size.value_namespace = name_space
                                    self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-session-id"):
                                    self.remote_session_id = value
                                    self.remote_session_id.value_namespace = name_space
                                    self.remote_session_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos"):
                                    self.tos = value
                                    self.tos.value_namespace = name_space
                                    self.tos.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos-mode"):
                                    self.tos_mode = value
                                    self.tos_mode.value_namespace = name_space
                                    self.tos_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "ttl"):
                                    self.ttl = value
                                    self.ttl.value_namespace = name_space
                                    self.ttl.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-state"):
                                    self.tunnel_state = value
                                    self.tunnel_state.value_namespace = name_space
                                    self.tunnel_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.encapsulation.is_set or
                                (self.atom is not None and self.atom.has_data()) or
                                (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.encapsulation.yfilter != YFilter.not_set or
                                (self.atom is not None and self.atom.has_operation()) or
                                (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "encapsulation-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "atom"):
                                if (self.atom is None):
                                    self.atom = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                return self.atom

                            if (child_yang_name == "l2tpv3"):
                                if (self.l2tpv3 is None):
                                    self.l2tpv3 = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                return self.l2tpv3

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "encapsulation"):
                                self.encapsulation = value
                                self.encapsulation.value_namespace = name_space
                                self.encapsulation.value_namespace_prefix = name_space_prefix


                    class LocalInterface(Entity):
                        """
                        Local interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__init__()

                            self.yang_name = "local-interface"
                            self.yang_parent_name = "pseudo-wire"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "local-interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class RemoteInterface(Entity):
                        """
                        Remote interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__init__()

                            self.yang_name = "remote-interface"
                            self.yang_parent_name = "pseudo-wire"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "remote-interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class PreferredPath(Entity):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__init__()

                            self.yang_name = "preferred-path"
                            self.yang_parent_name = "pseudo-wire"

                            self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                            self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                            self.option = YLeaf(YType.enumeration, "option")

                            self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                            self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ip_tunnel_interface_number",
                                            "next_hop_ip",
                                            "option",
                                            "te_tunnel_interface_number",
                                            "tp_tunnel_interface_number") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ip_tunnel_interface_number.is_set or
                                self.next_hop_ip.is_set or
                                self.option.is_set or
                                self.te_tunnel_interface_number.is_set or
                                self.tp_tunnel_interface_number.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set or
                                self.option.yfilter != YFilter.not_set or
                                self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "preferred-path" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                            if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.option.get_name_leafdata())
                            if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                            if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ip-tunnel-interface-number"):
                                self.ip_tunnel_interface_number = value
                                self.ip_tunnel_interface_number.value_namespace = name_space
                                self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix
                            if(value_path == "option"):
                                self.option = value
                                self.option.value_namespace = name_space
                                self.option.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-tunnel-interface-number"):
                                self.te_tunnel_interface_number = value
                                self.te_tunnel_interface_number.value_namespace = name_space
                                self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "tp-tunnel-interface-number"):
                                self.tp_tunnel_interface_number = value
                                self.tp_tunnel_interface_number.value_namespace = name_space
                                self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                    class LocalSignalling(Entity):
                        """
                        Local signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__init__()

                            self.yang_name = "local-signalling"
                            self.yang_parent_name = "pseudo-wire"

                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self._children_name_map["status_tlv"] = "status-tlv"
                            self._children_yang_names.add("status-tlv")

                            self.tlv = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pw_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                        class StatusTlv(Entity):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                self.yang_name = "status-tlv"
                                self.yang_parent_name = "local-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "status-tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix


                        class Tlv(Entity):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "local-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.tlv:
                                if (c.has_data()):
                                    return True
                            return (
                                self.pw_status.is_set or
                                (self.status_tlv is not None and self.status_tlv.has_data()))

                        def has_operation(self):
                            for c in self.tlv:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pw_status.yfilter != YFilter.not_set or
                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-signalling" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "status-tlv"):
                                if (self.status_tlv is None):
                                    self.status_tlv = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                return self.status_tlv

                            if (child_yang_name == "tlv"):
                                for c in self.tlv:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.tlv.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pw-status"):
                                self.pw_status = value
                                self.pw_status.value_namespace = name_space
                                self.pw_status.value_namespace_prefix = name_space_prefix


                    class RemoteSignalling(Entity):
                        """
                        Remote signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__init__()

                            self.yang_name = "remote-signalling"
                            self.yang_parent_name = "pseudo-wire"

                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self._children_name_map["status_tlv"] = "status-tlv"
                            self._children_yang_names.add("status-tlv")

                            self.tlv = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pw_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                        class StatusTlv(Entity):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                self.yang_name = "status-tlv"
                                self.yang_parent_name = "remote-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "status-tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix


                        class Tlv(Entity):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "remote-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.tlv:
                                if (c.has_data()):
                                    return True
                            return (
                                self.pw_status.is_set or
                                (self.status_tlv is not None and self.status_tlv.has_data()))

                        def has_operation(self):
                            for c in self.tlv:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pw_status.yfilter != YFilter.not_set or
                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-signalling" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "status-tlv"):
                                if (self.status_tlv is None):
                                    self.status_tlv = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                return self.status_tlv

                            if (child_yang_name == "tlv"):
                                for c in self.tlv:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.tlv.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pw-status"):
                                self.pw_status = value
                                self.pw_status.value_namespace = name_space
                                self.pw_status.value_namespace_prefix = name_space_prefix


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "pseudo-wire"

                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                            self._children_yang_names.add("dispostion-stats")

                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self._children_name_map["impostion_stats"] = "impostion-stats"
                            self._children_yang_names.add("impostion-stats")

                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                            self.sequence_number.parent = self
                            self._children_name_map["sequence_number"] = "sequence-number"
                            self._children_yang_names.add("sequence-number")


                        class ImpostionStats(Entity):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                self.yang_name = "impostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self._children_name_map["broadcast"] = "broadcast"
                                self._children_yang_names.add("broadcast")

                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                self._children_yang_names.add("imposition-mtu-drop")

                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                self._children_yang_names.add("imposition-stat")

                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                self._children_yang_names.add("impostion-tail-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                self._children_yang_names.add("l2fsbi-drop")

                                self.multicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                                self._children_yang_names.add("multicast")

                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self
                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                self._children_yang_names.add("unknown-unicast")


                            class ImpositionStat(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                    self.yang_name = "imposition-stat"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpositionMtuDrop(Entity):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                    self.yang_name = "imposition-mtu-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpostionTailDrop(Entity):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                    self.yang_name = "impostion-tail-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class L2FsbiDrop(Entity):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                    self.yang_name = "l2fsbi-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fsbi-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Multicast(Entity):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Broadcast(Entity):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                    self.yang_name = "broadcast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnknownUnicast(Entity):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                    self.yang_name = "unknown-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unknown-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                    (self.multicast is not None and self.multicast.has_data()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                    (self.multicast is not None and self.multicast.has_operation()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "impostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast"):
                                    if (self.broadcast is None):
                                        self.broadcast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                    return self.broadcast

                                if (child_yang_name == "imposition-mtu-drop"):
                                    if (self.imposition_mtu_drop is None):
                                        self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    return self.imposition_mtu_drop

                                if (child_yang_name == "imposition-stat"):
                                    if (self.imposition_stat is None):
                                        self.imposition_stat = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                    return self.imposition_stat

                                if (child_yang_name == "impostion-tail-drop"):
                                    if (self.impostion_tail_drop is None):
                                        self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    return self.impostion_tail_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "l2fsbi-drop"):
                                    if (self.l2fsbi_drop is None):
                                        self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    return self.l2fsbi_drop

                                if (child_yang_name == "multicast"):
                                    if (self.multicast is None):
                                        self.multicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                    return self.multicast

                                if (child_yang_name == "unknown-unicast"):
                                    if (self.unknown_unicast is None):
                                        self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    return self.unknown_unicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DispostionStats(Entity):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats, self).__init__()

                                self.yang_name = "dispostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                self._children_yang_names.add("broadcast-drop")

                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self._children_name_map["dai_drop"] = "dai-drop"
                                self._children_yang_names.add("dai-drop")

                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                self._children_yang_names.add("disposition-mtu-drop")

                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                self._children_yang_names.add("disposition-oo-o-drops")

                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                self._children_yang_names.add("disposition-p2mp-stats")

                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                self._children_yang_names.add("disposition-stat")

                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                self._children_yang_names.add("disposition-tail-drop")

                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                self._children_yang_names.add("ipsg-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.mac_move = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self._children_name_map["mac_move"] = "mac-move"
                                self._children_yang_names.add("mac-move")

                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                self._children_yang_names.add("multicast-drop")

                                self.received_drops = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self._children_name_map["received_drops"] = "received-drops"
                                self._children_yang_names.add("received-drops")

                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self
                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                self._children_yang_names.add("unicast-drop")


                            class DispositionStat(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                    self.yang_name = "disposition-stat"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionMtuDrop(Entity):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                    self.yang_name = "disposition-mtu-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionTailDrop(Entity):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                    self.yang_name = "disposition-tail-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MulticastDrop(Entity):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                    self.yang_name = "multicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnicastDrop(Entity):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                    self.yang_name = "unicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class BroadcastDrop(Entity):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                    self.yang_name = "broadcast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ReceivedDrops(Entity):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                    self.yang_name = "received-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DaiDrop(Entity):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                    self.yang_name = "dai-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dai-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class IpsgDrop(Entity):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                    self.yang_name = "ipsg-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipsg-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionOoODrops(Entity):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                    self.yang_name = "disposition-oo-o-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionP2MpStats(Entity):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                    self.yang_name = "disposition-p2mp-stats"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MacMove(Entity):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                    self.yang_name = "mac-move"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-move" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dispostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast-drop"):
                                    if (self.broadcast_drop is None):
                                        self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    return self.broadcast_drop

                                if (child_yang_name == "dai-drop"):
                                    if (self.dai_drop is None):
                                        self.dai_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                    return self.dai_drop

                                if (child_yang_name == "disposition-mtu-drop"):
                                    if (self.disposition_mtu_drop is None):
                                        self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    return self.disposition_mtu_drop

                                if (child_yang_name == "disposition-oo-o-drops"):
                                    if (self.disposition_oo_o_drops is None):
                                        self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    return self.disposition_oo_o_drops

                                if (child_yang_name == "disposition-p2mp-stats"):
                                    if (self.disposition_p2mp_stats is None):
                                        self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    return self.disposition_p2mp_stats

                                if (child_yang_name == "disposition-stat"):
                                    if (self.disposition_stat is None):
                                        self.disposition_stat = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                    return self.disposition_stat

                                if (child_yang_name == "disposition-tail-drop"):
                                    if (self.disposition_tail_drop is None):
                                        self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    return self.disposition_tail_drop

                                if (child_yang_name == "ipsg-drop"):
                                    if (self.ipsg_drop is None):
                                        self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    return self.ipsg_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "mac-move"):
                                    if (self.mac_move is None):
                                        self.mac_move = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                    return self.mac_move

                                if (child_yang_name == "multicast-drop"):
                                    if (self.multicast_drop is None):
                                        self.multicast_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                    return self.multicast_drop

                                if (child_yang_name == "received-drops"):
                                    if (self.received_drops is None):
                                        self.received_drops = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                    return self.received_drops

                                if (child_yang_name == "unicast-drop"):
                                    if (self.unicast_drop is None):
                                        self.unicast_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                    return self.unicast_drop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SequenceNumber(Entity):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                self.yang_name = "sequence-number"
                                self.yang_parent_name = "statistics"

                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bypassed_inbound_sequence_packet",
                                                "bypassed_out_sequence_packet",
                                                "sequence_number_expected",
                                                "sequence_number_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bypassed_inbound_sequence_packet.is_set or
                                    self.bypassed_out_sequence_packet.is_set or
                                    self.sequence_number_expected.is_set or
                                    self.sequence_number_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sequence-number" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bypassed-inbound-sequence-packet"):
                                    self.bypassed_inbound_sequence_packet = value
                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "bypassed-out-sequence-packet"):
                                    self.bypassed_out_sequence_packet = value
                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-expected"):
                                    self.sequence_number_expected = value
                                    self.sequence_number_expected.value_namespace = name_space
                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-sent"):
                                    self.sequence_number_sent = value
                                    self.sequence_number_sent.value_namespace = name_space
                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                (self.sequence_number is not None and self.sequence_number.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dispostion-stats"):
                                if (self.dispostion_stats is None):
                                    self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                return self.dispostion_stats

                            if (child_yang_name == "impostion-stats"):
                                if (self.impostion_stats is None):
                                    self.impostion_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                return self.impostion_stats

                            if (child_yang_name == "sequence-number"):
                                if (self.sequence_number is None):
                                    self.sequence_number = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                return self.sequence_number

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class P2MpPw(Entity):
                        """
                        P2MP Pseudowire Information
                        
                        .. attribute:: local_available
                        
                        	Local LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: local_extended_tunnel_id
                        
                        	Local Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_flags
                        
                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: local_label
                        
                        	Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_p2mp_id
                        
                        	Local P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_ptree_type
                        
                        	Local P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                        
                        .. attribute:: local_tunnel_id
                        
                        	Local Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_available
                        
                        	Remote LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: remote_extended_tunnel_id
                        
                        	Remote Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_flags
                        
                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_label
                        
                        	Remote Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_p2mp_id
                        
                        	Remote P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_ptree_type
                        
                        	Remote P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                        
                        .. attribute:: remote_tunnel_id
                        
                        	Remote Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__init__()

                            self.yang_name = "p2mp-pw"
                            self.yang_parent_name = "pseudo-wire"

                            self.local_available = YLeaf(YType.boolean, "local-available")

                            self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                            self.local_flags = YLeaf(YType.uint8, "local-flags")

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                            self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                            self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                            self.remote_available = YLeaf(YType.boolean, "remote-available")

                            self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                            self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                            self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                            self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                            self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("local_available",
                                            "local_extended_tunnel_id",
                                            "local_flags",
                                            "local_label",
                                            "local_p2mp_id",
                                            "local_ptree_type",
                                            "local_tunnel_id",
                                            "remote_available",
                                            "remote_extended_tunnel_id",
                                            "remote_flags",
                                            "remote_label",
                                            "remote_p2mp_id",
                                            "remote_ptree_type",
                                            "remote_tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.local_available.is_set or
                                self.local_extended_tunnel_id.is_set or
                                self.local_flags.is_set or
                                self.local_label.is_set or
                                self.local_p2mp_id.is_set or
                                self.local_ptree_type.is_set or
                                self.local_tunnel_id.is_set or
                                self.remote_available.is_set or
                                self.remote_extended_tunnel_id.is_set or
                                self.remote_flags.is_set or
                                self.remote_label.is_set or
                                self.remote_p2mp_id.is_set or
                                self.remote_ptree_type.is_set or
                                self.remote_tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.local_available.yfilter != YFilter.not_set or
                                self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                self.local_flags.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                self.local_p2mp_id.yfilter != YFilter.not_set or
                                self.local_ptree_type.yfilter != YFilter.not_set or
                                self.local_tunnel_id.yfilter != YFilter.not_set or
                                self.remote_available.yfilter != YFilter.not_set or
                                self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                self.remote_flags.yfilter != YFilter.not_set or
                                self.remote_label.yfilter != YFilter.not_set or
                                self.remote_p2mp_id.yfilter != YFilter.not_set or
                                self.remote_ptree_type.yfilter != YFilter.not_set or
                                self.remote_tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-pw" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_available.get_name_leafdata())
                            if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                            if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_flags.get_name_leafdata())
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())
                            if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                            if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                            if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                            if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_available.get_name_leafdata())
                            if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                            if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_flags.get_name_leafdata())
                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                            if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                            if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                            if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "local-available"):
                                self.local_available = value
                                self.local_available.value_namespace = name_space
                                self.local_available.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-extended-tunnel-id"):
                                self.local_extended_tunnel_id = value
                                self.local_extended_tunnel_id.value_namespace = name_space
                                self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-flags"):
                                self.local_flags = value
                                self.local_flags.value_namespace = name_space
                                self.local_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-p2mp-id"):
                                self.local_p2mp_id = value
                                self.local_p2mp_id.value_namespace = name_space
                                self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-ptree-type"):
                                self.local_ptree_type = value
                                self.local_ptree_type.value_namespace = name_space
                                self.local_ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-tunnel-id"):
                                self.local_tunnel_id = value
                                self.local_tunnel_id.value_namespace = name_space
                                self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-available"):
                                self.remote_available = value
                                self.remote_available.value_namespace = name_space
                                self.remote_available.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-extended-tunnel-id"):
                                self.remote_extended_tunnel_id = value
                                self.remote_extended_tunnel_id.value_namespace = name_space
                                self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-flags"):
                                self.remote_flags = value
                                self.remote_flags.value_namespace = name_space
                                self.remote_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label"):
                                self.remote_label = value
                                self.remote_label.value_namespace = name_space
                                self.remote_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-p2mp-id"):
                                self.remote_p2mp_id = value
                                self.remote_p2mp_id.value_namespace = name_space
                                self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-ptree-type"):
                                self.remote_ptree_type = value
                                self.remote_ptree_type.value_namespace = name_space
                                self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-tunnel-id"):
                                self.remote_tunnel_id = value
                                self.remote_tunnel_id.value_namespace = name_space
                                self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ad_method.is_set or
                            self.ad_remote_down.is_set or
                            self.admited_bw.is_set or
                            self.auto_discovery.is_set or
                            self.backup_active.is_set or
                            self.backup_force_active.is_set or
                            self.backup_pw.is_set or
                            self.bitrate_mismatched.is_set or
                            self.bridge_pw_type_mismatch.is_set or
                            self.cas_mismatched.is_set or
                            self.diff_ts_mismatched.is_set or
                            self.disable_delay.is_set or
                            self.disable_never.is_set or
                            self.evpn_src_acid.is_set or
                            self.fe_ctype.is_set or
                            self.forward_class.is_set or
                            self.freq_mismatched.is_set or
                            self.illegal_control_word.is_set or
                            self.imposed_vlan_id.is_set or
                            self.interworking.is_set or
                            self.ipv6_local_source_address.is_set or
                            self.is_evpnvpws_type.is_set or
                            self.is_flow_label_static.is_set or
                            self.is_multi_segment_pseudowire.is_set or
                            self.is_partially_programmed.is_set or
                            self.is_pwr_type.is_set or
                            self.is_vfi.is_set or
                            self.last_time_status_changed.is_set or
                            self.last_time_status_down.is_set or
                            self.ldp_label_advertise_failed.is_set or
                            self.load_balance.is_set or
                            self.local_control_word.is_set or
                            self.local_label_failed.is_set or
                            self.local_pseudo_wire_type.is_set or
                            self.local_source_address.is_set or
                            self.mac_limit_oper_down.is_set or
                            self.mtu_mismatched.is_set or
                            self.not_supported_qinq.is_set or
                            self.num_ma_cwithdraw_msg_received.is_set or
                            self.number_ma_cwithdraw_message_sent.is_set or
                            self.out_of_memory_state.is_set or
                            self.payload_bytes_mismatched.is_set or
                            self.payload_type_mismatched.is_set or
                            self.preferred_path_disable_fallback.is_set or
                            self.primary_peer_id.is_set or
                            self.primary_pseudo_wire_id.is_set or
                            self.primary_pw.is_set or
                            self.protocol.is_set or
                            self.pseudo_wire_id.is_set or
                            self.pseudo_wire_state.is_set or
                            self.pseudo_wire_type_mismatched.is_set or
                            self.pw_class_name.is_set or
                            self.pw_flow_label_code17_disabled.is_set or
                            self.pw_flow_label_type.is_set or
                            self.pw_flow_label_type_cfg.is_set or
                            self.pw_redundancy_initial_delay.is_set or
                            self.pw_redundancy_one_way.is_set or
                            self.pw_status_use.is_set or
                            self.pwlsd_rewrite_failed.is_set or
                            self.remote_control_word.is_set or
                            self.remote_label_failed.is_set or
                            self.remote_pseudo_wire_type.is_set or
                            self.required_bw.is_set or
                            self.resync_enabled.is_set or
                            self.resync_threshold.is_set or
                            self.rtp_mismatched.is_set or
                            self.sequencing_type.is_set or
                            self.shutdown.is_set or
                            self.sig_pkts_mismatched.is_set or
                            self.ssrc_mismatched.is_set or
                            self.state.is_set or
                            self.table_policy_name.is_set or
                            self.tag_rewrite.is_set or
                            self.time_created.is_set or
                            self.time_elapsed_creation.is_set or
                            self.time_elapsed_status_changed.is_set or
                            self.time_elapsed_status_down.is_set or
                            self.transport_lsp_down.is_set or
                            self.xconnect_id.is_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                            (self.local_interface is not None and self.local_interface.has_data()) or
                            (self.local_signalling is not None and self.local_signalling.has_data()) or
                            (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                            (self.peer_id is not None and self.peer_id.has_data()) or
                            (self.preferred_path is not None and self.preferred_path.has_data()) or
                            (self.remote_interface is not None and self.remote_interface.has_data()) or
                            (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ad_method.yfilter != YFilter.not_set or
                            self.ad_remote_down.yfilter != YFilter.not_set or
                            self.admited_bw.yfilter != YFilter.not_set or
                            self.auto_discovery.yfilter != YFilter.not_set or
                            self.backup_active.yfilter != YFilter.not_set or
                            self.backup_force_active.yfilter != YFilter.not_set or
                            self.backup_pw.yfilter != YFilter.not_set or
                            self.bitrate_mismatched.yfilter != YFilter.not_set or
                            self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                            self.cas_mismatched.yfilter != YFilter.not_set or
                            self.diff_ts_mismatched.yfilter != YFilter.not_set or
                            self.disable_delay.yfilter != YFilter.not_set or
                            self.disable_never.yfilter != YFilter.not_set or
                            self.evpn_src_acid.yfilter != YFilter.not_set or
                            self.fe_ctype.yfilter != YFilter.not_set or
                            self.forward_class.yfilter != YFilter.not_set or
                            self.freq_mismatched.yfilter != YFilter.not_set or
                            self.illegal_control_word.yfilter != YFilter.not_set or
                            self.imposed_vlan_id.yfilter != YFilter.not_set or
                            self.interworking.yfilter != YFilter.not_set or
                            self.ipv6_local_source_address.yfilter != YFilter.not_set or
                            self.is_evpnvpws_type.yfilter != YFilter.not_set or
                            self.is_flow_label_static.yfilter != YFilter.not_set or
                            self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                            self.is_partially_programmed.yfilter != YFilter.not_set or
                            self.is_pwr_type.yfilter != YFilter.not_set or
                            self.is_vfi.yfilter != YFilter.not_set or
                            self.last_time_status_changed.yfilter != YFilter.not_set or
                            self.last_time_status_down.yfilter != YFilter.not_set or
                            self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                            self.load_balance.yfilter != YFilter.not_set or
                            self.local_control_word.yfilter != YFilter.not_set or
                            self.local_label_failed.yfilter != YFilter.not_set or
                            self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                            self.local_source_address.yfilter != YFilter.not_set or
                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                            self.mtu_mismatched.yfilter != YFilter.not_set or
                            self.not_supported_qinq.yfilter != YFilter.not_set or
                            self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                            self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                            self.out_of_memory_state.yfilter != YFilter.not_set or
                            self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                            self.payload_type_mismatched.yfilter != YFilter.not_set or
                            self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                            self.primary_peer_id.yfilter != YFilter.not_set or
                            self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                            self.primary_pw.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.pseudo_wire_id.yfilter != YFilter.not_set or
                            self.pseudo_wire_state.yfilter != YFilter.not_set or
                            self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                            self.pw_class_name.yfilter != YFilter.not_set or
                            self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                            self.pw_flow_label_type.yfilter != YFilter.not_set or
                            self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                            self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                            self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                            self.pw_status_use.yfilter != YFilter.not_set or
                            self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                            self.remote_control_word.yfilter != YFilter.not_set or
                            self.remote_label_failed.yfilter != YFilter.not_set or
                            self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                            self.required_bw.yfilter != YFilter.not_set or
                            self.resync_enabled.yfilter != YFilter.not_set or
                            self.resync_threshold.yfilter != YFilter.not_set or
                            self.rtp_mismatched.yfilter != YFilter.not_set or
                            self.sequencing_type.yfilter != YFilter.not_set or
                            self.shutdown.yfilter != YFilter.not_set or
                            self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                            self.ssrc_mismatched.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.table_policy_name.yfilter != YFilter.not_set or
                            self.tag_rewrite.yfilter != YFilter.not_set or
                            self.time_created.yfilter != YFilter.not_set or
                            self.time_elapsed_creation.yfilter != YFilter.not_set or
                            self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                            self.time_elapsed_status_down.yfilter != YFilter.not_set or
                            self.transport_lsp_down.yfilter != YFilter.not_set or
                            self.xconnect_id.yfilter != YFilter.not_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                            (self.local_interface is not None and self.local_interface.has_operation()) or
                            (self.local_signalling is not None and self.local_signalling.has_operation()) or
                            (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                            (self.peer_id is not None and self.peer_id.has_operation()) or
                            (self.preferred_path is not None and self.preferred_path.has_operation()) or
                            (self.remote_interface is not None and self.remote_interface.has_operation()) or
                            (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pseudo-wire" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_method.get_name_leafdata())
                        if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                        if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.admited_bw.get_name_leafdata())
                        if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                        if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_active.get_name_leafdata())
                        if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                        if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_pw.get_name_leafdata())
                        if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                        if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                        if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                        if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                        if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_delay.get_name_leafdata())
                        if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_never.get_name_leafdata())
                        if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                        if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                        if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.forward_class.get_name_leafdata())
                        if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                        if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                        if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interworking.get_name_leafdata())
                        if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                        if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                        if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                        if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                        if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                        if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                        if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_vfi.get_name_leafdata())
                        if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                        if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                        if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                        if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance.get_name_leafdata())
                        if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_control_word.get_name_leafdata())
                        if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                        if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                        if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_source_address.get_name_leafdata())
                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                        if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                        if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                        if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                        if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                        if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                        if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                        if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                        if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                        if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_pw.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                        if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                        if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                        if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                        if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                        if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                        if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                        if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                        if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                        if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                        if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                        if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                        if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                        if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                        if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.required_bw.get_name_leafdata())
                        if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                        if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                        if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                        if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                        if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                        if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                        if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                        if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_created.get_name_leafdata())
                        if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                        if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                        if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                        if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "encapsulation-info"):
                            if (self.encapsulation_info is None):
                                self.encapsulation_info = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            return self.encapsulation_info

                        if (child_yang_name == "local-interface"):
                            if (self.local_interface is None):
                                self.local_interface = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                            return self.local_interface

                        if (child_yang_name == "local-signalling"):
                            if (self.local_signalling is None):
                                self.local_signalling = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                            return self.local_signalling

                        if (child_yang_name == "p2mp-pw"):
                            if (self.p2mp_pw is None):
                                self.p2mp_pw = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            return self.p2mp_pw

                        if (child_yang_name == "peer-id"):
                            if (self.peer_id is None):
                                self.peer_id = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                            return self.peer_id

                        if (child_yang_name == "preferred-path"):
                            if (self.preferred_path is None):
                                self.preferred_path = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                            return self.preferred_path

                        if (child_yang_name == "remote-interface"):
                            if (self.remote_interface is None):
                                self.remote_interface = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                            return self.remote_interface

                        if (child_yang_name == "remote-signalling"):
                            if (self.remote_signalling is None):
                                self.remote_signalling = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                            return self.remote_signalling

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ad-method"):
                            self.ad_method = value
                            self.ad_method.value_namespace = name_space
                            self.ad_method.value_namespace_prefix = name_space_prefix
                        if(value_path == "ad-remote-down"):
                            self.ad_remote_down = value
                            self.ad_remote_down.value_namespace = name_space
                            self.ad_remote_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "admited-bw"):
                            self.admited_bw = value
                            self.admited_bw.value_namespace = name_space
                            self.admited_bw.value_namespace_prefix = name_space_prefix
                        if(value_path == "auto-discovery"):
                            self.auto_discovery = value
                            self.auto_discovery.value_namespace = name_space
                            self.auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-active"):
                            self.backup_active = value
                            self.backup_active.value_namespace = name_space
                            self.backup_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-force-active"):
                            self.backup_force_active = value
                            self.backup_force_active.value_namespace = name_space
                            self.backup_force_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-pw"):
                            self.backup_pw = value
                            self.backup_pw.value_namespace = name_space
                            self.backup_pw.value_namespace_prefix = name_space_prefix
                        if(value_path == "bitrate-mismatched"):
                            self.bitrate_mismatched = value
                            self.bitrate_mismatched.value_namespace = name_space
                            self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-pw-type-mismatch"):
                            self.bridge_pw_type_mismatch = value
                            self.bridge_pw_type_mismatch.value_namespace = name_space
                            self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                        if(value_path == "cas-mismatched"):
                            self.cas_mismatched = value
                            self.cas_mismatched.value_namespace = name_space
                            self.cas_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "diff-ts-mismatched"):
                            self.diff_ts_mismatched = value
                            self.diff_ts_mismatched.value_namespace = name_space
                            self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-delay"):
                            self.disable_delay = value
                            self.disable_delay.value_namespace = name_space
                            self.disable_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-never"):
                            self.disable_never = value
                            self.disable_never.value_namespace = name_space
                            self.disable_never.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-src-acid"):
                            self.evpn_src_acid = value
                            self.evpn_src_acid.value_namespace = name_space
                            self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                        if(value_path == "fe-ctype"):
                            self.fe_ctype = value
                            self.fe_ctype.value_namespace = name_space
                            self.fe_ctype.value_namespace_prefix = name_space_prefix
                        if(value_path == "forward-class"):
                            self.forward_class = value
                            self.forward_class.value_namespace = name_space
                            self.forward_class.value_namespace_prefix = name_space_prefix
                        if(value_path == "freq-mismatched"):
                            self.freq_mismatched = value
                            self.freq_mismatched.value_namespace = name_space
                            self.freq_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "illegal-control-word"):
                            self.illegal_control_word = value
                            self.illegal_control_word.value_namespace = name_space
                            self.illegal_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "imposed-vlan-id"):
                            self.imposed_vlan_id = value
                            self.imposed_vlan_id.value_namespace = name_space
                            self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interworking"):
                            self.interworking = value
                            self.interworking.value_namespace = name_space
                            self.interworking.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-local-source-address"):
                            self.ipv6_local_source_address = value
                            self.ipv6_local_source_address.value_namespace = name_space
                            self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-evpnvpws-type"):
                            self.is_evpnvpws_type = value
                            self.is_evpnvpws_type.value_namespace = name_space
                            self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-flow-label-static"):
                            self.is_flow_label_static = value
                            self.is_flow_label_static.value_namespace = name_space
                            self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multi-segment-pseudowire"):
                            self.is_multi_segment_pseudowire = value
                            self.is_multi_segment_pseudowire.value_namespace = name_space
                            self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-partially-programmed"):
                            self.is_partially_programmed = value
                            self.is_partially_programmed.value_namespace = name_space
                            self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pwr-type"):
                            self.is_pwr_type = value
                            self.is_pwr_type.value_namespace = name_space
                            self.is_pwr_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-vfi"):
                            self.is_vfi = value
                            self.is_vfi.value_namespace = name_space
                            self.is_vfi.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-changed"):
                            self.last_time_status_changed = value
                            self.last_time_status_changed.value_namespace = name_space
                            self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-down"):
                            self.last_time_status_down = value
                            self.last_time_status_down.value_namespace = name_space
                            self.last_time_status_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "ldp-label-advertise-failed"):
                            self.ldp_label_advertise_failed = value
                            self.ldp_label_advertise_failed.value_namespace = name_space
                            self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance"):
                            self.load_balance = value
                            self.load_balance.value_namespace = name_space
                            self.load_balance.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-control-word"):
                            self.local_control_word = value
                            self.local_control_word.value_namespace = name_space
                            self.local_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-label-failed"):
                            self.local_label_failed = value
                            self.local_label_failed.value_namespace = name_space
                            self.local_label_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-pseudo-wire-type"):
                            self.local_pseudo_wire_type = value
                            self.local_pseudo_wire_type.value_namespace = name_space
                            self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-source-address"):
                            self.local_source_address = value
                            self.local_source_address.value_namespace = name_space
                            self.local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-oper-down"):
                            self.mac_limit_oper_down = value
                            self.mac_limit_oper_down.value_namespace = name_space
                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-mismatched"):
                            self.mtu_mismatched = value
                            self.mtu_mismatched.value_namespace = name_space
                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-qinq"):
                            self.not_supported_qinq = value
                            self.not_supported_qinq.value_namespace = name_space
                            self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-ma-cwithdraw-msg-received"):
                            self.num_ma_cwithdraw_msg_received = value
                            self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                            self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-ma-cwithdraw-message-sent"):
                            self.number_ma_cwithdraw_message_sent = value
                            self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                            self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-of-memory-state"):
                            self.out_of_memory_state = value
                            self.out_of_memory_state.value_namespace = name_space
                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "payload-bytes-mismatched"):
                            self.payload_bytes_mismatched = value
                            self.payload_bytes_mismatched.value_namespace = name_space
                            self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "payload-type-mismatched"):
                            self.payload_type_mismatched = value
                            self.payload_type_mismatched.value_namespace = name_space
                            self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "preferred-path-disable-fallback"):
                            self.preferred_path_disable_fallback = value
                            self.preferred_path_disable_fallback.value_namespace = name_space
                            self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-peer-id"):
                            self.primary_peer_id = value
                            self.primary_peer_id.value_namespace = name_space
                            self.primary_peer_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-pseudo-wire-id"):
                            self.primary_pseudo_wire_id = value
                            self.primary_pseudo_wire_id.value_namespace = name_space
                            self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-pw"):
                            self.primary_pw = value
                            self.primary_pw.value_namespace = name_space
                            self.primary_pw.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-id"):
                            self.pseudo_wire_id = value
                            self.pseudo_wire_id.value_namespace = name_space
                            self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-state"):
                            self.pseudo_wire_state = value
                            self.pseudo_wire_state.value_namespace = name_space
                            self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-type-mismatched"):
                            self.pseudo_wire_type_mismatched = value
                            self.pseudo_wire_type_mismatched.value_namespace = name_space
                            self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-class-name"):
                            self.pw_class_name = value
                            self.pw_class_name.value_namespace = name_space
                            self.pw_class_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-code17-disabled"):
                            self.pw_flow_label_code17_disabled = value
                            self.pw_flow_label_code17_disabled.value_namespace = name_space
                            self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type"):
                            self.pw_flow_label_type = value
                            self.pw_flow_label_type.value_namespace = name_space
                            self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type-cfg"):
                            self.pw_flow_label_type_cfg = value
                            self.pw_flow_label_type_cfg.value_namespace = name_space
                            self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-redundancy-initial-delay"):
                            self.pw_redundancy_initial_delay = value
                            self.pw_redundancy_initial_delay.value_namespace = name_space
                            self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-redundancy-one-way"):
                            self.pw_redundancy_one_way = value
                            self.pw_redundancy_one_way.value_namespace = name_space
                            self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-status-use"):
                            self.pw_status_use = value
                            self.pw_status_use.value_namespace = name_space
                            self.pw_status_use.value_namespace_prefix = name_space_prefix
                        if(value_path == "pwlsd-rewrite-failed"):
                            self.pwlsd_rewrite_failed = value
                            self.pwlsd_rewrite_failed.value_namespace = name_space
                            self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-control-word"):
                            self.remote_control_word = value
                            self.remote_control_word.value_namespace = name_space
                            self.remote_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-label-failed"):
                            self.remote_label_failed = value
                            self.remote_label_failed.value_namespace = name_space
                            self.remote_label_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-pseudo-wire-type"):
                            self.remote_pseudo_wire_type = value
                            self.remote_pseudo_wire_type.value_namespace = name_space
                            self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "required-bw"):
                            self.required_bw = value
                            self.required_bw.value_namespace = name_space
                            self.required_bw.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-enabled"):
                            self.resync_enabled = value
                            self.resync_enabled.value_namespace = name_space
                            self.resync_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-threshold"):
                            self.resync_threshold = value
                            self.resync_threshold.value_namespace = name_space
                            self.resync_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "rtp-mismatched"):
                            self.rtp_mismatched = value
                            self.rtp_mismatched.value_namespace = name_space
                            self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "sequencing-type"):
                            self.sequencing_type = value
                            self.sequencing_type.value_namespace = name_space
                            self.sequencing_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "shutdown"):
                            self.shutdown = value
                            self.shutdown.value_namespace = name_space
                            self.shutdown.value_namespace_prefix = name_space_prefix
                        if(value_path == "sig-pkts-mismatched"):
                            self.sig_pkts_mismatched = value
                            self.sig_pkts_mismatched.value_namespace = name_space
                            self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssrc-mismatched"):
                            self.ssrc_mismatched = value
                            self.ssrc_mismatched.value_namespace = name_space
                            self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-policy-name"):
                            self.table_policy_name = value
                            self.table_policy_name.value_namespace = name_space
                            self.table_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "tag-rewrite"):
                            self.tag_rewrite = value
                            self.tag_rewrite.value_namespace = name_space
                            self.tag_rewrite.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-created"):
                            self.time_created = value
                            self.time_created.value_namespace = name_space
                            self.time_created.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-creation"):
                            self.time_elapsed_creation = value
                            self.time_elapsed_creation.value_namespace = name_space
                            self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-changed"):
                            self.time_elapsed_status_changed = value
                            self.time_elapsed_status_changed.value_namespace = name_space
                            self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-down"):
                            self.time_elapsed_status_down = value
                            self.time_elapsed_status_down.value_namespace = name_space
                            self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "transport-lsp-down"):
                            self.transport_lsp_down = value
                            self.transport_lsp_down.value_namespace = name_space
                            self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-id"):
                            self.xconnect_id = value
                            self.xconnect_id.value_namespace = name_space
                            self.xconnect_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.segment_type.is_set or
                        (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                        (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.segment_type.yfilter != YFilter.not_set or
                        (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                        (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "backup" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.segment_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "attachment-circuit"):
                        if (self.attachment_circuit is None):
                            self.attachment_circuit = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        return self.attachment_circuit

                    if (child_yang_name == "pseudo-wire"):
                        if (self.pseudo_wire is None):
                            self.pseudo_wire = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        return self.pseudo_wire

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "segment-type"):
                        self.segment_type = value
                        self.segment_type.value_namespace = name_space
                        self.segment_type.value_namespace_prefix = name_space_prefix


            class Segment1(Entity):
                """
                Segment 1
                
                .. attribute:: attachment_circuit
                
                	Attachment Circuit
                	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                
                .. attribute:: pseudo_wire
                
                	Pseudowire
                	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire>`
                
                .. attribute:: segment_type
                
                	SegmentType
                	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Xconnects.Xconnect.Segment1, self).__init__()

                    self.yang_name = "segment1"
                    self.yang_parent_name = "xconnect"

                    self.segment_type = YLeaf(YType.enumeration, "segment-type")

                    self.attachment_circuit = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                    self.attachment_circuit.parent = self
                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                    self._children_yang_names.add("attachment-circuit")

                    self.pseudo_wire = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire()
                    self.pseudo_wire.parent = self
                    self._children_name_map["pseudo_wire"] = "pseudo-wire"
                    self._children_yang_names.add("pseudo-wire")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("segment_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Xconnects.Xconnect.Segment1, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Xconnects.Xconnect.Segment1, self).__setattr__(name, value)


                class AttachmentCircuit(Entity):
                    """
                    Attachment Circuit
                    
                    .. attribute:: bvi_mac_conflict
                    
                    	BVI Mac Conflict
                    	**type**\:  bool
                    
                    .. attribute:: bvi_no_port_up
                    
                    	BVI no BP Up
                    	**type**\:  bool
                    
                    .. attribute:: control_word_mismatched
                    
                    	Control word mismatched
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_error
                    
                    	Encapsulation Error
                    	**type**\:  str
                    
                    .. attribute:: encapsulation_mismatched
                    
                    	Encapsulation mismatched
                    	**type**\:  bool
                    
                    .. attribute:: evpn_internal_label
                    
                    	EVPN Internal Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interface
                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                    
                    .. attribute:: interface_handle
                    
                    	Interface Handler
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: internal_ms_ti
                    
                    	Internal MSTi
                    	**type**\:  str
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                    
                    .. attribute:: is_ac_partially_programmed
                    
                    	Is attachment\-circuit partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: l2vpn_protection
                    
                    	Protection object used for this segment
                    	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection>`
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: ms_ti_mismatch
                    
                    	MSTi mismatch
                    	**type**\:  bool
                    
                    .. attribute:: msti
                    
                    	MSTi
                    	**type**\:  str
                    
                    .. attribute:: msti_mismatch_down
                    
                    	Oper down due to MSTI mismatch
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Node ID
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_id
                    
                    	Redundancy Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_state
                    
                    	Redundancy Group State
                    	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                    
                    .. attribute:: redundancy_object_id
                    
                    	Redundancy Object ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                    
                    .. attribute:: tdm_media_mismatched
                    
                    	TDM media parms mismatched
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__init__()

                        self.yang_name = "attachment-circuit"
                        self.yang_parent_name = "segment1"

                        self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                        self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                        self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                        self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                        self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                        self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                        self.interface_handle = YLeaf(YType.str, "interface-handle")

                        self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                        self.interworking = YLeaf(YType.enumeration, "interworking")

                        self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                        self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                        self.msti = YLeaf(YType.str, "msti")

                        self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                        self.node_id = YLeaf(YType.str, "node-id")

                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                        self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                        self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                        self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                        self.interface = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._children_yang_names.add("interface")

                        self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                        self.l2vpn_protection.parent = self
                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                        self._children_yang_names.add("l2vpn-protection")

                        self.statistics = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bvi_mac_conflict",
                                        "bvi_no_port_up",
                                        "control_word_mismatched",
                                        "encapsulation_error",
                                        "encapsulation_mismatched",
                                        "evpn_internal_label",
                                        "interface_handle",
                                        "internal_ms_ti",
                                        "interworking",
                                        "is_ac_partially_programmed",
                                        "mac_limit_oper_down",
                                        "ms_ti_mismatch",
                                        "msti",
                                        "msti_mismatch_down",
                                        "mtu_mismatched",
                                        "node_id",
                                        "out_of_memory_state",
                                        "redundancy_group_id",
                                        "redundancy_group_state",
                                        "redundancy_object_id",
                                        "state",
                                        "tdm_media_mismatched",
                                        "xconnect_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "attachment-circuit"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "attachment-circuit"

                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                            self._children_yang_names.add("dispostion-stats")

                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self._children_name_map["impostion_stats"] = "impostion-stats"
                            self._children_yang_names.add("impostion-stats")

                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                            self.sequence_number.parent = self
                            self._children_name_map["sequence_number"] = "sequence-number"
                            self._children_yang_names.add("sequence-number")


                        class ImpostionStats(Entity):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                self.yang_name = "impostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self._children_name_map["broadcast"] = "broadcast"
                                self._children_yang_names.add("broadcast")

                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                self._children_yang_names.add("imposition-mtu-drop")

                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                self._children_yang_names.add("imposition-stat")

                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                self._children_yang_names.add("impostion-tail-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                self._children_yang_names.add("l2fsbi-drop")

                                self.multicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                                self._children_yang_names.add("multicast")

                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self
                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                self._children_yang_names.add("unknown-unicast")


                            class ImpositionStat(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                    self.yang_name = "imposition-stat"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpositionMtuDrop(Entity):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                    self.yang_name = "imposition-mtu-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpostionTailDrop(Entity):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                    self.yang_name = "impostion-tail-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class L2FsbiDrop(Entity):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                    self.yang_name = "l2fsbi-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fsbi-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Multicast(Entity):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Broadcast(Entity):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                    self.yang_name = "broadcast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnknownUnicast(Entity):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                    self.yang_name = "unknown-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unknown-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                    (self.multicast is not None and self.multicast.has_data()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                    (self.multicast is not None and self.multicast.has_operation()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "impostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast"):
                                    if (self.broadcast is None):
                                        self.broadcast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                    return self.broadcast

                                if (child_yang_name == "imposition-mtu-drop"):
                                    if (self.imposition_mtu_drop is None):
                                        self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    return self.imposition_mtu_drop

                                if (child_yang_name == "imposition-stat"):
                                    if (self.imposition_stat is None):
                                        self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                    return self.imposition_stat

                                if (child_yang_name == "impostion-tail-drop"):
                                    if (self.impostion_tail_drop is None):
                                        self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    return self.impostion_tail_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "l2fsbi-drop"):
                                    if (self.l2fsbi_drop is None):
                                        self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    return self.l2fsbi_drop

                                if (child_yang_name == "multicast"):
                                    if (self.multicast is None):
                                        self.multicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                    return self.multicast

                                if (child_yang_name == "unknown-unicast"):
                                    if (self.unknown_unicast is None):
                                        self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    return self.unknown_unicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DispostionStats(Entity):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                self.yang_name = "dispostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                self._children_yang_names.add("broadcast-drop")

                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self._children_name_map["dai_drop"] = "dai-drop"
                                self._children_yang_names.add("dai-drop")

                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                self._children_yang_names.add("disposition-mtu-drop")

                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                self._children_yang_names.add("disposition-oo-o-drops")

                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                self._children_yang_names.add("disposition-p2mp-stats")

                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                self._children_yang_names.add("disposition-stat")

                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                self._children_yang_names.add("disposition-tail-drop")

                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                self._children_yang_names.add("ipsg-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.mac_move = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self._children_name_map["mac_move"] = "mac-move"
                                self._children_yang_names.add("mac-move")

                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                self._children_yang_names.add("multicast-drop")

                                self.received_drops = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self._children_name_map["received_drops"] = "received-drops"
                                self._children_yang_names.add("received-drops")

                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self
                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                self._children_yang_names.add("unicast-drop")


                            class DispositionStat(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                    self.yang_name = "disposition-stat"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionMtuDrop(Entity):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                    self.yang_name = "disposition-mtu-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionTailDrop(Entity):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                    self.yang_name = "disposition-tail-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MulticastDrop(Entity):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                    self.yang_name = "multicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnicastDrop(Entity):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                    self.yang_name = "unicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class BroadcastDrop(Entity):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                    self.yang_name = "broadcast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ReceivedDrops(Entity):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                    self.yang_name = "received-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DaiDrop(Entity):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                    self.yang_name = "dai-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dai-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class IpsgDrop(Entity):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                    self.yang_name = "ipsg-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipsg-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionOoODrops(Entity):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                    self.yang_name = "disposition-oo-o-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionP2MpStats(Entity):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                    self.yang_name = "disposition-p2mp-stats"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MacMove(Entity):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                    self.yang_name = "mac-move"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-move" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dispostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast-drop"):
                                    if (self.broadcast_drop is None):
                                        self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    return self.broadcast_drop

                                if (child_yang_name == "dai-drop"):
                                    if (self.dai_drop is None):
                                        self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                    return self.dai_drop

                                if (child_yang_name == "disposition-mtu-drop"):
                                    if (self.disposition_mtu_drop is None):
                                        self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    return self.disposition_mtu_drop

                                if (child_yang_name == "disposition-oo-o-drops"):
                                    if (self.disposition_oo_o_drops is None):
                                        self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    return self.disposition_oo_o_drops

                                if (child_yang_name == "disposition-p2mp-stats"):
                                    if (self.disposition_p2mp_stats is None):
                                        self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    return self.disposition_p2mp_stats

                                if (child_yang_name == "disposition-stat"):
                                    if (self.disposition_stat is None):
                                        self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                    return self.disposition_stat

                                if (child_yang_name == "disposition-tail-drop"):
                                    if (self.disposition_tail_drop is None):
                                        self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    return self.disposition_tail_drop

                                if (child_yang_name == "ipsg-drop"):
                                    if (self.ipsg_drop is None):
                                        self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    return self.ipsg_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "mac-move"):
                                    if (self.mac_move is None):
                                        self.mac_move = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                    return self.mac_move

                                if (child_yang_name == "multicast-drop"):
                                    if (self.multicast_drop is None):
                                        self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                    return self.multicast_drop

                                if (child_yang_name == "received-drops"):
                                    if (self.received_drops is None):
                                        self.received_drops = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                    return self.received_drops

                                if (child_yang_name == "unicast-drop"):
                                    if (self.unicast_drop is None):
                                        self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                    return self.unicast_drop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SequenceNumber(Entity):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                self.yang_name = "sequence-number"
                                self.yang_parent_name = "statistics"

                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bypassed_inbound_sequence_packet",
                                                "bypassed_out_sequence_packet",
                                                "sequence_number_expected",
                                                "sequence_number_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bypassed_inbound_sequence_packet.is_set or
                                    self.bypassed_out_sequence_packet.is_set or
                                    self.sequence_number_expected.is_set or
                                    self.sequence_number_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sequence-number" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bypassed-inbound-sequence-packet"):
                                    self.bypassed_inbound_sequence_packet = value
                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "bypassed-out-sequence-packet"):
                                    self.bypassed_out_sequence_packet = value
                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-expected"):
                                    self.sequence_number_expected = value
                                    self.sequence_number_expected.value_namespace = name_space
                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-sent"):
                                    self.sequence_number_sent = value
                                    self.sequence_number_sent.value_namespace = name_space
                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                (self.sequence_number is not None and self.sequence_number.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dispostion-stats"):
                                if (self.dispostion_stats is None):
                                    self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                return self.dispostion_stats

                            if (child_yang_name == "impostion-stats"):
                                if (self.impostion_stats is None):
                                    self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                return self.impostion_stats

                            if (child_yang_name == "sequence-number"):
                                if (self.sequence_number is None):
                                    self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                return self.sequence_number

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class L2VpnProtection(Entity):
                        """
                        Protection object used for this segment
                        
                        .. attribute:: active
                        
                        	Active
                        	**type**\:  bool
                        
                        .. attribute:: protected_name
                        
                        	Name of the protected segment
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_configured
                        
                        	Protection configured
                        	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                        
                        .. attribute:: protection_name
                        
                        	Name of the segment acting as backup
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_type
                        
                        	Type of the protection
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__init__()

                            self.yang_name = "l2vpn-protection"
                            self.yang_parent_name = "attachment-circuit"

                            self.active = YLeaf(YType.boolean, "active")

                            self.protected_name = YLeaf(YType.str, "protected-name")

                            self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                            self.protection_name = YLeaf(YType.str, "protection-name")

                            self.protection_type = YLeaf(YType.enumeration, "protection-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active",
                                            "protected_name",
                                            "protection_configured",
                                            "protection_name",
                                            "protection_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active.is_set or
                                self.protected_name.is_set or
                                self.protection_configured.is_set or
                                self.protection_name.is_set or
                                self.protection_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active.yfilter != YFilter.not_set or
                                self.protected_name.yfilter != YFilter.not_set or
                                self.protection_configured.yfilter != YFilter.not_set or
                                self.protection_name.yfilter != YFilter.not_set or
                                self.protection_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2vpn-protection" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active.get_name_leafdata())
                            if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protected_name.get_name_leafdata())
                            if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_configured.get_name_leafdata())
                            if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_name.get_name_leafdata())
                            if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active"):
                                self.active = value
                                self.active.value_namespace = name_space
                                self.active.value_namespace_prefix = name_space_prefix
                            if(value_path == "protected-name"):
                                self.protected_name = value
                                self.protected_name.value_namespace = name_space
                                self.protected_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-configured"):
                                self.protection_configured = value
                                self.protection_configured.value_namespace = name_space
                                self.protection_configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-name"):
                                self.protection_name = value
                                self.protection_name.value_namespace = name_space
                                self.protection_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-type"):
                                self.protection_type = value
                                self.protection_type.value_namespace = name_space
                                self.protection_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bvi_mac_conflict.is_set or
                            self.bvi_no_port_up.is_set or
                            self.control_word_mismatched.is_set or
                            self.encapsulation_error.is_set or
                            self.encapsulation_mismatched.is_set or
                            self.evpn_internal_label.is_set or
                            self.interface_handle.is_set or
                            self.internal_ms_ti.is_set or
                            self.interworking.is_set or
                            self.is_ac_partially_programmed.is_set or
                            self.mac_limit_oper_down.is_set or
                            self.ms_ti_mismatch.is_set or
                            self.msti.is_set or
                            self.msti_mismatch_down.is_set or
                            self.mtu_mismatched.is_set or
                            self.node_id.is_set or
                            self.out_of_memory_state.is_set or
                            self.redundancy_group_id.is_set or
                            self.redundancy_group_state.is_set or
                            self.redundancy_object_id.is_set or
                            self.state.is_set or
                            self.tdm_media_mismatched.is_set or
                            self.xconnect_id.is_set or
                            (self.interface is not None and self.interface.has_data()) or
                            (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bvi_mac_conflict.yfilter != YFilter.not_set or
                            self.bvi_no_port_up.yfilter != YFilter.not_set or
                            self.control_word_mismatched.yfilter != YFilter.not_set or
                            self.encapsulation_error.yfilter != YFilter.not_set or
                            self.encapsulation_mismatched.yfilter != YFilter.not_set or
                            self.evpn_internal_label.yfilter != YFilter.not_set or
                            self.interface_handle.yfilter != YFilter.not_set or
                            self.internal_ms_ti.yfilter != YFilter.not_set or
                            self.interworking.yfilter != YFilter.not_set or
                            self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                            self.ms_ti_mismatch.yfilter != YFilter.not_set or
                            self.msti.yfilter != YFilter.not_set or
                            self.msti_mismatch_down.yfilter != YFilter.not_set or
                            self.mtu_mismatched.yfilter != YFilter.not_set or
                            self.node_id.yfilter != YFilter.not_set or
                            self.out_of_memory_state.yfilter != YFilter.not_set or
                            self.redundancy_group_id.yfilter != YFilter.not_set or
                            self.redundancy_group_state.yfilter != YFilter.not_set or
                            self.redundancy_object_id.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.tdm_media_mismatched.yfilter != YFilter.not_set or
                            self.xconnect_id.yfilter != YFilter.not_set or
                            (self.interface is not None and self.interface.has_operation()) or
                            (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "attachment-circuit" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                        if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                        if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                        if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                        if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                        if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                        if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_handle.get_name_leafdata())
                        if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interworking.get_name_leafdata())
                        if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                        if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti.get_name_leafdata())
                        if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                        if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_id.get_name_leafdata())
                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                        if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                        if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                        if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            if (self.interface is None):
                                self.interface = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                            return self.interface

                        if (child_yang_name == "l2vpn-protection"):
                            if (self.l2vpn_protection is None):
                                self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            return self.l2vpn_protection

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bvi-mac-conflict"):
                            self.bvi_mac_conflict = value
                            self.bvi_mac_conflict.value_namespace = name_space
                            self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                        if(value_path == "bvi-no-port-up"):
                            self.bvi_no_port_up = value
                            self.bvi_no_port_up.value_namespace = name_space
                            self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "control-word-mismatched"):
                            self.control_word_mismatched = value
                            self.control_word_mismatched.value_namespace = name_space
                            self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "encapsulation-error"):
                            self.encapsulation_error = value
                            self.encapsulation_error.value_namespace = name_space
                            self.encapsulation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "encapsulation-mismatched"):
                            self.encapsulation_mismatched = value
                            self.encapsulation_mismatched.value_namespace = name_space
                            self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-internal-label"):
                            self.evpn_internal_label = value
                            self.evpn_internal_label.value_namespace = name_space
                            self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-handle"):
                            self.interface_handle = value
                            self.interface_handle.value_namespace = name_space
                            self.interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "internal-ms-ti"):
                            self.internal_ms_ti = value
                            self.internal_ms_ti.value_namespace = name_space
                            self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                        if(value_path == "interworking"):
                            self.interworking = value
                            self.interworking.value_namespace = name_space
                            self.interworking.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ac-partially-programmed"):
                            self.is_ac_partially_programmed = value
                            self.is_ac_partially_programmed.value_namespace = name_space
                            self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-oper-down"):
                            self.mac_limit_oper_down = value
                            self.mac_limit_oper_down.value_namespace = name_space
                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "ms-ti-mismatch"):
                            self.ms_ti_mismatch = value
                            self.ms_ti_mismatch.value_namespace = name_space
                            self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti"):
                            self.msti = value
                            self.msti.value_namespace = name_space
                            self.msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-mismatch-down"):
                            self.msti_mismatch_down = value
                            self.msti_mismatch_down.value_namespace = name_space
                            self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-mismatched"):
                            self.mtu_mismatched = value
                            self.mtu_mismatched.value_namespace = name_space
                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-id"):
                            self.node_id = value
                            self.node_id.value_namespace = name_space
                            self.node_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-of-memory-state"):
                            self.out_of_memory_state = value
                            self.out_of_memory_state.value_namespace = name_space
                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-group-id"):
                            self.redundancy_group_id = value
                            self.redundancy_group_id.value_namespace = name_space
                            self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-group-state"):
                            self.redundancy_group_state = value
                            self.redundancy_group_state.value_namespace = name_space
                            self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-object-id"):
                            self.redundancy_object_id = value
                            self.redundancy_object_id.value_namespace = name_space
                            self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "tdm-media-mismatched"):
                            self.tdm_media_mismatched = value
                            self.tdm_media_mismatched.value_namespace = name_space
                            self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-id"):
                            self.xconnect_id = value
                            self.xconnect_id.value_namespace = name_space
                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                class PseudoWire(Entity):
                    """
                    Pseudowire
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_remote_down
                    
                    	Auto\-Discovered PW remote state down
                    	**type**\:  bool
                    
                    .. attribute:: admited_bw
                    
                    	Admited Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: auto_discovery
                    
                    	Is autodiscovery
                    	**type**\:  bool
                    
                    .. attribute:: backup_active
                    
                    	TRUE if backup is active
                    	**type**\:  bool
                    
                    .. attribute:: backup_force_active
                    
                    	TRUE if backup is active due to switchover
                    	**type**\:  bool
                    
                    .. attribute:: backup_pw
                    
                    	TRUE if PW is a backup PW
                    	**type**\:  bool
                    
                    .. attribute:: bitrate_mismatched
                    
                    	Bitrate mismatched
                    	**type**\:  bool
                    
                    .. attribute:: bridge_pw_type_mismatch
                    
                    	Oper down because Bridge has mismatched PW Types
                    	**type**\:  bool
                    
                    .. attribute:: cas_mismatched
                    
                    	CAS mismatched
                    	**type**\:  bool
                    
                    .. attribute:: diff_ts_mismatched
                    
                    	Differential timestamp mismatched
                    	**type**\:  bool
                    
                    .. attribute:: disable_delay
                    
                    	Backup disable delay
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                    
                    .. attribute:: evpn_src_acid
                    
                    	EVPN VPWS Source AC ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fe_ctype
                    
                    	Pseudowire FEC type
                    	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                    
                    .. attribute:: forward_class
                    
                    	Forward Class attribute
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: freq_mismatched
                    
                    	Frequency mismatched
                    	**type**\:  bool
                    
                    .. attribute:: illegal_control_word
                    
                    	Illegal control word
                    	**type**\:  bool
                    
                    .. attribute:: imposed_vlan_id
                    
                    	Imposed vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                    
                    .. attribute:: ipv6_local_source_address
                    
                    	Local IPv6 Source Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_evpnvpws_type
                    
                    	is EVPN VPWS
                    	**type**\:  bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: is_multi_segment_pseudowire
                    
                    	Is Multi\-Segment Pseudowire
                    	**type**\:  bool
                    
                    .. attribute:: is_partially_programmed
                    
                    	Is Pseudowire partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_pwr_type
                    
                    	is Pseudowire\-routed
                    	**type**\:  bool
                    
                    .. attribute:: is_vfi
                    
                    	Is VFI interface
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the pseudowire status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_down
                    
                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: ldp_label_advertise_failed
                    
                    	LDP label advertisment failed
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                    
                    .. attribute:: local_control_word
                    
                    	Local control word
                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                    
                    .. attribute:: local_label_failed
                    
                    	Failed to set BGP advertised local label
                    	**type**\:  bool
                    
                    .. attribute:: local_pseudo_wire_type
                    
                    	Local pseudowire type
                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                    
                    .. attribute:: local_signalling
                    
                    	Local signalling
                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                    
                    .. attribute:: local_source_address
                    
                    	Local Source Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_qinq
                    
                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                    	**type**\:  bool
                    
                    .. attribute:: num_ma_cwithdraw_msg_received
                    
                    	Num MW messages received over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ma_cwithdraw_message_sent
                    
                    	Num MW messages sent over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_pw
                    
                    	P2MP Pseudowire Information
                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw>`
                    
                    .. attribute:: payload_bytes_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: payload_type_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: peer_id
                    
                    	Peer
                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	Prefpath fallback enable/disable
                    	**type**\:  bool
                    
                    .. attribute:: primary_peer_id
                    
                    	Primary Peer IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: primary_pseudo_wire_id
                    
                    	Primary Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: primary_pw
                    
                    	TRUE if PW is a primary PW
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                    
                    .. attribute:: pseudo_wire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: pseudo_wire_state
                    
                    	Pseudowire state
                    	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                    
                    .. attribute:: pseudo_wire_type_mismatched
                    
                    	Pseudowire type mismatched
                    	**type**\:  bool
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type
                    
                    	Negotiated pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label Type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: pw_redundancy_initial_delay
                    
                    	Initial delay for redundant PW in seconds
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    .. attribute:: pw_redundancy_one_way
                    
                    	Force one\-way PW redundancy behaviour in Redundancy Group
                    	**type**\:  bool
                    
                    .. attribute:: pw_status_use
                    
                    	PW status in use
                    	**type**\:  bool
                    
                    .. attribute:: pwlsd_rewrite_failed
                    
                    	LSD rewrite failed
                    	**type**\:  bool
                    
                    .. attribute:: remote_control_word
                    
                    	Remote control word
                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                    
                    .. attribute:: remote_interface
                    
                    	Remote interface
                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                    
                    .. attribute:: remote_label_failed
                    
                    	Failed to set BGP advertised remote label
                    	**type**\:  bool
                    
                    .. attribute:: remote_pseudo_wire_type
                    
                    	Remote pseudowire type
                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                    
                    .. attribute:: remote_signalling
                    
                    	Remote signalling
                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                    
                    .. attribute:: required_bw
                    
                    	Required Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rtp_mismatched
                    
                    	RTP mismatched
                    	**type**\:  bool
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: sig_pkts_mismatched
                    
                    	Signalling packets mismatched
                    	**type**\:  bool
                    
                    .. attribute:: ssrc_mismatched
                    
                    	SSRC mismatched
                    	**type**\:  bool
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                    
                    .. attribute:: table_policy_name
                    
                    	Table\-policy Name
                    	**type**\:  str
                    
                    .. attribute:: tag_rewrite
                    
                    	StaticTagRewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: time_created
                    
                    	Time when the pseudowire was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_down
                    
                    	Time elapsed since last status down in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: transport_lsp_down
                    
                    	Oper down due to Transport LSP down
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire, self).__init__()

                        self.yang_name = "pseudo-wire"
                        self.yang_parent_name = "segment1"

                        self.ad_method = YLeaf(YType.uint32, "ad-method")

                        self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                        self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                        self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                        self.backup_active = YLeaf(YType.boolean, "backup-active")

                        self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                        self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                        self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                        self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                        self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                        self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                        self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                        self.disable_never = YLeaf(YType.boolean, "disable-never")

                        self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                        self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                        self.forward_class = YLeaf(YType.uint8, "forward-class")

                        self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                        self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                        self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                        self.interworking = YLeaf(YType.enumeration, "interworking")

                        self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                        self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                        self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                        self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                        self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                        self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                        self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                        self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                        self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                        self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                        self.load_balance = YLeaf(YType.enumeration, "load-balance")

                        self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                        self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                        self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                        self.local_source_address = YLeaf(YType.str, "local-source-address")

                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                        self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                        self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                        self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                        self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                        self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                        self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                        self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                        self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                        self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                        self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                        self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                        self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                        self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                        self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                        self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                        self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                        self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                        self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                        self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                        self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                        self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                        self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                        self.required_bw = YLeaf(YType.uint32, "required-bw")

                        self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                        self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                        self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                        self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                        self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                        self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                        self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                        self.time_created = YLeaf(YType.str, "time-created")

                        self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                        self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                        self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                        self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                        self.encapsulation_info = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                        self._children_yang_names.add("encapsulation-info")

                        self.local_interface = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                        self.local_interface.parent = self
                        self._children_name_map["local_interface"] = "local-interface"
                        self._children_yang_names.add("local-interface")

                        self.local_signalling = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                        self.local_signalling.parent = self
                        self._children_name_map["local_signalling"] = "local-signalling"
                        self._children_yang_names.add("local-signalling")

                        self.p2mp_pw = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                        self.p2mp_pw.parent = self
                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                        self._children_yang_names.add("p2mp-pw")

                        self.peer_id = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                        self.peer_id.parent = self
                        self._children_name_map["peer_id"] = "peer-id"
                        self._children_yang_names.add("peer-id")

                        self.preferred_path = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                        self.preferred_path.parent = self
                        self._children_name_map["preferred_path"] = "preferred-path"
                        self._children_yang_names.add("preferred-path")

                        self.remote_interface = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                        self.remote_interface.parent = self
                        self._children_name_map["remote_interface"] = "remote-interface"
                        self._children_yang_names.add("remote-interface")

                        self.remote_signalling = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                        self.remote_signalling.parent = self
                        self._children_name_map["remote_signalling"] = "remote-signalling"
                        self._children_yang_names.add("remote-signalling")

                        self.statistics = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ad_method",
                                        "ad_remote_down",
                                        "admited_bw",
                                        "auto_discovery",
                                        "backup_active",
                                        "backup_force_active",
                                        "backup_pw",
                                        "bitrate_mismatched",
                                        "bridge_pw_type_mismatch",
                                        "cas_mismatched",
                                        "diff_ts_mismatched",
                                        "disable_delay",
                                        "disable_never",
                                        "evpn_src_acid",
                                        "fe_ctype",
                                        "forward_class",
                                        "freq_mismatched",
                                        "illegal_control_word",
                                        "imposed_vlan_id",
                                        "interworking",
                                        "ipv6_local_source_address",
                                        "is_evpnvpws_type",
                                        "is_flow_label_static",
                                        "is_multi_segment_pseudowire",
                                        "is_partially_programmed",
                                        "is_pwr_type",
                                        "is_vfi",
                                        "last_time_status_changed",
                                        "last_time_status_down",
                                        "ldp_label_advertise_failed",
                                        "load_balance",
                                        "local_control_word",
                                        "local_label_failed",
                                        "local_pseudo_wire_type",
                                        "local_source_address",
                                        "mac_limit_oper_down",
                                        "mtu_mismatched",
                                        "not_supported_qinq",
                                        "num_ma_cwithdraw_msg_received",
                                        "number_ma_cwithdraw_message_sent",
                                        "out_of_memory_state",
                                        "payload_bytes_mismatched",
                                        "payload_type_mismatched",
                                        "preferred_path_disable_fallback",
                                        "primary_peer_id",
                                        "primary_pseudo_wire_id",
                                        "primary_pw",
                                        "protocol",
                                        "pseudo_wire_id",
                                        "pseudo_wire_state",
                                        "pseudo_wire_type_mismatched",
                                        "pw_class_name",
                                        "pw_flow_label_code17_disabled",
                                        "pw_flow_label_type",
                                        "pw_flow_label_type_cfg",
                                        "pw_redundancy_initial_delay",
                                        "pw_redundancy_one_way",
                                        "pw_status_use",
                                        "pwlsd_rewrite_failed",
                                        "remote_control_word",
                                        "remote_label_failed",
                                        "remote_pseudo_wire_type",
                                        "required_bw",
                                        "resync_enabled",
                                        "resync_threshold",
                                        "rtp_mismatched",
                                        "sequencing_type",
                                        "shutdown",
                                        "sig_pkts_mismatched",
                                        "ssrc_mismatched",
                                        "state",
                                        "table_policy_name",
                                        "tag_rewrite",
                                        "time_created",
                                        "time_elapsed_creation",
                                        "time_elapsed_status_changed",
                                        "time_elapsed_status_down",
                                        "transport_lsp_down",
                                        "xconnect_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire, self).__setattr__(name, value)


                    class PeerId(Entity):
                        """
                        Peer
                        
                        .. attribute:: internal_label
                        
                        	Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_peer_id
                        
                        	Peer IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_peer_id
                        
                        	Peer IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: type
                        
                        	type
                        	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__init__()

                            self.yang_name = "peer-id"
                            self.yang_parent_name = "pseudo-wire"

                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                            self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                            self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                            self.type = YLeaf(YType.enumeration, "type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("internal_label",
                                            "ipv4_peer_id",
                                            "ipv6_peer_id",
                                            "type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.internal_label.is_set or
                                self.ipv4_peer_id.is_set or
                                self.ipv6_peer_id.is_set or
                                self.type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.internal_label.yfilter != YFilter.not_set or
                                self.ipv4_peer_id.yfilter != YFilter.not_set or
                                self.ipv6_peer_id.yfilter != YFilter.not_set or
                                self.type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "peer-id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                            if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                            if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "internal-label"):
                                self.internal_label = value
                                self.internal_label.value_namespace = name_space
                                self.internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-peer-id"):
                                self.ipv4_peer_id = value
                                self.ipv4_peer_id.value_namespace = name_space
                                self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-peer-id"):
                                self.ipv6_peer_id = value
                                self.ipv6_peer_id.value_namespace = name_space
                                self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "type"):
                                self.type = value
                                self.type.value_namespace = name_space
                                self.type.value_namespace_prefix = name_space_prefix


                    class EncapsulationInfo(Entity):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: atom
                        
                        	atom
                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__init__()

                            self.yang_name = "encapsulation-info"
                            self.yang_parent_name = "pseudo-wire"

                            self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                            self.atom = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                            self.atom.parent = self
                            self._children_name_map["atom"] = "atom"
                            self._children_yang_names.add("atom")

                            self.l2tpv3 = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self
                            self._children_name_map["l2tpv3"] = "l2tpv3"
                            self._children_yang_names.add("l2tpv3")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("encapsulation") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                        class Atom(Entity):
                            """
                            atom
                            
                            .. attribute:: is_pseudowire_headend
                            
                            	Is this connected to a PW\-HE AC
                            	**type**\:  bool
                            
                            .. attribute:: is_sai_itype2
                            
                            	Is SAII FEC129 Type 2
                            	**type**\:  bool
                            
                            .. attribute:: is_tai_itype2
                            
                            	Is TAII type 2
                            	**type**\:  bool
                            
                            .. attribute:: ldp_label_advertisment_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: local_agi
                            
                            	Local Attachment Group Identifier
                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                            
                            .. attribute:: local_c_ctype
                            
                            	Local VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_ceid
                            
                            	Local CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cv_type
                            
                            	Local VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_group_id
                            
                            	Local group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ldp_id
                            
                            	Local LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_saii_gbl_id
                            
                            	Local SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_saiiac_id
                            
                            	Local SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taii_gbl_id
                            
                            	Local TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taiiac_id
                            
                            	Local TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_veid
                            
                            	Local VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: multi_segment_pseudowire_stats
                            
                            	Multisegment pseudowire statistics
                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                            
                            .. attribute:: rem_saii
                            
                            	Remote Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_saii_gbl_id
                            
                            	Remote SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_saiiac_id
                            
                            	Remote SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taii
                            
                            	Remote Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_taii_gbl_id
                            
                            	Remote TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taiiac_id
                            
                            	Remote TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_agi
                            
                            	Remote Attachment Group Identifier
                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                            
                            .. attribute:: remote_c_ctype
                            
                            	Remote VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_ceid
                            
                            	Remote CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cv_type
                            
                            	Remote VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_group_id
                            
                            	Remote group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_label
                            
                            	Remote label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ldp_id
                            
                            	Remote LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_source_address
                            
                            	Remote BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_veid
                            
                            	Remote VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_address
                            
                            	Local BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                self.yang_name = "atom"
                                self.yang_parent_name = "encapsulation-info"

                                self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                self.local_veid = YLeaf(YType.uint32, "local-veid")

                                self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                self.rem_saii = YLeaf(YType.str, "rem-saii")

                                self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                self.rem_taii = YLeaf(YType.str, "rem-taii")

                                self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                self.saii = YLeaf(YType.str, "saii")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.taii = YLeaf(YType.str, "taii")

                                self.local_agi = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                self.local_agi.parent = self
                                self._children_name_map["local_agi"] = "local-agi"
                                self._children_yang_names.add("local-agi")

                                self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                self.multi_segment_pseudowire_stats.parent = self
                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                self._children_yang_names.add("multi-segment-pseudowire-stats")

                                self.remote_agi = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                self.remote_agi.parent = self
                                self._children_name_map["remote_agi"] = "remote-agi"
                                self._children_yang_names.add("remote-agi")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_pseudowire_headend",
                                                "is_sai_itype2",
                                                "is_tai_itype2",
                                                "ldp_label_advertisment_failed",
                                                "local_c_ctype",
                                                "local_ceid",
                                                "local_cv_type",
                                                "local_group_id",
                                                "local_label",
                                                "local_ldp_id",
                                                "local_saii_gbl_id",
                                                "local_saiiac_id",
                                                "local_taii_gbl_id",
                                                "local_taiiac_id",
                                                "local_veid",
                                                "lsd_rewrite_failed",
                                                "rem_saii",
                                                "rem_saii_gbl_id",
                                                "rem_saiiac_id",
                                                "rem_taii",
                                                "rem_taii_gbl_id",
                                                "rem_taiiac_id",
                                                "remote_c_ctype",
                                                "remote_ceid",
                                                "remote_cv_type",
                                                "remote_group_id",
                                                "remote_label",
                                                "remote_ldp_id",
                                                "remote_source_address",
                                                "remote_veid",
                                                "saii",
                                                "source_address",
                                                "taii") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                            class LocalAgi(Entity):
                                """
                                Local Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                    self.yang_name = "local-agi"
                                    self.yang_parent_name = "atom"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "local-agi"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "local-agi"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "local-agi"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-agi" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class RemoteAgi(Entity):
                                """
                                Remote Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                    self.yang_name = "remote-agi"
                                    self.yang_parent_name = "atom"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "remote-agi"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "remote-agi"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "remote-agi"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-agi" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class MultiSegmentPseudowireStats(Entity):
                                """
                                Multisegment pseudowire statistics
                                
                                .. attribute:: received_bytes
                                
                                	Bytes received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: received_packets
                                
                                	Packets received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                    self.yang_name = "multi-segment-pseudowire-stats"
                                    self.yang_parent_name = "atom"

                                    self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                    self.received_packets = YLeaf(YType.uint64, "received-packets")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("received_bytes",
                                                    "received_packets") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.received_bytes.is_set or
                                        self.received_packets.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.received_bytes.yfilter != YFilter.not_set or
                                        self.received_packets.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                    if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_packets.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-bytes" or name == "received-packets"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "received-bytes"):
                                        self.received_bytes = value
                                        self.received_bytes.value_namespace = name_space
                                        self.received_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-packets"):
                                        self.received_packets = value
                                        self.received_packets.value_namespace = name_space
                                        self.received_packets.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.is_pseudowire_headend.is_set or
                                    self.is_sai_itype2.is_set or
                                    self.is_tai_itype2.is_set or
                                    self.ldp_label_advertisment_failed.is_set or
                                    self.local_c_ctype.is_set or
                                    self.local_ceid.is_set or
                                    self.local_cv_type.is_set or
                                    self.local_group_id.is_set or
                                    self.local_label.is_set or
                                    self.local_ldp_id.is_set or
                                    self.local_saii_gbl_id.is_set or
                                    self.local_saiiac_id.is_set or
                                    self.local_taii_gbl_id.is_set or
                                    self.local_taiiac_id.is_set or
                                    self.local_veid.is_set or
                                    self.lsd_rewrite_failed.is_set or
                                    self.rem_saii.is_set or
                                    self.rem_saii_gbl_id.is_set or
                                    self.rem_saiiac_id.is_set or
                                    self.rem_taii.is_set or
                                    self.rem_taii_gbl_id.is_set or
                                    self.rem_taiiac_id.is_set or
                                    self.remote_c_ctype.is_set or
                                    self.remote_ceid.is_set or
                                    self.remote_cv_type.is_set or
                                    self.remote_group_id.is_set or
                                    self.remote_label.is_set or
                                    self.remote_ldp_id.is_set or
                                    self.remote_source_address.is_set or
                                    self.remote_veid.is_set or
                                    self.saii.is_set or
                                    self.source_address.is_set or
                                    self.taii.is_set or
                                    (self.local_agi is not None and self.local_agi.has_data()) or
                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                    (self.remote_agi is not None and self.remote_agi.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                    self.is_sai_itype2.yfilter != YFilter.not_set or
                                    self.is_tai_itype2.yfilter != YFilter.not_set or
                                    self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                    self.local_c_ctype.yfilter != YFilter.not_set or
                                    self.local_ceid.yfilter != YFilter.not_set or
                                    self.local_cv_type.yfilter != YFilter.not_set or
                                    self.local_group_id.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_ldp_id.yfilter != YFilter.not_set or
                                    self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                    self.local_saiiac_id.yfilter != YFilter.not_set or
                                    self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                    self.local_taiiac_id.yfilter != YFilter.not_set or
                                    self.local_veid.yfilter != YFilter.not_set or
                                    self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.rem_saii.yfilter != YFilter.not_set or
                                    self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                    self.rem_saiiac_id.yfilter != YFilter.not_set or
                                    self.rem_taii.yfilter != YFilter.not_set or
                                    self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                    self.rem_taiiac_id.yfilter != YFilter.not_set or
                                    self.remote_c_ctype.yfilter != YFilter.not_set or
                                    self.remote_ceid.yfilter != YFilter.not_set or
                                    self.remote_cv_type.yfilter != YFilter.not_set or
                                    self.remote_group_id.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_ldp_id.yfilter != YFilter.not_set or
                                    self.remote_source_address.yfilter != YFilter.not_set or
                                    self.remote_veid.yfilter != YFilter.not_set or
                                    self.saii.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.taii.yfilter != YFilter.not_set or
                                    (self.local_agi is not None and self.local_agi.has_operation()) or
                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                    (self.remote_agi is not None and self.remote_agi.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "atom" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_veid.get_name_leafdata())
                                if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.saii.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.taii.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-agi"):
                                    if (self.local_agi is None):
                                        self.local_agi = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                    return self.local_agi

                                if (child_yang_name == "multi-segment-pseudowire-stats"):
                                    if (self.multi_segment_pseudowire_stats is None):
                                        self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    return self.multi_segment_pseudowire_stats

                                if (child_yang_name == "remote-agi"):
                                    if (self.remote_agi is None):
                                        self.remote_agi = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                    return self.remote_agi

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-pseudowire-headend"):
                                    self.is_pseudowire_headend = value
                                    self.is_pseudowire_headend.value_namespace = name_space
                                    self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-sai-itype2"):
                                    self.is_sai_itype2 = value
                                    self.is_sai_itype2.value_namespace = name_space
                                    self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-tai-itype2"):
                                    self.is_tai_itype2 = value
                                    self.is_tai_itype2.value_namespace = name_space
                                    self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertisment-failed"):
                                    self.ldp_label_advertisment_failed = value
                                    self.ldp_label_advertisment_failed.value_namespace = name_space
                                    self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-c-ctype"):
                                    self.local_c_ctype = value
                                    self.local_c_ctype.value_namespace = name_space
                                    self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ceid"):
                                    self.local_ceid = value
                                    self.local_ceid.value_namespace = name_space
                                    self.local_ceid.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cv-type"):
                                    self.local_cv_type = value
                                    self.local_cv_type.value_namespace = name_space
                                    self.local_cv_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-group-id"):
                                    self.local_group_id = value
                                    self.local_group_id.value_namespace = name_space
                                    self.local_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ldp-id"):
                                    self.local_ldp_id = value
                                    self.local_ldp_id.value_namespace = name_space
                                    self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-saii-gbl-id"):
                                    self.local_saii_gbl_id = value
                                    self.local_saii_gbl_id.value_namespace = name_space
                                    self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-saiiac-id"):
                                    self.local_saiiac_id = value
                                    self.local_saiiac_id.value_namespace = name_space
                                    self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-taii-gbl-id"):
                                    self.local_taii_gbl_id = value
                                    self.local_taii_gbl_id.value_namespace = name_space
                                    self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-taiiac-id"):
                                    self.local_taiiac_id = value
                                    self.local_taiiac_id.value_namespace = name_space
                                    self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-veid"):
                                    self.local_veid = value
                                    self.local_veid.value_namespace = name_space
                                    self.local_veid.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsd-rewrite-failed"):
                                    self.lsd_rewrite_failed = value
                                    self.lsd_rewrite_failed.value_namespace = name_space
                                    self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saii"):
                                    self.rem_saii = value
                                    self.rem_saii.value_namespace = name_space
                                    self.rem_saii.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saii-gbl-id"):
                                    self.rem_saii_gbl_id = value
                                    self.rem_saii_gbl_id.value_namespace = name_space
                                    self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saiiac-id"):
                                    self.rem_saiiac_id = value
                                    self.rem_saiiac_id.value_namespace = name_space
                                    self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taii"):
                                    self.rem_taii = value
                                    self.rem_taii.value_namespace = name_space
                                    self.rem_taii.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taii-gbl-id"):
                                    self.rem_taii_gbl_id = value
                                    self.rem_taii_gbl_id.value_namespace = name_space
                                    self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taiiac-id"):
                                    self.rem_taiiac_id = value
                                    self.rem_taiiac_id.value_namespace = name_space
                                    self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-c-ctype"):
                                    self.remote_c_ctype = value
                                    self.remote_c_ctype.value_namespace = name_space
                                    self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ceid"):
                                    self.remote_ceid = value
                                    self.remote_ceid.value_namespace = name_space
                                    self.remote_ceid.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cv-type"):
                                    self.remote_cv_type = value
                                    self.remote_cv_type.value_namespace = name_space
                                    self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-group-id"):
                                    self.remote_group_id = value
                                    self.remote_group_id.value_namespace = name_space
                                    self.remote_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ldp-id"):
                                    self.remote_ldp_id = value
                                    self.remote_ldp_id.value_namespace = name_space
                                    self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-source-address"):
                                    self.remote_source_address = value
                                    self.remote_source_address.value_namespace = name_space
                                    self.remote_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-veid"):
                                    self.remote_veid = value
                                    self.remote_veid.value_namespace = name_space
                                    self.remote_veid.value_namespace_prefix = name_space_prefix
                                if(value_path == "saii"):
                                    self.saii = value
                                    self.saii.value_namespace = name_space
                                    self.saii.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "taii"):
                                    self.taii = value
                                    self.taii.value_namespace = name_space
                                    self.taii.value_namespace_prefix = name_space_prefix


                        class L2Tpv3(Entity):
                            """
                            l2tpv3
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_source_address
                            
                            	IPv6 source address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: local_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_size
                            
                            	Local cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_secondary_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_size
                            
                            	Local secondary cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_session_id
                            
                            	Local session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: remote_circuit_status_up
                            
                            	RemoteCircuitStatusUp
                            	**type**\:  bool
                            
                            .. attribute:: remote_cookie_high_value
                            
                            	Upper 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_low_value
                            
                            	Lower 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_size
                            
                            	Remote cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_session_id
                            
                            	Remote session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_state
                            
                            	L2TP tunnel state
                            	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                self.yang_name = "l2tpv3"
                                self.yang_parent_name = "encapsulation-info"

                                self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                self.tos = YLeaf(YType.uint8, "tos")

                                self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                self.ttl = YLeaf(YType.uint8, "ttl")

                                self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dont_fragment_bit",
                                                "ipv4_source_address",
                                                "ipv6_source_address",
                                                "l2tp_class_name",
                                                "local_cookie_high_value",
                                                "local_cookie_low_value",
                                                "local_cookie_size",
                                                "local_secondary_cookie_high_value",
                                                "local_secondary_cookie_low_value",
                                                "local_secondary_cookie_size",
                                                "local_session_id",
                                                "path_mtu_enabled",
                                                "path_mtu_max_value",
                                                "remote_circuit_status_up",
                                                "remote_cookie_high_value",
                                                "remote_cookie_low_value",
                                                "remote_cookie_size",
                                                "remote_session_id",
                                                "tos",
                                                "tos_mode",
                                                "ttl",
                                                "tunnel_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dont_fragment_bit.is_set or
                                    self.ipv4_source_address.is_set or
                                    self.ipv6_source_address.is_set or
                                    self.l2tp_class_name.is_set or
                                    self.local_cookie_high_value.is_set or
                                    self.local_cookie_low_value.is_set or
                                    self.local_cookie_size.is_set or
                                    self.local_secondary_cookie_high_value.is_set or
                                    self.local_secondary_cookie_low_value.is_set or
                                    self.local_secondary_cookie_size.is_set or
                                    self.local_session_id.is_set or
                                    self.path_mtu_enabled.is_set or
                                    self.path_mtu_max_value.is_set or
                                    self.remote_circuit_status_up.is_set or
                                    self.remote_cookie_high_value.is_set or
                                    self.remote_cookie_low_value.is_set or
                                    self.remote_cookie_size.is_set or
                                    self.remote_session_id.is_set or
                                    self.tos.is_set or
                                    self.tos_mode.is_set or
                                    self.ttl.is_set or
                                    self.tunnel_state.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dont_fragment_bit.yfilter != YFilter.not_set or
                                    self.ipv4_source_address.yfilter != YFilter.not_set or
                                    self.ipv6_source_address.yfilter != YFilter.not_set or
                                    self.l2tp_class_name.yfilter != YFilter.not_set or
                                    self.local_cookie_high_value.yfilter != YFilter.not_set or
                                    self.local_cookie_low_value.yfilter != YFilter.not_set or
                                    self.local_cookie_size.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                    self.local_session_id.yfilter != YFilter.not_set or
                                    self.path_mtu_enabled.yfilter != YFilter.not_set or
                                    self.path_mtu_max_value.yfilter != YFilter.not_set or
                                    self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                    self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                    self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                    self.remote_cookie_size.yfilter != YFilter.not_set or
                                    self.remote_session_id.yfilter != YFilter.not_set or
                                    self.tos.yfilter != YFilter.not_set or
                                    self.tos_mode.yfilter != YFilter.not_set or
                                    self.ttl.yfilter != YFilter.not_set or
                                    self.tunnel_state.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2tpv3" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos.get_name_leafdata())
                                if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ttl.get_name_leafdata())
                                if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dont-fragment-bit"):
                                    self.dont_fragment_bit = value
                                    self.dont_fragment_bit.value_namespace = name_space
                                    self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-source-address"):
                                    self.ipv4_source_address = value
                                    self.ipv4_source_address.value_namespace = name_space
                                    self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-source-address"):
                                    self.ipv6_source_address = value
                                    self.ipv6_source_address.value_namespace = name_space
                                    self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "l2tp-class-name"):
                                    self.l2tp_class_name = value
                                    self.l2tp_class_name.value_namespace = name_space
                                    self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-high-value"):
                                    self.local_cookie_high_value = value
                                    self.local_cookie_high_value.value_namespace = name_space
                                    self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-low-value"):
                                    self.local_cookie_low_value = value
                                    self.local_cookie_low_value.value_namespace = name_space
                                    self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-size"):
                                    self.local_cookie_size = value
                                    self.local_cookie_size.value_namespace = name_space
                                    self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-high-value"):
                                    self.local_secondary_cookie_high_value = value
                                    self.local_secondary_cookie_high_value.value_namespace = name_space
                                    self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-low-value"):
                                    self.local_secondary_cookie_low_value = value
                                    self.local_secondary_cookie_low_value.value_namespace = name_space
                                    self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-size"):
                                    self.local_secondary_cookie_size = value
                                    self.local_secondary_cookie_size.value_namespace = name_space
                                    self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-session-id"):
                                    self.local_session_id = value
                                    self.local_session_id.value_namespace = name_space
                                    self.local_session_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-enabled"):
                                    self.path_mtu_enabled = value
                                    self.path_mtu_enabled.value_namespace = name_space
                                    self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-max-value"):
                                    self.path_mtu_max_value = value
                                    self.path_mtu_max_value.value_namespace = name_space
                                    self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-circuit-status-up"):
                                    self.remote_circuit_status_up = value
                                    self.remote_circuit_status_up.value_namespace = name_space
                                    self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-high-value"):
                                    self.remote_cookie_high_value = value
                                    self.remote_cookie_high_value.value_namespace = name_space
                                    self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-low-value"):
                                    self.remote_cookie_low_value = value
                                    self.remote_cookie_low_value.value_namespace = name_space
                                    self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-size"):
                                    self.remote_cookie_size = value
                                    self.remote_cookie_size.value_namespace = name_space
                                    self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-session-id"):
                                    self.remote_session_id = value
                                    self.remote_session_id.value_namespace = name_space
                                    self.remote_session_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos"):
                                    self.tos = value
                                    self.tos.value_namespace = name_space
                                    self.tos.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos-mode"):
                                    self.tos_mode = value
                                    self.tos_mode.value_namespace = name_space
                                    self.tos_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "ttl"):
                                    self.ttl = value
                                    self.ttl.value_namespace = name_space
                                    self.ttl.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-state"):
                                    self.tunnel_state = value
                                    self.tunnel_state.value_namespace = name_space
                                    self.tunnel_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.encapsulation.is_set or
                                (self.atom is not None and self.atom.has_data()) or
                                (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.encapsulation.yfilter != YFilter.not_set or
                                (self.atom is not None and self.atom.has_operation()) or
                                (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "encapsulation-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "atom"):
                                if (self.atom is None):
                                    self.atom = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                return self.atom

                            if (child_yang_name == "l2tpv3"):
                                if (self.l2tpv3 is None):
                                    self.l2tpv3 = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                return self.l2tpv3

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "encapsulation"):
                                self.encapsulation = value
                                self.encapsulation.value_namespace = name_space
                                self.encapsulation.value_namespace_prefix = name_space_prefix


                    class LocalInterface(Entity):
                        """
                        Local interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__init__()

                            self.yang_name = "local-interface"
                            self.yang_parent_name = "pseudo-wire"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "local-interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class RemoteInterface(Entity):
                        """
                        Remote interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__init__()

                            self.yang_name = "remote-interface"
                            self.yang_parent_name = "pseudo-wire"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "remote-interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class PreferredPath(Entity):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__init__()

                            self.yang_name = "preferred-path"
                            self.yang_parent_name = "pseudo-wire"

                            self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                            self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                            self.option = YLeaf(YType.enumeration, "option")

                            self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                            self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ip_tunnel_interface_number",
                                            "next_hop_ip",
                                            "option",
                                            "te_tunnel_interface_number",
                                            "tp_tunnel_interface_number") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ip_tunnel_interface_number.is_set or
                                self.next_hop_ip.is_set or
                                self.option.is_set or
                                self.te_tunnel_interface_number.is_set or
                                self.tp_tunnel_interface_number.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set or
                                self.option.yfilter != YFilter.not_set or
                                self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "preferred-path" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                            if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.option.get_name_leafdata())
                            if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                            if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ip-tunnel-interface-number"):
                                self.ip_tunnel_interface_number = value
                                self.ip_tunnel_interface_number.value_namespace = name_space
                                self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix
                            if(value_path == "option"):
                                self.option = value
                                self.option.value_namespace = name_space
                                self.option.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-tunnel-interface-number"):
                                self.te_tunnel_interface_number = value
                                self.te_tunnel_interface_number.value_namespace = name_space
                                self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "tp-tunnel-interface-number"):
                                self.tp_tunnel_interface_number = value
                                self.tp_tunnel_interface_number.value_namespace = name_space
                                self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                    class LocalSignalling(Entity):
                        """
                        Local signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__init__()

                            self.yang_name = "local-signalling"
                            self.yang_parent_name = "pseudo-wire"

                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self._children_name_map["status_tlv"] = "status-tlv"
                            self._children_yang_names.add("status-tlv")

                            self.tlv = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pw_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                        class StatusTlv(Entity):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                self.yang_name = "status-tlv"
                                self.yang_parent_name = "local-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "status-tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix


                        class Tlv(Entity):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "local-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.tlv:
                                if (c.has_data()):
                                    return True
                            return (
                                self.pw_status.is_set or
                                (self.status_tlv is not None and self.status_tlv.has_data()))

                        def has_operation(self):
                            for c in self.tlv:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pw_status.yfilter != YFilter.not_set or
                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-signalling" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "status-tlv"):
                                if (self.status_tlv is None):
                                    self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                return self.status_tlv

                            if (child_yang_name == "tlv"):
                                for c in self.tlv:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.tlv.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pw-status"):
                                self.pw_status = value
                                self.pw_status.value_namespace = name_space
                                self.pw_status.value_namespace_prefix = name_space_prefix


                    class RemoteSignalling(Entity):
                        """
                        Remote signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__init__()

                            self.yang_name = "remote-signalling"
                            self.yang_parent_name = "pseudo-wire"

                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self._children_name_map["status_tlv"] = "status-tlv"
                            self._children_yang_names.add("status-tlv")

                            self.tlv = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pw_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                        class StatusTlv(Entity):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                self.yang_name = "status-tlv"
                                self.yang_parent_name = "remote-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "status-tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix


                        class Tlv(Entity):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "remote-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.tlv:
                                if (c.has_data()):
                                    return True
                            return (
                                self.pw_status.is_set or
                                (self.status_tlv is not None and self.status_tlv.has_data()))

                        def has_operation(self):
                            for c in self.tlv:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pw_status.yfilter != YFilter.not_set or
                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-signalling" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "status-tlv"):
                                if (self.status_tlv is None):
                                    self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                return self.status_tlv

                            if (child_yang_name == "tlv"):
                                for c in self.tlv:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.tlv.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pw-status"):
                                self.pw_status = value
                                self.pw_status.value_namespace = name_space
                                self.pw_status.value_namespace_prefix = name_space_prefix


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "pseudo-wire"

                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                            self._children_yang_names.add("dispostion-stats")

                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self._children_name_map["impostion_stats"] = "impostion-stats"
                            self._children_yang_names.add("impostion-stats")

                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                            self.sequence_number.parent = self
                            self._children_name_map["sequence_number"] = "sequence-number"
                            self._children_yang_names.add("sequence-number")


                        class ImpostionStats(Entity):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                self.yang_name = "impostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self._children_name_map["broadcast"] = "broadcast"
                                self._children_yang_names.add("broadcast")

                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                self._children_yang_names.add("imposition-mtu-drop")

                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                self._children_yang_names.add("imposition-stat")

                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                self._children_yang_names.add("impostion-tail-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                self._children_yang_names.add("l2fsbi-drop")

                                self.multicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                                self._children_yang_names.add("multicast")

                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self
                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                self._children_yang_names.add("unknown-unicast")


                            class ImpositionStat(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                    self.yang_name = "imposition-stat"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpositionMtuDrop(Entity):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                    self.yang_name = "imposition-mtu-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpostionTailDrop(Entity):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                    self.yang_name = "impostion-tail-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class L2FsbiDrop(Entity):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                    self.yang_name = "l2fsbi-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fsbi-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Multicast(Entity):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Broadcast(Entity):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                    self.yang_name = "broadcast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnknownUnicast(Entity):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                    self.yang_name = "unknown-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unknown-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                    (self.multicast is not None and self.multicast.has_data()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                    (self.multicast is not None and self.multicast.has_operation()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "impostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast"):
                                    if (self.broadcast is None):
                                        self.broadcast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                    return self.broadcast

                                if (child_yang_name == "imposition-mtu-drop"):
                                    if (self.imposition_mtu_drop is None):
                                        self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    return self.imposition_mtu_drop

                                if (child_yang_name == "imposition-stat"):
                                    if (self.imposition_stat is None):
                                        self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                    return self.imposition_stat

                                if (child_yang_name == "impostion-tail-drop"):
                                    if (self.impostion_tail_drop is None):
                                        self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    return self.impostion_tail_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "l2fsbi-drop"):
                                    if (self.l2fsbi_drop is None):
                                        self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    return self.l2fsbi_drop

                                if (child_yang_name == "multicast"):
                                    if (self.multicast is None):
                                        self.multicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                    return self.multicast

                                if (child_yang_name == "unknown-unicast"):
                                    if (self.unknown_unicast is None):
                                        self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    return self.unknown_unicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DispostionStats(Entity):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats, self).__init__()

                                self.yang_name = "dispostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                self._children_yang_names.add("broadcast-drop")

                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self._children_name_map["dai_drop"] = "dai-drop"
                                self._children_yang_names.add("dai-drop")

                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                self._children_yang_names.add("disposition-mtu-drop")

                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                self._children_yang_names.add("disposition-oo-o-drops")

                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                self._children_yang_names.add("disposition-p2mp-stats")

                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                self._children_yang_names.add("disposition-stat")

                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                self._children_yang_names.add("disposition-tail-drop")

                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                self._children_yang_names.add("ipsg-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.mac_move = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self._children_name_map["mac_move"] = "mac-move"
                                self._children_yang_names.add("mac-move")

                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                self._children_yang_names.add("multicast-drop")

                                self.received_drops = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self._children_name_map["received_drops"] = "received-drops"
                                self._children_yang_names.add("received-drops")

                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self
                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                self._children_yang_names.add("unicast-drop")


                            class DispositionStat(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                    self.yang_name = "disposition-stat"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionMtuDrop(Entity):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                    self.yang_name = "disposition-mtu-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionTailDrop(Entity):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                    self.yang_name = "disposition-tail-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MulticastDrop(Entity):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                    self.yang_name = "multicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnicastDrop(Entity):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                    self.yang_name = "unicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class BroadcastDrop(Entity):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                    self.yang_name = "broadcast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ReceivedDrops(Entity):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                    self.yang_name = "received-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DaiDrop(Entity):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                    self.yang_name = "dai-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dai-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class IpsgDrop(Entity):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                    self.yang_name = "ipsg-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipsg-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionOoODrops(Entity):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                    self.yang_name = "disposition-oo-o-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionP2MpStats(Entity):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                    self.yang_name = "disposition-p2mp-stats"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MacMove(Entity):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                    self.yang_name = "mac-move"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-move" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dispostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast-drop"):
                                    if (self.broadcast_drop is None):
                                        self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    return self.broadcast_drop

                                if (child_yang_name == "dai-drop"):
                                    if (self.dai_drop is None):
                                        self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                    return self.dai_drop

                                if (child_yang_name == "disposition-mtu-drop"):
                                    if (self.disposition_mtu_drop is None):
                                        self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    return self.disposition_mtu_drop

                                if (child_yang_name == "disposition-oo-o-drops"):
                                    if (self.disposition_oo_o_drops is None):
                                        self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    return self.disposition_oo_o_drops

                                if (child_yang_name == "disposition-p2mp-stats"):
                                    if (self.disposition_p2mp_stats is None):
                                        self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    return self.disposition_p2mp_stats

                                if (child_yang_name == "disposition-stat"):
                                    if (self.disposition_stat is None):
                                        self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                    return self.disposition_stat

                                if (child_yang_name == "disposition-tail-drop"):
                                    if (self.disposition_tail_drop is None):
                                        self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    return self.disposition_tail_drop

                                if (child_yang_name == "ipsg-drop"):
                                    if (self.ipsg_drop is None):
                                        self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    return self.ipsg_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "mac-move"):
                                    if (self.mac_move is None):
                                        self.mac_move = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                    return self.mac_move

                                if (child_yang_name == "multicast-drop"):
                                    if (self.multicast_drop is None):
                                        self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                    return self.multicast_drop

                                if (child_yang_name == "received-drops"):
                                    if (self.received_drops is None):
                                        self.received_drops = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                    return self.received_drops

                                if (child_yang_name == "unicast-drop"):
                                    if (self.unicast_drop is None):
                                        self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                    return self.unicast_drop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SequenceNumber(Entity):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                self.yang_name = "sequence-number"
                                self.yang_parent_name = "statistics"

                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bypassed_inbound_sequence_packet",
                                                "bypassed_out_sequence_packet",
                                                "sequence_number_expected",
                                                "sequence_number_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bypassed_inbound_sequence_packet.is_set or
                                    self.bypassed_out_sequence_packet.is_set or
                                    self.sequence_number_expected.is_set or
                                    self.sequence_number_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sequence-number" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bypassed-inbound-sequence-packet"):
                                    self.bypassed_inbound_sequence_packet = value
                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "bypassed-out-sequence-packet"):
                                    self.bypassed_out_sequence_packet = value
                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-expected"):
                                    self.sequence_number_expected = value
                                    self.sequence_number_expected.value_namespace = name_space
                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-sent"):
                                    self.sequence_number_sent = value
                                    self.sequence_number_sent.value_namespace = name_space
                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                (self.sequence_number is not None and self.sequence_number.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dispostion-stats"):
                                if (self.dispostion_stats is None):
                                    self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                return self.dispostion_stats

                            if (child_yang_name == "impostion-stats"):
                                if (self.impostion_stats is None):
                                    self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                return self.impostion_stats

                            if (child_yang_name == "sequence-number"):
                                if (self.sequence_number is None):
                                    self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                return self.sequence_number

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class P2MpPw(Entity):
                        """
                        P2MP Pseudowire Information
                        
                        .. attribute:: local_available
                        
                        	Local LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: local_extended_tunnel_id
                        
                        	Local Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_flags
                        
                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: local_label
                        
                        	Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_p2mp_id
                        
                        	Local P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_ptree_type
                        
                        	Local P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                        
                        .. attribute:: local_tunnel_id
                        
                        	Local Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_available
                        
                        	Remote LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: remote_extended_tunnel_id
                        
                        	Remote Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_flags
                        
                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_label
                        
                        	Remote Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_p2mp_id
                        
                        	Remote P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_ptree_type
                        
                        	Remote P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                        
                        .. attribute:: remote_tunnel_id
                        
                        	Remote Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__init__()

                            self.yang_name = "p2mp-pw"
                            self.yang_parent_name = "pseudo-wire"

                            self.local_available = YLeaf(YType.boolean, "local-available")

                            self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                            self.local_flags = YLeaf(YType.uint8, "local-flags")

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                            self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                            self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                            self.remote_available = YLeaf(YType.boolean, "remote-available")

                            self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                            self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                            self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                            self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                            self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("local_available",
                                            "local_extended_tunnel_id",
                                            "local_flags",
                                            "local_label",
                                            "local_p2mp_id",
                                            "local_ptree_type",
                                            "local_tunnel_id",
                                            "remote_available",
                                            "remote_extended_tunnel_id",
                                            "remote_flags",
                                            "remote_label",
                                            "remote_p2mp_id",
                                            "remote_ptree_type",
                                            "remote_tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.local_available.is_set or
                                self.local_extended_tunnel_id.is_set or
                                self.local_flags.is_set or
                                self.local_label.is_set or
                                self.local_p2mp_id.is_set or
                                self.local_ptree_type.is_set or
                                self.local_tunnel_id.is_set or
                                self.remote_available.is_set or
                                self.remote_extended_tunnel_id.is_set or
                                self.remote_flags.is_set or
                                self.remote_label.is_set or
                                self.remote_p2mp_id.is_set or
                                self.remote_ptree_type.is_set or
                                self.remote_tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.local_available.yfilter != YFilter.not_set or
                                self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                self.local_flags.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                self.local_p2mp_id.yfilter != YFilter.not_set or
                                self.local_ptree_type.yfilter != YFilter.not_set or
                                self.local_tunnel_id.yfilter != YFilter.not_set or
                                self.remote_available.yfilter != YFilter.not_set or
                                self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                self.remote_flags.yfilter != YFilter.not_set or
                                self.remote_label.yfilter != YFilter.not_set or
                                self.remote_p2mp_id.yfilter != YFilter.not_set or
                                self.remote_ptree_type.yfilter != YFilter.not_set or
                                self.remote_tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-pw" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_available.get_name_leafdata())
                            if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                            if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_flags.get_name_leafdata())
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())
                            if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                            if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                            if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                            if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_available.get_name_leafdata())
                            if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                            if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_flags.get_name_leafdata())
                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                            if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                            if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                            if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "local-available"):
                                self.local_available = value
                                self.local_available.value_namespace = name_space
                                self.local_available.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-extended-tunnel-id"):
                                self.local_extended_tunnel_id = value
                                self.local_extended_tunnel_id.value_namespace = name_space
                                self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-flags"):
                                self.local_flags = value
                                self.local_flags.value_namespace = name_space
                                self.local_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-p2mp-id"):
                                self.local_p2mp_id = value
                                self.local_p2mp_id.value_namespace = name_space
                                self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-ptree-type"):
                                self.local_ptree_type = value
                                self.local_ptree_type.value_namespace = name_space
                                self.local_ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-tunnel-id"):
                                self.local_tunnel_id = value
                                self.local_tunnel_id.value_namespace = name_space
                                self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-available"):
                                self.remote_available = value
                                self.remote_available.value_namespace = name_space
                                self.remote_available.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-extended-tunnel-id"):
                                self.remote_extended_tunnel_id = value
                                self.remote_extended_tunnel_id.value_namespace = name_space
                                self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-flags"):
                                self.remote_flags = value
                                self.remote_flags.value_namespace = name_space
                                self.remote_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label"):
                                self.remote_label = value
                                self.remote_label.value_namespace = name_space
                                self.remote_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-p2mp-id"):
                                self.remote_p2mp_id = value
                                self.remote_p2mp_id.value_namespace = name_space
                                self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-ptree-type"):
                                self.remote_ptree_type = value
                                self.remote_ptree_type.value_namespace = name_space
                                self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-tunnel-id"):
                                self.remote_tunnel_id = value
                                self.remote_tunnel_id.value_namespace = name_space
                                self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ad_method.is_set or
                            self.ad_remote_down.is_set or
                            self.admited_bw.is_set or
                            self.auto_discovery.is_set or
                            self.backup_active.is_set or
                            self.backup_force_active.is_set or
                            self.backup_pw.is_set or
                            self.bitrate_mismatched.is_set or
                            self.bridge_pw_type_mismatch.is_set or
                            self.cas_mismatched.is_set or
                            self.diff_ts_mismatched.is_set or
                            self.disable_delay.is_set or
                            self.disable_never.is_set or
                            self.evpn_src_acid.is_set or
                            self.fe_ctype.is_set or
                            self.forward_class.is_set or
                            self.freq_mismatched.is_set or
                            self.illegal_control_word.is_set or
                            self.imposed_vlan_id.is_set or
                            self.interworking.is_set or
                            self.ipv6_local_source_address.is_set or
                            self.is_evpnvpws_type.is_set or
                            self.is_flow_label_static.is_set or
                            self.is_multi_segment_pseudowire.is_set or
                            self.is_partially_programmed.is_set or
                            self.is_pwr_type.is_set or
                            self.is_vfi.is_set or
                            self.last_time_status_changed.is_set or
                            self.last_time_status_down.is_set or
                            self.ldp_label_advertise_failed.is_set or
                            self.load_balance.is_set or
                            self.local_control_word.is_set or
                            self.local_label_failed.is_set or
                            self.local_pseudo_wire_type.is_set or
                            self.local_source_address.is_set or
                            self.mac_limit_oper_down.is_set or
                            self.mtu_mismatched.is_set or
                            self.not_supported_qinq.is_set or
                            self.num_ma_cwithdraw_msg_received.is_set or
                            self.number_ma_cwithdraw_message_sent.is_set or
                            self.out_of_memory_state.is_set or
                            self.payload_bytes_mismatched.is_set or
                            self.payload_type_mismatched.is_set or
                            self.preferred_path_disable_fallback.is_set or
                            self.primary_peer_id.is_set or
                            self.primary_pseudo_wire_id.is_set or
                            self.primary_pw.is_set or
                            self.protocol.is_set or
                            self.pseudo_wire_id.is_set or
                            self.pseudo_wire_state.is_set or
                            self.pseudo_wire_type_mismatched.is_set or
                            self.pw_class_name.is_set or
                            self.pw_flow_label_code17_disabled.is_set or
                            self.pw_flow_label_type.is_set or
                            self.pw_flow_label_type_cfg.is_set or
                            self.pw_redundancy_initial_delay.is_set or
                            self.pw_redundancy_one_way.is_set or
                            self.pw_status_use.is_set or
                            self.pwlsd_rewrite_failed.is_set or
                            self.remote_control_word.is_set or
                            self.remote_label_failed.is_set or
                            self.remote_pseudo_wire_type.is_set or
                            self.required_bw.is_set or
                            self.resync_enabled.is_set or
                            self.resync_threshold.is_set or
                            self.rtp_mismatched.is_set or
                            self.sequencing_type.is_set or
                            self.shutdown.is_set or
                            self.sig_pkts_mismatched.is_set or
                            self.ssrc_mismatched.is_set or
                            self.state.is_set or
                            self.table_policy_name.is_set or
                            self.tag_rewrite.is_set or
                            self.time_created.is_set or
                            self.time_elapsed_creation.is_set or
                            self.time_elapsed_status_changed.is_set or
                            self.time_elapsed_status_down.is_set or
                            self.transport_lsp_down.is_set or
                            self.xconnect_id.is_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                            (self.local_interface is not None and self.local_interface.has_data()) or
                            (self.local_signalling is not None and self.local_signalling.has_data()) or
                            (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                            (self.peer_id is not None and self.peer_id.has_data()) or
                            (self.preferred_path is not None and self.preferred_path.has_data()) or
                            (self.remote_interface is not None and self.remote_interface.has_data()) or
                            (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ad_method.yfilter != YFilter.not_set or
                            self.ad_remote_down.yfilter != YFilter.not_set or
                            self.admited_bw.yfilter != YFilter.not_set or
                            self.auto_discovery.yfilter != YFilter.not_set or
                            self.backup_active.yfilter != YFilter.not_set or
                            self.backup_force_active.yfilter != YFilter.not_set or
                            self.backup_pw.yfilter != YFilter.not_set or
                            self.bitrate_mismatched.yfilter != YFilter.not_set or
                            self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                            self.cas_mismatched.yfilter != YFilter.not_set or
                            self.diff_ts_mismatched.yfilter != YFilter.not_set or
                            self.disable_delay.yfilter != YFilter.not_set or
                            self.disable_never.yfilter != YFilter.not_set or
                            self.evpn_src_acid.yfilter != YFilter.not_set or
                            self.fe_ctype.yfilter != YFilter.not_set or
                            self.forward_class.yfilter != YFilter.not_set or
                            self.freq_mismatched.yfilter != YFilter.not_set or
                            self.illegal_control_word.yfilter != YFilter.not_set or
                            self.imposed_vlan_id.yfilter != YFilter.not_set or
                            self.interworking.yfilter != YFilter.not_set or
                            self.ipv6_local_source_address.yfilter != YFilter.not_set or
                            self.is_evpnvpws_type.yfilter != YFilter.not_set or
                            self.is_flow_label_static.yfilter != YFilter.not_set or
                            self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                            self.is_partially_programmed.yfilter != YFilter.not_set or
                            self.is_pwr_type.yfilter != YFilter.not_set or
                            self.is_vfi.yfilter != YFilter.not_set or
                            self.last_time_status_changed.yfilter != YFilter.not_set or
                            self.last_time_status_down.yfilter != YFilter.not_set or
                            self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                            self.load_balance.yfilter != YFilter.not_set or
                            self.local_control_word.yfilter != YFilter.not_set or
                            self.local_label_failed.yfilter != YFilter.not_set or
                            self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                            self.local_source_address.yfilter != YFilter.not_set or
                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                            self.mtu_mismatched.yfilter != YFilter.not_set or
                            self.not_supported_qinq.yfilter != YFilter.not_set or
                            self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                            self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                            self.out_of_memory_state.yfilter != YFilter.not_set or
                            self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                            self.payload_type_mismatched.yfilter != YFilter.not_set or
                            self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                            self.primary_peer_id.yfilter != YFilter.not_set or
                            self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                            self.primary_pw.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.pseudo_wire_id.yfilter != YFilter.not_set or
                            self.pseudo_wire_state.yfilter != YFilter.not_set or
                            self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                            self.pw_class_name.yfilter != YFilter.not_set or
                            self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                            self.pw_flow_label_type.yfilter != YFilter.not_set or
                            self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                            self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                            self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                            self.pw_status_use.yfilter != YFilter.not_set or
                            self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                            self.remote_control_word.yfilter != YFilter.not_set or
                            self.remote_label_failed.yfilter != YFilter.not_set or
                            self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                            self.required_bw.yfilter != YFilter.not_set or
                            self.resync_enabled.yfilter != YFilter.not_set or
                            self.resync_threshold.yfilter != YFilter.not_set or
                            self.rtp_mismatched.yfilter != YFilter.not_set or
                            self.sequencing_type.yfilter != YFilter.not_set or
                            self.shutdown.yfilter != YFilter.not_set or
                            self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                            self.ssrc_mismatched.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.table_policy_name.yfilter != YFilter.not_set or
                            self.tag_rewrite.yfilter != YFilter.not_set or
                            self.time_created.yfilter != YFilter.not_set or
                            self.time_elapsed_creation.yfilter != YFilter.not_set or
                            self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                            self.time_elapsed_status_down.yfilter != YFilter.not_set or
                            self.transport_lsp_down.yfilter != YFilter.not_set or
                            self.xconnect_id.yfilter != YFilter.not_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                            (self.local_interface is not None and self.local_interface.has_operation()) or
                            (self.local_signalling is not None and self.local_signalling.has_operation()) or
                            (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                            (self.peer_id is not None and self.peer_id.has_operation()) or
                            (self.preferred_path is not None and self.preferred_path.has_operation()) or
                            (self.remote_interface is not None and self.remote_interface.has_operation()) or
                            (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pseudo-wire" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment1/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_method.get_name_leafdata())
                        if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                        if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.admited_bw.get_name_leafdata())
                        if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                        if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_active.get_name_leafdata())
                        if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                        if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_pw.get_name_leafdata())
                        if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                        if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                        if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                        if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                        if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_delay.get_name_leafdata())
                        if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_never.get_name_leafdata())
                        if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                        if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                        if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.forward_class.get_name_leafdata())
                        if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                        if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                        if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interworking.get_name_leafdata())
                        if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                        if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                        if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                        if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                        if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                        if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                        if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_vfi.get_name_leafdata())
                        if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                        if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                        if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                        if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance.get_name_leafdata())
                        if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_control_word.get_name_leafdata())
                        if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                        if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                        if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_source_address.get_name_leafdata())
                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                        if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                        if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                        if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                        if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                        if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                        if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                        if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                        if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                        if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_pw.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                        if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                        if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                        if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                        if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                        if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                        if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                        if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                        if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                        if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                        if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                        if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                        if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                        if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                        if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.required_bw.get_name_leafdata())
                        if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                        if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                        if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                        if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                        if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                        if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                        if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                        if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_created.get_name_leafdata())
                        if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                        if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                        if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                        if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "encapsulation-info"):
                            if (self.encapsulation_info is None):
                                self.encapsulation_info = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            return self.encapsulation_info

                        if (child_yang_name == "local-interface"):
                            if (self.local_interface is None):
                                self.local_interface = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                            return self.local_interface

                        if (child_yang_name == "local-signalling"):
                            if (self.local_signalling is None):
                                self.local_signalling = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                            return self.local_signalling

                        if (child_yang_name == "p2mp-pw"):
                            if (self.p2mp_pw is None):
                                self.p2mp_pw = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            return self.p2mp_pw

                        if (child_yang_name == "peer-id"):
                            if (self.peer_id is None):
                                self.peer_id = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                            return self.peer_id

                        if (child_yang_name == "preferred-path"):
                            if (self.preferred_path is None):
                                self.preferred_path = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                            return self.preferred_path

                        if (child_yang_name == "remote-interface"):
                            if (self.remote_interface is None):
                                self.remote_interface = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                            return self.remote_interface

                        if (child_yang_name == "remote-signalling"):
                            if (self.remote_signalling is None):
                                self.remote_signalling = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                            return self.remote_signalling

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ad-method"):
                            self.ad_method = value
                            self.ad_method.value_namespace = name_space
                            self.ad_method.value_namespace_prefix = name_space_prefix
                        if(value_path == "ad-remote-down"):
                            self.ad_remote_down = value
                            self.ad_remote_down.value_namespace = name_space
                            self.ad_remote_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "admited-bw"):
                            self.admited_bw = value
                            self.admited_bw.value_namespace = name_space
                            self.admited_bw.value_namespace_prefix = name_space_prefix
                        if(value_path == "auto-discovery"):
                            self.auto_discovery = value
                            self.auto_discovery.value_namespace = name_space
                            self.auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-active"):
                            self.backup_active = value
                            self.backup_active.value_namespace = name_space
                            self.backup_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-force-active"):
                            self.backup_force_active = value
                            self.backup_force_active.value_namespace = name_space
                            self.backup_force_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-pw"):
                            self.backup_pw = value
                            self.backup_pw.value_namespace = name_space
                            self.backup_pw.value_namespace_prefix = name_space_prefix
                        if(value_path == "bitrate-mismatched"):
                            self.bitrate_mismatched = value
                            self.bitrate_mismatched.value_namespace = name_space
                            self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-pw-type-mismatch"):
                            self.bridge_pw_type_mismatch = value
                            self.bridge_pw_type_mismatch.value_namespace = name_space
                            self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                        if(value_path == "cas-mismatched"):
                            self.cas_mismatched = value
                            self.cas_mismatched.value_namespace = name_space
                            self.cas_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "diff-ts-mismatched"):
                            self.diff_ts_mismatched = value
                            self.diff_ts_mismatched.value_namespace = name_space
                            self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-delay"):
                            self.disable_delay = value
                            self.disable_delay.value_namespace = name_space
                            self.disable_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-never"):
                            self.disable_never = value
                            self.disable_never.value_namespace = name_space
                            self.disable_never.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-src-acid"):
                            self.evpn_src_acid = value
                            self.evpn_src_acid.value_namespace = name_space
                            self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                        if(value_path == "fe-ctype"):
                            self.fe_ctype = value
                            self.fe_ctype.value_namespace = name_space
                            self.fe_ctype.value_namespace_prefix = name_space_prefix
                        if(value_path == "forward-class"):
                            self.forward_class = value
                            self.forward_class.value_namespace = name_space
                            self.forward_class.value_namespace_prefix = name_space_prefix
                        if(value_path == "freq-mismatched"):
                            self.freq_mismatched = value
                            self.freq_mismatched.value_namespace = name_space
                            self.freq_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "illegal-control-word"):
                            self.illegal_control_word = value
                            self.illegal_control_word.value_namespace = name_space
                            self.illegal_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "imposed-vlan-id"):
                            self.imposed_vlan_id = value
                            self.imposed_vlan_id.value_namespace = name_space
                            self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interworking"):
                            self.interworking = value
                            self.interworking.value_namespace = name_space
                            self.interworking.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-local-source-address"):
                            self.ipv6_local_source_address = value
                            self.ipv6_local_source_address.value_namespace = name_space
                            self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-evpnvpws-type"):
                            self.is_evpnvpws_type = value
                            self.is_evpnvpws_type.value_namespace = name_space
                            self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-flow-label-static"):
                            self.is_flow_label_static = value
                            self.is_flow_label_static.value_namespace = name_space
                            self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multi-segment-pseudowire"):
                            self.is_multi_segment_pseudowire = value
                            self.is_multi_segment_pseudowire.value_namespace = name_space
                            self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-partially-programmed"):
                            self.is_partially_programmed = value
                            self.is_partially_programmed.value_namespace = name_space
                            self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pwr-type"):
                            self.is_pwr_type = value
                            self.is_pwr_type.value_namespace = name_space
                            self.is_pwr_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-vfi"):
                            self.is_vfi = value
                            self.is_vfi.value_namespace = name_space
                            self.is_vfi.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-changed"):
                            self.last_time_status_changed = value
                            self.last_time_status_changed.value_namespace = name_space
                            self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-down"):
                            self.last_time_status_down = value
                            self.last_time_status_down.value_namespace = name_space
                            self.last_time_status_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "ldp-label-advertise-failed"):
                            self.ldp_label_advertise_failed = value
                            self.ldp_label_advertise_failed.value_namespace = name_space
                            self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance"):
                            self.load_balance = value
                            self.load_balance.value_namespace = name_space
                            self.load_balance.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-control-word"):
                            self.local_control_word = value
                            self.local_control_word.value_namespace = name_space
                            self.local_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-label-failed"):
                            self.local_label_failed = value
                            self.local_label_failed.value_namespace = name_space
                            self.local_label_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-pseudo-wire-type"):
                            self.local_pseudo_wire_type = value
                            self.local_pseudo_wire_type.value_namespace = name_space
                            self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-source-address"):
                            self.local_source_address = value
                            self.local_source_address.value_namespace = name_space
                            self.local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-oper-down"):
                            self.mac_limit_oper_down = value
                            self.mac_limit_oper_down.value_namespace = name_space
                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-mismatched"):
                            self.mtu_mismatched = value
                            self.mtu_mismatched.value_namespace = name_space
                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-qinq"):
                            self.not_supported_qinq = value
                            self.not_supported_qinq.value_namespace = name_space
                            self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-ma-cwithdraw-msg-received"):
                            self.num_ma_cwithdraw_msg_received = value
                            self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                            self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-ma-cwithdraw-message-sent"):
                            self.number_ma_cwithdraw_message_sent = value
                            self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                            self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-of-memory-state"):
                            self.out_of_memory_state = value
                            self.out_of_memory_state.value_namespace = name_space
                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "payload-bytes-mismatched"):
                            self.payload_bytes_mismatched = value
                            self.payload_bytes_mismatched.value_namespace = name_space
                            self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "payload-type-mismatched"):
                            self.payload_type_mismatched = value
                            self.payload_type_mismatched.value_namespace = name_space
                            self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "preferred-path-disable-fallback"):
                            self.preferred_path_disable_fallback = value
                            self.preferred_path_disable_fallback.value_namespace = name_space
                            self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-peer-id"):
                            self.primary_peer_id = value
                            self.primary_peer_id.value_namespace = name_space
                            self.primary_peer_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-pseudo-wire-id"):
                            self.primary_pseudo_wire_id = value
                            self.primary_pseudo_wire_id.value_namespace = name_space
                            self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-pw"):
                            self.primary_pw = value
                            self.primary_pw.value_namespace = name_space
                            self.primary_pw.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-id"):
                            self.pseudo_wire_id = value
                            self.pseudo_wire_id.value_namespace = name_space
                            self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-state"):
                            self.pseudo_wire_state = value
                            self.pseudo_wire_state.value_namespace = name_space
                            self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-type-mismatched"):
                            self.pseudo_wire_type_mismatched = value
                            self.pseudo_wire_type_mismatched.value_namespace = name_space
                            self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-class-name"):
                            self.pw_class_name = value
                            self.pw_class_name.value_namespace = name_space
                            self.pw_class_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-code17-disabled"):
                            self.pw_flow_label_code17_disabled = value
                            self.pw_flow_label_code17_disabled.value_namespace = name_space
                            self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type"):
                            self.pw_flow_label_type = value
                            self.pw_flow_label_type.value_namespace = name_space
                            self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type-cfg"):
                            self.pw_flow_label_type_cfg = value
                            self.pw_flow_label_type_cfg.value_namespace = name_space
                            self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-redundancy-initial-delay"):
                            self.pw_redundancy_initial_delay = value
                            self.pw_redundancy_initial_delay.value_namespace = name_space
                            self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-redundancy-one-way"):
                            self.pw_redundancy_one_way = value
                            self.pw_redundancy_one_way.value_namespace = name_space
                            self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-status-use"):
                            self.pw_status_use = value
                            self.pw_status_use.value_namespace = name_space
                            self.pw_status_use.value_namespace_prefix = name_space_prefix
                        if(value_path == "pwlsd-rewrite-failed"):
                            self.pwlsd_rewrite_failed = value
                            self.pwlsd_rewrite_failed.value_namespace = name_space
                            self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-control-word"):
                            self.remote_control_word = value
                            self.remote_control_word.value_namespace = name_space
                            self.remote_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-label-failed"):
                            self.remote_label_failed = value
                            self.remote_label_failed.value_namespace = name_space
                            self.remote_label_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-pseudo-wire-type"):
                            self.remote_pseudo_wire_type = value
                            self.remote_pseudo_wire_type.value_namespace = name_space
                            self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "required-bw"):
                            self.required_bw = value
                            self.required_bw.value_namespace = name_space
                            self.required_bw.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-enabled"):
                            self.resync_enabled = value
                            self.resync_enabled.value_namespace = name_space
                            self.resync_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-threshold"):
                            self.resync_threshold = value
                            self.resync_threshold.value_namespace = name_space
                            self.resync_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "rtp-mismatched"):
                            self.rtp_mismatched = value
                            self.rtp_mismatched.value_namespace = name_space
                            self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "sequencing-type"):
                            self.sequencing_type = value
                            self.sequencing_type.value_namespace = name_space
                            self.sequencing_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "shutdown"):
                            self.shutdown = value
                            self.shutdown.value_namespace = name_space
                            self.shutdown.value_namespace_prefix = name_space_prefix
                        if(value_path == "sig-pkts-mismatched"):
                            self.sig_pkts_mismatched = value
                            self.sig_pkts_mismatched.value_namespace = name_space
                            self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssrc-mismatched"):
                            self.ssrc_mismatched = value
                            self.ssrc_mismatched.value_namespace = name_space
                            self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-policy-name"):
                            self.table_policy_name = value
                            self.table_policy_name.value_namespace = name_space
                            self.table_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "tag-rewrite"):
                            self.tag_rewrite = value
                            self.tag_rewrite.value_namespace = name_space
                            self.tag_rewrite.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-created"):
                            self.time_created = value
                            self.time_created.value_namespace = name_space
                            self.time_created.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-creation"):
                            self.time_elapsed_creation = value
                            self.time_elapsed_creation.value_namespace = name_space
                            self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-changed"):
                            self.time_elapsed_status_changed = value
                            self.time_elapsed_status_changed.value_namespace = name_space
                            self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-down"):
                            self.time_elapsed_status_down = value
                            self.time_elapsed_status_down.value_namespace = name_space
                            self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "transport-lsp-down"):
                            self.transport_lsp_down = value
                            self.transport_lsp_down.value_namespace = name_space
                            self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-id"):
                            self.xconnect_id = value
                            self.xconnect_id.value_namespace = name_space
                            self.xconnect_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.segment_type.is_set or
                        (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                        (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.segment_type.yfilter != YFilter.not_set or
                        (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                        (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "segment1" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.segment_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "attachment-circuit"):
                        if (self.attachment_circuit is None):
                            self.attachment_circuit = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        return self.attachment_circuit

                    if (child_yang_name == "pseudo-wire"):
                        if (self.pseudo_wire is None):
                            self.pseudo_wire = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        return self.pseudo_wire

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "segment-type"):
                        self.segment_type = value
                        self.segment_type.value_namespace = name_space
                        self.segment_type.value_namespace_prefix = name_space_prefix


            class Segment2(Entity):
                """
                Segment 2
                
                .. attribute:: attachment_circuit
                
                	Attachment Circuit
                	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                
                .. attribute:: pseudo_wire
                
                	Pseudowire
                	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire>`
                
                .. attribute:: segment_type
                
                	SegmentType
                	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Xconnects.Xconnect.Segment2, self).__init__()

                    self.yang_name = "segment2"
                    self.yang_parent_name = "xconnect"

                    self.segment_type = YLeaf(YType.enumeration, "segment-type")

                    self.attachment_circuit = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                    self.attachment_circuit.parent = self
                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                    self._children_yang_names.add("attachment-circuit")

                    self.pseudo_wire = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire()
                    self.pseudo_wire.parent = self
                    self._children_name_map["pseudo_wire"] = "pseudo-wire"
                    self._children_yang_names.add("pseudo-wire")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("segment_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Xconnects.Xconnect.Segment2, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Xconnects.Xconnect.Segment2, self).__setattr__(name, value)


                class AttachmentCircuit(Entity):
                    """
                    Attachment Circuit
                    
                    .. attribute:: bvi_mac_conflict
                    
                    	BVI Mac Conflict
                    	**type**\:  bool
                    
                    .. attribute:: bvi_no_port_up
                    
                    	BVI no BP Up
                    	**type**\:  bool
                    
                    .. attribute:: control_word_mismatched
                    
                    	Control word mismatched
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_error
                    
                    	Encapsulation Error
                    	**type**\:  str
                    
                    .. attribute:: encapsulation_mismatched
                    
                    	Encapsulation mismatched
                    	**type**\:  bool
                    
                    .. attribute:: evpn_internal_label
                    
                    	EVPN Internal Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interface
                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                    
                    .. attribute:: interface_handle
                    
                    	Interface Handler
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: internal_ms_ti
                    
                    	Internal MSTi
                    	**type**\:  str
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                    
                    .. attribute:: is_ac_partially_programmed
                    
                    	Is attachment\-circuit partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: l2vpn_protection
                    
                    	Protection object used for this segment
                    	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection>`
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: ms_ti_mismatch
                    
                    	MSTi mismatch
                    	**type**\:  bool
                    
                    .. attribute:: msti
                    
                    	MSTi
                    	**type**\:  str
                    
                    .. attribute:: msti_mismatch_down
                    
                    	Oper down due to MSTI mismatch
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Node ID
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_id
                    
                    	Redundancy Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_state
                    
                    	Redundancy Group State
                    	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                    
                    .. attribute:: redundancy_object_id
                    
                    	Redundancy Object ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                    
                    .. attribute:: tdm_media_mismatched
                    
                    	TDM media parms mismatched
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__init__()

                        self.yang_name = "attachment-circuit"
                        self.yang_parent_name = "segment2"

                        self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                        self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                        self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                        self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                        self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                        self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                        self.interface_handle = YLeaf(YType.str, "interface-handle")

                        self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                        self.interworking = YLeaf(YType.enumeration, "interworking")

                        self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                        self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                        self.msti = YLeaf(YType.str, "msti")

                        self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                        self.node_id = YLeaf(YType.str, "node-id")

                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                        self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                        self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                        self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                        self.interface = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._children_yang_names.add("interface")

                        self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                        self.l2vpn_protection.parent = self
                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                        self._children_yang_names.add("l2vpn-protection")

                        self.statistics = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bvi_mac_conflict",
                                        "bvi_no_port_up",
                                        "control_word_mismatched",
                                        "encapsulation_error",
                                        "encapsulation_mismatched",
                                        "evpn_internal_label",
                                        "interface_handle",
                                        "internal_ms_ti",
                                        "interworking",
                                        "is_ac_partially_programmed",
                                        "mac_limit_oper_down",
                                        "ms_ti_mismatch",
                                        "msti",
                                        "msti_mismatch_down",
                                        "mtu_mismatched",
                                        "node_id",
                                        "out_of_memory_state",
                                        "redundancy_group_id",
                                        "redundancy_group_state",
                                        "redundancy_object_id",
                                        "state",
                                        "tdm_media_mismatched",
                                        "xconnect_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "attachment-circuit"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "attachment-circuit"

                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                            self._children_yang_names.add("dispostion-stats")

                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self._children_name_map["impostion_stats"] = "impostion-stats"
                            self._children_yang_names.add("impostion-stats")

                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                            self.sequence_number.parent = self
                            self._children_name_map["sequence_number"] = "sequence-number"
                            self._children_yang_names.add("sequence-number")


                        class ImpostionStats(Entity):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                self.yang_name = "impostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self._children_name_map["broadcast"] = "broadcast"
                                self._children_yang_names.add("broadcast")

                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                self._children_yang_names.add("imposition-mtu-drop")

                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                self._children_yang_names.add("imposition-stat")

                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                self._children_yang_names.add("impostion-tail-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                self._children_yang_names.add("l2fsbi-drop")

                                self.multicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                                self._children_yang_names.add("multicast")

                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self
                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                self._children_yang_names.add("unknown-unicast")


                            class ImpositionStat(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                    self.yang_name = "imposition-stat"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpositionMtuDrop(Entity):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                    self.yang_name = "imposition-mtu-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpostionTailDrop(Entity):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                    self.yang_name = "impostion-tail-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class L2FsbiDrop(Entity):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                    self.yang_name = "l2fsbi-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fsbi-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Multicast(Entity):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Broadcast(Entity):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                    self.yang_name = "broadcast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnknownUnicast(Entity):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                    self.yang_name = "unknown-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unknown-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                    (self.multicast is not None and self.multicast.has_data()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                    (self.multicast is not None and self.multicast.has_operation()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "impostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast"):
                                    if (self.broadcast is None):
                                        self.broadcast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                    return self.broadcast

                                if (child_yang_name == "imposition-mtu-drop"):
                                    if (self.imposition_mtu_drop is None):
                                        self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    return self.imposition_mtu_drop

                                if (child_yang_name == "imposition-stat"):
                                    if (self.imposition_stat is None):
                                        self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                    return self.imposition_stat

                                if (child_yang_name == "impostion-tail-drop"):
                                    if (self.impostion_tail_drop is None):
                                        self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    return self.impostion_tail_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "l2fsbi-drop"):
                                    if (self.l2fsbi_drop is None):
                                        self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    return self.l2fsbi_drop

                                if (child_yang_name == "multicast"):
                                    if (self.multicast is None):
                                        self.multicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                    return self.multicast

                                if (child_yang_name == "unknown-unicast"):
                                    if (self.unknown_unicast is None):
                                        self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    return self.unknown_unicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DispostionStats(Entity):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                self.yang_name = "dispostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                self._children_yang_names.add("broadcast-drop")

                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self._children_name_map["dai_drop"] = "dai-drop"
                                self._children_yang_names.add("dai-drop")

                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                self._children_yang_names.add("disposition-mtu-drop")

                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                self._children_yang_names.add("disposition-oo-o-drops")

                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                self._children_yang_names.add("disposition-p2mp-stats")

                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                self._children_yang_names.add("disposition-stat")

                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                self._children_yang_names.add("disposition-tail-drop")

                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                self._children_yang_names.add("ipsg-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.mac_move = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self._children_name_map["mac_move"] = "mac-move"
                                self._children_yang_names.add("mac-move")

                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                self._children_yang_names.add("multicast-drop")

                                self.received_drops = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self._children_name_map["received_drops"] = "received-drops"
                                self._children_yang_names.add("received-drops")

                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self
                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                self._children_yang_names.add("unicast-drop")


                            class DispositionStat(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                    self.yang_name = "disposition-stat"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionMtuDrop(Entity):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                    self.yang_name = "disposition-mtu-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionTailDrop(Entity):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                    self.yang_name = "disposition-tail-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MulticastDrop(Entity):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                    self.yang_name = "multicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnicastDrop(Entity):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                    self.yang_name = "unicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class BroadcastDrop(Entity):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                    self.yang_name = "broadcast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ReceivedDrops(Entity):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                    self.yang_name = "received-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DaiDrop(Entity):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                    self.yang_name = "dai-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dai-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class IpsgDrop(Entity):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                    self.yang_name = "ipsg-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipsg-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionOoODrops(Entity):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                    self.yang_name = "disposition-oo-o-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionP2MpStats(Entity):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                    self.yang_name = "disposition-p2mp-stats"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MacMove(Entity):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                    self.yang_name = "mac-move"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-move" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dispostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast-drop"):
                                    if (self.broadcast_drop is None):
                                        self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    return self.broadcast_drop

                                if (child_yang_name == "dai-drop"):
                                    if (self.dai_drop is None):
                                        self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                    return self.dai_drop

                                if (child_yang_name == "disposition-mtu-drop"):
                                    if (self.disposition_mtu_drop is None):
                                        self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    return self.disposition_mtu_drop

                                if (child_yang_name == "disposition-oo-o-drops"):
                                    if (self.disposition_oo_o_drops is None):
                                        self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    return self.disposition_oo_o_drops

                                if (child_yang_name == "disposition-p2mp-stats"):
                                    if (self.disposition_p2mp_stats is None):
                                        self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    return self.disposition_p2mp_stats

                                if (child_yang_name == "disposition-stat"):
                                    if (self.disposition_stat is None):
                                        self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                    return self.disposition_stat

                                if (child_yang_name == "disposition-tail-drop"):
                                    if (self.disposition_tail_drop is None):
                                        self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    return self.disposition_tail_drop

                                if (child_yang_name == "ipsg-drop"):
                                    if (self.ipsg_drop is None):
                                        self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    return self.ipsg_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "mac-move"):
                                    if (self.mac_move is None):
                                        self.mac_move = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                    return self.mac_move

                                if (child_yang_name == "multicast-drop"):
                                    if (self.multicast_drop is None):
                                        self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                    return self.multicast_drop

                                if (child_yang_name == "received-drops"):
                                    if (self.received_drops is None):
                                        self.received_drops = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                    return self.received_drops

                                if (child_yang_name == "unicast-drop"):
                                    if (self.unicast_drop is None):
                                        self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                    return self.unicast_drop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SequenceNumber(Entity):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                self.yang_name = "sequence-number"
                                self.yang_parent_name = "statistics"

                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bypassed_inbound_sequence_packet",
                                                "bypassed_out_sequence_packet",
                                                "sequence_number_expected",
                                                "sequence_number_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bypassed_inbound_sequence_packet.is_set or
                                    self.bypassed_out_sequence_packet.is_set or
                                    self.sequence_number_expected.is_set or
                                    self.sequence_number_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sequence-number" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bypassed-inbound-sequence-packet"):
                                    self.bypassed_inbound_sequence_packet = value
                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "bypassed-out-sequence-packet"):
                                    self.bypassed_out_sequence_packet = value
                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-expected"):
                                    self.sequence_number_expected = value
                                    self.sequence_number_expected.value_namespace = name_space
                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-sent"):
                                    self.sequence_number_sent = value
                                    self.sequence_number_sent.value_namespace = name_space
                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                (self.sequence_number is not None and self.sequence_number.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dispostion-stats"):
                                if (self.dispostion_stats is None):
                                    self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                return self.dispostion_stats

                            if (child_yang_name == "impostion-stats"):
                                if (self.impostion_stats is None):
                                    self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                return self.impostion_stats

                            if (child_yang_name == "sequence-number"):
                                if (self.sequence_number is None):
                                    self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                return self.sequence_number

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class L2VpnProtection(Entity):
                        """
                        Protection object used for this segment
                        
                        .. attribute:: active
                        
                        	Active
                        	**type**\:  bool
                        
                        .. attribute:: protected_name
                        
                        	Name of the protected segment
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_configured
                        
                        	Protection configured
                        	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                        
                        .. attribute:: protection_name
                        
                        	Name of the segment acting as backup
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_type
                        
                        	Type of the protection
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__init__()

                            self.yang_name = "l2vpn-protection"
                            self.yang_parent_name = "attachment-circuit"

                            self.active = YLeaf(YType.boolean, "active")

                            self.protected_name = YLeaf(YType.str, "protected-name")

                            self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                            self.protection_name = YLeaf(YType.str, "protection-name")

                            self.protection_type = YLeaf(YType.enumeration, "protection-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active",
                                            "protected_name",
                                            "protection_configured",
                                            "protection_name",
                                            "protection_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active.is_set or
                                self.protected_name.is_set or
                                self.protection_configured.is_set or
                                self.protection_name.is_set or
                                self.protection_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active.yfilter != YFilter.not_set or
                                self.protected_name.yfilter != YFilter.not_set or
                                self.protection_configured.yfilter != YFilter.not_set or
                                self.protection_name.yfilter != YFilter.not_set or
                                self.protection_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2vpn-protection" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active.get_name_leafdata())
                            if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protected_name.get_name_leafdata())
                            if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_configured.get_name_leafdata())
                            if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_name.get_name_leafdata())
                            if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active"):
                                self.active = value
                                self.active.value_namespace = name_space
                                self.active.value_namespace_prefix = name_space_prefix
                            if(value_path == "protected-name"):
                                self.protected_name = value
                                self.protected_name.value_namespace = name_space
                                self.protected_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-configured"):
                                self.protection_configured = value
                                self.protection_configured.value_namespace = name_space
                                self.protection_configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-name"):
                                self.protection_name = value
                                self.protection_name.value_namespace = name_space
                                self.protection_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-type"):
                                self.protection_type = value
                                self.protection_type.value_namespace = name_space
                                self.protection_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bvi_mac_conflict.is_set or
                            self.bvi_no_port_up.is_set or
                            self.control_word_mismatched.is_set or
                            self.encapsulation_error.is_set or
                            self.encapsulation_mismatched.is_set or
                            self.evpn_internal_label.is_set or
                            self.interface_handle.is_set or
                            self.internal_ms_ti.is_set or
                            self.interworking.is_set or
                            self.is_ac_partially_programmed.is_set or
                            self.mac_limit_oper_down.is_set or
                            self.ms_ti_mismatch.is_set or
                            self.msti.is_set or
                            self.msti_mismatch_down.is_set or
                            self.mtu_mismatched.is_set or
                            self.node_id.is_set or
                            self.out_of_memory_state.is_set or
                            self.redundancy_group_id.is_set or
                            self.redundancy_group_state.is_set or
                            self.redundancy_object_id.is_set or
                            self.state.is_set or
                            self.tdm_media_mismatched.is_set or
                            self.xconnect_id.is_set or
                            (self.interface is not None and self.interface.has_data()) or
                            (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bvi_mac_conflict.yfilter != YFilter.not_set or
                            self.bvi_no_port_up.yfilter != YFilter.not_set or
                            self.control_word_mismatched.yfilter != YFilter.not_set or
                            self.encapsulation_error.yfilter != YFilter.not_set or
                            self.encapsulation_mismatched.yfilter != YFilter.not_set or
                            self.evpn_internal_label.yfilter != YFilter.not_set or
                            self.interface_handle.yfilter != YFilter.not_set or
                            self.internal_ms_ti.yfilter != YFilter.not_set or
                            self.interworking.yfilter != YFilter.not_set or
                            self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                            self.ms_ti_mismatch.yfilter != YFilter.not_set or
                            self.msti.yfilter != YFilter.not_set or
                            self.msti_mismatch_down.yfilter != YFilter.not_set or
                            self.mtu_mismatched.yfilter != YFilter.not_set or
                            self.node_id.yfilter != YFilter.not_set or
                            self.out_of_memory_state.yfilter != YFilter.not_set or
                            self.redundancy_group_id.yfilter != YFilter.not_set or
                            self.redundancy_group_state.yfilter != YFilter.not_set or
                            self.redundancy_object_id.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.tdm_media_mismatched.yfilter != YFilter.not_set or
                            self.xconnect_id.yfilter != YFilter.not_set or
                            (self.interface is not None and self.interface.has_operation()) or
                            (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "attachment-circuit" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                        if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                        if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                        if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                        if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                        if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                        if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_handle.get_name_leafdata())
                        if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interworking.get_name_leafdata())
                        if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                        if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti.get_name_leafdata())
                        if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                        if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_id.get_name_leafdata())
                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                        if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                        if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                        if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            if (self.interface is None):
                                self.interface = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                            return self.interface

                        if (child_yang_name == "l2vpn-protection"):
                            if (self.l2vpn_protection is None):
                                self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            return self.l2vpn_protection

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bvi-mac-conflict"):
                            self.bvi_mac_conflict = value
                            self.bvi_mac_conflict.value_namespace = name_space
                            self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                        if(value_path == "bvi-no-port-up"):
                            self.bvi_no_port_up = value
                            self.bvi_no_port_up.value_namespace = name_space
                            self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "control-word-mismatched"):
                            self.control_word_mismatched = value
                            self.control_word_mismatched.value_namespace = name_space
                            self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "encapsulation-error"):
                            self.encapsulation_error = value
                            self.encapsulation_error.value_namespace = name_space
                            self.encapsulation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "encapsulation-mismatched"):
                            self.encapsulation_mismatched = value
                            self.encapsulation_mismatched.value_namespace = name_space
                            self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-internal-label"):
                            self.evpn_internal_label = value
                            self.evpn_internal_label.value_namespace = name_space
                            self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-handle"):
                            self.interface_handle = value
                            self.interface_handle.value_namespace = name_space
                            self.interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "internal-ms-ti"):
                            self.internal_ms_ti = value
                            self.internal_ms_ti.value_namespace = name_space
                            self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                        if(value_path == "interworking"):
                            self.interworking = value
                            self.interworking.value_namespace = name_space
                            self.interworking.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ac-partially-programmed"):
                            self.is_ac_partially_programmed = value
                            self.is_ac_partially_programmed.value_namespace = name_space
                            self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-oper-down"):
                            self.mac_limit_oper_down = value
                            self.mac_limit_oper_down.value_namespace = name_space
                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "ms-ti-mismatch"):
                            self.ms_ti_mismatch = value
                            self.ms_ti_mismatch.value_namespace = name_space
                            self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti"):
                            self.msti = value
                            self.msti.value_namespace = name_space
                            self.msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-mismatch-down"):
                            self.msti_mismatch_down = value
                            self.msti_mismatch_down.value_namespace = name_space
                            self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-mismatched"):
                            self.mtu_mismatched = value
                            self.mtu_mismatched.value_namespace = name_space
                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-id"):
                            self.node_id = value
                            self.node_id.value_namespace = name_space
                            self.node_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-of-memory-state"):
                            self.out_of_memory_state = value
                            self.out_of_memory_state.value_namespace = name_space
                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-group-id"):
                            self.redundancy_group_id = value
                            self.redundancy_group_id.value_namespace = name_space
                            self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-group-state"):
                            self.redundancy_group_state = value
                            self.redundancy_group_state.value_namespace = name_space
                            self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-object-id"):
                            self.redundancy_object_id = value
                            self.redundancy_object_id.value_namespace = name_space
                            self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "tdm-media-mismatched"):
                            self.tdm_media_mismatched = value
                            self.tdm_media_mismatched.value_namespace = name_space
                            self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-id"):
                            self.xconnect_id = value
                            self.xconnect_id.value_namespace = name_space
                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                class PseudoWire(Entity):
                    """
                    Pseudowire
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_remote_down
                    
                    	Auto\-Discovered PW remote state down
                    	**type**\:  bool
                    
                    .. attribute:: admited_bw
                    
                    	Admited Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: auto_discovery
                    
                    	Is autodiscovery
                    	**type**\:  bool
                    
                    .. attribute:: backup_active
                    
                    	TRUE if backup is active
                    	**type**\:  bool
                    
                    .. attribute:: backup_force_active
                    
                    	TRUE if backup is active due to switchover
                    	**type**\:  bool
                    
                    .. attribute:: backup_pw
                    
                    	TRUE if PW is a backup PW
                    	**type**\:  bool
                    
                    .. attribute:: bitrate_mismatched
                    
                    	Bitrate mismatched
                    	**type**\:  bool
                    
                    .. attribute:: bridge_pw_type_mismatch
                    
                    	Oper down because Bridge has mismatched PW Types
                    	**type**\:  bool
                    
                    .. attribute:: cas_mismatched
                    
                    	CAS mismatched
                    	**type**\:  bool
                    
                    .. attribute:: diff_ts_mismatched
                    
                    	Differential timestamp mismatched
                    	**type**\:  bool
                    
                    .. attribute:: disable_delay
                    
                    	Backup disable delay
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                    
                    .. attribute:: evpn_src_acid
                    
                    	EVPN VPWS Source AC ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fe_ctype
                    
                    	Pseudowire FEC type
                    	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                    
                    .. attribute:: forward_class
                    
                    	Forward Class attribute
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: freq_mismatched
                    
                    	Frequency mismatched
                    	**type**\:  bool
                    
                    .. attribute:: illegal_control_word
                    
                    	Illegal control word
                    	**type**\:  bool
                    
                    .. attribute:: imposed_vlan_id
                    
                    	Imposed vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                    
                    .. attribute:: ipv6_local_source_address
                    
                    	Local IPv6 Source Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_evpnvpws_type
                    
                    	is EVPN VPWS
                    	**type**\:  bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: is_multi_segment_pseudowire
                    
                    	Is Multi\-Segment Pseudowire
                    	**type**\:  bool
                    
                    .. attribute:: is_partially_programmed
                    
                    	Is Pseudowire partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_pwr_type
                    
                    	is Pseudowire\-routed
                    	**type**\:  bool
                    
                    .. attribute:: is_vfi
                    
                    	Is VFI interface
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the pseudowire status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_down
                    
                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: ldp_label_advertise_failed
                    
                    	LDP label advertisment failed
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                    
                    .. attribute:: local_control_word
                    
                    	Local control word
                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                    
                    .. attribute:: local_label_failed
                    
                    	Failed to set BGP advertised local label
                    	**type**\:  bool
                    
                    .. attribute:: local_pseudo_wire_type
                    
                    	Local pseudowire type
                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                    
                    .. attribute:: local_signalling
                    
                    	Local signalling
                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                    
                    .. attribute:: local_source_address
                    
                    	Local Source Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_qinq
                    
                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                    	**type**\:  bool
                    
                    .. attribute:: num_ma_cwithdraw_msg_received
                    
                    	Num MW messages received over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ma_cwithdraw_message_sent
                    
                    	Num MW messages sent over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_pw
                    
                    	P2MP Pseudowire Information
                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw>`
                    
                    .. attribute:: payload_bytes_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: payload_type_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: peer_id
                    
                    	Peer
                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	Prefpath fallback enable/disable
                    	**type**\:  bool
                    
                    .. attribute:: primary_peer_id
                    
                    	Primary Peer IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: primary_pseudo_wire_id
                    
                    	Primary Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: primary_pw
                    
                    	TRUE if PW is a primary PW
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                    
                    .. attribute:: pseudo_wire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: pseudo_wire_state
                    
                    	Pseudowire state
                    	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                    
                    .. attribute:: pseudo_wire_type_mismatched
                    
                    	Pseudowire type mismatched
                    	**type**\:  bool
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type
                    
                    	Negotiated pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label Type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: pw_redundancy_initial_delay
                    
                    	Initial delay for redundant PW in seconds
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    .. attribute:: pw_redundancy_one_way
                    
                    	Force one\-way PW redundancy behaviour in Redundancy Group
                    	**type**\:  bool
                    
                    .. attribute:: pw_status_use
                    
                    	PW status in use
                    	**type**\:  bool
                    
                    .. attribute:: pwlsd_rewrite_failed
                    
                    	LSD rewrite failed
                    	**type**\:  bool
                    
                    .. attribute:: remote_control_word
                    
                    	Remote control word
                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                    
                    .. attribute:: remote_interface
                    
                    	Remote interface
                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                    
                    .. attribute:: remote_label_failed
                    
                    	Failed to set BGP advertised remote label
                    	**type**\:  bool
                    
                    .. attribute:: remote_pseudo_wire_type
                    
                    	Remote pseudowire type
                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                    
                    .. attribute:: remote_signalling
                    
                    	Remote signalling
                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                    
                    .. attribute:: required_bw
                    
                    	Required Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rtp_mismatched
                    
                    	RTP mismatched
                    	**type**\:  bool
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: sig_pkts_mismatched
                    
                    	Signalling packets mismatched
                    	**type**\:  bool
                    
                    .. attribute:: ssrc_mismatched
                    
                    	SSRC mismatched
                    	**type**\:  bool
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                    
                    .. attribute:: table_policy_name
                    
                    	Table\-policy Name
                    	**type**\:  str
                    
                    .. attribute:: tag_rewrite
                    
                    	StaticTagRewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: time_created
                    
                    	Time when the pseudowire was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_down
                    
                    	Time elapsed since last status down in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: transport_lsp_down
                    
                    	Oper down due to Transport LSP down
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire, self).__init__()

                        self.yang_name = "pseudo-wire"
                        self.yang_parent_name = "segment2"

                        self.ad_method = YLeaf(YType.uint32, "ad-method")

                        self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                        self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                        self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                        self.backup_active = YLeaf(YType.boolean, "backup-active")

                        self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                        self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                        self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                        self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                        self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                        self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                        self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                        self.disable_never = YLeaf(YType.boolean, "disable-never")

                        self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                        self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                        self.forward_class = YLeaf(YType.uint8, "forward-class")

                        self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                        self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                        self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                        self.interworking = YLeaf(YType.enumeration, "interworking")

                        self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                        self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                        self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                        self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                        self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                        self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                        self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                        self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                        self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                        self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                        self.load_balance = YLeaf(YType.enumeration, "load-balance")

                        self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                        self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                        self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                        self.local_source_address = YLeaf(YType.str, "local-source-address")

                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                        self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                        self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                        self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                        self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                        self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                        self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                        self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                        self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                        self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                        self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                        self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                        self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                        self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                        self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                        self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                        self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                        self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                        self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                        self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                        self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                        self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                        self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                        self.required_bw = YLeaf(YType.uint32, "required-bw")

                        self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                        self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                        self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                        self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                        self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                        self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                        self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                        self.time_created = YLeaf(YType.str, "time-created")

                        self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                        self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                        self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                        self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                        self.encapsulation_info = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                        self._children_yang_names.add("encapsulation-info")

                        self.local_interface = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                        self.local_interface.parent = self
                        self._children_name_map["local_interface"] = "local-interface"
                        self._children_yang_names.add("local-interface")

                        self.local_signalling = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                        self.local_signalling.parent = self
                        self._children_name_map["local_signalling"] = "local-signalling"
                        self._children_yang_names.add("local-signalling")

                        self.p2mp_pw = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                        self.p2mp_pw.parent = self
                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                        self._children_yang_names.add("p2mp-pw")

                        self.peer_id = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                        self.peer_id.parent = self
                        self._children_name_map["peer_id"] = "peer-id"
                        self._children_yang_names.add("peer-id")

                        self.preferred_path = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                        self.preferred_path.parent = self
                        self._children_name_map["preferred_path"] = "preferred-path"
                        self._children_yang_names.add("preferred-path")

                        self.remote_interface = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                        self.remote_interface.parent = self
                        self._children_name_map["remote_interface"] = "remote-interface"
                        self._children_yang_names.add("remote-interface")

                        self.remote_signalling = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                        self.remote_signalling.parent = self
                        self._children_name_map["remote_signalling"] = "remote-signalling"
                        self._children_yang_names.add("remote-signalling")

                        self.statistics = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ad_method",
                                        "ad_remote_down",
                                        "admited_bw",
                                        "auto_discovery",
                                        "backup_active",
                                        "backup_force_active",
                                        "backup_pw",
                                        "bitrate_mismatched",
                                        "bridge_pw_type_mismatch",
                                        "cas_mismatched",
                                        "diff_ts_mismatched",
                                        "disable_delay",
                                        "disable_never",
                                        "evpn_src_acid",
                                        "fe_ctype",
                                        "forward_class",
                                        "freq_mismatched",
                                        "illegal_control_word",
                                        "imposed_vlan_id",
                                        "interworking",
                                        "ipv6_local_source_address",
                                        "is_evpnvpws_type",
                                        "is_flow_label_static",
                                        "is_multi_segment_pseudowire",
                                        "is_partially_programmed",
                                        "is_pwr_type",
                                        "is_vfi",
                                        "last_time_status_changed",
                                        "last_time_status_down",
                                        "ldp_label_advertise_failed",
                                        "load_balance",
                                        "local_control_word",
                                        "local_label_failed",
                                        "local_pseudo_wire_type",
                                        "local_source_address",
                                        "mac_limit_oper_down",
                                        "mtu_mismatched",
                                        "not_supported_qinq",
                                        "num_ma_cwithdraw_msg_received",
                                        "number_ma_cwithdraw_message_sent",
                                        "out_of_memory_state",
                                        "payload_bytes_mismatched",
                                        "payload_type_mismatched",
                                        "preferred_path_disable_fallback",
                                        "primary_peer_id",
                                        "primary_pseudo_wire_id",
                                        "primary_pw",
                                        "protocol",
                                        "pseudo_wire_id",
                                        "pseudo_wire_state",
                                        "pseudo_wire_type_mismatched",
                                        "pw_class_name",
                                        "pw_flow_label_code17_disabled",
                                        "pw_flow_label_type",
                                        "pw_flow_label_type_cfg",
                                        "pw_redundancy_initial_delay",
                                        "pw_redundancy_one_way",
                                        "pw_status_use",
                                        "pwlsd_rewrite_failed",
                                        "remote_control_word",
                                        "remote_label_failed",
                                        "remote_pseudo_wire_type",
                                        "required_bw",
                                        "resync_enabled",
                                        "resync_threshold",
                                        "rtp_mismatched",
                                        "sequencing_type",
                                        "shutdown",
                                        "sig_pkts_mismatched",
                                        "ssrc_mismatched",
                                        "state",
                                        "table_policy_name",
                                        "tag_rewrite",
                                        "time_created",
                                        "time_elapsed_creation",
                                        "time_elapsed_status_changed",
                                        "time_elapsed_status_down",
                                        "transport_lsp_down",
                                        "xconnect_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire, self).__setattr__(name, value)


                    class PeerId(Entity):
                        """
                        Peer
                        
                        .. attribute:: internal_label
                        
                        	Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_peer_id
                        
                        	Peer IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_peer_id
                        
                        	Peer IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: type
                        
                        	type
                        	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__init__()

                            self.yang_name = "peer-id"
                            self.yang_parent_name = "pseudo-wire"

                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                            self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                            self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                            self.type = YLeaf(YType.enumeration, "type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("internal_label",
                                            "ipv4_peer_id",
                                            "ipv6_peer_id",
                                            "type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.internal_label.is_set or
                                self.ipv4_peer_id.is_set or
                                self.ipv6_peer_id.is_set or
                                self.type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.internal_label.yfilter != YFilter.not_set or
                                self.ipv4_peer_id.yfilter != YFilter.not_set or
                                self.ipv6_peer_id.yfilter != YFilter.not_set or
                                self.type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "peer-id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                            if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                            if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "internal-label"):
                                self.internal_label = value
                                self.internal_label.value_namespace = name_space
                                self.internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-peer-id"):
                                self.ipv4_peer_id = value
                                self.ipv4_peer_id.value_namespace = name_space
                                self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-peer-id"):
                                self.ipv6_peer_id = value
                                self.ipv6_peer_id.value_namespace = name_space
                                self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "type"):
                                self.type = value
                                self.type.value_namespace = name_space
                                self.type.value_namespace_prefix = name_space_prefix


                    class EncapsulationInfo(Entity):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: atom
                        
                        	atom
                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__init__()

                            self.yang_name = "encapsulation-info"
                            self.yang_parent_name = "pseudo-wire"

                            self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                            self.atom = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                            self.atom.parent = self
                            self._children_name_map["atom"] = "atom"
                            self._children_yang_names.add("atom")

                            self.l2tpv3 = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self
                            self._children_name_map["l2tpv3"] = "l2tpv3"
                            self._children_yang_names.add("l2tpv3")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("encapsulation") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                        class Atom(Entity):
                            """
                            atom
                            
                            .. attribute:: is_pseudowire_headend
                            
                            	Is this connected to a PW\-HE AC
                            	**type**\:  bool
                            
                            .. attribute:: is_sai_itype2
                            
                            	Is SAII FEC129 Type 2
                            	**type**\:  bool
                            
                            .. attribute:: is_tai_itype2
                            
                            	Is TAII type 2
                            	**type**\:  bool
                            
                            .. attribute:: ldp_label_advertisment_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: local_agi
                            
                            	Local Attachment Group Identifier
                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                            
                            .. attribute:: local_c_ctype
                            
                            	Local VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_ceid
                            
                            	Local CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cv_type
                            
                            	Local VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_group_id
                            
                            	Local group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ldp_id
                            
                            	Local LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_saii_gbl_id
                            
                            	Local SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_saiiac_id
                            
                            	Local SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taii_gbl_id
                            
                            	Local TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taiiac_id
                            
                            	Local TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_veid
                            
                            	Local VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: multi_segment_pseudowire_stats
                            
                            	Multisegment pseudowire statistics
                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                            
                            .. attribute:: rem_saii
                            
                            	Remote Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_saii_gbl_id
                            
                            	Remote SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_saiiac_id
                            
                            	Remote SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taii
                            
                            	Remote Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_taii_gbl_id
                            
                            	Remote TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taiiac_id
                            
                            	Remote TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_agi
                            
                            	Remote Attachment Group Identifier
                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                            
                            .. attribute:: remote_c_ctype
                            
                            	Remote VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_ceid
                            
                            	Remote CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cv_type
                            
                            	Remote VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_group_id
                            
                            	Remote group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_label
                            
                            	Remote label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ldp_id
                            
                            	Remote LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_source_address
                            
                            	Remote BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_veid
                            
                            	Remote VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_address
                            
                            	Local BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                self.yang_name = "atom"
                                self.yang_parent_name = "encapsulation-info"

                                self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                self.local_veid = YLeaf(YType.uint32, "local-veid")

                                self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                self.rem_saii = YLeaf(YType.str, "rem-saii")

                                self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                self.rem_taii = YLeaf(YType.str, "rem-taii")

                                self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                self.saii = YLeaf(YType.str, "saii")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.taii = YLeaf(YType.str, "taii")

                                self.local_agi = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                self.local_agi.parent = self
                                self._children_name_map["local_agi"] = "local-agi"
                                self._children_yang_names.add("local-agi")

                                self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                self.multi_segment_pseudowire_stats.parent = self
                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                self._children_yang_names.add("multi-segment-pseudowire-stats")

                                self.remote_agi = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                self.remote_agi.parent = self
                                self._children_name_map["remote_agi"] = "remote-agi"
                                self._children_yang_names.add("remote-agi")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_pseudowire_headend",
                                                "is_sai_itype2",
                                                "is_tai_itype2",
                                                "ldp_label_advertisment_failed",
                                                "local_c_ctype",
                                                "local_ceid",
                                                "local_cv_type",
                                                "local_group_id",
                                                "local_label",
                                                "local_ldp_id",
                                                "local_saii_gbl_id",
                                                "local_saiiac_id",
                                                "local_taii_gbl_id",
                                                "local_taiiac_id",
                                                "local_veid",
                                                "lsd_rewrite_failed",
                                                "rem_saii",
                                                "rem_saii_gbl_id",
                                                "rem_saiiac_id",
                                                "rem_taii",
                                                "rem_taii_gbl_id",
                                                "rem_taiiac_id",
                                                "remote_c_ctype",
                                                "remote_ceid",
                                                "remote_cv_type",
                                                "remote_group_id",
                                                "remote_label",
                                                "remote_ldp_id",
                                                "remote_source_address",
                                                "remote_veid",
                                                "saii",
                                                "source_address",
                                                "taii") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                            class LocalAgi(Entity):
                                """
                                Local Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                    self.yang_name = "local-agi"
                                    self.yang_parent_name = "atom"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "local-agi"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "local-agi"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "local-agi"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-agi" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class RemoteAgi(Entity):
                                """
                                Remote Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                    self.yang_name = "remote-agi"
                                    self.yang_parent_name = "atom"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "remote-agi"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "remote-agi"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "remote-agi"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-agi" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class MultiSegmentPseudowireStats(Entity):
                                """
                                Multisegment pseudowire statistics
                                
                                .. attribute:: received_bytes
                                
                                	Bytes received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: received_packets
                                
                                	Packets received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                    self.yang_name = "multi-segment-pseudowire-stats"
                                    self.yang_parent_name = "atom"

                                    self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                    self.received_packets = YLeaf(YType.uint64, "received-packets")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("received_bytes",
                                                    "received_packets") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.received_bytes.is_set or
                                        self.received_packets.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.received_bytes.yfilter != YFilter.not_set or
                                        self.received_packets.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                    if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_packets.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-bytes" or name == "received-packets"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "received-bytes"):
                                        self.received_bytes = value
                                        self.received_bytes.value_namespace = name_space
                                        self.received_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-packets"):
                                        self.received_packets = value
                                        self.received_packets.value_namespace = name_space
                                        self.received_packets.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.is_pseudowire_headend.is_set or
                                    self.is_sai_itype2.is_set or
                                    self.is_tai_itype2.is_set or
                                    self.ldp_label_advertisment_failed.is_set or
                                    self.local_c_ctype.is_set or
                                    self.local_ceid.is_set or
                                    self.local_cv_type.is_set or
                                    self.local_group_id.is_set or
                                    self.local_label.is_set or
                                    self.local_ldp_id.is_set or
                                    self.local_saii_gbl_id.is_set or
                                    self.local_saiiac_id.is_set or
                                    self.local_taii_gbl_id.is_set or
                                    self.local_taiiac_id.is_set or
                                    self.local_veid.is_set or
                                    self.lsd_rewrite_failed.is_set or
                                    self.rem_saii.is_set or
                                    self.rem_saii_gbl_id.is_set or
                                    self.rem_saiiac_id.is_set or
                                    self.rem_taii.is_set or
                                    self.rem_taii_gbl_id.is_set or
                                    self.rem_taiiac_id.is_set or
                                    self.remote_c_ctype.is_set or
                                    self.remote_ceid.is_set or
                                    self.remote_cv_type.is_set or
                                    self.remote_group_id.is_set or
                                    self.remote_label.is_set or
                                    self.remote_ldp_id.is_set or
                                    self.remote_source_address.is_set or
                                    self.remote_veid.is_set or
                                    self.saii.is_set or
                                    self.source_address.is_set or
                                    self.taii.is_set or
                                    (self.local_agi is not None and self.local_agi.has_data()) or
                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                    (self.remote_agi is not None and self.remote_agi.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                    self.is_sai_itype2.yfilter != YFilter.not_set or
                                    self.is_tai_itype2.yfilter != YFilter.not_set or
                                    self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                    self.local_c_ctype.yfilter != YFilter.not_set or
                                    self.local_ceid.yfilter != YFilter.not_set or
                                    self.local_cv_type.yfilter != YFilter.not_set or
                                    self.local_group_id.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_ldp_id.yfilter != YFilter.not_set or
                                    self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                    self.local_saiiac_id.yfilter != YFilter.not_set or
                                    self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                    self.local_taiiac_id.yfilter != YFilter.not_set or
                                    self.local_veid.yfilter != YFilter.not_set or
                                    self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.rem_saii.yfilter != YFilter.not_set or
                                    self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                    self.rem_saiiac_id.yfilter != YFilter.not_set or
                                    self.rem_taii.yfilter != YFilter.not_set or
                                    self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                    self.rem_taiiac_id.yfilter != YFilter.not_set or
                                    self.remote_c_ctype.yfilter != YFilter.not_set or
                                    self.remote_ceid.yfilter != YFilter.not_set or
                                    self.remote_cv_type.yfilter != YFilter.not_set or
                                    self.remote_group_id.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_ldp_id.yfilter != YFilter.not_set or
                                    self.remote_source_address.yfilter != YFilter.not_set or
                                    self.remote_veid.yfilter != YFilter.not_set or
                                    self.saii.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.taii.yfilter != YFilter.not_set or
                                    (self.local_agi is not None and self.local_agi.has_operation()) or
                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                    (self.remote_agi is not None and self.remote_agi.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "atom" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_veid.get_name_leafdata())
                                if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.saii.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.taii.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-agi"):
                                    if (self.local_agi is None):
                                        self.local_agi = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                    return self.local_agi

                                if (child_yang_name == "multi-segment-pseudowire-stats"):
                                    if (self.multi_segment_pseudowire_stats is None):
                                        self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    return self.multi_segment_pseudowire_stats

                                if (child_yang_name == "remote-agi"):
                                    if (self.remote_agi is None):
                                        self.remote_agi = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                    return self.remote_agi

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-pseudowire-headend"):
                                    self.is_pseudowire_headend = value
                                    self.is_pseudowire_headend.value_namespace = name_space
                                    self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-sai-itype2"):
                                    self.is_sai_itype2 = value
                                    self.is_sai_itype2.value_namespace = name_space
                                    self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-tai-itype2"):
                                    self.is_tai_itype2 = value
                                    self.is_tai_itype2.value_namespace = name_space
                                    self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertisment-failed"):
                                    self.ldp_label_advertisment_failed = value
                                    self.ldp_label_advertisment_failed.value_namespace = name_space
                                    self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-c-ctype"):
                                    self.local_c_ctype = value
                                    self.local_c_ctype.value_namespace = name_space
                                    self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ceid"):
                                    self.local_ceid = value
                                    self.local_ceid.value_namespace = name_space
                                    self.local_ceid.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cv-type"):
                                    self.local_cv_type = value
                                    self.local_cv_type.value_namespace = name_space
                                    self.local_cv_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-group-id"):
                                    self.local_group_id = value
                                    self.local_group_id.value_namespace = name_space
                                    self.local_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ldp-id"):
                                    self.local_ldp_id = value
                                    self.local_ldp_id.value_namespace = name_space
                                    self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-saii-gbl-id"):
                                    self.local_saii_gbl_id = value
                                    self.local_saii_gbl_id.value_namespace = name_space
                                    self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-saiiac-id"):
                                    self.local_saiiac_id = value
                                    self.local_saiiac_id.value_namespace = name_space
                                    self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-taii-gbl-id"):
                                    self.local_taii_gbl_id = value
                                    self.local_taii_gbl_id.value_namespace = name_space
                                    self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-taiiac-id"):
                                    self.local_taiiac_id = value
                                    self.local_taiiac_id.value_namespace = name_space
                                    self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-veid"):
                                    self.local_veid = value
                                    self.local_veid.value_namespace = name_space
                                    self.local_veid.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsd-rewrite-failed"):
                                    self.lsd_rewrite_failed = value
                                    self.lsd_rewrite_failed.value_namespace = name_space
                                    self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saii"):
                                    self.rem_saii = value
                                    self.rem_saii.value_namespace = name_space
                                    self.rem_saii.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saii-gbl-id"):
                                    self.rem_saii_gbl_id = value
                                    self.rem_saii_gbl_id.value_namespace = name_space
                                    self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saiiac-id"):
                                    self.rem_saiiac_id = value
                                    self.rem_saiiac_id.value_namespace = name_space
                                    self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taii"):
                                    self.rem_taii = value
                                    self.rem_taii.value_namespace = name_space
                                    self.rem_taii.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taii-gbl-id"):
                                    self.rem_taii_gbl_id = value
                                    self.rem_taii_gbl_id.value_namespace = name_space
                                    self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taiiac-id"):
                                    self.rem_taiiac_id = value
                                    self.rem_taiiac_id.value_namespace = name_space
                                    self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-c-ctype"):
                                    self.remote_c_ctype = value
                                    self.remote_c_ctype.value_namespace = name_space
                                    self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ceid"):
                                    self.remote_ceid = value
                                    self.remote_ceid.value_namespace = name_space
                                    self.remote_ceid.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cv-type"):
                                    self.remote_cv_type = value
                                    self.remote_cv_type.value_namespace = name_space
                                    self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-group-id"):
                                    self.remote_group_id = value
                                    self.remote_group_id.value_namespace = name_space
                                    self.remote_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ldp-id"):
                                    self.remote_ldp_id = value
                                    self.remote_ldp_id.value_namespace = name_space
                                    self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-source-address"):
                                    self.remote_source_address = value
                                    self.remote_source_address.value_namespace = name_space
                                    self.remote_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-veid"):
                                    self.remote_veid = value
                                    self.remote_veid.value_namespace = name_space
                                    self.remote_veid.value_namespace_prefix = name_space_prefix
                                if(value_path == "saii"):
                                    self.saii = value
                                    self.saii.value_namespace = name_space
                                    self.saii.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "taii"):
                                    self.taii = value
                                    self.taii.value_namespace = name_space
                                    self.taii.value_namespace_prefix = name_space_prefix


                        class L2Tpv3(Entity):
                            """
                            l2tpv3
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_source_address
                            
                            	IPv6 source address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: local_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_size
                            
                            	Local cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_secondary_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_size
                            
                            	Local secondary cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_session_id
                            
                            	Local session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: remote_circuit_status_up
                            
                            	RemoteCircuitStatusUp
                            	**type**\:  bool
                            
                            .. attribute:: remote_cookie_high_value
                            
                            	Upper 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_low_value
                            
                            	Lower 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_size
                            
                            	Remote cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_session_id
                            
                            	Remote session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_state
                            
                            	L2TP tunnel state
                            	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                self.yang_name = "l2tpv3"
                                self.yang_parent_name = "encapsulation-info"

                                self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                self.tos = YLeaf(YType.uint8, "tos")

                                self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                self.ttl = YLeaf(YType.uint8, "ttl")

                                self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dont_fragment_bit",
                                                "ipv4_source_address",
                                                "ipv6_source_address",
                                                "l2tp_class_name",
                                                "local_cookie_high_value",
                                                "local_cookie_low_value",
                                                "local_cookie_size",
                                                "local_secondary_cookie_high_value",
                                                "local_secondary_cookie_low_value",
                                                "local_secondary_cookie_size",
                                                "local_session_id",
                                                "path_mtu_enabled",
                                                "path_mtu_max_value",
                                                "remote_circuit_status_up",
                                                "remote_cookie_high_value",
                                                "remote_cookie_low_value",
                                                "remote_cookie_size",
                                                "remote_session_id",
                                                "tos",
                                                "tos_mode",
                                                "ttl",
                                                "tunnel_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dont_fragment_bit.is_set or
                                    self.ipv4_source_address.is_set or
                                    self.ipv6_source_address.is_set or
                                    self.l2tp_class_name.is_set or
                                    self.local_cookie_high_value.is_set or
                                    self.local_cookie_low_value.is_set or
                                    self.local_cookie_size.is_set or
                                    self.local_secondary_cookie_high_value.is_set or
                                    self.local_secondary_cookie_low_value.is_set or
                                    self.local_secondary_cookie_size.is_set or
                                    self.local_session_id.is_set or
                                    self.path_mtu_enabled.is_set or
                                    self.path_mtu_max_value.is_set or
                                    self.remote_circuit_status_up.is_set or
                                    self.remote_cookie_high_value.is_set or
                                    self.remote_cookie_low_value.is_set or
                                    self.remote_cookie_size.is_set or
                                    self.remote_session_id.is_set or
                                    self.tos.is_set or
                                    self.tos_mode.is_set or
                                    self.ttl.is_set or
                                    self.tunnel_state.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dont_fragment_bit.yfilter != YFilter.not_set or
                                    self.ipv4_source_address.yfilter != YFilter.not_set or
                                    self.ipv6_source_address.yfilter != YFilter.not_set or
                                    self.l2tp_class_name.yfilter != YFilter.not_set or
                                    self.local_cookie_high_value.yfilter != YFilter.not_set or
                                    self.local_cookie_low_value.yfilter != YFilter.not_set or
                                    self.local_cookie_size.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                    self.local_session_id.yfilter != YFilter.not_set or
                                    self.path_mtu_enabled.yfilter != YFilter.not_set or
                                    self.path_mtu_max_value.yfilter != YFilter.not_set or
                                    self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                    self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                    self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                    self.remote_cookie_size.yfilter != YFilter.not_set or
                                    self.remote_session_id.yfilter != YFilter.not_set or
                                    self.tos.yfilter != YFilter.not_set or
                                    self.tos_mode.yfilter != YFilter.not_set or
                                    self.ttl.yfilter != YFilter.not_set or
                                    self.tunnel_state.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2tpv3" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos.get_name_leafdata())
                                if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ttl.get_name_leafdata())
                                if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dont-fragment-bit"):
                                    self.dont_fragment_bit = value
                                    self.dont_fragment_bit.value_namespace = name_space
                                    self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-source-address"):
                                    self.ipv4_source_address = value
                                    self.ipv4_source_address.value_namespace = name_space
                                    self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-source-address"):
                                    self.ipv6_source_address = value
                                    self.ipv6_source_address.value_namespace = name_space
                                    self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "l2tp-class-name"):
                                    self.l2tp_class_name = value
                                    self.l2tp_class_name.value_namespace = name_space
                                    self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-high-value"):
                                    self.local_cookie_high_value = value
                                    self.local_cookie_high_value.value_namespace = name_space
                                    self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-low-value"):
                                    self.local_cookie_low_value = value
                                    self.local_cookie_low_value.value_namespace = name_space
                                    self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-size"):
                                    self.local_cookie_size = value
                                    self.local_cookie_size.value_namespace = name_space
                                    self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-high-value"):
                                    self.local_secondary_cookie_high_value = value
                                    self.local_secondary_cookie_high_value.value_namespace = name_space
                                    self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-low-value"):
                                    self.local_secondary_cookie_low_value = value
                                    self.local_secondary_cookie_low_value.value_namespace = name_space
                                    self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-size"):
                                    self.local_secondary_cookie_size = value
                                    self.local_secondary_cookie_size.value_namespace = name_space
                                    self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-session-id"):
                                    self.local_session_id = value
                                    self.local_session_id.value_namespace = name_space
                                    self.local_session_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-enabled"):
                                    self.path_mtu_enabled = value
                                    self.path_mtu_enabled.value_namespace = name_space
                                    self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-max-value"):
                                    self.path_mtu_max_value = value
                                    self.path_mtu_max_value.value_namespace = name_space
                                    self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-circuit-status-up"):
                                    self.remote_circuit_status_up = value
                                    self.remote_circuit_status_up.value_namespace = name_space
                                    self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-high-value"):
                                    self.remote_cookie_high_value = value
                                    self.remote_cookie_high_value.value_namespace = name_space
                                    self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-low-value"):
                                    self.remote_cookie_low_value = value
                                    self.remote_cookie_low_value.value_namespace = name_space
                                    self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-size"):
                                    self.remote_cookie_size = value
                                    self.remote_cookie_size.value_namespace = name_space
                                    self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-session-id"):
                                    self.remote_session_id = value
                                    self.remote_session_id.value_namespace = name_space
                                    self.remote_session_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos"):
                                    self.tos = value
                                    self.tos.value_namespace = name_space
                                    self.tos.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos-mode"):
                                    self.tos_mode = value
                                    self.tos_mode.value_namespace = name_space
                                    self.tos_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "ttl"):
                                    self.ttl = value
                                    self.ttl.value_namespace = name_space
                                    self.ttl.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-state"):
                                    self.tunnel_state = value
                                    self.tunnel_state.value_namespace = name_space
                                    self.tunnel_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.encapsulation.is_set or
                                (self.atom is not None and self.atom.has_data()) or
                                (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.encapsulation.yfilter != YFilter.not_set or
                                (self.atom is not None and self.atom.has_operation()) or
                                (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "encapsulation-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "atom"):
                                if (self.atom is None):
                                    self.atom = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                return self.atom

                            if (child_yang_name == "l2tpv3"):
                                if (self.l2tpv3 is None):
                                    self.l2tpv3 = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                return self.l2tpv3

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "encapsulation"):
                                self.encapsulation = value
                                self.encapsulation.value_namespace = name_space
                                self.encapsulation.value_namespace_prefix = name_space_prefix


                    class LocalInterface(Entity):
                        """
                        Local interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__init__()

                            self.yang_name = "local-interface"
                            self.yang_parent_name = "pseudo-wire"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "local-interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class RemoteInterface(Entity):
                        """
                        Remote interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__init__()

                            self.yang_name = "remote-interface"
                            self.yang_parent_name = "pseudo-wire"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "remote-interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class PreferredPath(Entity):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__init__()

                            self.yang_name = "preferred-path"
                            self.yang_parent_name = "pseudo-wire"

                            self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                            self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                            self.option = YLeaf(YType.enumeration, "option")

                            self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                            self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ip_tunnel_interface_number",
                                            "next_hop_ip",
                                            "option",
                                            "te_tunnel_interface_number",
                                            "tp_tunnel_interface_number") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ip_tunnel_interface_number.is_set or
                                self.next_hop_ip.is_set or
                                self.option.is_set or
                                self.te_tunnel_interface_number.is_set or
                                self.tp_tunnel_interface_number.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set or
                                self.option.yfilter != YFilter.not_set or
                                self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "preferred-path" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                            if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.option.get_name_leafdata())
                            if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                            if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ip-tunnel-interface-number"):
                                self.ip_tunnel_interface_number = value
                                self.ip_tunnel_interface_number.value_namespace = name_space
                                self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix
                            if(value_path == "option"):
                                self.option = value
                                self.option.value_namespace = name_space
                                self.option.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-tunnel-interface-number"):
                                self.te_tunnel_interface_number = value
                                self.te_tunnel_interface_number.value_namespace = name_space
                                self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "tp-tunnel-interface-number"):
                                self.tp_tunnel_interface_number = value
                                self.tp_tunnel_interface_number.value_namespace = name_space
                                self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                    class LocalSignalling(Entity):
                        """
                        Local signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__init__()

                            self.yang_name = "local-signalling"
                            self.yang_parent_name = "pseudo-wire"

                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self._children_name_map["status_tlv"] = "status-tlv"
                            self._children_yang_names.add("status-tlv")

                            self.tlv = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pw_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                        class StatusTlv(Entity):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                self.yang_name = "status-tlv"
                                self.yang_parent_name = "local-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "status-tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix


                        class Tlv(Entity):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "local-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.tlv:
                                if (c.has_data()):
                                    return True
                            return (
                                self.pw_status.is_set or
                                (self.status_tlv is not None and self.status_tlv.has_data()))

                        def has_operation(self):
                            for c in self.tlv:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pw_status.yfilter != YFilter.not_set or
                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-signalling" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "status-tlv"):
                                if (self.status_tlv is None):
                                    self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                return self.status_tlv

                            if (child_yang_name == "tlv"):
                                for c in self.tlv:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.tlv.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pw-status"):
                                self.pw_status = value
                                self.pw_status.value_namespace = name_space
                                self.pw_status.value_namespace_prefix = name_space_prefix


                    class RemoteSignalling(Entity):
                        """
                        Remote signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__init__()

                            self.yang_name = "remote-signalling"
                            self.yang_parent_name = "pseudo-wire"

                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self._children_name_map["status_tlv"] = "status-tlv"
                            self._children_yang_names.add("status-tlv")

                            self.tlv = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pw_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                        class StatusTlv(Entity):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                self.yang_name = "status-tlv"
                                self.yang_parent_name = "remote-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "status-tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix


                        class Tlv(Entity):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "remote-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.tlv:
                                if (c.has_data()):
                                    return True
                            return (
                                self.pw_status.is_set or
                                (self.status_tlv is not None and self.status_tlv.has_data()))

                        def has_operation(self):
                            for c in self.tlv:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pw_status.yfilter != YFilter.not_set or
                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-signalling" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "status-tlv"):
                                if (self.status_tlv is None):
                                    self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                return self.status_tlv

                            if (child_yang_name == "tlv"):
                                for c in self.tlv:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.tlv.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pw-status"):
                                self.pw_status = value
                                self.pw_status.value_namespace = name_space
                                self.pw_status.value_namespace_prefix = name_space_prefix


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "pseudo-wire"

                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                            self._children_yang_names.add("dispostion-stats")

                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self._children_name_map["impostion_stats"] = "impostion-stats"
                            self._children_yang_names.add("impostion-stats")

                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                            self.sequence_number.parent = self
                            self._children_name_map["sequence_number"] = "sequence-number"
                            self._children_yang_names.add("sequence-number")


                        class ImpostionStats(Entity):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                self.yang_name = "impostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self._children_name_map["broadcast"] = "broadcast"
                                self._children_yang_names.add("broadcast")

                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                self._children_yang_names.add("imposition-mtu-drop")

                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                self._children_yang_names.add("imposition-stat")

                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                self._children_yang_names.add("impostion-tail-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                self._children_yang_names.add("l2fsbi-drop")

                                self.multicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                                self._children_yang_names.add("multicast")

                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self
                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                self._children_yang_names.add("unknown-unicast")


                            class ImpositionStat(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                    self.yang_name = "imposition-stat"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpositionMtuDrop(Entity):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                    self.yang_name = "imposition-mtu-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpostionTailDrop(Entity):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                    self.yang_name = "impostion-tail-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class L2FsbiDrop(Entity):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                    self.yang_name = "l2fsbi-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fsbi-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Multicast(Entity):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Broadcast(Entity):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                    self.yang_name = "broadcast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnknownUnicast(Entity):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                    self.yang_name = "unknown-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unknown-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                    (self.multicast is not None and self.multicast.has_data()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                    (self.multicast is not None and self.multicast.has_operation()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "impostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast"):
                                    if (self.broadcast is None):
                                        self.broadcast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                    return self.broadcast

                                if (child_yang_name == "imposition-mtu-drop"):
                                    if (self.imposition_mtu_drop is None):
                                        self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    return self.imposition_mtu_drop

                                if (child_yang_name == "imposition-stat"):
                                    if (self.imposition_stat is None):
                                        self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                    return self.imposition_stat

                                if (child_yang_name == "impostion-tail-drop"):
                                    if (self.impostion_tail_drop is None):
                                        self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    return self.impostion_tail_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "l2fsbi-drop"):
                                    if (self.l2fsbi_drop is None):
                                        self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    return self.l2fsbi_drop

                                if (child_yang_name == "multicast"):
                                    if (self.multicast is None):
                                        self.multicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                    return self.multicast

                                if (child_yang_name == "unknown-unicast"):
                                    if (self.unknown_unicast is None):
                                        self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    return self.unknown_unicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DispostionStats(Entity):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats, self).__init__()

                                self.yang_name = "dispostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                self._children_yang_names.add("broadcast-drop")

                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self._children_name_map["dai_drop"] = "dai-drop"
                                self._children_yang_names.add("dai-drop")

                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                self._children_yang_names.add("disposition-mtu-drop")

                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                self._children_yang_names.add("disposition-oo-o-drops")

                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                self._children_yang_names.add("disposition-p2mp-stats")

                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                self._children_yang_names.add("disposition-stat")

                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                self._children_yang_names.add("disposition-tail-drop")

                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                self._children_yang_names.add("ipsg-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.mac_move = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self._children_name_map["mac_move"] = "mac-move"
                                self._children_yang_names.add("mac-move")

                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                self._children_yang_names.add("multicast-drop")

                                self.received_drops = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self._children_name_map["received_drops"] = "received-drops"
                                self._children_yang_names.add("received-drops")

                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self
                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                self._children_yang_names.add("unicast-drop")


                            class DispositionStat(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                    self.yang_name = "disposition-stat"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionMtuDrop(Entity):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                    self.yang_name = "disposition-mtu-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionTailDrop(Entity):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                    self.yang_name = "disposition-tail-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MulticastDrop(Entity):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                    self.yang_name = "multicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnicastDrop(Entity):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                    self.yang_name = "unicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class BroadcastDrop(Entity):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                    self.yang_name = "broadcast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ReceivedDrops(Entity):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                    self.yang_name = "received-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DaiDrop(Entity):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                    self.yang_name = "dai-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dai-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class IpsgDrop(Entity):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                    self.yang_name = "ipsg-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipsg-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionOoODrops(Entity):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                    self.yang_name = "disposition-oo-o-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionP2MpStats(Entity):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                    self.yang_name = "disposition-p2mp-stats"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MacMove(Entity):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                    self.yang_name = "mac-move"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-move" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dispostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast-drop"):
                                    if (self.broadcast_drop is None):
                                        self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    return self.broadcast_drop

                                if (child_yang_name == "dai-drop"):
                                    if (self.dai_drop is None):
                                        self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                    return self.dai_drop

                                if (child_yang_name == "disposition-mtu-drop"):
                                    if (self.disposition_mtu_drop is None):
                                        self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    return self.disposition_mtu_drop

                                if (child_yang_name == "disposition-oo-o-drops"):
                                    if (self.disposition_oo_o_drops is None):
                                        self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    return self.disposition_oo_o_drops

                                if (child_yang_name == "disposition-p2mp-stats"):
                                    if (self.disposition_p2mp_stats is None):
                                        self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    return self.disposition_p2mp_stats

                                if (child_yang_name == "disposition-stat"):
                                    if (self.disposition_stat is None):
                                        self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                    return self.disposition_stat

                                if (child_yang_name == "disposition-tail-drop"):
                                    if (self.disposition_tail_drop is None):
                                        self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    return self.disposition_tail_drop

                                if (child_yang_name == "ipsg-drop"):
                                    if (self.ipsg_drop is None):
                                        self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    return self.ipsg_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "mac-move"):
                                    if (self.mac_move is None):
                                        self.mac_move = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                    return self.mac_move

                                if (child_yang_name == "multicast-drop"):
                                    if (self.multicast_drop is None):
                                        self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                    return self.multicast_drop

                                if (child_yang_name == "received-drops"):
                                    if (self.received_drops is None):
                                        self.received_drops = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                    return self.received_drops

                                if (child_yang_name == "unicast-drop"):
                                    if (self.unicast_drop is None):
                                        self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                    return self.unicast_drop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SequenceNumber(Entity):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                self.yang_name = "sequence-number"
                                self.yang_parent_name = "statistics"

                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bypassed_inbound_sequence_packet",
                                                "bypassed_out_sequence_packet",
                                                "sequence_number_expected",
                                                "sequence_number_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bypassed_inbound_sequence_packet.is_set or
                                    self.bypassed_out_sequence_packet.is_set or
                                    self.sequence_number_expected.is_set or
                                    self.sequence_number_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sequence-number" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bypassed-inbound-sequence-packet"):
                                    self.bypassed_inbound_sequence_packet = value
                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "bypassed-out-sequence-packet"):
                                    self.bypassed_out_sequence_packet = value
                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-expected"):
                                    self.sequence_number_expected = value
                                    self.sequence_number_expected.value_namespace = name_space
                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-sent"):
                                    self.sequence_number_sent = value
                                    self.sequence_number_sent.value_namespace = name_space
                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                (self.sequence_number is not None and self.sequence_number.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dispostion-stats"):
                                if (self.dispostion_stats is None):
                                    self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                return self.dispostion_stats

                            if (child_yang_name == "impostion-stats"):
                                if (self.impostion_stats is None):
                                    self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                return self.impostion_stats

                            if (child_yang_name == "sequence-number"):
                                if (self.sequence_number is None):
                                    self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                return self.sequence_number

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class P2MpPw(Entity):
                        """
                        P2MP Pseudowire Information
                        
                        .. attribute:: local_available
                        
                        	Local LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: local_extended_tunnel_id
                        
                        	Local Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_flags
                        
                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: local_label
                        
                        	Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_p2mp_id
                        
                        	Local P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_ptree_type
                        
                        	Local P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                        
                        .. attribute:: local_tunnel_id
                        
                        	Local Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_available
                        
                        	Remote LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: remote_extended_tunnel_id
                        
                        	Remote Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_flags
                        
                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_label
                        
                        	Remote Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_p2mp_id
                        
                        	Remote P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_ptree_type
                        
                        	Remote P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                        
                        .. attribute:: remote_tunnel_id
                        
                        	Remote Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__init__()

                            self.yang_name = "p2mp-pw"
                            self.yang_parent_name = "pseudo-wire"

                            self.local_available = YLeaf(YType.boolean, "local-available")

                            self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                            self.local_flags = YLeaf(YType.uint8, "local-flags")

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                            self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                            self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                            self.remote_available = YLeaf(YType.boolean, "remote-available")

                            self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                            self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                            self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                            self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                            self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("local_available",
                                            "local_extended_tunnel_id",
                                            "local_flags",
                                            "local_label",
                                            "local_p2mp_id",
                                            "local_ptree_type",
                                            "local_tunnel_id",
                                            "remote_available",
                                            "remote_extended_tunnel_id",
                                            "remote_flags",
                                            "remote_label",
                                            "remote_p2mp_id",
                                            "remote_ptree_type",
                                            "remote_tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.local_available.is_set or
                                self.local_extended_tunnel_id.is_set or
                                self.local_flags.is_set or
                                self.local_label.is_set or
                                self.local_p2mp_id.is_set or
                                self.local_ptree_type.is_set or
                                self.local_tunnel_id.is_set or
                                self.remote_available.is_set or
                                self.remote_extended_tunnel_id.is_set or
                                self.remote_flags.is_set or
                                self.remote_label.is_set or
                                self.remote_p2mp_id.is_set or
                                self.remote_ptree_type.is_set or
                                self.remote_tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.local_available.yfilter != YFilter.not_set or
                                self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                self.local_flags.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                self.local_p2mp_id.yfilter != YFilter.not_set or
                                self.local_ptree_type.yfilter != YFilter.not_set or
                                self.local_tunnel_id.yfilter != YFilter.not_set or
                                self.remote_available.yfilter != YFilter.not_set or
                                self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                self.remote_flags.yfilter != YFilter.not_set or
                                self.remote_label.yfilter != YFilter.not_set or
                                self.remote_p2mp_id.yfilter != YFilter.not_set or
                                self.remote_ptree_type.yfilter != YFilter.not_set or
                                self.remote_tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-pw" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_available.get_name_leafdata())
                            if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                            if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_flags.get_name_leafdata())
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())
                            if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                            if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                            if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                            if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_available.get_name_leafdata())
                            if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                            if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_flags.get_name_leafdata())
                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                            if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                            if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                            if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "local-available"):
                                self.local_available = value
                                self.local_available.value_namespace = name_space
                                self.local_available.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-extended-tunnel-id"):
                                self.local_extended_tunnel_id = value
                                self.local_extended_tunnel_id.value_namespace = name_space
                                self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-flags"):
                                self.local_flags = value
                                self.local_flags.value_namespace = name_space
                                self.local_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-p2mp-id"):
                                self.local_p2mp_id = value
                                self.local_p2mp_id.value_namespace = name_space
                                self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-ptree-type"):
                                self.local_ptree_type = value
                                self.local_ptree_type.value_namespace = name_space
                                self.local_ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-tunnel-id"):
                                self.local_tunnel_id = value
                                self.local_tunnel_id.value_namespace = name_space
                                self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-available"):
                                self.remote_available = value
                                self.remote_available.value_namespace = name_space
                                self.remote_available.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-extended-tunnel-id"):
                                self.remote_extended_tunnel_id = value
                                self.remote_extended_tunnel_id.value_namespace = name_space
                                self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-flags"):
                                self.remote_flags = value
                                self.remote_flags.value_namespace = name_space
                                self.remote_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label"):
                                self.remote_label = value
                                self.remote_label.value_namespace = name_space
                                self.remote_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-p2mp-id"):
                                self.remote_p2mp_id = value
                                self.remote_p2mp_id.value_namespace = name_space
                                self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-ptree-type"):
                                self.remote_ptree_type = value
                                self.remote_ptree_type.value_namespace = name_space
                                self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-tunnel-id"):
                                self.remote_tunnel_id = value
                                self.remote_tunnel_id.value_namespace = name_space
                                self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ad_method.is_set or
                            self.ad_remote_down.is_set or
                            self.admited_bw.is_set or
                            self.auto_discovery.is_set or
                            self.backup_active.is_set or
                            self.backup_force_active.is_set or
                            self.backup_pw.is_set or
                            self.bitrate_mismatched.is_set or
                            self.bridge_pw_type_mismatch.is_set or
                            self.cas_mismatched.is_set or
                            self.diff_ts_mismatched.is_set or
                            self.disable_delay.is_set or
                            self.disable_never.is_set or
                            self.evpn_src_acid.is_set or
                            self.fe_ctype.is_set or
                            self.forward_class.is_set or
                            self.freq_mismatched.is_set or
                            self.illegal_control_word.is_set or
                            self.imposed_vlan_id.is_set or
                            self.interworking.is_set or
                            self.ipv6_local_source_address.is_set or
                            self.is_evpnvpws_type.is_set or
                            self.is_flow_label_static.is_set or
                            self.is_multi_segment_pseudowire.is_set or
                            self.is_partially_programmed.is_set or
                            self.is_pwr_type.is_set or
                            self.is_vfi.is_set or
                            self.last_time_status_changed.is_set or
                            self.last_time_status_down.is_set or
                            self.ldp_label_advertise_failed.is_set or
                            self.load_balance.is_set or
                            self.local_control_word.is_set or
                            self.local_label_failed.is_set or
                            self.local_pseudo_wire_type.is_set or
                            self.local_source_address.is_set or
                            self.mac_limit_oper_down.is_set or
                            self.mtu_mismatched.is_set or
                            self.not_supported_qinq.is_set or
                            self.num_ma_cwithdraw_msg_received.is_set or
                            self.number_ma_cwithdraw_message_sent.is_set or
                            self.out_of_memory_state.is_set or
                            self.payload_bytes_mismatched.is_set or
                            self.payload_type_mismatched.is_set or
                            self.preferred_path_disable_fallback.is_set or
                            self.primary_peer_id.is_set or
                            self.primary_pseudo_wire_id.is_set or
                            self.primary_pw.is_set or
                            self.protocol.is_set or
                            self.pseudo_wire_id.is_set or
                            self.pseudo_wire_state.is_set or
                            self.pseudo_wire_type_mismatched.is_set or
                            self.pw_class_name.is_set or
                            self.pw_flow_label_code17_disabled.is_set or
                            self.pw_flow_label_type.is_set or
                            self.pw_flow_label_type_cfg.is_set or
                            self.pw_redundancy_initial_delay.is_set or
                            self.pw_redundancy_one_way.is_set or
                            self.pw_status_use.is_set or
                            self.pwlsd_rewrite_failed.is_set or
                            self.remote_control_word.is_set or
                            self.remote_label_failed.is_set or
                            self.remote_pseudo_wire_type.is_set or
                            self.required_bw.is_set or
                            self.resync_enabled.is_set or
                            self.resync_threshold.is_set or
                            self.rtp_mismatched.is_set or
                            self.sequencing_type.is_set or
                            self.shutdown.is_set or
                            self.sig_pkts_mismatched.is_set or
                            self.ssrc_mismatched.is_set or
                            self.state.is_set or
                            self.table_policy_name.is_set or
                            self.tag_rewrite.is_set or
                            self.time_created.is_set or
                            self.time_elapsed_creation.is_set or
                            self.time_elapsed_status_changed.is_set or
                            self.time_elapsed_status_down.is_set or
                            self.transport_lsp_down.is_set or
                            self.xconnect_id.is_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                            (self.local_interface is not None and self.local_interface.has_data()) or
                            (self.local_signalling is not None and self.local_signalling.has_data()) or
                            (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                            (self.peer_id is not None and self.peer_id.has_data()) or
                            (self.preferred_path is not None and self.preferred_path.has_data()) or
                            (self.remote_interface is not None and self.remote_interface.has_data()) or
                            (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ad_method.yfilter != YFilter.not_set or
                            self.ad_remote_down.yfilter != YFilter.not_set or
                            self.admited_bw.yfilter != YFilter.not_set or
                            self.auto_discovery.yfilter != YFilter.not_set or
                            self.backup_active.yfilter != YFilter.not_set or
                            self.backup_force_active.yfilter != YFilter.not_set or
                            self.backup_pw.yfilter != YFilter.not_set or
                            self.bitrate_mismatched.yfilter != YFilter.not_set or
                            self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                            self.cas_mismatched.yfilter != YFilter.not_set or
                            self.diff_ts_mismatched.yfilter != YFilter.not_set or
                            self.disable_delay.yfilter != YFilter.not_set or
                            self.disable_never.yfilter != YFilter.not_set or
                            self.evpn_src_acid.yfilter != YFilter.not_set or
                            self.fe_ctype.yfilter != YFilter.not_set or
                            self.forward_class.yfilter != YFilter.not_set or
                            self.freq_mismatched.yfilter != YFilter.not_set or
                            self.illegal_control_word.yfilter != YFilter.not_set or
                            self.imposed_vlan_id.yfilter != YFilter.not_set or
                            self.interworking.yfilter != YFilter.not_set or
                            self.ipv6_local_source_address.yfilter != YFilter.not_set or
                            self.is_evpnvpws_type.yfilter != YFilter.not_set or
                            self.is_flow_label_static.yfilter != YFilter.not_set or
                            self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                            self.is_partially_programmed.yfilter != YFilter.not_set or
                            self.is_pwr_type.yfilter != YFilter.not_set or
                            self.is_vfi.yfilter != YFilter.not_set or
                            self.last_time_status_changed.yfilter != YFilter.not_set or
                            self.last_time_status_down.yfilter != YFilter.not_set or
                            self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                            self.load_balance.yfilter != YFilter.not_set or
                            self.local_control_word.yfilter != YFilter.not_set or
                            self.local_label_failed.yfilter != YFilter.not_set or
                            self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                            self.local_source_address.yfilter != YFilter.not_set or
                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                            self.mtu_mismatched.yfilter != YFilter.not_set or
                            self.not_supported_qinq.yfilter != YFilter.not_set or
                            self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                            self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                            self.out_of_memory_state.yfilter != YFilter.not_set or
                            self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                            self.payload_type_mismatched.yfilter != YFilter.not_set or
                            self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                            self.primary_peer_id.yfilter != YFilter.not_set or
                            self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                            self.primary_pw.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.pseudo_wire_id.yfilter != YFilter.not_set or
                            self.pseudo_wire_state.yfilter != YFilter.not_set or
                            self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                            self.pw_class_name.yfilter != YFilter.not_set or
                            self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                            self.pw_flow_label_type.yfilter != YFilter.not_set or
                            self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                            self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                            self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                            self.pw_status_use.yfilter != YFilter.not_set or
                            self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                            self.remote_control_word.yfilter != YFilter.not_set or
                            self.remote_label_failed.yfilter != YFilter.not_set or
                            self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                            self.required_bw.yfilter != YFilter.not_set or
                            self.resync_enabled.yfilter != YFilter.not_set or
                            self.resync_threshold.yfilter != YFilter.not_set or
                            self.rtp_mismatched.yfilter != YFilter.not_set or
                            self.sequencing_type.yfilter != YFilter.not_set or
                            self.shutdown.yfilter != YFilter.not_set or
                            self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                            self.ssrc_mismatched.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.table_policy_name.yfilter != YFilter.not_set or
                            self.tag_rewrite.yfilter != YFilter.not_set or
                            self.time_created.yfilter != YFilter.not_set or
                            self.time_elapsed_creation.yfilter != YFilter.not_set or
                            self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                            self.time_elapsed_status_down.yfilter != YFilter.not_set or
                            self.transport_lsp_down.yfilter != YFilter.not_set or
                            self.xconnect_id.yfilter != YFilter.not_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                            (self.local_interface is not None and self.local_interface.has_operation()) or
                            (self.local_signalling is not None and self.local_signalling.has_operation()) or
                            (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                            (self.peer_id is not None and self.peer_id.has_operation()) or
                            (self.preferred_path is not None and self.preferred_path.has_operation()) or
                            (self.remote_interface is not None and self.remote_interface.has_operation()) or
                            (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pseudo-wire" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/segment2/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_method.get_name_leafdata())
                        if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                        if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.admited_bw.get_name_leafdata())
                        if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                        if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_active.get_name_leafdata())
                        if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                        if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_pw.get_name_leafdata())
                        if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                        if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                        if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                        if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                        if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_delay.get_name_leafdata())
                        if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_never.get_name_leafdata())
                        if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                        if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                        if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.forward_class.get_name_leafdata())
                        if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                        if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                        if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interworking.get_name_leafdata())
                        if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                        if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                        if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                        if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                        if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                        if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                        if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_vfi.get_name_leafdata())
                        if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                        if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                        if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                        if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance.get_name_leafdata())
                        if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_control_word.get_name_leafdata())
                        if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                        if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                        if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_source_address.get_name_leafdata())
                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                        if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                        if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                        if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                        if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                        if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                        if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                        if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                        if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                        if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_pw.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                        if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                        if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                        if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                        if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                        if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                        if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                        if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                        if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                        if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                        if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                        if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                        if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                        if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                        if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.required_bw.get_name_leafdata())
                        if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                        if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                        if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                        if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                        if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                        if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                        if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                        if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_created.get_name_leafdata())
                        if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                        if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                        if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                        if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "encapsulation-info"):
                            if (self.encapsulation_info is None):
                                self.encapsulation_info = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            return self.encapsulation_info

                        if (child_yang_name == "local-interface"):
                            if (self.local_interface is None):
                                self.local_interface = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                            return self.local_interface

                        if (child_yang_name == "local-signalling"):
                            if (self.local_signalling is None):
                                self.local_signalling = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                            return self.local_signalling

                        if (child_yang_name == "p2mp-pw"):
                            if (self.p2mp_pw is None):
                                self.p2mp_pw = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            return self.p2mp_pw

                        if (child_yang_name == "peer-id"):
                            if (self.peer_id is None):
                                self.peer_id = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                            return self.peer_id

                        if (child_yang_name == "preferred-path"):
                            if (self.preferred_path is None):
                                self.preferred_path = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                            return self.preferred_path

                        if (child_yang_name == "remote-interface"):
                            if (self.remote_interface is None):
                                self.remote_interface = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                            return self.remote_interface

                        if (child_yang_name == "remote-signalling"):
                            if (self.remote_signalling is None):
                                self.remote_signalling = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                            return self.remote_signalling

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ad-method"):
                            self.ad_method = value
                            self.ad_method.value_namespace = name_space
                            self.ad_method.value_namespace_prefix = name_space_prefix
                        if(value_path == "ad-remote-down"):
                            self.ad_remote_down = value
                            self.ad_remote_down.value_namespace = name_space
                            self.ad_remote_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "admited-bw"):
                            self.admited_bw = value
                            self.admited_bw.value_namespace = name_space
                            self.admited_bw.value_namespace_prefix = name_space_prefix
                        if(value_path == "auto-discovery"):
                            self.auto_discovery = value
                            self.auto_discovery.value_namespace = name_space
                            self.auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-active"):
                            self.backup_active = value
                            self.backup_active.value_namespace = name_space
                            self.backup_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-force-active"):
                            self.backup_force_active = value
                            self.backup_force_active.value_namespace = name_space
                            self.backup_force_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-pw"):
                            self.backup_pw = value
                            self.backup_pw.value_namespace = name_space
                            self.backup_pw.value_namespace_prefix = name_space_prefix
                        if(value_path == "bitrate-mismatched"):
                            self.bitrate_mismatched = value
                            self.bitrate_mismatched.value_namespace = name_space
                            self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-pw-type-mismatch"):
                            self.bridge_pw_type_mismatch = value
                            self.bridge_pw_type_mismatch.value_namespace = name_space
                            self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                        if(value_path == "cas-mismatched"):
                            self.cas_mismatched = value
                            self.cas_mismatched.value_namespace = name_space
                            self.cas_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "diff-ts-mismatched"):
                            self.diff_ts_mismatched = value
                            self.diff_ts_mismatched.value_namespace = name_space
                            self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-delay"):
                            self.disable_delay = value
                            self.disable_delay.value_namespace = name_space
                            self.disable_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-never"):
                            self.disable_never = value
                            self.disable_never.value_namespace = name_space
                            self.disable_never.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-src-acid"):
                            self.evpn_src_acid = value
                            self.evpn_src_acid.value_namespace = name_space
                            self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                        if(value_path == "fe-ctype"):
                            self.fe_ctype = value
                            self.fe_ctype.value_namespace = name_space
                            self.fe_ctype.value_namespace_prefix = name_space_prefix
                        if(value_path == "forward-class"):
                            self.forward_class = value
                            self.forward_class.value_namespace = name_space
                            self.forward_class.value_namespace_prefix = name_space_prefix
                        if(value_path == "freq-mismatched"):
                            self.freq_mismatched = value
                            self.freq_mismatched.value_namespace = name_space
                            self.freq_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "illegal-control-word"):
                            self.illegal_control_word = value
                            self.illegal_control_word.value_namespace = name_space
                            self.illegal_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "imposed-vlan-id"):
                            self.imposed_vlan_id = value
                            self.imposed_vlan_id.value_namespace = name_space
                            self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interworking"):
                            self.interworking = value
                            self.interworking.value_namespace = name_space
                            self.interworking.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-local-source-address"):
                            self.ipv6_local_source_address = value
                            self.ipv6_local_source_address.value_namespace = name_space
                            self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-evpnvpws-type"):
                            self.is_evpnvpws_type = value
                            self.is_evpnvpws_type.value_namespace = name_space
                            self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-flow-label-static"):
                            self.is_flow_label_static = value
                            self.is_flow_label_static.value_namespace = name_space
                            self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multi-segment-pseudowire"):
                            self.is_multi_segment_pseudowire = value
                            self.is_multi_segment_pseudowire.value_namespace = name_space
                            self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-partially-programmed"):
                            self.is_partially_programmed = value
                            self.is_partially_programmed.value_namespace = name_space
                            self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pwr-type"):
                            self.is_pwr_type = value
                            self.is_pwr_type.value_namespace = name_space
                            self.is_pwr_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-vfi"):
                            self.is_vfi = value
                            self.is_vfi.value_namespace = name_space
                            self.is_vfi.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-changed"):
                            self.last_time_status_changed = value
                            self.last_time_status_changed.value_namespace = name_space
                            self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-down"):
                            self.last_time_status_down = value
                            self.last_time_status_down.value_namespace = name_space
                            self.last_time_status_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "ldp-label-advertise-failed"):
                            self.ldp_label_advertise_failed = value
                            self.ldp_label_advertise_failed.value_namespace = name_space
                            self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance"):
                            self.load_balance = value
                            self.load_balance.value_namespace = name_space
                            self.load_balance.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-control-word"):
                            self.local_control_word = value
                            self.local_control_word.value_namespace = name_space
                            self.local_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-label-failed"):
                            self.local_label_failed = value
                            self.local_label_failed.value_namespace = name_space
                            self.local_label_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-pseudo-wire-type"):
                            self.local_pseudo_wire_type = value
                            self.local_pseudo_wire_type.value_namespace = name_space
                            self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-source-address"):
                            self.local_source_address = value
                            self.local_source_address.value_namespace = name_space
                            self.local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-oper-down"):
                            self.mac_limit_oper_down = value
                            self.mac_limit_oper_down.value_namespace = name_space
                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-mismatched"):
                            self.mtu_mismatched = value
                            self.mtu_mismatched.value_namespace = name_space
                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-qinq"):
                            self.not_supported_qinq = value
                            self.not_supported_qinq.value_namespace = name_space
                            self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-ma-cwithdraw-msg-received"):
                            self.num_ma_cwithdraw_msg_received = value
                            self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                            self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-ma-cwithdraw-message-sent"):
                            self.number_ma_cwithdraw_message_sent = value
                            self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                            self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-of-memory-state"):
                            self.out_of_memory_state = value
                            self.out_of_memory_state.value_namespace = name_space
                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "payload-bytes-mismatched"):
                            self.payload_bytes_mismatched = value
                            self.payload_bytes_mismatched.value_namespace = name_space
                            self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "payload-type-mismatched"):
                            self.payload_type_mismatched = value
                            self.payload_type_mismatched.value_namespace = name_space
                            self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "preferred-path-disable-fallback"):
                            self.preferred_path_disable_fallback = value
                            self.preferred_path_disable_fallback.value_namespace = name_space
                            self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-peer-id"):
                            self.primary_peer_id = value
                            self.primary_peer_id.value_namespace = name_space
                            self.primary_peer_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-pseudo-wire-id"):
                            self.primary_pseudo_wire_id = value
                            self.primary_pseudo_wire_id.value_namespace = name_space
                            self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-pw"):
                            self.primary_pw = value
                            self.primary_pw.value_namespace = name_space
                            self.primary_pw.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-id"):
                            self.pseudo_wire_id = value
                            self.pseudo_wire_id.value_namespace = name_space
                            self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-state"):
                            self.pseudo_wire_state = value
                            self.pseudo_wire_state.value_namespace = name_space
                            self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-type-mismatched"):
                            self.pseudo_wire_type_mismatched = value
                            self.pseudo_wire_type_mismatched.value_namespace = name_space
                            self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-class-name"):
                            self.pw_class_name = value
                            self.pw_class_name.value_namespace = name_space
                            self.pw_class_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-code17-disabled"):
                            self.pw_flow_label_code17_disabled = value
                            self.pw_flow_label_code17_disabled.value_namespace = name_space
                            self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type"):
                            self.pw_flow_label_type = value
                            self.pw_flow_label_type.value_namespace = name_space
                            self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type-cfg"):
                            self.pw_flow_label_type_cfg = value
                            self.pw_flow_label_type_cfg.value_namespace = name_space
                            self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-redundancy-initial-delay"):
                            self.pw_redundancy_initial_delay = value
                            self.pw_redundancy_initial_delay.value_namespace = name_space
                            self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-redundancy-one-way"):
                            self.pw_redundancy_one_way = value
                            self.pw_redundancy_one_way.value_namespace = name_space
                            self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-status-use"):
                            self.pw_status_use = value
                            self.pw_status_use.value_namespace = name_space
                            self.pw_status_use.value_namespace_prefix = name_space_prefix
                        if(value_path == "pwlsd-rewrite-failed"):
                            self.pwlsd_rewrite_failed = value
                            self.pwlsd_rewrite_failed.value_namespace = name_space
                            self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-control-word"):
                            self.remote_control_word = value
                            self.remote_control_word.value_namespace = name_space
                            self.remote_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-label-failed"):
                            self.remote_label_failed = value
                            self.remote_label_failed.value_namespace = name_space
                            self.remote_label_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-pseudo-wire-type"):
                            self.remote_pseudo_wire_type = value
                            self.remote_pseudo_wire_type.value_namespace = name_space
                            self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "required-bw"):
                            self.required_bw = value
                            self.required_bw.value_namespace = name_space
                            self.required_bw.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-enabled"):
                            self.resync_enabled = value
                            self.resync_enabled.value_namespace = name_space
                            self.resync_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-threshold"):
                            self.resync_threshold = value
                            self.resync_threshold.value_namespace = name_space
                            self.resync_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "rtp-mismatched"):
                            self.rtp_mismatched = value
                            self.rtp_mismatched.value_namespace = name_space
                            self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "sequencing-type"):
                            self.sequencing_type = value
                            self.sequencing_type.value_namespace = name_space
                            self.sequencing_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "shutdown"):
                            self.shutdown = value
                            self.shutdown.value_namespace = name_space
                            self.shutdown.value_namespace_prefix = name_space_prefix
                        if(value_path == "sig-pkts-mismatched"):
                            self.sig_pkts_mismatched = value
                            self.sig_pkts_mismatched.value_namespace = name_space
                            self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssrc-mismatched"):
                            self.ssrc_mismatched = value
                            self.ssrc_mismatched.value_namespace = name_space
                            self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-policy-name"):
                            self.table_policy_name = value
                            self.table_policy_name.value_namespace = name_space
                            self.table_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "tag-rewrite"):
                            self.tag_rewrite = value
                            self.tag_rewrite.value_namespace = name_space
                            self.tag_rewrite.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-created"):
                            self.time_created = value
                            self.time_created.value_namespace = name_space
                            self.time_created.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-creation"):
                            self.time_elapsed_creation = value
                            self.time_elapsed_creation.value_namespace = name_space
                            self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-changed"):
                            self.time_elapsed_status_changed = value
                            self.time_elapsed_status_changed.value_namespace = name_space
                            self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-down"):
                            self.time_elapsed_status_down = value
                            self.time_elapsed_status_down.value_namespace = name_space
                            self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "transport-lsp-down"):
                            self.transport_lsp_down = value
                            self.transport_lsp_down.value_namespace = name_space
                            self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-id"):
                            self.xconnect_id = value
                            self.xconnect_id.value_namespace = name_space
                            self.xconnect_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.segment_type.is_set or
                        (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                        (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.segment_type.yfilter != YFilter.not_set or
                        (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                        (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "segment2" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.segment_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "attachment-circuit"):
                        if (self.attachment_circuit is None):
                            self.attachment_circuit = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        return self.attachment_circuit

                    if (child_yang_name == "pseudo-wire"):
                        if (self.pseudo_wire is None):
                            self.pseudo_wire = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        return self.pseudo_wire

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "segment-type"):
                        self.segment_type = value
                        self.segment_type.value_namespace = name_space
                        self.segment_type.value_namespace_prefix = name_space_prefix


            class Ce2Ce(Entity):
                """
                CE2CE
                
                .. attribute:: ce_added
                
                	CE2CE Advertised
                	**type**\:  bool
                
                .. attribute:: local_customer_edge_id
                
                	Local CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: remote_customer_edge_id
                
                	Remote CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Xconnects.Xconnect.Ce2Ce, self).__init__()

                    self.yang_name = "ce2ce"
                    self.yang_parent_name = "xconnect"

                    self.ce_added = YLeaf(YType.boolean, "ce-added")

                    self.local_customer_edge_id = YLeaf(YType.uint16, "local-customer-edge-id")

                    self.remote_customer_edge_id = YLeaf(YType.uint16, "remote-customer-edge-id")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ce_added",
                                    "local_customer_edge_id",
                                    "remote_customer_edge_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Xconnects.Xconnect.Ce2Ce, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Xconnects.Xconnect.Ce2Ce, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ce_added.is_set or
                        self.local_customer_edge_id.is_set or
                        self.remote_customer_edge_id.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ce_added.yfilter != YFilter.not_set or
                        self.local_customer_edge_id.yfilter != YFilter.not_set or
                        self.remote_customer_edge_id.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ce2ce" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ce_added.is_set or self.ce_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ce_added.get_name_leafdata())
                    if (self.local_customer_edge_id.is_set or self.local_customer_edge_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_customer_edge_id.get_name_leafdata())
                    if (self.remote_customer_edge_id.is_set or self.remote_customer_edge_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote_customer_edge_id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ce-added" or name == "local-customer-edge-id" or name == "remote-customer-edge-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ce-added"):
                        self.ce_added = value
                        self.ce_added.value_namespace = name_space
                        self.ce_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-customer-edge-id"):
                        self.local_customer_edge_id = value
                        self.local_customer_edge_id.value_namespace = name_space
                        self.local_customer_edge_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote-customer-edge-id"):
                        self.remote_customer_edge_id = value
                        self.remote_customer_edge_id.value_namespace = name_space
                        self.remote_customer_edge_id.value_namespace_prefix = name_space_prefix


            class BackupSegment(Entity):
                """
                Backup Segment
                
                .. attribute:: attachment_circuit
                
                	Attachment Circuit
                	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                
                .. attribute:: pseudo_wire
                
                	Pseudowire
                	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                
                .. attribute:: segment_type
                
                	SegmentType
                	**type**\:   :py:class:`L2VpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegment>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Xconnects.Xconnect.BackupSegment, self).__init__()

                    self.yang_name = "backup-segment"
                    self.yang_parent_name = "xconnect"

                    self.segment_type = YLeaf(YType.enumeration, "segment-type")

                    self.attachment_circuit = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                    self.attachment_circuit.parent = self
                    self._children_name_map["attachment_circuit"] = "attachment-circuit"
                    self._children_yang_names.add("attachment-circuit")

                    self.pseudo_wire = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire()
                    self.pseudo_wire.parent = self
                    self._children_name_map["pseudo_wire"] = "pseudo-wire"
                    self._children_yang_names.add("pseudo-wire")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("segment_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment, self).__setattr__(name, value)


                class AttachmentCircuit(Entity):
                    """
                    Attachment Circuit
                    
                    .. attribute:: bvi_mac_conflict
                    
                    	BVI Mac Conflict
                    	**type**\:  bool
                    
                    .. attribute:: bvi_no_port_up
                    
                    	BVI no BP Up
                    	**type**\:  bool
                    
                    .. attribute:: control_word_mismatched
                    
                    	Control word mismatched
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_error
                    
                    	Encapsulation Error
                    	**type**\:  str
                    
                    .. attribute:: encapsulation_mismatched
                    
                    	Encapsulation mismatched
                    	**type**\:  bool
                    
                    .. attribute:: evpn_internal_label
                    
                    	EVPN Internal Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interface
                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                    
                    .. attribute:: interface_handle
                    
                    	Interface Handler
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: internal_ms_ti
                    
                    	Internal MSTi
                    	**type**\:  str
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                    
                    .. attribute:: is_ac_partially_programmed
                    
                    	Is attachment\-circuit partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: l2vpn_protection
                    
                    	Protection object used for this segment
                    	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection>`
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: ms_ti_mismatch
                    
                    	MSTi mismatch
                    	**type**\:  bool
                    
                    .. attribute:: msti
                    
                    	MSTi
                    	**type**\:  str
                    
                    .. attribute:: msti_mismatch_down
                    
                    	Oper down due to MSTI mismatch
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Node ID
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_id
                    
                    	Redundancy Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_state
                    
                    	Redundancy Group State
                    	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                    
                    .. attribute:: redundancy_object_id
                    
                    	Redundancy Object ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                    
                    .. attribute:: tdm_media_mismatched
                    
                    	TDM media parms mismatched
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__init__()

                        self.yang_name = "attachment-circuit"
                        self.yang_parent_name = "backup-segment"

                        self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                        self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                        self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                        self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                        self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                        self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                        self.interface_handle = YLeaf(YType.str, "interface-handle")

                        self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                        self.interworking = YLeaf(YType.enumeration, "interworking")

                        self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                        self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                        self.msti = YLeaf(YType.str, "msti")

                        self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                        self.node_id = YLeaf(YType.str, "node-id")

                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                        self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                        self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                        self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                        self.interface = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                        self.interface.parent = self
                        self._children_name_map["interface"] = "interface"
                        self._children_yang_names.add("interface")

                        self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                        self.l2vpn_protection.parent = self
                        self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                        self._children_yang_names.add("l2vpn-protection")

                        self.statistics = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bvi_mac_conflict",
                                        "bvi_no_port_up",
                                        "control_word_mismatched",
                                        "encapsulation_error",
                                        "encapsulation_mismatched",
                                        "evpn_internal_label",
                                        "interface_handle",
                                        "internal_ms_ti",
                                        "interworking",
                                        "is_ac_partially_programmed",
                                        "mac_limit_oper_down",
                                        "ms_ti_mismatch",
                                        "msti",
                                        "msti_mismatch_down",
                                        "mtu_mismatched",
                                        "node_id",
                                        "out_of_memory_state",
                                        "redundancy_group_id",
                                        "redundancy_group_state",
                                        "redundancy_object_id",
                                        "state",
                                        "tdm_media_mismatched",
                                        "xconnect_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "attachment-circuit"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "attachment-circuit"

                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                            self._children_yang_names.add("dispostion-stats")

                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self._children_name_map["impostion_stats"] = "impostion-stats"
                            self._children_yang_names.add("impostion-stats")

                            self.sequence_number = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                            self.sequence_number.parent = self
                            self._children_name_map["sequence_number"] = "sequence-number"
                            self._children_yang_names.add("sequence-number")


                        class ImpostionStats(Entity):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                self.yang_name = "impostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self._children_name_map["broadcast"] = "broadcast"
                                self._children_yang_names.add("broadcast")

                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                self._children_yang_names.add("imposition-mtu-drop")

                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                self._children_yang_names.add("imposition-stat")

                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                self._children_yang_names.add("impostion-tail-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                self._children_yang_names.add("l2fsbi-drop")

                                self.multicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                                self._children_yang_names.add("multicast")

                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self
                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                self._children_yang_names.add("unknown-unicast")


                            class ImpositionStat(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                    self.yang_name = "imposition-stat"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpositionMtuDrop(Entity):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                    self.yang_name = "imposition-mtu-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpostionTailDrop(Entity):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                    self.yang_name = "impostion-tail-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class L2FsbiDrop(Entity):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                    self.yang_name = "l2fsbi-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fsbi-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Multicast(Entity):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Broadcast(Entity):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                    self.yang_name = "broadcast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnknownUnicast(Entity):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                    self.yang_name = "unknown-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unknown-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                    (self.multicast is not None and self.multicast.has_data()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                    (self.multicast is not None and self.multicast.has_operation()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "impostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast"):
                                    if (self.broadcast is None):
                                        self.broadcast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                    return self.broadcast

                                if (child_yang_name == "imposition-mtu-drop"):
                                    if (self.imposition_mtu_drop is None):
                                        self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    return self.imposition_mtu_drop

                                if (child_yang_name == "imposition-stat"):
                                    if (self.imposition_stat is None):
                                        self.imposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                    return self.imposition_stat

                                if (child_yang_name == "impostion-tail-drop"):
                                    if (self.impostion_tail_drop is None):
                                        self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    return self.impostion_tail_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "l2fsbi-drop"):
                                    if (self.l2fsbi_drop is None):
                                        self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    return self.l2fsbi_drop

                                if (child_yang_name == "multicast"):
                                    if (self.multicast is None):
                                        self.multicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                    return self.multicast

                                if (child_yang_name == "unknown-unicast"):
                                    if (self.unknown_unicast is None):
                                        self.unknown_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    return self.unknown_unicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DispostionStats(Entity):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                self.yang_name = "dispostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                self._children_yang_names.add("broadcast-drop")

                                self.dai_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self._children_name_map["dai_drop"] = "dai-drop"
                                self._children_yang_names.add("dai-drop")

                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                self._children_yang_names.add("disposition-mtu-drop")

                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                self._children_yang_names.add("disposition-oo-o-drops")

                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                self._children_yang_names.add("disposition-p2mp-stats")

                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                self._children_yang_names.add("disposition-stat")

                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                self._children_yang_names.add("disposition-tail-drop")

                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                self._children_yang_names.add("ipsg-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.mac_move = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self._children_name_map["mac_move"] = "mac-move"
                                self._children_yang_names.add("mac-move")

                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                self._children_yang_names.add("multicast-drop")

                                self.received_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self._children_name_map["received_drops"] = "received-drops"
                                self._children_yang_names.add("received-drops")

                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self
                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                self._children_yang_names.add("unicast-drop")


                            class DispositionStat(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                    self.yang_name = "disposition-stat"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionMtuDrop(Entity):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                    self.yang_name = "disposition-mtu-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionTailDrop(Entity):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                    self.yang_name = "disposition-tail-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MulticastDrop(Entity):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                    self.yang_name = "multicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnicastDrop(Entity):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                    self.yang_name = "unicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class BroadcastDrop(Entity):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                    self.yang_name = "broadcast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ReceivedDrops(Entity):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                    self.yang_name = "received-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DaiDrop(Entity):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                    self.yang_name = "dai-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dai-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class IpsgDrop(Entity):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                    self.yang_name = "ipsg-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipsg-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionOoODrops(Entity):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                    self.yang_name = "disposition-oo-o-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionP2MpStats(Entity):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                    self.yang_name = "disposition-p2mp-stats"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MacMove(Entity):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                    self.yang_name = "mac-move"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-move" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dispostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast-drop"):
                                    if (self.broadcast_drop is None):
                                        self.broadcast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    return self.broadcast_drop

                                if (child_yang_name == "dai-drop"):
                                    if (self.dai_drop is None):
                                        self.dai_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                    return self.dai_drop

                                if (child_yang_name == "disposition-mtu-drop"):
                                    if (self.disposition_mtu_drop is None):
                                        self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    return self.disposition_mtu_drop

                                if (child_yang_name == "disposition-oo-o-drops"):
                                    if (self.disposition_oo_o_drops is None):
                                        self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    return self.disposition_oo_o_drops

                                if (child_yang_name == "disposition-p2mp-stats"):
                                    if (self.disposition_p2mp_stats is None):
                                        self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    return self.disposition_p2mp_stats

                                if (child_yang_name == "disposition-stat"):
                                    if (self.disposition_stat is None):
                                        self.disposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                    return self.disposition_stat

                                if (child_yang_name == "disposition-tail-drop"):
                                    if (self.disposition_tail_drop is None):
                                        self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    return self.disposition_tail_drop

                                if (child_yang_name == "ipsg-drop"):
                                    if (self.ipsg_drop is None):
                                        self.ipsg_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    return self.ipsg_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "mac-move"):
                                    if (self.mac_move is None):
                                        self.mac_move = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                    return self.mac_move

                                if (child_yang_name == "multicast-drop"):
                                    if (self.multicast_drop is None):
                                        self.multicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                    return self.multicast_drop

                                if (child_yang_name == "received-drops"):
                                    if (self.received_drops is None):
                                        self.received_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                    return self.received_drops

                                if (child_yang_name == "unicast-drop"):
                                    if (self.unicast_drop is None):
                                        self.unicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                    return self.unicast_drop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SequenceNumber(Entity):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                self.yang_name = "sequence-number"
                                self.yang_parent_name = "statistics"

                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bypassed_inbound_sequence_packet",
                                                "bypassed_out_sequence_packet",
                                                "sequence_number_expected",
                                                "sequence_number_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bypassed_inbound_sequence_packet.is_set or
                                    self.bypassed_out_sequence_packet.is_set or
                                    self.sequence_number_expected.is_set or
                                    self.sequence_number_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sequence-number" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bypassed-inbound-sequence-packet"):
                                    self.bypassed_inbound_sequence_packet = value
                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "bypassed-out-sequence-packet"):
                                    self.bypassed_out_sequence_packet = value
                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-expected"):
                                    self.sequence_number_expected = value
                                    self.sequence_number_expected.value_namespace = name_space
                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-sent"):
                                    self.sequence_number_sent = value
                                    self.sequence_number_sent.value_namespace = name_space
                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                (self.sequence_number is not None and self.sequence_number.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dispostion-stats"):
                                if (self.dispostion_stats is None):
                                    self.dispostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                return self.dispostion_stats

                            if (child_yang_name == "impostion-stats"):
                                if (self.impostion_stats is None):
                                    self.impostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                return self.impostion_stats

                            if (child_yang_name == "sequence-number"):
                                if (self.sequence_number is None):
                                    self.sequence_number = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                return self.sequence_number

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class L2VpnProtection(Entity):
                        """
                        Protection object used for this segment
                        
                        .. attribute:: active
                        
                        	Active
                        	**type**\:  bool
                        
                        .. attribute:: protected_name
                        
                        	Name of the protected segment
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_configured
                        
                        	Protection configured
                        	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                        
                        .. attribute:: protection_name
                        
                        	Name of the segment acting as backup
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_type
                        
                        	Type of the protection
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__init__()

                            self.yang_name = "l2vpn-protection"
                            self.yang_parent_name = "attachment-circuit"

                            self.active = YLeaf(YType.boolean, "active")

                            self.protected_name = YLeaf(YType.str, "protected-name")

                            self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                            self.protection_name = YLeaf(YType.str, "protection-name")

                            self.protection_type = YLeaf(YType.enumeration, "protection-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active",
                                            "protected_name",
                                            "protection_configured",
                                            "protection_name",
                                            "protection_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active.is_set or
                                self.protected_name.is_set or
                                self.protection_configured.is_set or
                                self.protection_name.is_set or
                                self.protection_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active.yfilter != YFilter.not_set or
                                self.protected_name.yfilter != YFilter.not_set or
                                self.protection_configured.yfilter != YFilter.not_set or
                                self.protection_name.yfilter != YFilter.not_set or
                                self.protection_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "l2vpn-protection" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active.get_name_leafdata())
                            if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protected_name.get_name_leafdata())
                            if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_configured.get_name_leafdata())
                            if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_name.get_name_leafdata())
                            if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protection_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active"):
                                self.active = value
                                self.active.value_namespace = name_space
                                self.active.value_namespace_prefix = name_space_prefix
                            if(value_path == "protected-name"):
                                self.protected_name = value
                                self.protected_name.value_namespace = name_space
                                self.protected_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-configured"):
                                self.protection_configured = value
                                self.protection_configured.value_namespace = name_space
                                self.protection_configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-name"):
                                self.protection_name = value
                                self.protection_name.value_namespace = name_space
                                self.protection_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "protection-type"):
                                self.protection_type = value
                                self.protection_type.value_namespace = name_space
                                self.protection_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bvi_mac_conflict.is_set or
                            self.bvi_no_port_up.is_set or
                            self.control_word_mismatched.is_set or
                            self.encapsulation_error.is_set or
                            self.encapsulation_mismatched.is_set or
                            self.evpn_internal_label.is_set or
                            self.interface_handle.is_set or
                            self.internal_ms_ti.is_set or
                            self.interworking.is_set or
                            self.is_ac_partially_programmed.is_set or
                            self.mac_limit_oper_down.is_set or
                            self.ms_ti_mismatch.is_set or
                            self.msti.is_set or
                            self.msti_mismatch_down.is_set or
                            self.mtu_mismatched.is_set or
                            self.node_id.is_set or
                            self.out_of_memory_state.is_set or
                            self.redundancy_group_id.is_set or
                            self.redundancy_group_state.is_set or
                            self.redundancy_object_id.is_set or
                            self.state.is_set or
                            self.tdm_media_mismatched.is_set or
                            self.xconnect_id.is_set or
                            (self.interface is not None and self.interface.has_data()) or
                            (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bvi_mac_conflict.yfilter != YFilter.not_set or
                            self.bvi_no_port_up.yfilter != YFilter.not_set or
                            self.control_word_mismatched.yfilter != YFilter.not_set or
                            self.encapsulation_error.yfilter != YFilter.not_set or
                            self.encapsulation_mismatched.yfilter != YFilter.not_set or
                            self.evpn_internal_label.yfilter != YFilter.not_set or
                            self.interface_handle.yfilter != YFilter.not_set or
                            self.internal_ms_ti.yfilter != YFilter.not_set or
                            self.interworking.yfilter != YFilter.not_set or
                            self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                            self.ms_ti_mismatch.yfilter != YFilter.not_set or
                            self.msti.yfilter != YFilter.not_set or
                            self.msti_mismatch_down.yfilter != YFilter.not_set or
                            self.mtu_mismatched.yfilter != YFilter.not_set or
                            self.node_id.yfilter != YFilter.not_set or
                            self.out_of_memory_state.yfilter != YFilter.not_set or
                            self.redundancy_group_id.yfilter != YFilter.not_set or
                            self.redundancy_group_state.yfilter != YFilter.not_set or
                            self.redundancy_object_id.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.tdm_media_mismatched.yfilter != YFilter.not_set or
                            self.xconnect_id.yfilter != YFilter.not_set or
                            (self.interface is not None and self.interface.has_operation()) or
                            (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "attachment-circuit" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                        if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                        if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                        if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                        if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                        if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                        if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_handle.get_name_leafdata())
                        if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interworking.get_name_leafdata())
                        if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                        if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                        if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti.get_name_leafdata())
                        if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                        if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_id.get_name_leafdata())
                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                        if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                        if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                        if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            if (self.interface is None):
                                self.interface = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"
                            return self.interface

                        if (child_yang_name == "l2vpn-protection"):
                            if (self.l2vpn_protection is None):
                                self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            return self.l2vpn_protection

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bvi-mac-conflict"):
                            self.bvi_mac_conflict = value
                            self.bvi_mac_conflict.value_namespace = name_space
                            self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                        if(value_path == "bvi-no-port-up"):
                            self.bvi_no_port_up = value
                            self.bvi_no_port_up.value_namespace = name_space
                            self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "control-word-mismatched"):
                            self.control_word_mismatched = value
                            self.control_word_mismatched.value_namespace = name_space
                            self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "encapsulation-error"):
                            self.encapsulation_error = value
                            self.encapsulation_error.value_namespace = name_space
                            self.encapsulation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "encapsulation-mismatched"):
                            self.encapsulation_mismatched = value
                            self.encapsulation_mismatched.value_namespace = name_space
                            self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-internal-label"):
                            self.evpn_internal_label = value
                            self.evpn_internal_label.value_namespace = name_space
                            self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-handle"):
                            self.interface_handle = value
                            self.interface_handle.value_namespace = name_space
                            self.interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "internal-ms-ti"):
                            self.internal_ms_ti = value
                            self.internal_ms_ti.value_namespace = name_space
                            self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                        if(value_path == "interworking"):
                            self.interworking = value
                            self.interworking.value_namespace = name_space
                            self.interworking.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ac-partially-programmed"):
                            self.is_ac_partially_programmed = value
                            self.is_ac_partially_programmed.value_namespace = name_space
                            self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-oper-down"):
                            self.mac_limit_oper_down = value
                            self.mac_limit_oper_down.value_namespace = name_space
                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "ms-ti-mismatch"):
                            self.ms_ti_mismatch = value
                            self.ms_ti_mismatch.value_namespace = name_space
                            self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti"):
                            self.msti = value
                            self.msti.value_namespace = name_space
                            self.msti.value_namespace_prefix = name_space_prefix
                        if(value_path == "msti-mismatch-down"):
                            self.msti_mismatch_down = value
                            self.msti_mismatch_down.value_namespace = name_space
                            self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-mismatched"):
                            self.mtu_mismatched = value
                            self.mtu_mismatched.value_namespace = name_space
                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-id"):
                            self.node_id = value
                            self.node_id.value_namespace = name_space
                            self.node_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-of-memory-state"):
                            self.out_of_memory_state = value
                            self.out_of_memory_state.value_namespace = name_space
                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-group-id"):
                            self.redundancy_group_id = value
                            self.redundancy_group_id.value_namespace = name_space
                            self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-group-state"):
                            self.redundancy_group_state = value
                            self.redundancy_group_state.value_namespace = name_space
                            self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "redundancy-object-id"):
                            self.redundancy_object_id = value
                            self.redundancy_object_id.value_namespace = name_space
                            self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "tdm-media-mismatched"):
                            self.tdm_media_mismatched = value
                            self.tdm_media_mismatched.value_namespace = name_space
                            self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-id"):
                            self.xconnect_id = value
                            self.xconnect_id.value_namespace = name_space
                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                class PseudoWire(Entity):
                    """
                    Pseudowire
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_remote_down
                    
                    	Auto\-Discovered PW remote state down
                    	**type**\:  bool
                    
                    .. attribute:: admited_bw
                    
                    	Admited Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: auto_discovery
                    
                    	Is autodiscovery
                    	**type**\:  bool
                    
                    .. attribute:: backup_active
                    
                    	TRUE if backup is active
                    	**type**\:  bool
                    
                    .. attribute:: backup_force_active
                    
                    	TRUE if backup is active due to switchover
                    	**type**\:  bool
                    
                    .. attribute:: backup_pw
                    
                    	TRUE if PW is a backup PW
                    	**type**\:  bool
                    
                    .. attribute:: bitrate_mismatched
                    
                    	Bitrate mismatched
                    	**type**\:  bool
                    
                    .. attribute:: bridge_pw_type_mismatch
                    
                    	Oper down because Bridge has mismatched PW Types
                    	**type**\:  bool
                    
                    .. attribute:: cas_mismatched
                    
                    	CAS mismatched
                    	**type**\:  bool
                    
                    .. attribute:: diff_ts_mismatched
                    
                    	Differential timestamp mismatched
                    	**type**\:  bool
                    
                    .. attribute:: disable_delay
                    
                    	Backup disable delay
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                    
                    .. attribute:: evpn_src_acid
                    
                    	EVPN VPWS Source AC ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fe_ctype
                    
                    	Pseudowire FEC type
                    	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                    
                    .. attribute:: forward_class
                    
                    	Forward Class attribute
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: freq_mismatched
                    
                    	Frequency mismatched
                    	**type**\:  bool
                    
                    .. attribute:: illegal_control_word
                    
                    	Illegal control word
                    	**type**\:  bool
                    
                    .. attribute:: imposed_vlan_id
                    
                    	Imposed vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                    
                    .. attribute:: ipv6_local_source_address
                    
                    	Local IPv6 Source Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_evpnvpws_type
                    
                    	is EVPN VPWS
                    	**type**\:  bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: is_multi_segment_pseudowire
                    
                    	Is Multi\-Segment Pseudowire
                    	**type**\:  bool
                    
                    .. attribute:: is_partially_programmed
                    
                    	Is Pseudowire partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_pwr_type
                    
                    	is Pseudowire\-routed
                    	**type**\:  bool
                    
                    .. attribute:: is_vfi
                    
                    	Is VFI interface
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the pseudowire status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_down
                    
                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: ldp_label_advertise_failed
                    
                    	LDP label advertisment failed
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                    
                    .. attribute:: local_control_word
                    
                    	Local control word
                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                    
                    .. attribute:: local_label_failed
                    
                    	Failed to set BGP advertised local label
                    	**type**\:  bool
                    
                    .. attribute:: local_pseudo_wire_type
                    
                    	Local pseudowire type
                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                    
                    .. attribute:: local_signalling
                    
                    	Local signalling
                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                    
                    .. attribute:: local_source_address
                    
                    	Local Source Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_qinq
                    
                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                    	**type**\:  bool
                    
                    .. attribute:: num_ma_cwithdraw_msg_received
                    
                    	Num MW messages received over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ma_cwithdraw_message_sent
                    
                    	Num MW messages sent over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_pw
                    
                    	P2MP Pseudowire Information
                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw>`
                    
                    .. attribute:: payload_bytes_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: payload_type_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: peer_id
                    
                    	Peer
                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	Prefpath fallback enable/disable
                    	**type**\:  bool
                    
                    .. attribute:: primary_peer_id
                    
                    	Primary Peer IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: primary_pseudo_wire_id
                    
                    	Primary Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: primary_pw
                    
                    	TRUE if PW is a primary PW
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                    
                    .. attribute:: pseudo_wire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: pseudo_wire_state
                    
                    	Pseudowire state
                    	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                    
                    .. attribute:: pseudo_wire_type_mismatched
                    
                    	Pseudowire type mismatched
                    	**type**\:  bool
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type
                    
                    	Negotiated pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label Type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: pw_redundancy_initial_delay
                    
                    	Initial delay for redundant PW in seconds
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    .. attribute:: pw_redundancy_one_way
                    
                    	Force one\-way PW redundancy behaviour in Redundancy Group
                    	**type**\:  bool
                    
                    .. attribute:: pw_status_use
                    
                    	PW status in use
                    	**type**\:  bool
                    
                    .. attribute:: pwlsd_rewrite_failed
                    
                    	LSD rewrite failed
                    	**type**\:  bool
                    
                    .. attribute:: remote_control_word
                    
                    	Remote control word
                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                    
                    .. attribute:: remote_interface
                    
                    	Remote interface
                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                    
                    .. attribute:: remote_label_failed
                    
                    	Failed to set BGP advertised remote label
                    	**type**\:  bool
                    
                    .. attribute:: remote_pseudo_wire_type
                    
                    	Remote pseudowire type
                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                    
                    .. attribute:: remote_signalling
                    
                    	Remote signalling
                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                    
                    .. attribute:: required_bw
                    
                    	Required Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rtp_mismatched
                    
                    	RTP mismatched
                    	**type**\:  bool
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: sig_pkts_mismatched
                    
                    	Signalling packets mismatched
                    	**type**\:  bool
                    
                    .. attribute:: ssrc_mismatched
                    
                    	SSRC mismatched
                    	**type**\:  bool
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                    
                    .. attribute:: table_policy_name
                    
                    	Table\-policy Name
                    	**type**\:  str
                    
                    .. attribute:: tag_rewrite
                    
                    	StaticTagRewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: time_created
                    
                    	Time when the pseudowire was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_down
                    
                    	Time elapsed since last status down in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: transport_lsp_down
                    
                    	Oper down due to Transport LSP down
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__init__()

                        self.yang_name = "pseudo-wire"
                        self.yang_parent_name = "backup-segment"

                        self.ad_method = YLeaf(YType.uint32, "ad-method")

                        self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                        self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                        self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                        self.backup_active = YLeaf(YType.boolean, "backup-active")

                        self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                        self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                        self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                        self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                        self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                        self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                        self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                        self.disable_never = YLeaf(YType.boolean, "disable-never")

                        self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                        self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                        self.forward_class = YLeaf(YType.uint8, "forward-class")

                        self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                        self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                        self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                        self.interworking = YLeaf(YType.enumeration, "interworking")

                        self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                        self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                        self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                        self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                        self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                        self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                        self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                        self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                        self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                        self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                        self.load_balance = YLeaf(YType.enumeration, "load-balance")

                        self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                        self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                        self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                        self.local_source_address = YLeaf(YType.str, "local-source-address")

                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                        self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                        self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                        self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                        self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                        self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                        self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                        self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                        self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                        self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                        self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                        self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                        self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                        self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                        self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                        self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                        self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                        self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                        self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                        self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                        self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                        self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                        self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                        self.required_bw = YLeaf(YType.uint32, "required-bw")

                        self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                        self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                        self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                        self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                        self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                        self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                        self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                        self.time_created = YLeaf(YType.str, "time-created")

                        self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                        self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                        self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                        self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                        self.encapsulation_info = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                        self._children_yang_names.add("encapsulation-info")

                        self.local_interface = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                        self.local_interface.parent = self
                        self._children_name_map["local_interface"] = "local-interface"
                        self._children_yang_names.add("local-interface")

                        self.local_signalling = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                        self.local_signalling.parent = self
                        self._children_name_map["local_signalling"] = "local-signalling"
                        self._children_yang_names.add("local-signalling")

                        self.p2mp_pw = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                        self.p2mp_pw.parent = self
                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                        self._children_yang_names.add("p2mp-pw")

                        self.peer_id = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                        self.peer_id.parent = self
                        self._children_name_map["peer_id"] = "peer-id"
                        self._children_yang_names.add("peer-id")

                        self.preferred_path = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                        self.preferred_path.parent = self
                        self._children_name_map["preferred_path"] = "preferred-path"
                        self._children_yang_names.add("preferred-path")

                        self.remote_interface = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                        self.remote_interface.parent = self
                        self._children_name_map["remote_interface"] = "remote-interface"
                        self._children_yang_names.add("remote-interface")

                        self.remote_signalling = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                        self.remote_signalling.parent = self
                        self._children_name_map["remote_signalling"] = "remote-signalling"
                        self._children_yang_names.add("remote-signalling")

                        self.statistics = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ad_method",
                                        "ad_remote_down",
                                        "admited_bw",
                                        "auto_discovery",
                                        "backup_active",
                                        "backup_force_active",
                                        "backup_pw",
                                        "bitrate_mismatched",
                                        "bridge_pw_type_mismatch",
                                        "cas_mismatched",
                                        "diff_ts_mismatched",
                                        "disable_delay",
                                        "disable_never",
                                        "evpn_src_acid",
                                        "fe_ctype",
                                        "forward_class",
                                        "freq_mismatched",
                                        "illegal_control_word",
                                        "imposed_vlan_id",
                                        "interworking",
                                        "ipv6_local_source_address",
                                        "is_evpnvpws_type",
                                        "is_flow_label_static",
                                        "is_multi_segment_pseudowire",
                                        "is_partially_programmed",
                                        "is_pwr_type",
                                        "is_vfi",
                                        "last_time_status_changed",
                                        "last_time_status_down",
                                        "ldp_label_advertise_failed",
                                        "load_balance",
                                        "local_control_word",
                                        "local_label_failed",
                                        "local_pseudo_wire_type",
                                        "local_source_address",
                                        "mac_limit_oper_down",
                                        "mtu_mismatched",
                                        "not_supported_qinq",
                                        "num_ma_cwithdraw_msg_received",
                                        "number_ma_cwithdraw_message_sent",
                                        "out_of_memory_state",
                                        "payload_bytes_mismatched",
                                        "payload_type_mismatched",
                                        "preferred_path_disable_fallback",
                                        "primary_peer_id",
                                        "primary_pseudo_wire_id",
                                        "primary_pw",
                                        "protocol",
                                        "pseudo_wire_id",
                                        "pseudo_wire_state",
                                        "pseudo_wire_type_mismatched",
                                        "pw_class_name",
                                        "pw_flow_label_code17_disabled",
                                        "pw_flow_label_type",
                                        "pw_flow_label_type_cfg",
                                        "pw_redundancy_initial_delay",
                                        "pw_redundancy_one_way",
                                        "pw_status_use",
                                        "pwlsd_rewrite_failed",
                                        "remote_control_word",
                                        "remote_label_failed",
                                        "remote_pseudo_wire_type",
                                        "required_bw",
                                        "resync_enabled",
                                        "resync_threshold",
                                        "rtp_mismatched",
                                        "sequencing_type",
                                        "shutdown",
                                        "sig_pkts_mismatched",
                                        "ssrc_mismatched",
                                        "state",
                                        "table_policy_name",
                                        "tag_rewrite",
                                        "time_created",
                                        "time_elapsed_creation",
                                        "time_elapsed_status_changed",
                                        "time_elapsed_status_down",
                                        "transport_lsp_down",
                                        "xconnect_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__setattr__(name, value)


                    class PeerId(Entity):
                        """
                        Peer
                        
                        .. attribute:: internal_label
                        
                        	Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_peer_id
                        
                        	Peer IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_peer_id
                        
                        	Peer IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: type
                        
                        	type
                        	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__init__()

                            self.yang_name = "peer-id"
                            self.yang_parent_name = "pseudo-wire"

                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                            self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                            self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                            self.type = YLeaf(YType.enumeration, "type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("internal_label",
                                            "ipv4_peer_id",
                                            "ipv6_peer_id",
                                            "type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.internal_label.is_set or
                                self.ipv4_peer_id.is_set or
                                self.ipv6_peer_id.is_set or
                                self.type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.internal_label.yfilter != YFilter.not_set or
                                self.ipv4_peer_id.yfilter != YFilter.not_set or
                                self.ipv6_peer_id.yfilter != YFilter.not_set or
                                self.type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "peer-id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                            if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                            if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "internal-label"):
                                self.internal_label = value
                                self.internal_label.value_namespace = name_space
                                self.internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-peer-id"):
                                self.ipv4_peer_id = value
                                self.ipv4_peer_id.value_namespace = name_space
                                self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-peer-id"):
                                self.ipv6_peer_id = value
                                self.ipv6_peer_id.value_namespace = name_space
                                self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "type"):
                                self.type = value
                                self.type.value_namespace = name_space
                                self.type.value_namespace_prefix = name_space_prefix


                    class EncapsulationInfo(Entity):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: atom
                        
                        	atom
                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__init__()

                            self.yang_name = "encapsulation-info"
                            self.yang_parent_name = "pseudo-wire"

                            self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                            self.atom = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                            self.atom.parent = self
                            self._children_name_map["atom"] = "atom"
                            self._children_yang_names.add("atom")

                            self.l2tpv3 = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self
                            self._children_name_map["l2tpv3"] = "l2tpv3"
                            self._children_yang_names.add("l2tpv3")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("encapsulation") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__setattr__(name, value)


                        class Atom(Entity):
                            """
                            atom
                            
                            .. attribute:: is_pseudowire_headend
                            
                            	Is this connected to a PW\-HE AC
                            	**type**\:  bool
                            
                            .. attribute:: is_sai_itype2
                            
                            	Is SAII FEC129 Type 2
                            	**type**\:  bool
                            
                            .. attribute:: is_tai_itype2
                            
                            	Is TAII type 2
                            	**type**\:  bool
                            
                            .. attribute:: ldp_label_advertisment_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: local_agi
                            
                            	Local Attachment Group Identifier
                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                            
                            .. attribute:: local_c_ctype
                            
                            	Local VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_ceid
                            
                            	Local CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cv_type
                            
                            	Local VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_group_id
                            
                            	Local group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ldp_id
                            
                            	Local LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_saii_gbl_id
                            
                            	Local SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_saiiac_id
                            
                            	Local SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taii_gbl_id
                            
                            	Local TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taiiac_id
                            
                            	Local TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_veid
                            
                            	Local VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: multi_segment_pseudowire_stats
                            
                            	Multisegment pseudowire statistics
                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                            
                            .. attribute:: rem_saii
                            
                            	Remote Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_saii_gbl_id
                            
                            	Remote SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_saiiac_id
                            
                            	Remote SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taii
                            
                            	Remote Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_taii_gbl_id
                            
                            	Remote TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taiiac_id
                            
                            	Remote TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_agi
                            
                            	Remote Attachment Group Identifier
                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                            
                            .. attribute:: remote_c_ctype
                            
                            	Remote VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_ceid
                            
                            	Remote CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cv_type
                            
                            	Remote VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_group_id
                            
                            	Remote group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_label
                            
                            	Remote label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ldp_id
                            
                            	Remote LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_source_address
                            
                            	Remote BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_veid
                            
                            	Remote VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_address
                            
                            	Local BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                self.yang_name = "atom"
                                self.yang_parent_name = "encapsulation-info"

                                self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                self.local_veid = YLeaf(YType.uint32, "local-veid")

                                self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                self.rem_saii = YLeaf(YType.str, "rem-saii")

                                self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                self.rem_taii = YLeaf(YType.str, "rem-taii")

                                self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                self.saii = YLeaf(YType.str, "saii")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.taii = YLeaf(YType.str, "taii")

                                self.local_agi = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                self.local_agi.parent = self
                                self._children_name_map["local_agi"] = "local-agi"
                                self._children_yang_names.add("local-agi")

                                self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                self.multi_segment_pseudowire_stats.parent = self
                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                self._children_yang_names.add("multi-segment-pseudowire-stats")

                                self.remote_agi = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                self.remote_agi.parent = self
                                self._children_name_map["remote_agi"] = "remote-agi"
                                self._children_yang_names.add("remote-agi")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_pseudowire_headend",
                                                "is_sai_itype2",
                                                "is_tai_itype2",
                                                "ldp_label_advertisment_failed",
                                                "local_c_ctype",
                                                "local_ceid",
                                                "local_cv_type",
                                                "local_group_id",
                                                "local_label",
                                                "local_ldp_id",
                                                "local_saii_gbl_id",
                                                "local_saiiac_id",
                                                "local_taii_gbl_id",
                                                "local_taiiac_id",
                                                "local_veid",
                                                "lsd_rewrite_failed",
                                                "rem_saii",
                                                "rem_saii_gbl_id",
                                                "rem_saiiac_id",
                                                "rem_taii",
                                                "rem_taii_gbl_id",
                                                "rem_taiiac_id",
                                                "remote_c_ctype",
                                                "remote_ceid",
                                                "remote_cv_type",
                                                "remote_group_id",
                                                "remote_label",
                                                "remote_ldp_id",
                                                "remote_source_address",
                                                "remote_veid",
                                                "saii",
                                                "source_address",
                                                "taii") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                            class LocalAgi(Entity):
                                """
                                Local Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                    self.yang_name = "local-agi"
                                    self.yang_parent_name = "atom"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "local-agi"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "local-agi"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "local-agi"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-agi" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class RemoteAgi(Entity):
                                """
                                Remote Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                    self.yang_name = "remote-agi"
                                    self.yang_parent_name = "atom"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "remote-agi"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "remote-agi"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "remote-agi"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-agi" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class MultiSegmentPseudowireStats(Entity):
                                """
                                Multisegment pseudowire statistics
                                
                                .. attribute:: received_bytes
                                
                                	Bytes received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: received_packets
                                
                                	Packets received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                    self.yang_name = "multi-segment-pseudowire-stats"
                                    self.yang_parent_name = "atom"

                                    self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                    self.received_packets = YLeaf(YType.uint64, "received-packets")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("received_bytes",
                                                    "received_packets") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.received_bytes.is_set or
                                        self.received_packets.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.received_bytes.yfilter != YFilter.not_set or
                                        self.received_packets.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                    if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_packets.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-bytes" or name == "received-packets"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "received-bytes"):
                                        self.received_bytes = value
                                        self.received_bytes.value_namespace = name_space
                                        self.received_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-packets"):
                                        self.received_packets = value
                                        self.received_packets.value_namespace = name_space
                                        self.received_packets.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.is_pseudowire_headend.is_set or
                                    self.is_sai_itype2.is_set or
                                    self.is_tai_itype2.is_set or
                                    self.ldp_label_advertisment_failed.is_set or
                                    self.local_c_ctype.is_set or
                                    self.local_ceid.is_set or
                                    self.local_cv_type.is_set or
                                    self.local_group_id.is_set or
                                    self.local_label.is_set or
                                    self.local_ldp_id.is_set or
                                    self.local_saii_gbl_id.is_set or
                                    self.local_saiiac_id.is_set or
                                    self.local_taii_gbl_id.is_set or
                                    self.local_taiiac_id.is_set or
                                    self.local_veid.is_set or
                                    self.lsd_rewrite_failed.is_set or
                                    self.rem_saii.is_set or
                                    self.rem_saii_gbl_id.is_set or
                                    self.rem_saiiac_id.is_set or
                                    self.rem_taii.is_set or
                                    self.rem_taii_gbl_id.is_set or
                                    self.rem_taiiac_id.is_set or
                                    self.remote_c_ctype.is_set or
                                    self.remote_ceid.is_set or
                                    self.remote_cv_type.is_set or
                                    self.remote_group_id.is_set or
                                    self.remote_label.is_set or
                                    self.remote_ldp_id.is_set or
                                    self.remote_source_address.is_set or
                                    self.remote_veid.is_set or
                                    self.saii.is_set or
                                    self.source_address.is_set or
                                    self.taii.is_set or
                                    (self.local_agi is not None and self.local_agi.has_data()) or
                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                    (self.remote_agi is not None and self.remote_agi.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                    self.is_sai_itype2.yfilter != YFilter.not_set or
                                    self.is_tai_itype2.yfilter != YFilter.not_set or
                                    self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                    self.local_c_ctype.yfilter != YFilter.not_set or
                                    self.local_ceid.yfilter != YFilter.not_set or
                                    self.local_cv_type.yfilter != YFilter.not_set or
                                    self.local_group_id.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_ldp_id.yfilter != YFilter.not_set or
                                    self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                    self.local_saiiac_id.yfilter != YFilter.not_set or
                                    self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                    self.local_taiiac_id.yfilter != YFilter.not_set or
                                    self.local_veid.yfilter != YFilter.not_set or
                                    self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.rem_saii.yfilter != YFilter.not_set or
                                    self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                    self.rem_saiiac_id.yfilter != YFilter.not_set or
                                    self.rem_taii.yfilter != YFilter.not_set or
                                    self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                    self.rem_taiiac_id.yfilter != YFilter.not_set or
                                    self.remote_c_ctype.yfilter != YFilter.not_set or
                                    self.remote_ceid.yfilter != YFilter.not_set or
                                    self.remote_cv_type.yfilter != YFilter.not_set or
                                    self.remote_group_id.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_ldp_id.yfilter != YFilter.not_set or
                                    self.remote_source_address.yfilter != YFilter.not_set or
                                    self.remote_veid.yfilter != YFilter.not_set or
                                    self.saii.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.taii.yfilter != YFilter.not_set or
                                    (self.local_agi is not None and self.local_agi.has_operation()) or
                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                    (self.remote_agi is not None and self.remote_agi.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "atom" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_veid.get_name_leafdata())
                                if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.saii.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.taii.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-agi"):
                                    if (self.local_agi is None):
                                        self.local_agi = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                    return self.local_agi

                                if (child_yang_name == "multi-segment-pseudowire-stats"):
                                    if (self.multi_segment_pseudowire_stats is None):
                                        self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    return self.multi_segment_pseudowire_stats

                                if (child_yang_name == "remote-agi"):
                                    if (self.remote_agi is None):
                                        self.remote_agi = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                    return self.remote_agi

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-pseudowire-headend"):
                                    self.is_pseudowire_headend = value
                                    self.is_pseudowire_headend.value_namespace = name_space
                                    self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-sai-itype2"):
                                    self.is_sai_itype2 = value
                                    self.is_sai_itype2.value_namespace = name_space
                                    self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-tai-itype2"):
                                    self.is_tai_itype2 = value
                                    self.is_tai_itype2.value_namespace = name_space
                                    self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertisment-failed"):
                                    self.ldp_label_advertisment_failed = value
                                    self.ldp_label_advertisment_failed.value_namespace = name_space
                                    self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-c-ctype"):
                                    self.local_c_ctype = value
                                    self.local_c_ctype.value_namespace = name_space
                                    self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ceid"):
                                    self.local_ceid = value
                                    self.local_ceid.value_namespace = name_space
                                    self.local_ceid.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cv-type"):
                                    self.local_cv_type = value
                                    self.local_cv_type.value_namespace = name_space
                                    self.local_cv_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-group-id"):
                                    self.local_group_id = value
                                    self.local_group_id.value_namespace = name_space
                                    self.local_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ldp-id"):
                                    self.local_ldp_id = value
                                    self.local_ldp_id.value_namespace = name_space
                                    self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-saii-gbl-id"):
                                    self.local_saii_gbl_id = value
                                    self.local_saii_gbl_id.value_namespace = name_space
                                    self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-saiiac-id"):
                                    self.local_saiiac_id = value
                                    self.local_saiiac_id.value_namespace = name_space
                                    self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-taii-gbl-id"):
                                    self.local_taii_gbl_id = value
                                    self.local_taii_gbl_id.value_namespace = name_space
                                    self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-taiiac-id"):
                                    self.local_taiiac_id = value
                                    self.local_taiiac_id.value_namespace = name_space
                                    self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-veid"):
                                    self.local_veid = value
                                    self.local_veid.value_namespace = name_space
                                    self.local_veid.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsd-rewrite-failed"):
                                    self.lsd_rewrite_failed = value
                                    self.lsd_rewrite_failed.value_namespace = name_space
                                    self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saii"):
                                    self.rem_saii = value
                                    self.rem_saii.value_namespace = name_space
                                    self.rem_saii.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saii-gbl-id"):
                                    self.rem_saii_gbl_id = value
                                    self.rem_saii_gbl_id.value_namespace = name_space
                                    self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saiiac-id"):
                                    self.rem_saiiac_id = value
                                    self.rem_saiiac_id.value_namespace = name_space
                                    self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taii"):
                                    self.rem_taii = value
                                    self.rem_taii.value_namespace = name_space
                                    self.rem_taii.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taii-gbl-id"):
                                    self.rem_taii_gbl_id = value
                                    self.rem_taii_gbl_id.value_namespace = name_space
                                    self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taiiac-id"):
                                    self.rem_taiiac_id = value
                                    self.rem_taiiac_id.value_namespace = name_space
                                    self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-c-ctype"):
                                    self.remote_c_ctype = value
                                    self.remote_c_ctype.value_namespace = name_space
                                    self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ceid"):
                                    self.remote_ceid = value
                                    self.remote_ceid.value_namespace = name_space
                                    self.remote_ceid.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cv-type"):
                                    self.remote_cv_type = value
                                    self.remote_cv_type.value_namespace = name_space
                                    self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-group-id"):
                                    self.remote_group_id = value
                                    self.remote_group_id.value_namespace = name_space
                                    self.remote_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ldp-id"):
                                    self.remote_ldp_id = value
                                    self.remote_ldp_id.value_namespace = name_space
                                    self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-source-address"):
                                    self.remote_source_address = value
                                    self.remote_source_address.value_namespace = name_space
                                    self.remote_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-veid"):
                                    self.remote_veid = value
                                    self.remote_veid.value_namespace = name_space
                                    self.remote_veid.value_namespace_prefix = name_space_prefix
                                if(value_path == "saii"):
                                    self.saii = value
                                    self.saii.value_namespace = name_space
                                    self.saii.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "taii"):
                                    self.taii = value
                                    self.taii.value_namespace = name_space
                                    self.taii.value_namespace_prefix = name_space_prefix


                        class L2Tpv3(Entity):
                            """
                            l2tpv3
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_source_address
                            
                            	IPv6 source address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: local_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_size
                            
                            	Local cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_secondary_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_size
                            
                            	Local secondary cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_session_id
                            
                            	Local session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: remote_circuit_status_up
                            
                            	RemoteCircuitStatusUp
                            	**type**\:  bool
                            
                            .. attribute:: remote_cookie_high_value
                            
                            	Upper 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_low_value
                            
                            	Lower 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_size
                            
                            	Remote cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_session_id
                            
                            	Remote session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_state
                            
                            	L2TP tunnel state
                            	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__init__()

                                self.yang_name = "l2tpv3"
                                self.yang_parent_name = "encapsulation-info"

                                self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                self.tos = YLeaf(YType.uint8, "tos")

                                self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                self.ttl = YLeaf(YType.uint8, "ttl")

                                self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dont_fragment_bit",
                                                "ipv4_source_address",
                                                "ipv6_source_address",
                                                "l2tp_class_name",
                                                "local_cookie_high_value",
                                                "local_cookie_low_value",
                                                "local_cookie_size",
                                                "local_secondary_cookie_high_value",
                                                "local_secondary_cookie_low_value",
                                                "local_secondary_cookie_size",
                                                "local_session_id",
                                                "path_mtu_enabled",
                                                "path_mtu_max_value",
                                                "remote_circuit_status_up",
                                                "remote_cookie_high_value",
                                                "remote_cookie_low_value",
                                                "remote_cookie_size",
                                                "remote_session_id",
                                                "tos",
                                                "tos_mode",
                                                "ttl",
                                                "tunnel_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dont_fragment_bit.is_set or
                                    self.ipv4_source_address.is_set or
                                    self.ipv6_source_address.is_set or
                                    self.l2tp_class_name.is_set or
                                    self.local_cookie_high_value.is_set or
                                    self.local_cookie_low_value.is_set or
                                    self.local_cookie_size.is_set or
                                    self.local_secondary_cookie_high_value.is_set or
                                    self.local_secondary_cookie_low_value.is_set or
                                    self.local_secondary_cookie_size.is_set or
                                    self.local_session_id.is_set or
                                    self.path_mtu_enabled.is_set or
                                    self.path_mtu_max_value.is_set or
                                    self.remote_circuit_status_up.is_set or
                                    self.remote_cookie_high_value.is_set or
                                    self.remote_cookie_low_value.is_set or
                                    self.remote_cookie_size.is_set or
                                    self.remote_session_id.is_set or
                                    self.tos.is_set or
                                    self.tos_mode.is_set or
                                    self.ttl.is_set or
                                    self.tunnel_state.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dont_fragment_bit.yfilter != YFilter.not_set or
                                    self.ipv4_source_address.yfilter != YFilter.not_set or
                                    self.ipv6_source_address.yfilter != YFilter.not_set or
                                    self.l2tp_class_name.yfilter != YFilter.not_set or
                                    self.local_cookie_high_value.yfilter != YFilter.not_set or
                                    self.local_cookie_low_value.yfilter != YFilter.not_set or
                                    self.local_cookie_size.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                    self.local_session_id.yfilter != YFilter.not_set or
                                    self.path_mtu_enabled.yfilter != YFilter.not_set or
                                    self.path_mtu_max_value.yfilter != YFilter.not_set or
                                    self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                    self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                    self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                    self.remote_cookie_size.yfilter != YFilter.not_set or
                                    self.remote_session_id.yfilter != YFilter.not_set or
                                    self.tos.yfilter != YFilter.not_set or
                                    self.tos_mode.yfilter != YFilter.not_set or
                                    self.ttl.yfilter != YFilter.not_set or
                                    self.tunnel_state.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2tpv3" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos.get_name_leafdata())
                                if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ttl.get_name_leafdata())
                                if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dont-fragment-bit"):
                                    self.dont_fragment_bit = value
                                    self.dont_fragment_bit.value_namespace = name_space
                                    self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-source-address"):
                                    self.ipv4_source_address = value
                                    self.ipv4_source_address.value_namespace = name_space
                                    self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-source-address"):
                                    self.ipv6_source_address = value
                                    self.ipv6_source_address.value_namespace = name_space
                                    self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "l2tp-class-name"):
                                    self.l2tp_class_name = value
                                    self.l2tp_class_name.value_namespace = name_space
                                    self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-high-value"):
                                    self.local_cookie_high_value = value
                                    self.local_cookie_high_value.value_namespace = name_space
                                    self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-low-value"):
                                    self.local_cookie_low_value = value
                                    self.local_cookie_low_value.value_namespace = name_space
                                    self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-size"):
                                    self.local_cookie_size = value
                                    self.local_cookie_size.value_namespace = name_space
                                    self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-high-value"):
                                    self.local_secondary_cookie_high_value = value
                                    self.local_secondary_cookie_high_value.value_namespace = name_space
                                    self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-low-value"):
                                    self.local_secondary_cookie_low_value = value
                                    self.local_secondary_cookie_low_value.value_namespace = name_space
                                    self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-size"):
                                    self.local_secondary_cookie_size = value
                                    self.local_secondary_cookie_size.value_namespace = name_space
                                    self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-session-id"):
                                    self.local_session_id = value
                                    self.local_session_id.value_namespace = name_space
                                    self.local_session_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-enabled"):
                                    self.path_mtu_enabled = value
                                    self.path_mtu_enabled.value_namespace = name_space
                                    self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-max-value"):
                                    self.path_mtu_max_value = value
                                    self.path_mtu_max_value.value_namespace = name_space
                                    self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-circuit-status-up"):
                                    self.remote_circuit_status_up = value
                                    self.remote_circuit_status_up.value_namespace = name_space
                                    self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-high-value"):
                                    self.remote_cookie_high_value = value
                                    self.remote_cookie_high_value.value_namespace = name_space
                                    self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-low-value"):
                                    self.remote_cookie_low_value = value
                                    self.remote_cookie_low_value.value_namespace = name_space
                                    self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-size"):
                                    self.remote_cookie_size = value
                                    self.remote_cookie_size.value_namespace = name_space
                                    self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-session-id"):
                                    self.remote_session_id = value
                                    self.remote_session_id.value_namespace = name_space
                                    self.remote_session_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos"):
                                    self.tos = value
                                    self.tos.value_namespace = name_space
                                    self.tos.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos-mode"):
                                    self.tos_mode = value
                                    self.tos_mode.value_namespace = name_space
                                    self.tos_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "ttl"):
                                    self.ttl = value
                                    self.ttl.value_namespace = name_space
                                    self.ttl.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-state"):
                                    self.tunnel_state = value
                                    self.tunnel_state.value_namespace = name_space
                                    self.tunnel_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.encapsulation.is_set or
                                (self.atom is not None and self.atom.has_data()) or
                                (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.encapsulation.yfilter != YFilter.not_set or
                                (self.atom is not None and self.atom.has_operation()) or
                                (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "encapsulation-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "atom"):
                                if (self.atom is None):
                                    self.atom = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                return self.atom

                            if (child_yang_name == "l2tpv3"):
                                if (self.l2tpv3 is None):
                                    self.l2tpv3 = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                return self.l2tpv3

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "encapsulation"):
                                self.encapsulation = value
                                self.encapsulation.value_namespace = name_space
                                self.encapsulation.value_namespace_prefix = name_space_prefix


                    class LocalInterface(Entity):
                        """
                        Local interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__init__()

                            self.yang_name = "local-interface"
                            self.yang_parent_name = "pseudo-wire"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "local-interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class RemoteInterface(Entity):
                        """
                        Remote interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__init__()

                            self.yang_name = "remote-interface"
                            self.yang_parent_name = "pseudo-wire"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "remote-interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class PreferredPath(Entity):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__init__()

                            self.yang_name = "preferred-path"
                            self.yang_parent_name = "pseudo-wire"

                            self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                            self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                            self.option = YLeaf(YType.enumeration, "option")

                            self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                            self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ip_tunnel_interface_number",
                                            "next_hop_ip",
                                            "option",
                                            "te_tunnel_interface_number",
                                            "tp_tunnel_interface_number") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ip_tunnel_interface_number.is_set or
                                self.next_hop_ip.is_set or
                                self.option.is_set or
                                self.te_tunnel_interface_number.is_set or
                                self.tp_tunnel_interface_number.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set or
                                self.option.yfilter != YFilter.not_set or
                                self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "preferred-path" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                            if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.option.get_name_leafdata())
                            if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                            if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ip-tunnel-interface-number"):
                                self.ip_tunnel_interface_number = value
                                self.ip_tunnel_interface_number.value_namespace = name_space
                                self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix
                            if(value_path == "option"):
                                self.option = value
                                self.option.value_namespace = name_space
                                self.option.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-tunnel-interface-number"):
                                self.te_tunnel_interface_number = value
                                self.te_tunnel_interface_number.value_namespace = name_space
                                self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "tp-tunnel-interface-number"):
                                self.tp_tunnel_interface_number = value
                                self.tp_tunnel_interface_number.value_namespace = name_space
                                self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                    class LocalSignalling(Entity):
                        """
                        Local signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__init__()

                            self.yang_name = "local-signalling"
                            self.yang_parent_name = "pseudo-wire"

                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                            self.status_tlv = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self._children_name_map["status_tlv"] = "status-tlv"
                            self._children_yang_names.add("status-tlv")

                            self.tlv = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pw_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__setattr__(name, value)


                        class StatusTlv(Entity):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                self.yang_name = "status-tlv"
                                self.yang_parent_name = "local-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "status-tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix


                        class Tlv(Entity):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "local-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/local-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.tlv:
                                if (c.has_data()):
                                    return True
                            return (
                                self.pw_status.is_set or
                                (self.status_tlv is not None and self.status_tlv.has_data()))

                        def has_operation(self):
                            for c in self.tlv:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pw_status.yfilter != YFilter.not_set or
                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-signalling" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "status-tlv"):
                                if (self.status_tlv is None):
                                    self.status_tlv = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                return self.status_tlv

                            if (child_yang_name == "tlv"):
                                for c in self.tlv:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.tlv.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pw-status"):
                                self.pw_status = value
                                self.pw_status.value_namespace = name_space
                                self.pw_status.value_namespace_prefix = name_space_prefix


                    class RemoteSignalling(Entity):
                        """
                        Remote signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__init__()

                            self.yang_name = "remote-signalling"
                            self.yang_parent_name = "pseudo-wire"

                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                            self.status_tlv = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self._children_name_map["status_tlv"] = "status-tlv"
                            self._children_yang_names.add("status-tlv")

                            self.tlv = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pw_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__setattr__(name, value)


                        class StatusTlv(Entity):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                self.yang_name = "status-tlv"
                                self.yang_parent_name = "remote-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "status-tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix


                        class Tlv(Entity):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "remote-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/remote-signalling/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.tlv:
                                if (c.has_data()):
                                    return True
                            return (
                                self.pw_status.is_set or
                                (self.status_tlv is not None and self.status_tlv.has_data()))

                        def has_operation(self):
                            for c in self.tlv:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pw_status.yfilter != YFilter.not_set or
                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-signalling" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "status-tlv"):
                                if (self.status_tlv is None):
                                    self.status_tlv = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                return self.status_tlv

                            if (child_yang_name == "tlv"):
                                for c in self.tlv:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.tlv.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pw-status"):
                                self.pw_status = value
                                self.pw_status.value_namespace = name_space
                                self.pw_status.value_namespace_prefix = name_space_prefix


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "pseudo-wire"

                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                            self._children_yang_names.add("dispostion-stats")

                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self._children_name_map["impostion_stats"] = "impostion-stats"
                            self._children_yang_names.add("impostion-stats")

                            self.sequence_number = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                            self.sequence_number.parent = self
                            self._children_name_map["sequence_number"] = "sequence-number"
                            self._children_yang_names.add("sequence-number")


                        class ImpostionStats(Entity):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                self.yang_name = "impostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self._children_name_map["broadcast"] = "broadcast"
                                self._children_yang_names.add("broadcast")

                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                self._children_yang_names.add("imposition-mtu-drop")

                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                self._children_yang_names.add("imposition-stat")

                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                self._children_yang_names.add("impostion-tail-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                self._children_yang_names.add("l2fsbi-drop")

                                self.multicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                                self._children_yang_names.add("multicast")

                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self
                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                self._children_yang_names.add("unknown-unicast")


                            class ImpositionStat(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                    self.yang_name = "imposition-stat"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpositionMtuDrop(Entity):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                    self.yang_name = "imposition-mtu-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpostionTailDrop(Entity):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                    self.yang_name = "impostion-tail-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class L2FsbiDrop(Entity):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                    self.yang_name = "l2fsbi-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fsbi-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Multicast(Entity):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Broadcast(Entity):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                    self.yang_name = "broadcast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnknownUnicast(Entity):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                    self.yang_name = "unknown-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unknown-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                    (self.multicast is not None and self.multicast.has_data()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                    (self.multicast is not None and self.multicast.has_operation()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "impostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast"):
                                    if (self.broadcast is None):
                                        self.broadcast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                    return self.broadcast

                                if (child_yang_name == "imposition-mtu-drop"):
                                    if (self.imposition_mtu_drop is None):
                                        self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    return self.imposition_mtu_drop

                                if (child_yang_name == "imposition-stat"):
                                    if (self.imposition_stat is None):
                                        self.imposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                    return self.imposition_stat

                                if (child_yang_name == "impostion-tail-drop"):
                                    if (self.impostion_tail_drop is None):
                                        self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    return self.impostion_tail_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "l2fsbi-drop"):
                                    if (self.l2fsbi_drop is None):
                                        self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    return self.l2fsbi_drop

                                if (child_yang_name == "multicast"):
                                    if (self.multicast is None):
                                        self.multicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                    return self.multicast

                                if (child_yang_name == "unknown-unicast"):
                                    if (self.unknown_unicast is None):
                                        self.unknown_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    return self.unknown_unicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DispostionStats(Entity):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats, self).__init__()

                                self.yang_name = "dispostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                self._children_yang_names.add("broadcast-drop")

                                self.dai_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self._children_name_map["dai_drop"] = "dai-drop"
                                self._children_yang_names.add("dai-drop")

                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                self._children_yang_names.add("disposition-mtu-drop")

                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                self._children_yang_names.add("disposition-oo-o-drops")

                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                self._children_yang_names.add("disposition-p2mp-stats")

                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                self._children_yang_names.add("disposition-stat")

                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                self._children_yang_names.add("disposition-tail-drop")

                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                self._children_yang_names.add("ipsg-drop")

                                self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.mac_move = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self._children_name_map["mac_move"] = "mac-move"
                                self._children_yang_names.add("mac-move")

                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                self._children_yang_names.add("multicast-drop")

                                self.received_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self._children_name_map["received_drops"] = "received-drops"
                                self._children_yang_names.add("received-drops")

                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self
                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                self._children_yang_names.add("unicast-drop")


                            class DispositionStat(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                    self.yang_name = "disposition-stat"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionMtuDrop(Entity):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                    self.yang_name = "disposition-mtu-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionTailDrop(Entity):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                    self.yang_name = "disposition-tail-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MulticastDrop(Entity):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                    self.yang_name = "multicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnicastDrop(Entity):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                    self.yang_name = "unicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class BroadcastDrop(Entity):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                    self.yang_name = "broadcast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ReceivedDrops(Entity):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                    self.yang_name = "received-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DaiDrop(Entity):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                    self.yang_name = "dai-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dai-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class IpsgDrop(Entity):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                    self.yang_name = "ipsg-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipsg-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionOoODrops(Entity):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                    self.yang_name = "disposition-oo-o-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionP2MpStats(Entity):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                    self.yang_name = "disposition-p2mp-stats"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MacMove(Entity):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                    self.yang_name = "mac-move"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-move" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dispostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast-drop"):
                                    if (self.broadcast_drop is None):
                                        self.broadcast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    return self.broadcast_drop

                                if (child_yang_name == "dai-drop"):
                                    if (self.dai_drop is None):
                                        self.dai_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                    return self.dai_drop

                                if (child_yang_name == "disposition-mtu-drop"):
                                    if (self.disposition_mtu_drop is None):
                                        self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    return self.disposition_mtu_drop

                                if (child_yang_name == "disposition-oo-o-drops"):
                                    if (self.disposition_oo_o_drops is None):
                                        self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    return self.disposition_oo_o_drops

                                if (child_yang_name == "disposition-p2mp-stats"):
                                    if (self.disposition_p2mp_stats is None):
                                        self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    return self.disposition_p2mp_stats

                                if (child_yang_name == "disposition-stat"):
                                    if (self.disposition_stat is None):
                                        self.disposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                    return self.disposition_stat

                                if (child_yang_name == "disposition-tail-drop"):
                                    if (self.disposition_tail_drop is None):
                                        self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    return self.disposition_tail_drop

                                if (child_yang_name == "ipsg-drop"):
                                    if (self.ipsg_drop is None):
                                        self.ipsg_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    return self.ipsg_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "mac-move"):
                                    if (self.mac_move is None):
                                        self.mac_move = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                    return self.mac_move

                                if (child_yang_name == "multicast-drop"):
                                    if (self.multicast_drop is None):
                                        self.multicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                    return self.multicast_drop

                                if (child_yang_name == "received-drops"):
                                    if (self.received_drops is None):
                                        self.received_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                    return self.received_drops

                                if (child_yang_name == "unicast-drop"):
                                    if (self.unicast_drop is None):
                                        self.unicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                    return self.unicast_drop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SequenceNumber(Entity):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                self.yang_name = "sequence-number"
                                self.yang_parent_name = "statistics"

                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bypassed_inbound_sequence_packet",
                                                "bypassed_out_sequence_packet",
                                                "sequence_number_expected",
                                                "sequence_number_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bypassed_inbound_sequence_packet.is_set or
                                    self.bypassed_out_sequence_packet.is_set or
                                    self.sequence_number_expected.is_set or
                                    self.sequence_number_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sequence-number" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bypassed-inbound-sequence-packet"):
                                    self.bypassed_inbound_sequence_packet = value
                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "bypassed-out-sequence-packet"):
                                    self.bypassed_out_sequence_packet = value
                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-expected"):
                                    self.sequence_number_expected = value
                                    self.sequence_number_expected.value_namespace = name_space
                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-sent"):
                                    self.sequence_number_sent = value
                                    self.sequence_number_sent.value_namespace = name_space
                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                (self.sequence_number is not None and self.sequence_number.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dispostion-stats"):
                                if (self.dispostion_stats is None):
                                    self.dispostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                return self.dispostion_stats

                            if (child_yang_name == "impostion-stats"):
                                if (self.impostion_stats is None):
                                    self.impostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                return self.impostion_stats

                            if (child_yang_name == "sequence-number"):
                                if (self.sequence_number is None):
                                    self.sequence_number = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                return self.sequence_number

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class P2MpPw(Entity):
                        """
                        P2MP Pseudowire Information
                        
                        .. attribute:: local_available
                        
                        	Local LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: local_extended_tunnel_id
                        
                        	Local Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_flags
                        
                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: local_label
                        
                        	Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_p2mp_id
                        
                        	Local P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_ptree_type
                        
                        	Local P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                        
                        .. attribute:: local_tunnel_id
                        
                        	Local Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_available
                        
                        	Remote LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: remote_extended_tunnel_id
                        
                        	Remote Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_flags
                        
                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_label
                        
                        	Remote Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_p2mp_id
                        
                        	Remote P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_ptree_type
                        
                        	Remote P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                        
                        .. attribute:: remote_tunnel_id
                        
                        	Remote Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__init__()

                            self.yang_name = "p2mp-pw"
                            self.yang_parent_name = "pseudo-wire"

                            self.local_available = YLeaf(YType.boolean, "local-available")

                            self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                            self.local_flags = YLeaf(YType.uint8, "local-flags")

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                            self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                            self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                            self.remote_available = YLeaf(YType.boolean, "remote-available")

                            self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                            self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                            self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                            self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                            self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("local_available",
                                            "local_extended_tunnel_id",
                                            "local_flags",
                                            "local_label",
                                            "local_p2mp_id",
                                            "local_ptree_type",
                                            "local_tunnel_id",
                                            "remote_available",
                                            "remote_extended_tunnel_id",
                                            "remote_flags",
                                            "remote_label",
                                            "remote_p2mp_id",
                                            "remote_ptree_type",
                                            "remote_tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.local_available.is_set or
                                self.local_extended_tunnel_id.is_set or
                                self.local_flags.is_set or
                                self.local_label.is_set or
                                self.local_p2mp_id.is_set or
                                self.local_ptree_type.is_set or
                                self.local_tunnel_id.is_set or
                                self.remote_available.is_set or
                                self.remote_extended_tunnel_id.is_set or
                                self.remote_flags.is_set or
                                self.remote_label.is_set or
                                self.remote_p2mp_id.is_set or
                                self.remote_ptree_type.is_set or
                                self.remote_tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.local_available.yfilter != YFilter.not_set or
                                self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                self.local_flags.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                self.local_p2mp_id.yfilter != YFilter.not_set or
                                self.local_ptree_type.yfilter != YFilter.not_set or
                                self.local_tunnel_id.yfilter != YFilter.not_set or
                                self.remote_available.yfilter != YFilter.not_set or
                                self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                self.remote_flags.yfilter != YFilter.not_set or
                                self.remote_label.yfilter != YFilter.not_set or
                                self.remote_p2mp_id.yfilter != YFilter.not_set or
                                self.remote_ptree_type.yfilter != YFilter.not_set or
                                self.remote_tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-pw" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_available.get_name_leafdata())
                            if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                            if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_flags.get_name_leafdata())
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())
                            if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                            if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                            if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                            if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_available.get_name_leafdata())
                            if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                            if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_flags.get_name_leafdata())
                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                            if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                            if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                            if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "local-available"):
                                self.local_available = value
                                self.local_available.value_namespace = name_space
                                self.local_available.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-extended-tunnel-id"):
                                self.local_extended_tunnel_id = value
                                self.local_extended_tunnel_id.value_namespace = name_space
                                self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-flags"):
                                self.local_flags = value
                                self.local_flags.value_namespace = name_space
                                self.local_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-p2mp-id"):
                                self.local_p2mp_id = value
                                self.local_p2mp_id.value_namespace = name_space
                                self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-ptree-type"):
                                self.local_ptree_type = value
                                self.local_ptree_type.value_namespace = name_space
                                self.local_ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-tunnel-id"):
                                self.local_tunnel_id = value
                                self.local_tunnel_id.value_namespace = name_space
                                self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-available"):
                                self.remote_available = value
                                self.remote_available.value_namespace = name_space
                                self.remote_available.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-extended-tunnel-id"):
                                self.remote_extended_tunnel_id = value
                                self.remote_extended_tunnel_id.value_namespace = name_space
                                self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-flags"):
                                self.remote_flags = value
                                self.remote_flags.value_namespace = name_space
                                self.remote_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label"):
                                self.remote_label = value
                                self.remote_label.value_namespace = name_space
                                self.remote_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-p2mp-id"):
                                self.remote_p2mp_id = value
                                self.remote_p2mp_id.value_namespace = name_space
                                self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-ptree-type"):
                                self.remote_ptree_type = value
                                self.remote_ptree_type.value_namespace = name_space
                                self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-tunnel-id"):
                                self.remote_tunnel_id = value
                                self.remote_tunnel_id.value_namespace = name_space
                                self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ad_method.is_set or
                            self.ad_remote_down.is_set or
                            self.admited_bw.is_set or
                            self.auto_discovery.is_set or
                            self.backup_active.is_set or
                            self.backup_force_active.is_set or
                            self.backup_pw.is_set or
                            self.bitrate_mismatched.is_set or
                            self.bridge_pw_type_mismatch.is_set or
                            self.cas_mismatched.is_set or
                            self.diff_ts_mismatched.is_set or
                            self.disable_delay.is_set or
                            self.disable_never.is_set or
                            self.evpn_src_acid.is_set or
                            self.fe_ctype.is_set or
                            self.forward_class.is_set or
                            self.freq_mismatched.is_set or
                            self.illegal_control_word.is_set or
                            self.imposed_vlan_id.is_set or
                            self.interworking.is_set or
                            self.ipv6_local_source_address.is_set or
                            self.is_evpnvpws_type.is_set or
                            self.is_flow_label_static.is_set or
                            self.is_multi_segment_pseudowire.is_set or
                            self.is_partially_programmed.is_set or
                            self.is_pwr_type.is_set or
                            self.is_vfi.is_set or
                            self.last_time_status_changed.is_set or
                            self.last_time_status_down.is_set or
                            self.ldp_label_advertise_failed.is_set or
                            self.load_balance.is_set or
                            self.local_control_word.is_set or
                            self.local_label_failed.is_set or
                            self.local_pseudo_wire_type.is_set or
                            self.local_source_address.is_set or
                            self.mac_limit_oper_down.is_set or
                            self.mtu_mismatched.is_set or
                            self.not_supported_qinq.is_set or
                            self.num_ma_cwithdraw_msg_received.is_set or
                            self.number_ma_cwithdraw_message_sent.is_set or
                            self.out_of_memory_state.is_set or
                            self.payload_bytes_mismatched.is_set or
                            self.payload_type_mismatched.is_set or
                            self.preferred_path_disable_fallback.is_set or
                            self.primary_peer_id.is_set or
                            self.primary_pseudo_wire_id.is_set or
                            self.primary_pw.is_set or
                            self.protocol.is_set or
                            self.pseudo_wire_id.is_set or
                            self.pseudo_wire_state.is_set or
                            self.pseudo_wire_type_mismatched.is_set or
                            self.pw_class_name.is_set or
                            self.pw_flow_label_code17_disabled.is_set or
                            self.pw_flow_label_type.is_set or
                            self.pw_flow_label_type_cfg.is_set or
                            self.pw_redundancy_initial_delay.is_set or
                            self.pw_redundancy_one_way.is_set or
                            self.pw_status_use.is_set or
                            self.pwlsd_rewrite_failed.is_set or
                            self.remote_control_word.is_set or
                            self.remote_label_failed.is_set or
                            self.remote_pseudo_wire_type.is_set or
                            self.required_bw.is_set or
                            self.resync_enabled.is_set or
                            self.resync_threshold.is_set or
                            self.rtp_mismatched.is_set or
                            self.sequencing_type.is_set or
                            self.shutdown.is_set or
                            self.sig_pkts_mismatched.is_set or
                            self.ssrc_mismatched.is_set or
                            self.state.is_set or
                            self.table_policy_name.is_set or
                            self.tag_rewrite.is_set or
                            self.time_created.is_set or
                            self.time_elapsed_creation.is_set or
                            self.time_elapsed_status_changed.is_set or
                            self.time_elapsed_status_down.is_set or
                            self.transport_lsp_down.is_set or
                            self.xconnect_id.is_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                            (self.local_interface is not None and self.local_interface.has_data()) or
                            (self.local_signalling is not None and self.local_signalling.has_data()) or
                            (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                            (self.peer_id is not None and self.peer_id.has_data()) or
                            (self.preferred_path is not None and self.preferred_path.has_data()) or
                            (self.remote_interface is not None and self.remote_interface.has_data()) or
                            (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ad_method.yfilter != YFilter.not_set or
                            self.ad_remote_down.yfilter != YFilter.not_set or
                            self.admited_bw.yfilter != YFilter.not_set or
                            self.auto_discovery.yfilter != YFilter.not_set or
                            self.backup_active.yfilter != YFilter.not_set or
                            self.backup_force_active.yfilter != YFilter.not_set or
                            self.backup_pw.yfilter != YFilter.not_set or
                            self.bitrate_mismatched.yfilter != YFilter.not_set or
                            self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                            self.cas_mismatched.yfilter != YFilter.not_set or
                            self.diff_ts_mismatched.yfilter != YFilter.not_set or
                            self.disable_delay.yfilter != YFilter.not_set or
                            self.disable_never.yfilter != YFilter.not_set or
                            self.evpn_src_acid.yfilter != YFilter.not_set or
                            self.fe_ctype.yfilter != YFilter.not_set or
                            self.forward_class.yfilter != YFilter.not_set or
                            self.freq_mismatched.yfilter != YFilter.not_set or
                            self.illegal_control_word.yfilter != YFilter.not_set or
                            self.imposed_vlan_id.yfilter != YFilter.not_set or
                            self.interworking.yfilter != YFilter.not_set or
                            self.ipv6_local_source_address.yfilter != YFilter.not_set or
                            self.is_evpnvpws_type.yfilter != YFilter.not_set or
                            self.is_flow_label_static.yfilter != YFilter.not_set or
                            self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                            self.is_partially_programmed.yfilter != YFilter.not_set or
                            self.is_pwr_type.yfilter != YFilter.not_set or
                            self.is_vfi.yfilter != YFilter.not_set or
                            self.last_time_status_changed.yfilter != YFilter.not_set or
                            self.last_time_status_down.yfilter != YFilter.not_set or
                            self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                            self.load_balance.yfilter != YFilter.not_set or
                            self.local_control_word.yfilter != YFilter.not_set or
                            self.local_label_failed.yfilter != YFilter.not_set or
                            self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                            self.local_source_address.yfilter != YFilter.not_set or
                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                            self.mtu_mismatched.yfilter != YFilter.not_set or
                            self.not_supported_qinq.yfilter != YFilter.not_set or
                            self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                            self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                            self.out_of_memory_state.yfilter != YFilter.not_set or
                            self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                            self.payload_type_mismatched.yfilter != YFilter.not_set or
                            self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                            self.primary_peer_id.yfilter != YFilter.not_set or
                            self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                            self.primary_pw.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.pseudo_wire_id.yfilter != YFilter.not_set or
                            self.pseudo_wire_state.yfilter != YFilter.not_set or
                            self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                            self.pw_class_name.yfilter != YFilter.not_set or
                            self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                            self.pw_flow_label_type.yfilter != YFilter.not_set or
                            self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                            self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                            self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                            self.pw_status_use.yfilter != YFilter.not_set or
                            self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                            self.remote_control_word.yfilter != YFilter.not_set or
                            self.remote_label_failed.yfilter != YFilter.not_set or
                            self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                            self.required_bw.yfilter != YFilter.not_set or
                            self.resync_enabled.yfilter != YFilter.not_set or
                            self.resync_threshold.yfilter != YFilter.not_set or
                            self.rtp_mismatched.yfilter != YFilter.not_set or
                            self.sequencing_type.yfilter != YFilter.not_set or
                            self.shutdown.yfilter != YFilter.not_set or
                            self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                            self.ssrc_mismatched.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.table_policy_name.yfilter != YFilter.not_set or
                            self.tag_rewrite.yfilter != YFilter.not_set or
                            self.time_created.yfilter != YFilter.not_set or
                            self.time_elapsed_creation.yfilter != YFilter.not_set or
                            self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                            self.time_elapsed_status_down.yfilter != YFilter.not_set or
                            self.transport_lsp_down.yfilter != YFilter.not_set or
                            self.xconnect_id.yfilter != YFilter.not_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                            (self.local_interface is not None and self.local_interface.has_operation()) or
                            (self.local_signalling is not None and self.local_signalling.has_operation()) or
                            (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                            (self.peer_id is not None and self.peer_id.has_operation()) or
                            (self.preferred_path is not None and self.preferred_path.has_operation()) or
                            (self.remote_interface is not None and self.remote_interface.has_operation()) or
                            (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pseudo-wire" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/backup-segment/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_method.get_name_leafdata())
                        if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                        if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.admited_bw.get_name_leafdata())
                        if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                        if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_active.get_name_leafdata())
                        if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                        if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_pw.get_name_leafdata())
                        if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                        if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                        if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                        if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                        if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_delay.get_name_leafdata())
                        if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_never.get_name_leafdata())
                        if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                        if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                        if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.forward_class.get_name_leafdata())
                        if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                        if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                        if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interworking.get_name_leafdata())
                        if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                        if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                        if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                        if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                        if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                        if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                        if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_vfi.get_name_leafdata())
                        if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                        if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                        if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                        if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance.get_name_leafdata())
                        if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_control_word.get_name_leafdata())
                        if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                        if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                        if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_source_address.get_name_leafdata())
                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                        if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                        if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                        if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                        if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                        if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                        if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                        if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                        if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                        if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_pw.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                        if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                        if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                        if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                        if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                        if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                        if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                        if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                        if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                        if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                        if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                        if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                        if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                        if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                        if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.required_bw.get_name_leafdata())
                        if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                        if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                        if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                        if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                        if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                        if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                        if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                        if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_created.get_name_leafdata())
                        if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                        if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                        if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                        if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "encapsulation-info"):
                            if (self.encapsulation_info is None):
                                self.encapsulation_info = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            return self.encapsulation_info

                        if (child_yang_name == "local-interface"):
                            if (self.local_interface is None):
                                self.local_interface = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                            return self.local_interface

                        if (child_yang_name == "local-signalling"):
                            if (self.local_signalling is None):
                                self.local_signalling = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                            return self.local_signalling

                        if (child_yang_name == "p2mp-pw"):
                            if (self.p2mp_pw is None):
                                self.p2mp_pw = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            return self.p2mp_pw

                        if (child_yang_name == "peer-id"):
                            if (self.peer_id is None):
                                self.peer_id = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                            return self.peer_id

                        if (child_yang_name == "preferred-path"):
                            if (self.preferred_path is None):
                                self.preferred_path = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                            return self.preferred_path

                        if (child_yang_name == "remote-interface"):
                            if (self.remote_interface is None):
                                self.remote_interface = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                            return self.remote_interface

                        if (child_yang_name == "remote-signalling"):
                            if (self.remote_signalling is None):
                                self.remote_signalling = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                            return self.remote_signalling

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ad-method"):
                            self.ad_method = value
                            self.ad_method.value_namespace = name_space
                            self.ad_method.value_namespace_prefix = name_space_prefix
                        if(value_path == "ad-remote-down"):
                            self.ad_remote_down = value
                            self.ad_remote_down.value_namespace = name_space
                            self.ad_remote_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "admited-bw"):
                            self.admited_bw = value
                            self.admited_bw.value_namespace = name_space
                            self.admited_bw.value_namespace_prefix = name_space_prefix
                        if(value_path == "auto-discovery"):
                            self.auto_discovery = value
                            self.auto_discovery.value_namespace = name_space
                            self.auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-active"):
                            self.backup_active = value
                            self.backup_active.value_namespace = name_space
                            self.backup_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-force-active"):
                            self.backup_force_active = value
                            self.backup_force_active.value_namespace = name_space
                            self.backup_force_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-pw"):
                            self.backup_pw = value
                            self.backup_pw.value_namespace = name_space
                            self.backup_pw.value_namespace_prefix = name_space_prefix
                        if(value_path == "bitrate-mismatched"):
                            self.bitrate_mismatched = value
                            self.bitrate_mismatched.value_namespace = name_space
                            self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-pw-type-mismatch"):
                            self.bridge_pw_type_mismatch = value
                            self.bridge_pw_type_mismatch.value_namespace = name_space
                            self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                        if(value_path == "cas-mismatched"):
                            self.cas_mismatched = value
                            self.cas_mismatched.value_namespace = name_space
                            self.cas_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "diff-ts-mismatched"):
                            self.diff_ts_mismatched = value
                            self.diff_ts_mismatched.value_namespace = name_space
                            self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-delay"):
                            self.disable_delay = value
                            self.disable_delay.value_namespace = name_space
                            self.disable_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-never"):
                            self.disable_never = value
                            self.disable_never.value_namespace = name_space
                            self.disable_never.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-src-acid"):
                            self.evpn_src_acid = value
                            self.evpn_src_acid.value_namespace = name_space
                            self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                        if(value_path == "fe-ctype"):
                            self.fe_ctype = value
                            self.fe_ctype.value_namespace = name_space
                            self.fe_ctype.value_namespace_prefix = name_space_prefix
                        if(value_path == "forward-class"):
                            self.forward_class = value
                            self.forward_class.value_namespace = name_space
                            self.forward_class.value_namespace_prefix = name_space_prefix
                        if(value_path == "freq-mismatched"):
                            self.freq_mismatched = value
                            self.freq_mismatched.value_namespace = name_space
                            self.freq_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "illegal-control-word"):
                            self.illegal_control_word = value
                            self.illegal_control_word.value_namespace = name_space
                            self.illegal_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "imposed-vlan-id"):
                            self.imposed_vlan_id = value
                            self.imposed_vlan_id.value_namespace = name_space
                            self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interworking"):
                            self.interworking = value
                            self.interworking.value_namespace = name_space
                            self.interworking.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-local-source-address"):
                            self.ipv6_local_source_address = value
                            self.ipv6_local_source_address.value_namespace = name_space
                            self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-evpnvpws-type"):
                            self.is_evpnvpws_type = value
                            self.is_evpnvpws_type.value_namespace = name_space
                            self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-flow-label-static"):
                            self.is_flow_label_static = value
                            self.is_flow_label_static.value_namespace = name_space
                            self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multi-segment-pseudowire"):
                            self.is_multi_segment_pseudowire = value
                            self.is_multi_segment_pseudowire.value_namespace = name_space
                            self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-partially-programmed"):
                            self.is_partially_programmed = value
                            self.is_partially_programmed.value_namespace = name_space
                            self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pwr-type"):
                            self.is_pwr_type = value
                            self.is_pwr_type.value_namespace = name_space
                            self.is_pwr_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-vfi"):
                            self.is_vfi = value
                            self.is_vfi.value_namespace = name_space
                            self.is_vfi.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-changed"):
                            self.last_time_status_changed = value
                            self.last_time_status_changed.value_namespace = name_space
                            self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-down"):
                            self.last_time_status_down = value
                            self.last_time_status_down.value_namespace = name_space
                            self.last_time_status_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "ldp-label-advertise-failed"):
                            self.ldp_label_advertise_failed = value
                            self.ldp_label_advertise_failed.value_namespace = name_space
                            self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance"):
                            self.load_balance = value
                            self.load_balance.value_namespace = name_space
                            self.load_balance.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-control-word"):
                            self.local_control_word = value
                            self.local_control_word.value_namespace = name_space
                            self.local_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-label-failed"):
                            self.local_label_failed = value
                            self.local_label_failed.value_namespace = name_space
                            self.local_label_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-pseudo-wire-type"):
                            self.local_pseudo_wire_type = value
                            self.local_pseudo_wire_type.value_namespace = name_space
                            self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-source-address"):
                            self.local_source_address = value
                            self.local_source_address.value_namespace = name_space
                            self.local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-oper-down"):
                            self.mac_limit_oper_down = value
                            self.mac_limit_oper_down.value_namespace = name_space
                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-mismatched"):
                            self.mtu_mismatched = value
                            self.mtu_mismatched.value_namespace = name_space
                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-qinq"):
                            self.not_supported_qinq = value
                            self.not_supported_qinq.value_namespace = name_space
                            self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-ma-cwithdraw-msg-received"):
                            self.num_ma_cwithdraw_msg_received = value
                            self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                            self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-ma-cwithdraw-message-sent"):
                            self.number_ma_cwithdraw_message_sent = value
                            self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                            self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-of-memory-state"):
                            self.out_of_memory_state = value
                            self.out_of_memory_state.value_namespace = name_space
                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "payload-bytes-mismatched"):
                            self.payload_bytes_mismatched = value
                            self.payload_bytes_mismatched.value_namespace = name_space
                            self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "payload-type-mismatched"):
                            self.payload_type_mismatched = value
                            self.payload_type_mismatched.value_namespace = name_space
                            self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "preferred-path-disable-fallback"):
                            self.preferred_path_disable_fallback = value
                            self.preferred_path_disable_fallback.value_namespace = name_space
                            self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-peer-id"):
                            self.primary_peer_id = value
                            self.primary_peer_id.value_namespace = name_space
                            self.primary_peer_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-pseudo-wire-id"):
                            self.primary_pseudo_wire_id = value
                            self.primary_pseudo_wire_id.value_namespace = name_space
                            self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-pw"):
                            self.primary_pw = value
                            self.primary_pw.value_namespace = name_space
                            self.primary_pw.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-id"):
                            self.pseudo_wire_id = value
                            self.pseudo_wire_id.value_namespace = name_space
                            self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-state"):
                            self.pseudo_wire_state = value
                            self.pseudo_wire_state.value_namespace = name_space
                            self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-type-mismatched"):
                            self.pseudo_wire_type_mismatched = value
                            self.pseudo_wire_type_mismatched.value_namespace = name_space
                            self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-class-name"):
                            self.pw_class_name = value
                            self.pw_class_name.value_namespace = name_space
                            self.pw_class_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-code17-disabled"):
                            self.pw_flow_label_code17_disabled = value
                            self.pw_flow_label_code17_disabled.value_namespace = name_space
                            self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type"):
                            self.pw_flow_label_type = value
                            self.pw_flow_label_type.value_namespace = name_space
                            self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type-cfg"):
                            self.pw_flow_label_type_cfg = value
                            self.pw_flow_label_type_cfg.value_namespace = name_space
                            self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-redundancy-initial-delay"):
                            self.pw_redundancy_initial_delay = value
                            self.pw_redundancy_initial_delay.value_namespace = name_space
                            self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-redundancy-one-way"):
                            self.pw_redundancy_one_way = value
                            self.pw_redundancy_one_way.value_namespace = name_space
                            self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-status-use"):
                            self.pw_status_use = value
                            self.pw_status_use.value_namespace = name_space
                            self.pw_status_use.value_namespace_prefix = name_space_prefix
                        if(value_path == "pwlsd-rewrite-failed"):
                            self.pwlsd_rewrite_failed = value
                            self.pwlsd_rewrite_failed.value_namespace = name_space
                            self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-control-word"):
                            self.remote_control_word = value
                            self.remote_control_word.value_namespace = name_space
                            self.remote_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-label-failed"):
                            self.remote_label_failed = value
                            self.remote_label_failed.value_namespace = name_space
                            self.remote_label_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-pseudo-wire-type"):
                            self.remote_pseudo_wire_type = value
                            self.remote_pseudo_wire_type.value_namespace = name_space
                            self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "required-bw"):
                            self.required_bw = value
                            self.required_bw.value_namespace = name_space
                            self.required_bw.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-enabled"):
                            self.resync_enabled = value
                            self.resync_enabled.value_namespace = name_space
                            self.resync_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-threshold"):
                            self.resync_threshold = value
                            self.resync_threshold.value_namespace = name_space
                            self.resync_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "rtp-mismatched"):
                            self.rtp_mismatched = value
                            self.rtp_mismatched.value_namespace = name_space
                            self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "sequencing-type"):
                            self.sequencing_type = value
                            self.sequencing_type.value_namespace = name_space
                            self.sequencing_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "shutdown"):
                            self.shutdown = value
                            self.shutdown.value_namespace = name_space
                            self.shutdown.value_namespace_prefix = name_space_prefix
                        if(value_path == "sig-pkts-mismatched"):
                            self.sig_pkts_mismatched = value
                            self.sig_pkts_mismatched.value_namespace = name_space
                            self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssrc-mismatched"):
                            self.ssrc_mismatched = value
                            self.ssrc_mismatched.value_namespace = name_space
                            self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-policy-name"):
                            self.table_policy_name = value
                            self.table_policy_name.value_namespace = name_space
                            self.table_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "tag-rewrite"):
                            self.tag_rewrite = value
                            self.tag_rewrite.value_namespace = name_space
                            self.tag_rewrite.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-created"):
                            self.time_created = value
                            self.time_created.value_namespace = name_space
                            self.time_created.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-creation"):
                            self.time_elapsed_creation = value
                            self.time_elapsed_creation.value_namespace = name_space
                            self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-changed"):
                            self.time_elapsed_status_changed = value
                            self.time_elapsed_status_changed.value_namespace = name_space
                            self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-down"):
                            self.time_elapsed_status_down = value
                            self.time_elapsed_status_down.value_namespace = name_space
                            self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "transport-lsp-down"):
                            self.transport_lsp_down = value
                            self.transport_lsp_down.value_namespace = name_space
                            self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-id"):
                            self.xconnect_id = value
                            self.xconnect_id.value_namespace = name_space
                            self.xconnect_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.segment_type.is_set or
                        (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                        (self.pseudo_wire is not None and self.pseudo_wire.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.segment_type.yfilter != YFilter.not_set or
                        (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                        (self.pseudo_wire is not None and self.pseudo_wire.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "backup-segment" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/xconnect/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.segment_type.is_set or self.segment_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.segment_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "attachment-circuit"):
                        if (self.attachment_circuit is None):
                            self.attachment_circuit = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        return self.attachment_circuit

                    if (child_yang_name == "pseudo-wire"):
                        if (self.pseudo_wire is None):
                            self.pseudo_wire = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        return self.pseudo_wire

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "attachment-circuit" or name == "pseudo-wire" or name == "segment-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "segment-type"):
                        self.segment_type = value
                        self.segment_type.value_namespace = name_space
                        self.segment_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.backup_segment:
                    if (c.has_data()):
                        return True
                return (
                    self.description.is_set or
                    self.diag_mask.is_set or
                    self.group_name.is_set or
                    self.group_name_xr.is_set or
                    self.interworking.is_set or
                    self.is_mp2mp.is_set or
                    self.number_of_backup_p_ws.is_set or
                    self.state.is_set or
                    self.xconnect_name.is_set or
                    self.xconnect_name_xr.is_set or
                    (self.backup is not None and self.backup.has_data()) or
                    (self.ce2ce is not None and self.ce2ce.has_data()) or
                    (self.segment1 is not None and self.segment1.has_data()) or
                    (self.segment2 is not None and self.segment2.has_data()))

            def has_operation(self):
                for c in self.backup_segment:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.description.yfilter != YFilter.not_set or
                    self.diag_mask.yfilter != YFilter.not_set or
                    self.group_name.yfilter != YFilter.not_set or
                    self.group_name_xr.yfilter != YFilter.not_set or
                    self.interworking.yfilter != YFilter.not_set or
                    self.is_mp2mp.yfilter != YFilter.not_set or
                    self.number_of_backup_p_ws.yfilter != YFilter.not_set or
                    self.state.yfilter != YFilter.not_set or
                    self.xconnect_name.yfilter != YFilter.not_set or
                    self.xconnect_name_xr.yfilter != YFilter.not_set or
                    (self.backup is not None and self.backup.has_operation()) or
                    (self.ce2ce is not None and self.ce2ce.has_operation()) or
                    (self.segment1 is not None and self.segment1.has_operation()) or
                    (self.segment2 is not None and self.segment2.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnects/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.description.get_name_leafdata())
                if (self.diag_mask.is_set or self.diag_mask.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.diag_mask.get_name_leafdata())
                if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.group_name.get_name_leafdata())
                if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interworking.get_name_leafdata())
                if (self.is_mp2mp.is_set or self.is_mp2mp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_mp2mp.get_name_leafdata())
                if (self.number_of_backup_p_ws.is_set or self.number_of_backup_p_ws.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_of_backup_p_ws.get_name_leafdata())
                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.state.get_name_leafdata())
                if (self.xconnect_name.is_set or self.xconnect_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.xconnect_name.get_name_leafdata())
                if (self.xconnect_name_xr.is_set or self.xconnect_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.xconnect_name_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "backup"):
                    if (self.backup is None):
                        self.backup = L2Vpn.Xconnects.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"
                    return self.backup

                if (child_yang_name == "backup-segment"):
                    for c in self.backup_segment:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.Xconnects.Xconnect.BackupSegment()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.backup_segment.append(c)
                    return c

                if (child_yang_name == "ce2ce"):
                    if (self.ce2ce is None):
                        self.ce2ce = L2Vpn.Xconnects.Xconnect.Ce2Ce()
                        self.ce2ce.parent = self
                        self._children_name_map["ce2ce"] = "ce2ce"
                    return self.ce2ce

                if (child_yang_name == "segment1"):
                    if (self.segment1 is None):
                        self.segment1 = L2Vpn.Xconnects.Xconnect.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"
                    return self.segment1

                if (child_yang_name == "segment2"):
                    if (self.segment2 is None):
                        self.segment2 = L2Vpn.Xconnects.Xconnect.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"
                    return self.segment2

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "backup" or name == "backup-segment" or name == "ce2ce" or name == "segment1" or name == "segment2" or name == "description" or name == "diag-mask" or name == "group-name" or name == "group-name-xr" or name == "interworking" or name == "is-mp2mp" or name == "number-of-backup-p-ws" or name == "state" or name == "xconnect-name" or name == "xconnect-name-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "description"):
                    self.description = value
                    self.description.value_namespace = name_space
                    self.description.value_namespace_prefix = name_space_prefix
                if(value_path == "diag-mask"):
                    self.diag_mask = value
                    self.diag_mask.value_namespace = name_space
                    self.diag_mask.value_namespace_prefix = name_space_prefix
                if(value_path == "group-name"):
                    self.group_name = value
                    self.group_name.value_namespace = name_space
                    self.group_name.value_namespace_prefix = name_space_prefix
                if(value_path == "group-name-xr"):
                    self.group_name_xr = value
                    self.group_name_xr.value_namespace = name_space
                    self.group_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "interworking"):
                    self.interworking = value
                    self.interworking.value_namespace = name_space
                    self.interworking.value_namespace_prefix = name_space_prefix
                if(value_path == "is-mp2mp"):
                    self.is_mp2mp = value
                    self.is_mp2mp.value_namespace = name_space
                    self.is_mp2mp.value_namespace_prefix = name_space_prefix
                if(value_path == "number-of-backup-p-ws"):
                    self.number_of_backup_p_ws = value
                    self.number_of_backup_p_ws.value_namespace = name_space
                    self.number_of_backup_p_ws.value_namespace_prefix = name_space_prefix
                if(value_path == "state"):
                    self.state = value
                    self.state.value_namespace = name_space
                    self.state.value_namespace_prefix = name_space_prefix
                if(value_path == "xconnect-name"):
                    self.xconnect_name = value
                    self.xconnect_name.value_namespace = name_space
                    self.xconnect_name.value_namespace_prefix = name_space_prefix
                if(value_path == "xconnect-name-xr"):
                    self.xconnect_name_xr = value
                    self.xconnect_name_xr.value_namespace = name_space
                    self.xconnect_name_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.xconnect:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.xconnect:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "xconnects" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "xconnect"):
                for c in self.xconnect:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.Xconnects.Xconnect()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.xconnect.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "xconnect"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class XconnectGroups(Entity):
        """
        XConnect group Table
        
        .. attribute:: xconnect_group
        
        	XConnect group information
        	**type**\: list of    :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectGroups.XconnectGroup>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.XconnectGroups, self).__init__()

            self.yang_name = "xconnect-groups"
            self.yang_parent_name = "l2vpn"

            self.xconnect_group = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.XconnectGroups, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.XconnectGroups, self).__setattr__(name, value)


        class XconnectGroup(Entity):
            """
            XConnect group information
            
            .. attribute:: group_name  <key>
            
            	XConnect Group
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: group_name_xr
            
            	Group name
            	**type**\:  str
            
            .. attribute:: number_xconnects
            
            	Number of xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.XconnectGroups.XconnectGroup, self).__init__()

                self.yang_name = "xconnect-group"
                self.yang_parent_name = "xconnect-groups"

                self.group_name = YLeaf(YType.str, "group-name")

                self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                self.number_xconnects = YLeaf(YType.uint32, "number-xconnects")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("group_name",
                                "group_name_xr",
                                "number_xconnects") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.XconnectGroups.XconnectGroup, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.XconnectGroups.XconnectGroup, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.group_name.is_set or
                    self.group_name_xr.is_set or
                    self.number_xconnects.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.group_name.yfilter != YFilter.not_set or
                    self.group_name_xr.yfilter != YFilter.not_set or
                    self.number_xconnects.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-group" + "[group-name='" + self.group_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-groups/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.group_name.get_name_leafdata())
                if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                if (self.number_xconnects.is_set or self.number_xconnects.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_xconnects.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "group-name" or name == "group-name-xr" or name == "number-xconnects"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "group-name"):
                    self.group_name = value
                    self.group_name.value_namespace = name_space
                    self.group_name.value_namespace_prefix = name_space_prefix
                if(value_path == "group-name-xr"):
                    self.group_name_xr = value
                    self.group_name_xr.value_namespace = name_space
                    self.group_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "number-xconnects"):
                    self.number_xconnects = value
                    self.number_xconnects.value_namespace = name_space
                    self.number_xconnects.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.xconnect_group:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.xconnect_group:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "xconnect-groups" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "xconnect-group"):
                for c in self.xconnect_group:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.XconnectGroups.XconnectGroup()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.xconnect_group.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "xconnect-group"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class XconnectMp2Mps(Entity):
        """
        XConnect MP2MP Table
        
        .. attribute:: xconnect_mp2mp
        
        	XConnect MP2MP information
        	**type**\: list of    :py:class:`XconnectMp2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.XconnectMp2Mps, self).__init__()

            self.yang_name = "xconnect-mp2mps"
            self.yang_parent_name = "l2vpn"

            self.xconnect_mp2mp = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.XconnectMp2Mps, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.XconnectMp2Mps, self).__setattr__(name, value)


        class XconnectMp2Mp(Entity):
            """
            XConnect MP2MP information
            
            .. attribute:: discovery
            
            	l2vpn xc auto discovery info
            	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery>`
            
            .. attribute:: group_name
            
            	XConnect Group
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: group_name_xr
            
            	Group name
            	**type**\:  str
            
            .. attribute:: l2_encapsulation
            
            	L2 Encapsulation
            	**type**\:   :py:class:`L2VpnBagAdEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagAdEncap>`
            
            .. attribute:: mp2_mp_name
            
            	Mp2Mp Name
            	**type**\:  str
            
            	**length:** 1..26
            
            .. attribute:: mp2mp_name
            
            	MP2MP name
            	**type**\:  str
            
            .. attribute:: mp2mpid
            
            	Identification Number
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: vpn_id
            
            	Vpn ID
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: vpn_mtu
            
            	VPN MTU
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: xconnect_shutdown
            
            	Administratively disabled
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp, self).__init__()

                self.yang_name = "xconnect-mp2mp"
                self.yang_parent_name = "xconnect-mp2mps"

                self.group_name = YLeaf(YType.str, "group-name")

                self.group_name_xr = YLeaf(YType.str, "group-name-xr")

                self.l2_encapsulation = YLeaf(YType.enumeration, "l2-encapsulation")

                self.mp2_mp_name = YLeaf(YType.str, "mp2-mp-name")

                self.mp2mp_name = YLeaf(YType.str, "mp2mp-name")

                self.mp2mpid = YLeaf(YType.uint32, "mp2mpid")

                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                self.vpn_mtu = YLeaf(YType.uint32, "vpn-mtu")

                self.xconnect_shutdown = YLeaf(YType.boolean, "xconnect-shutdown")

                self.discovery = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                self.discovery.parent = self
                self._children_name_map["discovery"] = "discovery"
                self._children_yang_names.add("discovery")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("group_name",
                                "group_name_xr",
                                "l2_encapsulation",
                                "mp2_mp_name",
                                "mp2mp_name",
                                "mp2mpid",
                                "vpn_id",
                                "vpn_mtu",
                                "xconnect_shutdown") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp, self).__setattr__(name, value)


            class Discovery(Entity):
                """
                l2vpn xc auto discovery info
                
                .. attribute:: ad_method
                
                	Autodiscovery Method
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ad_service_connected
                
                	Service Connected
                	**type**\:  bool
                
                .. attribute:: ad_signalling_method
                
                	Signaling Protocol
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ce_range
                
                	CE Range
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: export_route_policy
                
                	Export Route Policy
                	**type**\:  str
                
                .. attribute:: export_rt
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt>`
                
                .. attribute:: import_rt
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt>`
                
                .. attribute:: number_a_cs
                
                	Number of attachment circuits
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs_up
                
                	Number of attachment circuits up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2c_es
                
                	Number of ce2ce
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2ce_advertised
                
                	Number of ce2ce Advertised
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p_ws_up
                
                	Number of pseudowires up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pseudowires
                
                	Number of pseudowires
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rd_value
                
                	Route Distinguisher
                	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue>`
                
                .. attribute:: vpn_added
                
                	VPN Added
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__init__()

                    self.yang_name = "discovery"
                    self.yang_parent_name = "xconnect-mp2mp"

                    self.ad_method = YLeaf(YType.uint32, "ad-method")

                    self.ad_service_connected = YLeaf(YType.boolean, "ad-service-connected")

                    self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                    self.ce_range = YLeaf(YType.uint16, "ce-range")

                    self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                    self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                    self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                    self.number_ce2c_es = YLeaf(YType.uint32, "number-ce2c-es")

                    self.number_ce2ce_advertised = YLeaf(YType.uint32, "number-ce2ce-advertised")

                    self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                    self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                    self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                    self.rd_value = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                    self.rd_value.parent = self
                    self._children_name_map["rd_value"] = "rd-value"
                    self._children_yang_names.add("rd-value")

                    self.export_rt = YList(self)
                    self.import_rt = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ad_method",
                                    "ad_service_connected",
                                    "ad_signalling_method",
                                    "ce_range",
                                    "export_route_policy",
                                    "number_a_cs",
                                    "number_a_cs_up",
                                    "number_ce2c_es",
                                    "number_ce2ce_advertised",
                                    "number_p_ws_up",
                                    "number_pseudowires",
                                    "vpn_added") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery, self).__setattr__(name, value)


                class RdValue(Entity):
                    """
                    Route Distinguisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__init__()

                        self.yang_name = "rd-value"
                        self.yang_parent_name = "discovery"

                        self.rd = YLeaf(YType.enumeration, "rd")

                        self.auto = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"
                        self._children_yang_names.add("auto")

                        self.four_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"
                        self._children_yang_names.add("four-byte-as")

                        self.two_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"
                        self._children_yang_names.add("two-byte-as")

                        self.v4_addr = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._children_yang_names.add("v4-addr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("rd") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue, self).__setattr__(name, value)


                    class Auto(Entity):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "rd-value"

                            self.auto_index = YLeaf(YType.uint16, "auto-index")

                            self.router_id = YLeaf(YType.str, "router-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("auto_index",
                                            "router_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.auto_index.is_set or
                                self.router_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.auto_index.yfilter != YFilter.not_set or
                                self.router_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "auto" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_index.get_name_leafdata())
                            if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto-index" or name == "router-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "auto-index"):
                                self.auto_index = value
                                self.auto_index.value_namespace = name_space
                                self.auto_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-id"):
                                self.router_id = value
                                self.router_id.value_namespace = name_space
                                self.router_id.value_namespace_prefix = name_space_prefix


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "rd-value"

                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_index",
                                            "two_byte_as") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_index.is_set or
                                self.two_byte_as.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_index.yfilter != YFilter.not_set or
                                self.two_byte_as.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "two-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-index" or name == "two-byte-as"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-index"):
                                self.four_byte_index = value
                                self.four_byte_index.value_namespace = name_space
                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-as"):
                                self.two_byte_as = value
                                self.two_byte_as.value_namespace = name_space
                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "rd-value"

                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_as",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_as.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_as.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "four-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-as" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-as"):
                                self.four_byte_as = value
                                self.four_byte_as.value_namespace = name_space
                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "rd-value"

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ipv4_address",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ipv4_address.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "v4-addr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4-address" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.rd.is_set or
                            (self.auto is not None and self.auto.has_data()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                            (self.v4_addr is not None and self.v4_addr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.rd.yfilter != YFilter.not_set or
                            (self.auto is not None and self.auto.has_operation()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rd-value" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rd.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "auto"):
                            if (self.auto is None):
                                self.auto = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                            return self.auto

                        if (child_yang_name == "four-byte-as"):
                            if (self.four_byte_as is None):
                                self.four_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                            return self.four_byte_as

                        if (child_yang_name == "two-byte-as"):
                            if (self.two_byte_as is None):
                                self.two_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                            return self.two_byte_as

                        if (child_yang_name == "v4-addr"):
                            if (self.v4_addr is None):
                                self.v4_addr = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                            return self.v4_addr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "rd"):
                            self.rd = value
                            self.rd.value_namespace = name_space
                            self.rd.value_namespace_prefix = name_space_prefix


                class ImportRt(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: es_import
                    
                    	es import
                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs>`
                    
                    .. attribute:: rt
                    
                    	RT
                    	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__init__()

                        self.yang_name = "import-rt"
                        self.yang_parent_name = "discovery"

                        self.rt = YLeaf(YType.enumeration, "rt")

                        self.es_import = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                        self.es_import.parent = self
                        self._children_name_map["es_import"] = "es-import"
                        self._children_yang_names.add("es-import")

                        self.four_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"
                        self._children_yang_names.add("four-byte-as")

                        self.two_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"
                        self._children_yang_names.add("two-byte-as")

                        self.v4_addr = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._children_yang_names.add("v4-addr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("rt") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt, self).__setattr__(name, value)


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "import-rt"

                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_index",
                                            "two_byte_as") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_index.is_set or
                                self.two_byte_as.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_index.yfilter != YFilter.not_set or
                                self.two_byte_as.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "two-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-index" or name == "two-byte-as"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-index"):
                                self.four_byte_index = value
                                self.four_byte_index.value_namespace = name_space
                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-as"):
                                self.two_byte_as = value
                                self.two_byte_as.value_namespace = name_space
                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "import-rt"

                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_as",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_as.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_as.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "four-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-as" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-as"):
                                self.four_byte_as = value
                                self.four_byte_as.value_namespace = name_space
                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "import-rt"

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ipv4_address",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ipv4_address.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "v4-addr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4-address" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                    class EsImport(Entity):
                        """
                        es import
                        
                        .. attribute:: high_bytes
                        
                        	Top 4 bytes of ES Import
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: low_bytes
                        
                        	Low 2 bytes of ES Import
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__init__()

                            self.yang_name = "es-import"
                            self.yang_parent_name = "import-rt"

                            self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                            self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("high_bytes",
                                            "low_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.high_bytes.is_set or
                                self.low_bytes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.high_bytes.yfilter != YFilter.not_set or
                                self.low_bytes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "es-import" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.high_bytes.get_name_leafdata())
                            if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.low_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "high-bytes" or name == "low-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "high-bytes"):
                                self.high_bytes = value
                                self.high_bytes.value_namespace = name_space
                                self.high_bytes.value_namespace_prefix = name_space_prefix
                            if(value_path == "low-bytes"):
                                self.low_bytes = value
                                self.low_bytes.value_namespace = name_space
                                self.low_bytes.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.rt.is_set or
                            (self.es_import is not None and self.es_import.has_data()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                            (self.v4_addr is not None and self.v4_addr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.rt.yfilter != YFilter.not_set or
                            (self.es_import is not None and self.es_import.has_operation()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "import-rt" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rt.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "es-import"):
                            if (self.es_import is None):
                                self.es_import = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                                self.es_import.parent = self
                                self._children_name_map["es_import"] = "es-import"
                            return self.es_import

                        if (child_yang_name == "four-byte-as"):
                            if (self.four_byte_as is None):
                                self.four_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                            return self.four_byte_as

                        if (child_yang_name == "two-byte-as"):
                            if (self.two_byte_as is None):
                                self.two_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                            return self.two_byte_as

                        if (child_yang_name == "v4-addr"):
                            if (self.v4_addr is None):
                                self.v4_addr = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                            return self.v4_addr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "rt"):
                            self.rt = value
                            self.rt.value_namespace = name_space
                            self.rt.value_namespace_prefix = name_space_prefix


                class ExportRt(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: es_import
                    
                    	es import
                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs>`
                    
                    .. attribute:: rt
                    
                    	RT
                    	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__init__()

                        self.yang_name = "export-rt"
                        self.yang_parent_name = "discovery"

                        self.rt = YLeaf(YType.enumeration, "rt")

                        self.es_import = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                        self.es_import.parent = self
                        self._children_name_map["es_import"] = "es-import"
                        self._children_yang_names.add("es-import")

                        self.four_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"
                        self._children_yang_names.add("four-byte-as")

                        self.two_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"
                        self._children_yang_names.add("two-byte-as")

                        self.v4_addr = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._children_yang_names.add("v4-addr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("rt") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt, self).__setattr__(name, value)


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "export-rt"

                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_index",
                                            "two_byte_as") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_index.is_set or
                                self.two_byte_as.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_index.yfilter != YFilter.not_set or
                                self.two_byte_as.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "two-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-index" or name == "two-byte-as"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-index"):
                                self.four_byte_index = value
                                self.four_byte_index.value_namespace = name_space
                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-as"):
                                self.two_byte_as = value
                                self.two_byte_as.value_namespace = name_space
                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "export-rt"

                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_as",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_as.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_as.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "four-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-as" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-as"):
                                self.four_byte_as = value
                                self.four_byte_as.value_namespace = name_space
                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "export-rt"

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ipv4_address",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ipv4_address.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "v4-addr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4-address" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                    class EsImport(Entity):
                        """
                        es import
                        
                        .. attribute:: high_bytes
                        
                        	Top 4 bytes of ES Import
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: low_bytes
                        
                        	Low 2 bytes of ES Import
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__init__()

                            self.yang_name = "es-import"
                            self.yang_parent_name = "export-rt"

                            self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                            self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("high_bytes",
                                            "low_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.high_bytes.is_set or
                                self.low_bytes.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.high_bytes.yfilter != YFilter.not_set or
                                self.low_bytes.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "es-import" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.high_bytes.get_name_leafdata())
                            if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.low_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "high-bytes" or name == "low-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "high-bytes"):
                                self.high_bytes = value
                                self.high_bytes.value_namespace = name_space
                                self.high_bytes.value_namespace_prefix = name_space_prefix
                            if(value_path == "low-bytes"):
                                self.low_bytes = value
                                self.low_bytes.value_namespace = name_space
                                self.low_bytes.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.rt.is_set or
                            (self.es_import is not None and self.es_import.has_data()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                            (self.v4_addr is not None and self.v4_addr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.rt.yfilter != YFilter.not_set or
                            (self.es_import is not None and self.es_import.has_operation()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "export-rt" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rt.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "es-import"):
                            if (self.es_import is None):
                                self.es_import = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                                self.es_import.parent = self
                                self._children_name_map["es_import"] = "es-import"
                            return self.es_import

                        if (child_yang_name == "four-byte-as"):
                            if (self.four_byte_as is None):
                                self.four_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                            return self.four_byte_as

                        if (child_yang_name == "two-byte-as"):
                            if (self.two_byte_as is None):
                                self.two_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                            return self.two_byte_as

                        if (child_yang_name == "v4-addr"):
                            if (self.v4_addr is None):
                                self.v4_addr = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                            return self.v4_addr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "rt"):
                            self.rt = value
                            self.rt.value_namespace = name_space
                            self.rt.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.export_rt:
                        if (c.has_data()):
                            return True
                    for c in self.import_rt:
                        if (c.has_data()):
                            return True
                    return (
                        self.ad_method.is_set or
                        self.ad_service_connected.is_set or
                        self.ad_signalling_method.is_set or
                        self.ce_range.is_set or
                        self.export_route_policy.is_set or
                        self.number_a_cs.is_set or
                        self.number_a_cs_up.is_set or
                        self.number_ce2c_es.is_set or
                        self.number_ce2ce_advertised.is_set or
                        self.number_p_ws_up.is_set or
                        self.number_pseudowires.is_set or
                        self.vpn_added.is_set or
                        (self.rd_value is not None and self.rd_value.has_data()))

                def has_operation(self):
                    for c in self.export_rt:
                        if (c.has_operation()):
                            return True
                    for c in self.import_rt:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ad_method.yfilter != YFilter.not_set or
                        self.ad_service_connected.yfilter != YFilter.not_set or
                        self.ad_signalling_method.yfilter != YFilter.not_set or
                        self.ce_range.yfilter != YFilter.not_set or
                        self.export_route_policy.yfilter != YFilter.not_set or
                        self.number_a_cs.yfilter != YFilter.not_set or
                        self.number_a_cs_up.yfilter != YFilter.not_set or
                        self.number_ce2c_es.yfilter != YFilter.not_set or
                        self.number_ce2ce_advertised.yfilter != YFilter.not_set or
                        self.number_p_ws_up.yfilter != YFilter.not_set or
                        self.number_pseudowires.yfilter != YFilter.not_set or
                        self.vpn_added.yfilter != YFilter.not_set or
                        (self.rd_value is not None and self.rd_value.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "discovery" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/xconnect-mp2mp/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ad_method.get_name_leafdata())
                    if (self.ad_service_connected.is_set or self.ad_service_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ad_service_connected.get_name_leafdata())
                    if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                    if (self.ce_range.is_set or self.ce_range.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ce_range.get_name_leafdata())
                    if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                    if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                    if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                    if (self.number_ce2c_es.is_set or self.number_ce2c_es.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_ce2c_es.get_name_leafdata())
                    if (self.number_ce2ce_advertised.is_set or self.number_ce2ce_advertised.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_ce2ce_advertised.get_name_leafdata())
                    if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                    if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                    if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_added.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "export-rt"):
                        for c in self.export_rt:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.export_rt.append(c)
                        return c

                    if (child_yang_name == "import-rt"):
                        for c in self.import_rt:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.import_rt.append(c)
                        return c

                    if (child_yang_name == "rd-value"):
                        if (self.rd_value is None):
                            self.rd_value = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                            self.rd_value.parent = self
                            self._children_name_map["rd_value"] = "rd-value"
                        return self.rd_value

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "ad-method" or name == "ad-service-connected" or name == "ad-signalling-method" or name == "ce-range" or name == "export-route-policy" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-ce2c-es" or name == "number-ce2ce-advertised" or name == "number-p-ws-up" or name == "number-pseudowires" or name == "vpn-added"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ad-method"):
                        self.ad_method = value
                        self.ad_method.value_namespace = name_space
                        self.ad_method.value_namespace_prefix = name_space_prefix
                    if(value_path == "ad-service-connected"):
                        self.ad_service_connected = value
                        self.ad_service_connected.value_namespace = name_space
                        self.ad_service_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "ad-signalling-method"):
                        self.ad_signalling_method = value
                        self.ad_signalling_method.value_namespace = name_space
                        self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                    if(value_path == "ce-range"):
                        self.ce_range = value
                        self.ce_range.value_namespace = name_space
                        self.ce_range.value_namespace_prefix = name_space_prefix
                    if(value_path == "export-route-policy"):
                        self.export_route_policy = value
                        self.export_route_policy.value_namespace = name_space
                        self.export_route_policy.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-a-cs"):
                        self.number_a_cs = value
                        self.number_a_cs.value_namespace = name_space
                        self.number_a_cs.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-a-cs-up"):
                        self.number_a_cs_up = value
                        self.number_a_cs_up.value_namespace = name_space
                        self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-ce2c-es"):
                        self.number_ce2c_es = value
                        self.number_ce2c_es.value_namespace = name_space
                        self.number_ce2c_es.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-ce2ce-advertised"):
                        self.number_ce2ce_advertised = value
                        self.number_ce2ce_advertised.value_namespace = name_space
                        self.number_ce2ce_advertised.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-p-ws-up"):
                        self.number_p_ws_up = value
                        self.number_p_ws_up.value_namespace = name_space
                        self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-pseudowires"):
                        self.number_pseudowires = value
                        self.number_pseudowires.value_namespace = name_space
                        self.number_pseudowires.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-added"):
                        self.vpn_added = value
                        self.vpn_added.value_namespace = name_space
                        self.vpn_added.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.group_name.is_set or
                    self.group_name_xr.is_set or
                    self.l2_encapsulation.is_set or
                    self.mp2_mp_name.is_set or
                    self.mp2mp_name.is_set or
                    self.mp2mpid.is_set or
                    self.vpn_id.is_set or
                    self.vpn_mtu.is_set or
                    self.xconnect_shutdown.is_set or
                    (self.discovery is not None and self.discovery.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.group_name.yfilter != YFilter.not_set or
                    self.group_name_xr.yfilter != YFilter.not_set or
                    self.l2_encapsulation.yfilter != YFilter.not_set or
                    self.mp2_mp_name.yfilter != YFilter.not_set or
                    self.mp2mp_name.yfilter != YFilter.not_set or
                    self.mp2mpid.yfilter != YFilter.not_set or
                    self.vpn_id.yfilter != YFilter.not_set or
                    self.vpn_mtu.yfilter != YFilter.not_set or
                    self.xconnect_shutdown.yfilter != YFilter.not_set or
                    (self.discovery is not None and self.discovery.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xconnect-mp2mp" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-mp2mps/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.group_name.get_name_leafdata())
                if (self.group_name_xr.is_set or self.group_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.group_name_xr.get_name_leafdata())
                if (self.l2_encapsulation.is_set or self.l2_encapsulation.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.l2_encapsulation.get_name_leafdata())
                if (self.mp2_mp_name.is_set or self.mp2_mp_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mp2_mp_name.get_name_leafdata())
                if (self.mp2mp_name.is_set or self.mp2mp_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mp2mp_name.get_name_leafdata())
                if (self.mp2mpid.is_set or self.mp2mpid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mp2mpid.get_name_leafdata())
                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vpn_id.get_name_leafdata())
                if (self.vpn_mtu.is_set or self.vpn_mtu.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vpn_mtu.get_name_leafdata())
                if (self.xconnect_shutdown.is_set or self.xconnect_shutdown.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.xconnect_shutdown.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "discovery"):
                    if (self.discovery is None):
                        self.discovery = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"
                    return self.discovery

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "discovery" or name == "group-name" or name == "group-name-xr" or name == "l2-encapsulation" or name == "mp2-mp-name" or name == "mp2mp-name" or name == "mp2mpid" or name == "vpn-id" or name == "vpn-mtu" or name == "xconnect-shutdown"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "group-name"):
                    self.group_name = value
                    self.group_name.value_namespace = name_space
                    self.group_name.value_namespace_prefix = name_space_prefix
                if(value_path == "group-name-xr"):
                    self.group_name_xr = value
                    self.group_name_xr.value_namespace = name_space
                    self.group_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "l2-encapsulation"):
                    self.l2_encapsulation = value
                    self.l2_encapsulation.value_namespace = name_space
                    self.l2_encapsulation.value_namespace_prefix = name_space_prefix
                if(value_path == "mp2-mp-name"):
                    self.mp2_mp_name = value
                    self.mp2_mp_name.value_namespace = name_space
                    self.mp2_mp_name.value_namespace_prefix = name_space_prefix
                if(value_path == "mp2mp-name"):
                    self.mp2mp_name = value
                    self.mp2mp_name.value_namespace = name_space
                    self.mp2mp_name.value_namespace_prefix = name_space_prefix
                if(value_path == "mp2mpid"):
                    self.mp2mpid = value
                    self.mp2mpid.value_namespace = name_space
                    self.mp2mpid.value_namespace_prefix = name_space_prefix
                if(value_path == "vpn-id"):
                    self.vpn_id = value
                    self.vpn_id.value_namespace = name_space
                    self.vpn_id.value_namespace_prefix = name_space_prefix
                if(value_path == "vpn-mtu"):
                    self.vpn_mtu = value
                    self.vpn_mtu.value_namespace = name_space
                    self.vpn_mtu.value_namespace_prefix = name_space_prefix
                if(value_path == "xconnect-shutdown"):
                    self.xconnect_shutdown = value
                    self.xconnect_shutdown.value_namespace = name_space
                    self.xconnect_shutdown.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.xconnect_mp2mp:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.xconnect_mp2mp:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "xconnect-mp2mps" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "xconnect-mp2mp"):
                for c in self.xconnect_mp2mp:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.XconnectMp2Mps.XconnectMp2Mp()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.xconnect_mp2mp.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "xconnect-mp2mp"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Indexes(Entity):
        """
        ID Manager Index Table
        
        .. attribute:: index
        
        	ID Manager Index Pool
        	**type**\: list of    :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Indexes.Index>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.Indexes, self).__init__()

            self.yang_name = "indexes"
            self.yang_parent_name = "l2vpn"

            self.index = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.Indexes, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.Indexes, self).__setattr__(name, value)


        class Index(Entity):
            """
            ID Manager Index Pool
            
            .. attribute:: pool_id  <key>
            
            	Pool ID
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            .. attribute:: allocated_ids
            
            	Number of IDs allocated
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: application_type
            
            	Application Type
            	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
            
            .. attribute:: max_num_id_mgr
            
            	Maximum number of pool extensions
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_id_mgr_in_use
            
            	ID mgr instances in use
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pool_id_xr
            
            	Pool Id
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pool_size
            
            	Pool size
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: zombied_ids
            
            	Number of IDs allocated
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Indexes.Index, self).__init__()

                self.yang_name = "index"
                self.yang_parent_name = "indexes"

                self.pool_id = YLeaf(YType.str, "pool-id")

                self.allocated_ids = YLeaf(YType.uint32, "allocated-ids")

                self.application_type = YLeaf(YType.enumeration, "application-type")

                self.max_num_id_mgr = YLeaf(YType.uint32, "max-num-id-mgr")

                self.num_id_mgr_in_use = YLeaf(YType.uint32, "num-id-mgr-in-use")

                self.pool_id_xr = YLeaf(YType.uint32, "pool-id-xr")

                self.pool_size = YLeaf(YType.uint32, "pool-size")

                self.zombied_ids = YLeaf(YType.uint32, "zombied-ids")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("pool_id",
                                "allocated_ids",
                                "application_type",
                                "max_num_id_mgr",
                                "num_id_mgr_in_use",
                                "pool_id_xr",
                                "pool_size",
                                "zombied_ids") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Indexes.Index, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Indexes.Index, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.pool_id.is_set or
                    self.allocated_ids.is_set or
                    self.application_type.is_set or
                    self.max_num_id_mgr.is_set or
                    self.num_id_mgr_in_use.is_set or
                    self.pool_id_xr.is_set or
                    self.pool_size.is_set or
                    self.zombied_ids.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.pool_id.yfilter != YFilter.not_set or
                    self.allocated_ids.yfilter != YFilter.not_set or
                    self.application_type.yfilter != YFilter.not_set or
                    self.max_num_id_mgr.yfilter != YFilter.not_set or
                    self.num_id_mgr_in_use.yfilter != YFilter.not_set or
                    self.pool_id_xr.yfilter != YFilter.not_set or
                    self.pool_size.yfilter != YFilter.not_set or
                    self.zombied_ids.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "index" + "[pool-id='" + self.pool_id.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/indexes/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.pool_id.is_set or self.pool_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pool_id.get_name_leafdata())
                if (self.allocated_ids.is_set or self.allocated_ids.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.allocated_ids.get_name_leafdata())
                if (self.application_type.is_set or self.application_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.application_type.get_name_leafdata())
                if (self.max_num_id_mgr.is_set or self.max_num_id_mgr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.max_num_id_mgr.get_name_leafdata())
                if (self.num_id_mgr_in_use.is_set or self.num_id_mgr_in_use.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.num_id_mgr_in_use.get_name_leafdata())
                if (self.pool_id_xr.is_set or self.pool_id_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pool_id_xr.get_name_leafdata())
                if (self.pool_size.is_set or self.pool_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pool_size.get_name_leafdata())
                if (self.zombied_ids.is_set or self.zombied_ids.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.zombied_ids.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "pool-id" or name == "allocated-ids" or name == "application-type" or name == "max-num-id-mgr" or name == "num-id-mgr-in-use" or name == "pool-id-xr" or name == "pool-size" or name == "zombied-ids"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "pool-id"):
                    self.pool_id = value
                    self.pool_id.value_namespace = name_space
                    self.pool_id.value_namespace_prefix = name_space_prefix
                if(value_path == "allocated-ids"):
                    self.allocated_ids = value
                    self.allocated_ids.value_namespace = name_space
                    self.allocated_ids.value_namespace_prefix = name_space_prefix
                if(value_path == "application-type"):
                    self.application_type = value
                    self.application_type.value_namespace = name_space
                    self.application_type.value_namespace_prefix = name_space_prefix
                if(value_path == "max-num-id-mgr"):
                    self.max_num_id_mgr = value
                    self.max_num_id_mgr.value_namespace = name_space
                    self.max_num_id_mgr.value_namespace_prefix = name_space_prefix
                if(value_path == "num-id-mgr-in-use"):
                    self.num_id_mgr_in_use = value
                    self.num_id_mgr_in_use.value_namespace = name_space
                    self.num_id_mgr_in_use.value_namespace_prefix = name_space_prefix
                if(value_path == "pool-id-xr"):
                    self.pool_id_xr = value
                    self.pool_id_xr.value_namespace = name_space
                    self.pool_id_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "pool-size"):
                    self.pool_size = value
                    self.pool_size.value_namespace = name_space
                    self.pool_size.value_namespace_prefix = name_space_prefix
                if(value_path == "zombied-ids"):
                    self.zombied_ids = value
                    self.zombied_ids.value_namespace = name_space
                    self.zombied_ids.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.index:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.index:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "indexes" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "index"):
                for c in self.index:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.Indexes.Index()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.index.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "index"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class XconnectSummary(Entity):
        """
        XConnect summary information
        
        .. attribute:: admin_down_backup_interface_xconnects
        
        	Number of XCs with backup interface in admin down state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: admin_down_backup_xconnects
        
        	Number of XCs with backup PW in admin down state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: down_backup_interface_xconnects
        
        	Number of XCs with backup interface in down state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: down_backup_xconnects
        
        	Number of XCs with backup PW in down state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_ce2_ceconnections
        
        	Number of Ce2Ce connections
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_ce2ce_advertized
        
        	Number of CE2CE connections that have been advertized
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_ce2ce_not_advertized
        
        	Number of CE2CE connections that have not been advertized
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_groups
        
        	Number of groups
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2mp_xconnects
        
        	Number of mp2mp xconnects
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2mp_xconnects_advertised
        
        	Number of Mp2mp XCs that have been advertized
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2mp_xconnects_down
        
        	Number of Mp2mp XCs that have ben admined down
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2mp_xconnects_up
        
        	Number of Mp2mp XCs that have been admined up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2mp_xconnectss_not_advertised
        
        	Number of Mp2mp XCs that have not been advertized
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects
        
        	Number of xconnects
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_administratively_down
        
        	Number of xconnects with segments in admin down state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_currently_using_backup
        
        	Number of XCs currently using backup PW (UP state)
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_currently_using_backup_interface
        
        	Number of XCs currently using backup interface (UP state)
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_down
        
        	Number of xconnects whose state is down
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_locally_switched
        
        	Number of locally switched xconnects
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
        
        	Number of xconnects of type attachment circuit to pseudowire
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
        
        	Number of xconnects of type monitor session to pseudowire
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
        
        	Number of xconnects of type PseudoWire To PseudoWire
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_unresolved
        
        	Number of xconnects whose state is unresolved
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_up
        
        	Numxber of xconnects whose state is up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_with_backup_interface
        
        	Number of XCs configured with backup interface
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_with_backup_pw
        
        	Number of XCs configured with backup PW
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: out_of_memory_state
        
        	L2VPN Out of memory state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: partially_programmed_xconnects
        
        	Number of cross\-connects partially programmed
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: standby_backup_interface_xconnects
        
        	Number of XCs with backup interface in standby state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: standby_backup_xconnects
        
        	Number of XCs with backup PW in standby state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: standby_ready_backup_xconnects
        
        	Number of XCs with backup PW in standby ready state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: unresolved_backup_interface_xconnects
        
        	Number of XCs with backup interface in unresolved state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: unresolved_backup_xconnects
        
        	Number of XCs with backup PW in unresolved state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.XconnectSummary, self).__init__()

            self.yang_name = "xconnect-summary"
            self.yang_parent_name = "l2vpn"

            self.admin_down_backup_interface_xconnects = YLeaf(YType.uint32, "admin-down-backup-interface-xconnects")

            self.admin_down_backup_xconnects = YLeaf(YType.uint32, "admin-down-backup-xconnects")

            self.down_backup_interface_xconnects = YLeaf(YType.uint32, "down-backup-interface-xconnects")

            self.down_backup_xconnects = YLeaf(YType.uint32, "down-backup-xconnects")

            self.number_ce2_ceconnections = YLeaf(YType.uint32, "number-ce2-ceconnections")

            self.number_ce2ce_advertized = YLeaf(YType.uint32, "number-ce2ce-advertized")

            self.number_ce2ce_not_advertized = YLeaf(YType.uint32, "number-ce2ce-not-advertized")

            self.number_groups = YLeaf(YType.uint32, "number-groups")

            self.number_mp2mp_xconnects = YLeaf(YType.uint32, "number-mp2mp-xconnects")

            self.number_mp2mp_xconnects_advertised = YLeaf(YType.uint32, "number-mp2mp-xconnects-advertised")

            self.number_mp2mp_xconnects_down = YLeaf(YType.uint32, "number-mp2mp-xconnects-down")

            self.number_mp2mp_xconnects_up = YLeaf(YType.uint32, "number-mp2mp-xconnects-up")

            self.number_mp2mp_xconnectss_not_advertised = YLeaf(YType.uint32, "number-mp2mp-xconnectss-not-advertised")

            self.number_xconnects = YLeaf(YType.uint32, "number-xconnects")

            self.number_xconnects_administratively_down = YLeaf(YType.uint32, "number-xconnects-administratively-down")

            self.number_xconnects_currently_using_backup = YLeaf(YType.uint32, "number-xconnects-currently-using-backup")

            self.number_xconnects_currently_using_backup_interface = YLeaf(YType.uint32, "number-xconnects-currently-using-backup-interface")

            self.number_xconnects_down = YLeaf(YType.uint32, "number-xconnects-down")

            self.number_xconnects_locally_switched = YLeaf(YType.uint32, "number-xconnects-locally-switched")

            self.number_xconnects_type_attachment_circuit_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-attachment-circuit-to-pseudo-wire")

            self.number_xconnects_type_monitor_session_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-monitor-session-to-pseudo-wire")

            self.number_xconnects_type_pseudo_wire_to_pseudo_wire = YLeaf(YType.uint32, "number-xconnects-type-pseudo-wire-to-pseudo-wire")

            self.number_xconnects_unresolved = YLeaf(YType.uint32, "number-xconnects-unresolved")

            self.number_xconnects_up = YLeaf(YType.uint32, "number-xconnects-up")

            self.number_xconnects_with_backup_interface = YLeaf(YType.uint32, "number-xconnects-with-backup-interface")

            self.number_xconnects_with_backup_pw = YLeaf(YType.uint32, "number-xconnects-with-backup-pw")

            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

            self.partially_programmed_xconnects = YLeaf(YType.uint32, "partially-programmed-xconnects")

            self.standby_backup_interface_xconnects = YLeaf(YType.uint32, "standby-backup-interface-xconnects")

            self.standby_backup_xconnects = YLeaf(YType.uint32, "standby-backup-xconnects")

            self.standby_ready_backup_xconnects = YLeaf(YType.uint32, "standby-ready-backup-xconnects")

            self.unresolved_backup_interface_xconnects = YLeaf(YType.uint32, "unresolved-backup-interface-xconnects")

            self.unresolved_backup_xconnects = YLeaf(YType.uint32, "unresolved-backup-xconnects")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("admin_down_backup_interface_xconnects",
                            "admin_down_backup_xconnects",
                            "down_backup_interface_xconnects",
                            "down_backup_xconnects",
                            "number_ce2_ceconnections",
                            "number_ce2ce_advertized",
                            "number_ce2ce_not_advertized",
                            "number_groups",
                            "number_mp2mp_xconnects",
                            "number_mp2mp_xconnects_advertised",
                            "number_mp2mp_xconnects_down",
                            "number_mp2mp_xconnects_up",
                            "number_mp2mp_xconnectss_not_advertised",
                            "number_xconnects",
                            "number_xconnects_administratively_down",
                            "number_xconnects_currently_using_backup",
                            "number_xconnects_currently_using_backup_interface",
                            "number_xconnects_down",
                            "number_xconnects_locally_switched",
                            "number_xconnects_type_attachment_circuit_to_pseudo_wire",
                            "number_xconnects_type_monitor_session_to_pseudo_wire",
                            "number_xconnects_type_pseudo_wire_to_pseudo_wire",
                            "number_xconnects_unresolved",
                            "number_xconnects_up",
                            "number_xconnects_with_backup_interface",
                            "number_xconnects_with_backup_pw",
                            "out_of_memory_state",
                            "partially_programmed_xconnects",
                            "standby_backup_interface_xconnects",
                            "standby_backup_xconnects",
                            "standby_ready_backup_xconnects",
                            "unresolved_backup_interface_xconnects",
                            "unresolved_backup_xconnects") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.XconnectSummary, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.XconnectSummary, self).__setattr__(name, value)

        def has_data(self):
            return (
                self.admin_down_backup_interface_xconnects.is_set or
                self.admin_down_backup_xconnects.is_set or
                self.down_backup_interface_xconnects.is_set or
                self.down_backup_xconnects.is_set or
                self.number_ce2_ceconnections.is_set or
                self.number_ce2ce_advertized.is_set or
                self.number_ce2ce_not_advertized.is_set or
                self.number_groups.is_set or
                self.number_mp2mp_xconnects.is_set or
                self.number_mp2mp_xconnects_advertised.is_set or
                self.number_mp2mp_xconnects_down.is_set or
                self.number_mp2mp_xconnects_up.is_set or
                self.number_mp2mp_xconnectss_not_advertised.is_set or
                self.number_xconnects.is_set or
                self.number_xconnects_administratively_down.is_set or
                self.number_xconnects_currently_using_backup.is_set or
                self.number_xconnects_currently_using_backup_interface.is_set or
                self.number_xconnects_down.is_set or
                self.number_xconnects_locally_switched.is_set or
                self.number_xconnects_type_attachment_circuit_to_pseudo_wire.is_set or
                self.number_xconnects_type_monitor_session_to_pseudo_wire.is_set or
                self.number_xconnects_type_pseudo_wire_to_pseudo_wire.is_set or
                self.number_xconnects_unresolved.is_set or
                self.number_xconnects_up.is_set or
                self.number_xconnects_with_backup_interface.is_set or
                self.number_xconnects_with_backup_pw.is_set or
                self.out_of_memory_state.is_set or
                self.partially_programmed_xconnects.is_set or
                self.standby_backup_interface_xconnects.is_set or
                self.standby_backup_xconnects.is_set or
                self.standby_ready_backup_xconnects.is_set or
                self.unresolved_backup_interface_xconnects.is_set or
                self.unresolved_backup_xconnects.is_set)

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.admin_down_backup_interface_xconnects.yfilter != YFilter.not_set or
                self.admin_down_backup_xconnects.yfilter != YFilter.not_set or
                self.down_backup_interface_xconnects.yfilter != YFilter.not_set or
                self.down_backup_xconnects.yfilter != YFilter.not_set or
                self.number_ce2_ceconnections.yfilter != YFilter.not_set or
                self.number_ce2ce_advertized.yfilter != YFilter.not_set or
                self.number_ce2ce_not_advertized.yfilter != YFilter.not_set or
                self.number_groups.yfilter != YFilter.not_set or
                self.number_mp2mp_xconnects.yfilter != YFilter.not_set or
                self.number_mp2mp_xconnects_advertised.yfilter != YFilter.not_set or
                self.number_mp2mp_xconnects_down.yfilter != YFilter.not_set or
                self.number_mp2mp_xconnects_up.yfilter != YFilter.not_set or
                self.number_mp2mp_xconnectss_not_advertised.yfilter != YFilter.not_set or
                self.number_xconnects.yfilter != YFilter.not_set or
                self.number_xconnects_administratively_down.yfilter != YFilter.not_set or
                self.number_xconnects_currently_using_backup.yfilter != YFilter.not_set or
                self.number_xconnects_currently_using_backup_interface.yfilter != YFilter.not_set or
                self.number_xconnects_down.yfilter != YFilter.not_set or
                self.number_xconnects_locally_switched.yfilter != YFilter.not_set or
                self.number_xconnects_type_attachment_circuit_to_pseudo_wire.yfilter != YFilter.not_set or
                self.number_xconnects_type_monitor_session_to_pseudo_wire.yfilter != YFilter.not_set or
                self.number_xconnects_type_pseudo_wire_to_pseudo_wire.yfilter != YFilter.not_set or
                self.number_xconnects_unresolved.yfilter != YFilter.not_set or
                self.number_xconnects_up.yfilter != YFilter.not_set or
                self.number_xconnects_with_backup_interface.yfilter != YFilter.not_set or
                self.number_xconnects_with_backup_pw.yfilter != YFilter.not_set or
                self.out_of_memory_state.yfilter != YFilter.not_set or
                self.partially_programmed_xconnects.yfilter != YFilter.not_set or
                self.standby_backup_interface_xconnects.yfilter != YFilter.not_set or
                self.standby_backup_xconnects.yfilter != YFilter.not_set or
                self.standby_ready_backup_xconnects.yfilter != YFilter.not_set or
                self.unresolved_backup_interface_xconnects.yfilter != YFilter.not_set or
                self.unresolved_backup_xconnects.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "xconnect-summary" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.admin_down_backup_interface_xconnects.is_set or self.admin_down_backup_interface_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.admin_down_backup_interface_xconnects.get_name_leafdata())
            if (self.admin_down_backup_xconnects.is_set or self.admin_down_backup_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.admin_down_backup_xconnects.get_name_leafdata())
            if (self.down_backup_interface_xconnects.is_set or self.down_backup_interface_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.down_backup_interface_xconnects.get_name_leafdata())
            if (self.down_backup_xconnects.is_set or self.down_backup_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.down_backup_xconnects.get_name_leafdata())
            if (self.number_ce2_ceconnections.is_set or self.number_ce2_ceconnections.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_ce2_ceconnections.get_name_leafdata())
            if (self.number_ce2ce_advertized.is_set or self.number_ce2ce_advertized.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_ce2ce_advertized.get_name_leafdata())
            if (self.number_ce2ce_not_advertized.is_set or self.number_ce2ce_not_advertized.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_ce2ce_not_advertized.get_name_leafdata())
            if (self.number_groups.is_set or self.number_groups.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_groups.get_name_leafdata())
            if (self.number_mp2mp_xconnects.is_set or self.number_mp2mp_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_mp2mp_xconnects.get_name_leafdata())
            if (self.number_mp2mp_xconnects_advertised.is_set or self.number_mp2mp_xconnects_advertised.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_mp2mp_xconnects_advertised.get_name_leafdata())
            if (self.number_mp2mp_xconnects_down.is_set or self.number_mp2mp_xconnects_down.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_mp2mp_xconnects_down.get_name_leafdata())
            if (self.number_mp2mp_xconnects_up.is_set or self.number_mp2mp_xconnects_up.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_mp2mp_xconnects_up.get_name_leafdata())
            if (self.number_mp2mp_xconnectss_not_advertised.is_set or self.number_mp2mp_xconnectss_not_advertised.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_mp2mp_xconnectss_not_advertised.get_name_leafdata())
            if (self.number_xconnects.is_set or self.number_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects.get_name_leafdata())
            if (self.number_xconnects_administratively_down.is_set or self.number_xconnects_administratively_down.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_administratively_down.get_name_leafdata())
            if (self.number_xconnects_currently_using_backup.is_set or self.number_xconnects_currently_using_backup.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_currently_using_backup.get_name_leafdata())
            if (self.number_xconnects_currently_using_backup_interface.is_set or self.number_xconnects_currently_using_backup_interface.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_currently_using_backup_interface.get_name_leafdata())
            if (self.number_xconnects_down.is_set or self.number_xconnects_down.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_down.get_name_leafdata())
            if (self.number_xconnects_locally_switched.is_set or self.number_xconnects_locally_switched.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_locally_switched.get_name_leafdata())
            if (self.number_xconnects_type_attachment_circuit_to_pseudo_wire.is_set or self.number_xconnects_type_attachment_circuit_to_pseudo_wire.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_type_attachment_circuit_to_pseudo_wire.get_name_leafdata())
            if (self.number_xconnects_type_monitor_session_to_pseudo_wire.is_set or self.number_xconnects_type_monitor_session_to_pseudo_wire.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_type_monitor_session_to_pseudo_wire.get_name_leafdata())
            if (self.number_xconnects_type_pseudo_wire_to_pseudo_wire.is_set or self.number_xconnects_type_pseudo_wire_to_pseudo_wire.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_type_pseudo_wire_to_pseudo_wire.get_name_leafdata())
            if (self.number_xconnects_unresolved.is_set or self.number_xconnects_unresolved.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_unresolved.get_name_leafdata())
            if (self.number_xconnects_up.is_set or self.number_xconnects_up.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_up.get_name_leafdata())
            if (self.number_xconnects_with_backup_interface.is_set or self.number_xconnects_with_backup_interface.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_with_backup_interface.get_name_leafdata())
            if (self.number_xconnects_with_backup_pw.is_set or self.number_xconnects_with_backup_pw.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_xconnects_with_backup_pw.get_name_leafdata())
            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
            if (self.partially_programmed_xconnects.is_set or self.partially_programmed_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.partially_programmed_xconnects.get_name_leafdata())
            if (self.standby_backup_interface_xconnects.is_set or self.standby_backup_interface_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.standby_backup_interface_xconnects.get_name_leafdata())
            if (self.standby_backup_xconnects.is_set or self.standby_backup_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.standby_backup_xconnects.get_name_leafdata())
            if (self.standby_ready_backup_xconnects.is_set or self.standby_ready_backup_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.standby_ready_backup_xconnects.get_name_leafdata())
            if (self.unresolved_backup_interface_xconnects.is_set or self.unresolved_backup_interface_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.unresolved_backup_interface_xconnects.get_name_leafdata())
            if (self.unresolved_backup_xconnects.is_set or self.unresolved_backup_xconnects.yfilter != YFilter.not_set):
                leaf_name_data.append(self.unresolved_backup_xconnects.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "admin-down-backup-interface-xconnects" or name == "admin-down-backup-xconnects" or name == "down-backup-interface-xconnects" or name == "down-backup-xconnects" or name == "number-ce2-ceconnections" or name == "number-ce2ce-advertized" or name == "number-ce2ce-not-advertized" or name == "number-groups" or name == "number-mp2mp-xconnects" or name == "number-mp2mp-xconnects-advertised" or name == "number-mp2mp-xconnects-down" or name == "number-mp2mp-xconnects-up" or name == "number-mp2mp-xconnectss-not-advertised" or name == "number-xconnects" or name == "number-xconnects-administratively-down" or name == "number-xconnects-currently-using-backup" or name == "number-xconnects-currently-using-backup-interface" or name == "number-xconnects-down" or name == "number-xconnects-locally-switched" or name == "number-xconnects-type-attachment-circuit-to-pseudo-wire" or name == "number-xconnects-type-monitor-session-to-pseudo-wire" or name == "number-xconnects-type-pseudo-wire-to-pseudo-wire" or name == "number-xconnects-unresolved" or name == "number-xconnects-up" or name == "number-xconnects-with-backup-interface" or name == "number-xconnects-with-backup-pw" or name == "out-of-memory-state" or name == "partially-programmed-xconnects" or name == "standby-backup-interface-xconnects" or name == "standby-backup-xconnects" or name == "standby-ready-backup-xconnects" or name == "unresolved-backup-interface-xconnects" or name == "unresolved-backup-xconnects"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "admin-down-backup-interface-xconnects"):
                self.admin_down_backup_interface_xconnects = value
                self.admin_down_backup_interface_xconnects.value_namespace = name_space
                self.admin_down_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "admin-down-backup-xconnects"):
                self.admin_down_backup_xconnects = value
                self.admin_down_backup_xconnects.value_namespace = name_space
                self.admin_down_backup_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "down-backup-interface-xconnects"):
                self.down_backup_interface_xconnects = value
                self.down_backup_interface_xconnects.value_namespace = name_space
                self.down_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "down-backup-xconnects"):
                self.down_backup_xconnects = value
                self.down_backup_xconnects.value_namespace = name_space
                self.down_backup_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "number-ce2-ceconnections"):
                self.number_ce2_ceconnections = value
                self.number_ce2_ceconnections.value_namespace = name_space
                self.number_ce2_ceconnections.value_namespace_prefix = name_space_prefix
            if(value_path == "number-ce2ce-advertized"):
                self.number_ce2ce_advertized = value
                self.number_ce2ce_advertized.value_namespace = name_space
                self.number_ce2ce_advertized.value_namespace_prefix = name_space_prefix
            if(value_path == "number-ce2ce-not-advertized"):
                self.number_ce2ce_not_advertized = value
                self.number_ce2ce_not_advertized.value_namespace = name_space
                self.number_ce2ce_not_advertized.value_namespace_prefix = name_space_prefix
            if(value_path == "number-groups"):
                self.number_groups = value
                self.number_groups.value_namespace = name_space
                self.number_groups.value_namespace_prefix = name_space_prefix
            if(value_path == "number-mp2mp-xconnects"):
                self.number_mp2mp_xconnects = value
                self.number_mp2mp_xconnects.value_namespace = name_space
                self.number_mp2mp_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "number-mp2mp-xconnects-advertised"):
                self.number_mp2mp_xconnects_advertised = value
                self.number_mp2mp_xconnects_advertised.value_namespace = name_space
                self.number_mp2mp_xconnects_advertised.value_namespace_prefix = name_space_prefix
            if(value_path == "number-mp2mp-xconnects-down"):
                self.number_mp2mp_xconnects_down = value
                self.number_mp2mp_xconnects_down.value_namespace = name_space
                self.number_mp2mp_xconnects_down.value_namespace_prefix = name_space_prefix
            if(value_path == "number-mp2mp-xconnects-up"):
                self.number_mp2mp_xconnects_up = value
                self.number_mp2mp_xconnects_up.value_namespace = name_space
                self.number_mp2mp_xconnects_up.value_namespace_prefix = name_space_prefix
            if(value_path == "number-mp2mp-xconnectss-not-advertised"):
                self.number_mp2mp_xconnectss_not_advertised = value
                self.number_mp2mp_xconnectss_not_advertised.value_namespace = name_space
                self.number_mp2mp_xconnectss_not_advertised.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects"):
                self.number_xconnects = value
                self.number_xconnects.value_namespace = name_space
                self.number_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-administratively-down"):
                self.number_xconnects_administratively_down = value
                self.number_xconnects_administratively_down.value_namespace = name_space
                self.number_xconnects_administratively_down.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-currently-using-backup"):
                self.number_xconnects_currently_using_backup = value
                self.number_xconnects_currently_using_backup.value_namespace = name_space
                self.number_xconnects_currently_using_backup.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-currently-using-backup-interface"):
                self.number_xconnects_currently_using_backup_interface = value
                self.number_xconnects_currently_using_backup_interface.value_namespace = name_space
                self.number_xconnects_currently_using_backup_interface.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-down"):
                self.number_xconnects_down = value
                self.number_xconnects_down.value_namespace = name_space
                self.number_xconnects_down.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-locally-switched"):
                self.number_xconnects_locally_switched = value
                self.number_xconnects_locally_switched.value_namespace = name_space
                self.number_xconnects_locally_switched.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-type-attachment-circuit-to-pseudo-wire"):
                self.number_xconnects_type_attachment_circuit_to_pseudo_wire = value
                self.number_xconnects_type_attachment_circuit_to_pseudo_wire.value_namespace = name_space
                self.number_xconnects_type_attachment_circuit_to_pseudo_wire.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-type-monitor-session-to-pseudo-wire"):
                self.number_xconnects_type_monitor_session_to_pseudo_wire = value
                self.number_xconnects_type_monitor_session_to_pseudo_wire.value_namespace = name_space
                self.number_xconnects_type_monitor_session_to_pseudo_wire.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-type-pseudo-wire-to-pseudo-wire"):
                self.number_xconnects_type_pseudo_wire_to_pseudo_wire = value
                self.number_xconnects_type_pseudo_wire_to_pseudo_wire.value_namespace = name_space
                self.number_xconnects_type_pseudo_wire_to_pseudo_wire.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-unresolved"):
                self.number_xconnects_unresolved = value
                self.number_xconnects_unresolved.value_namespace = name_space
                self.number_xconnects_unresolved.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-up"):
                self.number_xconnects_up = value
                self.number_xconnects_up.value_namespace = name_space
                self.number_xconnects_up.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-with-backup-interface"):
                self.number_xconnects_with_backup_interface = value
                self.number_xconnects_with_backup_interface.value_namespace = name_space
                self.number_xconnects_with_backup_interface.value_namespace_prefix = name_space_prefix
            if(value_path == "number-xconnects-with-backup-pw"):
                self.number_xconnects_with_backup_pw = value
                self.number_xconnects_with_backup_pw.value_namespace = name_space
                self.number_xconnects_with_backup_pw.value_namespace_prefix = name_space_prefix
            if(value_path == "out-of-memory-state"):
                self.out_of_memory_state = value
                self.out_of_memory_state.value_namespace = name_space
                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
            if(value_path == "partially-programmed-xconnects"):
                self.partially_programmed_xconnects = value
                self.partially_programmed_xconnects.value_namespace = name_space
                self.partially_programmed_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "standby-backup-interface-xconnects"):
                self.standby_backup_interface_xconnects = value
                self.standby_backup_interface_xconnects.value_namespace = name_space
                self.standby_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "standby-backup-xconnects"):
                self.standby_backup_xconnects = value
                self.standby_backup_xconnects.value_namespace = name_space
                self.standby_backup_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "standby-ready-backup-xconnects"):
                self.standby_ready_backup_xconnects = value
                self.standby_ready_backup_xconnects.value_namespace = name_space
                self.standby_ready_backup_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "unresolved-backup-interface-xconnects"):
                self.unresolved_backup_interface_xconnects = value
                self.unresolved_backup_interface_xconnects.value_namespace = name_space
                self.unresolved_backup_interface_xconnects.value_namespace_prefix = name_space_prefix
            if(value_path == "unresolved-backup-xconnects"):
                self.unresolved_backup_xconnects = value
                self.unresolved_backup_xconnects.value_namespace = name_space
                self.unresolved_backup_xconnects.value_namespace_prefix = name_space_prefix


    class ProcFsm(Entity):
        """
        L2VPN Process FSM information
        
        .. attribute:: event_history
        
        	L2VPN Process event history
        	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.EventHistory>`
        
        .. attribute:: failover_status
        
        	L2VPN failover status
        	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.FailoverStatus>`
        
        .. attribute:: issu_status
        
        	L2VPN ISSU Status and timestamp
        	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.IssuStatus>`
        
        .. attribute:: nsr_status
        
        	L2VPN NSR status and timestamp
        	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.NsrStatus>`
        
        .. attribute:: process_role
        
        	Current Process Role
        	**type**\:  int
        
        	**range:** 0..255
        
        .. attribute:: process_state
        
        	Current Process State
        	**type**\:  int
        
        	**range:** 0..255
        
        .. attribute:: report_card
        
        	L2VPN Collaborator report card
        	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.ReportCard>`
        
        .. attribute:: state_transition_time
        
        	Transition time for all states
        	**type**\:  list of int
        
        	**range:** 0..4294967295
        
        .. attribute:: sw_install_in_progress
        
        	Is s/w install currently in progress?
        	**type**\:  bool
        
        .. attribute:: sync_flags
        
        	Sync complete flags
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: xid_info
        
        	XID information
        	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.XidInfo>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.ProcFsm, self).__init__()

            self.yang_name = "proc-fsm"
            self.yang_parent_name = "l2vpn"

            self.process_role = YLeaf(YType.uint8, "process-role")

            self.process_state = YLeaf(YType.uint8, "process-state")

            self.state_transition_time = YLeafList(YType.uint32, "state-transition-time")

            self.sw_install_in_progress = YLeaf(YType.boolean, "sw-install-in-progress")

            self.sync_flags = YLeaf(YType.uint32, "sync-flags")

            self.failover_status = L2Vpn.ProcFsm.FailoverStatus()
            self.failover_status.parent = self
            self._children_name_map["failover_status"] = "failover-status"
            self._children_yang_names.add("failover-status")

            self.issu_status = L2Vpn.ProcFsm.IssuStatus()
            self.issu_status.parent = self
            self._children_name_map["issu_status"] = "issu-status"
            self._children_yang_names.add("issu-status")

            self.nsr_status = L2Vpn.ProcFsm.NsrStatus()
            self.nsr_status.parent = self
            self._children_name_map["nsr_status"] = "nsr-status"
            self._children_yang_names.add("nsr-status")

            self.event_history = YList(self)
            self.report_card = YList(self)
            self.xid_info = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("process_role",
                            "process_state",
                            "state_transition_time",
                            "sw_install_in_progress",
                            "sync_flags") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.ProcFsm, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.ProcFsm, self).__setattr__(name, value)


        class FailoverStatus(Entity):
            """
            L2VPN failover status
            
            .. attribute:: master_time
            
            	Master time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: start_time
            
            	Start time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: triggered_time
            
            	Triggered time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.ProcFsm.FailoverStatus, self).__init__()

                self.yang_name = "failover-status"
                self.yang_parent_name = "proc-fsm"

                self.master_time = YLeaf(YType.uint32, "master-time")

                self.start_time = YLeaf(YType.uint32, "start-time")

                self.triggered_time = YLeaf(YType.uint32, "triggered-time")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("master_time",
                                "start_time",
                                "triggered_time") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.ProcFsm.FailoverStatus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.ProcFsm.FailoverStatus, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.master_time.is_set or
                    self.start_time.is_set or
                    self.triggered_time.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.master_time.yfilter != YFilter.not_set or
                    self.start_time.yfilter != YFilter.not_set or
                    self.triggered_time.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "failover-status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/proc-fsm/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.master_time.is_set or self.master_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.master_time.get_name_leafdata())
                if (self.start_time.is_set or self.start_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.start_time.get_name_leafdata())
                if (self.triggered_time.is_set or self.triggered_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.triggered_time.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "master-time" or name == "start-time" or name == "triggered-time"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "master-time"):
                    self.master_time = value
                    self.master_time.value_namespace = name_space
                    self.master_time.value_namespace_prefix = name_space_prefix
                if(value_path == "start-time"):
                    self.start_time = value
                    self.start_time.value_namespace = name_space
                    self.start_time.value_namespace_prefix = name_space_prefix
                if(value_path == "triggered-time"):
                    self.triggered_time = value
                    self.triggered_time.value_namespace = name_space
                    self.triggered_time.value_namespace_prefix = name_space_prefix


        class NsrStatus(Entity):
            """
            L2VPN NSR status and timestamp
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.NsrStatus.IdtStatus>`
            
            .. attribute:: previ_ous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.NsrStatus.PreviOusIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.ProcFsm.NsrStatus, self).__init__()

                self.yang_name = "nsr-status"
                self.yang_parent_name = "proc-fsm"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = L2Vpn.ProcFsm.NsrStatus.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previ_ous_idt_status = L2Vpn.ProcFsm.NsrStatus.PreviOusIdtStatus()
                self.previ_ous_idt_status.parent = self
                self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                self._children_yang_names.add("previ-ous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.ProcFsm.NsrStatus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.ProcFsm.NsrStatus, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.ProcFsm.NsrStatus.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "nsr-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.ProcFsm.NsrStatus.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.ProcFsm.NsrStatus.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/proc-fsm/nsr-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviOusIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__init__()

                    self.yang_name = "previ-ous-idt-status"
                    self.yang_parent_name = "nsr-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previ-ous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/proc-fsm/nsr-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "nsr-status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/proc-fsm/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = L2Vpn.ProcFsm.NsrStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previ-ous-idt-status"):
                    if (self.previ_ous_idt_status is None):
                        self.previ_ous_idt_status = L2Vpn.ProcFsm.NsrStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    return self.previ_ous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix


        class IssuStatus(Entity):
            """
            L2VPN ISSU Status and timestamp
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.IssuStatus.IdtStatus>`
            
            .. attribute:: previ_ous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.IssuStatus.PreviOusIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`L2VpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRole>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.ProcFsm.IssuStatus, self).__init__()

                self.yang_name = "issu-status"
                self.yang_parent_name = "proc-fsm"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = L2Vpn.ProcFsm.IssuStatus.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previ_ous_idt_status = L2Vpn.ProcFsm.IssuStatus.PreviOusIdtStatus()
                self.previ_ous_idt_status.parent = self
                self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                self._children_yang_names.add("previ-ous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.ProcFsm.IssuStatus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.ProcFsm.IssuStatus, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.ProcFsm.IssuStatus.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "issu-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.ProcFsm.IssuStatus.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.ProcFsm.IssuStatus.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/proc-fsm/issu-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviOusIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__init__()

                    self.yang_name = "previ-ous-idt-status"
                    self.yang_parent_name = "issu-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previ-ous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/proc-fsm/issu-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previ_ous_idt_status is not None and self.previ_ous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "issu-status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/proc-fsm/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = L2Vpn.ProcFsm.IssuStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previ-ous-idt-status"):
                    if (self.previ_ous_idt_status is None):
                        self.previ_ous_idt_status = L2Vpn.ProcFsm.IssuStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    return self.previ_ous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previ-ous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix


        class XidInfo(Entity):
            """
            XID information
            
            .. attribute:: app_type
            
            	App type
            	**type**\:   :py:class:`L2VpnIdMgrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrApp>`
            
            .. attribute:: sent_ids
            
            	Number of XIDs transferred
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.ProcFsm.XidInfo, self).__init__()

                self.yang_name = "xid-info"
                self.yang_parent_name = "proc-fsm"

                self.app_type = YLeaf(YType.enumeration, "app-type")

                self.sent_ids = YLeaf(YType.uint32, "sent-ids")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("app_type",
                                "sent_ids") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.ProcFsm.XidInfo, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.ProcFsm.XidInfo, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.app_type.is_set or
                    self.sent_ids.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.app_type.yfilter != YFilter.not_set or
                    self.sent_ids.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "xid-info" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/proc-fsm/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.app_type.is_set or self.app_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.app_type.get_name_leafdata())
                if (self.sent_ids.is_set or self.sent_ids.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sent_ids.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "app-type" or name == "sent-ids"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "app-type"):
                    self.app_type = value
                    self.app_type.value_namespace = name_space
                    self.app_type.value_namespace_prefix = name_space_prefix
                if(value_path == "sent-ids"):
                    self.sent_ids = value
                    self.sent_ids.value_namespace = name_space
                    self.sent_ids.value_namespace_prefix = name_space_prefix


        class ReportCard(Entity):
            """
            L2VPN Collaborator report card
            
            .. attribute:: collaborator_idt_done
            
            	Is IDT done for this collaborator
            	**type**\:  bool
            
            .. attribute:: collaborator_is_connected
            
            	Is the collaborator connected
            	**type**\:  bool
            
            .. attribute:: collaborator_skipped
            
            	Was this collaborator skipped for not connecting in time
            	**type**\:  bool
            
            .. attribute:: connection_change_time
            
            	Time when connection state (UP/DOWN) changed
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: idt_time
            
            	Time when IDT was done
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.ProcFsm.ReportCard, self).__init__()

                self.yang_name = "report-card"
                self.yang_parent_name = "proc-fsm"

                self.collaborator_idt_done = YLeaf(YType.boolean, "collaborator-idt-done")

                self.collaborator_is_connected = YLeaf(YType.boolean, "collaborator-is-connected")

                self.collaborator_skipped = YLeaf(YType.boolean, "collaborator-skipped")

                self.connection_change_time = YLeaf(YType.uint32, "connection-change-time")

                self.idt_time = YLeaf(YType.uint32, "idt-time")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("collaborator_idt_done",
                                "collaborator_is_connected",
                                "collaborator_skipped",
                                "connection_change_time",
                                "idt_time") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.ProcFsm.ReportCard, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.ProcFsm.ReportCard, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.collaborator_idt_done.is_set or
                    self.collaborator_is_connected.is_set or
                    self.collaborator_skipped.is_set or
                    self.connection_change_time.is_set or
                    self.idt_time.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.collaborator_idt_done.yfilter != YFilter.not_set or
                    self.collaborator_is_connected.yfilter != YFilter.not_set or
                    self.collaborator_skipped.yfilter != YFilter.not_set or
                    self.connection_change_time.yfilter != YFilter.not_set or
                    self.idt_time.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "report-card" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/proc-fsm/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.collaborator_idt_done.is_set or self.collaborator_idt_done.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.collaborator_idt_done.get_name_leafdata())
                if (self.collaborator_is_connected.is_set or self.collaborator_is_connected.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.collaborator_is_connected.get_name_leafdata())
                if (self.collaborator_skipped.is_set or self.collaborator_skipped.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.collaborator_skipped.get_name_leafdata())
                if (self.connection_change_time.is_set or self.connection_change_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.connection_change_time.get_name_leafdata())
                if (self.idt_time.is_set or self.idt_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.idt_time.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "collaborator-idt-done" or name == "collaborator-is-connected" or name == "collaborator-skipped" or name == "connection-change-time" or name == "idt-time"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "collaborator-idt-done"):
                    self.collaborator_idt_done = value
                    self.collaborator_idt_done.value_namespace = name_space
                    self.collaborator_idt_done.value_namespace_prefix = name_space_prefix
                if(value_path == "collaborator-is-connected"):
                    self.collaborator_is_connected = value
                    self.collaborator_is_connected.value_namespace = name_space
                    self.collaborator_is_connected.value_namespace_prefix = name_space_prefix
                if(value_path == "collaborator-skipped"):
                    self.collaborator_skipped = value
                    self.collaborator_skipped.value_namespace = name_space
                    self.collaborator_skipped.value_namespace_prefix = name_space_prefix
                if(value_path == "connection-change-time"):
                    self.connection_change_time = value
                    self.connection_change_time.value_namespace = name_space
                    self.connection_change_time.value_namespace_prefix = name_space_prefix
                if(value_path == "idt-time"):
                    self.idt_time = value
                    self.idt_time.value_namespace = name_space
                    self.idt_time.value_namespace_prefix = name_space_prefix


        class EventHistory(Entity):
            """
            L2VPN Process event history
            
            .. attribute:: event_timestamp
            
            	Event timestamp
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: new_state
            
            	New state
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: previous_state
            
            	Previous state
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_collaborator
            
            	Process collaborator
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: process_event
            
            	Process event
            	**type**\:  int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.ProcFsm.EventHistory, self).__init__()

                self.yang_name = "event-history"
                self.yang_parent_name = "proc-fsm"

                self.event_timestamp = YLeaf(YType.uint32, "event-timestamp")

                self.new_state = YLeaf(YType.uint8, "new-state")

                self.previous_state = YLeaf(YType.uint8, "previous-state")

                self.process_collaborator = YLeaf(YType.uint16, "process-collaborator")

                self.process_event = YLeaf(YType.uint16, "process-event")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("event_timestamp",
                                "new_state",
                                "previous_state",
                                "process_collaborator",
                                "process_event") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.ProcFsm.EventHistory, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.ProcFsm.EventHistory, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.event_timestamp.is_set or
                    self.new_state.is_set or
                    self.previous_state.is_set or
                    self.process_collaborator.is_set or
                    self.process_event.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.event_timestamp.yfilter != YFilter.not_set or
                    self.new_state.yfilter != YFilter.not_set or
                    self.previous_state.yfilter != YFilter.not_set or
                    self.process_collaborator.yfilter != YFilter.not_set or
                    self.process_event.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "event-history" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/proc-fsm/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.event_timestamp.is_set or self.event_timestamp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.event_timestamp.get_name_leafdata())
                if (self.new_state.is_set or self.new_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.new_state.get_name_leafdata())
                if (self.previous_state.is_set or self.previous_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.previous_state.get_name_leafdata())
                if (self.process_collaborator.is_set or self.process_collaborator.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_collaborator.get_name_leafdata())
                if (self.process_event.is_set or self.process_event.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_event.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "event-timestamp" or name == "new-state" or name == "previous-state" or name == "process-collaborator" or name == "process-event"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "event-timestamp"):
                    self.event_timestamp = value
                    self.event_timestamp.value_namespace = name_space
                    self.event_timestamp.value_namespace_prefix = name_space_prefix
                if(value_path == "new-state"):
                    self.new_state = value
                    self.new_state.value_namespace = name_space
                    self.new_state.value_namespace_prefix = name_space_prefix
                if(value_path == "previous-state"):
                    self.previous_state = value
                    self.previous_state.value_namespace = name_space
                    self.previous_state.value_namespace_prefix = name_space_prefix
                if(value_path == "process-collaborator"):
                    self.process_collaborator = value
                    self.process_collaborator.value_namespace = name_space
                    self.process_collaborator.value_namespace_prefix = name_space_prefix
                if(value_path == "process-event"):
                    self.process_event = value
                    self.process_event.value_namespace = name_space
                    self.process_event.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.event_history:
                if (c.has_data()):
                    return True
            for c in self.report_card:
                if (c.has_data()):
                    return True
            for c in self.xid_info:
                if (c.has_data()):
                    return True
            for leaf in self.state_transition_time.getYLeafs():
                if (leaf.yfilter != YFilter.not_set):
                    return True
            return (
                self.process_role.is_set or
                self.process_state.is_set or
                self.sw_install_in_progress.is_set or
                self.sync_flags.is_set or
                (self.failover_status is not None and self.failover_status.has_data()) or
                (self.issu_status is not None and self.issu_status.has_data()) or
                (self.nsr_status is not None and self.nsr_status.has_data()))

        def has_operation(self):
            for c in self.event_history:
                if (c.has_operation()):
                    return True
            for c in self.report_card:
                if (c.has_operation()):
                    return True
            for c in self.xid_info:
                if (c.has_operation()):
                    return True
            for leaf in self.state_transition_time.getYLeafs():
                if (leaf.is_set):
                    return True
            return (
                self.yfilter != YFilter.not_set or
                self.process_role.yfilter != YFilter.not_set or
                self.process_state.yfilter != YFilter.not_set or
                self.state_transition_time.yfilter != YFilter.not_set or
                self.sw_install_in_progress.yfilter != YFilter.not_set or
                self.sync_flags.yfilter != YFilter.not_set or
                (self.failover_status is not None and self.failover_status.has_operation()) or
                (self.issu_status is not None and self.issu_status.has_operation()) or
                (self.nsr_status is not None and self.nsr_status.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "proc-fsm" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.process_role.is_set or self.process_role.yfilter != YFilter.not_set):
                leaf_name_data.append(self.process_role.get_name_leafdata())
            if (self.process_state.is_set or self.process_state.yfilter != YFilter.not_set):
                leaf_name_data.append(self.process_state.get_name_leafdata())
            if (self.sw_install_in_progress.is_set or self.sw_install_in_progress.yfilter != YFilter.not_set):
                leaf_name_data.append(self.sw_install_in_progress.get_name_leafdata())
            if (self.sync_flags.is_set or self.sync_flags.yfilter != YFilter.not_set):
                leaf_name_data.append(self.sync_flags.get_name_leafdata())

            leaf_name_data.extend(self.state_transition_time.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "event-history"):
                for c in self.event_history:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.ProcFsm.EventHistory()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.event_history.append(c)
                return c

            if (child_yang_name == "failover-status"):
                if (self.failover_status is None):
                    self.failover_status = L2Vpn.ProcFsm.FailoverStatus()
                    self.failover_status.parent = self
                    self._children_name_map["failover_status"] = "failover-status"
                return self.failover_status

            if (child_yang_name == "issu-status"):
                if (self.issu_status is None):
                    self.issu_status = L2Vpn.ProcFsm.IssuStatus()
                    self.issu_status.parent = self
                    self._children_name_map["issu_status"] = "issu-status"
                return self.issu_status

            if (child_yang_name == "nsr-status"):
                if (self.nsr_status is None):
                    self.nsr_status = L2Vpn.ProcFsm.NsrStatus()
                    self.nsr_status.parent = self
                    self._children_name_map["nsr_status"] = "nsr-status"
                return self.nsr_status

            if (child_yang_name == "report-card"):
                for c in self.report_card:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.ProcFsm.ReportCard()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.report_card.append(c)
                return c

            if (child_yang_name == "xid-info"):
                for c in self.xid_info:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.ProcFsm.XidInfo()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.xid_info.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "event-history" or name == "failover-status" or name == "issu-status" or name == "nsr-status" or name == "report-card" or name == "xid-info" or name == "process-role" or name == "process-state" or name == "state-transition-time" or name == "sw-install-in-progress" or name == "sync-flags"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "process-role"):
                self.process_role = value
                self.process_role.value_namespace = name_space
                self.process_role.value_namespace_prefix = name_space_prefix
            if(value_path == "process-state"):
                self.process_state = value
                self.process_state.value_namespace = name_space
                self.process_state.value_namespace_prefix = name_space_prefix
            if(value_path == "state-transition-time"):
                self.state_transition_time.append(value)
            if(value_path == "sw-install-in-progress"):
                self.sw_install_in_progress = value
                self.sw_install_in_progress.value_namespace = name_space
                self.sw_install_in_progress.value_namespace_prefix = name_space_prefix
            if(value_path == "sync-flags"):
                self.sync_flags = value
                self.sync_flags.value_namespace = name_space
                self.sync_flags.value_namespace_prefix = name_space_prefix


    class MstpPorts(Entity):
        """
        L2VPN MSTP Port Table
        
        .. attribute:: mstp_port
        
        	MSTP Port information
        	**type**\: list of    :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpPorts.MstpPort>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.MstpPorts, self).__init__()

            self.yang_name = "mstp-ports"
            self.yang_parent_name = "l2vpn"

            self.mstp_port = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.MstpPorts, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.MstpPorts, self).__setattr__(name, value)


        class MstpPort(Entity):
            """
            MSTP Port information
            
            .. attribute:: interface  <key>
            
            	Interface
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: interface_name
            
            	Interface name
            	**type**\:  str
            
            .. attribute:: msti_entry
            
            	MSTI
            	**type**\: list of    :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpPorts.MstpPort.MstiEntry>`
            
            .. attribute:: mstp_interface_handle
            
            	Interface handle
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: protected
            
            	Protected
            	**type**\:  bool
            
            .. attribute:: reference_count
            
            	Reference Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.MstpPorts.MstpPort, self).__init__()

                self.yang_name = "mstp-port"
                self.yang_parent_name = "mstp-ports"

                self.interface = YLeaf(YType.str, "interface")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.mstp_interface_handle = YLeaf(YType.str, "mstp-interface-handle")

                self.protected = YLeaf(YType.boolean, "protected")

                self.reference_count = YLeaf(YType.uint32, "reference-count")

                self.msti_entry = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("interface",
                                "interface_name",
                                "mstp_interface_handle",
                                "protected",
                                "reference_count") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.MstpPorts.MstpPort, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.MstpPorts.MstpPort, self).__setattr__(name, value)


            class MstiEntry(Entity):
                """
                MSTI
                
                .. attribute:: ack_count
                
                	Ack count 
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bd_count
                
                	BD count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bd_entry
                
                	BD entries
                	**type**\: list of    :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                
                .. attribute:: cfg_ms_ti
                
                	 Configured MSTi
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flush_count
                
                	Flush count 
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Interface count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: msti_flags
                
                	Msti Flags
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: msti_state
                
                	Msti State
                	**type**\:   :py:class:`L2VpnMstiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMstiState>`
                
                .. attribute:: nack_count
                
                	Nack count 
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rcv_count
                
                	Receive count 
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.MstpPorts.MstpPort.MstiEntry, self).__init__()

                    self.yang_name = "msti-entry"
                    self.yang_parent_name = "mstp-port"

                    self.ack_count = YLeaf(YType.uint32, "ack-count")

                    self.bd_count = YLeaf(YType.uint32, "bd-count")

                    self.cfg_ms_ti = YLeaf(YType.uint32, "cfg-ms-ti")

                    self.flush_count = YLeaf(YType.uint32, "flush-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                    self.msti_flags = YLeaf(YType.uint32, "msti-flags")

                    self.msti_state = YLeaf(YType.enumeration, "msti-state")

                    self.nack_count = YLeaf(YType.uint32, "nack-count")

                    self.rcv_count = YLeaf(YType.uint32, "rcv-count")

                    self.bd_entry = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ack_count",
                                    "bd_count",
                                    "cfg_ms_ti",
                                    "flush_count",
                                    "interface_count",
                                    "msti_flags",
                                    "msti_state",
                                    "nack_count",
                                    "rcv_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.MstpPorts.MstpPort.MstiEntry, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.MstpPorts.MstpPort.MstiEntry, self).__setattr__(name, value)


                class BdEntry(Entity):
                    """
                    BD entries
                    
                    .. attribute:: bdid
                    
                    	BD ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bdif_count
                    
                    	BD Intf Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__init__()

                        self.yang_name = "bd-entry"
                        self.yang_parent_name = "msti-entry"

                        self.bdid = YLeaf(YType.uint32, "bdid")

                        self.bdif_count = YLeaf(YType.uint32, "bdif-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bdid",
                                        "bdif_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bdid.is_set or
                            self.bdif_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bdid.yfilter != YFilter.not_set or
                            self.bdif_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bd-entry" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bdid.is_set or self.bdid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bdid.get_name_leafdata())
                        if (self.bdif_count.is_set or self.bdif_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bdif_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bdid" or name == "bdif-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bdid"):
                            self.bdid = value
                            self.bdid.value_namespace = name_space
                            self.bdid.value_namespace_prefix = name_space_prefix
                        if(value_path == "bdif-count"):
                            self.bdif_count = value
                            self.bdif_count.value_namespace = name_space
                            self.bdif_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bd_entry:
                        if (c.has_data()):
                            return True
                    return (
                        self.ack_count.is_set or
                        self.bd_count.is_set or
                        self.cfg_ms_ti.is_set or
                        self.flush_count.is_set or
                        self.interface_count.is_set or
                        self.msti_flags.is_set or
                        self.msti_state.is_set or
                        self.nack_count.is_set or
                        self.rcv_count.is_set)

                def has_operation(self):
                    for c in self.bd_entry:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ack_count.yfilter != YFilter.not_set or
                        self.bd_count.yfilter != YFilter.not_set or
                        self.cfg_ms_ti.yfilter != YFilter.not_set or
                        self.flush_count.yfilter != YFilter.not_set or
                        self.interface_count.yfilter != YFilter.not_set or
                        self.msti_flags.yfilter != YFilter.not_set or
                        self.msti_state.yfilter != YFilter.not_set or
                        self.nack_count.yfilter != YFilter.not_set or
                        self.rcv_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "msti-entry" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ack_count.is_set or self.ack_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ack_count.get_name_leafdata())
                    if (self.bd_count.is_set or self.bd_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bd_count.get_name_leafdata())
                    if (self.cfg_ms_ti.is_set or self.cfg_ms_ti.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cfg_ms_ti.get_name_leafdata())
                    if (self.flush_count.is_set or self.flush_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flush_count.get_name_leafdata())
                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_count.get_name_leafdata())
                    if (self.msti_flags.is_set or self.msti_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.msti_flags.get_name_leafdata())
                    if (self.msti_state.is_set or self.msti_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.msti_state.get_name_leafdata())
                    if (self.nack_count.is_set or self.nack_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nack_count.get_name_leafdata())
                    if (self.rcv_count.is_set or self.rcv_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rcv_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bd-entry"):
                        for c in self.bd_entry:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.MstpPorts.MstpPort.MstiEntry.BdEntry()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bd_entry.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bd-entry" or name == "ack-count" or name == "bd-count" or name == "cfg-ms-ti" or name == "flush-count" or name == "interface-count" or name == "msti-flags" or name == "msti-state" or name == "nack-count" or name == "rcv-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ack-count"):
                        self.ack_count = value
                        self.ack_count.value_namespace = name_space
                        self.ack_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bd-count"):
                        self.bd_count = value
                        self.bd_count.value_namespace = name_space
                        self.bd_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "cfg-ms-ti"):
                        self.cfg_ms_ti = value
                        self.cfg_ms_ti.value_namespace = name_space
                        self.cfg_ms_ti.value_namespace_prefix = name_space_prefix
                    if(value_path == "flush-count"):
                        self.flush_count = value
                        self.flush_count.value_namespace = name_space
                        self.flush_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-count"):
                        self.interface_count = value
                        self.interface_count.value_namespace = name_space
                        self.interface_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "msti-flags"):
                        self.msti_flags = value
                        self.msti_flags.value_namespace = name_space
                        self.msti_flags.value_namespace_prefix = name_space_prefix
                    if(value_path == "msti-state"):
                        self.msti_state = value
                        self.msti_state.value_namespace = name_space
                        self.msti_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "nack-count"):
                        self.nack_count = value
                        self.nack_count.value_namespace = name_space
                        self.nack_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "rcv-count"):
                        self.rcv_count = value
                        self.rcv_count.value_namespace = name_space
                        self.rcv_count.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.msti_entry:
                    if (c.has_data()):
                        return True
                return (
                    self.interface.is_set or
                    self.interface_name.is_set or
                    self.mstp_interface_handle.is_set or
                    self.protected.is_set or
                    self.reference_count.is_set)

            def has_operation(self):
                for c in self.msti_entry:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.interface.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.mstp_interface_handle.yfilter != YFilter.not_set or
                    self.protected.yfilter != YFilter.not_set or
                    self.reference_count.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mstp-port" + "[interface='" + self.interface.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/mstp-ports/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface.get_name_leafdata())
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.mstp_interface_handle.is_set or self.mstp_interface_handle.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mstp_interface_handle.get_name_leafdata())
                if (self.protected.is_set or self.protected.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protected.get_name_leafdata())
                if (self.reference_count.is_set or self.reference_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reference_count.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "msti-entry"):
                    for c in self.msti_entry:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.MstpPorts.MstpPort.MstiEntry()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.msti_entry.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "msti-entry" or name == "interface" or name == "interface-name" or name == "mstp-interface-handle" or name == "protected" or name == "reference-count"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "interface"):
                    self.interface = value
                    self.interface.value_namespace = name_space
                    self.interface.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "mstp-interface-handle"):
                    self.mstp_interface_handle = value
                    self.mstp_interface_handle.value_namespace = name_space
                    self.mstp_interface_handle.value_namespace_prefix = name_space_prefix
                if(value_path == "protected"):
                    self.protected = value
                    self.protected.value_namespace = name_space
                    self.protected.value_namespace_prefix = name_space_prefix
                if(value_path == "reference-count"):
                    self.reference_count = value
                    self.reference_count.value_namespace = name_space
                    self.reference_count.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.mstp_port:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.mstp_port:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "mstp-ports" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "mstp-port"):
                for c in self.mstp_port:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.MstpPorts.MstpPort()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.mstp_port.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "mstp-port"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class GenericInterfaceListDetails(Entity):
        """
        L2VPN generic interface list Detail Table
        
        .. attribute:: generic_interface_list_detail
        
        	Generic Interface List detail information
        	**type**\: list of    :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.GenericInterfaceListDetails, self).__init__()

            self.yang_name = "generic-interface-list-details"
            self.yang_parent_name = "l2vpn"

            self.generic_interface_list_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.GenericInterfaceListDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.GenericInterfaceListDetails, self).__setattr__(name, value)


        class GenericInterfaceListDetail(Entity):
            """
            Generic Interface List detail information
            
            .. attribute:: interface_list_name  <key>
            
            	Generic Interface List Name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: interface
            
            	Interfaces
            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
            
            .. attribute:: is_provisioned
            
            	Is Provisioned
            	**type**\:  bool
            
            .. attribute:: items
            
            	Number of items
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: psedowire_ether_items
            
            	Number PW Ether Items
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pseudowire_ether_range
            
            	PW\-Ether ranges
            	**type**\: list of    :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
            
            .. attribute:: pseudowire_iw_items
            
            	Number PW IW Items
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pseudowire_iw_range
            
            	PW\-IW ranges
            	**type**\: list of    :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
            
            .. attribute:: summary
            
            	Summary information
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__init__()

                self.yang_name = "generic-interface-list-detail"
                self.yang_parent_name = "generic-interface-list-details"

                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                self.is_provisioned = YLeaf(YType.boolean, "is-provisioned")

                self.items = YLeaf(YType.uint32, "items")

                self.psedowire_ether_items = YLeaf(YType.uint32, "psedowire-ether-items")

                self.pseudowire_iw_items = YLeaf(YType.uint32, "pseudowire-iw-items")

                self.summary = L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.interface = YList(self)
                self.pseudowire_ether_range = YList(self)
                self.pseudowire_iw_range = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("interface_list_name",
                                "is_provisioned",
                                "items",
                                "psedowire_ether_items",
                                "pseudowire_iw_items") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__setattr__(name, value)


            class Summary(Entity):
                """
                Summary information
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_list_name_xr
                
                	Interface\-list name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: items
                
                	Number of items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "generic-interface-list-detail"

                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                    self.interface_list_name_xr = YLeaf(YType.str, "interface-list-name-xr")

                    self.items = YLeaf(YType.uint32, "items")

                    self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_list_id",
                                    "interface_list_name_xr",
                                    "items",
                                    "number_of_interfaces") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "summary"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                        self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                        self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_fib_downloaded",
                                        "not_supported_replications",
                                        "pending_replications") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.is_fib_downloaded.is_set or
                            self.not_supported_replications.is_set or
                            self.pending_replications.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_fib_downloaded.yfilter != YFilter.not_set or
                            self.not_supported_replications.yfilter != YFilter.not_set or
                            self.pending_replications.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                        if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                        if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pending_replications.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-fib-downloaded"):
                            self.is_fib_downloaded = value
                            self.is_fib_downloaded.value_namespace = name_space
                            self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-replications"):
                            self.not_supported_replications = value
                            self.not_supported_replications.value_namespace = name_space
                            self.not_supported_replications.value_namespace_prefix = name_space_prefix
                        if(value_path == "pending-replications"):
                            self.pending_replications = value
                            self.pending_replications.value_namespace = name_space
                            self.pending_replications.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.interface_list_id.is_set or
                        self.interface_list_name_xr.is_set or
                        self.items.is_set or
                        self.number_of_interfaces.is_set)

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_list_id.yfilter != YFilter.not_set or
                        self.interface_list_name_xr.yfilter != YFilter.not_set or
                        self.items.yfilter != YFilter.not_set or
                        self.number_of_interfaces.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                    if (self.interface_list_name_xr.is_set or self.interface_list_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_name_xr.get_name_leafdata())
                    if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.items.get_name_leafdata())
                    if (self.number_of_interfaces.is_set or self.number_of_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_of_interfaces.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "interface-list-id" or name == "interface-list-name-xr" or name == "items" or name == "number-of-interfaces"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-list-id"):
                        self.interface_list_id = value
                        self.interface_list_id.value_namespace = name_space
                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-list-name-xr"):
                        self.interface_list_name_xr = value
                        self.interface_list_name_xr.value_namespace = name_space
                        self.interface_list_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "items"):
                        self.items = value
                        self.items.value_namespace = name_space
                        self.items.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-of-interfaces"):
                        self.number_of_interfaces = value
                        self.number_of_interfaces.value_namespace = name_space
                        self.number_of_interfaces.value_namespace_prefix = name_space_prefix


            class Interface(Entity):
                """
                Interfaces
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\:  str
                
                .. attribute:: is_fib_downloaded
                
                	Is interface downloaded to FIB
                	**type**\:  bool
                
                .. attribute:: not_supported_replications
                
                	Number of replications failed because unsupported
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pending_replications
                
                	Number of pending replications
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__init__()

                    self.yang_name = "interface"
                    self.yang_parent_name = "generic-interface-list-detail"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                    self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                    self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "is_fib_downloaded",
                                    "not_supported_replications",
                                    "pending_replications") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.is_fib_downloaded.is_set or
                        self.not_supported_replications.is_set or
                        self.pending_replications.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.is_fib_downloaded.yfilter != YFilter.not_set or
                        self.not_supported_replications.yfilter != YFilter.not_set or
                        self.pending_replications.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                    if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                    if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pending_replications.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-fib-downloaded"):
                        self.is_fib_downloaded = value
                        self.is_fib_downloaded.value_namespace = name_space
                        self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-supported-replications"):
                        self.not_supported_replications = value
                        self.not_supported_replications.value_namespace = name_space
                        self.not_supported_replications.value_namespace_prefix = name_space_prefix
                    if(value_path == "pending-replications"):
                        self.pending_replications = value
                        self.pending_replications.value_namespace = name_space
                        self.pending_replications.value_namespace_prefix = name_space_prefix


            class PseudowireEtherRange(Entity):
                """
                PW\-Ether ranges
                
                .. attribute:: lower
                
                	lower range
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: upper
                
                	upper range
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__init__()

                    self.yang_name = "pseudowire-ether-range"
                    self.yang_parent_name = "generic-interface-list-detail"

                    self.lower = YLeaf(YType.uint16, "lower")

                    self.upper = YLeaf(YType.uint16, "upper")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("lower",
                                    "upper") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.lower.is_set or
                        self.upper.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.lower.yfilter != YFilter.not_set or
                        self.upper.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pseudowire-ether-range" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lower.get_name_leafdata())
                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.upper.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "lower" or name == "upper"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "lower"):
                        self.lower = value
                        self.lower.value_namespace = name_space
                        self.lower.value_namespace_prefix = name_space_prefix
                    if(value_path == "upper"):
                        self.upper = value
                        self.upper.value_namespace = name_space
                        self.upper.value_namespace_prefix = name_space_prefix


            class PseudowireIwRange(Entity):
                """
                PW\-IW ranges
                
                .. attribute:: lower
                
                	lower range
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: upper
                
                	upper range
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__init__()

                    self.yang_name = "pseudowire-iw-range"
                    self.yang_parent_name = "generic-interface-list-detail"

                    self.lower = YLeaf(YType.uint16, "lower")

                    self.upper = YLeaf(YType.uint16, "upper")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("lower",
                                    "upper") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.lower.is_set or
                        self.upper.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.lower.yfilter != YFilter.not_set or
                        self.upper.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pseudowire-iw-range" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lower.get_name_leafdata())
                    if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.upper.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "lower" or name == "upper"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "lower"):
                        self.lower = value
                        self.lower.value_namespace = name_space
                        self.lower.value_namespace_prefix = name_space_prefix
                    if(value_path == "upper"):
                        self.upper = value
                        self.upper.value_namespace = name_space
                        self.upper.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface:
                    if (c.has_data()):
                        return True
                for c in self.pseudowire_ether_range:
                    if (c.has_data()):
                        return True
                for c in self.pseudowire_iw_range:
                    if (c.has_data()):
                        return True
                return (
                    self.interface_list_name.is_set or
                    self.is_provisioned.is_set or
                    self.items.is_set or
                    self.psedowire_ether_items.is_set or
                    self.pseudowire_iw_items.is_set or
                    (self.summary is not None and self.summary.has_data()))

            def has_operation(self):
                for c in self.interface:
                    if (c.has_operation()):
                        return True
                for c in self.pseudowire_ether_range:
                    if (c.has_operation()):
                        return True
                for c in self.pseudowire_iw_range:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.interface_list_name.yfilter != YFilter.not_set or
                    self.is_provisioned.yfilter != YFilter.not_set or
                    self.items.yfilter != YFilter.not_set or
                    self.psedowire_ether_items.yfilter != YFilter.not_set or
                    self.pseudowire_iw_items.yfilter != YFilter.not_set or
                    (self.summary is not None and self.summary.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "generic-interface-list-detail" + "[interface-list-name='" + self.interface_list_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/generic-interface-list-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                if (self.is_provisioned.is_set or self.is_provisioned.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_provisioned.get_name_leafdata())
                if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.items.get_name_leafdata())
                if (self.psedowire_ether_items.is_set or self.psedowire_ether_items.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.psedowire_ether_items.get_name_leafdata())
                if (self.pseudowire_iw_items.is_set or self.pseudowire_iw_items.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pseudowire_iw_items.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface"):
                    for c in self.interface:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface.append(c)
                    return c

                if (child_yang_name == "pseudowire-ether-range"):
                    for c in self.pseudowire_ether_range:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.pseudowire_ether_range.append(c)
                    return c

                if (child_yang_name == "pseudowire-iw-range"):
                    for c in self.pseudowire_iw_range:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.pseudowire_iw_range.append(c)
                    return c

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface" or name == "pseudowire-ether-range" or name == "pseudowire-iw-range" or name == "summary" or name == "interface-list-name" or name == "is-provisioned" or name == "items" or name == "psedowire-ether-items" or name == "pseudowire-iw-items"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "interface-list-name"):
                    self.interface_list_name = value
                    self.interface_list_name.value_namespace = name_space
                    self.interface_list_name.value_namespace_prefix = name_space_prefix
                if(value_path == "is-provisioned"):
                    self.is_provisioned = value
                    self.is_provisioned.value_namespace = name_space
                    self.is_provisioned.value_namespace_prefix = name_space_prefix
                if(value_path == "items"):
                    self.items = value
                    self.items.value_namespace = name_space
                    self.items.value_namespace_prefix = name_space_prefix
                if(value_path == "psedowire-ether-items"):
                    self.psedowire_ether_items = value
                    self.psedowire_ether_items.value_namespace = name_space
                    self.psedowire_ether_items.value_namespace_prefix = name_space_prefix
                if(value_path == "pseudowire-iw-items"):
                    self.pseudowire_iw_items = value
                    self.pseudowire_iw_items.value_namespace = name_space
                    self.pseudowire_iw_items.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.generic_interface_list_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.generic_interface_list_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "generic-interface-list-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "generic-interface-list-detail"):
                for c in self.generic_interface_list_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.generic_interface_list_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "generic-interface-list-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class L2VpnResourceState(Entity):
        """
        L2VPN resource state information
        
        .. attribute:: resource_out_of_memory_state
        
        	L2VPN Out of memory state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.L2VpnResourceState, self).__init__()

            self.yang_name = "l2vpn-resource-state"
            self.yang_parent_name = "l2vpn"

            self.resource_out_of_memory_state = YLeaf(YType.uint32, "resource-out-of-memory-state")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("resource_out_of_memory_state") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.L2VpnResourceState, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.L2VpnResourceState, self).__setattr__(name, value)

        def has_data(self):
            return self.resource_out_of_memory_state.is_set

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.resource_out_of_memory_state.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "l2vpn-resource-state" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.resource_out_of_memory_state.is_set or self.resource_out_of_memory_state.yfilter != YFilter.not_set):
                leaf_name_data.append(self.resource_out_of_memory_state.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "resource-out-of-memory-state"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "resource-out-of-memory-state"):
                self.resource_out_of_memory_state = value
                self.resource_out_of_memory_state.value_namespace = name_space
                self.resource_out_of_memory_state.value_namespace_prefix = name_space_prefix


    class BridgeDomains(Entity):
        """
        VPLS Bridge Domain Information
        
        .. attribute:: bridge_domain
        
        	VPLS Bridge Domain Information
        	**type**\: list of    :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.BridgeDomains, self).__init__()

            self.yang_name = "bridge-domains"
            self.yang_parent_name = "l2vpn"

            self.bridge_domain = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.BridgeDomains, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.BridgeDomains, self).__setattr__(name, value)


        class BridgeDomain(Entity):
            """
            VPLS Bridge Domain Information
            
            .. attribute:: bridge_access_pws
            
            	VPLS Bridge Domain Access Pseudowire Table
            	**type**\:   :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws>`
            
            .. attribute:: bridge_access_vfi_table
            
            	Bridge Domain Access VFI Table
            	**type**\:   :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
            
            .. attribute:: bridge_acs
            
            	VPLS Bridge Domain Attachment Circuit Table
            	**type**\:   :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs>`
            
            .. attribute:: bridge_core_vfi_table
            
            	Bridge Domain Core VFI Table
            	**type**\:   :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
            
            .. attribute:: bridge_domain_group_name
            
            	Bridge Domain Group Name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: bridge_domain_info
            
            	VPLS Bridge Domain Information
            	**type**\:   :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
            
            .. attribute:: bridge_domain_name
            
            	Bridge Domain Name
            	**type**\:  str
            
            	**length:** 1..27
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.BridgeDomains.BridgeDomain, self).__init__()

                self.yang_name = "bridge-domain"
                self.yang_parent_name = "bridge-domains"

                self.bridge_domain_group_name = YLeaf(YType.str, "bridge-domain-group-name")

                self.bridge_domain_name = YLeaf(YType.str, "bridge-domain-name")

                self.bridge_access_pws = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws()
                self.bridge_access_pws.parent = self
                self._children_name_map["bridge_access_pws"] = "bridge-access-pws"
                self._children_yang_names.add("bridge-access-pws")

                self.bridge_access_vfi_table = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                self.bridge_access_vfi_table.parent = self
                self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"
                self._children_yang_names.add("bridge-access-vfi-table")

                self.bridge_acs = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs()
                self.bridge_acs.parent = self
                self._children_name_map["bridge_acs"] = "bridge-acs"
                self._children_yang_names.add("bridge-acs")

                self.bridge_core_vfi_table = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                self.bridge_core_vfi_table.parent = self
                self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"
                self._children_yang_names.add("bridge-core-vfi-table")

                self.bridge_domain_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                self.bridge_domain_info.parent = self
                self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                self._children_yang_names.add("bridge-domain-info")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("bridge_domain_group_name",
                                "bridge_domain_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.BridgeDomains.BridgeDomain, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.BridgeDomains.BridgeDomain, self).__setattr__(name, value)


            class BridgeAccessVfiTable(Entity):
                """
                Bridge Domain Access VFI Table
                
                .. attribute:: bridge_pws
                
                	Bridge Domain Access/Core Pseudowire Table
                	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable, self).__init__()

                    self.yang_name = "bridge-access-vfi-table"
                    self.yang_parent_name = "bridge-domain"

                    self.bridge_pws = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                    self.bridge_pws.parent = self
                    self._children_name_map["bridge_pws"] = "bridge-pws"
                    self._children_yang_names.add("bridge-pws")


                class BridgePws(Entity):
                    """
                    Bridge Domain Access/Core Pseudowire Table
                    
                    .. attribute:: bridge_pw
                    
                    	VPLS Bridge Domain Pseudowire
                    	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__init__()

                        self.yang_name = "bridge-pws"
                        self.yang_parent_name = "bridge-access-vfi-table"

                        self.bridge_pw = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__setattr__(name, value)


                    class BridgePw(Entity):
                        """
                        VPLS Bridge Domain Pseudowire
                        
                        .. attribute:: is_access
                        
                        	Is Access PW
                        	**type**\:  bool
                        
                        .. attribute:: neighbor
                        
                        	Neighbor IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                        
                        .. attribute:: pseudowire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_type
                        
                        	PW Type
                        	**type**\:   :py:class:`L2Vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnpw>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                        
                        .. attribute:: ve_id_vpls_id_0_3
                        
                        	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vpls_id_4_7
                        
                        	Zero or Last 4 bytes of VPLS\-ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__init__()

                            self.yang_name = "bridge-pw"
                            self.yang_parent_name = "bridge-pws"

                            self.is_access = YLeaf(YType.boolean, "is-access")

                            self.neighbor = YLeaf(YType.str, "neighbor")

                            self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                            self.pw_type = YLeaf(YType.enumeration, "pw-type")

                            self.ve_id_vpls_id_0_3 = YLeaf(YType.uint32, "ve-id-vpls-id-0-3")

                            self.vpls_id_4_7 = YLeaf(YType.uint32, "vpls-id-4-7")

                            self.pseudowire = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                            self.pseudowire.parent = self
                            self._children_name_map["pseudowire"] = "pseudowire"
                            self._children_yang_names.add("pseudowire")

                            self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                            self._children_yang_names.add("security-parameters")

                            self.static_mac = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("is_access",
                                            "neighbor",
                                            "pseudowire_id",
                                            "pw_type",
                                            "ve_id_vpls_id_0_3",
                                            "vpls_id_4_7") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)


                        class Pseudowire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                self.yang_name = "pseudowire"
                                self.yang_parent_name = "bridge-pw"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                self.backup_active = YLeaf(YType.boolean, "backup-active")

                                self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                self.disable_never = YLeaf(YType.boolean, "disable-never")

                                self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                self.local_source_address = YLeaf(YType.str, "local-source-address")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                self.required_bw = YLeaf(YType.uint32, "required-bw")

                                self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                self.time_created = YLeaf(YType.str, "time-created")

                                self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.encapsulation_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                self._children_yang_names.add("encapsulation-info")

                                self.local_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                                self._children_yang_names.add("local-interface")

                                self.local_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                                self._children_yang_names.add("local-signalling")

                                self.p2mp_pw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._children_yang_names.add("p2mp-pw")

                                self.peer_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                                self._children_yang_names.add("peer-id")

                                self.preferred_path = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                                self._children_yang_names.add("preferred-path")

                                self.remote_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                                self._children_yang_names.add("remote-interface")

                                self.remote_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                self._children_yang_names.add("remote-signalling")

                                self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_remote_down",
                                                "admited_bw",
                                                "auto_discovery",
                                                "backup_active",
                                                "backup_force_active",
                                                "backup_pw",
                                                "bitrate_mismatched",
                                                "bridge_pw_type_mismatch",
                                                "cas_mismatched",
                                                "diff_ts_mismatched",
                                                "disable_delay",
                                                "disable_never",
                                                "evpn_src_acid",
                                                "fe_ctype",
                                                "forward_class",
                                                "freq_mismatched",
                                                "illegal_control_word",
                                                "imposed_vlan_id",
                                                "interworking",
                                                "ipv6_local_source_address",
                                                "is_evpnvpws_type",
                                                "is_flow_label_static",
                                                "is_multi_segment_pseudowire",
                                                "is_partially_programmed",
                                                "is_pwr_type",
                                                "is_vfi",
                                                "last_time_status_changed",
                                                "last_time_status_down",
                                                "ldp_label_advertise_failed",
                                                "load_balance",
                                                "local_control_word",
                                                "local_label_failed",
                                                "local_pseudo_wire_type",
                                                "local_source_address",
                                                "mac_limit_oper_down",
                                                "mtu_mismatched",
                                                "not_supported_qinq",
                                                "num_ma_cwithdraw_msg_received",
                                                "number_ma_cwithdraw_message_sent",
                                                "out_of_memory_state",
                                                "payload_bytes_mismatched",
                                                "payload_type_mismatched",
                                                "preferred_path_disable_fallback",
                                                "primary_peer_id",
                                                "primary_pseudo_wire_id",
                                                "primary_pw",
                                                "protocol",
                                                "pseudo_wire_id",
                                                "pseudo_wire_state",
                                                "pseudo_wire_type_mismatched",
                                                "pw_class_name",
                                                "pw_flow_label_code17_disabled",
                                                "pw_flow_label_type",
                                                "pw_flow_label_type_cfg",
                                                "pw_redundancy_initial_delay",
                                                "pw_redundancy_one_way",
                                                "pw_status_use",
                                                "pwlsd_rewrite_failed",
                                                "remote_control_word",
                                                "remote_label_failed",
                                                "remote_pseudo_wire_type",
                                                "required_bw",
                                                "resync_enabled",
                                                "resync_threshold",
                                                "rtp_mismatched",
                                                "sequencing_type",
                                                "shutdown",
                                                "sig_pkts_mismatched",
                                                "ssrc_mismatched",
                                                "state",
                                                "table_policy_name",
                                                "tag_rewrite",
                                                "time_created",
                                                "time_elapsed_creation",
                                                "time_elapsed_status_changed",
                                                "time_elapsed_status_down",
                                                "transport_lsp_down",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudowire"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                    self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                    self.type = YLeaf(YType.enumeration, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "ipv4_peer_id",
                                                    "ipv6_peer_id",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.ipv4_peer_id.is_set or
                                        self.ipv6_peer_id.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.ipv4_peer_id.yfilter != YFilter.not_set or
                                        self.ipv6_peer_id.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "peer-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                    if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-peer-id"):
                                        self.ipv4_peer_id = value
                                        self.ipv4_peer_id.value_namespace = name_space
                                        self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-peer-id"):
                                        self.ipv6_peer_id = value
                                        self.ipv6_peer_id.value_namespace = name_space
                                        self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudowire"

                                    self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                    self.atom = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                    self.l2tpv3 = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._children_yang_names.add("l2tpv3")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                        self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                        self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                        self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                        self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                        self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                        self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                        self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                        self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                        self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                        self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                        self.local_veid = YLeaf(YType.uint32, "local-veid")

                                        self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                        self.rem_saii = YLeaf(YType.str, "rem-saii")

                                        self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                        self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                        self.rem_taii = YLeaf(YType.str, "rem-taii")

                                        self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                        self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                        self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                        self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                        self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                        self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                        self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                        self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                        self.saii = YLeaf(YType.str, "saii")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.taii = YLeaf(YType.str, "taii")

                                        self.local_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                        self._children_yang_names.add("local-agi")

                                        self.multi_segment_pseudowire_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._children_yang_names.add("multi-segment-pseudowire-stats")

                                        self.remote_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                        self._children_yang_names.add("remote-agi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_pseudowire_headend",
                                                        "is_sai_itype2",
                                                        "is_tai_itype2",
                                                        "ldp_label_advertisment_failed",
                                                        "local_c_ctype",
                                                        "local_ceid",
                                                        "local_cv_type",
                                                        "local_group_id",
                                                        "local_label",
                                                        "local_ldp_id",
                                                        "local_saii_gbl_id",
                                                        "local_saiiac_id",
                                                        "local_taii_gbl_id",
                                                        "local_taiiac_id",
                                                        "local_veid",
                                                        "lsd_rewrite_failed",
                                                        "rem_saii",
                                                        "rem_saii_gbl_id",
                                                        "rem_saiiac_id",
                                                        "rem_taii",
                                                        "rem_taii_gbl_id",
                                                        "rem_taiiac_id",
                                                        "remote_c_ctype",
                                                        "remote_ceid",
                                                        "remote_cv_type",
                                                        "remote_group_id",
                                                        "remote_label",
                                                        "remote_ldp_id",
                                                        "remote_source_address",
                                                        "remote_veid",
                                                        "saii",
                                                        "source_address",
                                                        "taii") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"

                                            self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                            self.received_packets = YLeaf(YType.uint64, "received-packets")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("received_bytes",
                                                            "received_packets") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.received_bytes.is_set or
                                                self.received_packets.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.received_bytes.yfilter != YFilter.not_set or
                                                self.received_packets.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                            if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_packets.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "received-bytes" or name == "received-packets"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "received-bytes"):
                                                self.received_bytes = value
                                                self.received_bytes.value_namespace = name_space
                                                self.received_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "received-packets"):
                                                self.received_packets = value
                                                self.received_packets.value_namespace = name_space
                                                self.received_packets.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_pseudowire_headend.is_set or
                                            self.is_sai_itype2.is_set or
                                            self.is_tai_itype2.is_set or
                                            self.ldp_label_advertisment_failed.is_set or
                                            self.local_c_ctype.is_set or
                                            self.local_ceid.is_set or
                                            self.local_cv_type.is_set or
                                            self.local_group_id.is_set or
                                            self.local_label.is_set or
                                            self.local_ldp_id.is_set or
                                            self.local_saii_gbl_id.is_set or
                                            self.local_saiiac_id.is_set or
                                            self.local_taii_gbl_id.is_set or
                                            self.local_taiiac_id.is_set or
                                            self.local_veid.is_set or
                                            self.lsd_rewrite_failed.is_set or
                                            self.rem_saii.is_set or
                                            self.rem_saii_gbl_id.is_set or
                                            self.rem_saiiac_id.is_set or
                                            self.rem_taii.is_set or
                                            self.rem_taii_gbl_id.is_set or
                                            self.rem_taiiac_id.is_set or
                                            self.remote_c_ctype.is_set or
                                            self.remote_ceid.is_set or
                                            self.remote_cv_type.is_set or
                                            self.remote_group_id.is_set or
                                            self.remote_label.is_set or
                                            self.remote_ldp_id.is_set or
                                            self.remote_source_address.is_set or
                                            self.remote_veid.is_set or
                                            self.saii.is_set or
                                            self.source_address.is_set or
                                            self.taii.is_set or
                                            (self.local_agi is not None and self.local_agi.has_data()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                            (self.remote_agi is not None and self.remote_agi.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                            self.is_sai_itype2.yfilter != YFilter.not_set or
                                            self.is_tai_itype2.yfilter != YFilter.not_set or
                                            self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                            self.local_c_ctype.yfilter != YFilter.not_set or
                                            self.local_ceid.yfilter != YFilter.not_set or
                                            self.local_cv_type.yfilter != YFilter.not_set or
                                            self.local_group_id.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_ldp_id.yfilter != YFilter.not_set or
                                            self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_saiiac_id.yfilter != YFilter.not_set or
                                            self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_taiiac_id.yfilter != YFilter.not_set or
                                            self.local_veid.yfilter != YFilter.not_set or
                                            self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.rem_saii.yfilter != YFilter.not_set or
                                            self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_saiiac_id.yfilter != YFilter.not_set or
                                            self.rem_taii.yfilter != YFilter.not_set or
                                            self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_taiiac_id.yfilter != YFilter.not_set or
                                            self.remote_c_ctype.yfilter != YFilter.not_set or
                                            self.remote_ceid.yfilter != YFilter.not_set or
                                            self.remote_cv_type.yfilter != YFilter.not_set or
                                            self.remote_group_id.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_ldp_id.yfilter != YFilter.not_set or
                                            self.remote_source_address.yfilter != YFilter.not_set or
                                            self.remote_veid.yfilter != YFilter.not_set or
                                            self.saii.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.taii.yfilter != YFilter.not_set or
                                            (self.local_agi is not None and self.local_agi.has_operation()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                            (self.remote_agi is not None and self.remote_agi.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                        if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                        if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                        if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                        if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                        if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                        if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                        if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                        if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                        if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                        if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                        if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                        if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_veid.get_name_leafdata())
                                        if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                        if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                        if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                        if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                        if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                        if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                        if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                        if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                        if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                        if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                        if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                        if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                        if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                        if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saii.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.taii.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local-agi"):
                                            if (self.local_agi is None):
                                                self.local_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                            return self.local_agi

                                        if (child_yang_name == "multi-segment-pseudowire-stats"):
                                            if (self.multi_segment_pseudowire_stats is None):
                                                self.multi_segment_pseudowire_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            return self.multi_segment_pseudowire_stats

                                        if (child_yang_name == "remote-agi"):
                                            if (self.remote_agi is None):
                                                self.remote_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                            return self.remote_agi

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-pseudowire-headend"):
                                            self.is_pseudowire_headend = value
                                            self.is_pseudowire_headend.value_namespace = name_space
                                            self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-sai-itype2"):
                                            self.is_sai_itype2 = value
                                            self.is_sai_itype2.value_namespace = name_space
                                            self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-tai-itype2"):
                                            self.is_tai_itype2 = value
                                            self.is_tai_itype2.value_namespace = name_space
                                            self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertisment-failed"):
                                            self.ldp_label_advertisment_failed = value
                                            self.ldp_label_advertisment_failed.value_namespace = name_space
                                            self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-c-ctype"):
                                            self.local_c_ctype = value
                                            self.local_c_ctype.value_namespace = name_space
                                            self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ceid"):
                                            self.local_ceid = value
                                            self.local_ceid.value_namespace = name_space
                                            self.local_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cv-type"):
                                            self.local_cv_type = value
                                            self.local_cv_type.value_namespace = name_space
                                            self.local_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-group-id"):
                                            self.local_group_id = value
                                            self.local_group_id.value_namespace = name_space
                                            self.local_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ldp-id"):
                                            self.local_ldp_id = value
                                            self.local_ldp_id.value_namespace = name_space
                                            self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saii-gbl-id"):
                                            self.local_saii_gbl_id = value
                                            self.local_saii_gbl_id.value_namespace = name_space
                                            self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saiiac-id"):
                                            self.local_saiiac_id = value
                                            self.local_saiiac_id.value_namespace = name_space
                                            self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taii-gbl-id"):
                                            self.local_taii_gbl_id = value
                                            self.local_taii_gbl_id.value_namespace = name_space
                                            self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taiiac-id"):
                                            self.local_taiiac_id = value
                                            self.local_taiiac_id.value_namespace = name_space
                                            self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-veid"):
                                            self.local_veid = value
                                            self.local_veid.value_namespace = name_space
                                            self.local_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsd-rewrite-failed"):
                                            self.lsd_rewrite_failed = value
                                            self.lsd_rewrite_failed.value_namespace = name_space
                                            self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii"):
                                            self.rem_saii = value
                                            self.rem_saii.value_namespace = name_space
                                            self.rem_saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii-gbl-id"):
                                            self.rem_saii_gbl_id = value
                                            self.rem_saii_gbl_id.value_namespace = name_space
                                            self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saiiac-id"):
                                            self.rem_saiiac_id = value
                                            self.rem_saiiac_id.value_namespace = name_space
                                            self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii"):
                                            self.rem_taii = value
                                            self.rem_taii.value_namespace = name_space
                                            self.rem_taii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii-gbl-id"):
                                            self.rem_taii_gbl_id = value
                                            self.rem_taii_gbl_id.value_namespace = name_space
                                            self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taiiac-id"):
                                            self.rem_taiiac_id = value
                                            self.rem_taiiac_id.value_namespace = name_space
                                            self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-c-ctype"):
                                            self.remote_c_ctype = value
                                            self.remote_c_ctype.value_namespace = name_space
                                            self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ceid"):
                                            self.remote_ceid = value
                                            self.remote_ceid.value_namespace = name_space
                                            self.remote_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cv-type"):
                                            self.remote_cv_type = value
                                            self.remote_cv_type.value_namespace = name_space
                                            self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-group-id"):
                                            self.remote_group_id = value
                                            self.remote_group_id.value_namespace = name_space
                                            self.remote_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ldp-id"):
                                            self.remote_ldp_id = value
                                            self.remote_ldp_id.value_namespace = name_space
                                            self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-source-address"):
                                            self.remote_source_address = value
                                            self.remote_source_address.value_namespace = name_space
                                            self.remote_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-veid"):
                                            self.remote_veid = value
                                            self.remote_veid.value_namespace = name_space
                                            self.remote_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saii"):
                                            self.saii = value
                                            self.saii.value_namespace = name_space
                                            self.saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "taii"):
                                            self.taii = value
                                            self.taii.value_namespace = name_space
                                            self.taii.value_namespace_prefix = name_space_prefix


                                class L2Tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                        self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                        self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                        self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                        self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                        self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                        self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                        self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                        self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                        self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                        self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                        self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                        self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                        self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                        self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                        self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                        self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                        self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                        self.tos = YLeaf(YType.uint8, "tos")

                                        self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dont_fragment_bit",
                                                        "ipv4_source_address",
                                                        "ipv6_source_address",
                                                        "l2tp_class_name",
                                                        "local_cookie_high_value",
                                                        "local_cookie_low_value",
                                                        "local_cookie_size",
                                                        "local_secondary_cookie_high_value",
                                                        "local_secondary_cookie_low_value",
                                                        "local_secondary_cookie_size",
                                                        "local_session_id",
                                                        "path_mtu_enabled",
                                                        "path_mtu_max_value",
                                                        "remote_circuit_status_up",
                                                        "remote_cookie_high_value",
                                                        "remote_cookie_low_value",
                                                        "remote_cookie_size",
                                                        "remote_session_id",
                                                        "tos",
                                                        "tos_mode",
                                                        "ttl",
                                                        "tunnel_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dont_fragment_bit.is_set or
                                            self.ipv4_source_address.is_set or
                                            self.ipv6_source_address.is_set or
                                            self.l2tp_class_name.is_set or
                                            self.local_cookie_high_value.is_set or
                                            self.local_cookie_low_value.is_set or
                                            self.local_cookie_size.is_set or
                                            self.local_secondary_cookie_high_value.is_set or
                                            self.local_secondary_cookie_low_value.is_set or
                                            self.local_secondary_cookie_size.is_set or
                                            self.local_session_id.is_set or
                                            self.path_mtu_enabled.is_set or
                                            self.path_mtu_max_value.is_set or
                                            self.remote_circuit_status_up.is_set or
                                            self.remote_cookie_high_value.is_set or
                                            self.remote_cookie_low_value.is_set or
                                            self.remote_cookie_size.is_set or
                                            self.remote_session_id.is_set or
                                            self.tos.is_set or
                                            self.tos_mode.is_set or
                                            self.ttl.is_set or
                                            self.tunnel_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dont_fragment_bit.yfilter != YFilter.not_set or
                                            self.ipv4_source_address.yfilter != YFilter.not_set or
                                            self.ipv6_source_address.yfilter != YFilter.not_set or
                                            self.l2tp_class_name.yfilter != YFilter.not_set or
                                            self.local_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_cookie_size.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                            self.local_session_id.yfilter != YFilter.not_set or
                                            self.path_mtu_enabled.yfilter != YFilter.not_set or
                                            self.path_mtu_max_value.yfilter != YFilter.not_set or
                                            self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                            self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_size.yfilter != YFilter.not_set or
                                            self.remote_session_id.yfilter != YFilter.not_set or
                                            self.tos.yfilter != YFilter.not_set or
                                            self.tos_mode.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.tunnel_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv3" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                        if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                        if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                        if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                        if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                        if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                        if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                        if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                        if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                        if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                        if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                        if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                        if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                        if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                        if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                        if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                        if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos.get_name_leafdata())
                                        if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dont-fragment-bit"):
                                            self.dont_fragment_bit = value
                                            self.dont_fragment_bit.value_namespace = name_space
                                            self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-source-address"):
                                            self.ipv4_source_address = value
                                            self.ipv4_source_address.value_namespace = name_space
                                            self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-source-address"):
                                            self.ipv6_source_address = value
                                            self.ipv6_source_address.value_namespace = name_space
                                            self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l2tp-class-name"):
                                            self.l2tp_class_name = value
                                            self.l2tp_class_name.value_namespace = name_space
                                            self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-high-value"):
                                            self.local_cookie_high_value = value
                                            self.local_cookie_high_value.value_namespace = name_space
                                            self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-low-value"):
                                            self.local_cookie_low_value = value
                                            self.local_cookie_low_value.value_namespace = name_space
                                            self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-size"):
                                            self.local_cookie_size = value
                                            self.local_cookie_size.value_namespace = name_space
                                            self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-high-value"):
                                            self.local_secondary_cookie_high_value = value
                                            self.local_secondary_cookie_high_value.value_namespace = name_space
                                            self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-low-value"):
                                            self.local_secondary_cookie_low_value = value
                                            self.local_secondary_cookie_low_value.value_namespace = name_space
                                            self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-size"):
                                            self.local_secondary_cookie_size = value
                                            self.local_secondary_cookie_size.value_namespace = name_space
                                            self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-session-id"):
                                            self.local_session_id = value
                                            self.local_session_id.value_namespace = name_space
                                            self.local_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-enabled"):
                                            self.path_mtu_enabled = value
                                            self.path_mtu_enabled.value_namespace = name_space
                                            self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-max-value"):
                                            self.path_mtu_max_value = value
                                            self.path_mtu_max_value.value_namespace = name_space
                                            self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-circuit-status-up"):
                                            self.remote_circuit_status_up = value
                                            self.remote_circuit_status_up.value_namespace = name_space
                                            self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-high-value"):
                                            self.remote_cookie_high_value = value
                                            self.remote_cookie_high_value.value_namespace = name_space
                                            self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-low-value"):
                                            self.remote_cookie_low_value = value
                                            self.remote_cookie_low_value.value_namespace = name_space
                                            self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-size"):
                                            self.remote_cookie_size = value
                                            self.remote_cookie_size.value_namespace = name_space
                                            self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-session-id"):
                                            self.remote_session_id = value
                                            self.remote_session_id.value_namespace = name_space
                                            self.remote_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos"):
                                            self.tos = value
                                            self.tos.value_namespace = name_space
                                            self.tos.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-mode"):
                                            self.tos_mode = value
                                            self.tos_mode.value_namespace = name_space
                                            self.tos_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tunnel-state"):
                                            self.tunnel_state = value
                                            self.tunnel_state.value_namespace = name_space
                                            self.tunnel_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.encapsulation.is_set or
                                        (self.atom is not None and self.atom.has_data()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "encapsulation-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    if (child_yang_name == "l2tpv3"):
                                        if (self.l2tpv3 is None):
                                            self.l2tpv3 = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                        return self.l2tpv3

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation"):
                                        self.encapsulation = value
                                        self.encapsulation.value_namespace = name_space
                                        self.encapsulation.value_namespace_prefix = name_space_prefix


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudowire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudowire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudowire"

                                    self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                    self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                    self.option = YLeaf(YType.enumeration, "option")

                                    self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                    self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ip_tunnel_interface_number",
                                                    "next_hop_ip",
                                                    "option",
                                                    "te_tunnel_interface_number",
                                                    "tp_tunnel_interface_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ip_tunnel_interface_number.is_set or
                                        self.next_hop_ip.is_set or
                                        self.option.is_set or
                                        self.te_tunnel_interface_number.is_set or
                                        self.tp_tunnel_interface_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set or
                                        self.option.yfilter != YFilter.not_set or
                                        self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "preferred-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                    if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.option.get_name_leafdata())
                                    if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                    if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ip-tunnel-interface-number"):
                                        self.ip_tunnel_interface_number = value
                                        self.ip_tunnel_interface_number.value_namespace = name_space
                                        self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                    if(value_path == "option"):
                                        self.option = value
                                        self.option.value_namespace = name_space
                                        self.option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-tunnel-interface-number"):
                                        self.te_tunnel_interface_number = value
                                        self.te_tunnel_interface_number.value_namespace = name_space
                                        self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tp-tunnel-interface-number"):
                                        self.tp_tunnel_interface_number = value
                                        self.tp_tunnel_interface_number.value_namespace = name_space
                                        self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudowire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudowire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudowire"

                                    self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class P2MpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudowire"

                                    self.local_available = YLeaf(YType.boolean, "local-available")

                                    self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                    self.local_flags = YLeaf(YType.uint8, "local-flags")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                    self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                    self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                    self.remote_available = YLeaf(YType.boolean, "remote-available")

                                    self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                    self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                    self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                    self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_available",
                                                    "local_extended_tunnel_id",
                                                    "local_flags",
                                                    "local_label",
                                                    "local_p2mp_id",
                                                    "local_ptree_type",
                                                    "local_tunnel_id",
                                                    "remote_available",
                                                    "remote_extended_tunnel_id",
                                                    "remote_flags",
                                                    "remote_label",
                                                    "remote_p2mp_id",
                                                    "remote_ptree_type",
                                                    "remote_tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_available.is_set or
                                        self.local_extended_tunnel_id.is_set or
                                        self.local_flags.is_set or
                                        self.local_label.is_set or
                                        self.local_p2mp_id.is_set or
                                        self.local_ptree_type.is_set or
                                        self.local_tunnel_id.is_set or
                                        self.remote_available.is_set or
                                        self.remote_extended_tunnel_id.is_set or
                                        self.remote_flags.is_set or
                                        self.remote_label.is_set or
                                        self.remote_p2mp_id.is_set or
                                        self.remote_ptree_type.is_set or
                                        self.remote_tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_available.yfilter != YFilter.not_set or
                                        self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.local_flags.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_p2mp_id.yfilter != YFilter.not_set or
                                        self.local_ptree_type.yfilter != YFilter.not_set or
                                        self.local_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_available.yfilter != YFilter.not_set or
                                        self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_flags.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_p2mp_id.yfilter != YFilter.not_set or
                                        self.remote_ptree_type.yfilter != YFilter.not_set or
                                        self.remote_tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_available.get_name_leafdata())
                                    if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                    if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_flags.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                    if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                    if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                    if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_available.get_name_leafdata())
                                    if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                    if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                    if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                    if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-available"):
                                        self.local_available = value
                                        self.local_available.value_namespace = name_space
                                        self.local_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-extended-tunnel-id"):
                                        self.local_extended_tunnel_id = value
                                        self.local_extended_tunnel_id.value_namespace = name_space
                                        self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-flags"):
                                        self.local_flags = value
                                        self.local_flags.value_namespace = name_space
                                        self.local_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-p2mp-id"):
                                        self.local_p2mp_id = value
                                        self.local_p2mp_id.value_namespace = name_space
                                        self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ptree-type"):
                                        self.local_ptree_type = value
                                        self.local_ptree_type.value_namespace = name_space
                                        self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-tunnel-id"):
                                        self.local_tunnel_id = value
                                        self.local_tunnel_id.value_namespace = name_space
                                        self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-available"):
                                        self.remote_available = value
                                        self.remote_available.value_namespace = name_space
                                        self.remote_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-extended-tunnel-id"):
                                        self.remote_extended_tunnel_id = value
                                        self.remote_extended_tunnel_id.value_namespace = name_space
                                        self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-flags"):
                                        self.remote_flags = value
                                        self.remote_flags.value_namespace = name_space
                                        self.remote_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-p2mp-id"):
                                        self.remote_p2mp_id = value
                                        self.remote_p2mp_id.value_namespace = name_space
                                        self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ptree-type"):
                                        self.remote_ptree_type = value
                                        self.remote_ptree_type.value_namespace = name_space
                                        self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-tunnel-id"):
                                        self.remote_tunnel_id = value
                                        self.remote_tunnel_id.value_namespace = name_space
                                        self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ad_method.is_set or
                                    self.ad_remote_down.is_set or
                                    self.admited_bw.is_set or
                                    self.auto_discovery.is_set or
                                    self.backup_active.is_set or
                                    self.backup_force_active.is_set or
                                    self.backup_pw.is_set or
                                    self.bitrate_mismatched.is_set or
                                    self.bridge_pw_type_mismatch.is_set or
                                    self.cas_mismatched.is_set or
                                    self.diff_ts_mismatched.is_set or
                                    self.disable_delay.is_set or
                                    self.disable_never.is_set or
                                    self.evpn_src_acid.is_set or
                                    self.fe_ctype.is_set or
                                    self.forward_class.is_set or
                                    self.freq_mismatched.is_set or
                                    self.illegal_control_word.is_set or
                                    self.imposed_vlan_id.is_set or
                                    self.interworking.is_set or
                                    self.ipv6_local_source_address.is_set or
                                    self.is_evpnvpws_type.is_set or
                                    self.is_flow_label_static.is_set or
                                    self.is_multi_segment_pseudowire.is_set or
                                    self.is_partially_programmed.is_set or
                                    self.is_pwr_type.is_set or
                                    self.is_vfi.is_set or
                                    self.last_time_status_changed.is_set or
                                    self.last_time_status_down.is_set or
                                    self.ldp_label_advertise_failed.is_set or
                                    self.load_balance.is_set or
                                    self.local_control_word.is_set or
                                    self.local_label_failed.is_set or
                                    self.local_pseudo_wire_type.is_set or
                                    self.local_source_address.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.not_supported_qinq.is_set or
                                    self.num_ma_cwithdraw_msg_received.is_set or
                                    self.number_ma_cwithdraw_message_sent.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.payload_bytes_mismatched.is_set or
                                    self.payload_type_mismatched.is_set or
                                    self.preferred_path_disable_fallback.is_set or
                                    self.primary_peer_id.is_set or
                                    self.primary_pseudo_wire_id.is_set or
                                    self.primary_pw.is_set or
                                    self.protocol.is_set or
                                    self.pseudo_wire_id.is_set or
                                    self.pseudo_wire_state.is_set or
                                    self.pseudo_wire_type_mismatched.is_set or
                                    self.pw_class_name.is_set or
                                    self.pw_flow_label_code17_disabled.is_set or
                                    self.pw_flow_label_type.is_set or
                                    self.pw_flow_label_type_cfg.is_set or
                                    self.pw_redundancy_initial_delay.is_set or
                                    self.pw_redundancy_one_way.is_set or
                                    self.pw_status_use.is_set or
                                    self.pwlsd_rewrite_failed.is_set or
                                    self.remote_control_word.is_set or
                                    self.remote_label_failed.is_set or
                                    self.remote_pseudo_wire_type.is_set or
                                    self.required_bw.is_set or
                                    self.resync_enabled.is_set or
                                    self.resync_threshold.is_set or
                                    self.rtp_mismatched.is_set or
                                    self.sequencing_type.is_set or
                                    self.shutdown.is_set or
                                    self.sig_pkts_mismatched.is_set or
                                    self.ssrc_mismatched.is_set or
                                    self.state.is_set or
                                    self.table_policy_name.is_set or
                                    self.tag_rewrite.is_set or
                                    self.time_created.is_set or
                                    self.time_elapsed_creation.is_set or
                                    self.time_elapsed_status_changed.is_set or
                                    self.time_elapsed_status_down.is_set or
                                    self.transport_lsp_down.is_set or
                                    self.xconnect_id.is_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                    (self.local_interface is not None and self.local_interface.has_data()) or
                                    (self.local_signalling is not None and self.local_signalling.has_data()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                    (self.peer_id is not None and self.peer_id.has_data()) or
                                    (self.preferred_path is not None and self.preferred_path.has_data()) or
                                    (self.remote_interface is not None and self.remote_interface.has_data()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_remote_down.yfilter != YFilter.not_set or
                                    self.admited_bw.yfilter != YFilter.not_set or
                                    self.auto_discovery.yfilter != YFilter.not_set or
                                    self.backup_active.yfilter != YFilter.not_set or
                                    self.backup_force_active.yfilter != YFilter.not_set or
                                    self.backup_pw.yfilter != YFilter.not_set or
                                    self.bitrate_mismatched.yfilter != YFilter.not_set or
                                    self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                    self.cas_mismatched.yfilter != YFilter.not_set or
                                    self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                    self.disable_delay.yfilter != YFilter.not_set or
                                    self.disable_never.yfilter != YFilter.not_set or
                                    self.evpn_src_acid.yfilter != YFilter.not_set or
                                    self.fe_ctype.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.freq_mismatched.yfilter != YFilter.not_set or
                                    self.illegal_control_word.yfilter != YFilter.not_set or
                                    self.imposed_vlan_id.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                    self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                    self.is_flow_label_static.yfilter != YFilter.not_set or
                                    self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                    self.is_partially_programmed.yfilter != YFilter.not_set or
                                    self.is_pwr_type.yfilter != YFilter.not_set or
                                    self.is_vfi.yfilter != YFilter.not_set or
                                    self.last_time_status_changed.yfilter != YFilter.not_set or
                                    self.last_time_status_down.yfilter != YFilter.not_set or
                                    self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                    self.load_balance.yfilter != YFilter.not_set or
                                    self.local_control_word.yfilter != YFilter.not_set or
                                    self.local_label_failed.yfilter != YFilter.not_set or
                                    self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.local_source_address.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.not_supported_qinq.yfilter != YFilter.not_set or
                                    self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                    self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                    self.payload_type_mismatched.yfilter != YFilter.not_set or
                                    self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                    self.primary_peer_id.yfilter != YFilter.not_set or
                                    self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.primary_pw.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.pseudo_wire_state.yfilter != YFilter.not_set or
                                    self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                    self.pw_class_name.yfilter != YFilter.not_set or
                                    self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                    self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                    self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                    self.pw_status_use.yfilter != YFilter.not_set or
                                    self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.remote_control_word.yfilter != YFilter.not_set or
                                    self.remote_label_failed.yfilter != YFilter.not_set or
                                    self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.required_bw.yfilter != YFilter.not_set or
                                    self.resync_enabled.yfilter != YFilter.not_set or
                                    self.resync_threshold.yfilter != YFilter.not_set or
                                    self.rtp_mismatched.yfilter != YFilter.not_set or
                                    self.sequencing_type.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                    self.ssrc_mismatched.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.table_policy_name.yfilter != YFilter.not_set or
                                    self.tag_rewrite.yfilter != YFilter.not_set or
                                    self.time_created.yfilter != YFilter.not_set or
                                    self.time_elapsed_creation.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                    self.transport_lsp_down.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                    (self.local_interface is not None and self.local_interface.has_operation()) or
                                    (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                    (self.peer_id is not None and self.peer_id.has_operation()) or
                                    (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                    (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pseudowire" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_active.get_name_leafdata())
                                if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_never.get_name_leafdata())
                                if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance.get_name_leafdata())
                                if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())
                                if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.required_bw.get_name_leafdata())
                                if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_created.get_name_leafdata())
                                if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "encapsulation-info"):
                                    if (self.encapsulation_info is None):
                                        self.encapsulation_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    return self.encapsulation_info

                                if (child_yang_name == "local-interface"):
                                    if (self.local_interface is None):
                                        self.local_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                    return self.local_interface

                                if (child_yang_name == "local-signalling"):
                                    if (self.local_signalling is None):
                                        self.local_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                    return self.local_signalling

                                if (child_yang_name == "p2mp-pw"):
                                    if (self.p2mp_pw is None):
                                        self.p2mp_pw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    return self.p2mp_pw

                                if (child_yang_name == "peer-id"):
                                    if (self.peer_id is None):
                                        self.peer_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                    return self.peer_id

                                if (child_yang_name == "preferred-path"):
                                    if (self.preferred_path is None):
                                        self.preferred_path = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                    return self.preferred_path

                                if (child_yang_name == "remote-interface"):
                                    if (self.remote_interface is None):
                                        self.remote_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                    return self.remote_interface

                                if (child_yang_name == "remote-signalling"):
                                    if (self.remote_signalling is None):
                                        self.remote_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                    return self.remote_signalling

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-remote-down"):
                                    self.ad_remote_down = value
                                    self.ad_remote_down.value_namespace = name_space
                                    self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "admited-bw"):
                                    self.admited_bw = value
                                    self.admited_bw.value_namespace = name_space
                                    self.admited_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "auto-discovery"):
                                    self.auto_discovery = value
                                    self.auto_discovery.value_namespace = name_space
                                    self.auto_discovery.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-active"):
                                    self.backup_active = value
                                    self.backup_active.value_namespace = name_space
                                    self.backup_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-force-active"):
                                    self.backup_force_active = value
                                    self.backup_force_active.value_namespace = name_space
                                    self.backup_force_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-pw"):
                                    self.backup_pw = value
                                    self.backup_pw.value_namespace = name_space
                                    self.backup_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "bitrate-mismatched"):
                                    self.bitrate_mismatched = value
                                    self.bitrate_mismatched.value_namespace = name_space
                                    self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-pw-type-mismatch"):
                                    self.bridge_pw_type_mismatch = value
                                    self.bridge_pw_type_mismatch.value_namespace = name_space
                                    self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "cas-mismatched"):
                                    self.cas_mismatched = value
                                    self.cas_mismatched.value_namespace = name_space
                                    self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "diff-ts-mismatched"):
                                    self.diff_ts_mismatched = value
                                    self.diff_ts_mismatched.value_namespace = name_space
                                    self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-delay"):
                                    self.disable_delay = value
                                    self.disable_delay.value_namespace = name_space
                                    self.disable_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-never"):
                                    self.disable_never = value
                                    self.disable_never.value_namespace = name_space
                                    self.disable_never.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-src-acid"):
                                    self.evpn_src_acid = value
                                    self.evpn_src_acid.value_namespace = name_space
                                    self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                if(value_path == "fe-ctype"):
                                    self.fe_ctype = value
                                    self.fe_ctype.value_namespace = name_space
                                    self.fe_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "freq-mismatched"):
                                    self.freq_mismatched = value
                                    self.freq_mismatched.value_namespace = name_space
                                    self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-control-word"):
                                    self.illegal_control_word = value
                                    self.illegal_control_word.value_namespace = name_space
                                    self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "imposed-vlan-id"):
                                    self.imposed_vlan_id = value
                                    self.imposed_vlan_id.value_namespace = name_space
                                    self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-local-source-address"):
                                    self.ipv6_local_source_address = value
                                    self.ipv6_local_source_address.value_namespace = name_space
                                    self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpnvpws-type"):
                                    self.is_evpnvpws_type = value
                                    self.is_evpnvpws_type.value_namespace = name_space
                                    self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-flow-label-static"):
                                    self.is_flow_label_static = value
                                    self.is_flow_label_static.value_namespace = name_space
                                    self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-multi-segment-pseudowire"):
                                    self.is_multi_segment_pseudowire = value
                                    self.is_multi_segment_pseudowire.value_namespace = name_space
                                    self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-partially-programmed"):
                                    self.is_partially_programmed = value
                                    self.is_partially_programmed.value_namespace = name_space
                                    self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pwr-type"):
                                    self.is_pwr_type = value
                                    self.is_pwr_type.value_namespace = name_space
                                    self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vfi"):
                                    self.is_vfi = value
                                    self.is_vfi.value_namespace = name_space
                                    self.is_vfi.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-changed"):
                                    self.last_time_status_changed = value
                                    self.last_time_status_changed.value_namespace = name_space
                                    self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-down"):
                                    self.last_time_status_down = value
                                    self.last_time_status_down.value_namespace = name_space
                                    self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertise-failed"):
                                    self.ldp_label_advertise_failed = value
                                    self.ldp_label_advertise_failed.value_namespace = name_space
                                    self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance"):
                                    self.load_balance = value
                                    self.load_balance.value_namespace = name_space
                                    self.load_balance.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-control-word"):
                                    self.local_control_word = value
                                    self.local_control_word.value_namespace = name_space
                                    self.local_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label-failed"):
                                    self.local_label_failed = value
                                    self.local_label_failed.value_namespace = name_space
                                    self.local_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-pseudo-wire-type"):
                                    self.local_pseudo_wire_type = value
                                    self.local_pseudo_wire_type.value_namespace = name_space
                                    self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-source-address"):
                                    self.local_source_address = value
                                    self.local_source_address.value_namespace = name_space
                                    self.local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-supported-qinq"):
                                    self.not_supported_qinq = value
                                    self.not_supported_qinq.value_namespace = name_space
                                    self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                if(value_path == "num-ma-cwithdraw-msg-received"):
                                    self.num_ma_cwithdraw_msg_received = value
                                    self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                    self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-ma-cwithdraw-message-sent"):
                                    self.number_ma_cwithdraw_message_sent = value
                                    self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                    self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes-mismatched"):
                                    self.payload_bytes_mismatched = value
                                    self.payload_bytes_mismatched.value_namespace = name_space
                                    self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-type-mismatched"):
                                    self.payload_type_mismatched = value
                                    self.payload_type_mismatched.value_namespace = name_space
                                    self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "preferred-path-disable-fallback"):
                                    self.preferred_path_disable_fallback = value
                                    self.preferred_path_disable_fallback.value_namespace = name_space
                                    self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-peer-id"):
                                    self.primary_peer_id = value
                                    self.primary_peer_id.value_namespace = name_space
                                    self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pseudo-wire-id"):
                                    self.primary_pseudo_wire_id = value
                                    self.primary_pseudo_wire_id.value_namespace = name_space
                                    self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pw"):
                                    self.primary_pw = value
                                    self.primary_pw.value_namespace = name_space
                                    self.primary_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id"):
                                    self.pseudo_wire_id = value
                                    self.pseudo_wire_id.value_namespace = name_space
                                    self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-state"):
                                    self.pseudo_wire_state = value
                                    self.pseudo_wire_state.value_namespace = name_space
                                    self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-type-mismatched"):
                                    self.pseudo_wire_type_mismatched = value
                                    self.pseudo_wire_type_mismatched.value_namespace = name_space
                                    self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-class-name"):
                                    self.pw_class_name = value
                                    self.pw_class_name.value_namespace = name_space
                                    self.pw_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-code17-disabled"):
                                    self.pw_flow_label_code17_disabled = value
                                    self.pw_flow_label_code17_disabled.value_namespace = name_space
                                    self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type"):
                                    self.pw_flow_label_type = value
                                    self.pw_flow_label_type.value_namespace = name_space
                                    self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type-cfg"):
                                    self.pw_flow_label_type_cfg = value
                                    self.pw_flow_label_type_cfg.value_namespace = name_space
                                    self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-initial-delay"):
                                    self.pw_redundancy_initial_delay = value
                                    self.pw_redundancy_initial_delay.value_namespace = name_space
                                    self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-one-way"):
                                    self.pw_redundancy_one_way = value
                                    self.pw_redundancy_one_way.value_namespace = name_space
                                    self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-status-use"):
                                    self.pw_status_use = value
                                    self.pw_status_use.value_namespace = name_space
                                    self.pw_status_use.value_namespace_prefix = name_space_prefix
                                if(value_path == "pwlsd-rewrite-failed"):
                                    self.pwlsd_rewrite_failed = value
                                    self.pwlsd_rewrite_failed.value_namespace = name_space
                                    self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-control-word"):
                                    self.remote_control_word = value
                                    self.remote_control_word.value_namespace = name_space
                                    self.remote_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label-failed"):
                                    self.remote_label_failed = value
                                    self.remote_label_failed.value_namespace = name_space
                                    self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-pseudo-wire-type"):
                                    self.remote_pseudo_wire_type = value
                                    self.remote_pseudo_wire_type.value_namespace = name_space
                                    self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "required-bw"):
                                    self.required_bw = value
                                    self.required_bw.value_namespace = name_space
                                    self.required_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-enabled"):
                                    self.resync_enabled = value
                                    self.resync_enabled.value_namespace = name_space
                                    self.resync_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-threshold"):
                                    self.resync_threshold = value
                                    self.resync_threshold.value_namespace = name_space
                                    self.resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "rtp-mismatched"):
                                    self.rtp_mismatched = value
                                    self.rtp_mismatched.value_namespace = name_space
                                    self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequencing-type"):
                                    self.sequencing_type = value
                                    self.sequencing_type.value_namespace = name_space
                                    self.sequencing_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "sig-pkts-mismatched"):
                                    self.sig_pkts_mismatched = value
                                    self.sig_pkts_mismatched.value_namespace = name_space
                                    self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "ssrc-mismatched"):
                                    self.ssrc_mismatched = value
                                    self.ssrc_mismatched.value_namespace = name_space
                                    self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-policy-name"):
                                    self.table_policy_name = value
                                    self.table_policy_name.value_namespace = name_space
                                    self.table_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag-rewrite"):
                                    self.tag_rewrite = value
                                    self.tag_rewrite.value_namespace = name_space
                                    self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-created"):
                                    self.time_created = value
                                    self.time_created.value_namespace = name_space
                                    self.time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-creation"):
                                    self.time_elapsed_creation = value
                                    self.time_elapsed_creation.value_namespace = name_space
                                    self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-changed"):
                                    self.time_elapsed_status_changed = value
                                    self.time_elapsed_status_changed.value_namespace = name_space
                                    self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-down"):
                                    self.time_elapsed_status_down = value
                                    self.time_elapsed_status_down.value_namespace = name_space
                                    self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-lsp-down"):
                                    self.transport_lsp_down = value
                                    self.transport_lsp_down.value_namespace = name_space
                                    self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-pw"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dhcpv4_trust",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                    self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                    self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                    self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                    self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                    self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                    self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                    self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                    self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                    self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                    self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                    self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                    self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                    self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                    self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                    self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                    self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                    self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                    self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                    self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                    self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                    self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                    self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                    self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                    self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                    self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                    self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                    self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                    self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                    self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dai_address_validation_mask",
                                                    "dhcpv4_profile_name",
                                                    "dhcpv4_snoop",
                                                    "flood_unknown_unicast_enabled",
                                                    "flood_uu_disabled_mac_limit_action",
                                                    "igm_pv4_disabled",
                                                    "igm_pv4_profile_name",
                                                    "is_dai_addr_validate_destination_mac_enabled",
                                                    "is_dai_addr_validate_ipv4_enabled",
                                                    "is_dai_addr_validate_source_mac_enabled",
                                                    "is_dai_enabled",
                                                    "is_dai_logging_enabled",
                                                    "is_ip_source_guard_enabled",
                                                    "is_ipsg_logging_enabled",
                                                    "is_mac_secure_accept_shutdown_enabled",
                                                    "is_mac_secure_enabled",
                                                    "is_mac_secure_logging_enabled",
                                                    "learn_disabled_mac_limit_action",
                                                    "mac_aging_mode",
                                                    "mac_aging_time",
                                                    "mac_flooding",
                                                    "mac_learning",
                                                    "mac_limit",
                                                    "mac_limit_action",
                                                    "mac_limit_notification",
                                                    "mac_limit_reached",
                                                    "mac_port_down_flush_enabled",
                                                    "mac_secure_action",
                                                    "mld_profile_name",
                                                    "mmrp_flood_optimization",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "split_horizon_group_id",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/base/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dai_address_validation_mask.is_set or
                                        self.dhcpv4_profile_name.is_set or
                                        self.dhcpv4_snoop.is_set or
                                        self.flood_unknown_unicast_enabled.is_set or
                                        self.flood_uu_disabled_mac_limit_action.is_set or
                                        self.igm_pv4_disabled.is_set or
                                        self.igm_pv4_profile_name.is_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                        self.is_dai_addr_validate_ipv4_enabled.is_set or
                                        self.is_dai_addr_validate_source_mac_enabled.is_set or
                                        self.is_dai_enabled.is_set or
                                        self.is_dai_logging_enabled.is_set or
                                        self.is_ip_source_guard_enabled.is_set or
                                        self.is_ipsg_logging_enabled.is_set or
                                        self.is_mac_secure_accept_shutdown_enabled.is_set or
                                        self.is_mac_secure_enabled.is_set or
                                        self.is_mac_secure_logging_enabled.is_set or
                                        self.learn_disabled_mac_limit_action.is_set or
                                        self.mac_aging_mode.is_set or
                                        self.mac_aging_time.is_set or
                                        self.mac_flooding.is_set or
                                        self.mac_learning.is_set or
                                        self.mac_limit.is_set or
                                        self.mac_limit_action.is_set or
                                        self.mac_limit_notification.is_set or
                                        self.mac_limit_reached.is_set or
                                        self.mac_port_down_flush_enabled.is_set or
                                        self.mac_secure_action.is_set or
                                        self.mld_profile_name.is_set or
                                        self.mmrp_flood_optimization.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.split_horizon_group_id.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                        self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                        self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                        self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                        self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                        self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                        self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                        self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_aging_mode.yfilter != YFilter.not_set or
                                        self.mac_aging_time.yfilter != YFilter.not_set or
                                        self.mac_flooding.yfilter != YFilter.not_set or
                                        self.mac_learning.yfilter != YFilter.not_set or
                                        self.mac_limit.yfilter != YFilter.not_set or
                                        self.mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_limit_notification.yfilter != YFilter.not_set or
                                        self.mac_limit_reached.yfilter != YFilter.not_set or
                                        self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                        self.mac_secure_action.yfilter != YFilter.not_set or
                                        self.mld_profile_name.yfilter != YFilter.not_set or
                                        self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.split_horizon_group_id.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                    if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                    if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                    if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                    if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                    if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                    if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                    if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                    if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                    if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                    if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                    if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                    if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                    if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                    if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                    if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                    if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                    if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                    if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                    if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                    if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                    if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dai-address-validation-mask"):
                                        self.dai_address_validation_mask = value
                                        self.dai_address_validation_mask.value_namespace = name_space
                                        self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-profile-name"):
                                        self.dhcpv4_profile_name = value
                                        self.dhcpv4_profile_name.value_namespace = name_space
                                        self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-snoop"):
                                        self.dhcpv4_snoop = value
                                        self.dhcpv4_snoop.value_namespace = name_space
                                        self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-unknown-unicast-enabled"):
                                        self.flood_unknown_unicast_enabled = value
                                        self.flood_unknown_unicast_enabled.value_namespace = name_space
                                        self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-uu-disabled-mac-limit-action"):
                                        self.flood_uu_disabled_mac_limit_action = value
                                        self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                        self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-disabled"):
                                        self.igm_pv4_disabled = value
                                        self.igm_pv4_disabled.value_namespace = name_space
                                        self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-profile-name"):
                                        self.igm_pv4_profile_name = value
                                        self.igm_pv4_profile_name.value_namespace = name_space
                                        self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                        self.is_dai_addr_validate_destination_mac_enabled = value
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                        self.is_dai_addr_validate_ipv4_enabled = value
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                        self.is_dai_addr_validate_source_mac_enabled = value
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-enabled"):
                                        self.is_dai_enabled = value
                                        self.is_dai_enabled.value_namespace = name_space
                                        self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-logging-enabled"):
                                        self.is_dai_logging_enabled = value
                                        self.is_dai_logging_enabled.value_namespace = name_space
                                        self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ip-source-guard-enabled"):
                                        self.is_ip_source_guard_enabled = value
                                        self.is_ip_source_guard_enabled.value_namespace = name_space
                                        self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ipsg-logging-enabled"):
                                        self.is_ipsg_logging_enabled = value
                                        self.is_ipsg_logging_enabled.value_namespace = name_space
                                        self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                        self.is_mac_secure_accept_shutdown_enabled = value
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-enabled"):
                                        self.is_mac_secure_enabled = value
                                        self.is_mac_secure_enabled.value_namespace = name_space
                                        self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-logging-enabled"):
                                        self.is_mac_secure_logging_enabled = value
                                        self.is_mac_secure_logging_enabled.value_namespace = name_space
                                        self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "learn-disabled-mac-limit-action"):
                                        self.learn_disabled_mac_limit_action = value
                                        self.learn_disabled_mac_limit_action.value_namespace = name_space
                                        self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-mode"):
                                        self.mac_aging_mode = value
                                        self.mac_aging_mode.value_namespace = name_space
                                        self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-time"):
                                        self.mac_aging_time = value
                                        self.mac_aging_time.value_namespace = name_space
                                        self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flooding"):
                                        self.mac_flooding = value
                                        self.mac_flooding.value_namespace = name_space
                                        self.mac_flooding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-learning"):
                                        self.mac_learning = value
                                        self.mac_learning.value_namespace = name_space
                                        self.mac_learning.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit"):
                                        self.mac_limit = value
                                        self.mac_limit.value_namespace = name_space
                                        self.mac_limit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-action"):
                                        self.mac_limit_action = value
                                        self.mac_limit_action.value_namespace = name_space
                                        self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-notification"):
                                        self.mac_limit_notification = value
                                        self.mac_limit_notification.value_namespace = name_space
                                        self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-reached"):
                                        self.mac_limit_reached = value
                                        self.mac_limit_reached.value_namespace = name_space
                                        self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-port-down-flush-enabled"):
                                        self.mac_port_down_flush_enabled = value
                                        self.mac_port_down_flush_enabled.value_namespace = name_space
                                        self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-secure-action"):
                                        self.mac_secure_action = value
                                        self.mac_secure_action.value_namespace = name_space
                                        self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mld-profile-name"):
                                        self.mld_profile_name = value
                                        self.mld_profile_name.value_namespace = name_space
                                        self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mmrp-flood-optimization"):
                                        self.mmrp_flood_optimization = value
                                        self.mmrp_flood_optimization.value_namespace = name_space
                                        self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "split-horizon-group-id"):
                                        self.split_horizon_group_id = value
                                        self.split_horizon_group_id.value_namespace = name_space
                                        self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dhcpv4_trust.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dhcpv4_trust.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-trust"):
                                    self.dhcpv4_trust = value
                                    self.dhcpv4_trust.value_namespace = name_space
                                    self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "bridge-pw"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "static-mac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.static_mac:
                                if (c.has_data()):
                                    return True
                            return (
                                self.is_access.is_set or
                                self.neighbor.is_set or
                                self.pseudowire_id.is_set or
                                self.pw_type.is_set or
                                self.ve_id_vpls_id_0_3.is_set or
                                self.vpls_id_4_7.is_set or
                                (self.pseudowire is not None and self.pseudowire.has_data()) or
                                (self.security_parameters is not None and self.security_parameters.has_data()))

                        def has_operation(self):
                            for c in self.static_mac:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.is_access.yfilter != YFilter.not_set or
                                self.neighbor.yfilter != YFilter.not_set or
                                self.pseudowire_id.yfilter != YFilter.not_set or
                                self.pw_type.yfilter != YFilter.not_set or
                                self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set or
                                self.vpls_id_4_7.yfilter != YFilter.not_set or
                                (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                (self.security_parameters is not None and self.security_parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-pw" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_access.get_name_leafdata())
                            if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor.get_name_leafdata())
                            if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudowire_id.get_name_leafdata())
                            if (self.pw_type.is_set or self.pw_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_type.get_name_leafdata())
                            if (self.ve_id_vpls_id_0_3.is_set or self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ve_id_vpls_id_0_3.get_name_leafdata())
                            if (self.vpls_id_4_7.is_set or self.vpls_id_4_7.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vpls_id_4_7.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "pseudowire"):
                                if (self.pseudowire is None):
                                    self.pseudowire = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                    self.pseudowire.parent = self
                                    self._children_name_map["pseudowire"] = "pseudowire"
                                return self.pseudowire

                            if (child_yang_name == "security-parameters"):
                                if (self.security_parameters is None):
                                    self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                return self.security_parameters

                            if (child_yang_name == "static-mac"):
                                for c in self.static_mac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.static_mac.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id" or name == "pw-type" or name == "ve-id-vpls-id-0-3" or name == "vpls-id-4-7"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "is-access"):
                                self.is_access = value
                                self.is_access.value_namespace = name_space
                                self.is_access.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor"):
                                self.neighbor = value
                                self.neighbor.value_namespace = name_space
                                self.neighbor.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudowire-id"):
                                self.pseudowire_id = value
                                self.pseudowire_id.value_namespace = name_space
                                self.pseudowire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-type"):
                                self.pw_type = value
                                self.pw_type.value_namespace = name_space
                                self.pw_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "ve-id-vpls-id-0-3"):
                                self.ve_id_vpls_id_0_3 = value
                                self.ve_id_vpls_id_0_3.value_namespace = name_space
                                self.ve_id_vpls_id_0_3.value_namespace_prefix = name_space_prefix
                            if(value_path == "vpls-id-4-7"):
                                self.vpls_id_4_7 = value
                                self.vpls_id_4_7.value_namespace = name_space
                                self.vpls_id_4_7.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bridge_pw:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bridge_pw:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-pws" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-vfi-table/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-pw"):
                            for c in self.bridge_pw:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bridge_pw.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-pw"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.bridge_pws is not None and self.bridge_pws.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bridge_pws is not None and self.bridge_pws.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bridge-access-vfi-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bridge-pws"):
                        if (self.bridge_pws is None):
                            self.bridge_pws = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                            self.bridge_pws.parent = self
                            self._children_name_map["bridge_pws"] = "bridge-pws"
                        return self.bridge_pws

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bridge-pws"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BridgeCoreVfiTable(Entity):
                """
                Bridge Domain Core VFI Table
                
                .. attribute:: bridge_pws
                
                	Bridge Domain Access/Core Pseudowire Table
                	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable, self).__init__()

                    self.yang_name = "bridge-core-vfi-table"
                    self.yang_parent_name = "bridge-domain"

                    self.bridge_pws = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                    self.bridge_pws.parent = self
                    self._children_name_map["bridge_pws"] = "bridge-pws"
                    self._children_yang_names.add("bridge-pws")


                class BridgePws(Entity):
                    """
                    Bridge Domain Access/Core Pseudowire Table
                    
                    .. attribute:: bridge_pw
                    
                    	VPLS Bridge Domain Pseudowire
                    	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__init__()

                        self.yang_name = "bridge-pws"
                        self.yang_parent_name = "bridge-core-vfi-table"

                        self.bridge_pw = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__setattr__(name, value)


                    class BridgePw(Entity):
                        """
                        VPLS Bridge Domain Pseudowire
                        
                        .. attribute:: is_access
                        
                        	Is Access PW
                        	**type**\:  bool
                        
                        .. attribute:: neighbor
                        
                        	Neighbor IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                        
                        .. attribute:: pseudowire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_type
                        
                        	PW Type
                        	**type**\:   :py:class:`L2Vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnpw>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                        
                        .. attribute:: ve_id_vpls_id_0_3
                        
                        	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vpls_id_4_7
                        
                        	Zero or Last 4 bytes of VPLS\-ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__init__()

                            self.yang_name = "bridge-pw"
                            self.yang_parent_name = "bridge-pws"

                            self.is_access = YLeaf(YType.boolean, "is-access")

                            self.neighbor = YLeaf(YType.str, "neighbor")

                            self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                            self.pw_type = YLeaf(YType.enumeration, "pw-type")

                            self.ve_id_vpls_id_0_3 = YLeaf(YType.uint32, "ve-id-vpls-id-0-3")

                            self.vpls_id_4_7 = YLeaf(YType.uint32, "vpls-id-4-7")

                            self.pseudowire = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                            self.pseudowire.parent = self
                            self._children_name_map["pseudowire"] = "pseudowire"
                            self._children_yang_names.add("pseudowire")

                            self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                            self._children_yang_names.add("security-parameters")

                            self.static_mac = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("is_access",
                                            "neighbor",
                                            "pseudowire_id",
                                            "pw_type",
                                            "ve_id_vpls_id_0_3",
                                            "vpls_id_4_7") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__setattr__(name, value)


                        class Pseudowire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                self.yang_name = "pseudowire"
                                self.yang_parent_name = "bridge-pw"

                                self.ad_method = YLeaf(YType.uint32, "ad-method")

                                self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                                self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                                self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                                self.backup_active = YLeaf(YType.boolean, "backup-active")

                                self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                                self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                                self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                                self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                                self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                                self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                                self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                                self.disable_never = YLeaf(YType.boolean, "disable-never")

                                self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                                self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                                self.forward_class = YLeaf(YType.uint8, "forward-class")

                                self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                                self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                                self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                                self.interworking = YLeaf(YType.enumeration, "interworking")

                                self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                                self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                                self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                                self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                                self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                                self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                                self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                                self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                                self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                                self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                                self.load_balance = YLeaf(YType.enumeration, "load-balance")

                                self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                                self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                                self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                                self.local_source_address = YLeaf(YType.str, "local-source-address")

                                self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                                self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                                self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                                self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                                self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                                self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                                self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                                self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                                self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                                self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                                self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                                self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                                self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                                self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                                self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                                self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                                self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                                self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                                self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                                self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                                self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                                self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                                self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                                self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                                self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                                self.required_bw = YLeaf(YType.uint32, "required-bw")

                                self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                                self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                                self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                                self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                                self.shutdown = YLeaf(YType.boolean, "shutdown")

                                self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                                self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                                self.state = YLeaf(YType.enumeration, "state")

                                self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                                self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                                self.time_created = YLeaf(YType.str, "time-created")

                                self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                                self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                                self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                                self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.encapsulation_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                self._children_yang_names.add("encapsulation-info")

                                self.local_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                                self._children_yang_names.add("local-interface")

                                self.local_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                                self._children_yang_names.add("local-signalling")

                                self.p2mp_pw = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._children_yang_names.add("p2mp-pw")

                                self.peer_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                                self._children_yang_names.add("peer-id")

                                self.preferred_path = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                                self._children_yang_names.add("preferred-path")

                                self.remote_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                                self._children_yang_names.add("remote-interface")

                                self.remote_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                                self._children_yang_names.add("remote-signalling")

                                self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ad_method",
                                                "ad_remote_down",
                                                "admited_bw",
                                                "auto_discovery",
                                                "backup_active",
                                                "backup_force_active",
                                                "backup_pw",
                                                "bitrate_mismatched",
                                                "bridge_pw_type_mismatch",
                                                "cas_mismatched",
                                                "diff_ts_mismatched",
                                                "disable_delay",
                                                "disable_never",
                                                "evpn_src_acid",
                                                "fe_ctype",
                                                "forward_class",
                                                "freq_mismatched",
                                                "illegal_control_word",
                                                "imposed_vlan_id",
                                                "interworking",
                                                "ipv6_local_source_address",
                                                "is_evpnvpws_type",
                                                "is_flow_label_static",
                                                "is_multi_segment_pseudowire",
                                                "is_partially_programmed",
                                                "is_pwr_type",
                                                "is_vfi",
                                                "last_time_status_changed",
                                                "last_time_status_down",
                                                "ldp_label_advertise_failed",
                                                "load_balance",
                                                "local_control_word",
                                                "local_label_failed",
                                                "local_pseudo_wire_type",
                                                "local_source_address",
                                                "mac_limit_oper_down",
                                                "mtu_mismatched",
                                                "not_supported_qinq",
                                                "num_ma_cwithdraw_msg_received",
                                                "number_ma_cwithdraw_message_sent",
                                                "out_of_memory_state",
                                                "payload_bytes_mismatched",
                                                "payload_type_mismatched",
                                                "preferred_path_disable_fallback",
                                                "primary_peer_id",
                                                "primary_pseudo_wire_id",
                                                "primary_pw",
                                                "protocol",
                                                "pseudo_wire_id",
                                                "pseudo_wire_state",
                                                "pseudo_wire_type_mismatched",
                                                "pw_class_name",
                                                "pw_flow_label_code17_disabled",
                                                "pw_flow_label_type",
                                                "pw_flow_label_type_cfg",
                                                "pw_redundancy_initial_delay",
                                                "pw_redundancy_one_way",
                                                "pw_status_use",
                                                "pwlsd_rewrite_failed",
                                                "remote_control_word",
                                                "remote_label_failed",
                                                "remote_pseudo_wire_type",
                                                "required_bw",
                                                "resync_enabled",
                                                "resync_threshold",
                                                "rtp_mismatched",
                                                "sequencing_type",
                                                "shutdown",
                                                "sig_pkts_mismatched",
                                                "ssrc_mismatched",
                                                "state",
                                                "table_policy_name",
                                                "tag_rewrite",
                                                "time_created",
                                                "time_elapsed_creation",
                                                "time_elapsed_status_changed",
                                                "time_elapsed_status_down",
                                                "transport_lsp_down",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__setattr__(name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudowire"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                    self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                    self.type = YLeaf(YType.enumeration, "type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "ipv4_peer_id",
                                                    "ipv6_peer_id",
                                                    "type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.ipv4_peer_id.is_set or
                                        self.ipv6_peer_id.is_set or
                                        self.type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.ipv4_peer_id.yfilter != YFilter.not_set or
                                        self.ipv6_peer_id.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "peer-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                    if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-peer-id"):
                                        self.ipv4_peer_id = value
                                        self.ipv4_peer_id.value_namespace = name_space
                                        self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-peer-id"):
                                        self.ipv6_peer_id = value
                                        self.ipv6_peer_id.value_namespace = name_space
                                        self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudowire"

                                    self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                    self.atom = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._children_yang_names.add("atom")

                                    self.l2tpv3 = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._children_yang_names.add("l2tpv3")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                        self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                        self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                        self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                        self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                        self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                        self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                        self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                        self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                        self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                        self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                        self.local_veid = YLeaf(YType.uint32, "local-veid")

                                        self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                        self.rem_saii = YLeaf(YType.str, "rem-saii")

                                        self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                        self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                        self.rem_taii = YLeaf(YType.str, "rem-taii")

                                        self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                        self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                        self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                        self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                        self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                        self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                        self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                        self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                        self.saii = YLeaf(YType.str, "saii")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.taii = YLeaf(YType.str, "taii")

                                        self.local_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                        self._children_yang_names.add("local-agi")

                                        self.multi_segment_pseudowire_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._children_yang_names.add("multi-segment-pseudowire-stats")

                                        self.remote_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                        self._children_yang_names.add("remote-agi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_pseudowire_headend",
                                                        "is_sai_itype2",
                                                        "is_tai_itype2",
                                                        "ldp_label_advertisment_failed",
                                                        "local_c_ctype",
                                                        "local_ceid",
                                                        "local_cv_type",
                                                        "local_group_id",
                                                        "local_label",
                                                        "local_ldp_id",
                                                        "local_saii_gbl_id",
                                                        "local_saiiac_id",
                                                        "local_taii_gbl_id",
                                                        "local_taiiac_id",
                                                        "local_veid",
                                                        "lsd_rewrite_failed",
                                                        "rem_saii",
                                                        "rem_saii_gbl_id",
                                                        "rem_saiiac_id",
                                                        "rem_taii",
                                                        "rem_taii_gbl_id",
                                                        "rem_taiiac_id",
                                                        "remote_c_ctype",
                                                        "remote_ceid",
                                                        "remote_cv_type",
                                                        "remote_group_id",
                                                        "remote_label",
                                                        "remote_ldp_id",
                                                        "remote_source_address",
                                                        "remote_veid",
                                                        "saii",
                                                        "source_address",
                                                        "taii") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "local-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"

                                            self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                            self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                            self._children_yang_names.add("auto")

                                            self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                            self._children_yang_names.add("two-byte-as")

                                            self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._children_yang_names.add("v4-addr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("vpls_id_type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"

                                                self.asn = YLeaf(YType.uint16, "asn")

                                                self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("asn",
                                                                "vpn_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.asn.is_set or
                                                    self.vpn_id.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.asn.yfilter != YFilter.not_set or
                                                    self.vpn_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "auto" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.asn.get_name_leafdata())
                                                if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "asn" or name == "vpn-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "asn"):
                                                    self.asn = value
                                                    self.asn.value_namespace = name_space
                                                    self.asn.value_namespace_prefix = name_space_prefix
                                                if(value_path == "vpn-id"):
                                                    self.vpn_id = value
                                                    self.vpn_id.value_namespace = name_space
                                                    self.vpn_id.value_namespace_prefix = name_space_prefix


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"

                                                self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                                self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("four_byte_index",
                                                                "two_byte_as") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.four_byte_index.is_set or
                                                    self.two_byte_as.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.four_byte_index.yfilter != YFilter.not_set or
                                                    self.two_byte_as.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "two-byte-as" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                                if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "four-byte-index" or name == "two-byte-as"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "four-byte-index"):
                                                    self.four_byte_index = value
                                                    self.four_byte_index.value_namespace = name_space
                                                    self.four_byte_index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-as"):
                                                    self.two_byte_as = value
                                                    self.two_byte_as.value_namespace = name_space
                                                    self.two_byte_as.value_namespace_prefix = name_space_prefix


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("ipv4_address",
                                                                "two_byte_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.ipv4_address.is_set or
                                                    self.two_byte_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.ipv4_address.yfilter != YFilter.not_set or
                                                    self.two_byte_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "v4-addr" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                                if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4-address" or name == "two-byte-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "ipv4-address"):
                                                    self.ipv4_address = value
                                                    self.ipv4_address.value_namespace = name_space
                                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "two-byte-index"):
                                                    self.two_byte_index = value
                                                    self.two_byte_index.value_namespace = name_space
                                                    self.two_byte_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.vpls_id_type.is_set or
                                                (self.auto is not None and self.auto.has_data()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                                (self.v4_addr is not None and self.v4_addr.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.vpls_id_type.yfilter != YFilter.not_set or
                                                (self.auto is not None and self.auto.has_operation()) or
                                                (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                                (self.v4_addr is not None and self.v4_addr.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-agi" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "auto"):
                                                if (self.auto is None):
                                                    self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"
                                                return self.auto

                                            if (child_yang_name == "two-byte-as"):
                                                if (self.two_byte_as is None):
                                                    self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                                return self.two_byte_as

                                            if (child_yang_name == "v4-addr"):
                                                if (self.v4_addr is None):
                                                    self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                return self.v4_addr

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "vpls-id-type"):
                                                self.vpls_id_type = value
                                                self.vpls_id_type.value_namespace = name_space
                                                self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"

                                            self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                            self.received_packets = YLeaf(YType.uint64, "received-packets")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("received_bytes",
                                                            "received_packets") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.received_bytes.is_set or
                                                self.received_packets.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.received_bytes.yfilter != YFilter.not_set or
                                                self.received_packets.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                            if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.received_packets.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "received-bytes" or name == "received-packets"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "received-bytes"):
                                                self.received_bytes = value
                                                self.received_bytes.value_namespace = name_space
                                                self.received_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "received-packets"):
                                                self.received_packets = value
                                                self.received_packets.value_namespace = name_space
                                                self.received_packets.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_pseudowire_headend.is_set or
                                            self.is_sai_itype2.is_set or
                                            self.is_tai_itype2.is_set or
                                            self.ldp_label_advertisment_failed.is_set or
                                            self.local_c_ctype.is_set or
                                            self.local_ceid.is_set or
                                            self.local_cv_type.is_set or
                                            self.local_group_id.is_set or
                                            self.local_label.is_set or
                                            self.local_ldp_id.is_set or
                                            self.local_saii_gbl_id.is_set or
                                            self.local_saiiac_id.is_set or
                                            self.local_taii_gbl_id.is_set or
                                            self.local_taiiac_id.is_set or
                                            self.local_veid.is_set or
                                            self.lsd_rewrite_failed.is_set or
                                            self.rem_saii.is_set or
                                            self.rem_saii_gbl_id.is_set or
                                            self.rem_saiiac_id.is_set or
                                            self.rem_taii.is_set or
                                            self.rem_taii_gbl_id.is_set or
                                            self.rem_taiiac_id.is_set or
                                            self.remote_c_ctype.is_set or
                                            self.remote_ceid.is_set or
                                            self.remote_cv_type.is_set or
                                            self.remote_group_id.is_set or
                                            self.remote_label.is_set or
                                            self.remote_ldp_id.is_set or
                                            self.remote_source_address.is_set or
                                            self.remote_veid.is_set or
                                            self.saii.is_set or
                                            self.source_address.is_set or
                                            self.taii.is_set or
                                            (self.local_agi is not None and self.local_agi.has_data()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                            (self.remote_agi is not None and self.remote_agi.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                            self.is_sai_itype2.yfilter != YFilter.not_set or
                                            self.is_tai_itype2.yfilter != YFilter.not_set or
                                            self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                            self.local_c_ctype.yfilter != YFilter.not_set or
                                            self.local_ceid.yfilter != YFilter.not_set or
                                            self.local_cv_type.yfilter != YFilter.not_set or
                                            self.local_group_id.yfilter != YFilter.not_set or
                                            self.local_label.yfilter != YFilter.not_set or
                                            self.local_ldp_id.yfilter != YFilter.not_set or
                                            self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_saiiac_id.yfilter != YFilter.not_set or
                                            self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.local_taiiac_id.yfilter != YFilter.not_set or
                                            self.local_veid.yfilter != YFilter.not_set or
                                            self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                            self.rem_saii.yfilter != YFilter.not_set or
                                            self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_saiiac_id.yfilter != YFilter.not_set or
                                            self.rem_taii.yfilter != YFilter.not_set or
                                            self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                            self.rem_taiiac_id.yfilter != YFilter.not_set or
                                            self.remote_c_ctype.yfilter != YFilter.not_set or
                                            self.remote_ceid.yfilter != YFilter.not_set or
                                            self.remote_cv_type.yfilter != YFilter.not_set or
                                            self.remote_group_id.yfilter != YFilter.not_set or
                                            self.remote_label.yfilter != YFilter.not_set or
                                            self.remote_ldp_id.yfilter != YFilter.not_set or
                                            self.remote_source_address.yfilter != YFilter.not_set or
                                            self.remote_veid.yfilter != YFilter.not_set or
                                            self.saii.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.taii.yfilter != YFilter.not_set or
                                            (self.local_agi is not None and self.local_agi.has_operation()) or
                                            (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                            (self.remote_agi is not None and self.remote_agi.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atom" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                        if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                        if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                        if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                        if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                        if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                        if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                        if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                        if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_label.get_name_leafdata())
                                        if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                        if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                        if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                        if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                        if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                        if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_veid.get_name_leafdata())
                                        if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                        if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                        if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                        if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                        if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                        if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                        if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                        if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                        if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                        if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                        if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                        if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_label.get_name_leafdata())
                                        if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                        if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                        if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                        if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saii.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.taii.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "local-agi"):
                                            if (self.local_agi is None):
                                                self.local_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"
                                            return self.local_agi

                                        if (child_yang_name == "multi-segment-pseudowire-stats"):
                                            if (self.multi_segment_pseudowire_stats is None):
                                                self.multi_segment_pseudowire_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            return self.multi_segment_pseudowire_stats

                                        if (child_yang_name == "remote-agi"):
                                            if (self.remote_agi is None):
                                                self.remote_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"
                                            return self.remote_agi

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-pseudowire-headend"):
                                            self.is_pseudowire_headend = value
                                            self.is_pseudowire_headend.value_namespace = name_space
                                            self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-sai-itype2"):
                                            self.is_sai_itype2 = value
                                            self.is_sai_itype2.value_namespace = name_space
                                            self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-tai-itype2"):
                                            self.is_tai_itype2 = value
                                            self.is_tai_itype2.value_namespace = name_space
                                            self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-label-advertisment-failed"):
                                            self.ldp_label_advertisment_failed = value
                                            self.ldp_label_advertisment_failed.value_namespace = name_space
                                            self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-c-ctype"):
                                            self.local_c_ctype = value
                                            self.local_c_ctype.value_namespace = name_space
                                            self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ceid"):
                                            self.local_ceid = value
                                            self.local_ceid.value_namespace = name_space
                                            self.local_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cv-type"):
                                            self.local_cv_type = value
                                            self.local_cv_type.value_namespace = name_space
                                            self.local_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-group-id"):
                                            self.local_group_id = value
                                            self.local_group_id.value_namespace = name_space
                                            self.local_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-label"):
                                            self.local_label = value
                                            self.local_label.value_namespace = name_space
                                            self.local_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ldp-id"):
                                            self.local_ldp_id = value
                                            self.local_ldp_id.value_namespace = name_space
                                            self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saii-gbl-id"):
                                            self.local_saii_gbl_id = value
                                            self.local_saii_gbl_id.value_namespace = name_space
                                            self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-saiiac-id"):
                                            self.local_saiiac_id = value
                                            self.local_saiiac_id.value_namespace = name_space
                                            self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taii-gbl-id"):
                                            self.local_taii_gbl_id = value
                                            self.local_taii_gbl_id.value_namespace = name_space
                                            self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-taiiac-id"):
                                            self.local_taiiac_id = value
                                            self.local_taiiac_id.value_namespace = name_space
                                            self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-veid"):
                                            self.local_veid = value
                                            self.local_veid.value_namespace = name_space
                                            self.local_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lsd-rewrite-failed"):
                                            self.lsd_rewrite_failed = value
                                            self.lsd_rewrite_failed.value_namespace = name_space
                                            self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii"):
                                            self.rem_saii = value
                                            self.rem_saii.value_namespace = name_space
                                            self.rem_saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saii-gbl-id"):
                                            self.rem_saii_gbl_id = value
                                            self.rem_saii_gbl_id.value_namespace = name_space
                                            self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-saiiac-id"):
                                            self.rem_saiiac_id = value
                                            self.rem_saiiac_id.value_namespace = name_space
                                            self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii"):
                                            self.rem_taii = value
                                            self.rem_taii.value_namespace = name_space
                                            self.rem_taii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taii-gbl-id"):
                                            self.rem_taii_gbl_id = value
                                            self.rem_taii_gbl_id.value_namespace = name_space
                                            self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rem-taiiac-id"):
                                            self.rem_taiiac_id = value
                                            self.rem_taiiac_id.value_namespace = name_space
                                            self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-c-ctype"):
                                            self.remote_c_ctype = value
                                            self.remote_c_ctype.value_namespace = name_space
                                            self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ceid"):
                                            self.remote_ceid = value
                                            self.remote_ceid.value_namespace = name_space
                                            self.remote_ceid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cv-type"):
                                            self.remote_cv_type = value
                                            self.remote_cv_type.value_namespace = name_space
                                            self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-group-id"):
                                            self.remote_group_id = value
                                            self.remote_group_id.value_namespace = name_space
                                            self.remote_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-label"):
                                            self.remote_label = value
                                            self.remote_label.value_namespace = name_space
                                            self.remote_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-ldp-id"):
                                            self.remote_ldp_id = value
                                            self.remote_ldp_id.value_namespace = name_space
                                            self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-source-address"):
                                            self.remote_source_address = value
                                            self.remote_source_address.value_namespace = name_space
                                            self.remote_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-veid"):
                                            self.remote_veid = value
                                            self.remote_veid.value_namespace = name_space
                                            self.remote_veid.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saii"):
                                            self.saii = value
                                            self.saii.value_namespace = name_space
                                            self.saii.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "taii"):
                                            self.taii = value
                                            self.taii.value_namespace = name_space
                                            self.taii.value_namespace_prefix = name_space_prefix


                                class L2Tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"

                                        self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                        self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                        self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                        self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                        self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                        self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                        self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                        self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                        self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                        self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                        self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                        self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                        self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                        self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                        self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                        self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                        self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                        self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                        self.tos = YLeaf(YType.uint8, "tos")

                                        self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                        self.ttl = YLeaf(YType.uint8, "ttl")

                                        self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dont_fragment_bit",
                                                        "ipv4_source_address",
                                                        "ipv6_source_address",
                                                        "l2tp_class_name",
                                                        "local_cookie_high_value",
                                                        "local_cookie_low_value",
                                                        "local_cookie_size",
                                                        "local_secondary_cookie_high_value",
                                                        "local_secondary_cookie_low_value",
                                                        "local_secondary_cookie_size",
                                                        "local_session_id",
                                                        "path_mtu_enabled",
                                                        "path_mtu_max_value",
                                                        "remote_circuit_status_up",
                                                        "remote_cookie_high_value",
                                                        "remote_cookie_low_value",
                                                        "remote_cookie_size",
                                                        "remote_session_id",
                                                        "tos",
                                                        "tos_mode",
                                                        "ttl",
                                                        "tunnel_state") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dont_fragment_bit.is_set or
                                            self.ipv4_source_address.is_set or
                                            self.ipv6_source_address.is_set or
                                            self.l2tp_class_name.is_set or
                                            self.local_cookie_high_value.is_set or
                                            self.local_cookie_low_value.is_set or
                                            self.local_cookie_size.is_set or
                                            self.local_secondary_cookie_high_value.is_set or
                                            self.local_secondary_cookie_low_value.is_set or
                                            self.local_secondary_cookie_size.is_set or
                                            self.local_session_id.is_set or
                                            self.path_mtu_enabled.is_set or
                                            self.path_mtu_max_value.is_set or
                                            self.remote_circuit_status_up.is_set or
                                            self.remote_cookie_high_value.is_set or
                                            self.remote_cookie_low_value.is_set or
                                            self.remote_cookie_size.is_set or
                                            self.remote_session_id.is_set or
                                            self.tos.is_set or
                                            self.tos_mode.is_set or
                                            self.ttl.is_set or
                                            self.tunnel_state.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dont_fragment_bit.yfilter != YFilter.not_set or
                                            self.ipv4_source_address.yfilter != YFilter.not_set or
                                            self.ipv6_source_address.yfilter != YFilter.not_set or
                                            self.l2tp_class_name.yfilter != YFilter.not_set or
                                            self.local_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_cookie_size.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                            self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                            self.local_session_id.yfilter != YFilter.not_set or
                                            self.path_mtu_enabled.yfilter != YFilter.not_set or
                                            self.path_mtu_max_value.yfilter != YFilter.not_set or
                                            self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                            self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                            self.remote_cookie_size.yfilter != YFilter.not_set or
                                            self.remote_session_id.yfilter != YFilter.not_set or
                                            self.tos.yfilter != YFilter.not_set or
                                            self.tos_mode.yfilter != YFilter.not_set or
                                            self.ttl.yfilter != YFilter.not_set or
                                            self.tunnel_state.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2tpv3" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                        if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                        if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                        if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                        if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                        if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                        if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                        if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                        if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                        if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                        if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                        if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                        if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                        if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                        if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                        if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                        if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                        if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos.get_name_leafdata())
                                        if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ttl.get_name_leafdata())
                                        if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dont-fragment-bit"):
                                            self.dont_fragment_bit = value
                                            self.dont_fragment_bit.value_namespace = name_space
                                            self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-source-address"):
                                            self.ipv4_source_address = value
                                            self.ipv4_source_address.value_namespace = name_space
                                            self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-source-address"):
                                            self.ipv6_source_address = value
                                            self.ipv6_source_address.value_namespace = name_space
                                            self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "l2tp-class-name"):
                                            self.l2tp_class_name = value
                                            self.l2tp_class_name.value_namespace = name_space
                                            self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-high-value"):
                                            self.local_cookie_high_value = value
                                            self.local_cookie_high_value.value_namespace = name_space
                                            self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-low-value"):
                                            self.local_cookie_low_value = value
                                            self.local_cookie_low_value.value_namespace = name_space
                                            self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-cookie-size"):
                                            self.local_cookie_size = value
                                            self.local_cookie_size.value_namespace = name_space
                                            self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-high-value"):
                                            self.local_secondary_cookie_high_value = value
                                            self.local_secondary_cookie_high_value.value_namespace = name_space
                                            self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-low-value"):
                                            self.local_secondary_cookie_low_value = value
                                            self.local_secondary_cookie_low_value.value_namespace = name_space
                                            self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-secondary-cookie-size"):
                                            self.local_secondary_cookie_size = value
                                            self.local_secondary_cookie_size.value_namespace = name_space
                                            self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-session-id"):
                                            self.local_session_id = value
                                            self.local_session_id.value_namespace = name_space
                                            self.local_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-enabled"):
                                            self.path_mtu_enabled = value
                                            self.path_mtu_enabled.value_namespace = name_space
                                            self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-mtu-max-value"):
                                            self.path_mtu_max_value = value
                                            self.path_mtu_max_value.value_namespace = name_space
                                            self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-circuit-status-up"):
                                            self.remote_circuit_status_up = value
                                            self.remote_circuit_status_up.value_namespace = name_space
                                            self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-high-value"):
                                            self.remote_cookie_high_value = value
                                            self.remote_cookie_high_value.value_namespace = name_space
                                            self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-low-value"):
                                            self.remote_cookie_low_value = value
                                            self.remote_cookie_low_value.value_namespace = name_space
                                            self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-cookie-size"):
                                            self.remote_cookie_size = value
                                            self.remote_cookie_size.value_namespace = name_space
                                            self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-session-id"):
                                            self.remote_session_id = value
                                            self.remote_session_id.value_namespace = name_space
                                            self.remote_session_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos"):
                                            self.tos = value
                                            self.tos.value_namespace = name_space
                                            self.tos.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tos-mode"):
                                            self.tos_mode = value
                                            self.tos_mode.value_namespace = name_space
                                            self.tos_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ttl"):
                                            self.ttl = value
                                            self.ttl.value_namespace = name_space
                                            self.ttl.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tunnel-state"):
                                            self.tunnel_state = value
                                            self.tunnel_state.value_namespace = name_space
                                            self.tunnel_state.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.encapsulation.is_set or
                                        (self.atom is not None and self.atom.has_data()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation.yfilter != YFilter.not_set or
                                        (self.atom is not None and self.atom.has_operation()) or
                                        (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "encapsulation-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atom"):
                                        if (self.atom is None):
                                            self.atom = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"
                                        return self.atom

                                    if (child_yang_name == "l2tpv3"):
                                        if (self.l2tpv3 is None):
                                            self.l2tpv3 = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                        return self.l2tpv3

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation"):
                                        self.encapsulation = value
                                        self.encapsulation.value_namespace = name_space
                                        self.encapsulation.value_namespace_prefix = name_space_prefix


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudowire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudowire"

                                    self.mtu = YLeaf(YType.uint32, "mtu")

                                    self.name = YLeaf(YType.str, "name")

                                    self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                    self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._children_yang_names.add("parameters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mtu",
                                                    "name",
                                                    "payload_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                        self._children_yang_names.add("atm")

                                        self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                        self._children_yang_names.add("ethernet")

                                        self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                        self._children_yang_names.add("fr")

                                        self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        self._children_yang_names.add("pseudowire-ether")

                                        self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._children_yang_names.add("pseudowire-iw")

                                        self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                        self._children_yang_names.add("tdm")

                                        self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                        self._children_yang_names.add("vlan")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.xconnect_tags.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"

                                            self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                            self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                            self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                            self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                            self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                            self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                            self.vlan_range = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("encapsulation_type",
                                                            "outer_tag",
                                                            "rewrite_tag",
                                                            "simple_efp",
                                                            "vlan_rewrite_tag",
                                                            "xconnect_tags") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"

                                                self.lower = YLeaf(YType.uint16, "lower")

                                                self.upper = YLeaf(YType.uint16, "upper")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("lower",
                                                                "upper") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.lower.is_set or
                                                    self.upper.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.lower.yfilter != YFilter.not_set or
                                                    self.upper.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "vlan-range" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "lower" or name == "upper"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "lower"):
                                                    self.lower = value
                                                    self.lower.value_namespace = name_space
                                                    self.lower.value_namespace_prefix = name_space_prefix
                                                if(value_path == "upper"):
                                                    self.upper = value
                                                    self.upper.value_namespace = name_space
                                                    self.upper.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.vlan_range:
                                                if (c.has_data()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.yfilter != YFilter.not_set):
                                                    return True
                                            return (
                                                self.encapsulation_type.is_set or
                                                self.outer_tag.is_set or
                                                self.simple_efp.is_set or
                                                self.vlan_rewrite_tag.is_set or
                                                self.xconnect_tags.is_set)

                                        def has_operation(self):
                                            for c in self.vlan_range:
                                                if (c.has_operation()):
                                                    return True
                                            for leaf in self.rewrite_tag.getYLeafs():
                                                if (leaf.is_set):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.encapsulation_type.yfilter != YFilter.not_set or
                                                self.outer_tag.yfilter != YFilter.not_set or
                                                self.rewrite_tag.yfilter != YFilter.not_set or
                                                self.simple_efp.yfilter != YFilter.not_set or
                                                self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                                self.xconnect_tags.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                            if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                            if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                            if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                            if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                            leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "vlan-range"):
                                                for c in self.vlan_range:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.vlan_range.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "encapsulation-type"):
                                                self.encapsulation_type = value
                                                self.encapsulation_type.value_namespace = name_space
                                                self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "outer-tag"):
                                                self.outer_tag = value
                                                self.outer_tag.value_namespace = name_space
                                                self.outer_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rewrite-tag"):
                                                self.rewrite_tag.append(value)
                                            if(value_path == "simple-efp"):
                                                self.simple_efp = value
                                                self.simple_efp.value_namespace = name_space
                                                self.simple_efp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vlan-rewrite-tag"):
                                                self.vlan_rewrite_tag = value
                                                self.vlan_rewrite_tag.value_namespace = name_space
                                                self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                            if(value_path == "xconnect-tags"):
                                                self.xconnect_tags = value
                                                self.xconnect_tags.value_namespace = name_space
                                                self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"

                                            self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                            self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                            self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                            self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._children_yang_names.add("tdm-options")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("tdm_mode",
                                                            "timeslot_group",
                                                            "timeslot_rate") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"

                                                self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                                self.cas = YLeaf(YType.uint8, "cas")

                                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                                self.rtp = YLeaf(YType.enumeration, "rtp")

                                                self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                                self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                                self.ssrc = YLeaf(YType.uint32, "ssrc")

                                                self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                                self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("bit_rate",
                                                                "cas",
                                                                "payload_bytes",
                                                                "rtp",
                                                                "rtp_header_payload_type",
                                                                "signalling_packets",
                                                                "ssrc",
                                                                "timestamp_clock_freq",
                                                                "timestamp_mode") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.bit_rate.is_set or
                                                    self.cas.is_set or
                                                    self.payload_bytes.is_set or
                                                    self.rtp.is_set or
                                                    self.rtp_header_payload_type.is_set or
                                                    self.signalling_packets.is_set or
                                                    self.ssrc.is_set or
                                                    self.timestamp_clock_freq.is_set or
                                                    self.timestamp_mode.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.bit_rate.yfilter != YFilter.not_set or
                                                    self.cas.yfilter != YFilter.not_set or
                                                    self.payload_bytes.yfilter != YFilter.not_set or
                                                    self.rtp.yfilter != YFilter.not_set or
                                                    self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                    self.signalling_packets.yfilter != YFilter.not_set or
                                                    self.ssrc.yfilter != YFilter.not_set or
                                                    self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                    self.timestamp_mode.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tdm-options" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                                if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cas.get_name_leafdata())
                                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                                if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp.get_name_leafdata())
                                                if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                                if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                                if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ssrc.get_name_leafdata())
                                                if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                                if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "bit-rate"):
                                                    self.bit_rate = value
                                                    self.bit_rate.value_namespace = name_space
                                                    self.bit_rate.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cas"):
                                                    self.cas = value
                                                    self.cas.value_namespace = name_space
                                                    self.cas.value_namespace_prefix = name_space_prefix
                                                if(value_path == "payload-bytes"):
                                                    self.payload_bytes = value
                                                    self.payload_bytes.value_namespace = name_space
                                                    self.payload_bytes.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp"):
                                                    self.rtp = value
                                                    self.rtp.value_namespace = name_space
                                                    self.rtp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "rtp-header-payload-type"):
                                                    self.rtp_header_payload_type = value
                                                    self.rtp_header_payload_type.value_namespace = name_space
                                                    self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "signalling-packets"):
                                                    self.signalling_packets = value
                                                    self.signalling_packets.value_namespace = name_space
                                                    self.signalling_packets.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ssrc"):
                                                    self.ssrc = value
                                                    self.ssrc.value_namespace = name_space
                                                    self.ssrc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-clock-freq"):
                                                    self.timestamp_clock_freq = value
                                                    self.timestamp_clock_freq.value_namespace = name_space
                                                    self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp-mode"):
                                                    self.timestamp_mode = value
                                                    self.timestamp_mode.value_namespace = name_space
                                                    self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.tdm_mode.is_set or
                                                self.timeslot_group.is_set or
                                                self.timeslot_rate.is_set or
                                                (self.tdm_options is not None and self.tdm_options.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.tdm_mode.yfilter != YFilter.not_set or
                                                self.timeslot_group.yfilter != YFilter.not_set or
                                                self.timeslot_rate.yfilter != YFilter.not_set or
                                                (self.tdm_options is not None and self.tdm_options.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                            if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                            if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tdm-options"):
                                                if (self.tdm_options is None):
                                                    self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                return self.tdm_options

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "tdm-mode"):
                                                self.tdm_mode = value
                                                self.tdm_mode.value_namespace = name_space
                                                self.tdm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-group"):
                                                self.timeslot_group = value
                                                self.timeslot_group.value_namespace = name_space
                                                self.timeslot_group.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timeslot-rate"):
                                                self.timeslot_rate = value
                                                self.timeslot_rate.value_namespace = name_space
                                                self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"

                                            self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                            self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                            self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                            self.vci = YLeaf(YType.uint16, "vci")

                                            self.vpi = YLeaf(YType.uint16, "vpi")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("atm_mode",
                                                            "maximum_number_cells_packed",
                                                            "maximum_number_cells_un_packed",
                                                            "vci",
                                                            "vpi") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.atm_mode.is_set or
                                                self.maximum_number_cells_packed.is_set or
                                                self.maximum_number_cells_un_packed.is_set or
                                                self.vci.is_set or
                                                self.vpi.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.atm_mode.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                                self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                                self.vci.yfilter != YFilter.not_set or
                                                self.vpi.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "atm" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                            if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                            if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                            if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vci.get_name_leafdata())
                                            if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpi.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "atm-mode"):
                                                self.atm_mode = value
                                                self.atm_mode.value_namespace = name_space
                                                self.atm_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-packed"):
                                                self.maximum_number_cells_packed = value
                                                self.maximum_number_cells_packed.value_namespace = name_space
                                                self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "maximum-number-cells-un-packed"):
                                                self.maximum_number_cells_un_packed = value
                                                self.maximum_number_cells_un_packed.value_namespace = name_space
                                                self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vci"):
                                                self.vci = value
                                                self.vci.value_namespace = name_space
                                                self.vci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpi"):
                                                self.vpi = value
                                                self.vpi.value_namespace = name_space
                                                self.vpi.value_namespace_prefix = name_space_prefix


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"

                                            self.dlci = YLeaf(YType.uint32, "dlci")

                                            self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("dlci",
                                                            "fr_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.dlci.is_set or
                                                self.fr_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.dlci.yfilter != YFilter.not_set or
                                                self.fr_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.dlci.get_name_leafdata())
                                            if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dlci" or name == "fr-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "dlci"):
                                                self.dlci = value
                                                self.dlci.value_namespace = name_space
                                                self.dlci.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fr-mode"):
                                                self.fr_mode = value
                                                self.fr_mode.value_namespace = name_space
                                                self.fr_mode.value_namespace_prefix = name_space_prefix


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-ether" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"

                                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                                            self.is_valid = YLeaf(YType.boolean, "is-valid")

                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._children_yang_names.add("interface-list")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("internal_label",
                                                            "is_valid") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"

                                                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                                self.interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_list_id",
                                                                "interface_list_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name",
                                                                    "replicate_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.interface_name.is_set or
                                                        self.replicate_status.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set or
                                                        self.replicate_status.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "interface" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                    if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name" or name == "replicate-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "replicate-status"):
                                                        self.replicate_status = value
                                                        self.replicate_status.value_namespace = name_space
                                                        self.replicate_status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.interface:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.interface_list_id.is_set or
                                                    self.interface_list_name.is_set)

                                            def has_operation(self):
                                                for c in self.interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_list_id.yfilter != YFilter.not_set or
                                                    self.interface_list_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface-list" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "interface"):
                                                    for c in self.interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-list-id"):
                                                    self.interface_list_id = value
                                                    self.interface_list_id.value_namespace = name_space
                                                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "interface-list-name"):
                                                    self.interface_list_name = value
                                                    self.interface_list_name.value_namespace = name_space
                                                    self.interface_list_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.internal_label.is_set or
                                                self.is_valid.is_set or
                                                (self.interface_list is not None and self.interface_list.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.internal_label.yfilter != YFilter.not_set or
                                                self.is_valid.yfilter != YFilter.not_set or
                                                (self.interface_list is not None and self.interface_list.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "pseudowire-iw" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                                            if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_valid.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface-list"):
                                                if (self.interface_list is None):
                                                    self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                return self.interface_list

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "internal-label"):
                                                self.internal_label = value
                                                self.internal_label.value_namespace = name_space
                                                self.internal_label.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-valid"):
                                                self.is_valid = value
                                                self.is_valid.value_namespace = name_space
                                                self.is_valid.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.type.is_set or
                                            (self.atm is not None and self.atm.has_data()) or
                                            (self.ethernet is not None and self.ethernet.has_data()) or
                                            (self.fr is not None and self.fr.has_data()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                            (self.tdm is not None and self.tdm.has_data()) or
                                            (self.vlan is not None and self.vlan.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            (self.atm is not None and self.atm.has_operation()) or
                                            (self.ethernet is not None and self.ethernet.has_operation()) or
                                            (self.fr is not None and self.fr.has_operation()) or
                                            (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                            (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                            (self.tdm is not None and self.tdm.has_operation()) or
                                            (self.vlan is not None and self.vlan.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "parameters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "atm"):
                                            if (self.atm is None):
                                                self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"
                                            return self.atm

                                        if (child_yang_name == "ethernet"):
                                            if (self.ethernet is None):
                                                self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"
                                            return self.ethernet

                                        if (child_yang_name == "fr"):
                                            if (self.fr is None):
                                                self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"
                                            return self.fr

                                        if (child_yang_name == "pseudowire-ether"):
                                            if (self.pseudowire_ether is None):
                                                self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                            return self.pseudowire_ether

                                        if (child_yang_name == "pseudowire-iw"):
                                            if (self.pseudowire_iw is None):
                                                self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            return self.pseudowire_iw

                                        if (child_yang_name == "tdm"):
                                            if (self.tdm is None):
                                                self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"
                                            return self.tdm

                                        if (child_yang_name == "vlan"):
                                            if (self.vlan is None):
                                                self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"
                                            return self.vlan

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mtu.is_set or
                                        self.name.is_set or
                                        self.payload_bytes.is_set or
                                        (self.parameters is not None and self.parameters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mtu.yfilter != YFilter.not_set or
                                        self.name.yfilter != YFilter.not_set or
                                        self.payload_bytes.yfilter != YFilter.not_set or
                                        (self.parameters is not None and self.parameters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu.get_name_leafdata())
                                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.name.get_name_leafdata())
                                    if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "parameters"):
                                        if (self.parameters is None):
                                            self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                        return self.parameters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mtu"):
                                        self.mtu = value
                                        self.mtu.value_namespace = name_space
                                        self.mtu.value_namespace_prefix = name_space_prefix
                                    if(value_path == "name"):
                                        self.name = value
                                        self.name.value_namespace = name_space
                                        self.name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "payload-bytes"):
                                        self.payload_bytes = value
                                        self.payload_bytes.value_namespace = name_space
                                        self.payload_bytes.value_namespace_prefix = name_space_prefix


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudowire"

                                    self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                    self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                    self.option = YLeaf(YType.enumeration, "option")

                                    self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                    self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ip_tunnel_interface_number",
                                                    "next_hop_ip",
                                                    "option",
                                                    "te_tunnel_interface_number",
                                                    "tp_tunnel_interface_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ip_tunnel_interface_number.is_set or
                                        self.next_hop_ip.is_set or
                                        self.option.is_set or
                                        self.te_tunnel_interface_number.is_set or
                                        self.tp_tunnel_interface_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set or
                                        self.option.yfilter != YFilter.not_set or
                                        self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                        self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "preferred-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                    if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.option.get_name_leafdata())
                                    if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                    if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ip-tunnel-interface-number"):
                                        self.ip_tunnel_interface_number = value
                                        self.ip_tunnel_interface_number.value_namespace = name_space
                                        self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                    if(value_path == "option"):
                                        self.option = value
                                        self.option.value_namespace = name_space
                                        self.option.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-tunnel-interface-number"):
                                        self.te_tunnel_interface_number = value
                                        self.te_tunnel_interface_number.value_namespace = name_space
                                        self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tp-tunnel-interface-number"):
                                        self.tp_tunnel_interface_number = value
                                        self.tp_tunnel_interface_number.value_namespace = name_space
                                        self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudowire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudowire"

                                    self.pw_status = YLeaf(YType.uint32, "pw-status")

                                    self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                    self._children_yang_names.add("status-tlv")

                                    self.tlv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pw_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status-tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"

                                        self.description = YLeaf(YType.str, "description")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.pw_id = YLeaf(YType.uint32, "pw-id")

                                        self.remote_address = YLeaf(YType.str, "remote-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("description",
                                                        "local_address",
                                                        "pw_id",
                                                        "remote_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.description.is_set or
                                            self.local_address.is_set or
                                            self.pw_id.is_set or
                                            self.remote_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.description.yfilter != YFilter.not_set or
                                            self.local_address.yfilter != YFilter.not_set or
                                            self.pw_id.yfilter != YFilter.not_set or
                                            self.remote_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tlv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.description.get_name_leafdata())
                                        if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_address.get_name_leafdata())
                                        if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pw_id.get_name_leafdata())
                                        if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.remote_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "description"):
                                            self.description = value
                                            self.description.value_namespace = name_space
                                            self.description.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-address"):
                                            self.local_address = value
                                            self.local_address.value_namespace = name_space
                                            self.local_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pw-id"):
                                            self.pw_id = value
                                            self.pw_id.value_namespace = name_space
                                            self.pw_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "remote-address"):
                                            self.remote_address = value
                                            self.remote_address.value_namespace = name_space
                                            self.remote_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tlv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.pw_status.is_set or
                                        (self.status_tlv is not None and self.status_tlv.has_data()))

                                def has_operation(self):
                                    for c in self.tlv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pw_status.yfilter != YFilter.not_set or
                                        (self.status_tlv is not None and self.status_tlv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-signalling" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status-tlv"):
                                        if (self.status_tlv is None):
                                            self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"
                                        return self.status_tlv

                                    if (child_yang_name == "tlv"):
                                        for c in self.tlv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tlv.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pw-status"):
                                        self.pw_status = value
                                        self.pw_status.value_namespace = name_space
                                        self.pw_status.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudowire"

                                    self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class P2MpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudowire"

                                    self.local_available = YLeaf(YType.boolean, "local-available")

                                    self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                    self.local_flags = YLeaf(YType.uint8, "local-flags")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                    self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                    self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                    self.remote_available = YLeaf(YType.boolean, "remote-available")

                                    self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                    self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                    self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                    self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_available",
                                                    "local_extended_tunnel_id",
                                                    "local_flags",
                                                    "local_label",
                                                    "local_p2mp_id",
                                                    "local_ptree_type",
                                                    "local_tunnel_id",
                                                    "remote_available",
                                                    "remote_extended_tunnel_id",
                                                    "remote_flags",
                                                    "remote_label",
                                                    "remote_p2mp_id",
                                                    "remote_ptree_type",
                                                    "remote_tunnel_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_available.is_set or
                                        self.local_extended_tunnel_id.is_set or
                                        self.local_flags.is_set or
                                        self.local_label.is_set or
                                        self.local_p2mp_id.is_set or
                                        self.local_ptree_type.is_set or
                                        self.local_tunnel_id.is_set or
                                        self.remote_available.is_set or
                                        self.remote_extended_tunnel_id.is_set or
                                        self.remote_flags.is_set or
                                        self.remote_label.is_set or
                                        self.remote_p2mp_id.is_set or
                                        self.remote_ptree_type.is_set or
                                        self.remote_tunnel_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_available.yfilter != YFilter.not_set or
                                        self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.local_flags.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_p2mp_id.yfilter != YFilter.not_set or
                                        self.local_ptree_type.yfilter != YFilter.not_set or
                                        self.local_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_available.yfilter != YFilter.not_set or
                                        self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                        self.remote_flags.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_p2mp_id.yfilter != YFilter.not_set or
                                        self.remote_ptree_type.yfilter != YFilter.not_set or
                                        self.remote_tunnel_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2mp-pw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_available.get_name_leafdata())
                                    if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                    if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_flags.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                    if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                    if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                    if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_available.get_name_leafdata())
                                    if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                    if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                    if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                    if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-available"):
                                        self.local_available = value
                                        self.local_available.value_namespace = name_space
                                        self.local_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-extended-tunnel-id"):
                                        self.local_extended_tunnel_id = value
                                        self.local_extended_tunnel_id.value_namespace = name_space
                                        self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-flags"):
                                        self.local_flags = value
                                        self.local_flags.value_namespace = name_space
                                        self.local_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-p2mp-id"):
                                        self.local_p2mp_id = value
                                        self.local_p2mp_id.value_namespace = name_space
                                        self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ptree-type"):
                                        self.local_ptree_type = value
                                        self.local_ptree_type.value_namespace = name_space
                                        self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-tunnel-id"):
                                        self.local_tunnel_id = value
                                        self.local_tunnel_id.value_namespace = name_space
                                        self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-available"):
                                        self.remote_available = value
                                        self.remote_available.value_namespace = name_space
                                        self.remote_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-extended-tunnel-id"):
                                        self.remote_extended_tunnel_id = value
                                        self.remote_extended_tunnel_id.value_namespace = name_space
                                        self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-flags"):
                                        self.remote_flags = value
                                        self.remote_flags.value_namespace = name_space
                                        self.remote_flags.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-p2mp-id"):
                                        self.remote_p2mp_id = value
                                        self.remote_p2mp_id.value_namespace = name_space
                                        self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ptree-type"):
                                        self.remote_ptree_type = value
                                        self.remote_ptree_type.value_namespace = name_space
                                        self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-tunnel-id"):
                                        self.remote_tunnel_id = value
                                        self.remote_tunnel_id.value_namespace = name_space
                                        self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ad_method.is_set or
                                    self.ad_remote_down.is_set or
                                    self.admited_bw.is_set or
                                    self.auto_discovery.is_set or
                                    self.backup_active.is_set or
                                    self.backup_force_active.is_set or
                                    self.backup_pw.is_set or
                                    self.bitrate_mismatched.is_set or
                                    self.bridge_pw_type_mismatch.is_set or
                                    self.cas_mismatched.is_set or
                                    self.diff_ts_mismatched.is_set or
                                    self.disable_delay.is_set or
                                    self.disable_never.is_set or
                                    self.evpn_src_acid.is_set or
                                    self.fe_ctype.is_set or
                                    self.forward_class.is_set or
                                    self.freq_mismatched.is_set or
                                    self.illegal_control_word.is_set or
                                    self.imposed_vlan_id.is_set or
                                    self.interworking.is_set or
                                    self.ipv6_local_source_address.is_set or
                                    self.is_evpnvpws_type.is_set or
                                    self.is_flow_label_static.is_set or
                                    self.is_multi_segment_pseudowire.is_set or
                                    self.is_partially_programmed.is_set or
                                    self.is_pwr_type.is_set or
                                    self.is_vfi.is_set or
                                    self.last_time_status_changed.is_set or
                                    self.last_time_status_down.is_set or
                                    self.ldp_label_advertise_failed.is_set or
                                    self.load_balance.is_set or
                                    self.local_control_word.is_set or
                                    self.local_label_failed.is_set or
                                    self.local_pseudo_wire_type.is_set or
                                    self.local_source_address.is_set or
                                    self.mac_limit_oper_down.is_set or
                                    self.mtu_mismatched.is_set or
                                    self.not_supported_qinq.is_set or
                                    self.num_ma_cwithdraw_msg_received.is_set or
                                    self.number_ma_cwithdraw_message_sent.is_set or
                                    self.out_of_memory_state.is_set or
                                    self.payload_bytes_mismatched.is_set or
                                    self.payload_type_mismatched.is_set or
                                    self.preferred_path_disable_fallback.is_set or
                                    self.primary_peer_id.is_set or
                                    self.primary_pseudo_wire_id.is_set or
                                    self.primary_pw.is_set or
                                    self.protocol.is_set or
                                    self.pseudo_wire_id.is_set or
                                    self.pseudo_wire_state.is_set or
                                    self.pseudo_wire_type_mismatched.is_set or
                                    self.pw_class_name.is_set or
                                    self.pw_flow_label_code17_disabled.is_set or
                                    self.pw_flow_label_type.is_set or
                                    self.pw_flow_label_type_cfg.is_set or
                                    self.pw_redundancy_initial_delay.is_set or
                                    self.pw_redundancy_one_way.is_set or
                                    self.pw_status_use.is_set or
                                    self.pwlsd_rewrite_failed.is_set or
                                    self.remote_control_word.is_set or
                                    self.remote_label_failed.is_set or
                                    self.remote_pseudo_wire_type.is_set or
                                    self.required_bw.is_set or
                                    self.resync_enabled.is_set or
                                    self.resync_threshold.is_set or
                                    self.rtp_mismatched.is_set or
                                    self.sequencing_type.is_set or
                                    self.shutdown.is_set or
                                    self.sig_pkts_mismatched.is_set or
                                    self.ssrc_mismatched.is_set or
                                    self.state.is_set or
                                    self.table_policy_name.is_set or
                                    self.tag_rewrite.is_set or
                                    self.time_created.is_set or
                                    self.time_elapsed_creation.is_set or
                                    self.time_elapsed_status_changed.is_set or
                                    self.time_elapsed_status_down.is_set or
                                    self.transport_lsp_down.is_set or
                                    self.xconnect_id.is_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                    (self.local_interface is not None and self.local_interface.has_data()) or
                                    (self.local_signalling is not None and self.local_signalling.has_data()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                    (self.peer_id is not None and self.peer_id.has_data()) or
                                    (self.preferred_path is not None and self.preferred_path.has_data()) or
                                    (self.remote_interface is not None and self.remote_interface.has_data()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ad_method.yfilter != YFilter.not_set or
                                    self.ad_remote_down.yfilter != YFilter.not_set or
                                    self.admited_bw.yfilter != YFilter.not_set or
                                    self.auto_discovery.yfilter != YFilter.not_set or
                                    self.backup_active.yfilter != YFilter.not_set or
                                    self.backup_force_active.yfilter != YFilter.not_set or
                                    self.backup_pw.yfilter != YFilter.not_set or
                                    self.bitrate_mismatched.yfilter != YFilter.not_set or
                                    self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                    self.cas_mismatched.yfilter != YFilter.not_set or
                                    self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                    self.disable_delay.yfilter != YFilter.not_set or
                                    self.disable_never.yfilter != YFilter.not_set or
                                    self.evpn_src_acid.yfilter != YFilter.not_set or
                                    self.fe_ctype.yfilter != YFilter.not_set or
                                    self.forward_class.yfilter != YFilter.not_set or
                                    self.freq_mismatched.yfilter != YFilter.not_set or
                                    self.illegal_control_word.yfilter != YFilter.not_set or
                                    self.imposed_vlan_id.yfilter != YFilter.not_set or
                                    self.interworking.yfilter != YFilter.not_set or
                                    self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                    self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                    self.is_flow_label_static.yfilter != YFilter.not_set or
                                    self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                    self.is_partially_programmed.yfilter != YFilter.not_set or
                                    self.is_pwr_type.yfilter != YFilter.not_set or
                                    self.is_vfi.yfilter != YFilter.not_set or
                                    self.last_time_status_changed.yfilter != YFilter.not_set or
                                    self.last_time_status_down.yfilter != YFilter.not_set or
                                    self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                    self.load_balance.yfilter != YFilter.not_set or
                                    self.local_control_word.yfilter != YFilter.not_set or
                                    self.local_label_failed.yfilter != YFilter.not_set or
                                    self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.local_source_address.yfilter != YFilter.not_set or
                                    self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                    self.mtu_mismatched.yfilter != YFilter.not_set or
                                    self.not_supported_qinq.yfilter != YFilter.not_set or
                                    self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                    self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                    self.out_of_memory_state.yfilter != YFilter.not_set or
                                    self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                    self.payload_type_mismatched.yfilter != YFilter.not_set or
                                    self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                    self.primary_peer_id.yfilter != YFilter.not_set or
                                    self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.primary_pw.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    self.pseudo_wire_id.yfilter != YFilter.not_set or
                                    self.pseudo_wire_state.yfilter != YFilter.not_set or
                                    self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                    self.pw_class_name.yfilter != YFilter.not_set or
                                    self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type.yfilter != YFilter.not_set or
                                    self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                    self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                    self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                    self.pw_status_use.yfilter != YFilter.not_set or
                                    self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.remote_control_word.yfilter != YFilter.not_set or
                                    self.remote_label_failed.yfilter != YFilter.not_set or
                                    self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                    self.required_bw.yfilter != YFilter.not_set or
                                    self.resync_enabled.yfilter != YFilter.not_set or
                                    self.resync_threshold.yfilter != YFilter.not_set or
                                    self.rtp_mismatched.yfilter != YFilter.not_set or
                                    self.sequencing_type.yfilter != YFilter.not_set or
                                    self.shutdown.yfilter != YFilter.not_set or
                                    self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                    self.ssrc_mismatched.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.table_policy_name.yfilter != YFilter.not_set or
                                    self.tag_rewrite.yfilter != YFilter.not_set or
                                    self.time_created.yfilter != YFilter.not_set or
                                    self.time_elapsed_creation.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                    self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                    self.transport_lsp_down.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                    (self.local_interface is not None and self.local_interface.has_operation()) or
                                    (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                    (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                    (self.peer_id is not None and self.peer_id.has_operation()) or
                                    (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                    (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                    (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pseudowire" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_method.get_name_leafdata())
                                if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                                if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admited_bw.get_name_leafdata())
                                if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                                if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_active.get_name_leafdata())
                                if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                                if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backup_pw.get_name_leafdata())
                                if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                                if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                                if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                                if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                                if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_delay.get_name_leafdata())
                                if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.disable_never.get_name_leafdata())
                                if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                                if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                                if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forward_class.get_name_leafdata())
                                if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                                if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                                if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                                if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interworking.get_name_leafdata())
                                if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                                if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                                if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                                if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                                if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                                if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                                if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_vfi.get_name_leafdata())
                                if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                                if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                                if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                                if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance.get_name_leafdata())
                                if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_control_word.get_name_leafdata())
                                if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                                if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                                if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_source_address.get_name_leafdata())
                                if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                                if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                                if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                                if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                                if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                                if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                                if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                                if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                                if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                                if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                                if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                                if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_pw.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())
                                if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                                if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                                if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                                if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                                if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                                if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                                if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                                if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                                if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                                if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                                if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                                if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                                if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                                if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                                if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.required_bw.get_name_leafdata())
                                if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                                if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                                if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                                if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                                if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shutdown.get_name_leafdata())
                                if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                                if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                                if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                                if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_created.get_name_leafdata())
                                if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                                if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                                if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                                if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "encapsulation-info"):
                                    if (self.encapsulation_info is None):
                                        self.encapsulation_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                    return self.encapsulation_info

                                if (child_yang_name == "local-interface"):
                                    if (self.local_interface is None):
                                        self.local_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"
                                    return self.local_interface

                                if (child_yang_name == "local-signalling"):
                                    if (self.local_signalling is None):
                                        self.local_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"
                                    return self.local_signalling

                                if (child_yang_name == "p2mp-pw"):
                                    if (self.p2mp_pw is None):
                                        self.p2mp_pw = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    return self.p2mp_pw

                                if (child_yang_name == "peer-id"):
                                    if (self.peer_id is None):
                                        self.peer_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"
                                    return self.peer_id

                                if (child_yang_name == "preferred-path"):
                                    if (self.preferred_path is None):
                                        self.preferred_path = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"
                                    return self.preferred_path

                                if (child_yang_name == "remote-interface"):
                                    if (self.remote_interface is None):
                                        self.remote_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"
                                    return self.remote_interface

                                if (child_yang_name == "remote-signalling"):
                                    if (self.remote_signalling is None):
                                        self.remote_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"
                                    return self.remote_signalling

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ad-method"):
                                    self.ad_method = value
                                    self.ad_method.value_namespace = name_space
                                    self.ad_method.value_namespace_prefix = name_space_prefix
                                if(value_path == "ad-remote-down"):
                                    self.ad_remote_down = value
                                    self.ad_remote_down.value_namespace = name_space
                                    self.ad_remote_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "admited-bw"):
                                    self.admited_bw = value
                                    self.admited_bw.value_namespace = name_space
                                    self.admited_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "auto-discovery"):
                                    self.auto_discovery = value
                                    self.auto_discovery.value_namespace = name_space
                                    self.auto_discovery.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-active"):
                                    self.backup_active = value
                                    self.backup_active.value_namespace = name_space
                                    self.backup_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-force-active"):
                                    self.backup_force_active = value
                                    self.backup_force_active.value_namespace = name_space
                                    self.backup_force_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "backup-pw"):
                                    self.backup_pw = value
                                    self.backup_pw.value_namespace = name_space
                                    self.backup_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "bitrate-mismatched"):
                                    self.bitrate_mismatched = value
                                    self.bitrate_mismatched.value_namespace = name_space
                                    self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "bridge-pw-type-mismatch"):
                                    self.bridge_pw_type_mismatch = value
                                    self.bridge_pw_type_mismatch.value_namespace = name_space
                                    self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                                if(value_path == "cas-mismatched"):
                                    self.cas_mismatched = value
                                    self.cas_mismatched.value_namespace = name_space
                                    self.cas_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "diff-ts-mismatched"):
                                    self.diff_ts_mismatched = value
                                    self.diff_ts_mismatched.value_namespace = name_space
                                    self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-delay"):
                                    self.disable_delay = value
                                    self.disable_delay.value_namespace = name_space
                                    self.disable_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "disable-never"):
                                    self.disable_never = value
                                    self.disable_never.value_namespace = name_space
                                    self.disable_never.value_namespace_prefix = name_space_prefix
                                if(value_path == "evpn-src-acid"):
                                    self.evpn_src_acid = value
                                    self.evpn_src_acid.value_namespace = name_space
                                    self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                                if(value_path == "fe-ctype"):
                                    self.fe_ctype = value
                                    self.fe_ctype.value_namespace = name_space
                                    self.fe_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "forward-class"):
                                    self.forward_class = value
                                    self.forward_class.value_namespace = name_space
                                    self.forward_class.value_namespace_prefix = name_space_prefix
                                if(value_path == "freq-mismatched"):
                                    self.freq_mismatched = value
                                    self.freq_mismatched.value_namespace = name_space
                                    self.freq_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-control-word"):
                                    self.illegal_control_word = value
                                    self.illegal_control_word.value_namespace = name_space
                                    self.illegal_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "imposed-vlan-id"):
                                    self.imposed_vlan_id = value
                                    self.imposed_vlan_id.value_namespace = name_space
                                    self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interworking"):
                                    self.interworking = value
                                    self.interworking.value_namespace = name_space
                                    self.interworking.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-local-source-address"):
                                    self.ipv6_local_source_address = value
                                    self.ipv6_local_source_address.value_namespace = name_space
                                    self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-evpnvpws-type"):
                                    self.is_evpnvpws_type = value
                                    self.is_evpnvpws_type.value_namespace = name_space
                                    self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-flow-label-static"):
                                    self.is_flow_label_static = value
                                    self.is_flow_label_static.value_namespace = name_space
                                    self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-multi-segment-pseudowire"):
                                    self.is_multi_segment_pseudowire = value
                                    self.is_multi_segment_pseudowire.value_namespace = name_space
                                    self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-partially-programmed"):
                                    self.is_partially_programmed = value
                                    self.is_partially_programmed.value_namespace = name_space
                                    self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-pwr-type"):
                                    self.is_pwr_type = value
                                    self.is_pwr_type.value_namespace = name_space
                                    self.is_pwr_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-vfi"):
                                    self.is_vfi = value
                                    self.is_vfi.value_namespace = name_space
                                    self.is_vfi.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-changed"):
                                    self.last_time_status_changed = value
                                    self.last_time_status_changed.value_namespace = name_space
                                    self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-time-status-down"):
                                    self.last_time_status_down = value
                                    self.last_time_status_down.value_namespace = name_space
                                    self.last_time_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertise-failed"):
                                    self.ldp_label_advertise_failed = value
                                    self.ldp_label_advertise_failed.value_namespace = name_space
                                    self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance"):
                                    self.load_balance = value
                                    self.load_balance.value_namespace = name_space
                                    self.load_balance.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-control-word"):
                                    self.local_control_word = value
                                    self.local_control_word.value_namespace = name_space
                                    self.local_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label-failed"):
                                    self.local_label_failed = value
                                    self.local_label_failed.value_namespace = name_space
                                    self.local_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-pseudo-wire-type"):
                                    self.local_pseudo_wire_type = value
                                    self.local_pseudo_wire_type.value_namespace = name_space
                                    self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-source-address"):
                                    self.local_source_address = value
                                    self.local_source_address.value_namespace = name_space
                                    self.local_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-oper-down"):
                                    self.mac_limit_oper_down = value
                                    self.mac_limit_oper_down.value_namespace = name_space
                                    self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-mismatched"):
                                    self.mtu_mismatched = value
                                    self.mtu_mismatched.value_namespace = name_space
                                    self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-supported-qinq"):
                                    self.not_supported_qinq = value
                                    self.not_supported_qinq.value_namespace = name_space
                                    self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                                if(value_path == "num-ma-cwithdraw-msg-received"):
                                    self.num_ma_cwithdraw_msg_received = value
                                    self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                    self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "number-ma-cwithdraw-message-sent"):
                                    self.number_ma_cwithdraw_message_sent = value
                                    self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                    self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                                if(value_path == "out-of-memory-state"):
                                    self.out_of_memory_state = value
                                    self.out_of_memory_state.value_namespace = name_space
                                    self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes-mismatched"):
                                    self.payload_bytes_mismatched = value
                                    self.payload_bytes_mismatched.value_namespace = name_space
                                    self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-type-mismatched"):
                                    self.payload_type_mismatched = value
                                    self.payload_type_mismatched.value_namespace = name_space
                                    self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "preferred-path-disable-fallback"):
                                    self.preferred_path_disable_fallback = value
                                    self.preferred_path_disable_fallback.value_namespace = name_space
                                    self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-peer-id"):
                                    self.primary_peer_id = value
                                    self.primary_peer_id.value_namespace = name_space
                                    self.primary_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pseudo-wire-id"):
                                    self.primary_pseudo_wire_id = value
                                    self.primary_pseudo_wire_id.value_namespace = name_space
                                    self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-pw"):
                                    self.primary_pw = value
                                    self.primary_pw.value_namespace = name_space
                                    self.primary_pw.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-id"):
                                    self.pseudo_wire_id = value
                                    self.pseudo_wire_id.value_namespace = name_space
                                    self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-state"):
                                    self.pseudo_wire_state = value
                                    self.pseudo_wire_state.value_namespace = name_space
                                    self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-wire-type-mismatched"):
                                    self.pseudo_wire_type_mismatched = value
                                    self.pseudo_wire_type_mismatched.value_namespace = name_space
                                    self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-class-name"):
                                    self.pw_class_name = value
                                    self.pw_class_name.value_namespace = name_space
                                    self.pw_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-code17-disabled"):
                                    self.pw_flow_label_code17_disabled = value
                                    self.pw_flow_label_code17_disabled.value_namespace = name_space
                                    self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type"):
                                    self.pw_flow_label_type = value
                                    self.pw_flow_label_type.value_namespace = name_space
                                    self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-flow-label-type-cfg"):
                                    self.pw_flow_label_type_cfg = value
                                    self.pw_flow_label_type_cfg.value_namespace = name_space
                                    self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-initial-delay"):
                                    self.pw_redundancy_initial_delay = value
                                    self.pw_redundancy_initial_delay.value_namespace = name_space
                                    self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-redundancy-one-way"):
                                    self.pw_redundancy_one_way = value
                                    self.pw_redundancy_one_way.value_namespace = name_space
                                    self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-status-use"):
                                    self.pw_status_use = value
                                    self.pw_status_use.value_namespace = name_space
                                    self.pw_status_use.value_namespace_prefix = name_space_prefix
                                if(value_path == "pwlsd-rewrite-failed"):
                                    self.pwlsd_rewrite_failed = value
                                    self.pwlsd_rewrite_failed.value_namespace = name_space
                                    self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-control-word"):
                                    self.remote_control_word = value
                                    self.remote_control_word.value_namespace = name_space
                                    self.remote_control_word.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label-failed"):
                                    self.remote_label_failed = value
                                    self.remote_label_failed.value_namespace = name_space
                                    self.remote_label_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-pseudo-wire-type"):
                                    self.remote_pseudo_wire_type = value
                                    self.remote_pseudo_wire_type.value_namespace = name_space
                                    self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "required-bw"):
                                    self.required_bw = value
                                    self.required_bw.value_namespace = name_space
                                    self.required_bw.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-enabled"):
                                    self.resync_enabled = value
                                    self.resync_enabled.value_namespace = name_space
                                    self.resync_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "resync-threshold"):
                                    self.resync_threshold = value
                                    self.resync_threshold.value_namespace = name_space
                                    self.resync_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "rtp-mismatched"):
                                    self.rtp_mismatched = value
                                    self.rtp_mismatched.value_namespace = name_space
                                    self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequencing-type"):
                                    self.sequencing_type = value
                                    self.sequencing_type.value_namespace = name_space
                                    self.sequencing_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "shutdown"):
                                    self.shutdown = value
                                    self.shutdown.value_namespace = name_space
                                    self.shutdown.value_namespace_prefix = name_space_prefix
                                if(value_path == "sig-pkts-mismatched"):
                                    self.sig_pkts_mismatched = value
                                    self.sig_pkts_mismatched.value_namespace = name_space
                                    self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "ssrc-mismatched"):
                                    self.ssrc_mismatched = value
                                    self.ssrc_mismatched.value_namespace = name_space
                                    self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-policy-name"):
                                    self.table_policy_name = value
                                    self.table_policy_name.value_namespace = name_space
                                    self.table_policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag-rewrite"):
                                    self.tag_rewrite = value
                                    self.tag_rewrite.value_namespace = name_space
                                    self.tag_rewrite.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-created"):
                                    self.time_created = value
                                    self.time_created.value_namespace = name_space
                                    self.time_created.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-creation"):
                                    self.time_elapsed_creation = value
                                    self.time_elapsed_creation.value_namespace = name_space
                                    self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-changed"):
                                    self.time_elapsed_status_changed = value
                                    self.time_elapsed_status_changed.value_namespace = name_space
                                    self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-elapsed-status-down"):
                                    self.time_elapsed_status_down = value
                                    self.time_elapsed_status_down.value_namespace = name_space
                                    self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-lsp-down"):
                                    self.transport_lsp_down = value
                                    self.transport_lsp_down.value_namespace = name_space
                                    self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-pw"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dhcpv4_trust",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                    self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                    self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                    self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                    self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                    self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                    self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                    self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                    self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                    self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                    self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                    self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                    self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                    self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                    self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                    self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                    self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                    self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                    self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                    self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                    self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                    self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                    self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                    self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                    self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                    self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                    self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                    self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                    self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                    self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dai_address_validation_mask",
                                                    "dhcpv4_profile_name",
                                                    "dhcpv4_snoop",
                                                    "flood_unknown_unicast_enabled",
                                                    "flood_uu_disabled_mac_limit_action",
                                                    "igm_pv4_disabled",
                                                    "igm_pv4_profile_name",
                                                    "is_dai_addr_validate_destination_mac_enabled",
                                                    "is_dai_addr_validate_ipv4_enabled",
                                                    "is_dai_addr_validate_source_mac_enabled",
                                                    "is_dai_enabled",
                                                    "is_dai_logging_enabled",
                                                    "is_ip_source_guard_enabled",
                                                    "is_ipsg_logging_enabled",
                                                    "is_mac_secure_accept_shutdown_enabled",
                                                    "is_mac_secure_enabled",
                                                    "is_mac_secure_logging_enabled",
                                                    "learn_disabled_mac_limit_action",
                                                    "mac_aging_mode",
                                                    "mac_aging_time",
                                                    "mac_flooding",
                                                    "mac_learning",
                                                    "mac_limit",
                                                    "mac_limit_action",
                                                    "mac_limit_notification",
                                                    "mac_limit_reached",
                                                    "mac_port_down_flush_enabled",
                                                    "mac_secure_action",
                                                    "mld_profile_name",
                                                    "mmrp_flood_optimization",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "split_horizon_group_id",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__setattr__(name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/base/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dai_address_validation_mask.is_set or
                                        self.dhcpv4_profile_name.is_set or
                                        self.dhcpv4_snoop.is_set or
                                        self.flood_unknown_unicast_enabled.is_set or
                                        self.flood_uu_disabled_mac_limit_action.is_set or
                                        self.igm_pv4_disabled.is_set or
                                        self.igm_pv4_profile_name.is_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                        self.is_dai_addr_validate_ipv4_enabled.is_set or
                                        self.is_dai_addr_validate_source_mac_enabled.is_set or
                                        self.is_dai_enabled.is_set or
                                        self.is_dai_logging_enabled.is_set or
                                        self.is_ip_source_guard_enabled.is_set or
                                        self.is_ipsg_logging_enabled.is_set or
                                        self.is_mac_secure_accept_shutdown_enabled.is_set or
                                        self.is_mac_secure_enabled.is_set or
                                        self.is_mac_secure_logging_enabled.is_set or
                                        self.learn_disabled_mac_limit_action.is_set or
                                        self.mac_aging_mode.is_set or
                                        self.mac_aging_time.is_set or
                                        self.mac_flooding.is_set or
                                        self.mac_learning.is_set or
                                        self.mac_limit.is_set or
                                        self.mac_limit_action.is_set or
                                        self.mac_limit_notification.is_set or
                                        self.mac_limit_reached.is_set or
                                        self.mac_port_down_flush_enabled.is_set or
                                        self.mac_secure_action.is_set or
                                        self.mld_profile_name.is_set or
                                        self.mmrp_flood_optimization.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.split_horizon_group_id.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                        self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                        self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                        self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                        self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                        self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                        self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                        self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_aging_mode.yfilter != YFilter.not_set or
                                        self.mac_aging_time.yfilter != YFilter.not_set or
                                        self.mac_flooding.yfilter != YFilter.not_set or
                                        self.mac_learning.yfilter != YFilter.not_set or
                                        self.mac_limit.yfilter != YFilter.not_set or
                                        self.mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_limit_notification.yfilter != YFilter.not_set or
                                        self.mac_limit_reached.yfilter != YFilter.not_set or
                                        self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                        self.mac_secure_action.yfilter != YFilter.not_set or
                                        self.mld_profile_name.yfilter != YFilter.not_set or
                                        self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.split_horizon_group_id.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                    if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                    if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                    if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                    if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                    if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                    if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                    if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                    if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                    if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                    if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                    if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                    if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                    if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                    if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                    if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                    if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                    if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                    if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                    if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                    if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                    if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dai-address-validation-mask"):
                                        self.dai_address_validation_mask = value
                                        self.dai_address_validation_mask.value_namespace = name_space
                                        self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-profile-name"):
                                        self.dhcpv4_profile_name = value
                                        self.dhcpv4_profile_name.value_namespace = name_space
                                        self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-snoop"):
                                        self.dhcpv4_snoop = value
                                        self.dhcpv4_snoop.value_namespace = name_space
                                        self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-unknown-unicast-enabled"):
                                        self.flood_unknown_unicast_enabled = value
                                        self.flood_unknown_unicast_enabled.value_namespace = name_space
                                        self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-uu-disabled-mac-limit-action"):
                                        self.flood_uu_disabled_mac_limit_action = value
                                        self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                        self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-disabled"):
                                        self.igm_pv4_disabled = value
                                        self.igm_pv4_disabled.value_namespace = name_space
                                        self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-profile-name"):
                                        self.igm_pv4_profile_name = value
                                        self.igm_pv4_profile_name.value_namespace = name_space
                                        self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                        self.is_dai_addr_validate_destination_mac_enabled = value
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                        self.is_dai_addr_validate_ipv4_enabled = value
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                        self.is_dai_addr_validate_source_mac_enabled = value
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-enabled"):
                                        self.is_dai_enabled = value
                                        self.is_dai_enabled.value_namespace = name_space
                                        self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-logging-enabled"):
                                        self.is_dai_logging_enabled = value
                                        self.is_dai_logging_enabled.value_namespace = name_space
                                        self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ip-source-guard-enabled"):
                                        self.is_ip_source_guard_enabled = value
                                        self.is_ip_source_guard_enabled.value_namespace = name_space
                                        self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ipsg-logging-enabled"):
                                        self.is_ipsg_logging_enabled = value
                                        self.is_ipsg_logging_enabled.value_namespace = name_space
                                        self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                        self.is_mac_secure_accept_shutdown_enabled = value
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-enabled"):
                                        self.is_mac_secure_enabled = value
                                        self.is_mac_secure_enabled.value_namespace = name_space
                                        self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-logging-enabled"):
                                        self.is_mac_secure_logging_enabled = value
                                        self.is_mac_secure_logging_enabled.value_namespace = name_space
                                        self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "learn-disabled-mac-limit-action"):
                                        self.learn_disabled_mac_limit_action = value
                                        self.learn_disabled_mac_limit_action.value_namespace = name_space
                                        self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-mode"):
                                        self.mac_aging_mode = value
                                        self.mac_aging_mode.value_namespace = name_space
                                        self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-time"):
                                        self.mac_aging_time = value
                                        self.mac_aging_time.value_namespace = name_space
                                        self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flooding"):
                                        self.mac_flooding = value
                                        self.mac_flooding.value_namespace = name_space
                                        self.mac_flooding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-learning"):
                                        self.mac_learning = value
                                        self.mac_learning.value_namespace = name_space
                                        self.mac_learning.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit"):
                                        self.mac_limit = value
                                        self.mac_limit.value_namespace = name_space
                                        self.mac_limit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-action"):
                                        self.mac_limit_action = value
                                        self.mac_limit_action.value_namespace = name_space
                                        self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-notification"):
                                        self.mac_limit_notification = value
                                        self.mac_limit_notification.value_namespace = name_space
                                        self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-reached"):
                                        self.mac_limit_reached = value
                                        self.mac_limit_reached.value_namespace = name_space
                                        self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-port-down-flush-enabled"):
                                        self.mac_port_down_flush_enabled = value
                                        self.mac_port_down_flush_enabled.value_namespace = name_space
                                        self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-secure-action"):
                                        self.mac_secure_action = value
                                        self.mac_secure_action.value_namespace = name_space
                                        self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mld-profile-name"):
                                        self.mld_profile_name = value
                                        self.mld_profile_name.value_namespace = name_space
                                        self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mmrp-flood-optimization"):
                                        self.mmrp_flood_optimization = value
                                        self.mmrp_flood_optimization.value_namespace = name_space
                                        self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "split-horizon-group-id"):
                                        self.split_horizon_group_id = value
                                        self.split_horizon_group_id.value_namespace = name_space
                                        self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dhcpv4_trust.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dhcpv4_trust.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-trust"):
                                    self.dhcpv4_trust = value
                                    self.dhcpv4_trust.value_namespace = name_space
                                    self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "bridge-pw"

                                self.address = YLeaf(YType.str, "address")

                                self.bmac = YLeaf(YType.str, "bmac")

                                self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "bmac",
                                                "next_hop_ip") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.bmac.is_set or
                                    self.next_hop_ip.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.bmac.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "static-mac" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bmac.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "bmac"):
                                    self.bmac = value
                                    self.bmac.value_namespace = name_space
                                    self.bmac.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.static_mac:
                                if (c.has_data()):
                                    return True
                            return (
                                self.is_access.is_set or
                                self.neighbor.is_set or
                                self.pseudowire_id.is_set or
                                self.pw_type.is_set or
                                self.ve_id_vpls_id_0_3.is_set or
                                self.vpls_id_4_7.is_set or
                                (self.pseudowire is not None and self.pseudowire.has_data()) or
                                (self.security_parameters is not None and self.security_parameters.has_data()))

                        def has_operation(self):
                            for c in self.static_mac:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.is_access.yfilter != YFilter.not_set or
                                self.neighbor.yfilter != YFilter.not_set or
                                self.pseudowire_id.yfilter != YFilter.not_set or
                                self.pw_type.yfilter != YFilter.not_set or
                                self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set or
                                self.vpls_id_4_7.yfilter != YFilter.not_set or
                                (self.pseudowire is not None and self.pseudowire.has_operation()) or
                                (self.security_parameters is not None and self.security_parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bridge-pw" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_access.get_name_leafdata())
                            if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor.get_name_leafdata())
                            if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudowire_id.get_name_leafdata())
                            if (self.pw_type.is_set or self.pw_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_type.get_name_leafdata())
                            if (self.ve_id_vpls_id_0_3.is_set or self.ve_id_vpls_id_0_3.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ve_id_vpls_id_0_3.get_name_leafdata())
                            if (self.vpls_id_4_7.is_set or self.vpls_id_4_7.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vpls_id_4_7.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "pseudowire"):
                                if (self.pseudowire is None):
                                    self.pseudowire = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                    self.pseudowire.parent = self
                                    self._children_name_map["pseudowire"] = "pseudowire"
                                return self.pseudowire

                            if (child_yang_name == "security-parameters"):
                                if (self.security_parameters is None):
                                    self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                return self.security_parameters

                            if (child_yang_name == "static-mac"):
                                for c in self.static_mac:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.static_mac.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id" or name == "pw-type" or name == "ve-id-vpls-id-0-3" or name == "vpls-id-4-7"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "is-access"):
                                self.is_access = value
                                self.is_access.value_namespace = name_space
                                self.is_access.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor"):
                                self.neighbor = value
                                self.neighbor.value_namespace = name_space
                                self.neighbor.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudowire-id"):
                                self.pseudowire_id = value
                                self.pseudowire_id.value_namespace = name_space
                                self.pseudowire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-type"):
                                self.pw_type = value
                                self.pw_type.value_namespace = name_space
                                self.pw_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "ve-id-vpls-id-0-3"):
                                self.ve_id_vpls_id_0_3 = value
                                self.ve_id_vpls_id_0_3.value_namespace = name_space
                                self.ve_id_vpls_id_0_3.value_namespace_prefix = name_space_prefix
                            if(value_path == "vpls-id-4-7"):
                                self.vpls_id_4_7 = value
                                self.vpls_id_4_7.value_namespace = name_space
                                self.vpls_id_4_7.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bridge_pw:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bridge_pw:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-pws" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-core-vfi-table/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bridge-pw"):
                            for c in self.bridge_pw:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bridge_pw.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bridge-pw"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.bridge_pws is not None and self.bridge_pws.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bridge_pws is not None and self.bridge_pws.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bridge-core-vfi-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bridge-pws"):
                        if (self.bridge_pws is None):
                            self.bridge_pws = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                            self.bridge_pws.parent = self
                            self._children_name_map["bridge_pws"] = "bridge-pws"
                        return self.bridge_pws

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bridge-pws"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BridgeAcs(Entity):
                """
                VPLS Bridge Domain Attachment Circuit Table
                
                .. attribute:: bridge_ac
                
                	VPLS Bridge Domain Attachment Circuit
                	**type**\: list of    :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs, self).__init__()

                    self.yang_name = "bridge-acs"
                    self.yang_parent_name = "bridge-domain"

                    self.bridge_ac = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs, self).__setattr__(name, value)


                class BridgeAc(Entity):
                    """
                    VPLS Bridge Domain Attachment Circuit
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                    
                    .. attribute:: bvi_mac_index
                    
                    	MyMac Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: bvimac
                    
                    	BVI MAC addresses
                    	**type**\: list of    :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                    
                    .. attribute:: security_parameters
                    
                    	Security Parameters
                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                    
                    .. attribute:: static_mac
                    
                    	Static MAC addresses
                    	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__init__()

                        self.yang_name = "bridge-ac"
                        self.yang_parent_name = "bridge-acs"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.bvi_mac_index = YLeaf(YType.uint16, "bvi-mac-index")

                        self.attachment_circuit = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        self._children_yang_names.add("attachment-circuit")

                        self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                        self.security_parameters.parent = self
                        self._children_name_map["security_parameters"] = "security-parameters"
                        self._children_yang_names.add("security-parameters")

                        self.bvimac = YList(self)
                        self.static_mac = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "bvi_mac_index") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__setattr__(name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "bridge-ac"

                            self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                            self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                            self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                            self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                            self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                            self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                            self.msti = YLeaf(YType.str, "msti")

                            self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                            self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")

                            self.l2vpn_protection = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._children_yang_names.add("l2vpn-protection")

                            self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_mac_conflict",
                                            "bvi_no_port_up",
                                            "control_word_mismatched",
                                            "encapsulation_error",
                                            "encapsulation_mismatched",
                                            "evpn_internal_label",
                                            "interface_handle",
                                            "internal_ms_ti",
                                            "interworking",
                                            "is_ac_partially_programmed",
                                            "mac_limit_oper_down",
                                            "ms_ti_mismatch",
                                            "msti",
                                            "msti_mismatch_down",
                                            "mtu_mismatched",
                                            "node_id",
                                            "out_of_memory_state",
                                            "redundancy_group_id",
                                            "redundancy_group_state",
                                            "redundancy_object_id",
                                            "state",
                                            "tdm_media_mismatched",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"

                                self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2VpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"

                                self.active = YLeaf(YType.boolean, "active")

                                self.protected_name = YLeaf(YType.str, "protected-name")

                                self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                self.protection_name = YLeaf(YType.str, "protection-name")

                                self.protection_type = YLeaf(YType.enumeration, "protection-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active",
                                                "protected_name",
                                                "protection_configured",
                                                "protection_name",
                                                "protection_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.active.is_set or
                                    self.protected_name.is_set or
                                    self.protection_configured.is_set or
                                    self.protection_name.is_set or
                                    self.protection_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.protected_name.yfilter != YFilter.not_set or
                                    self.protection_configured.yfilter != YFilter.not_set or
                                    self.protection_name.yfilter != YFilter.not_set or
                                    self.protection_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2vpn-protection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_name.get_name_leafdata())
                                if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_name.get_name_leafdata())
                                if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-name"):
                                    self.protected_name = value
                                    self.protected_name.value_namespace = name_space
                                    self.protected_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-configured"):
                                    self.protection_configured = value
                                    self.protection_configured.value_namespace = name_space
                                    self.protection_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-name"):
                                    self.protection_name = value
                                    self.protection_name.value_namespace = name_space
                                    self.protection_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-type"):
                                    self.protection_type = value
                                    self.protection_type.value_namespace = name_space
                                    self.protection_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bvi_mac_conflict.is_set or
                                self.bvi_no_port_up.is_set or
                                self.control_word_mismatched.is_set or
                                self.encapsulation_error.is_set or
                                self.encapsulation_mismatched.is_set or
                                self.evpn_internal_label.is_set or
                                self.interface_handle.is_set or
                                self.internal_ms_ti.is_set or
                                self.interworking.is_set or
                                self.is_ac_partially_programmed.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.ms_ti_mismatch.is_set or
                                self.msti.is_set or
                                self.msti_mismatch_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.node_id.is_set or
                                self.out_of_memory_state.is_set or
                                self.redundancy_group_id.is_set or
                                self.redundancy_group_state.is_set or
                                self.redundancy_object_id.is_set or
                                self.state.is_set or
                                self.tdm_media_mismatched.is_set or
                                self.xconnect_id.is_set or
                                (self.interface is not None and self.interface.has_data()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                self.bvi_no_port_up.yfilter != YFilter.not_set or
                                self.control_word_mismatched.yfilter != YFilter.not_set or
                                self.encapsulation_error.yfilter != YFilter.not_set or
                                self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                self.evpn_internal_label.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.internal_ms_ti.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                self.msti.yfilter != YFilter.not_set or
                                self.msti_mismatch_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.redundancy_group_id.yfilter != YFilter.not_set or
                                self.redundancy_group_state.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.interface is not None and self.interface.has_operation()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment-circuit" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                            if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                            if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                            if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                            if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                            if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                            if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti.get_name_leafdata())
                            if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                            if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                if (self.interface is None):
                                    self.interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                return self.interface

                            if (child_yang_name == "l2vpn-protection"):
                                if (self.l2vpn_protection is None):
                                    self.l2vpn_protection = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                return self.l2vpn_protection

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-mac-conflict"):
                                self.bvi_mac_conflict = value
                                self.bvi_mac_conflict.value_namespace = name_space
                                self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-no-port-up"):
                                self.bvi_no_port_up = value
                                self.bvi_no_port_up.value_namespace = name_space
                                self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-word-mismatched"):
                                self.control_word_mismatched = value
                                self.control_word_mismatched.value_namespace = name_space
                                self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-error"):
                                self.encapsulation_error = value
                                self.encapsulation_error.value_namespace = name_space
                                self.encapsulation_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-mismatched"):
                                self.encapsulation_mismatched = value
                                self.encapsulation_mismatched.value_namespace = name_space
                                self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-internal-label"):
                                self.evpn_internal_label = value
                                self.evpn_internal_label.value_namespace = name_space
                                self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-ms-ti"):
                                self.internal_ms_ti = value
                                self.internal_ms_ti.value_namespace = name_space
                                self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ac-partially-programmed"):
                                self.is_ac_partially_programmed = value
                                self.is_ac_partially_programmed.value_namespace = name_space
                                self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ms-ti-mismatch"):
                                self.ms_ti_mismatch = value
                                self.ms_ti_mismatch.value_namespace = name_space
                                self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti"):
                                self.msti = value
                                self.msti.value_namespace = name_space
                                self.msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-mismatch-down"):
                                self.msti_mismatch_down = value
                                self.msti_mismatch_down.value_namespace = name_space
                                self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-id"):
                                self.redundancy_group_id = value
                                self.redundancy_group_id.value_namespace = name_space
                                self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-state"):
                                self.redundancy_group_state = value
                                self.redundancy_group_state.value_namespace = name_space
                                self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "tdm-media-mismatched"):
                                self.tdm_media_mismatched = value
                                self.tdm_media_mismatched.value_namespace = name_space
                                self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class SecurityParameters(Entity):
                        """
                        Security Parameters
                        
                        .. attribute:: base
                        
                        	Basic Security Parameters
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        .. attribute:: dhcpv4_trust
                        
                        	DHCPv4 Trust Status
                        	**type**\:  bool
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__init__()

                            self.yang_name = "security-parameters"
                            self.yang_parent_name = "bridge-ac"

                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                            self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                            self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._children_yang_names.add("base")

                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self._children_name_map["storm_control"] = "storm-control"
                            self._children_yang_names.add("storm-control")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("broadcast_storm_control_kb_ps",
                                            "broadcast_storm_control_pps",
                                            "broadcast_storm_control_rate_unit",
                                            "dhcpv4_trust",
                                            "multicast_storm_control_kb_ps",
                                            "multicast_storm_control_pps",
                                            "multicast_storm_control_rate_unit",
                                            "unicast_storm_control_kb_ps",
                                            "unicast_storm_control_pps",
                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__setattr__(name, value)


                        class Base(Entity):
                            """
                            Basic Security Parameters
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dai_address_validation_mask
                            
                            	DAI Address Validation mask
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dhcpv4_profile_name
                            
                            	DHCPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: dhcpv4_snoop
                            
                            	DHCPv4 Snoop Status
                            	**type**\:  bool
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Flooding unknown unicast enabled
                            	**type**\:  bool
                            
                            .. attribute:: flood_uu_disabled_mac_limit_action
                            
                            	Flooding of unknown\-unicast disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_disabled
                            
                            	IGMPv4 Disabled
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_profile_name
                            
                            	IGMPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                            
                            	Is DAI Dstination MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                            
                            	Is DAI IPv4 Addr Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_source_guard_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                            
                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: learn_disabled_mac_limit_action
                            
                            	Learning disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_mode
                            
                            	MAC Aging Mode
                            	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: mac_flooding
                            
                            	MAC flooding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning
                            
                            	MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC address limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                            
                            .. attribute:: mac_limit_notification
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                            
                            .. attribute:: mac_limit_reached
                            
                            	MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mac_port_down_flush_enabled
                            
                            	MAC Flush when port goes down
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC Secure Action
                            	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                            
                            .. attribute:: mld_profile_name
                            
                            	MLD Profile Name
                            	**type**\:  str
                            
                            .. attribute:: mmrp_flood_optimization
                            
                            	MMRP Flood Optimization Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: split_horizon_group_id
                            
                            	Split Horizon Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "security-parameters"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dai_address_validation_mask",
                                                "dhcpv4_profile_name",
                                                "dhcpv4_snoop",
                                                "flood_unknown_unicast_enabled",
                                                "flood_uu_disabled_mac_limit_action",
                                                "igm_pv4_disabled",
                                                "igm_pv4_profile_name",
                                                "is_dai_addr_validate_destination_mac_enabled",
                                                "is_dai_addr_validate_ipv4_enabled",
                                                "is_dai_addr_validate_source_mac_enabled",
                                                "is_dai_enabled",
                                                "is_dai_logging_enabled",
                                                "is_ip_source_guard_enabled",
                                                "is_ipsg_logging_enabled",
                                                "is_mac_secure_accept_shutdown_enabled",
                                                "is_mac_secure_enabled",
                                                "is_mac_secure_logging_enabled",
                                                "learn_disabled_mac_limit_action",
                                                "mac_aging_mode",
                                                "mac_aging_time",
                                                "mac_flooding",
                                                "mac_learning",
                                                "mac_limit",
                                                "mac_limit_action",
                                                "mac_limit_notification",
                                                "mac_limit_reached",
                                                "mac_port_down_flush_enabled",
                                                "mac_secure_action",
                                                "mld_profile_name",
                                                "mmrp_flood_optimization",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "split_horizon_group_id",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__setattr__(name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "base"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dai_address_validation_mask.is_set or
                                    self.dhcpv4_profile_name.is_set or
                                    self.dhcpv4_snoop.is_set or
                                    self.flood_unknown_unicast_enabled.is_set or
                                    self.flood_uu_disabled_mac_limit_action.is_set or
                                    self.igm_pv4_disabled.is_set or
                                    self.igm_pv4_profile_name.is_set or
                                    self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                    self.is_dai_addr_validate_ipv4_enabled.is_set or
                                    self.is_dai_addr_validate_source_mac_enabled.is_set or
                                    self.is_dai_enabled.is_set or
                                    self.is_dai_logging_enabled.is_set or
                                    self.is_ip_source_guard_enabled.is_set or
                                    self.is_ipsg_logging_enabled.is_set or
                                    self.is_mac_secure_accept_shutdown_enabled.is_set or
                                    self.is_mac_secure_enabled.is_set or
                                    self.is_mac_secure_logging_enabled.is_set or
                                    self.learn_disabled_mac_limit_action.is_set or
                                    self.mac_aging_mode.is_set or
                                    self.mac_aging_time.is_set or
                                    self.mac_flooding.is_set or
                                    self.mac_learning.is_set or
                                    self.mac_limit.is_set or
                                    self.mac_limit_action.is_set or
                                    self.mac_limit_notification.is_set or
                                    self.mac_limit_reached.is_set or
                                    self.mac_port_down_flush_enabled.is_set or
                                    self.mac_secure_action.is_set or
                                    self.mld_profile_name.is_set or
                                    self.mmrp_flood_optimization.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.split_horizon_group_id.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                    self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                    self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                    self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                    self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                    self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                    self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                    self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                    self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                    self.mac_aging_mode.yfilter != YFilter.not_set or
                                    self.mac_aging_time.yfilter != YFilter.not_set or
                                    self.mac_flooding.yfilter != YFilter.not_set or
                                    self.mac_learning.yfilter != YFilter.not_set or
                                    self.mac_limit.yfilter != YFilter.not_set or
                                    self.mac_limit_action.yfilter != YFilter.not_set or
                                    self.mac_limit_notification.yfilter != YFilter.not_set or
                                    self.mac_limit_reached.yfilter != YFilter.not_set or
                                    self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                    self.mac_secure_action.yfilter != YFilter.not_set or
                                    self.mld_profile_name.yfilter != YFilter.not_set or
                                    self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.split_horizon_group_id.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "base" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dai-address-validation-mask"):
                                    self.dai_address_validation_mask = value
                                    self.dai_address_validation_mask.value_namespace = name_space
                                    self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-profile-name"):
                                    self.dhcpv4_profile_name = value
                                    self.dhcpv4_profile_name.value_namespace = name_space
                                    self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-snoop"):
                                    self.dhcpv4_snoop = value
                                    self.dhcpv4_snoop.value_namespace = name_space
                                    self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-unknown-unicast-enabled"):
                                    self.flood_unknown_unicast_enabled = value
                                    self.flood_unknown_unicast_enabled.value_namespace = name_space
                                    self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-uu-disabled-mac-limit-action"):
                                    self.flood_uu_disabled_mac_limit_action = value
                                    self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                    self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "igm-pv4-disabled"):
                                    self.igm_pv4_disabled = value
                                    self.igm_pv4_disabled.value_namespace = name_space
                                    self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igm-pv4-profile-name"):
                                    self.igm_pv4_profile_name = value
                                    self.igm_pv4_profile_name.value_namespace = name_space
                                    self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                    self.is_dai_addr_validate_destination_mac_enabled = value
                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                    self.is_dai_addr_validate_ipv4_enabled = value
                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                    self.is_dai_addr_validate_source_mac_enabled = value
                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-enabled"):
                                    self.is_dai_enabled = value
                                    self.is_dai_enabled.value_namespace = name_space
                                    self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-logging-enabled"):
                                    self.is_dai_logging_enabled = value
                                    self.is_dai_logging_enabled.value_namespace = name_space
                                    self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ip-source-guard-enabled"):
                                    self.is_ip_source_guard_enabled = value
                                    self.is_ip_source_guard_enabled.value_namespace = name_space
                                    self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ipsg-logging-enabled"):
                                    self.is_ipsg_logging_enabled = value
                                    self.is_ipsg_logging_enabled.value_namespace = name_space
                                    self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                    self.is_mac_secure_accept_shutdown_enabled = value
                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-enabled"):
                                    self.is_mac_secure_enabled = value
                                    self.is_mac_secure_enabled.value_namespace = name_space
                                    self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-logging-enabled"):
                                    self.is_mac_secure_logging_enabled = value
                                    self.is_mac_secure_logging_enabled.value_namespace = name_space
                                    self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "learn-disabled-mac-limit-action"):
                                    self.learn_disabled_mac_limit_action = value
                                    self.learn_disabled_mac_limit_action.value_namespace = name_space
                                    self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-mode"):
                                    self.mac_aging_mode = value
                                    self.mac_aging_mode.value_namespace = name_space
                                    self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-time"):
                                    self.mac_aging_time = value
                                    self.mac_aging_time.value_namespace = name_space
                                    self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-flooding"):
                                    self.mac_flooding = value
                                    self.mac_flooding.value_namespace = name_space
                                    self.mac_flooding.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-learning"):
                                    self.mac_learning = value
                                    self.mac_learning.value_namespace = name_space
                                    self.mac_learning.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit"):
                                    self.mac_limit = value
                                    self.mac_limit.value_namespace = name_space
                                    self.mac_limit.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-action"):
                                    self.mac_limit_action = value
                                    self.mac_limit_action.value_namespace = name_space
                                    self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-notification"):
                                    self.mac_limit_notification = value
                                    self.mac_limit_notification.value_namespace = name_space
                                    self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-reached"):
                                    self.mac_limit_reached = value
                                    self.mac_limit_reached.value_namespace = name_space
                                    self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-port-down-flush-enabled"):
                                    self.mac_port_down_flush_enabled = value
                                    self.mac_port_down_flush_enabled.value_namespace = name_space
                                    self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-secure-action"):
                                    self.mac_secure_action = value
                                    self.mac_secure_action.value_namespace = name_space
                                    self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-profile-name"):
                                    self.mld_profile_name = value
                                    self.mld_profile_name.value_namespace = name_space
                                    self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "mmrp-flood-optimization"):
                                    self.mmrp_flood_optimization = value
                                    self.mmrp_flood_optimization.value_namespace = name_space
                                    self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "split-horizon-group-id"):
                                    self.split_horizon_group_id = value
                                    self.split_horizon_group_id.value_namespace = name_space
                                    self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class StormControl(Entity):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\:  bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__init__()

                                self.yang_name = "storm-control"
                                self.yang_parent_name = "security-parameters"

                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                self.multicast = YLeaf(YType.boolean, "multicast")

                                self.unicast = YLeaf(YType.boolean, "unicast")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bd_policer",
                                                "broadcast",
                                                "multicast",
                                                "unicast") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bd_policer.is_set or
                                    self.broadcast.is_set or
                                    self.multicast.is_set or
                                    self.unicast.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bd_policer.yfilter != YFilter.not_set or
                                    self.broadcast.yfilter != YFilter.not_set or
                                    self.multicast.yfilter != YFilter.not_set or
                                    self.unicast.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "storm-control" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bd-policer"):
                                    self.bd_policer = value
                                    self.bd_policer.value_namespace = name_space
                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast"):
                                    self.broadcast = value
                                    self.broadcast.value_namespace = name_space
                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast"):
                                    self.multicast = value
                                    self.multicast.value_namespace = name_space
                                    self.multicast.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast"):
                                    self.unicast = value
                                    self.unicast.value_namespace = name_space
                                    self.unicast.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.broadcast_storm_control_kb_ps.is_set or
                                self.broadcast_storm_control_pps.is_set or
                                self.broadcast_storm_control_rate_unit.is_set or
                                self.dhcpv4_trust.is_set or
                                self.multicast_storm_control_kb_ps.is_set or
                                self.multicast_storm_control_pps.is_set or
                                self.multicast_storm_control_rate_unit.is_set or
                                self.unicast_storm_control_kb_ps.is_set or
                                self.unicast_storm_control_pps.is_set or
                                self.unicast_storm_control_rate_unit.is_set or
                                (self.base is not None and self.base.has_data()) or
                                (self.storm_control is not None and self.storm_control.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                self.dhcpv4_trust.yfilter != YFilter.not_set or
                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                (self.base is not None and self.base.has_operation()) or
                                (self.storm_control is not None and self.storm_control.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "security-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                            if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "base"):
                                if (self.base is None):
                                    self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                return self.base

                            if (child_yang_name == "storm-control"):
                                if (self.storm_control is None):
                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                return self.storm_control

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "broadcast-storm-control-kb-ps"):
                                self.broadcast_storm_control_kb_ps = value
                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-pps"):
                                self.broadcast_storm_control_pps = value
                                self.broadcast_storm_control_pps.value_namespace = name_space
                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-rate-unit"):
                                self.broadcast_storm_control_rate_unit = value
                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "dhcpv4-trust"):
                                self.dhcpv4_trust = value
                                self.dhcpv4_trust.value_namespace = name_space
                                self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-kb-ps"):
                                self.multicast_storm_control_kb_ps = value
                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-pps"):
                                self.multicast_storm_control_pps = value
                                self.multicast_storm_control_pps.value_namespace = name_space
                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-rate-unit"):
                                self.multicast_storm_control_rate_unit = value
                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-kb-ps"):
                                self.unicast_storm_control_kb_ps = value
                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-pps"):
                                self.unicast_storm_control_pps = value
                                self.unicast_storm_control_pps.value_namespace = name_space
                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-rate-unit"):
                                self.unicast_storm_control_rate_unit = value
                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                    class StaticMac(Entity):
                        """
                        Static MAC addresses
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__init__()

                            self.yang_name = "static-mac"
                            self.yang_parent_name = "bridge-ac"

                            self.address = YLeaf(YType.str, "address")

                            self.bmac = YLeaf(YType.str, "bmac")

                            self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "bmac",
                                            "next_hop_ip") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.bmac.is_set or
                                self.next_hop_ip.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.bmac.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "static-mac" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bmac.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "bmac"):
                                self.bmac = value
                                self.bmac.value_namespace = name_space
                                self.bmac.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix


                    class Bvimac(Entity):
                        """
                        BVI MAC addresses
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__init__()

                            self.yang_name = "bvimac"
                            self.yang_parent_name = "bridge-ac"

                            self.address = YLeaf(YType.str, "address")

                            self.bmac = YLeaf(YType.str, "bmac")

                            self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "bmac",
                                            "next_hop_ip") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.bmac.is_set or
                                self.next_hop_ip.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.bmac.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bvimac" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bmac.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "bmac"):
                                self.bmac = value
                                self.bmac.value_namespace = name_space
                                self.bmac.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bvimac:
                            if (c.has_data()):
                                return True
                        for c in self.static_mac:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.bvi_mac_index.is_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_data()) or
                            (self.security_parameters is not None and self.security_parameters.has_data()))

                    def has_operation(self):
                        for c in self.bvimac:
                            if (c.has_operation()):
                                return True
                        for c in self.static_mac:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.bvi_mac_index.yfilter != YFilter.not_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_operation()) or
                            (self.security_parameters is not None and self.security_parameters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-ac" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-acs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.bvi_mac_index.is_set or self.bvi_mac_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bvi_mac_index.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment-circuit"):
                            if (self.attachment_circuit is None):
                                self.attachment_circuit = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            return self.attachment_circuit

                        if (child_yang_name == "bvimac"):
                            for c in self.bvimac:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bvimac.append(c)
                            return c

                        if (child_yang_name == "security-parameters"):
                            if (self.security_parameters is None):
                                self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                            return self.security_parameters

                        if (child_yang_name == "static-mac"):
                            for c in self.static_mac:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.static_mac.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment-circuit" or name == "bvimac" or name == "security-parameters" or name == "static-mac" or name == "interface-name" or name == "bvi-mac-index"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bvi-mac-index"):
                            self.bvi_mac_index = value
                            self.bvi_mac_index.value_namespace = name_space
                            self.bvi_mac_index.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bridge_ac:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bridge_ac:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bridge-acs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bridge-ac"):
                        for c in self.bridge_ac:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bridge_ac.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bridge-ac"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BridgeAccessPws(Entity):
                """
                VPLS Bridge Domain Access Pseudowire Table
                
                .. attribute:: bridge_access_pw
                
                	VPLS Bridge Domain Access Pseudowire
                	**type**\: list of    :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__init__()

                    self.yang_name = "bridge-access-pws"
                    self.yang_parent_name = "bridge-domain"

                    self.bridge_access_pw = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__setattr__(name, value)


                class BridgeAccessPw(Entity):
                    """
                    VPLS Bridge Domain Access Pseudowire
                    
                    .. attribute:: is_access
                    
                    	Is Access PW
                    	**type**\:  bool
                    
                    .. attribute:: neighbor
                    
                    	Neighbor IPv4 address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                    
                    .. attribute:: pseudowire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: security_parameters
                    
                    	Security Parameters
                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                    
                    .. attribute:: static_mac
                    
                    	Static MAC addresses
                    	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__init__()

                        self.yang_name = "bridge-access-pw"
                        self.yang_parent_name = "bridge-access-pws"

                        self.is_access = YLeaf(YType.boolean, "is-access")

                        self.neighbor = YLeaf(YType.str, "neighbor")

                        self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")

                        self.pseudowire = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                        self.pseudowire.parent = self
                        self._children_name_map["pseudowire"] = "pseudowire"
                        self._children_yang_names.add("pseudowire")

                        self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                        self.security_parameters.parent = self
                        self._children_name_map["security_parameters"] = "security-parameters"
                        self._children_yang_names.add("security-parameters")

                        self.static_mac = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_access",
                                        "neighbor",
                                        "pseudowire_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__setattr__(name, value)


                    class Pseudowire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__init__()

                            self.yang_name = "pseudowire"
                            self.yang_parent_name = "bridge-access-pw"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                            self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                            self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                            self.backup_active = YLeaf(YType.boolean, "backup-active")

                            self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                            self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                            self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                            self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                            self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                            self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                            self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                            self.disable_never = YLeaf(YType.boolean, "disable-never")

                            self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.forward_class = YLeaf(YType.uint8, "forward-class")

                            self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                            self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                            self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                            self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                            self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                            self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                            self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                            self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                            self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                            self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                            self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                            self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                            self.load_balance = YLeaf(YType.enumeration, "load-balance")

                            self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                            self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                            self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                            self.local_source_address = YLeaf(YType.str, "local-source-address")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                            self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                            self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                            self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                            self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                            self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                            self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                            self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                            self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                            self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                            self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                            self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                            self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                            self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                            self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                            self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                            self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                            self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                            self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                            self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                            self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                            self.required_bw = YLeaf(YType.uint32, "required-bw")

                            self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                            self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                            self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                            self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                            self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                            self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                            self.time_created = YLeaf(YType.str, "time-created")

                            self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                            self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                            self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                            self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.encapsulation_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            self._children_yang_names.add("encapsulation-info")

                            self.local_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"
                            self._children_yang_names.add("local-interface")

                            self.local_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"
                            self._children_yang_names.add("local-signalling")

                            self.p2mp_pw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._children_yang_names.add("p2mp-pw")

                            self.peer_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"
                            self._children_yang_names.add("peer-id")

                            self.preferred_path = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"
                            self._children_yang_names.add("preferred-path")

                            self.remote_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"
                            self._children_yang_names.add("remote-interface")

                            self.remote_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"
                            self._children_yang_names.add("remote-signalling")

                            self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_remote_down",
                                            "admited_bw",
                                            "auto_discovery",
                                            "backup_active",
                                            "backup_force_active",
                                            "backup_pw",
                                            "bitrate_mismatched",
                                            "bridge_pw_type_mismatch",
                                            "cas_mismatched",
                                            "diff_ts_mismatched",
                                            "disable_delay",
                                            "disable_never",
                                            "evpn_src_acid",
                                            "fe_ctype",
                                            "forward_class",
                                            "freq_mismatched",
                                            "illegal_control_word",
                                            "imposed_vlan_id",
                                            "interworking",
                                            "ipv6_local_source_address",
                                            "is_evpnvpws_type",
                                            "is_flow_label_static",
                                            "is_multi_segment_pseudowire",
                                            "is_partially_programmed",
                                            "is_pwr_type",
                                            "is_vfi",
                                            "last_time_status_changed",
                                            "last_time_status_down",
                                            "ldp_label_advertise_failed",
                                            "load_balance",
                                            "local_control_word",
                                            "local_label_failed",
                                            "local_pseudo_wire_type",
                                            "local_source_address",
                                            "mac_limit_oper_down",
                                            "mtu_mismatched",
                                            "not_supported_qinq",
                                            "num_ma_cwithdraw_msg_received",
                                            "number_ma_cwithdraw_message_sent",
                                            "out_of_memory_state",
                                            "payload_bytes_mismatched",
                                            "payload_type_mismatched",
                                            "preferred_path_disable_fallback",
                                            "primary_peer_id",
                                            "primary_pseudo_wire_id",
                                            "primary_pw",
                                            "protocol",
                                            "pseudo_wire_id",
                                            "pseudo_wire_state",
                                            "pseudo_wire_type_mismatched",
                                            "pw_class_name",
                                            "pw_flow_label_code17_disabled",
                                            "pw_flow_label_type",
                                            "pw_flow_label_type_cfg",
                                            "pw_redundancy_initial_delay",
                                            "pw_redundancy_one_way",
                                            "pw_status_use",
                                            "pwlsd_rewrite_failed",
                                            "remote_control_word",
                                            "remote_label_failed",
                                            "remote_pseudo_wire_type",
                                            "required_bw",
                                            "resync_enabled",
                                            "resync_threshold",
                                            "rtp_mismatched",
                                            "sequencing_type",
                                            "shutdown",
                                            "sig_pkts_mismatched",
                                            "ssrc_mismatched",
                                            "state",
                                            "table_policy_name",
                                            "tag_rewrite",
                                            "time_created",
                                            "time_elapsed_creation",
                                            "time_elapsed_status_changed",
                                            "time_elapsed_status_down",
                                            "transport_lsp_down",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__setattr__(name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudowire"

                                self.internal_label = YLeaf(YType.uint32, "internal-label")

                                self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                                self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                                self.type = YLeaf(YType.enumeration, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("internal_label",
                                                "ipv4_peer_id",
                                                "ipv6_peer_id",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.internal_label.is_set or
                                    self.ipv4_peer_id.is_set or
                                    self.ipv6_peer_id.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.internal_label.yfilter != YFilter.not_set or
                                    self.ipv4_peer_id.yfilter != YFilter.not_set or
                                    self.ipv6_peer_id.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "peer-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_label.get_name_leafdata())
                                if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                                if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "internal-label"):
                                    self.internal_label = value
                                    self.internal_label.value_namespace = name_space
                                    self.internal_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-peer-id"):
                                    self.ipv4_peer_id = value
                                    self.ipv4_peer_id.value_namespace = name_space
                                    self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-peer-id"):
                                    self.ipv6_peer_id = value
                                    self.ipv6_peer_id.value_namespace = name_space
                                    self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudowire"

                                self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                                self.atom = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"
                                self._children_yang_names.add("atom")

                                self.l2tpv3 = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._children_yang_names.add("l2tpv3")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("encapsulation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                    self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                    self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                    self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                    self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                    self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                    self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                    self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                    self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                    self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                    self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                    self.local_veid = YLeaf(YType.uint32, "local-veid")

                                    self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                    self.rem_saii = YLeaf(YType.str, "rem-saii")

                                    self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                    self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                    self.rem_taii = YLeaf(YType.str, "rem-taii")

                                    self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                    self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                    self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                    self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                    self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                    self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                    self.remote_label = YLeaf(YType.uint32, "remote-label")

                                    self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                    self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                    self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                    self.saii = YLeaf(YType.str, "saii")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.taii = YLeaf(YType.str, "taii")

                                    self.local_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"
                                    self._children_yang_names.add("local-agi")

                                    self.multi_segment_pseudowire_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._children_yang_names.add("multi-segment-pseudowire-stats")

                                    self.remote_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"
                                    self._children_yang_names.add("remote-agi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_pseudowire_headend",
                                                    "is_sai_itype2",
                                                    "is_tai_itype2",
                                                    "ldp_label_advertisment_failed",
                                                    "local_c_ctype",
                                                    "local_ceid",
                                                    "local_cv_type",
                                                    "local_group_id",
                                                    "local_label",
                                                    "local_ldp_id",
                                                    "local_saii_gbl_id",
                                                    "local_saiiac_id",
                                                    "local_taii_gbl_id",
                                                    "local_taiiac_id",
                                                    "local_veid",
                                                    "lsd_rewrite_failed",
                                                    "rem_saii",
                                                    "rem_saii_gbl_id",
                                                    "rem_saiiac_id",
                                                    "rem_taii",
                                                    "rem_taii_gbl_id",
                                                    "rem_taiiac_id",
                                                    "remote_c_ctype",
                                                    "remote_ceid",
                                                    "remote_cv_type",
                                                    "remote_group_id",
                                                    "remote_label",
                                                    "remote_ldp_id",
                                                    "remote_source_address",
                                                    "remote_veid",
                                                    "saii",
                                                    "source_address",
                                                    "taii") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "local-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"

                                        self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                        self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                        self._children_yang_names.add("auto")

                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                        self._children_yang_names.add("two-byte-as")

                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._children_yang_names.add("v4-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("vpls_id_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"

                                            self.asn = YLeaf(YType.uint16, "asn")

                                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("asn",
                                                            "vpn_id") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.asn.is_set or
                                                self.vpn_id.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.asn.yfilter != YFilter.not_set or
                                                self.vpn_id.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "auto" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.asn.get_name_leafdata())
                                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "asn" or name == "vpn-id"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "asn"):
                                                self.asn = value
                                                self.asn.value_namespace = name_space
                                                self.asn.value_namespace_prefix = name_space_prefix
                                            if(value_path == "vpn-id"):
                                                self.vpn_id = value
                                                self.vpn_id.value_namespace = name_space
                                                self.vpn_id.value_namespace_prefix = name_space_prefix


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"

                                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("four_byte_index",
                                                            "two_byte_as") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.four_byte_index.is_set or
                                                self.two_byte_as.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.four_byte_index.yfilter != YFilter.not_set or
                                                self.two_byte_as.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "two-byte-as" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "four-byte-index" or name == "two-byte-as"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "four-byte-index"):
                                                self.four_byte_index = value
                                                self.four_byte_index.value_namespace = name_space
                                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-as"):
                                                self.two_byte_as = value
                                                self.two_byte_as.value_namespace = name_space
                                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ipv4_address",
                                                            "two_byte_index") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.ipv4_address.is_set or
                                                self.two_byte_index.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.two_byte_index.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "v4-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ipv4-address" or name == "two-byte-index"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "two-byte-index"):
                                                self.two_byte_index = value
                                                self.two_byte_index.value_namespace = name_space
                                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.vpls_id_type.is_set or
                                            (self.auto is not None and self.auto.has_data()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                            (self.v4_addr is not None and self.v4_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.vpls_id_type.yfilter != YFilter.not_set or
                                            (self.auto is not None and self.auto.has_operation()) or
                                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-agi" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "auto"):
                                            if (self.auto is None):
                                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"
                                            return self.auto

                                        if (child_yang_name == "two-byte-as"):
                                            if (self.two_byte_as is None):
                                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                            return self.two_byte_as

                                        if (child_yang_name == "v4-addr"):
                                            if (self.v4_addr is None):
                                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                            return self.v4_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "vpls-id-type"):
                                            self.vpls_id_type = value
                                            self.vpls_id_type.value_namespace = name_space
                                            self.vpls_id_type.value_namespace_prefix = name_space_prefix


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"

                                        self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                        self.received_packets = YLeaf(YType.uint64, "received-packets")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("received_bytes",
                                                        "received_packets") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.received_bytes.is_set or
                                            self.received_packets.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.received_bytes.yfilter != YFilter.not_set or
                                            self.received_packets.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                        if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_packets.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-bytes" or name == "received-packets"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "received-bytes"):
                                            self.received_bytes = value
                                            self.received_bytes.value_namespace = name_space
                                            self.received_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-packets"):
                                            self.received_packets = value
                                            self.received_packets.value_namespace = name_space
                                            self.received_packets.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_pseudowire_headend.is_set or
                                        self.is_sai_itype2.is_set or
                                        self.is_tai_itype2.is_set or
                                        self.ldp_label_advertisment_failed.is_set or
                                        self.local_c_ctype.is_set or
                                        self.local_ceid.is_set or
                                        self.local_cv_type.is_set or
                                        self.local_group_id.is_set or
                                        self.local_label.is_set or
                                        self.local_ldp_id.is_set or
                                        self.local_saii_gbl_id.is_set or
                                        self.local_saiiac_id.is_set or
                                        self.local_taii_gbl_id.is_set or
                                        self.local_taiiac_id.is_set or
                                        self.local_veid.is_set or
                                        self.lsd_rewrite_failed.is_set or
                                        self.rem_saii.is_set or
                                        self.rem_saii_gbl_id.is_set or
                                        self.rem_saiiac_id.is_set or
                                        self.rem_taii.is_set or
                                        self.rem_taii_gbl_id.is_set or
                                        self.rem_taiiac_id.is_set or
                                        self.remote_c_ctype.is_set or
                                        self.remote_ceid.is_set or
                                        self.remote_cv_type.is_set or
                                        self.remote_group_id.is_set or
                                        self.remote_label.is_set or
                                        self.remote_ldp_id.is_set or
                                        self.remote_source_address.is_set or
                                        self.remote_veid.is_set or
                                        self.saii.is_set or
                                        self.source_address.is_set or
                                        self.taii.is_set or
                                        (self.local_agi is not None and self.local_agi.has_data()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                        (self.remote_agi is not None and self.remote_agi.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                        self.is_sai_itype2.yfilter != YFilter.not_set or
                                        self.is_tai_itype2.yfilter != YFilter.not_set or
                                        self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                        self.local_c_ctype.yfilter != YFilter.not_set or
                                        self.local_ceid.yfilter != YFilter.not_set or
                                        self.local_cv_type.yfilter != YFilter.not_set or
                                        self.local_group_id.yfilter != YFilter.not_set or
                                        self.local_label.yfilter != YFilter.not_set or
                                        self.local_ldp_id.yfilter != YFilter.not_set or
                                        self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_saiiac_id.yfilter != YFilter.not_set or
                                        self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.local_taiiac_id.yfilter != YFilter.not_set or
                                        self.local_veid.yfilter != YFilter.not_set or
                                        self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                        self.rem_saii.yfilter != YFilter.not_set or
                                        self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_saiiac_id.yfilter != YFilter.not_set or
                                        self.rem_taii.yfilter != YFilter.not_set or
                                        self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                        self.rem_taiiac_id.yfilter != YFilter.not_set or
                                        self.remote_c_ctype.yfilter != YFilter.not_set or
                                        self.remote_ceid.yfilter != YFilter.not_set or
                                        self.remote_cv_type.yfilter != YFilter.not_set or
                                        self.remote_group_id.yfilter != YFilter.not_set or
                                        self.remote_label.yfilter != YFilter.not_set or
                                        self.remote_ldp_id.yfilter != YFilter.not_set or
                                        self.remote_source_address.yfilter != YFilter.not_set or
                                        self.remote_veid.yfilter != YFilter.not_set or
                                        self.saii.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.taii.yfilter != YFilter.not_set or
                                        (self.local_agi is not None and self.local_agi.has_operation()) or
                                        (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                        (self.remote_agi is not None and self.remote_agi.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atom" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                    if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                    if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                    if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                    if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                    if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                    if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                    if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                    if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_label.get_name_leafdata())
                                    if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                    if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                    if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                    if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                    if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                    if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_veid.get_name_leafdata())
                                    if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                    if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                    if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                    if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                    if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                    if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                    if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                    if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                    if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                    if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                    if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                    if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_label.get_name_leafdata())
                                    if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                    if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                    if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                    if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.saii.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.taii.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "local-agi"):
                                        if (self.local_agi is None):
                                            self.local_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"
                                        return self.local_agi

                                    if (child_yang_name == "multi-segment-pseudowire-stats"):
                                        if (self.multi_segment_pseudowire_stats is None):
                                            self.multi_segment_pseudowire_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        return self.multi_segment_pseudowire_stats

                                    if (child_yang_name == "remote-agi"):
                                        if (self.remote_agi is None):
                                            self.remote_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"
                                        return self.remote_agi

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-pseudowire-headend"):
                                        self.is_pseudowire_headend = value
                                        self.is_pseudowire_headend.value_namespace = name_space
                                        self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-sai-itype2"):
                                        self.is_sai_itype2 = value
                                        self.is_sai_itype2.value_namespace = name_space
                                        self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-tai-itype2"):
                                        self.is_tai_itype2 = value
                                        self.is_tai_itype2.value_namespace = name_space
                                        self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-label-advertisment-failed"):
                                        self.ldp_label_advertisment_failed = value
                                        self.ldp_label_advertisment_failed.value_namespace = name_space
                                        self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-c-ctype"):
                                        self.local_c_ctype = value
                                        self.local_c_ctype.value_namespace = name_space
                                        self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ceid"):
                                        self.local_ceid = value
                                        self.local_ceid.value_namespace = name_space
                                        self.local_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cv-type"):
                                        self.local_cv_type = value
                                        self.local_cv_type.value_namespace = name_space
                                        self.local_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-group-id"):
                                        self.local_group_id = value
                                        self.local_group_id.value_namespace = name_space
                                        self.local_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-label"):
                                        self.local_label = value
                                        self.local_label.value_namespace = name_space
                                        self.local_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-ldp-id"):
                                        self.local_ldp_id = value
                                        self.local_ldp_id.value_namespace = name_space
                                        self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saii-gbl-id"):
                                        self.local_saii_gbl_id = value
                                        self.local_saii_gbl_id.value_namespace = name_space
                                        self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-saiiac-id"):
                                        self.local_saiiac_id = value
                                        self.local_saiiac_id.value_namespace = name_space
                                        self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taii-gbl-id"):
                                        self.local_taii_gbl_id = value
                                        self.local_taii_gbl_id.value_namespace = name_space
                                        self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-taiiac-id"):
                                        self.local_taiiac_id = value
                                        self.local_taiiac_id.value_namespace = name_space
                                        self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-veid"):
                                        self.local_veid = value
                                        self.local_veid.value_namespace = name_space
                                        self.local_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsd-rewrite-failed"):
                                        self.lsd_rewrite_failed = value
                                        self.lsd_rewrite_failed.value_namespace = name_space
                                        self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii"):
                                        self.rem_saii = value
                                        self.rem_saii.value_namespace = name_space
                                        self.rem_saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saii-gbl-id"):
                                        self.rem_saii_gbl_id = value
                                        self.rem_saii_gbl_id.value_namespace = name_space
                                        self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-saiiac-id"):
                                        self.rem_saiiac_id = value
                                        self.rem_saiiac_id.value_namespace = name_space
                                        self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii"):
                                        self.rem_taii = value
                                        self.rem_taii.value_namespace = name_space
                                        self.rem_taii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taii-gbl-id"):
                                        self.rem_taii_gbl_id = value
                                        self.rem_taii_gbl_id.value_namespace = name_space
                                        self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rem-taiiac-id"):
                                        self.rem_taiiac_id = value
                                        self.rem_taiiac_id.value_namespace = name_space
                                        self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-c-ctype"):
                                        self.remote_c_ctype = value
                                        self.remote_c_ctype.value_namespace = name_space
                                        self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ceid"):
                                        self.remote_ceid = value
                                        self.remote_ceid.value_namespace = name_space
                                        self.remote_ceid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cv-type"):
                                        self.remote_cv_type = value
                                        self.remote_cv_type.value_namespace = name_space
                                        self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-group-id"):
                                        self.remote_group_id = value
                                        self.remote_group_id.value_namespace = name_space
                                        self.remote_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-label"):
                                        self.remote_label = value
                                        self.remote_label.value_namespace = name_space
                                        self.remote_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-ldp-id"):
                                        self.remote_ldp_id = value
                                        self.remote_ldp_id.value_namespace = name_space
                                        self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-source-address"):
                                        self.remote_source_address = value
                                        self.remote_source_address.value_namespace = name_space
                                        self.remote_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-veid"):
                                        self.remote_veid = value
                                        self.remote_veid.value_namespace = name_space
                                        self.remote_veid.value_namespace_prefix = name_space_prefix
                                    if(value_path == "saii"):
                                        self.saii = value
                                        self.saii.value_namespace = name_space
                                        self.saii.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "taii"):
                                        self.taii = value
                                        self.taii.value_namespace = name_space
                                        self.taii.value_namespace_prefix = name_space_prefix


                            class L2Tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"

                                    self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                    self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                    self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                    self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                    self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                    self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                    self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                    self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                    self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                    self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                    self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                    self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                    self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                    self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                    self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                    self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                    self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                    self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                    self.tos = YLeaf(YType.uint8, "tos")

                                    self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                    self.ttl = YLeaf(YType.uint8, "ttl")

                                    self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dont_fragment_bit",
                                                    "ipv4_source_address",
                                                    "ipv6_source_address",
                                                    "l2tp_class_name",
                                                    "local_cookie_high_value",
                                                    "local_cookie_low_value",
                                                    "local_cookie_size",
                                                    "local_secondary_cookie_high_value",
                                                    "local_secondary_cookie_low_value",
                                                    "local_secondary_cookie_size",
                                                    "local_session_id",
                                                    "path_mtu_enabled",
                                                    "path_mtu_max_value",
                                                    "remote_circuit_status_up",
                                                    "remote_cookie_high_value",
                                                    "remote_cookie_low_value",
                                                    "remote_cookie_size",
                                                    "remote_session_id",
                                                    "tos",
                                                    "tos_mode",
                                                    "ttl",
                                                    "tunnel_state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dont_fragment_bit.is_set or
                                        self.ipv4_source_address.is_set or
                                        self.ipv6_source_address.is_set or
                                        self.l2tp_class_name.is_set or
                                        self.local_cookie_high_value.is_set or
                                        self.local_cookie_low_value.is_set or
                                        self.local_cookie_size.is_set or
                                        self.local_secondary_cookie_high_value.is_set or
                                        self.local_secondary_cookie_low_value.is_set or
                                        self.local_secondary_cookie_size.is_set or
                                        self.local_session_id.is_set or
                                        self.path_mtu_enabled.is_set or
                                        self.path_mtu_max_value.is_set or
                                        self.remote_circuit_status_up.is_set or
                                        self.remote_cookie_high_value.is_set or
                                        self.remote_cookie_low_value.is_set or
                                        self.remote_cookie_size.is_set or
                                        self.remote_session_id.is_set or
                                        self.tos.is_set or
                                        self.tos_mode.is_set or
                                        self.ttl.is_set or
                                        self.tunnel_state.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dont_fragment_bit.yfilter != YFilter.not_set or
                                        self.ipv4_source_address.yfilter != YFilter.not_set or
                                        self.ipv6_source_address.yfilter != YFilter.not_set or
                                        self.l2tp_class_name.yfilter != YFilter.not_set or
                                        self.local_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_cookie_size.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                        self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                        self.local_session_id.yfilter != YFilter.not_set or
                                        self.path_mtu_enabled.yfilter != YFilter.not_set or
                                        self.path_mtu_max_value.yfilter != YFilter.not_set or
                                        self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                        self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                        self.remote_cookie_size.yfilter != YFilter.not_set or
                                        self.remote_session_id.yfilter != YFilter.not_set or
                                        self.tos.yfilter != YFilter.not_set or
                                        self.tos_mode.yfilter != YFilter.not_set or
                                        self.ttl.yfilter != YFilter.not_set or
                                        self.tunnel_state.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2tpv3" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                    if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                    if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                    if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                    if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                    if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                    if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                    if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                    if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                    if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                    if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                    if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                    if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                    if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                    if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                    if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                    if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos.get_name_leafdata())
                                    if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ttl.get_name_leafdata())
                                    if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dont-fragment-bit"):
                                        self.dont_fragment_bit = value
                                        self.dont_fragment_bit.value_namespace = name_space
                                        self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-source-address"):
                                        self.ipv4_source_address = value
                                        self.ipv4_source_address.value_namespace = name_space
                                        self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-source-address"):
                                        self.ipv6_source_address = value
                                        self.ipv6_source_address.value_namespace = name_space
                                        self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "l2tp-class-name"):
                                        self.l2tp_class_name = value
                                        self.l2tp_class_name.value_namespace = name_space
                                        self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-high-value"):
                                        self.local_cookie_high_value = value
                                        self.local_cookie_high_value.value_namespace = name_space
                                        self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-low-value"):
                                        self.local_cookie_low_value = value
                                        self.local_cookie_low_value.value_namespace = name_space
                                        self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-cookie-size"):
                                        self.local_cookie_size = value
                                        self.local_cookie_size.value_namespace = name_space
                                        self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-high-value"):
                                        self.local_secondary_cookie_high_value = value
                                        self.local_secondary_cookie_high_value.value_namespace = name_space
                                        self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-low-value"):
                                        self.local_secondary_cookie_low_value = value
                                        self.local_secondary_cookie_low_value.value_namespace = name_space
                                        self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-secondary-cookie-size"):
                                        self.local_secondary_cookie_size = value
                                        self.local_secondary_cookie_size.value_namespace = name_space
                                        self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-session-id"):
                                        self.local_session_id = value
                                        self.local_session_id.value_namespace = name_space
                                        self.local_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-enabled"):
                                        self.path_mtu_enabled = value
                                        self.path_mtu_enabled.value_namespace = name_space
                                        self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "path-mtu-max-value"):
                                        self.path_mtu_max_value = value
                                        self.path_mtu_max_value.value_namespace = name_space
                                        self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-circuit-status-up"):
                                        self.remote_circuit_status_up = value
                                        self.remote_circuit_status_up.value_namespace = name_space
                                        self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-high-value"):
                                        self.remote_cookie_high_value = value
                                        self.remote_cookie_high_value.value_namespace = name_space
                                        self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-low-value"):
                                        self.remote_cookie_low_value = value
                                        self.remote_cookie_low_value.value_namespace = name_space
                                        self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-cookie-size"):
                                        self.remote_cookie_size = value
                                        self.remote_cookie_size.value_namespace = name_space
                                        self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-session-id"):
                                        self.remote_session_id = value
                                        self.remote_session_id.value_namespace = name_space
                                        self.remote_session_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos"):
                                        self.tos = value
                                        self.tos.value_namespace = name_space
                                        self.tos.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tos-mode"):
                                        self.tos_mode = value
                                        self.tos_mode.value_namespace = name_space
                                        self.tos_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ttl"):
                                        self.ttl = value
                                        self.ttl.value_namespace = name_space
                                        self.ttl.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel-state"):
                                        self.tunnel_state = value
                                        self.tunnel_state.value_namespace = name_space
                                        self.tunnel_state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.encapsulation.is_set or
                                    (self.atom is not None and self.atom.has_data()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.encapsulation.yfilter != YFilter.not_set or
                                    (self.atom is not None and self.atom.has_operation()) or
                                    (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "encapsulation-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.encapsulation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atom"):
                                    if (self.atom is None):
                                        self.atom = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"
                                    return self.atom

                                if (child_yang_name == "l2tpv3"):
                                    if (self.l2tpv3 is None):
                                        self.l2tpv3 = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                    return self.l2tpv3

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "encapsulation"):
                                    self.encapsulation = value
                                    self.encapsulation.value_namespace = name_space
                                    self.encapsulation.value_namespace_prefix = name_space_prefix


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudowire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudowire"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/vlan/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/tdm/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self.get_segment_path()
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudowire"

                                self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                                self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                                self.option = YLeaf(YType.enumeration, "option")

                                self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                                self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ip_tunnel_interface_number",
                                                "next_hop_ip",
                                                "option",
                                                "te_tunnel_interface_number",
                                                "tp_tunnel_interface_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ip_tunnel_interface_number.is_set or
                                    self.next_hop_ip.is_set or
                                    self.option.is_set or
                                    self.te_tunnel_interface_number.is_set or
                                    self.tp_tunnel_interface_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.next_hop_ip.yfilter != YFilter.not_set or
                                    self.option.yfilter != YFilter.not_set or
                                    self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                    self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "preferred-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                                if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                                if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.option.get_name_leafdata())
                                if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                                if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ip-tunnel-interface-number"):
                                    self.ip_tunnel_interface_number = value
                                    self.ip_tunnel_interface_number.value_namespace = name_space
                                    self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-ip"):
                                    self.next_hop_ip = value
                                    self.next_hop_ip.value_namespace = name_space
                                    self.next_hop_ip.value_namespace_prefix = name_space_prefix
                                if(value_path == "option"):
                                    self.option = value
                                    self.option.value_namespace = name_space
                                    self.option.value_namespace_prefix = name_space_prefix
                                if(value_path == "te-tunnel-interface-number"):
                                    self.te_tunnel_interface_number = value
                                    self.te_tunnel_interface_number.value_namespace = name_space
                                    self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "tp-tunnel-interface-number"):
                                    self.tp_tunnel_interface_number = value
                                    self.tp_tunnel_interface_number.value_namespace = name_space
                                    self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudowire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudowire"

                                self.pw_status = YLeaf(YType.uint32, "pw-status")

                                self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"
                                self._children_yang_names.add("status-tlv")

                                self.tlv = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pw_status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "status-tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"

                                    self.description = YLeaf(YType.str, "description")

                                    self.local_address = YLeaf(YType.str, "local-address")

                                    self.pw_id = YLeaf(YType.uint32, "pw-id")

                                    self.remote_address = YLeaf(YType.str, "remote-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("description",
                                                    "local_address",
                                                    "pw_id",
                                                    "remote_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.description.is_set or
                                        self.local_address.is_set or
                                        self.pw_id.is_set or
                                        self.remote_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.description.yfilter != YFilter.not_set or
                                        self.local_address.yfilter != YFilter.not_set or
                                        self.pw_id.yfilter != YFilter.not_set or
                                        self.remote_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tlv" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-signalling/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.description.get_name_leafdata())
                                    if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_address.get_name_leafdata())
                                    if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pw_id.get_name_leafdata())
                                    if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.remote_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "description"):
                                        self.description = value
                                        self.description.value_namespace = name_space
                                        self.description.value_namespace_prefix = name_space_prefix
                                    if(value_path == "local-address"):
                                        self.local_address = value
                                        self.local_address.value_namespace = name_space
                                        self.local_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pw-id"):
                                        self.pw_id = value
                                        self.pw_id.value_namespace = name_space
                                        self.pw_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "remote-address"):
                                        self.remote_address = value
                                        self.remote_address.value_namespace = name_space
                                        self.remote_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tlv:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.pw_status.is_set or
                                    (self.status_tlv is not None and self.status_tlv.has_data()))

                            def has_operation(self):
                                for c in self.tlv:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pw_status.yfilter != YFilter.not_set or
                                    (self.status_tlv is not None and self.status_tlv.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remote-signalling" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "status-tlv"):
                                    if (self.status_tlv is None):
                                        self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"
                                    return self.status_tlv

                                if (child_yang_name == "tlv"):
                                    for c in self.tlv:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tlv.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pw-status"):
                                    self.pw_status = value
                                    self.pw_status.value_namespace = name_space
                                    self.pw_status.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudowire"

                                self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class P2MpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudowire"

                                self.local_available = YLeaf(YType.boolean, "local-available")

                                self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                                self.local_flags = YLeaf(YType.uint8, "local-flags")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                                self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                                self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                                self.remote_available = YLeaf(YType.boolean, "remote-available")

                                self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                                self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                                self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                                self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_available",
                                                "local_extended_tunnel_id",
                                                "local_flags",
                                                "local_label",
                                                "local_p2mp_id",
                                                "local_ptree_type",
                                                "local_tunnel_id",
                                                "remote_available",
                                                "remote_extended_tunnel_id",
                                                "remote_flags",
                                                "remote_label",
                                                "remote_p2mp_id",
                                                "remote_ptree_type",
                                                "remote_tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_available.is_set or
                                    self.local_extended_tunnel_id.is_set or
                                    self.local_flags.is_set or
                                    self.local_label.is_set or
                                    self.local_p2mp_id.is_set or
                                    self.local_ptree_type.is_set or
                                    self.local_tunnel_id.is_set or
                                    self.remote_available.is_set or
                                    self.remote_extended_tunnel_id.is_set or
                                    self.remote_flags.is_set or
                                    self.remote_label.is_set or
                                    self.remote_p2mp_id.is_set or
                                    self.remote_ptree_type.is_set or
                                    self.remote_tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_available.yfilter != YFilter.not_set or
                                    self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.local_flags.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_p2mp_id.yfilter != YFilter.not_set or
                                    self.local_ptree_type.yfilter != YFilter.not_set or
                                    self.local_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_available.yfilter != YFilter.not_set or
                                    self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.remote_flags.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_p2mp_id.yfilter != YFilter.not_set or
                                    self.remote_ptree_type.yfilter != YFilter.not_set or
                                    self.remote_tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "p2mp-pw" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_available.get_name_leafdata())
                                if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                                if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_flags.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                                if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                                if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                                if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_available.get_name_leafdata())
                                if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                                if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_flags.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                                if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                                if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-available"):
                                    self.local_available = value
                                    self.local_available.value_namespace = name_space
                                    self.local_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-extended-tunnel-id"):
                                    self.local_extended_tunnel_id = value
                                    self.local_extended_tunnel_id.value_namespace = name_space
                                    self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-flags"):
                                    self.local_flags = value
                                    self.local_flags.value_namespace = name_space
                                    self.local_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-p2mp-id"):
                                    self.local_p2mp_id = value
                                    self.local_p2mp_id.value_namespace = name_space
                                    self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ptree-type"):
                                    self.local_ptree_type = value
                                    self.local_ptree_type.value_namespace = name_space
                                    self.local_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-tunnel-id"):
                                    self.local_tunnel_id = value
                                    self.local_tunnel_id.value_namespace = name_space
                                    self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-available"):
                                    self.remote_available = value
                                    self.remote_available.value_namespace = name_space
                                    self.remote_available.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-extended-tunnel-id"):
                                    self.remote_extended_tunnel_id = value
                                    self.remote_extended_tunnel_id.value_namespace = name_space
                                    self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-flags"):
                                    self.remote_flags = value
                                    self.remote_flags.value_namespace = name_space
                                    self.remote_flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-p2mp-id"):
                                    self.remote_p2mp_id = value
                                    self.remote_p2mp_id.value_namespace = name_space
                                    self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ptree-type"):
                                    self.remote_ptree_type = value
                                    self.remote_ptree_type.value_namespace = name_space
                                    self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-tunnel-id"):
                                    self.remote_tunnel_id = value
                                    self.remote_tunnel_id.value_namespace = name_space
                                    self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ad_method.is_set or
                                self.ad_remote_down.is_set or
                                self.admited_bw.is_set or
                                self.auto_discovery.is_set or
                                self.backup_active.is_set or
                                self.backup_force_active.is_set or
                                self.backup_pw.is_set or
                                self.bitrate_mismatched.is_set or
                                self.bridge_pw_type_mismatch.is_set or
                                self.cas_mismatched.is_set or
                                self.diff_ts_mismatched.is_set or
                                self.disable_delay.is_set or
                                self.disable_never.is_set or
                                self.evpn_src_acid.is_set or
                                self.fe_ctype.is_set or
                                self.forward_class.is_set or
                                self.freq_mismatched.is_set or
                                self.illegal_control_word.is_set or
                                self.imposed_vlan_id.is_set or
                                self.interworking.is_set or
                                self.ipv6_local_source_address.is_set or
                                self.is_evpnvpws_type.is_set or
                                self.is_flow_label_static.is_set or
                                self.is_multi_segment_pseudowire.is_set or
                                self.is_partially_programmed.is_set or
                                self.is_pwr_type.is_set or
                                self.is_vfi.is_set or
                                self.last_time_status_changed.is_set or
                                self.last_time_status_down.is_set or
                                self.ldp_label_advertise_failed.is_set or
                                self.load_balance.is_set or
                                self.local_control_word.is_set or
                                self.local_label_failed.is_set or
                                self.local_pseudo_wire_type.is_set or
                                self.local_source_address.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.not_supported_qinq.is_set or
                                self.num_ma_cwithdraw_msg_received.is_set or
                                self.number_ma_cwithdraw_message_sent.is_set or
                                self.out_of_memory_state.is_set or
                                self.payload_bytes_mismatched.is_set or
                                self.payload_type_mismatched.is_set or
                                self.preferred_path_disable_fallback.is_set or
                                self.primary_peer_id.is_set or
                                self.primary_pseudo_wire_id.is_set or
                                self.primary_pw.is_set or
                                self.protocol.is_set or
                                self.pseudo_wire_id.is_set or
                                self.pseudo_wire_state.is_set or
                                self.pseudo_wire_type_mismatched.is_set or
                                self.pw_class_name.is_set or
                                self.pw_flow_label_code17_disabled.is_set or
                                self.pw_flow_label_type.is_set or
                                self.pw_flow_label_type_cfg.is_set or
                                self.pw_redundancy_initial_delay.is_set or
                                self.pw_redundancy_one_way.is_set or
                                self.pw_status_use.is_set or
                                self.pwlsd_rewrite_failed.is_set or
                                self.remote_control_word.is_set or
                                self.remote_label_failed.is_set or
                                self.remote_pseudo_wire_type.is_set or
                                self.required_bw.is_set or
                                self.resync_enabled.is_set or
                                self.resync_threshold.is_set or
                                self.rtp_mismatched.is_set or
                                self.sequencing_type.is_set or
                                self.shutdown.is_set or
                                self.sig_pkts_mismatched.is_set or
                                self.ssrc_mismatched.is_set or
                                self.state.is_set or
                                self.table_policy_name.is_set or
                                self.tag_rewrite.is_set or
                                self.time_created.is_set or
                                self.time_elapsed_creation.is_set or
                                self.time_elapsed_status_changed.is_set or
                                self.time_elapsed_status_down.is_set or
                                self.transport_lsp_down.is_set or
                                self.xconnect_id.is_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                                (self.local_interface is not None and self.local_interface.has_data()) or
                                (self.local_signalling is not None and self.local_signalling.has_data()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                                (self.peer_id is not None and self.peer_id.has_data()) or
                                (self.preferred_path is not None and self.preferred_path.has_data()) or
                                (self.remote_interface is not None and self.remote_interface.has_data()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_remote_down.yfilter != YFilter.not_set or
                                self.admited_bw.yfilter != YFilter.not_set or
                                self.auto_discovery.yfilter != YFilter.not_set or
                                self.backup_active.yfilter != YFilter.not_set or
                                self.backup_force_active.yfilter != YFilter.not_set or
                                self.backup_pw.yfilter != YFilter.not_set or
                                self.bitrate_mismatched.yfilter != YFilter.not_set or
                                self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                                self.cas_mismatched.yfilter != YFilter.not_set or
                                self.diff_ts_mismatched.yfilter != YFilter.not_set or
                                self.disable_delay.yfilter != YFilter.not_set or
                                self.disable_never.yfilter != YFilter.not_set or
                                self.evpn_src_acid.yfilter != YFilter.not_set or
                                self.fe_ctype.yfilter != YFilter.not_set or
                                self.forward_class.yfilter != YFilter.not_set or
                                self.freq_mismatched.yfilter != YFilter.not_set or
                                self.illegal_control_word.yfilter != YFilter.not_set or
                                self.imposed_vlan_id.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.ipv6_local_source_address.yfilter != YFilter.not_set or
                                self.is_evpnvpws_type.yfilter != YFilter.not_set or
                                self.is_flow_label_static.yfilter != YFilter.not_set or
                                self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                                self.is_partially_programmed.yfilter != YFilter.not_set or
                                self.is_pwr_type.yfilter != YFilter.not_set or
                                self.is_vfi.yfilter != YFilter.not_set or
                                self.last_time_status_changed.yfilter != YFilter.not_set or
                                self.last_time_status_down.yfilter != YFilter.not_set or
                                self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                                self.load_balance.yfilter != YFilter.not_set or
                                self.local_control_word.yfilter != YFilter.not_set or
                                self.local_label_failed.yfilter != YFilter.not_set or
                                self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.local_source_address.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.not_supported_qinq.yfilter != YFilter.not_set or
                                self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                                self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                                self.payload_type_mismatched.yfilter != YFilter.not_set or
                                self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                                self.primary_peer_id.yfilter != YFilter.not_set or
                                self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                                self.primary_pw.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.pseudo_wire_id.yfilter != YFilter.not_set or
                                self.pseudo_wire_state.yfilter != YFilter.not_set or
                                self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                                self.pw_class_name.yfilter != YFilter.not_set or
                                self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                                self.pw_flow_label_type.yfilter != YFilter.not_set or
                                self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                                self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                                self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                                self.pw_status_use.yfilter != YFilter.not_set or
                                self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                                self.remote_control_word.yfilter != YFilter.not_set or
                                self.remote_label_failed.yfilter != YFilter.not_set or
                                self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                                self.required_bw.yfilter != YFilter.not_set or
                                self.resync_enabled.yfilter != YFilter.not_set or
                                self.resync_threshold.yfilter != YFilter.not_set or
                                self.rtp_mismatched.yfilter != YFilter.not_set or
                                self.sequencing_type.yfilter != YFilter.not_set or
                                self.shutdown.yfilter != YFilter.not_set or
                                self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                                self.ssrc_mismatched.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.table_policy_name.yfilter != YFilter.not_set or
                                self.tag_rewrite.yfilter != YFilter.not_set or
                                self.time_created.yfilter != YFilter.not_set or
                                self.time_elapsed_creation.yfilter != YFilter.not_set or
                                self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                                self.time_elapsed_status_down.yfilter != YFilter.not_set or
                                self.transport_lsp_down.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                                (self.local_interface is not None and self.local_interface.has_operation()) or
                                (self.local_signalling is not None and self.local_signalling.has_operation()) or
                                (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                                (self.peer_id is not None and self.peer_id.has_operation()) or
                                (self.preferred_path is not None and self.preferred_path.has_operation()) or
                                (self.remote_interface is not None and self.remote_interface.has_operation()) or
                                (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pseudowire" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                            if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admited_bw.get_name_leafdata())
                            if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                            if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_active.get_name_leafdata())
                            if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                            if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backup_pw.get_name_leafdata())
                            if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                            if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                            if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                            if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                            if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_delay.get_name_leafdata())
                            if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable_never.get_name_leafdata())
                            if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                            if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                            if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forward_class.get_name_leafdata())
                            if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                            if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                            if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                            if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                            if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                            if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                            if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                            if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                            if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_vfi.get_name_leafdata())
                            if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                            if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                            if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                            if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance.get_name_leafdata())
                            if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_control_word.get_name_leafdata())
                            if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                            if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                            if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_source_address.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                            if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                            if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                            if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                            if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                            if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                            if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                            if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_pw.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                            if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                            if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                            if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                            if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                            if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                            if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                            if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                            if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                            if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                            if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                            if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                            if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                            if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                            if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.required_bw.get_name_leafdata())
                            if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                            if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                            if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                            if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                            if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.shutdown.get_name_leafdata())
                            if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                            if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                            if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                            if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_created.get_name_leafdata())
                            if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                            if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                            if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                            if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "encapsulation-info"):
                                if (self.encapsulation_info is None):
                                    self.encapsulation_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"
                                return self.encapsulation_info

                            if (child_yang_name == "local-interface"):
                                if (self.local_interface is None):
                                    self.local_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"
                                return self.local_interface

                            if (child_yang_name == "local-signalling"):
                                if (self.local_signalling is None):
                                    self.local_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"
                                return self.local_signalling

                            if (child_yang_name == "p2mp-pw"):
                                if (self.p2mp_pw is None):
                                    self.p2mp_pw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                return self.p2mp_pw

                            if (child_yang_name == "peer-id"):
                                if (self.peer_id is None):
                                    self.peer_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"
                                return self.peer_id

                            if (child_yang_name == "preferred-path"):
                                if (self.preferred_path is None):
                                    self.preferred_path = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"
                                return self.preferred_path

                            if (child_yang_name == "remote-interface"):
                                if (self.remote_interface is None):
                                    self.remote_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"
                                return self.remote_interface

                            if (child_yang_name == "remote-signalling"):
                                if (self.remote_signalling is None):
                                    self.remote_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"
                                return self.remote_signalling

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-remote-down"):
                                self.ad_remote_down = value
                                self.ad_remote_down.value_namespace = name_space
                                self.ad_remote_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "admited-bw"):
                                self.admited_bw = value
                                self.admited_bw.value_namespace = name_space
                                self.admited_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "auto-discovery"):
                                self.auto_discovery = value
                                self.auto_discovery.value_namespace = name_space
                                self.auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-active"):
                                self.backup_active = value
                                self.backup_active.value_namespace = name_space
                                self.backup_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-force-active"):
                                self.backup_force_active = value
                                self.backup_force_active.value_namespace = name_space
                                self.backup_force_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "backup-pw"):
                                self.backup_pw = value
                                self.backup_pw.value_namespace = name_space
                                self.backup_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "bitrate-mismatched"):
                                self.bitrate_mismatched = value
                                self.bitrate_mismatched.value_namespace = name_space
                                self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-pw-type-mismatch"):
                                self.bridge_pw_type_mismatch = value
                                self.bridge_pw_type_mismatch.value_namespace = name_space
                                self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "cas-mismatched"):
                                self.cas_mismatched = value
                                self.cas_mismatched.value_namespace = name_space
                                self.cas_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "diff-ts-mismatched"):
                                self.diff_ts_mismatched = value
                                self.diff_ts_mismatched.value_namespace = name_space
                                self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-delay"):
                                self.disable_delay = value
                                self.disable_delay.value_namespace = name_space
                                self.disable_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable-never"):
                                self.disable_never = value
                                self.disable_never.value_namespace = name_space
                                self.disable_never.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-src-acid"):
                                self.evpn_src_acid = value
                                self.evpn_src_acid.value_namespace = name_space
                                self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                            if(value_path == "fe-ctype"):
                                self.fe_ctype = value
                                self.fe_ctype.value_namespace = name_space
                                self.fe_ctype.value_namespace_prefix = name_space_prefix
                            if(value_path == "forward-class"):
                                self.forward_class = value
                                self.forward_class.value_namespace = name_space
                                self.forward_class.value_namespace_prefix = name_space_prefix
                            if(value_path == "freq-mismatched"):
                                self.freq_mismatched = value
                                self.freq_mismatched.value_namespace = name_space
                                self.freq_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-control-word"):
                                self.illegal_control_word = value
                                self.illegal_control_word.value_namespace = name_space
                                self.illegal_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "imposed-vlan-id"):
                                self.imposed_vlan_id = value
                                self.imposed_vlan_id.value_namespace = name_space
                                self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-local-source-address"):
                                self.ipv6_local_source_address = value
                                self.ipv6_local_source_address.value_namespace = name_space
                                self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-evpnvpws-type"):
                                self.is_evpnvpws_type = value
                                self.is_evpnvpws_type.value_namespace = name_space
                                self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-flow-label-static"):
                                self.is_flow_label_static = value
                                self.is_flow_label_static.value_namespace = name_space
                                self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-multi-segment-pseudowire"):
                                self.is_multi_segment_pseudowire = value
                                self.is_multi_segment_pseudowire.value_namespace = name_space
                                self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-partially-programmed"):
                                self.is_partially_programmed = value
                                self.is_partially_programmed.value_namespace = name_space
                                self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-pwr-type"):
                                self.is_pwr_type = value
                                self.is_pwr_type.value_namespace = name_space
                                self.is_pwr_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-vfi"):
                                self.is_vfi = value
                                self.is_vfi.value_namespace = name_space
                                self.is_vfi.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-changed"):
                                self.last_time_status_changed = value
                                self.last_time_status_changed.value_namespace = name_space
                                self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-status-down"):
                                self.last_time_status_down = value
                                self.last_time_status_down.value_namespace = name_space
                                self.last_time_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-label-advertise-failed"):
                                self.ldp_label_advertise_failed = value
                                self.ldp_label_advertise_failed.value_namespace = name_space
                                self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance"):
                                self.load_balance = value
                                self.load_balance.value_namespace = name_space
                                self.load_balance.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-control-word"):
                                self.local_control_word = value
                                self.local_control_word.value_namespace = name_space
                                self.local_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label-failed"):
                                self.local_label_failed = value
                                self.local_label_failed.value_namespace = name_space
                                self.local_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-pseudo-wire-type"):
                                self.local_pseudo_wire_type = value
                                self.local_pseudo_wire_type.value_namespace = name_space
                                self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-source-address"):
                                self.local_source_address = value
                                self.local_source_address.value_namespace = name_space
                                self.local_source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-qinq"):
                                self.not_supported_qinq = value
                                self.not_supported_qinq.value_namespace = name_space
                                self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                            if(value_path == "num-ma-cwithdraw-msg-received"):
                                self.num_ma_cwithdraw_msg_received = value
                                self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                                self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-ma-cwithdraw-message-sent"):
                                self.number_ma_cwithdraw_message_sent = value
                                self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                                self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes-mismatched"):
                                self.payload_bytes_mismatched = value
                                self.payload_bytes_mismatched.value_namespace = name_space
                                self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-type-mismatched"):
                                self.payload_type_mismatched = value
                                self.payload_type_mismatched.value_namespace = name_space
                                self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "preferred-path-disable-fallback"):
                                self.preferred_path_disable_fallback = value
                                self.preferred_path_disable_fallback.value_namespace = name_space
                                self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-peer-id"):
                                self.primary_peer_id = value
                                self.primary_peer_id.value_namespace = name_space
                                self.primary_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pseudo-wire-id"):
                                self.primary_pseudo_wire_id = value
                                self.primary_pseudo_wire_id.value_namespace = name_space
                                self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-pw"):
                                self.primary_pw = value
                                self.primary_pw.value_namespace = name_space
                                self.primary_pw.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-id"):
                                self.pseudo_wire_id = value
                                self.pseudo_wire_id.value_namespace = name_space
                                self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-state"):
                                self.pseudo_wire_state = value
                                self.pseudo_wire_state.value_namespace = name_space
                                self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "pseudo-wire-type-mismatched"):
                                self.pseudo_wire_type_mismatched = value
                                self.pseudo_wire_type_mismatched.value_namespace = name_space
                                self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-class-name"):
                                self.pw_class_name = value
                                self.pw_class_name.value_namespace = name_space
                                self.pw_class_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-code17-disabled"):
                                self.pw_flow_label_code17_disabled = value
                                self.pw_flow_label_code17_disabled.value_namespace = name_space
                                self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type"):
                                self.pw_flow_label_type = value
                                self.pw_flow_label_type.value_namespace = name_space
                                self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-flow-label-type-cfg"):
                                self.pw_flow_label_type_cfg = value
                                self.pw_flow_label_type_cfg.value_namespace = name_space
                                self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-initial-delay"):
                                self.pw_redundancy_initial_delay = value
                                self.pw_redundancy_initial_delay.value_namespace = name_space
                                self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-redundancy-one-way"):
                                self.pw_redundancy_one_way = value
                                self.pw_redundancy_one_way.value_namespace = name_space
                                self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                            if(value_path == "pw-status-use"):
                                self.pw_status_use = value
                                self.pw_status_use.value_namespace = name_space
                                self.pw_status_use.value_namespace_prefix = name_space_prefix
                            if(value_path == "pwlsd-rewrite-failed"):
                                self.pwlsd_rewrite_failed = value
                                self.pwlsd_rewrite_failed.value_namespace = name_space
                                self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-control-word"):
                                self.remote_control_word = value
                                self.remote_control_word.value_namespace = name_space
                                self.remote_control_word.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label-failed"):
                                self.remote_label_failed = value
                                self.remote_label_failed.value_namespace = name_space
                                self.remote_label_failed.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-pseudo-wire-type"):
                                self.remote_pseudo_wire_type = value
                                self.remote_pseudo_wire_type.value_namespace = name_space
                                self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "required-bw"):
                                self.required_bw = value
                                self.required_bw.value_namespace = name_space
                                self.required_bw.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-enabled"):
                                self.resync_enabled = value
                                self.resync_enabled.value_namespace = name_space
                                self.resync_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "resync-threshold"):
                                self.resync_threshold = value
                                self.resync_threshold.value_namespace = name_space
                                self.resync_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "rtp-mismatched"):
                                self.rtp_mismatched = value
                                self.rtp_mismatched.value_namespace = name_space
                                self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "sequencing-type"):
                                self.sequencing_type = value
                                self.sequencing_type.value_namespace = name_space
                                self.sequencing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "shutdown"):
                                self.shutdown = value
                                self.shutdown.value_namespace = name_space
                                self.shutdown.value_namespace_prefix = name_space_prefix
                            if(value_path == "sig-pkts-mismatched"):
                                self.sig_pkts_mismatched = value
                                self.sig_pkts_mismatched.value_namespace = name_space
                                self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssrc-mismatched"):
                                self.ssrc_mismatched = value
                                self.ssrc_mismatched.value_namespace = name_space
                                self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-policy-name"):
                                self.table_policy_name = value
                                self.table_policy_name.value_namespace = name_space
                                self.table_policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag-rewrite"):
                                self.tag_rewrite = value
                                self.tag_rewrite.value_namespace = name_space
                                self.tag_rewrite.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-created"):
                                self.time_created = value
                                self.time_created.value_namespace = name_space
                                self.time_created.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-creation"):
                                self.time_elapsed_creation = value
                                self.time_elapsed_creation.value_namespace = name_space
                                self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-changed"):
                                self.time_elapsed_status_changed = value
                                self.time_elapsed_status_changed.value_namespace = name_space
                                self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-elapsed-status-down"):
                                self.time_elapsed_status_down = value
                                self.time_elapsed_status_down.value_namespace = name_space
                                self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-lsp-down"):
                                self.transport_lsp_down = value
                                self.transport_lsp_down.value_namespace = name_space
                                self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix


                    class SecurityParameters(Entity):
                        """
                        Security Parameters
                        
                        .. attribute:: base
                        
                        	Basic Security Parameters
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        .. attribute:: dhcpv4_trust
                        
                        	DHCPv4 Trust Status
                        	**type**\:  bool
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__init__()

                            self.yang_name = "security-parameters"
                            self.yang_parent_name = "bridge-access-pw"

                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                            self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                            self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._children_yang_names.add("base")

                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self._children_name_map["storm_control"] = "storm-control"
                            self._children_yang_names.add("storm-control")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("broadcast_storm_control_kb_ps",
                                            "broadcast_storm_control_pps",
                                            "broadcast_storm_control_rate_unit",
                                            "dhcpv4_trust",
                                            "multicast_storm_control_kb_ps",
                                            "multicast_storm_control_pps",
                                            "multicast_storm_control_rate_unit",
                                            "unicast_storm_control_kb_ps",
                                            "unicast_storm_control_pps",
                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__setattr__(name, value)


                        class Base(Entity):
                            """
                            Basic Security Parameters
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dai_address_validation_mask
                            
                            	DAI Address Validation mask
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dhcpv4_profile_name
                            
                            	DHCPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: dhcpv4_snoop
                            
                            	DHCPv4 Snoop Status
                            	**type**\:  bool
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Flooding unknown unicast enabled
                            	**type**\:  bool
                            
                            .. attribute:: flood_uu_disabled_mac_limit_action
                            
                            	Flooding of unknown\-unicast disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_disabled
                            
                            	IGMPv4 Disabled
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_profile_name
                            
                            	IGMPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                            
                            	Is DAI Dstination MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                            
                            	Is DAI IPv4 Addr Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_source_guard_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                            
                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: learn_disabled_mac_limit_action
                            
                            	Learning disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_mode
                            
                            	MAC Aging Mode
                            	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: mac_flooding
                            
                            	MAC flooding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning
                            
                            	MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC address limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                            
                            .. attribute:: mac_limit_notification
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                            
                            .. attribute:: mac_limit_reached
                            
                            	MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mac_port_down_flush_enabled
                            
                            	MAC Flush when port goes down
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC Secure Action
                            	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                            
                            .. attribute:: mld_profile_name
                            
                            	MLD Profile Name
                            	**type**\:  str
                            
                            .. attribute:: mmrp_flood_optimization
                            
                            	MMRP Flood Optimization Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: split_horizon_group_id
                            
                            	Split Horizon Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "security-parameters"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dai_address_validation_mask",
                                                "dhcpv4_profile_name",
                                                "dhcpv4_snoop",
                                                "flood_unknown_unicast_enabled",
                                                "flood_uu_disabled_mac_limit_action",
                                                "igm_pv4_disabled",
                                                "igm_pv4_profile_name",
                                                "is_dai_addr_validate_destination_mac_enabled",
                                                "is_dai_addr_validate_ipv4_enabled",
                                                "is_dai_addr_validate_source_mac_enabled",
                                                "is_dai_enabled",
                                                "is_dai_logging_enabled",
                                                "is_ip_source_guard_enabled",
                                                "is_ipsg_logging_enabled",
                                                "is_mac_secure_accept_shutdown_enabled",
                                                "is_mac_secure_enabled",
                                                "is_mac_secure_logging_enabled",
                                                "learn_disabled_mac_limit_action",
                                                "mac_aging_mode",
                                                "mac_aging_time",
                                                "mac_flooding",
                                                "mac_learning",
                                                "mac_limit",
                                                "mac_limit_action",
                                                "mac_limit_notification",
                                                "mac_limit_reached",
                                                "mac_port_down_flush_enabled",
                                                "mac_secure_action",
                                                "mld_profile_name",
                                                "mmrp_flood_optimization",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "split_horizon_group_id",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__setattr__(name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "base"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/base/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dai_address_validation_mask.is_set or
                                    self.dhcpv4_profile_name.is_set or
                                    self.dhcpv4_snoop.is_set or
                                    self.flood_unknown_unicast_enabled.is_set or
                                    self.flood_uu_disabled_mac_limit_action.is_set or
                                    self.igm_pv4_disabled.is_set or
                                    self.igm_pv4_profile_name.is_set or
                                    self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                    self.is_dai_addr_validate_ipv4_enabled.is_set or
                                    self.is_dai_addr_validate_source_mac_enabled.is_set or
                                    self.is_dai_enabled.is_set or
                                    self.is_dai_logging_enabled.is_set or
                                    self.is_ip_source_guard_enabled.is_set or
                                    self.is_ipsg_logging_enabled.is_set or
                                    self.is_mac_secure_accept_shutdown_enabled.is_set or
                                    self.is_mac_secure_enabled.is_set or
                                    self.is_mac_secure_logging_enabled.is_set or
                                    self.learn_disabled_mac_limit_action.is_set or
                                    self.mac_aging_mode.is_set or
                                    self.mac_aging_time.is_set or
                                    self.mac_flooding.is_set or
                                    self.mac_learning.is_set or
                                    self.mac_limit.is_set or
                                    self.mac_limit_action.is_set or
                                    self.mac_limit_notification.is_set or
                                    self.mac_limit_reached.is_set or
                                    self.mac_port_down_flush_enabled.is_set or
                                    self.mac_secure_action.is_set or
                                    self.mld_profile_name.is_set or
                                    self.mmrp_flood_optimization.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.split_horizon_group_id.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                    self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                    self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                    self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                    self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                    self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                    self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                    self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                    self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                    self.mac_aging_mode.yfilter != YFilter.not_set or
                                    self.mac_aging_time.yfilter != YFilter.not_set or
                                    self.mac_flooding.yfilter != YFilter.not_set or
                                    self.mac_learning.yfilter != YFilter.not_set or
                                    self.mac_limit.yfilter != YFilter.not_set or
                                    self.mac_limit_action.yfilter != YFilter.not_set or
                                    self.mac_limit_notification.yfilter != YFilter.not_set or
                                    self.mac_limit_reached.yfilter != YFilter.not_set or
                                    self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                    self.mac_secure_action.yfilter != YFilter.not_set or
                                    self.mld_profile_name.yfilter != YFilter.not_set or
                                    self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.split_horizon_group_id.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "base" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dai-address-validation-mask"):
                                    self.dai_address_validation_mask = value
                                    self.dai_address_validation_mask.value_namespace = name_space
                                    self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-profile-name"):
                                    self.dhcpv4_profile_name = value
                                    self.dhcpv4_profile_name.value_namespace = name_space
                                    self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-snoop"):
                                    self.dhcpv4_snoop = value
                                    self.dhcpv4_snoop.value_namespace = name_space
                                    self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-unknown-unicast-enabled"):
                                    self.flood_unknown_unicast_enabled = value
                                    self.flood_unknown_unicast_enabled.value_namespace = name_space
                                    self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-uu-disabled-mac-limit-action"):
                                    self.flood_uu_disabled_mac_limit_action = value
                                    self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                    self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "igm-pv4-disabled"):
                                    self.igm_pv4_disabled = value
                                    self.igm_pv4_disabled.value_namespace = name_space
                                    self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igm-pv4-profile-name"):
                                    self.igm_pv4_profile_name = value
                                    self.igm_pv4_profile_name.value_namespace = name_space
                                    self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                    self.is_dai_addr_validate_destination_mac_enabled = value
                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                    self.is_dai_addr_validate_ipv4_enabled = value
                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                    self.is_dai_addr_validate_source_mac_enabled = value
                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-enabled"):
                                    self.is_dai_enabled = value
                                    self.is_dai_enabled.value_namespace = name_space
                                    self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-logging-enabled"):
                                    self.is_dai_logging_enabled = value
                                    self.is_dai_logging_enabled.value_namespace = name_space
                                    self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ip-source-guard-enabled"):
                                    self.is_ip_source_guard_enabled = value
                                    self.is_ip_source_guard_enabled.value_namespace = name_space
                                    self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ipsg-logging-enabled"):
                                    self.is_ipsg_logging_enabled = value
                                    self.is_ipsg_logging_enabled.value_namespace = name_space
                                    self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                    self.is_mac_secure_accept_shutdown_enabled = value
                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-enabled"):
                                    self.is_mac_secure_enabled = value
                                    self.is_mac_secure_enabled.value_namespace = name_space
                                    self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-logging-enabled"):
                                    self.is_mac_secure_logging_enabled = value
                                    self.is_mac_secure_logging_enabled.value_namespace = name_space
                                    self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "learn-disabled-mac-limit-action"):
                                    self.learn_disabled_mac_limit_action = value
                                    self.learn_disabled_mac_limit_action.value_namespace = name_space
                                    self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-mode"):
                                    self.mac_aging_mode = value
                                    self.mac_aging_mode.value_namespace = name_space
                                    self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-time"):
                                    self.mac_aging_time = value
                                    self.mac_aging_time.value_namespace = name_space
                                    self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-flooding"):
                                    self.mac_flooding = value
                                    self.mac_flooding.value_namespace = name_space
                                    self.mac_flooding.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-learning"):
                                    self.mac_learning = value
                                    self.mac_learning.value_namespace = name_space
                                    self.mac_learning.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit"):
                                    self.mac_limit = value
                                    self.mac_limit.value_namespace = name_space
                                    self.mac_limit.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-action"):
                                    self.mac_limit_action = value
                                    self.mac_limit_action.value_namespace = name_space
                                    self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-notification"):
                                    self.mac_limit_notification = value
                                    self.mac_limit_notification.value_namespace = name_space
                                    self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-reached"):
                                    self.mac_limit_reached = value
                                    self.mac_limit_reached.value_namespace = name_space
                                    self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-port-down-flush-enabled"):
                                    self.mac_port_down_flush_enabled = value
                                    self.mac_port_down_flush_enabled.value_namespace = name_space
                                    self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-secure-action"):
                                    self.mac_secure_action = value
                                    self.mac_secure_action.value_namespace = name_space
                                    self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-profile-name"):
                                    self.mld_profile_name = value
                                    self.mld_profile_name.value_namespace = name_space
                                    self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "mmrp-flood-optimization"):
                                    self.mmrp_flood_optimization = value
                                    self.mmrp_flood_optimization.value_namespace = name_space
                                    self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "split-horizon-group-id"):
                                    self.split_horizon_group_id = value
                                    self.split_horizon_group_id.value_namespace = name_space
                                    self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class StormControl(Entity):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\:  bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__init__()

                                self.yang_name = "storm-control"
                                self.yang_parent_name = "security-parameters"

                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                self.multicast = YLeaf(YType.boolean, "multicast")

                                self.unicast = YLeaf(YType.boolean, "unicast")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bd_policer",
                                                "broadcast",
                                                "multicast",
                                                "unicast") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bd_policer.is_set or
                                    self.broadcast.is_set or
                                    self.multicast.is_set or
                                    self.unicast.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bd_policer.yfilter != YFilter.not_set or
                                    self.broadcast.yfilter != YFilter.not_set or
                                    self.multicast.yfilter != YFilter.not_set or
                                    self.unicast.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "storm-control" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bd-policer"):
                                    self.bd_policer = value
                                    self.bd_policer.value_namespace = name_space
                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast"):
                                    self.broadcast = value
                                    self.broadcast.value_namespace = name_space
                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast"):
                                    self.multicast = value
                                    self.multicast.value_namespace = name_space
                                    self.multicast.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast"):
                                    self.unicast = value
                                    self.unicast.value_namespace = name_space
                                    self.unicast.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.broadcast_storm_control_kb_ps.is_set or
                                self.broadcast_storm_control_pps.is_set or
                                self.broadcast_storm_control_rate_unit.is_set or
                                self.dhcpv4_trust.is_set or
                                self.multicast_storm_control_kb_ps.is_set or
                                self.multicast_storm_control_pps.is_set or
                                self.multicast_storm_control_rate_unit.is_set or
                                self.unicast_storm_control_kb_ps.is_set or
                                self.unicast_storm_control_pps.is_set or
                                self.unicast_storm_control_rate_unit.is_set or
                                (self.base is not None and self.base.has_data()) or
                                (self.storm_control is not None and self.storm_control.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                self.dhcpv4_trust.yfilter != YFilter.not_set or
                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                (self.base is not None and self.base.has_operation()) or
                                (self.storm_control is not None and self.storm_control.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "security-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                            if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "base"):
                                if (self.base is None):
                                    self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                return self.base

                            if (child_yang_name == "storm-control"):
                                if (self.storm_control is None):
                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                return self.storm_control

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "broadcast-storm-control-kb-ps"):
                                self.broadcast_storm_control_kb_ps = value
                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-pps"):
                                self.broadcast_storm_control_pps = value
                                self.broadcast_storm_control_pps.value_namespace = name_space
                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-rate-unit"):
                                self.broadcast_storm_control_rate_unit = value
                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "dhcpv4-trust"):
                                self.dhcpv4_trust = value
                                self.dhcpv4_trust.value_namespace = name_space
                                self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-kb-ps"):
                                self.multicast_storm_control_kb_ps = value
                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-pps"):
                                self.multicast_storm_control_pps = value
                                self.multicast_storm_control_pps.value_namespace = name_space
                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-rate-unit"):
                                self.multicast_storm_control_rate_unit = value
                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-kb-ps"):
                                self.unicast_storm_control_kb_ps = value
                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-pps"):
                                self.unicast_storm_control_pps = value
                                self.unicast_storm_control_pps.value_namespace = name_space
                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-rate-unit"):
                                self.unicast_storm_control_rate_unit = value
                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                    class StaticMac(Entity):
                        """
                        Static MAC addresses
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__init__()

                            self.yang_name = "static-mac"
                            self.yang_parent_name = "bridge-access-pw"

                            self.address = YLeaf(YType.str, "address")

                            self.bmac = YLeaf(YType.str, "bmac")

                            self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "bmac",
                                            "next_hop_ip") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.bmac.is_set or
                                self.next_hop_ip.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.bmac.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "static-mac" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bmac.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "bmac"):
                                self.bmac = value
                                self.bmac.value_namespace = name_space
                                self.bmac.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.static_mac:
                            if (c.has_data()):
                                return True
                        return (
                            self.is_access.is_set or
                            self.neighbor.is_set or
                            self.pseudowire_id.is_set or
                            (self.pseudowire is not None and self.pseudowire.has_data()) or
                            (self.security_parameters is not None and self.security_parameters.has_data()))

                    def has_operation(self):
                        for c in self.static_mac:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_access.yfilter != YFilter.not_set or
                            self.neighbor.yfilter != YFilter.not_set or
                            self.pseudowire_id.yfilter != YFilter.not_set or
                            (self.pseudowire is not None and self.pseudowire.has_operation()) or
                            (self.security_parameters is not None and self.security_parameters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-access-pw" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-access-pws/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_access.is_set or self.is_access.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_access.get_name_leafdata())
                        if (self.neighbor.is_set or self.neighbor.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor.get_name_leafdata())
                        if (self.pseudowire_id.is_set or self.pseudowire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudowire_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "pseudowire"):
                            if (self.pseudowire is None):
                                self.pseudowire = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"
                            return self.pseudowire

                        if (child_yang_name == "security-parameters"):
                            if (self.security_parameters is None):
                                self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                            return self.security_parameters

                        if (child_yang_name == "static-mac"):
                            for c in self.static_mac:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.static_mac.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "pseudowire" or name == "security-parameters" or name == "static-mac" or name == "is-access" or name == "neighbor" or name == "pseudowire-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-access"):
                            self.is_access = value
                            self.is_access.value_namespace = name_space
                            self.is_access.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor"):
                            self.neighbor = value
                            self.neighbor.value_namespace = name_space
                            self.neighbor.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudowire-id"):
                            self.pseudowire_id = value
                            self.pseudowire_id.value_namespace = name_space
                            self.pseudowire_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bridge_access_pw:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bridge_access_pw:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bridge-access-pws" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bridge-access-pw"):
                        for c in self.bridge_access_pw:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bridge_access_pw.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bridge-access-pw"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BridgeDomainInfo(Entity):
                """
                VPLS Bridge Domain Information
                
                .. attribute:: acpwup
                
                	Number of bridge ports (AC,PW) which are up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: as_
                
                	BGP AS number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_access_vfi
                
                	Access Virtual Forwarding Interfaces
                	**type**\: list of    :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                
                .. attribute:: bridge_coupled_state
                
                	Bridge\-domain coupled state
                	**type**\:   :py:class:`L2VpnBridgeCoupledState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeCoupledState>`
                
                .. attribute:: bridge_description
                
                	Human\-readable bridge\-domain description
                	**type**\:  str
                
                .. attribute:: bridge_domain_id
                
                	Identification number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_internal_msti
                
                	Bridge\-domain internal msti
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_msti
                
                	Bridge\-domain msti
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_mtu
                
                	Maximum transmission unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_name
                
                	Bridge\-domain name
                	**type**\:  str
                
                .. attribute:: bridge_shg_id
                
                	Bridge\-domain shgid
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_state
                
                	Bridge\-domain state
                	**type**\:   :py:class:`L2VpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeState>`
                
                .. attribute:: bridge_type
                
                	Bridge\-domain type
                	**type**\:   :py:class:`L2VpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridge>`
                
                .. attribute:: bridge_vfi
                
                	Virtual Forwarding Interfaces
                	**type**\: list of    :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                
                .. attribute:: configured
                
                	Bridge\-domain is configured
                	**type**\:  bool
                
                .. attribute:: disposition_bytecount
                
                	EVPN Disposition Byte Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: disposition_pkt_count
                
                	EVPN Disposition Packet Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: evi
                
                	E\-VPN id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: evpn_parameters
                
                	EVPN parameters
                	**type**\:   :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                
                .. attribute:: flodd_group_id_down
                
                	Oper down because no FGID
                	**type**\:  bool
                
                .. attribute:: group_name
                
                	Group name
                	**type**\:  str
                
                .. attribute:: imposition_byte_count
                
                	EVPN Imposition Byte Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: imposition_pkt_count
                
                	EVPN Imposition Packet Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_bridge_partially_programmed
                
                	Bridge is partially programmed
                	**type**\:  bool
                
                .. attribute:: is_rd_configured
                
                	Config or Auto
                	**type**\:  bool
                
                .. attribute:: last_time_status_changed
                
                	Last time the bridge domain status changed
                	**type**\:  str
                
                	**length:** 0..50
                
                .. attribute:: load_balance
                
                	Load Balance Type
                	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                
                .. attribute:: mac_filter
                
                	MAC addresses for filtering
                	**type**\: list of    :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                
                .. attribute:: mac_limit_down
                
                	Oper down because MAC limit reached
                	**type**\:  bool
                
                .. attribute:: mac_withdraw
                
                	MAC withdraw enabled
                	**type**\:  bool
                
                .. attribute:: mac_withdraw_access
                
                	MAC Access PW withdraw enabled
                	**type**\:  bool
                
                .. attribute:: mac_withdraw_option
                
                	Event on which MAC withdraw is sent
                	**type**\:   :py:class:`L2VpnBagMacWithdrawOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacWithdrawOption>`
                
                .. attribute:: mac_withdraw_relay
                
                	MAC Access PW withdraw relaying from access to access enabled
                	**type**\:  bool
                
                .. attribute:: num_vn_is
                
                	Number of VNIs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_up
                
                	Number of VNIs up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs
                
                	Number of attachment circuits
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs_up
                
                	Number of attachment circuits up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_access_vf_is
                
                	Number of Access VFIs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p_ws_up
                
                	Number of pseudowires up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pb_bs
                
                	Number of pbbs
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: number_pb_bs_up
                
                	Number of pbbs up
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: number_pseudowires
                
                	Number of pseudowires
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_vf_is
                
                	Number of virtual forwarding interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                
                	nV Satellite Offload IPv4 Multicast Disabled
                	**type**\:  bool
                
                .. attribute:: p2mp_enabled
                
                	P2MP Enabled on this Bridge Domain
                	**type**\:  bool
                
                .. attribute:: partially_programmed_a_cs
                
                	Number of attachment circuits partially programmed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_pseudowires
                
                	Number of pseudowires partially programmed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pbb_parameters
                
                	PBB parameters
                	**type**\:   :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                
                .. attribute:: rd
                
                	Route Distinguisher
                	**type**\:   :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                
                .. attribute:: security_parameters
                
                	Security parameters
                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                
                .. attribute:: shutdown
                
                	Administratively disabled
                	**type**\:  bool
                
                .. attribute:: standby_pseudowires
                
                	Number of pseudowires standby
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: time_created
                
                	Time when the bridge domain was created
                	**type**\:  str
                
                	**length:** 0..50
                
                .. attribute:: time_elapsed_creation
                
                	Time elapsed since creation
                	**type**\:  str
                
                	**length:** 0..50
                
                .. attribute:: time_elapsed_status_changed
                
                	Time elapsed since status changed
                	**type**\:  str
                
                	**length:** 0..50
                
                .. attribute:: vine_fsm_state
                
                	VNI, IRB, Native\-Evpn state
                	**type**\:  str
                
                .. attribute:: vni_parameters
                
                	VNI parameters
                	**type**\:   :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__init__()

                    self.yang_name = "bridge-domain-info"
                    self.yang_parent_name = "bridge-domain"

                    self.acpwup = YLeaf(YType.uint32, "acpwup")

                    self.as_ = YLeaf(YType.uint32, "as")

                    self.bridge_coupled_state = YLeaf(YType.enumeration, "bridge-coupled-state")

                    self.bridge_description = YLeaf(YType.str, "bridge-description")

                    self.bridge_domain_id = YLeaf(YType.uint32, "bridge-domain-id")

                    self.bridge_internal_msti = YLeaf(YType.uint32, "bridge-internal-msti")

                    self.bridge_msti = YLeaf(YType.uint32, "bridge-msti")

                    self.bridge_mtu = YLeaf(YType.uint32, "bridge-mtu")

                    self.bridge_name = YLeaf(YType.str, "bridge-name")

                    self.bridge_shg_id = YLeaf(YType.uint32, "bridge-shg-id")

                    self.bridge_state = YLeaf(YType.enumeration, "bridge-state")

                    self.bridge_type = YLeaf(YType.enumeration, "bridge-type")

                    self.configured = YLeaf(YType.boolean, "configured")

                    self.disposition_bytecount = YLeaf(YType.uint64, "disposition-bytecount")

                    self.disposition_pkt_count = YLeaf(YType.uint64, "disposition-pkt-count")

                    self.evi = YLeaf(YType.uint32, "evi")

                    self.flodd_group_id_down = YLeaf(YType.boolean, "flodd-group-id-down")

                    self.group_name = YLeaf(YType.str, "group-name")

                    self.imposition_byte_count = YLeaf(YType.uint64, "imposition-byte-count")

                    self.imposition_pkt_count = YLeaf(YType.uint64, "imposition-pkt-count")

                    self.is_bridge_partially_programmed = YLeaf(YType.boolean, "is-bridge-partially-programmed")

                    self.is_rd_configured = YLeaf(YType.boolean, "is-rd-configured")

                    self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                    self.load_balance = YLeaf(YType.enumeration, "load-balance")

                    self.mac_limit_down = YLeaf(YType.boolean, "mac-limit-down")

                    self.mac_withdraw = YLeaf(YType.boolean, "mac-withdraw")

                    self.mac_withdraw_access = YLeaf(YType.boolean, "mac-withdraw-access")

                    self.mac_withdraw_option = YLeaf(YType.enumeration, "mac-withdraw-option")

                    self.mac_withdraw_relay = YLeaf(YType.boolean, "mac-withdraw-relay")

                    self.num_vn_is = YLeaf(YType.uint32, "num-vn-is")

                    self.num_vn_is_up = YLeaf(YType.uint32, "num-vn-is-up")

                    self.number_a_cs = YLeaf(YType.uint32, "number-a-cs")

                    self.number_a_cs_up = YLeaf(YType.uint32, "number-a-cs-up")

                    self.number_access_vf_is = YLeaf(YType.uint32, "number-access-vf-is")

                    self.number_p_ws_up = YLeaf(YType.uint32, "number-p-ws-up")

                    self.number_pb_bs = YLeaf(YType.uint8, "number-pb-bs")

                    self.number_pb_bs_up = YLeaf(YType.uint8, "number-pb-bs-up")

                    self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                    self.number_vf_is = YLeaf(YType.uint32, "number-vf-is")

                    self.nv_satellite_offload_ipv4_multicast_disabled = YLeaf(YType.boolean, "nv-satellite-offload-ipv4-multicast-disabled")

                    self.p2mp_enabled = YLeaf(YType.boolean, "p2mp-enabled")

                    self.partially_programmed_a_cs = YLeaf(YType.uint32, "partially-programmed-a-cs")

                    self.partially_programmed_pseudowires = YLeaf(YType.uint32, "partially-programmed-pseudowires")

                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                    self.standby_pseudowires = YLeaf(YType.uint32, "standby-pseudowires")

                    self.time_created = YLeaf(YType.str, "time-created")

                    self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                    self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                    self.vine_fsm_state = YLeaf(YType.str, "vine-fsm-state")

                    self.evpn_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                    self.evpn_parameters.parent = self
                    self._children_name_map["evpn_parameters"] = "evpn-parameters"
                    self._children_yang_names.add("evpn-parameters")

                    self.pbb_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                    self.pbb_parameters.parent = self
                    self._children_name_map["pbb_parameters"] = "pbb-parameters"
                    self._children_yang_names.add("pbb-parameters")

                    self.rd = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                    self.rd.parent = self
                    self._children_name_map["rd"] = "rd"
                    self._children_yang_names.add("rd")

                    self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                    self.security_parameters.parent = self
                    self._children_name_map["security_parameters"] = "security-parameters"
                    self._children_yang_names.add("security-parameters")

                    self.vni_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                    self.vni_parameters.parent = self
                    self._children_name_map["vni_parameters"] = "vni-parameters"
                    self._children_yang_names.add("vni-parameters")

                    self.bridge_access_vfi = YList(self)
                    self.bridge_vfi = YList(self)
                    self.mac_filter = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("acpwup",
                                    "as_",
                                    "bridge_coupled_state",
                                    "bridge_description",
                                    "bridge_domain_id",
                                    "bridge_internal_msti",
                                    "bridge_msti",
                                    "bridge_mtu",
                                    "bridge_name",
                                    "bridge_shg_id",
                                    "bridge_state",
                                    "bridge_type",
                                    "configured",
                                    "disposition_bytecount",
                                    "disposition_pkt_count",
                                    "evi",
                                    "flodd_group_id_down",
                                    "group_name",
                                    "imposition_byte_count",
                                    "imposition_pkt_count",
                                    "is_bridge_partially_programmed",
                                    "is_rd_configured",
                                    "last_time_status_changed",
                                    "load_balance",
                                    "mac_limit_down",
                                    "mac_withdraw",
                                    "mac_withdraw_access",
                                    "mac_withdraw_option",
                                    "mac_withdraw_relay",
                                    "num_vn_is",
                                    "num_vn_is_up",
                                    "number_a_cs",
                                    "number_a_cs_up",
                                    "number_access_vf_is",
                                    "number_p_ws_up",
                                    "number_pb_bs",
                                    "number_pb_bs_up",
                                    "number_pseudowires",
                                    "number_vf_is",
                                    "nv_satellite_offload_ipv4_multicast_disabled",
                                    "p2mp_enabled",
                                    "partially_programmed_a_cs",
                                    "partially_programmed_pseudowires",
                                    "shutdown",
                                    "standby_pseudowires",
                                    "time_created",
                                    "time_elapsed_creation",
                                    "time_elapsed_status_changed",
                                    "vine_fsm_state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__setattr__(name, value)


                class SecurityParameters(Entity):
                    """
                    Security parameters
                    
                    .. attribute:: broadcast_storm_control_kb_ps
                    
                    	Broadcast Storm Control KbPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: broadcast_storm_control_pps
                    
                    	Broadcast Storm Control PPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: broadcast_storm_control_rate_unit
                    
                    	Broadcast Storm Control Rate Unit
                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                    
                    .. attribute:: dai_address_validation_mask
                    
                    	DAI Address Validation mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: dhcpv4_profile_name
                    
                    	DHCPv4 Profile Name
                    	**type**\:  str
                    
                    .. attribute:: dhcpv4_snoop
                    
                    	DHCPv4 Snoop Status
                    	**type**\:  bool
                    
                    .. attribute:: flood_unknown_unicast_enabled
                    
                    	Flooding unknown unicast enabled
                    	**type**\:  bool
                    
                    .. attribute:: flood_uu_disabled_mac_limit_action
                    
                    	Flooding of unknown\-unicast disabled due to MAC limit action
                    	**type**\:  bool
                    
                    .. attribute:: igm_pv4_disabled
                    
                    	IGMPv4 Disabled
                    	**type**\:  bool
                    
                    .. attribute:: igm_pv4_profile_name
                    
                    	IGMPv4 Profile Name
                    	**type**\:  str
                    
                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                    
                    	Is DAI Dstination MAC Address Validation Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                    
                    	Is DAI IPv4 Addr Validation Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                    
                    	Is DAI Source MAC Address Validation Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_dai_enabled
                    
                    	Is Dynamic ARP Inspection Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_dai_logging_enabled
                    
                    	Is DAI Logging Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_source_guard_enabled
                    
                    	Is IP Source Guard Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_ipsg_logging_enabled
                    
                    	Is IP Source Guard Logging Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                    
                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                    	**type**\:  bool
                    
                    .. attribute:: is_mac_secure_enabled
                    
                    	Is MAC Secure Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_mac_secure_logging_enabled
                    
                    	Is MAC Secure Logging Enabled
                    	**type**\:  bool
                    
                    .. attribute:: learn_disabled_mac_limit_action
                    
                    	Learning disabled due to MAC limit action
                    	**type**\:  bool
                    
                    .. attribute:: mac_aging_mode
                    
                    	MAC Aging Mode
                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                    
                    .. attribute:: mac_aging_time
                    
                    	MAC aging time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: mac_flooding
                    
                    	MAC flooding enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_learning
                    
                    	MAC learning enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_limit
                    
                    	MAC address limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_limit_action
                    
                    	MAC limit action
                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                    
                    .. attribute:: mac_limit_notification
                    
                    	MAC limit notification
                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                    
                    .. attribute:: mac_limit_reached
                    
                    	MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mac_port_down_flush_enabled
                    
                    	MAC Flush when port goes down
                    	**type**\:  bool
                    
                    .. attribute:: mac_secure_action
                    
                    	MAC Secure Action
                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                    
                    .. attribute:: mld_profile_name
                    
                    	MLD Profile Name
                    	**type**\:  str
                    
                    .. attribute:: mmrp_flood_optimization
                    
                    	MMRP Flood Optimization Status
                    	**type**\:  bool
                    
                    .. attribute:: multicast_storm_control_kb_ps
                    
                    	Multicast Storm Control KbPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: multicast_storm_control_pps
                    
                    	Multicast Storm Control PPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: multicast_storm_control_rate_unit
                    
                    	Multicast Storm Control Rate Unit
                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                    
                    .. attribute:: split_horizon_group_id
                    
                    	Split Horizon Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: storm_control
                    
                    	Storm Control Configuration
                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                    
                    .. attribute:: unicast_storm_control_kb_ps
                    
                    	Unicast Storm Control KbPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: unicast_storm_control_pps
                    
                    	Unicast Storm Control PPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: unicast_storm_control_rate_unit
                    
                    	Unicast Storm Control Rate Unit
                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__init__()

                        self.yang_name = "security-parameters"
                        self.yang_parent_name = "bridge-domain-info"

                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                        self.storm_control.parent = self
                        self._children_name_map["storm_control"] = "storm-control"
                        self._children_yang_names.add("storm-control")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("broadcast_storm_control_kb_ps",
                                        "broadcast_storm_control_pps",
                                        "broadcast_storm_control_rate_unit",
                                        "dai_address_validation_mask",
                                        "dhcpv4_profile_name",
                                        "dhcpv4_snoop",
                                        "flood_unknown_unicast_enabled",
                                        "flood_uu_disabled_mac_limit_action",
                                        "igm_pv4_disabled",
                                        "igm_pv4_profile_name",
                                        "is_dai_addr_validate_destination_mac_enabled",
                                        "is_dai_addr_validate_ipv4_enabled",
                                        "is_dai_addr_validate_source_mac_enabled",
                                        "is_dai_enabled",
                                        "is_dai_logging_enabled",
                                        "is_ip_source_guard_enabled",
                                        "is_ipsg_logging_enabled",
                                        "is_mac_secure_accept_shutdown_enabled",
                                        "is_mac_secure_enabled",
                                        "is_mac_secure_logging_enabled",
                                        "learn_disabled_mac_limit_action",
                                        "mac_aging_mode",
                                        "mac_aging_time",
                                        "mac_flooding",
                                        "mac_learning",
                                        "mac_limit",
                                        "mac_limit_action",
                                        "mac_limit_notification",
                                        "mac_limit_reached",
                                        "mac_port_down_flush_enabled",
                                        "mac_secure_action",
                                        "mld_profile_name",
                                        "mmrp_flood_optimization",
                                        "multicast_storm_control_kb_ps",
                                        "multicast_storm_control_pps",
                                        "multicast_storm_control_rate_unit",
                                        "split_horizon_group_id",
                                        "unicast_storm_control_kb_ps",
                                        "unicast_storm_control_pps",
                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__setattr__(name, value)


                    class StormControl(Entity):
                        """
                        Storm Control Configuration
                        
                        .. attribute:: bd_policer
                        
                        	Bridge Domain Policer
                        	**type**\:  bool
                        
                        .. attribute:: broadcast
                        
                        	Broadcast Storm Control
                        	**type**\:  bool
                        
                        .. attribute:: multicast
                        
                        	Multicast Storm Control
                        	**type**\:  bool
                        
                        .. attribute:: unicast
                        
                        	Unknown\-unicast Storm Control
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__init__()

                            self.yang_name = "storm-control"
                            self.yang_parent_name = "security-parameters"

                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                            self.multicast = YLeaf(YType.boolean, "multicast")

                            self.unicast = YLeaf(YType.boolean, "unicast")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bd_policer",
                                            "broadcast",
                                            "multicast",
                                            "unicast") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bd_policer.is_set or
                                self.broadcast.is_set or
                                self.multicast.is_set or
                                self.unicast.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bd_policer.yfilter != YFilter.not_set or
                                self.broadcast.yfilter != YFilter.not_set or
                                self.multicast.yfilter != YFilter.not_set or
                                self.unicast.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "storm-control" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/security-parameters/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast.get_name_leafdata())
                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bd-policer"):
                                self.bd_policer = value
                                self.bd_policer.value_namespace = name_space
                                self.bd_policer.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast"):
                                self.broadcast = value
                                self.broadcast.value_namespace = name_space
                                self.broadcast.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast"):
                                self.multicast = value
                                self.multicast.value_namespace = name_space
                                self.multicast.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast"):
                                self.unicast = value
                                self.unicast.value_namespace = name_space
                                self.unicast.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.broadcast_storm_control_kb_ps.is_set or
                            self.broadcast_storm_control_pps.is_set or
                            self.broadcast_storm_control_rate_unit.is_set or
                            self.dai_address_validation_mask.is_set or
                            self.dhcpv4_profile_name.is_set or
                            self.dhcpv4_snoop.is_set or
                            self.flood_unknown_unicast_enabled.is_set or
                            self.flood_uu_disabled_mac_limit_action.is_set or
                            self.igm_pv4_disabled.is_set or
                            self.igm_pv4_profile_name.is_set or
                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                            self.is_dai_enabled.is_set or
                            self.is_dai_logging_enabled.is_set or
                            self.is_ip_source_guard_enabled.is_set or
                            self.is_ipsg_logging_enabled.is_set or
                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                            self.is_mac_secure_enabled.is_set or
                            self.is_mac_secure_logging_enabled.is_set or
                            self.learn_disabled_mac_limit_action.is_set or
                            self.mac_aging_mode.is_set or
                            self.mac_aging_time.is_set or
                            self.mac_flooding.is_set or
                            self.mac_learning.is_set or
                            self.mac_limit.is_set or
                            self.mac_limit_action.is_set or
                            self.mac_limit_notification.is_set or
                            self.mac_limit_reached.is_set or
                            self.mac_port_down_flush_enabled.is_set or
                            self.mac_secure_action.is_set or
                            self.mld_profile_name.is_set or
                            self.mmrp_flood_optimization.is_set or
                            self.multicast_storm_control_kb_ps.is_set or
                            self.multicast_storm_control_pps.is_set or
                            self.multicast_storm_control_rate_unit.is_set or
                            self.split_horizon_group_id.is_set or
                            self.unicast_storm_control_kb_ps.is_set or
                            self.unicast_storm_control_pps.is_set or
                            self.unicast_storm_control_rate_unit.is_set or
                            (self.storm_control is not None and self.storm_control.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                            self.is_dai_enabled.yfilter != YFilter.not_set or
                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                            self.mac_aging_mode.yfilter != YFilter.not_set or
                            self.mac_aging_time.yfilter != YFilter.not_set or
                            self.mac_flooding.yfilter != YFilter.not_set or
                            self.mac_learning.yfilter != YFilter.not_set or
                            self.mac_limit.yfilter != YFilter.not_set or
                            self.mac_limit_action.yfilter != YFilter.not_set or
                            self.mac_limit_notification.yfilter != YFilter.not_set or
                            self.mac_limit_reached.yfilter != YFilter.not_set or
                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                            self.mac_secure_action.yfilter != YFilter.not_set or
                            self.mld_profile_name.yfilter != YFilter.not_set or
                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                            (self.storm_control is not None and self.storm_control.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "security-parameters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "storm-control"):
                            if (self.storm_control is None):
                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                            return self.storm_control

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "broadcast-storm-control-kb-ps"):
                            self.broadcast_storm_control_kb_ps = value
                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                        if(value_path == "broadcast-storm-control-pps"):
                            self.broadcast_storm_control_pps = value
                            self.broadcast_storm_control_pps.value_namespace = name_space
                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                        if(value_path == "broadcast-storm-control-rate-unit"):
                            self.broadcast_storm_control_rate_unit = value
                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "dai-address-validation-mask"):
                            self.dai_address_validation_mask = value
                            self.dai_address_validation_mask.value_namespace = name_space
                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "dhcpv4-profile-name"):
                            self.dhcpv4_profile_name = value
                            self.dhcpv4_profile_name.value_namespace = name_space
                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "dhcpv4-snoop"):
                            self.dhcpv4_snoop = value
                            self.dhcpv4_snoop.value_namespace = name_space
                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                        if(value_path == "flood-unknown-unicast-enabled"):
                            self.flood_unknown_unicast_enabled = value
                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                            self.flood_uu_disabled_mac_limit_action = value
                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                        if(value_path == "igm-pv4-disabled"):
                            self.igm_pv4_disabled = value
                            self.igm_pv4_disabled.value_namespace = name_space
                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "igm-pv4-profile-name"):
                            self.igm_pv4_profile_name = value
                            self.igm_pv4_profile_name.value_namespace = name_space
                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                            self.is_dai_addr_validate_destination_mac_enabled = value
                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                            self.is_dai_addr_validate_ipv4_enabled = value
                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                            self.is_dai_addr_validate_source_mac_enabled = value
                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dai-enabled"):
                            self.is_dai_enabled = value
                            self.is_dai_enabled.value_namespace = name_space
                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dai-logging-enabled"):
                            self.is_dai_logging_enabled = value
                            self.is_dai_logging_enabled.value_namespace = name_space
                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-source-guard-enabled"):
                            self.is_ip_source_guard_enabled = value
                            self.is_ip_source_guard_enabled.value_namespace = name_space
                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ipsg-logging-enabled"):
                            self.is_ipsg_logging_enabled = value
                            self.is_ipsg_logging_enabled.value_namespace = name_space
                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                            self.is_mac_secure_accept_shutdown_enabled = value
                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mac-secure-enabled"):
                            self.is_mac_secure_enabled = value
                            self.is_mac_secure_enabled.value_namespace = name_space
                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mac-secure-logging-enabled"):
                            self.is_mac_secure_logging_enabled = value
                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "learn-disabled-mac-limit-action"):
                            self.learn_disabled_mac_limit_action = value
                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-aging-mode"):
                            self.mac_aging_mode = value
                            self.mac_aging_mode.value_namespace = name_space
                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-aging-time"):
                            self.mac_aging_time = value
                            self.mac_aging_time.value_namespace = name_space
                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-flooding"):
                            self.mac_flooding = value
                            self.mac_flooding.value_namespace = name_space
                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-learning"):
                            self.mac_learning = value
                            self.mac_learning.value_namespace = name_space
                            self.mac_learning.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit"):
                            self.mac_limit = value
                            self.mac_limit.value_namespace = name_space
                            self.mac_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-action"):
                            self.mac_limit_action = value
                            self.mac_limit_action.value_namespace = name_space
                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-notification"):
                            self.mac_limit_notification = value
                            self.mac_limit_notification.value_namespace = name_space
                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-reached"):
                            self.mac_limit_reached = value
                            self.mac_limit_reached.value_namespace = name_space
                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-port-down-flush-enabled"):
                            self.mac_port_down_flush_enabled = value
                            self.mac_port_down_flush_enabled.value_namespace = name_space
                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-secure-action"):
                            self.mac_secure_action = value
                            self.mac_secure_action.value_namespace = name_space
                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                        if(value_path == "mld-profile-name"):
                            self.mld_profile_name = value
                            self.mld_profile_name.value_namespace = name_space
                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mmrp-flood-optimization"):
                            self.mmrp_flood_optimization = value
                            self.mmrp_flood_optimization.value_namespace = name_space
                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                        if(value_path == "multicast-storm-control-kb-ps"):
                            self.multicast_storm_control_kb_ps = value
                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                        if(value_path == "multicast-storm-control-pps"):
                            self.multicast_storm_control_pps = value
                            self.multicast_storm_control_pps.value_namespace = name_space
                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                        if(value_path == "multicast-storm-control-rate-unit"):
                            self.multicast_storm_control_rate_unit = value
                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "split-horizon-group-id"):
                            self.split_horizon_group_id = value
                            self.split_horizon_group_id.value_namespace = name_space
                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "unicast-storm-control-kb-ps"):
                            self.unicast_storm_control_kb_ps = value
                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                        if(value_path == "unicast-storm-control-pps"):
                            self.unicast_storm_control_pps = value
                            self.unicast_storm_control_pps.value_namespace = name_space
                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                        if(value_path == "unicast-storm-control-rate-unit"):
                            self.unicast_storm_control_rate_unit = value
                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                class PbbParameters(Entity):
                    """
                    PBB parameters
                    
                    .. attribute:: pbb_core
                    
                    	PBB Core
                    	**type**\:   :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                    
                    .. attribute:: pbb_edge
                    
                    	PBB Edge
                    	**type**\:   :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                    
                    .. attribute:: type
                    
                    	Type
                    	**type**\:   :py:class:`L2VpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridge>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__init__()

                        self.yang_name = "pbb-parameters"
                        self.yang_parent_name = "bridge-domain-info"

                        self.type = YLeaf(YType.enumeration, "type")

                        self.pbb_core = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                        self.pbb_core.parent = self
                        self._children_name_map["pbb_core"] = "pbb-core"
                        self._children_yang_names.add("pbb-core")

                        self.pbb_edge = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                        self.pbb_edge.parent = self
                        self._children_name_map["pbb_edge"] = "pbb-edge"
                        self._children_yang_names.add("pbb-edge")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__setattr__(name, value)


                    class PbbEdge(Entity):
                        """
                        PBB Edge
                        
                        .. attribute:: core_bridge_name
                        
                        	Core Bridge Domain Name
                        	**type**\:  str
                        
                        .. attribute:: core_bridge_state
                        
                        	Core Bridge State
                        	**type**\:   :py:class:`L2VpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeState>`
                        
                        .. attribute:: edge_port
                        
                        	PBB Edge Port
                        	**type**\:   :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                        
                        .. attribute:: i_sid
                        
                        	SID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mirp_lite_protocol
                        
                        	MIRP\-lite protocol info
                        	**type**\:   :py:class:`L2VpnMirpLiteProtocolInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteProtocolInfo>`
                        
                        .. attribute:: mirp_lite_status
                        
                        	MIRP\-lite Status
                        	**type**\:   :py:class:`L2VpnMirpLiteStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteStatus>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__init__()

                            self.yang_name = "pbb-edge"
                            self.yang_parent_name = "pbb-parameters"

                            self.core_bridge_name = YLeaf(YType.str, "core-bridge-name")

                            self.core_bridge_state = YLeaf(YType.enumeration, "core-bridge-state")

                            self.i_sid = YLeaf(YType.uint32, "i-sid")

                            self.mirp_lite_protocol = YLeaf(YType.enumeration, "mirp-lite-protocol")

                            self.mirp_lite_status = YLeaf(YType.enumeration, "mirp-lite-status")

                            self.edge_port = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                            self.edge_port.parent = self
                            self._children_name_map["edge_port"] = "edge-port"
                            self._children_yang_names.add("edge-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("core_bridge_name",
                                            "core_bridge_state",
                                            "i_sid",
                                            "mirp_lite_protocol",
                                            "mirp_lite_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__setattr__(name, value)


                        class EdgePort(Entity):
                            """
                            PBB Edge Port
                            
                            .. attribute:: bmac_mapping
                            
                            	CMAC to BMAC Mapping
                            	**type**\: list of    :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                            
                            .. attribute:: edge_port_state
                            
                            	PBB Edge Port State
                            	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                            
                            .. attribute:: unknown_unicast_mac
                            
                            	Unknown Unicast MAC
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: unknown_unicast_mac_set
                            
                            	Unknown Unicast MAC Configured
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__init__()

                                self.yang_name = "edge-port"
                                self.yang_parent_name = "pbb-edge"

                                self.edge_port_state = YLeaf(YType.enumeration, "edge-port-state")

                                self.unknown_unicast_mac = YLeaf(YType.str, "unknown-unicast-mac")

                                self.unknown_unicast_mac_set = YLeaf(YType.boolean, "unknown-unicast-mac-set")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                                self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._children_yang_names.add("statistics")

                                self.bmac_mapping = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("edge_port_state",
                                                "unknown_unicast_mac",
                                                "unknown_unicast_mac_set",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__setattr__(name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "edge-port"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/base/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "edge-port"

                                    self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    self._children_yang_names.add("dispostion-stats")

                                    self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                    self._children_yang_names.add("impostion-stats")

                                    self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._children_yang_names.add("sequence-number")


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                        self._children_yang_names.add("broadcast")

                                        self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        self._children_yang_names.add("imposition-mtu-drop")

                                        self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                        self._children_yang_names.add("imposition-stat")

                                        self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        self._children_yang_names.add("impostion-tail-drop")

                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        self._children_yang_names.add("l2fsbi-drop")

                                        self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                        self._children_yang_names.add("multicast")

                                        self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._children_yang_names.add("unknown-unicast")


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "imposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "impostion-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class L2FsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "l2fsbi-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast is not None and self.broadcast.has_data()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                            (self.multicast is not None and self.multicast.has_data()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast is not None and self.broadcast.has_operation()) or
                                            (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                            (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                            (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                            (self.multicast is not None and self.multicast.has_operation()) or
                                            (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast"):
                                            if (self.broadcast is None):
                                                self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"
                                            return self.broadcast

                                        if (child_yang_name == "imposition-mtu-drop"):
                                            if (self.imposition_mtu_drop is None):
                                                self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                            return self.imposition_mtu_drop

                                        if (child_yang_name == "imposition-stat"):
                                            if (self.imposition_stat is None):
                                                self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                            return self.imposition_stat

                                        if (child_yang_name == "impostion-tail-drop"):
                                            if (self.impostion_tail_drop is None):
                                                self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                            return self.impostion_tail_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "l2fsbi-drop"):
                                            if (self.l2fsbi_drop is None):
                                                self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                            return self.l2fsbi_drop

                                        if (child_yang_name == "multicast"):
                                            if (self.multicast is None):
                                                self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"
                                            return self.multicast

                                        if (child_yang_name == "unknown-unicast"):
                                            if (self.unknown_unicast is None):
                                                self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            return self.unknown_unicast

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"

                                        self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        self._children_yang_names.add("broadcast-drop")

                                        self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                        self._children_yang_names.add("dai-drop")

                                        self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        self._children_yang_names.add("disposition-mtu-drop")

                                        self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        self._children_yang_names.add("disposition-oo-o-drops")

                                        self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        self._children_yang_names.add("disposition-p2mp-stats")

                                        self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                        self._children_yang_names.add("disposition-stat")

                                        self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        self._children_yang_names.add("disposition-tail-drop")

                                        self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        self._children_yang_names.add("ipsg-drop")

                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                        self._children_yang_names.add("known-unicast")

                                        self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._children_yang_names.add("mac-move")

                                        self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                        self._children_yang_names.add("multicast-drop")

                                        self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                        self._children_yang_names.add("received-drops")

                                        self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                        self._children_yang_names.add("unicast-drop")


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-stat" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-mtu-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-tail-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "multicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unicast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "broadcast-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dai-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ipsg-drop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-oo-o-drops" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class DispositionP2MpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disposition-p2mp-stats" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known-unicast" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"

                                            self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                            self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("byte_counts",
                                                            "packet_counts") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.byte_counts.is_set or
                                                self.packet_counts.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.byte_counts.yfilter != YFilter.not_set or
                                                self.packet_counts.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "mac-move" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                            if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "byte-counts" or name == "packet-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "byte-counts"):
                                                self.byte_counts = value
                                                self.byte_counts.value_namespace = name_space
                                                self.byte_counts.value_namespace_prefix = name_space_prefix
                                            if(value_path == "packet-counts"):
                                                self.packet_counts = value
                                                self.packet_counts.value_namespace = name_space
                                                self.packet_counts.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                            (self.dai_drop is not None and self.dai_drop.has_data()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                            (self.known_unicast is not None and self.known_unicast.has_data()) or
                                            (self.mac_move is not None and self.mac_move.has_data()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                            (self.received_drops is not None and self.received_drops.has_data()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                            (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                            (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                            (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                            (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                            (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                            (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                            (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                            (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                            (self.mac_move is not None and self.mac_move.has_operation()) or
                                            (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                            (self.received_drops is not None and self.received_drops.has_operation()) or
                                            (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dispostion-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "broadcast-drop"):
                                            if (self.broadcast_drop is None):
                                                self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                            return self.broadcast_drop

                                        if (child_yang_name == "dai-drop"):
                                            if (self.dai_drop is None):
                                                self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"
                                            return self.dai_drop

                                        if (child_yang_name == "disposition-mtu-drop"):
                                            if (self.disposition_mtu_drop is None):
                                                self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                            return self.disposition_mtu_drop

                                        if (child_yang_name == "disposition-oo-o-drops"):
                                            if (self.disposition_oo_o_drops is None):
                                                self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                            return self.disposition_oo_o_drops

                                        if (child_yang_name == "disposition-p2mp-stats"):
                                            if (self.disposition_p2mp_stats is None):
                                                self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                            return self.disposition_p2mp_stats

                                        if (child_yang_name == "disposition-stat"):
                                            if (self.disposition_stat is None):
                                                self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                            return self.disposition_stat

                                        if (child_yang_name == "disposition-tail-drop"):
                                            if (self.disposition_tail_drop is None):
                                                self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                            return self.disposition_tail_drop

                                        if (child_yang_name == "ipsg-drop"):
                                            if (self.ipsg_drop is None):
                                                self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                            return self.ipsg_drop

                                        if (child_yang_name == "known-unicast"):
                                            if (self.known_unicast is None):
                                                self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"
                                            return self.known_unicast

                                        if (child_yang_name == "mac-move"):
                                            if (self.mac_move is None):
                                                self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                            return self.mac_move

                                        if (child_yang_name == "multicast-drop"):
                                            if (self.multicast_drop is None):
                                                self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                            return self.multicast_drop

                                        if (child_yang_name == "received-drops"):
                                            if (self.received_drops is None):
                                                self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"
                                            return self.received_drops

                                        if (child_yang_name == "unicast-drop"):
                                            if (self.unicast_drop is None):
                                                self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                            return self.unicast_drop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"

                                        self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                        self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                        self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                        self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bypassed_inbound_sequence_packet",
                                                        "bypassed_out_sequence_packet",
                                                        "sequence_number_expected",
                                                        "sequence_number_sent") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bypassed_inbound_sequence_packet.is_set or
                                            self.bypassed_out_sequence_packet.is_set or
                                            self.sequence_number_expected.is_set or
                                            self.sequence_number_sent.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                            self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                            self.sequence_number_expected.yfilter != YFilter.not_set or
                                            self.sequence_number_sent.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sequence-number" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                        if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                        if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                        if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bypassed-inbound-sequence-packet"):
                                            self.bypassed_inbound_sequence_packet = value
                                            self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                            self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bypassed-out-sequence-packet"):
                                            self.bypassed_out_sequence_packet = value
                                            self.bypassed_out_sequence_packet.value_namespace = name_space
                                            self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-expected"):
                                            self.sequence_number_expected = value
                                            self.sequence_number_expected.value_namespace = name_space
                                            self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sequence-number-sent"):
                                            self.sequence_number_sent = value
                                            self.sequence_number_sent.value_namespace = name_space
                                            self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                        (self.sequence_number is not None and self.sequence_number.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                        (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                        (self.sequence_number is not None and self.sequence_number.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "statistics" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dispostion-stats"):
                                        if (self.dispostion_stats is None):
                                            self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                        return self.dispostion_stats

                                    if (child_yang_name == "impostion-stats"):
                                        if (self.impostion_stats is None):
                                            self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"
                                        return self.impostion_stats

                                    if (child_yang_name == "sequence-number"):
                                        if (self.sequence_number is None):
                                            self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                        return self.sequence_number

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class BmacMapping(Entity):
                                """
                                CMAC to BMAC Mapping
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__init__()

                                    self.yang_name = "bmac-mapping"
                                    self.yang_parent_name = "edge-port"

                                    self.address = YLeaf(YType.str, "address")

                                    self.bmac = YLeaf(YType.str, "bmac")

                                    self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "bmac",
                                                    "next_hop_ip") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.bmac.is_set or
                                        self.next_hop_ip.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.bmac.yfilter != YFilter.not_set or
                                        self.next_hop_ip.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bmac-mapping" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bmac.get_name_leafdata())
                                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bmac"):
                                        self.bmac = value
                                        self.bmac.value_namespace = name_space
                                        self.bmac.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-ip"):
                                        self.next_hop_ip = value
                                        self.next_hop_ip.value_namespace = name_space
                                        self.next_hop_ip.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.bmac_mapping:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.edge_port_state.is_set or
                                    self.unknown_unicast_mac.is_set or
                                    self.unknown_unicast_mac_set.is_set or
                                    self.xconnect_id.is_set or
                                    (self.security_parameters is not None and self.security_parameters.has_data()) or
                                    (self.statistics is not None and self.statistics.has_data()))

                            def has_operation(self):
                                for c in self.bmac_mapping:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.edge_port_state.yfilter != YFilter.not_set or
                                    self.unknown_unicast_mac.yfilter != YFilter.not_set or
                                    self.unknown_unicast_mac_set.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                    (self.statistics is not None and self.statistics.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "edge-port" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.edge_port_state.is_set or self.edge_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.edge_port_state.get_name_leafdata())
                                if (self.unknown_unicast_mac.is_set or self.unknown_unicast_mac.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_unicast_mac.get_name_leafdata())
                                if (self.unknown_unicast_mac_set.is_set or self.unknown_unicast_mac_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_unicast_mac_set.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bmac-mapping"):
                                    for c in self.bmac_mapping:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.bmac_mapping.append(c)
                                    return c

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                if (child_yang_name == "statistics"):
                                    if (self.statistics is None):
                                        self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"
                                    return self.statistics

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bmac-mapping" or name == "security-parameters" or name == "statistics" or name == "edge-port-state" or name == "unknown-unicast-mac" or name == "unknown-unicast-mac-set" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "edge-port-state"):
                                    self.edge_port_state = value
                                    self.edge_port_state.value_namespace = name_space
                                    self.edge_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-unicast-mac"):
                                    self.unknown_unicast_mac = value
                                    self.unknown_unicast_mac.value_namespace = name_space
                                    self.unknown_unicast_mac.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-unicast-mac-set"):
                                    self.unknown_unicast_mac_set = value
                                    self.unknown_unicast_mac_set.value_namespace = name_space
                                    self.unknown_unicast_mac_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.core_bridge_name.is_set or
                                self.core_bridge_state.is_set or
                                self.i_sid.is_set or
                                self.mirp_lite_protocol.is_set or
                                self.mirp_lite_status.is_set or
                                (self.edge_port is not None and self.edge_port.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.core_bridge_name.yfilter != YFilter.not_set or
                                self.core_bridge_state.yfilter != YFilter.not_set or
                                self.i_sid.yfilter != YFilter.not_set or
                                self.mirp_lite_protocol.yfilter != YFilter.not_set or
                                self.mirp_lite_status.yfilter != YFilter.not_set or
                                (self.edge_port is not None and self.edge_port.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pbb-edge" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.core_bridge_name.is_set or self.core_bridge_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.core_bridge_name.get_name_leafdata())
                            if (self.core_bridge_state.is_set or self.core_bridge_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.core_bridge_state.get_name_leafdata())
                            if (self.i_sid.is_set or self.i_sid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.i_sid.get_name_leafdata())
                            if (self.mirp_lite_protocol.is_set or self.mirp_lite_protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mirp_lite_protocol.get_name_leafdata())
                            if (self.mirp_lite_status.is_set or self.mirp_lite_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mirp_lite_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "edge-port"):
                                if (self.edge_port is None):
                                    self.edge_port = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                    self.edge_port.parent = self
                                    self._children_name_map["edge_port"] = "edge-port"
                                return self.edge_port

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "edge-port" or name == "core-bridge-name" or name == "core-bridge-state" or name == "i-sid" or name == "mirp-lite-protocol" or name == "mirp-lite-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "core-bridge-name"):
                                self.core_bridge_name = value
                                self.core_bridge_name.value_namespace = name_space
                                self.core_bridge_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "core-bridge-state"):
                                self.core_bridge_state = value
                                self.core_bridge_state.value_namespace = name_space
                                self.core_bridge_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "i-sid"):
                                self.i_sid = value
                                self.i_sid.value_namespace = name_space
                                self.i_sid.value_namespace_prefix = name_space_prefix
                            if(value_path == "mirp-lite-protocol"):
                                self.mirp_lite_protocol = value
                                self.mirp_lite_protocol.value_namespace = name_space
                                self.mirp_lite_protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "mirp-lite-status"):
                                self.mirp_lite_status = value
                                self.mirp_lite_status.value_namespace = name_space
                                self.mirp_lite_status.value_namespace_prefix = name_space_prefix


                    class PbbCore(Entity):
                        """
                        PBB Core
                        
                        .. attribute:: core_port
                        
                        	PBB Core Port
                        	**type**\:   :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                        
                        .. attribute:: num_ass_edge
                        
                        	Number of Associated PBB Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__init__()

                            self.yang_name = "pbb-core"
                            self.yang_parent_name = "pbb-parameters"

                            self.num_ass_edge = YLeaf(YType.uint32, "num-ass-edge")

                            self.core_port = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                            self.core_port.parent = self
                            self._children_name_map["core_port"] = "core-port"
                            self._children_yang_names.add("core-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("num_ass_edge") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__setattr__(name, value)


                        class CorePort(Entity):
                            """
                            PBB Core Port
                            
                            .. attribute:: core_port_state
                            
                            	PBB Core Port State
                            	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                            
                            .. attribute:: vlan_id
                            
                            	Vlan ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__init__()

                                self.yang_name = "core-port"
                                self.yang_parent_name = "pbb-core"

                                self.core_port_state = YLeaf(YType.enumeration, "core-port-state")

                                self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                                self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                                self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                                self._children_yang_names.add("security-parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("core_port_state",
                                                "vlan_id",
                                                "xconnect_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__setattr__(name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "core-port"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._children_yang_names.add("base")

                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dhcpv4_trust",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__setattr__(name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"

                                        self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                        self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                        self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                        self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                        self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                        self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                        self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                        self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                        self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                        self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                        self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                        self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                        self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                        self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                        self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                        self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                        self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                        self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                        self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                        self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                        self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                        self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                        self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                        self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                        self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                        self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                        self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                        self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                        self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                        self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                        self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                        self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                        self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                        self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                        self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                        self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                        self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                        self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                        self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                        self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._children_yang_names.add("storm-control")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("broadcast_storm_control_kb_ps",
                                                        "broadcast_storm_control_pps",
                                                        "broadcast_storm_control_rate_unit",
                                                        "dai_address_validation_mask",
                                                        "dhcpv4_profile_name",
                                                        "dhcpv4_snoop",
                                                        "flood_unknown_unicast_enabled",
                                                        "flood_uu_disabled_mac_limit_action",
                                                        "igm_pv4_disabled",
                                                        "igm_pv4_profile_name",
                                                        "is_dai_addr_validate_destination_mac_enabled",
                                                        "is_dai_addr_validate_ipv4_enabled",
                                                        "is_dai_addr_validate_source_mac_enabled",
                                                        "is_dai_enabled",
                                                        "is_dai_logging_enabled",
                                                        "is_ip_source_guard_enabled",
                                                        "is_ipsg_logging_enabled",
                                                        "is_mac_secure_accept_shutdown_enabled",
                                                        "is_mac_secure_enabled",
                                                        "is_mac_secure_logging_enabled",
                                                        "learn_disabled_mac_limit_action",
                                                        "mac_aging_mode",
                                                        "mac_aging_time",
                                                        "mac_flooding",
                                                        "mac_learning",
                                                        "mac_limit",
                                                        "mac_limit_action",
                                                        "mac_limit_notification",
                                                        "mac_limit_reached",
                                                        "mac_port_down_flush_enabled",
                                                        "mac_secure_action",
                                                        "mld_profile_name",
                                                        "mmrp_flood_optimization",
                                                        "multicast_storm_control_kb_ps",
                                                        "multicast_storm_control_pps",
                                                        "multicast_storm_control_rate_unit",
                                                        "split_horizon_group_id",
                                                        "unicast_storm_control_kb_ps",
                                                        "unicast_storm_control_pps",
                                                        "unicast_storm_control_rate_unit") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__setattr__(name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"

                                            self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                            self.broadcast = YLeaf(YType.boolean, "broadcast")

                                            self.multicast = YLeaf(YType.boolean, "multicast")

                                            self.unicast = YLeaf(YType.boolean, "unicast")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bd_policer",
                                                            "broadcast",
                                                            "multicast",
                                                            "unicast") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bd_policer.is_set or
                                                self.broadcast.is_set or
                                                self.multicast.is_set or
                                                self.unicast.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bd_policer.yfilter != YFilter.not_set or
                                                self.broadcast.yfilter != YFilter.not_set or
                                                self.multicast.yfilter != YFilter.not_set or
                                                self.unicast.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "storm-control" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/base/%s" % self.get_segment_path()
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                            if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.broadcast.get_name_leafdata())
                                            if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast.get_name_leafdata())
                                            if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unicast.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bd-policer"):
                                                self.bd_policer = value
                                                self.bd_policer.value_namespace = name_space
                                                self.bd_policer.value_namespace_prefix = name_space_prefix
                                            if(value_path == "broadcast"):
                                                self.broadcast = value
                                                self.broadcast.value_namespace = name_space
                                                self.broadcast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast"):
                                                self.multicast = value
                                                self.multicast.value_namespace = name_space
                                                self.multicast.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unicast"):
                                                self.unicast = value
                                                self.unicast.value_namespace = name_space
                                                self.unicast.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.broadcast_storm_control_kb_ps.is_set or
                                            self.broadcast_storm_control_pps.is_set or
                                            self.broadcast_storm_control_rate_unit.is_set or
                                            self.dai_address_validation_mask.is_set or
                                            self.dhcpv4_profile_name.is_set or
                                            self.dhcpv4_snoop.is_set or
                                            self.flood_unknown_unicast_enabled.is_set or
                                            self.flood_uu_disabled_mac_limit_action.is_set or
                                            self.igm_pv4_disabled.is_set or
                                            self.igm_pv4_profile_name.is_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                            self.is_dai_addr_validate_ipv4_enabled.is_set or
                                            self.is_dai_addr_validate_source_mac_enabled.is_set or
                                            self.is_dai_enabled.is_set or
                                            self.is_dai_logging_enabled.is_set or
                                            self.is_ip_source_guard_enabled.is_set or
                                            self.is_ipsg_logging_enabled.is_set or
                                            self.is_mac_secure_accept_shutdown_enabled.is_set or
                                            self.is_mac_secure_enabled.is_set or
                                            self.is_mac_secure_logging_enabled.is_set or
                                            self.learn_disabled_mac_limit_action.is_set or
                                            self.mac_aging_mode.is_set or
                                            self.mac_aging_time.is_set or
                                            self.mac_flooding.is_set or
                                            self.mac_learning.is_set or
                                            self.mac_limit.is_set or
                                            self.mac_limit_action.is_set or
                                            self.mac_limit_notification.is_set or
                                            self.mac_limit_reached.is_set or
                                            self.mac_port_down_flush_enabled.is_set or
                                            self.mac_secure_action.is_set or
                                            self.mld_profile_name.is_set or
                                            self.mmrp_flood_optimization.is_set or
                                            self.multicast_storm_control_kb_ps.is_set or
                                            self.multicast_storm_control_pps.is_set or
                                            self.multicast_storm_control_rate_unit.is_set or
                                            self.split_horizon_group_id.is_set or
                                            self.unicast_storm_control_kb_ps.is_set or
                                            self.unicast_storm_control_pps.is_set or
                                            self.unicast_storm_control_rate_unit.is_set or
                                            (self.storm_control is not None and self.storm_control.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                            self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                            self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                            self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                            self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                            self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_enabled.yfilter != YFilter.not_set or
                                            self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                            self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                            self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                            self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_aging_mode.yfilter != YFilter.not_set or
                                            self.mac_aging_time.yfilter != YFilter.not_set or
                                            self.mac_flooding.yfilter != YFilter.not_set or
                                            self.mac_learning.yfilter != YFilter.not_set or
                                            self.mac_limit.yfilter != YFilter.not_set or
                                            self.mac_limit_action.yfilter != YFilter.not_set or
                                            self.mac_limit_notification.yfilter != YFilter.not_set or
                                            self.mac_limit_reached.yfilter != YFilter.not_set or
                                            self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                            self.mac_secure_action.yfilter != YFilter.not_set or
                                            self.mld_profile_name.yfilter != YFilter.not_set or
                                            self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            self.split_horizon_group_id.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                            self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                            (self.storm_control is not None and self.storm_control.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "base" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                        if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                        if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                        if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                        if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                        if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                        if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                        if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                        if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                        if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                        if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                        if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                        if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                        if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                        if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                        if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                        if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                        if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                        if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                        if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                        if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                        if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                        if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                        if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                        if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                        if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                        if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                        if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                        if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                        if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                        if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                        if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                        if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "storm-control"):
                                            if (self.storm_control is None):
                                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                            return self.storm_control

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "broadcast-storm-control-kb-ps"):
                                            self.broadcast_storm_control_kb_ps = value
                                            self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                            self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-pps"):
                                            self.broadcast_storm_control_pps = value
                                            self.broadcast_storm_control_pps.value_namespace = name_space
                                            self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast-storm-control-rate-unit"):
                                            self.broadcast_storm_control_rate_unit = value
                                            self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                            self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dai-address-validation-mask"):
                                            self.dai_address_validation_mask = value
                                            self.dai_address_validation_mask.value_namespace = name_space
                                            self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-profile-name"):
                                            self.dhcpv4_profile_name = value
                                            self.dhcpv4_profile_name.value_namespace = name_space
                                            self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dhcpv4-snoop"):
                                            self.dhcpv4_snoop = value
                                            self.dhcpv4_snoop.value_namespace = name_space
                                            self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-unknown-unicast-enabled"):
                                            self.flood_unknown_unicast_enabled = value
                                            self.flood_unknown_unicast_enabled.value_namespace = name_space
                                            self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-uu-disabled-mac-limit-action"):
                                            self.flood_uu_disabled_mac_limit_action = value
                                            self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                            self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-disabled"):
                                            self.igm_pv4_disabled = value
                                            self.igm_pv4_disabled.value_namespace = name_space
                                            self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "igm-pv4-profile-name"):
                                            self.igm_pv4_profile_name = value
                                            self.igm_pv4_profile_name.value_namespace = name_space
                                            self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                            self.is_dai_addr_validate_destination_mac_enabled = value
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                            self.is_dai_addr_validate_ipv4_enabled = value
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                            self.is_dai_addr_validate_source_mac_enabled = value
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                            self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-enabled"):
                                            self.is_dai_enabled = value
                                            self.is_dai_enabled.value_namespace = name_space
                                            self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-dai-logging-enabled"):
                                            self.is_dai_logging_enabled = value
                                            self.is_dai_logging_enabled.value_namespace = name_space
                                            self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ip-source-guard-enabled"):
                                            self.is_ip_source_guard_enabled = value
                                            self.is_ip_source_guard_enabled.value_namespace = name_space
                                            self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-ipsg-logging-enabled"):
                                            self.is_ipsg_logging_enabled = value
                                            self.is_ipsg_logging_enabled.value_namespace = name_space
                                            self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                            self.is_mac_secure_accept_shutdown_enabled = value
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                            self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-enabled"):
                                            self.is_mac_secure_enabled = value
                                            self.is_mac_secure_enabled.value_namespace = name_space
                                            self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-mac-secure-logging-enabled"):
                                            self.is_mac_secure_logging_enabled = value
                                            self.is_mac_secure_logging_enabled.value_namespace = name_space
                                            self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "learn-disabled-mac-limit-action"):
                                            self.learn_disabled_mac_limit_action = value
                                            self.learn_disabled_mac_limit_action.value_namespace = name_space
                                            self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-mode"):
                                            self.mac_aging_mode = value
                                            self.mac_aging_mode.value_namespace = name_space
                                            self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-aging-time"):
                                            self.mac_aging_time = value
                                            self.mac_aging_time.value_namespace = name_space
                                            self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-flooding"):
                                            self.mac_flooding = value
                                            self.mac_flooding.value_namespace = name_space
                                            self.mac_flooding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-learning"):
                                            self.mac_learning = value
                                            self.mac_learning.value_namespace = name_space
                                            self.mac_learning.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit"):
                                            self.mac_limit = value
                                            self.mac_limit.value_namespace = name_space
                                            self.mac_limit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-action"):
                                            self.mac_limit_action = value
                                            self.mac_limit_action.value_namespace = name_space
                                            self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-notification"):
                                            self.mac_limit_notification = value
                                            self.mac_limit_notification.value_namespace = name_space
                                            self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-limit-reached"):
                                            self.mac_limit_reached = value
                                            self.mac_limit_reached.value_namespace = name_space
                                            self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-port-down-flush-enabled"):
                                            self.mac_port_down_flush_enabled = value
                                            self.mac_port_down_flush_enabled.value_namespace = name_space
                                            self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mac-secure-action"):
                                            self.mac_secure_action = value
                                            self.mac_secure_action.value_namespace = name_space
                                            self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mld-profile-name"):
                                            self.mld_profile_name = value
                                            self.mld_profile_name.value_namespace = name_space
                                            self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mmrp-flood-optimization"):
                                            self.mmrp_flood_optimization = value
                                            self.mmrp_flood_optimization.value_namespace = name_space
                                            self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-kb-ps"):
                                            self.multicast_storm_control_kb_ps = value
                                            self.multicast_storm_control_kb_ps.value_namespace = name_space
                                            self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-pps"):
                                            self.multicast_storm_control_pps = value
                                            self.multicast_storm_control_pps.value_namespace = name_space
                                            self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast-storm-control-rate-unit"):
                                            self.multicast_storm_control_rate_unit = value
                                            self.multicast_storm_control_rate_unit.value_namespace = name_space
                                            self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "split-horizon-group-id"):
                                            self.split_horizon_group_id = value
                                            self.split_horizon_group_id.value_namespace = name_space
                                            self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-kb-ps"):
                                            self.unicast_storm_control_kb_ps = value
                                            self.unicast_storm_control_kb_ps.value_namespace = name_space
                                            self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-pps"):
                                            self.unicast_storm_control_pps = value
                                            self.unicast_storm_control_pps.value_namespace = name_space
                                            self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast-storm-control-rate-unit"):
                                            self.unicast_storm_control_rate_unit = value
                                            self.unicast_storm_control_rate_unit.value_namespace = name_space
                                            self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dhcpv4_trust.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.base is not None and self.base.has_data()) or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dhcpv4_trust.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.base is not None and self.base.has_operation()) or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security-parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "base"):
                                        if (self.base is None):
                                            self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"
                                        return self.base

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-trust"):
                                        self.dhcpv4_trust = value
                                        self.dhcpv4_trust.value_namespace = name_space
                                        self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.core_port_state.is_set or
                                    self.vlan_id.is_set or
                                    self.xconnect_id.is_set or
                                    (self.security_parameters is not None and self.security_parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.core_port_state.yfilter != YFilter.not_set or
                                    self.vlan_id.yfilter != YFilter.not_set or
                                    self.xconnect_id.yfilter != YFilter.not_set or
                                    (self.security_parameters is not None and self.security_parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "core-port" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.core_port_state.is_set or self.core_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.core_port_state.get_name_leafdata())
                                if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vlan_id.get_name_leafdata())
                                if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "security-parameters"):
                                    if (self.security_parameters is None):
                                        self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                    return self.security_parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "security-parameters" or name == "core-port-state" or name == "vlan-id" or name == "xconnect-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "core-port-state"):
                                    self.core_port_state = value
                                    self.core_port_state.value_namespace = name_space
                                    self.core_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "vlan-id"):
                                    self.vlan_id = value
                                    self.vlan_id.value_namespace = name_space
                                    self.vlan_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "xconnect-id"):
                                    self.xconnect_id = value
                                    self.xconnect_id.value_namespace = name_space
                                    self.xconnect_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.num_ass_edge.is_set or
                                (self.core_port is not None and self.core_port.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.num_ass_edge.yfilter != YFilter.not_set or
                                (self.core_port is not None and self.core_port.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pbb-core" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.num_ass_edge.is_set or self.num_ass_edge.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.num_ass_edge.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "core-port"):
                                if (self.core_port is None):
                                    self.core_port = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                    self.core_port.parent = self
                                    self._children_name_map["core_port"] = "core-port"
                                return self.core_port

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "core-port" or name == "num-ass-edge"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "num-ass-edge"):
                                self.num_ass_edge = value
                                self.num_ass_edge.value_namespace = name_space
                                self.num_ass_edge.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.type.is_set or
                            (self.pbb_core is not None and self.pbb_core.has_data()) or
                            (self.pbb_edge is not None and self.pbb_edge.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.type.yfilter != YFilter.not_set or
                            (self.pbb_core is not None and self.pbb_core.has_operation()) or
                            (self.pbb_edge is not None and self.pbb_edge.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pbb-parameters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "pbb-core"):
                            if (self.pbb_core is None):
                                self.pbb_core = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                                self.pbb_core.parent = self
                                self._children_name_map["pbb_core"] = "pbb-core"
                            return self.pbb_core

                        if (child_yang_name == "pbb-edge"):
                            if (self.pbb_edge is None):
                                self.pbb_edge = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                                self.pbb_edge.parent = self
                                self._children_name_map["pbb_edge"] = "pbb-edge"
                            return self.pbb_edge

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "pbb-core" or name == "pbb-edge" or name == "type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "type"):
                            self.type = value
                            self.type.value_namespace = name_space
                            self.type.value_namespace_prefix = name_space_prefix


                class EvpnParameters(Entity):
                    """
                    EVPN parameters
                    
                    .. attribute:: evi
                    
                    	E\-VPN id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_port
                    
                    	EVPN Port
                    	**type**\:   :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__init__()

                        self.yang_name = "evpn-parameters"
                        self.yang_parent_name = "bridge-domain-info"

                        self.evi = YLeaf(YType.uint32, "evi")

                        self.evpn_port = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                        self.evpn_port.parent = self
                        self._children_name_map["evpn_port"] = "evpn-port"
                        self._children_yang_names.add("evpn-port")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("evi") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__setattr__(name, value)


                    class EvpnPort(Entity):
                        """
                        EVPN Port
                        
                        .. attribute:: evpn_port_state
                        
                        	EVPN Port State
                        	**type**\:   :py:class:`L2VpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportState>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                        
                        .. attribute:: xconnect_id
                        
                        	Xconnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__init__()

                            self.yang_name = "evpn-port"
                            self.yang_parent_name = "evpn-parameters"

                            self.evpn_port_state = YLeaf(YType.enumeration, "evpn-port-state")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                            self._children_yang_names.add("security-parameters")

                            self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("evpn_port_state",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__setattr__(name, value)


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "evpn-port"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._children_yang_names.add("base")

                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dhcpv4_trust",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__setattr__(name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"

                                    self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                    self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                    self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                    self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                    self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                    self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                    self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                    self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                    self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                    self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                    self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                    self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                    self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                    self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                    self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                    self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                    self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                    self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                    self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                    self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                    self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                    self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                    self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                    self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                    self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                    self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                    self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                    self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                    self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                    self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                    self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                    self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                    self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                    self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                    self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                    self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                    self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                    self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                    self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                    self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._children_yang_names.add("storm-control")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("broadcast_storm_control_kb_ps",
                                                    "broadcast_storm_control_pps",
                                                    "broadcast_storm_control_rate_unit",
                                                    "dai_address_validation_mask",
                                                    "dhcpv4_profile_name",
                                                    "dhcpv4_snoop",
                                                    "flood_unknown_unicast_enabled",
                                                    "flood_uu_disabled_mac_limit_action",
                                                    "igm_pv4_disabled",
                                                    "igm_pv4_profile_name",
                                                    "is_dai_addr_validate_destination_mac_enabled",
                                                    "is_dai_addr_validate_ipv4_enabled",
                                                    "is_dai_addr_validate_source_mac_enabled",
                                                    "is_dai_enabled",
                                                    "is_dai_logging_enabled",
                                                    "is_ip_source_guard_enabled",
                                                    "is_ipsg_logging_enabled",
                                                    "is_mac_secure_accept_shutdown_enabled",
                                                    "is_mac_secure_enabled",
                                                    "is_mac_secure_logging_enabled",
                                                    "learn_disabled_mac_limit_action",
                                                    "mac_aging_mode",
                                                    "mac_aging_time",
                                                    "mac_flooding",
                                                    "mac_learning",
                                                    "mac_limit",
                                                    "mac_limit_action",
                                                    "mac_limit_notification",
                                                    "mac_limit_reached",
                                                    "mac_port_down_flush_enabled",
                                                    "mac_secure_action",
                                                    "mld_profile_name",
                                                    "mmrp_flood_optimization",
                                                    "multicast_storm_control_kb_ps",
                                                    "multicast_storm_control_pps",
                                                    "multicast_storm_control_rate_unit",
                                                    "split_horizon_group_id",
                                                    "unicast_storm_control_kb_ps",
                                                    "unicast_storm_control_pps",
                                                    "unicast_storm_control_rate_unit") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__setattr__(name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"

                                        self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                        self.broadcast = YLeaf(YType.boolean, "broadcast")

                                        self.multicast = YLeaf(YType.boolean, "multicast")

                                        self.unicast = YLeaf(YType.boolean, "unicast")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bd_policer",
                                                        "broadcast",
                                                        "multicast",
                                                        "unicast") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bd_policer.is_set or
                                            self.broadcast.is_set or
                                            self.multicast.is_set or
                                            self.unicast.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bd_policer.yfilter != YFilter.not_set or
                                            self.broadcast.yfilter != YFilter.not_set or
                                            self.multicast.yfilter != YFilter.not_set or
                                            self.unicast.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "storm-control" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/base/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                        if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.broadcast.get_name_leafdata())
                                        if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multicast.get_name_leafdata())
                                        if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unicast.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bd-policer"):
                                            self.bd_policer = value
                                            self.bd_policer.value_namespace = name_space
                                            self.bd_policer.value_namespace_prefix = name_space_prefix
                                        if(value_path == "broadcast"):
                                            self.broadcast = value
                                            self.broadcast.value_namespace = name_space
                                            self.broadcast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multicast"):
                                            self.multicast = value
                                            self.multicast.value_namespace = name_space
                                            self.multicast.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unicast"):
                                            self.unicast = value
                                            self.unicast.value_namespace = name_space
                                            self.unicast.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.broadcast_storm_control_kb_ps.is_set or
                                        self.broadcast_storm_control_pps.is_set or
                                        self.broadcast_storm_control_rate_unit.is_set or
                                        self.dai_address_validation_mask.is_set or
                                        self.dhcpv4_profile_name.is_set or
                                        self.dhcpv4_snoop.is_set or
                                        self.flood_unknown_unicast_enabled.is_set or
                                        self.flood_uu_disabled_mac_limit_action.is_set or
                                        self.igm_pv4_disabled.is_set or
                                        self.igm_pv4_profile_name.is_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                        self.is_dai_addr_validate_ipv4_enabled.is_set or
                                        self.is_dai_addr_validate_source_mac_enabled.is_set or
                                        self.is_dai_enabled.is_set or
                                        self.is_dai_logging_enabled.is_set or
                                        self.is_ip_source_guard_enabled.is_set or
                                        self.is_ipsg_logging_enabled.is_set or
                                        self.is_mac_secure_accept_shutdown_enabled.is_set or
                                        self.is_mac_secure_enabled.is_set or
                                        self.is_mac_secure_logging_enabled.is_set or
                                        self.learn_disabled_mac_limit_action.is_set or
                                        self.mac_aging_mode.is_set or
                                        self.mac_aging_time.is_set or
                                        self.mac_flooding.is_set or
                                        self.mac_learning.is_set or
                                        self.mac_limit.is_set or
                                        self.mac_limit_action.is_set or
                                        self.mac_limit_notification.is_set or
                                        self.mac_limit_reached.is_set or
                                        self.mac_port_down_flush_enabled.is_set or
                                        self.mac_secure_action.is_set or
                                        self.mld_profile_name.is_set or
                                        self.mmrp_flood_optimization.is_set or
                                        self.multicast_storm_control_kb_ps.is_set or
                                        self.multicast_storm_control_pps.is_set or
                                        self.multicast_storm_control_rate_unit.is_set or
                                        self.split_horizon_group_id.is_set or
                                        self.unicast_storm_control_kb_ps.is_set or
                                        self.unicast_storm_control_pps.is_set or
                                        self.unicast_storm_control_rate_unit.is_set or
                                        (self.storm_control is not None and self.storm_control.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                        self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                        self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                        self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                        self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                        self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_enabled.yfilter != YFilter.not_set or
                                        self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                        self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                        self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                        self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_aging_mode.yfilter != YFilter.not_set or
                                        self.mac_aging_time.yfilter != YFilter.not_set or
                                        self.mac_flooding.yfilter != YFilter.not_set or
                                        self.mac_learning.yfilter != YFilter.not_set or
                                        self.mac_limit.yfilter != YFilter.not_set or
                                        self.mac_limit_action.yfilter != YFilter.not_set or
                                        self.mac_limit_notification.yfilter != YFilter.not_set or
                                        self.mac_limit_reached.yfilter != YFilter.not_set or
                                        self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                        self.mac_secure_action.yfilter != YFilter.not_set or
                                        self.mld_profile_name.yfilter != YFilter.not_set or
                                        self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        self.split_horizon_group_id.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                        self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                        (self.storm_control is not None and self.storm_control.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "base" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                    if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                    if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                    if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                    if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                    if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                    if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                    if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                    if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                    if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                    if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                    if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                    if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                    if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                    if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                    if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                    if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                    if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                    if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                    if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                    if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                    if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                    if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                    if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                    if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                    if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                    if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                    if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                    if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                    if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                    if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                    if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                    if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "storm-control"):
                                        if (self.storm_control is None):
                                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                        return self.storm_control

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "broadcast-storm-control-kb-ps"):
                                        self.broadcast_storm_control_kb_ps = value
                                        self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                        self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-pps"):
                                        self.broadcast_storm_control_pps = value
                                        self.broadcast_storm_control_pps.value_namespace = name_space
                                        self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast-storm-control-rate-unit"):
                                        self.broadcast_storm_control_rate_unit = value
                                        self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                        self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dai-address-validation-mask"):
                                        self.dai_address_validation_mask = value
                                        self.dai_address_validation_mask.value_namespace = name_space
                                        self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-profile-name"):
                                        self.dhcpv4_profile_name = value
                                        self.dhcpv4_profile_name.value_namespace = name_space
                                        self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "dhcpv4-snoop"):
                                        self.dhcpv4_snoop = value
                                        self.dhcpv4_snoop.value_namespace = name_space
                                        self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-unknown-unicast-enabled"):
                                        self.flood_unknown_unicast_enabled = value
                                        self.flood_unknown_unicast_enabled.value_namespace = name_space
                                        self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-uu-disabled-mac-limit-action"):
                                        self.flood_uu_disabled_mac_limit_action = value
                                        self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                        self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-disabled"):
                                        self.igm_pv4_disabled = value
                                        self.igm_pv4_disabled.value_namespace = name_space
                                        self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "igm-pv4-profile-name"):
                                        self.igm_pv4_profile_name = value
                                        self.igm_pv4_profile_name.value_namespace = name_space
                                        self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                        self.is_dai_addr_validate_destination_mac_enabled = value
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                        self.is_dai_addr_validate_ipv4_enabled = value
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                        self.is_dai_addr_validate_source_mac_enabled = value
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                        self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-enabled"):
                                        self.is_dai_enabled = value
                                        self.is_dai_enabled.value_namespace = name_space
                                        self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-dai-logging-enabled"):
                                        self.is_dai_logging_enabled = value
                                        self.is_dai_logging_enabled.value_namespace = name_space
                                        self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ip-source-guard-enabled"):
                                        self.is_ip_source_guard_enabled = value
                                        self.is_ip_source_guard_enabled.value_namespace = name_space
                                        self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-ipsg-logging-enabled"):
                                        self.is_ipsg_logging_enabled = value
                                        self.is_ipsg_logging_enabled.value_namespace = name_space
                                        self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                        self.is_mac_secure_accept_shutdown_enabled = value
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                        self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-enabled"):
                                        self.is_mac_secure_enabled = value
                                        self.is_mac_secure_enabled.value_namespace = name_space
                                        self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-mac-secure-logging-enabled"):
                                        self.is_mac_secure_logging_enabled = value
                                        self.is_mac_secure_logging_enabled.value_namespace = name_space
                                        self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "learn-disabled-mac-limit-action"):
                                        self.learn_disabled_mac_limit_action = value
                                        self.learn_disabled_mac_limit_action.value_namespace = name_space
                                        self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-mode"):
                                        self.mac_aging_mode = value
                                        self.mac_aging_mode.value_namespace = name_space
                                        self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-aging-time"):
                                        self.mac_aging_time = value
                                        self.mac_aging_time.value_namespace = name_space
                                        self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-flooding"):
                                        self.mac_flooding = value
                                        self.mac_flooding.value_namespace = name_space
                                        self.mac_flooding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-learning"):
                                        self.mac_learning = value
                                        self.mac_learning.value_namespace = name_space
                                        self.mac_learning.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit"):
                                        self.mac_limit = value
                                        self.mac_limit.value_namespace = name_space
                                        self.mac_limit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-action"):
                                        self.mac_limit_action = value
                                        self.mac_limit_action.value_namespace = name_space
                                        self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-notification"):
                                        self.mac_limit_notification = value
                                        self.mac_limit_notification.value_namespace = name_space
                                        self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-limit-reached"):
                                        self.mac_limit_reached = value
                                        self.mac_limit_reached.value_namespace = name_space
                                        self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-port-down-flush-enabled"):
                                        self.mac_port_down_flush_enabled = value
                                        self.mac_port_down_flush_enabled.value_namespace = name_space
                                        self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mac-secure-action"):
                                        self.mac_secure_action = value
                                        self.mac_secure_action.value_namespace = name_space
                                        self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mld-profile-name"):
                                        self.mld_profile_name = value
                                        self.mld_profile_name.value_namespace = name_space
                                        self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mmrp-flood-optimization"):
                                        self.mmrp_flood_optimization = value
                                        self.mmrp_flood_optimization.value_namespace = name_space
                                        self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-kb-ps"):
                                        self.multicast_storm_control_kb_ps = value
                                        self.multicast_storm_control_kb_ps.value_namespace = name_space
                                        self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-pps"):
                                        self.multicast_storm_control_pps = value
                                        self.multicast_storm_control_pps.value_namespace = name_space
                                        self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast-storm-control-rate-unit"):
                                        self.multicast_storm_control_rate_unit = value
                                        self.multicast_storm_control_rate_unit.value_namespace = name_space
                                        self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "split-horizon-group-id"):
                                        self.split_horizon_group_id = value
                                        self.split_horizon_group_id.value_namespace = name_space
                                        self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-kb-ps"):
                                        self.unicast_storm_control_kb_ps = value
                                        self.unicast_storm_control_kb_ps.value_namespace = name_space
                                        self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-pps"):
                                        self.unicast_storm_control_pps = value
                                        self.unicast_storm_control_pps.value_namespace = name_space
                                        self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast-storm-control-rate-unit"):
                                        self.unicast_storm_control_rate_unit = value
                                        self.unicast_storm_control_rate_unit.value_namespace = name_space
                                        self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dhcpv4_trust.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.base is not None and self.base.has_data()) or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dhcpv4_trust.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.base is not None and self.base.has_operation()) or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security-parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "base"):
                                    if (self.base is None):
                                        self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"
                                    return self.base

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-trust"):
                                    self.dhcpv4_trust = value
                                    self.dhcpv4_trust.value_namespace = name_space
                                    self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "evpn-port"

                                self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self.get_segment_path()
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.evpn_port_state.is_set or
                                self.xconnect_id.is_set or
                                (self.security_parameters is not None and self.security_parameters.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.evpn_port_state.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.security_parameters is not None and self.security_parameters.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "evpn-port" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.evpn_port_state.is_set or self.evpn_port_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_port_state.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "security-parameters"):
                                if (self.security_parameters is None):
                                    self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                return self.security_parameters

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "security-parameters" or name == "statistics" or name == "evpn-port-state" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "evpn-port-state"):
                                self.evpn_port_state = value
                                self.evpn_port_state.value_namespace = name_space
                                self.evpn_port_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.evi.is_set or
                            (self.evpn_port is not None and self.evpn_port.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.evi.yfilter != YFilter.not_set or
                            (self.evpn_port is not None and self.evpn_port.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "evpn-parameters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evi.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "evpn-port"):
                            if (self.evpn_port is None):
                                self.evpn_port = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                                self.evpn_port.parent = self
                                self._children_name_map["evpn_port"] = "evpn-port"
                            return self.evpn_port

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "evpn-port" or name == "evi"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "evi"):
                            self.evi = value
                            self.evi.value_namespace = name_space
                            self.evi.value_namespace_prefix = name_space_prefix


                class VniParameters(Entity):
                    """
                    VNI parameters
                    
                    .. attribute:: anycast_mcast_group_addr
                    
                    	Anycast Multicast Group Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: anycast_vtep_ip_addr
                    
                    	Anycast VTEP IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: multicast_group_addr
                    
                    	Multicast Group Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: overlay
                    
                    	NVE Overlay
                    	**type**\:  str
                    
                    .. attribute:: security_parameters
                    
                    	Security Parameters
                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                    
                    .. attribute:: source_ip_addr
                    
                    	Source IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: static_mac
                    
                    	Static MAC addresses
                    	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                    
                    .. attribute:: udp_port
                    
                    	UDP Port
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni
                    
                    	VNI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_encap_type
                    
                    	VNI Encapsulation Type
                    	**type**\:   :py:class:`L2VpnVniEncaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniEncaps>`
                    
                    .. attribute:: vni_mode
                    
                    	VNI Mode
                    	**type**\:   :py:class:`L2VpnVniMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniMode>`
                    
                    .. attribute:: vni_port_state
                    
                    	VNI Port State
                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                    
                    .. attribute:: xconnect_id
                    
                    	Xconnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__init__()

                        self.yang_name = "vni-parameters"
                        self.yang_parent_name = "bridge-domain-info"

                        self.anycast_mcast_group_addr = YLeaf(YType.str, "anycast-mcast-group-addr")

                        self.anycast_vtep_ip_addr = YLeaf(YType.str, "anycast-vtep-ip-addr")

                        self.multicast_group_addr = YLeaf(YType.str, "multicast-group-addr")

                        self.overlay = YLeaf(YType.str, "overlay")

                        self.source_ip_addr = YLeaf(YType.str, "source-ip-addr")

                        self.udp_port = YLeaf(YType.uint32, "udp-port")

                        self.vni = YLeaf(YType.uint32, "vni")

                        self.vni_encap_type = YLeaf(YType.enumeration, "vni-encap-type")

                        self.vni_mode = YLeaf(YType.enumeration, "vni-mode")

                        self.vni_port_state = YLeaf(YType.enumeration, "vni-port-state")

                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                        self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                        self.security_parameters.parent = self
                        self._children_name_map["security_parameters"] = "security-parameters"
                        self._children_yang_names.add("security-parameters")

                        self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                        self.static_mac = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("anycast_mcast_group_addr",
                                        "anycast_vtep_ip_addr",
                                        "multicast_group_addr",
                                        "overlay",
                                        "source_ip_addr",
                                        "udp_port",
                                        "vni",
                                        "vni_encap_type",
                                        "vni_mode",
                                        "vni_port_state",
                                        "xconnect_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__setattr__(name, value)


                    class SecurityParameters(Entity):
                        """
                        Security Parameters
                        
                        .. attribute:: base
                        
                        	Basic Security Parameters
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        .. attribute:: dhcpv4_trust
                        
                        	DHCPv4 Trust Status
                        	**type**\:  bool
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__init__()

                            self.yang_name = "security-parameters"
                            self.yang_parent_name = "vni-parameters"

                            self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                            self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                            self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                            self.dhcpv4_trust = YLeaf(YType.boolean, "dhcpv4-trust")

                            self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                            self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                            self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                            self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                            self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                            self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                            self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._children_yang_names.add("base")

                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self._children_name_map["storm_control"] = "storm-control"
                            self._children_yang_names.add("storm-control")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("broadcast_storm_control_kb_ps",
                                            "broadcast_storm_control_pps",
                                            "broadcast_storm_control_rate_unit",
                                            "dhcpv4_trust",
                                            "multicast_storm_control_kb_ps",
                                            "multicast_storm_control_pps",
                                            "multicast_storm_control_rate_unit",
                                            "unicast_storm_control_kb_ps",
                                            "unicast_storm_control_pps",
                                            "unicast_storm_control_rate_unit") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__setattr__(name, value)


                        class Base(Entity):
                            """
                            Basic Security Parameters
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: dai_address_validation_mask
                            
                            	DAI Address Validation mask
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dhcpv4_profile_name
                            
                            	DHCPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: dhcpv4_snoop
                            
                            	DHCPv4 Snoop Status
                            	**type**\:  bool
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Flooding unknown unicast enabled
                            	**type**\:  bool
                            
                            .. attribute:: flood_uu_disabled_mac_limit_action
                            
                            	Flooding of unknown\-unicast disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_disabled
                            
                            	IGMPv4 Disabled
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_profile_name
                            
                            	IGMPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                            
                            	Is DAI Dstination MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                            
                            	Is DAI IPv4 Addr Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_source_guard_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                            
                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: learn_disabled_mac_limit_action
                            
                            	Learning disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_mode
                            
                            	MAC Aging Mode
                            	**type**\:   :py:class:`L2VpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingMode>`
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: mac_flooding
                            
                            	MAC flooding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning
                            
                            	MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC address limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`L2VpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitAction>`
                            
                            .. attribute:: mac_limit_notification
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`L2VpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotify>`
                            
                            .. attribute:: mac_limit_reached
                            
                            	MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mac_port_down_flush_enabled
                            
                            	MAC Flush when port goes down
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC Secure Action
                            	**type**\:   :py:class:`L2VpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureAction>`
                            
                            .. attribute:: mld_profile_name
                            
                            	MLD Profile Name
                            	**type**\:  str
                            
                            .. attribute:: mmrp_flood_optimization
                            
                            	MMRP Flood Optimization Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            .. attribute:: split_horizon_group_id
                            
                            	Split Horizon Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "security-parameters"

                                self.broadcast_storm_control_kb_ps = YLeaf(YType.uint64, "broadcast-storm-control-kb-ps")

                                self.broadcast_storm_control_pps = YLeaf(YType.uint64, "broadcast-storm-control-pps")

                                self.broadcast_storm_control_rate_unit = YLeaf(YType.enumeration, "broadcast-storm-control-rate-unit")

                                self.dai_address_validation_mask = YLeaf(YType.uint8, "dai-address-validation-mask")

                                self.dhcpv4_profile_name = YLeaf(YType.str, "dhcpv4-profile-name")

                                self.dhcpv4_snoop = YLeaf(YType.boolean, "dhcpv4-snoop")

                                self.flood_unknown_unicast_enabled = YLeaf(YType.boolean, "flood-unknown-unicast-enabled")

                                self.flood_uu_disabled_mac_limit_action = YLeaf(YType.boolean, "flood-uu-disabled-mac-limit-action")

                                self.igm_pv4_disabled = YLeaf(YType.boolean, "igm-pv4-disabled")

                                self.igm_pv4_profile_name = YLeaf(YType.str, "igm-pv4-profile-name")

                                self.is_dai_addr_validate_destination_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-destination-mac-enabled")

                                self.is_dai_addr_validate_ipv4_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-ipv4-enabled")

                                self.is_dai_addr_validate_source_mac_enabled = YLeaf(YType.boolean, "is-dai-addr-validate-source-mac-enabled")

                                self.is_dai_enabled = YLeaf(YType.boolean, "is-dai-enabled")

                                self.is_dai_logging_enabled = YLeaf(YType.boolean, "is-dai-logging-enabled")

                                self.is_ip_source_guard_enabled = YLeaf(YType.boolean, "is-ip-source-guard-enabled")

                                self.is_ipsg_logging_enabled = YLeaf(YType.boolean, "is-ipsg-logging-enabled")

                                self.is_mac_secure_accept_shutdown_enabled = YLeaf(YType.boolean, "is-mac-secure-accept-shutdown-enabled")

                                self.is_mac_secure_enabled = YLeaf(YType.boolean, "is-mac-secure-enabled")

                                self.is_mac_secure_logging_enabled = YLeaf(YType.boolean, "is-mac-secure-logging-enabled")

                                self.learn_disabled_mac_limit_action = YLeaf(YType.boolean, "learn-disabled-mac-limit-action")

                                self.mac_aging_mode = YLeaf(YType.enumeration, "mac-aging-mode")

                                self.mac_aging_time = YLeaf(YType.uint32, "mac-aging-time")

                                self.mac_flooding = YLeaf(YType.boolean, "mac-flooding")

                                self.mac_learning = YLeaf(YType.boolean, "mac-learning")

                                self.mac_limit = YLeaf(YType.uint32, "mac-limit")

                                self.mac_limit_action = YLeaf(YType.enumeration, "mac-limit-action")

                                self.mac_limit_notification = YLeaf(YType.enumeration, "mac-limit-notification")

                                self.mac_limit_reached = YLeaf(YType.boolean, "mac-limit-reached")

                                self.mac_port_down_flush_enabled = YLeaf(YType.boolean, "mac-port-down-flush-enabled")

                                self.mac_secure_action = YLeaf(YType.enumeration, "mac-secure-action")

                                self.mld_profile_name = YLeaf(YType.str, "mld-profile-name")

                                self.mmrp_flood_optimization = YLeaf(YType.boolean, "mmrp-flood-optimization")

                                self.multicast_storm_control_kb_ps = YLeaf(YType.uint64, "multicast-storm-control-kb-ps")

                                self.multicast_storm_control_pps = YLeaf(YType.uint64, "multicast-storm-control-pps")

                                self.multicast_storm_control_rate_unit = YLeaf(YType.enumeration, "multicast-storm-control-rate-unit")

                                self.split_horizon_group_id = YLeaf(YType.uint32, "split-horizon-group-id")

                                self.unicast_storm_control_kb_ps = YLeaf(YType.uint64, "unicast-storm-control-kb-ps")

                                self.unicast_storm_control_pps = YLeaf(YType.uint64, "unicast-storm-control-pps")

                                self.unicast_storm_control_rate_unit = YLeaf(YType.enumeration, "unicast-storm-control-rate-unit")

                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._children_yang_names.add("storm-control")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("broadcast_storm_control_kb_ps",
                                                "broadcast_storm_control_pps",
                                                "broadcast_storm_control_rate_unit",
                                                "dai_address_validation_mask",
                                                "dhcpv4_profile_name",
                                                "dhcpv4_snoop",
                                                "flood_unknown_unicast_enabled",
                                                "flood_uu_disabled_mac_limit_action",
                                                "igm_pv4_disabled",
                                                "igm_pv4_profile_name",
                                                "is_dai_addr_validate_destination_mac_enabled",
                                                "is_dai_addr_validate_ipv4_enabled",
                                                "is_dai_addr_validate_source_mac_enabled",
                                                "is_dai_enabled",
                                                "is_dai_logging_enabled",
                                                "is_ip_source_guard_enabled",
                                                "is_ipsg_logging_enabled",
                                                "is_mac_secure_accept_shutdown_enabled",
                                                "is_mac_secure_enabled",
                                                "is_mac_secure_logging_enabled",
                                                "learn_disabled_mac_limit_action",
                                                "mac_aging_mode",
                                                "mac_aging_time",
                                                "mac_flooding",
                                                "mac_learning",
                                                "mac_limit",
                                                "mac_limit_action",
                                                "mac_limit_notification",
                                                "mac_limit_reached",
                                                "mac_port_down_flush_enabled",
                                                "mac_secure_action",
                                                "mld_profile_name",
                                                "mmrp_flood_optimization",
                                                "multicast_storm_control_kb_ps",
                                                "multicast_storm_control_pps",
                                                "multicast_storm_control_rate_unit",
                                                "split_horizon_group_id",
                                                "unicast_storm_control_kb_ps",
                                                "unicast_storm_control_pps",
                                                "unicast_storm_control_rate_unit") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__setattr__(name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "base"

                                    self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                    self.broadcast = YLeaf(YType.boolean, "broadcast")

                                    self.multicast = YLeaf(YType.boolean, "multicast")

                                    self.unicast = YLeaf(YType.boolean, "unicast")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bd_policer",
                                                    "broadcast",
                                                    "multicast",
                                                    "unicast") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bd_policer.is_set or
                                        self.broadcast.is_set or
                                        self.multicast.is_set or
                                        self.unicast.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bd_policer.yfilter != YFilter.not_set or
                                        self.broadcast.yfilter != YFilter.not_set or
                                        self.multicast.yfilter != YFilter.not_set or
                                        self.unicast.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "storm-control" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/base/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                    if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.broadcast.get_name_leafdata())
                                    if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multicast.get_name_leafdata())
                                    if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.unicast.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bd-policer"):
                                        self.bd_policer = value
                                        self.bd_policer.value_namespace = name_space
                                        self.bd_policer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "broadcast"):
                                        self.broadcast = value
                                        self.broadcast.value_namespace = name_space
                                        self.broadcast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multicast"):
                                        self.multicast = value
                                        self.multicast.value_namespace = name_space
                                        self.multicast.value_namespace_prefix = name_space_prefix
                                    if(value_path == "unicast"):
                                        self.unicast = value
                                        self.unicast.value_namespace = name_space
                                        self.unicast.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.broadcast_storm_control_kb_ps.is_set or
                                    self.broadcast_storm_control_pps.is_set or
                                    self.broadcast_storm_control_rate_unit.is_set or
                                    self.dai_address_validation_mask.is_set or
                                    self.dhcpv4_profile_name.is_set or
                                    self.dhcpv4_snoop.is_set or
                                    self.flood_unknown_unicast_enabled.is_set or
                                    self.flood_uu_disabled_mac_limit_action.is_set or
                                    self.igm_pv4_disabled.is_set or
                                    self.igm_pv4_profile_name.is_set or
                                    self.is_dai_addr_validate_destination_mac_enabled.is_set or
                                    self.is_dai_addr_validate_ipv4_enabled.is_set or
                                    self.is_dai_addr_validate_source_mac_enabled.is_set or
                                    self.is_dai_enabled.is_set or
                                    self.is_dai_logging_enabled.is_set or
                                    self.is_ip_source_guard_enabled.is_set or
                                    self.is_ipsg_logging_enabled.is_set or
                                    self.is_mac_secure_accept_shutdown_enabled.is_set or
                                    self.is_mac_secure_enabled.is_set or
                                    self.is_mac_secure_logging_enabled.is_set or
                                    self.learn_disabled_mac_limit_action.is_set or
                                    self.mac_aging_mode.is_set or
                                    self.mac_aging_time.is_set or
                                    self.mac_flooding.is_set or
                                    self.mac_learning.is_set or
                                    self.mac_limit.is_set or
                                    self.mac_limit_action.is_set or
                                    self.mac_limit_notification.is_set or
                                    self.mac_limit_reached.is_set or
                                    self.mac_port_down_flush_enabled.is_set or
                                    self.mac_secure_action.is_set or
                                    self.mld_profile_name.is_set or
                                    self.mmrp_flood_optimization.is_set or
                                    self.multicast_storm_control_kb_ps.is_set or
                                    self.multicast_storm_control_pps.is_set or
                                    self.multicast_storm_control_rate_unit.is_set or
                                    self.split_horizon_group_id.is_set or
                                    self.unicast_storm_control_kb_ps.is_set or
                                    self.unicast_storm_control_pps.is_set or
                                    self.unicast_storm_control_rate_unit.is_set or
                                    (self.storm_control is not None and self.storm_control.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.dai_address_validation_mask.yfilter != YFilter.not_set or
                                    self.dhcpv4_profile_name.yfilter != YFilter.not_set or
                                    self.dhcpv4_snoop.yfilter != YFilter.not_set or
                                    self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set or
                                    self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                    self.igm_pv4_disabled.yfilter != YFilter.not_set or
                                    self.igm_pv4_profile_name.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_enabled.yfilter != YFilter.not_set or
                                    self.is_dai_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_ip_source_guard_enabled.yfilter != YFilter.not_set or
                                    self.is_ipsg_logging_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_enabled.yfilter != YFilter.not_set or
                                    self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set or
                                    self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set or
                                    self.mac_aging_mode.yfilter != YFilter.not_set or
                                    self.mac_aging_time.yfilter != YFilter.not_set or
                                    self.mac_flooding.yfilter != YFilter.not_set or
                                    self.mac_learning.yfilter != YFilter.not_set or
                                    self.mac_limit.yfilter != YFilter.not_set or
                                    self.mac_limit_action.yfilter != YFilter.not_set or
                                    self.mac_limit_notification.yfilter != YFilter.not_set or
                                    self.mac_limit_reached.yfilter != YFilter.not_set or
                                    self.mac_port_down_flush_enabled.yfilter != YFilter.not_set or
                                    self.mac_secure_action.yfilter != YFilter.not_set or
                                    self.mld_profile_name.yfilter != YFilter.not_set or
                                    self.mmrp_flood_optimization.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    self.split_horizon_group_id.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                    self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                    (self.storm_control is not None and self.storm_control.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "base" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                                if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                                if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                                if (self.dai_address_validation_mask.is_set or self.dai_address_validation_mask.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dai_address_validation_mask.get_name_leafdata())
                                if (self.dhcpv4_profile_name.is_set or self.dhcpv4_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_profile_name.get_name_leafdata())
                                if (self.dhcpv4_snoop.is_set or self.dhcpv4_snoop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dhcpv4_snoop.get_name_leafdata())
                                if (self.flood_unknown_unicast_enabled.is_set or self.flood_unknown_unicast_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_unknown_unicast_enabled.get_name_leafdata())
                                if (self.flood_uu_disabled_mac_limit_action.is_set or self.flood_uu_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_uu_disabled_mac_limit_action.get_name_leafdata())
                                if (self.igm_pv4_disabled.is_set or self.igm_pv4_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igm_pv4_disabled.get_name_leafdata())
                                if (self.igm_pv4_profile_name.is_set or self.igm_pv4_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igm_pv4_profile_name.get_name_leafdata())
                                if (self.is_dai_addr_validate_destination_mac_enabled.is_set or self.is_dai_addr_validate_destination_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_destination_mac_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validate_ipv4_enabled.is_set or self.is_dai_addr_validate_ipv4_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_ipv4_enabled.get_name_leafdata())
                                if (self.is_dai_addr_validate_source_mac_enabled.is_set or self.is_dai_addr_validate_source_mac_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_addr_validate_source_mac_enabled.get_name_leafdata())
                                if (self.is_dai_enabled.is_set or self.is_dai_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_enabled.get_name_leafdata())
                                if (self.is_dai_logging_enabled.is_set or self.is_dai_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_dai_logging_enabled.get_name_leafdata())
                                if (self.is_ip_source_guard_enabled.is_set or self.is_ip_source_guard_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ip_source_guard_enabled.get_name_leafdata())
                                if (self.is_ipsg_logging_enabled.is_set or self.is_ipsg_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ipsg_logging_enabled.get_name_leafdata())
                                if (self.is_mac_secure_accept_shutdown_enabled.is_set or self.is_mac_secure_accept_shutdown_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_accept_shutdown_enabled.get_name_leafdata())
                                if (self.is_mac_secure_enabled.is_set or self.is_mac_secure_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_enabled.get_name_leafdata())
                                if (self.is_mac_secure_logging_enabled.is_set or self.is_mac_secure_logging_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_mac_secure_logging_enabled.get_name_leafdata())
                                if (self.learn_disabled_mac_limit_action.is_set or self.learn_disabled_mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.learn_disabled_mac_limit_action.get_name_leafdata())
                                if (self.mac_aging_mode.is_set or self.mac_aging_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_mode.get_name_leafdata())
                                if (self.mac_aging_time.is_set or self.mac_aging_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_aging_time.get_name_leafdata())
                                if (self.mac_flooding.is_set or self.mac_flooding.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_flooding.get_name_leafdata())
                                if (self.mac_learning.is_set or self.mac_learning.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_learning.get_name_leafdata())
                                if (self.mac_limit.is_set or self.mac_limit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit.get_name_leafdata())
                                if (self.mac_limit_action.is_set or self.mac_limit_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_action.get_name_leafdata())
                                if (self.mac_limit_notification.is_set or self.mac_limit_notification.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_notification.get_name_leafdata())
                                if (self.mac_limit_reached.is_set or self.mac_limit_reached.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_limit_reached.get_name_leafdata())
                                if (self.mac_port_down_flush_enabled.is_set or self.mac_port_down_flush_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_port_down_flush_enabled.get_name_leafdata())
                                if (self.mac_secure_action.is_set or self.mac_secure_action.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_secure_action.get_name_leafdata())
                                if (self.mld_profile_name.is_set or self.mld_profile_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mld_profile_name.get_name_leafdata())
                                if (self.mmrp_flood_optimization.is_set or self.mmrp_flood_optimization.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mmrp_flood_optimization.get_name_leafdata())
                                if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                                if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                                if (self.split_horizon_group_id.is_set or self.split_horizon_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.split_horizon_group_id.get_name_leafdata())
                                if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                                if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                                if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "storm-control"):
                                    if (self.storm_control is None):
                                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                    return self.storm_control

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dai-address-validation-mask" or name == "dhcpv4-profile-name" or name == "dhcpv4-snoop" or name == "flood-unknown-unicast-enabled" or name == "flood-uu-disabled-mac-limit-action" or name == "igm-pv4-disabled" or name == "igm-pv4-profile-name" or name == "is-dai-addr-validate-destination-mac-enabled" or name == "is-dai-addr-validate-ipv4-enabled" or name == "is-dai-addr-validate-source-mac-enabled" or name == "is-dai-enabled" or name == "is-dai-logging-enabled" or name == "is-ip-source-guard-enabled" or name == "is-ipsg-logging-enabled" or name == "is-mac-secure-accept-shutdown-enabled" or name == "is-mac-secure-enabled" or name == "is-mac-secure-logging-enabled" or name == "learn-disabled-mac-limit-action" or name == "mac-aging-mode" or name == "mac-aging-time" or name == "mac-flooding" or name == "mac-learning" or name == "mac-limit" or name == "mac-limit-action" or name == "mac-limit-notification" or name == "mac-limit-reached" or name == "mac-port-down-flush-enabled" or name == "mac-secure-action" or name == "mld-profile-name" or name == "mmrp-flood-optimization" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "split-horizon-group-id" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "broadcast-storm-control-kb-ps"):
                                    self.broadcast_storm_control_kb_ps = value
                                    self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                    self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-pps"):
                                    self.broadcast_storm_control_pps = value
                                    self.broadcast_storm_control_pps.value_namespace = name_space
                                    self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast-storm-control-rate-unit"):
                                    self.broadcast_storm_control_rate_unit = value
                                    self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                    self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "dai-address-validation-mask"):
                                    self.dai_address_validation_mask = value
                                    self.dai_address_validation_mask.value_namespace = name_space
                                    self.dai_address_validation_mask.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-profile-name"):
                                    self.dhcpv4_profile_name = value
                                    self.dhcpv4_profile_name.value_namespace = name_space
                                    self.dhcpv4_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "dhcpv4-snoop"):
                                    self.dhcpv4_snoop = value
                                    self.dhcpv4_snoop.value_namespace = name_space
                                    self.dhcpv4_snoop.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-unknown-unicast-enabled"):
                                    self.flood_unknown_unicast_enabled = value
                                    self.flood_unknown_unicast_enabled.value_namespace = name_space
                                    self.flood_unknown_unicast_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-uu-disabled-mac-limit-action"):
                                    self.flood_uu_disabled_mac_limit_action = value
                                    self.flood_uu_disabled_mac_limit_action.value_namespace = name_space
                                    self.flood_uu_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "igm-pv4-disabled"):
                                    self.igm_pv4_disabled = value
                                    self.igm_pv4_disabled.value_namespace = name_space
                                    self.igm_pv4_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "igm-pv4-profile-name"):
                                    self.igm_pv4_profile_name = value
                                    self.igm_pv4_profile_name.value_namespace = name_space
                                    self.igm_pv4_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-destination-mac-enabled"):
                                    self.is_dai_addr_validate_destination_mac_enabled = value
                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_destination_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-ipv4-enabled"):
                                    self.is_dai_addr_validate_ipv4_enabled = value
                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_ipv4_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-addr-validate-source-mac-enabled"):
                                    self.is_dai_addr_validate_source_mac_enabled = value
                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace = name_space
                                    self.is_dai_addr_validate_source_mac_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-enabled"):
                                    self.is_dai_enabled = value
                                    self.is_dai_enabled.value_namespace = name_space
                                    self.is_dai_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-dai-logging-enabled"):
                                    self.is_dai_logging_enabled = value
                                    self.is_dai_logging_enabled.value_namespace = name_space
                                    self.is_dai_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ip-source-guard-enabled"):
                                    self.is_ip_source_guard_enabled = value
                                    self.is_ip_source_guard_enabled.value_namespace = name_space
                                    self.is_ip_source_guard_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ipsg-logging-enabled"):
                                    self.is_ipsg_logging_enabled = value
                                    self.is_ipsg_logging_enabled.value_namespace = name_space
                                    self.is_ipsg_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-accept-shutdown-enabled"):
                                    self.is_mac_secure_accept_shutdown_enabled = value
                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace = name_space
                                    self.is_mac_secure_accept_shutdown_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-enabled"):
                                    self.is_mac_secure_enabled = value
                                    self.is_mac_secure_enabled.value_namespace = name_space
                                    self.is_mac_secure_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-mac-secure-logging-enabled"):
                                    self.is_mac_secure_logging_enabled = value
                                    self.is_mac_secure_logging_enabled.value_namespace = name_space
                                    self.is_mac_secure_logging_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "learn-disabled-mac-limit-action"):
                                    self.learn_disabled_mac_limit_action = value
                                    self.learn_disabled_mac_limit_action.value_namespace = name_space
                                    self.learn_disabled_mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-mode"):
                                    self.mac_aging_mode = value
                                    self.mac_aging_mode.value_namespace = name_space
                                    self.mac_aging_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-aging-time"):
                                    self.mac_aging_time = value
                                    self.mac_aging_time.value_namespace = name_space
                                    self.mac_aging_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-flooding"):
                                    self.mac_flooding = value
                                    self.mac_flooding.value_namespace = name_space
                                    self.mac_flooding.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-learning"):
                                    self.mac_learning = value
                                    self.mac_learning.value_namespace = name_space
                                    self.mac_learning.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit"):
                                    self.mac_limit = value
                                    self.mac_limit.value_namespace = name_space
                                    self.mac_limit.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-action"):
                                    self.mac_limit_action = value
                                    self.mac_limit_action.value_namespace = name_space
                                    self.mac_limit_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-notification"):
                                    self.mac_limit_notification = value
                                    self.mac_limit_notification.value_namespace = name_space
                                    self.mac_limit_notification.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-limit-reached"):
                                    self.mac_limit_reached = value
                                    self.mac_limit_reached.value_namespace = name_space
                                    self.mac_limit_reached.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-port-down-flush-enabled"):
                                    self.mac_port_down_flush_enabled = value
                                    self.mac_port_down_flush_enabled.value_namespace = name_space
                                    self.mac_port_down_flush_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-secure-action"):
                                    self.mac_secure_action = value
                                    self.mac_secure_action.value_namespace = name_space
                                    self.mac_secure_action.value_namespace_prefix = name_space_prefix
                                if(value_path == "mld-profile-name"):
                                    self.mld_profile_name = value
                                    self.mld_profile_name.value_namespace = name_space
                                    self.mld_profile_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "mmrp-flood-optimization"):
                                    self.mmrp_flood_optimization = value
                                    self.mmrp_flood_optimization.value_namespace = name_space
                                    self.mmrp_flood_optimization.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-kb-ps"):
                                    self.multicast_storm_control_kb_ps = value
                                    self.multicast_storm_control_kb_ps.value_namespace = name_space
                                    self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-pps"):
                                    self.multicast_storm_control_pps = value
                                    self.multicast_storm_control_pps.value_namespace = name_space
                                    self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast-storm-control-rate-unit"):
                                    self.multicast_storm_control_rate_unit = value
                                    self.multicast_storm_control_rate_unit.value_namespace = name_space
                                    self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "split-horizon-group-id"):
                                    self.split_horizon_group_id = value
                                    self.split_horizon_group_id.value_namespace = name_space
                                    self.split_horizon_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-kb-ps"):
                                    self.unicast_storm_control_kb_ps = value
                                    self.unicast_storm_control_kb_ps.value_namespace = name_space
                                    self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-pps"):
                                    self.unicast_storm_control_pps = value
                                    self.unicast_storm_control_pps.value_namespace = name_space
                                    self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast-storm-control-rate-unit"):
                                    self.unicast_storm_control_rate_unit = value
                                    self.unicast_storm_control_rate_unit.value_namespace = name_space
                                    self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                        class StormControl(Entity):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\:  bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__init__()

                                self.yang_name = "storm-control"
                                self.yang_parent_name = "security-parameters"

                                self.bd_policer = YLeaf(YType.boolean, "bd-policer")

                                self.broadcast = YLeaf(YType.boolean, "broadcast")

                                self.multicast = YLeaf(YType.boolean, "multicast")

                                self.unicast = YLeaf(YType.boolean, "unicast")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bd_policer",
                                                "broadcast",
                                                "multicast",
                                                "unicast") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bd_policer.is_set or
                                    self.broadcast.is_set or
                                    self.multicast.is_set or
                                    self.unicast.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bd_policer.yfilter != YFilter.not_set or
                                    self.broadcast.yfilter != YFilter.not_set or
                                    self.multicast.yfilter != YFilter.not_set or
                                    self.unicast.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "storm-control" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bd_policer.is_set or self.bd_policer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bd_policer.get_name_leafdata())
                                if (self.broadcast.is_set or self.broadcast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.broadcast.get_name_leafdata())
                                if (self.multicast.is_set or self.multicast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multicast.get_name_leafdata())
                                if (self.unicast.is_set or self.unicast.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unicast.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bd-policer" or name == "broadcast" or name == "multicast" or name == "unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bd-policer"):
                                    self.bd_policer = value
                                    self.bd_policer.value_namespace = name_space
                                    self.bd_policer.value_namespace_prefix = name_space_prefix
                                if(value_path == "broadcast"):
                                    self.broadcast = value
                                    self.broadcast.value_namespace = name_space
                                    self.broadcast.value_namespace_prefix = name_space_prefix
                                if(value_path == "multicast"):
                                    self.multicast = value
                                    self.multicast.value_namespace = name_space
                                    self.multicast.value_namespace_prefix = name_space_prefix
                                if(value_path == "unicast"):
                                    self.unicast = value
                                    self.unicast.value_namespace = name_space
                                    self.unicast.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.broadcast_storm_control_kb_ps.is_set or
                                self.broadcast_storm_control_pps.is_set or
                                self.broadcast_storm_control_rate_unit.is_set or
                                self.dhcpv4_trust.is_set or
                                self.multicast_storm_control_kb_ps.is_set or
                                self.multicast_storm_control_pps.is_set or
                                self.multicast_storm_control_rate_unit.is_set or
                                self.unicast_storm_control_kb_ps.is_set or
                                self.unicast_storm_control_pps.is_set or
                                self.unicast_storm_control_rate_unit.is_set or
                                (self.base is not None and self.base.has_data()) or
                                (self.storm_control is not None and self.storm_control.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_pps.yfilter != YFilter.not_set or
                                self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                self.dhcpv4_trust.yfilter != YFilter.not_set or
                                self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_pps.yfilter != YFilter.not_set or
                                self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set or
                                (self.base is not None and self.base.has_operation()) or
                                (self.storm_control is not None and self.storm_control.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "security-parameters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.broadcast_storm_control_kb_ps.is_set or self.broadcast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_kb_ps.get_name_leafdata())
                            if (self.broadcast_storm_control_pps.is_set or self.broadcast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_pps.get_name_leafdata())
                            if (self.broadcast_storm_control_rate_unit.is_set or self.broadcast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.broadcast_storm_control_rate_unit.get_name_leafdata())
                            if (self.dhcpv4_trust.is_set or self.dhcpv4_trust.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dhcpv4_trust.get_name_leafdata())
                            if (self.multicast_storm_control_kb_ps.is_set or self.multicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.multicast_storm_control_pps.is_set or self.multicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_pps.get_name_leafdata())
                            if (self.multicast_storm_control_rate_unit.is_set or self.multicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multicast_storm_control_rate_unit.get_name_leafdata())
                            if (self.unicast_storm_control_kb_ps.is_set or self.unicast_storm_control_kb_ps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_kb_ps.get_name_leafdata())
                            if (self.unicast_storm_control_pps.is_set or self.unicast_storm_control_pps.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_pps.get_name_leafdata())
                            if (self.unicast_storm_control_rate_unit.is_set or self.unicast_storm_control_rate_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unicast_storm_control_rate_unit.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "base"):
                                if (self.base is None):
                                    self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                return self.base

                            if (child_yang_name == "storm-control"):
                                if (self.storm_control is None):
                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                return self.storm_control

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "base" or name == "storm-control" or name == "broadcast-storm-control-kb-ps" or name == "broadcast-storm-control-pps" or name == "broadcast-storm-control-rate-unit" or name == "dhcpv4-trust" or name == "multicast-storm-control-kb-ps" or name == "multicast-storm-control-pps" or name == "multicast-storm-control-rate-unit" or name == "unicast-storm-control-kb-ps" or name == "unicast-storm-control-pps" or name == "unicast-storm-control-rate-unit"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "broadcast-storm-control-kb-ps"):
                                self.broadcast_storm_control_kb_ps = value
                                self.broadcast_storm_control_kb_ps.value_namespace = name_space
                                self.broadcast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-pps"):
                                self.broadcast_storm_control_pps = value
                                self.broadcast_storm_control_pps.value_namespace = name_space
                                self.broadcast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "broadcast-storm-control-rate-unit"):
                                self.broadcast_storm_control_rate_unit = value
                                self.broadcast_storm_control_rate_unit.value_namespace = name_space
                                self.broadcast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "dhcpv4-trust"):
                                self.dhcpv4_trust = value
                                self.dhcpv4_trust.value_namespace = name_space
                                self.dhcpv4_trust.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-kb-ps"):
                                self.multicast_storm_control_kb_ps = value
                                self.multicast_storm_control_kb_ps.value_namespace = name_space
                                self.multicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-pps"):
                                self.multicast_storm_control_pps = value
                                self.multicast_storm_control_pps.value_namespace = name_space
                                self.multicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "multicast-storm-control-rate-unit"):
                                self.multicast_storm_control_rate_unit = value
                                self.multicast_storm_control_rate_unit.value_namespace = name_space
                                self.multicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-kb-ps"):
                                self.unicast_storm_control_kb_ps = value
                                self.unicast_storm_control_kb_ps.value_namespace = name_space
                                self.unicast_storm_control_kb_ps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-pps"):
                                self.unicast_storm_control_pps = value
                                self.unicast_storm_control_pps.value_namespace = name_space
                                self.unicast_storm_control_pps.value_namespace_prefix = name_space_prefix
                            if(value_path == "unicast-storm-control-rate-unit"):
                                self.unicast_storm_control_rate_unit = value
                                self.unicast_storm_control_rate_unit.value_namespace = name_space
                                self.unicast_storm_control_rate_unit.value_namespace_prefix = name_space_prefix


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "vni-parameters"

                            self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                            self._children_yang_names.add("dispostion-stats")

                            self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self._children_name_map["impostion_stats"] = "impostion-stats"
                            self._children_yang_names.add("impostion-stats")

                            self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                            self.sequence_number.parent = self
                            self._children_name_map["sequence_number"] = "sequence-number"
                            self._children_yang_names.add("sequence-number")


                        class ImpostionStats(Entity):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats, self).__init__()

                                self.yang_name = "impostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self._children_name_map["broadcast"] = "broadcast"
                                self._children_yang_names.add("broadcast")

                                self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                self._children_yang_names.add("imposition-mtu-drop")

                                self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                self._children_yang_names.add("imposition-stat")

                                self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                self._children_yang_names.add("impostion-tail-drop")

                                self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                self._children_yang_names.add("l2fsbi-drop")

                                self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                                self._children_yang_names.add("multicast")

                                self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self
                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                self._children_yang_names.add("unknown-unicast")


                            class ImpositionStat(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                    self.yang_name = "imposition-stat"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpositionMtuDrop(Entity):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                    self.yang_name = "imposition-mtu-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpostionTailDrop(Entity):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                    self.yang_name = "impostion-tail-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class L2FsbiDrop(Entity):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                    self.yang_name = "l2fsbi-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fsbi-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Multicast(Entity):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Broadcast(Entity):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__init__()

                                    self.yang_name = "broadcast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnknownUnicast(Entity):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                    self.yang_name = "unknown-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unknown-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                    (self.multicast is not None and self.multicast.has_data()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                    (self.multicast is not None and self.multicast.has_operation()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "impostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast"):
                                    if (self.broadcast is None):
                                        self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                    return self.broadcast

                                if (child_yang_name == "imposition-mtu-drop"):
                                    if (self.imposition_mtu_drop is None):
                                        self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    return self.imposition_mtu_drop

                                if (child_yang_name == "imposition-stat"):
                                    if (self.imposition_stat is None):
                                        self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                    return self.imposition_stat

                                if (child_yang_name == "impostion-tail-drop"):
                                    if (self.impostion_tail_drop is None):
                                        self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    return self.impostion_tail_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "l2fsbi-drop"):
                                    if (self.l2fsbi_drop is None):
                                        self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    return self.l2fsbi_drop

                                if (child_yang_name == "multicast"):
                                    if (self.multicast is None):
                                        self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                    return self.multicast

                                if (child_yang_name == "unknown-unicast"):
                                    if (self.unknown_unicast is None):
                                        self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    return self.unknown_unicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DispostionStats(Entity):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats, self).__init__()

                                self.yang_name = "dispostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                self._children_yang_names.add("broadcast-drop")

                                self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self._children_name_map["dai_drop"] = "dai-drop"
                                self._children_yang_names.add("dai-drop")

                                self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                self._children_yang_names.add("disposition-mtu-drop")

                                self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                self._children_yang_names.add("disposition-oo-o-drops")

                                self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                self._children_yang_names.add("disposition-p2mp-stats")

                                self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                self._children_yang_names.add("disposition-stat")

                                self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                self._children_yang_names.add("disposition-tail-drop")

                                self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                self._children_yang_names.add("ipsg-drop")

                                self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self._children_name_map["mac_move"] = "mac-move"
                                self._children_yang_names.add("mac-move")

                                self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                self._children_yang_names.add("multicast-drop")

                                self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self._children_name_map["received_drops"] = "received-drops"
                                self._children_yang_names.add("received-drops")

                                self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self
                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                self._children_yang_names.add("unicast-drop")


                            class DispositionStat(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__init__()

                                    self.yang_name = "disposition-stat"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionMtuDrop(Entity):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                    self.yang_name = "disposition-mtu-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionTailDrop(Entity):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                    self.yang_name = "disposition-tail-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MulticastDrop(Entity):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                    self.yang_name = "multicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnicastDrop(Entity):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                    self.yang_name = "unicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class BroadcastDrop(Entity):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                    self.yang_name = "broadcast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ReceivedDrops(Entity):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                    self.yang_name = "received-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DaiDrop(Entity):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__init__()

                                    self.yang_name = "dai-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dai-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class IpsgDrop(Entity):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                    self.yang_name = "ipsg-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipsg-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionOoODrops(Entity):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                    self.yang_name = "disposition-oo-o-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionP2MpStats(Entity):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                    self.yang_name = "disposition-p2mp-stats"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MacMove(Entity):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__init__()

                                    self.yang_name = "mac-move"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-move" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dispostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast-drop"):
                                    if (self.broadcast_drop is None):
                                        self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    return self.broadcast_drop

                                if (child_yang_name == "dai-drop"):
                                    if (self.dai_drop is None):
                                        self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                    return self.dai_drop

                                if (child_yang_name == "disposition-mtu-drop"):
                                    if (self.disposition_mtu_drop is None):
                                        self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    return self.disposition_mtu_drop

                                if (child_yang_name == "disposition-oo-o-drops"):
                                    if (self.disposition_oo_o_drops is None):
                                        self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    return self.disposition_oo_o_drops

                                if (child_yang_name == "disposition-p2mp-stats"):
                                    if (self.disposition_p2mp_stats is None):
                                        self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    return self.disposition_p2mp_stats

                                if (child_yang_name == "disposition-stat"):
                                    if (self.disposition_stat is None):
                                        self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                    return self.disposition_stat

                                if (child_yang_name == "disposition-tail-drop"):
                                    if (self.disposition_tail_drop is None):
                                        self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    return self.disposition_tail_drop

                                if (child_yang_name == "ipsg-drop"):
                                    if (self.ipsg_drop is None):
                                        self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    return self.ipsg_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "mac-move"):
                                    if (self.mac_move is None):
                                        self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                    return self.mac_move

                                if (child_yang_name == "multicast-drop"):
                                    if (self.multicast_drop is None):
                                        self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                    return self.multicast_drop

                                if (child_yang_name == "received-drops"):
                                    if (self.received_drops is None):
                                        self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                    return self.received_drops

                                if (child_yang_name == "unicast-drop"):
                                    if (self.unicast_drop is None):
                                        self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                    return self.unicast_drop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SequenceNumber(Entity):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__init__()

                                self.yang_name = "sequence-number"
                                self.yang_parent_name = "statistics"

                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bypassed_inbound_sequence_packet",
                                                "bypassed_out_sequence_packet",
                                                "sequence_number_expected",
                                                "sequence_number_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bypassed_inbound_sequence_packet.is_set or
                                    self.bypassed_out_sequence_packet.is_set or
                                    self.sequence_number_expected.is_set or
                                    self.sequence_number_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sequence-number" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bypassed-inbound-sequence-packet"):
                                    self.bypassed_inbound_sequence_packet = value
                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "bypassed-out-sequence-packet"):
                                    self.bypassed_out_sequence_packet = value
                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-expected"):
                                    self.sequence_number_expected = value
                                    self.sequence_number_expected.value_namespace = name_space
                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-sent"):
                                    self.sequence_number_sent = value
                                    self.sequence_number_sent.value_namespace = name_space
                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                (self.sequence_number is not None and self.sequence_number.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dispostion-stats"):
                                if (self.dispostion_stats is None):
                                    self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                return self.dispostion_stats

                            if (child_yang_name == "impostion-stats"):
                                if (self.impostion_stats is None):
                                    self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                return self.impostion_stats

                            if (child_yang_name == "sequence-number"):
                                if (self.sequence_number is None):
                                    self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                return self.sequence_number

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class StaticMac(Entity):
                        """
                        Static MAC addresses
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__init__()

                            self.yang_name = "static-mac"
                            self.yang_parent_name = "vni-parameters"

                            self.address = YLeaf(YType.str, "address")

                            self.bmac = YLeaf(YType.str, "bmac")

                            self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "bmac",
                                            "next_hop_ip") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.bmac.is_set or
                                self.next_hop_ip.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.bmac.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "static-mac" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bmac.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "bmac"):
                                self.bmac = value
                                self.bmac.value_namespace = name_space
                                self.bmac.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.static_mac:
                            if (c.has_data()):
                                return True
                        return (
                            self.anycast_mcast_group_addr.is_set or
                            self.anycast_vtep_ip_addr.is_set or
                            self.multicast_group_addr.is_set or
                            self.overlay.is_set or
                            self.source_ip_addr.is_set or
                            self.udp_port.is_set or
                            self.vni.is_set or
                            self.vni_encap_type.is_set or
                            self.vni_mode.is_set or
                            self.vni_port_state.is_set or
                            self.xconnect_id.is_set or
                            (self.security_parameters is not None and self.security_parameters.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        for c in self.static_mac:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.anycast_mcast_group_addr.yfilter != YFilter.not_set or
                            self.anycast_vtep_ip_addr.yfilter != YFilter.not_set or
                            self.multicast_group_addr.yfilter != YFilter.not_set or
                            self.overlay.yfilter != YFilter.not_set or
                            self.source_ip_addr.yfilter != YFilter.not_set or
                            self.udp_port.yfilter != YFilter.not_set or
                            self.vni.yfilter != YFilter.not_set or
                            self.vni_encap_type.yfilter != YFilter.not_set or
                            self.vni_mode.yfilter != YFilter.not_set or
                            self.vni_port_state.yfilter != YFilter.not_set or
                            self.xconnect_id.yfilter != YFilter.not_set or
                            (self.security_parameters is not None and self.security_parameters.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vni-parameters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.anycast_mcast_group_addr.is_set or self.anycast_mcast_group_addr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_mcast_group_addr.get_name_leafdata())
                        if (self.anycast_vtep_ip_addr.is_set or self.anycast_vtep_ip_addr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_vtep_ip_addr.get_name_leafdata())
                        if (self.multicast_group_addr.is_set or self.multicast_group_addr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.multicast_group_addr.get_name_leafdata())
                        if (self.overlay.is_set or self.overlay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.overlay.get_name_leafdata())
                        if (self.source_ip_addr.is_set or self.source_ip_addr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_ip_addr.get_name_leafdata())
                        if (self.udp_port.is_set or self.udp_port.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.udp_port.get_name_leafdata())
                        if (self.vni.is_set or self.vni.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni.get_name_leafdata())
                        if (self.vni_encap_type.is_set or self.vni_encap_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_encap_type.get_name_leafdata())
                        if (self.vni_mode.is_set or self.vni_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_mode.get_name_leafdata())
                        if (self.vni_port_state.is_set or self.vni_port_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vni_port_state.get_name_leafdata())
                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "security-parameters"):
                            if (self.security_parameters is None):
                                self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"
                            return self.security_parameters

                        if (child_yang_name == "static-mac"):
                            for c in self.static_mac:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.static_mac.append(c)
                            return c

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "security-parameters" or name == "static-mac" or name == "statistics" or name == "anycast-mcast-group-addr" or name == "anycast-vtep-ip-addr" or name == "multicast-group-addr" or name == "overlay" or name == "source-ip-addr" or name == "udp-port" or name == "vni" or name == "vni-encap-type" or name == "vni-mode" or name == "vni-port-state" or name == "xconnect-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "anycast-mcast-group-addr"):
                            self.anycast_mcast_group_addr = value
                            self.anycast_mcast_group_addr.value_namespace = name_space
                            self.anycast_mcast_group_addr.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-vtep-ip-addr"):
                            self.anycast_vtep_ip_addr = value
                            self.anycast_vtep_ip_addr.value_namespace = name_space
                            self.anycast_vtep_ip_addr.value_namespace_prefix = name_space_prefix
                        if(value_path == "multicast-group-addr"):
                            self.multicast_group_addr = value
                            self.multicast_group_addr.value_namespace = name_space
                            self.multicast_group_addr.value_namespace_prefix = name_space_prefix
                        if(value_path == "overlay"):
                            self.overlay = value
                            self.overlay.value_namespace = name_space
                            self.overlay.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-ip-addr"):
                            self.source_ip_addr = value
                            self.source_ip_addr.value_namespace = name_space
                            self.source_ip_addr.value_namespace_prefix = name_space_prefix
                        if(value_path == "udp-port"):
                            self.udp_port = value
                            self.udp_port.value_namespace = name_space
                            self.udp_port.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni"):
                            self.vni = value
                            self.vni.value_namespace = name_space
                            self.vni.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni-encap-type"):
                            self.vni_encap_type = value
                            self.vni_encap_type.value_namespace = name_space
                            self.vni_encap_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni-mode"):
                            self.vni_mode = value
                            self.vni_mode.value_namespace = name_space
                            self.vni_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "vni-port-state"):
                            self.vni_port_state = value
                            self.vni_port_state.value_namespace = name_space
                            self.vni_port_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-id"):
                            self.xconnect_id = value
                            self.xconnect_id.value_namespace = name_space
                            self.xconnect_id.value_namespace_prefix = name_space_prefix


                class Rd(Entity):
                    """
                    Route Distinguisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__init__()

                        self.yang_name = "rd"
                        self.yang_parent_name = "bridge-domain-info"

                        self.rd = YLeaf(YType.enumeration, "rd")

                        self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"
                        self._children_yang_names.add("auto")

                        self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"
                        self._children_yang_names.add("four-byte-as")

                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"
                        self._children_yang_names.add("two-byte-as")

                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._children_yang_names.add("v4-addr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("rd") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__setattr__(name, value)


                    class Auto(Entity):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "rd"

                            self.auto_index = YLeaf(YType.uint16, "auto-index")

                            self.router_id = YLeaf(YType.str, "router-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("auto_index",
                                            "router_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.auto_index.is_set or
                                self.router_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.auto_index.yfilter != YFilter.not_set or
                                self.router_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "auto" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.auto_index.get_name_leafdata())
                            if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "auto-index" or name == "router-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "auto-index"):
                                self.auto_index = value
                                self.auto_index.value_namespace = name_space
                                self.auto_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-id"):
                                self.router_id = value
                                self.router_id.value_namespace = name_space
                                self.router_id.value_namespace_prefix = name_space_prefix


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "rd"

                            self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                            self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_index",
                                            "two_byte_as") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_index.is_set or
                                self.two_byte_as.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_index.yfilter != YFilter.not_set or
                                self.two_byte_as.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "two-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                            if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-index" or name == "two-byte-as"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-index"):
                                self.four_byte_index = value
                                self.four_byte_index.value_namespace = name_space
                                self.four_byte_index.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-as"):
                                self.two_byte_as = value
                                self.two_byte_as.value_namespace = name_space
                                self.two_byte_as.value_namespace_prefix = name_space_prefix


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "rd"

                            self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("four_byte_as",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.four_byte_as.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.four_byte_as.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "four-byte-as" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "four-byte-as" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "four-byte-as"):
                                self.four_byte_as = value
                                self.four_byte_as.value_namespace = name_space
                                self.four_byte_as.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "rd"

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ipv4_address",
                                            "two_byte_index") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ipv4_address.is_set or
                                self.two_byte_index.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.two_byte_index.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "v4-addr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4-address" or name == "two-byte-index"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "two-byte-index"):
                                self.two_byte_index = value
                                self.two_byte_index.value_namespace = name_space
                                self.two_byte_index.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.rd.is_set or
                            (self.auto is not None and self.auto.has_data()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                            (self.v4_addr is not None and self.v4_addr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.rd.yfilter != YFilter.not_set or
                            (self.auto is not None and self.auto.has_operation()) or
                            (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                            (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                            (self.v4_addr is not None and self.v4_addr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rd" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rd.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "auto"):
                            if (self.auto is None):
                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                            return self.auto

                        if (child_yang_name == "four-byte-as"):
                            if (self.four_byte_as is None):
                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                            return self.four_byte_as

                        if (child_yang_name == "two-byte-as"):
                            if (self.two_byte_as is None):
                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                            return self.two_byte_as

                        if (child_yang_name == "v4-addr"):
                            if (self.v4_addr is None):
                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                            return self.v4_addr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "rd"):
                            self.rd = value
                            self.rd.value_namespace = name_space
                            self.rd.value_namespace_prefix = name_space_prefix


                class MacFilter(Entity):
                    """
                    MAC addresses for filtering
                    
                    .. attribute:: address
                    
                    	MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: bmac
                    
                    	Backbone MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: next_hop_ip
                    
                    	Next Hop IP
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__init__()

                        self.yang_name = "mac-filter"
                        self.yang_parent_name = "bridge-domain-info"

                        self.address = YLeaf(YType.str, "address")

                        self.bmac = YLeaf(YType.str, "bmac")

                        self.next_hop_ip = YLeaf(YType.str, "next-hop-ip")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "bmac",
                                        "next_hop_ip") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.bmac.is_set or
                            self.next_hop_ip.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.bmac.yfilter != YFilter.not_set or
                            self.next_hop_ip.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mac-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.bmac.is_set or self.bmac.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bmac.get_name_leafdata())
                        if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.next_hop_ip.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "bmac" or name == "next-hop-ip"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "bmac"):
                            self.bmac = value
                            self.bmac.value_namespace = name_space
                            self.bmac.value_namespace_prefix = name_space_prefix
                        if(value_path == "next-hop-ip"):
                            self.next_hop_ip = value
                            self.next_hop_ip.value_namespace = name_space
                            self.next_hop_ip.value_namespace_prefix = name_space_prefix


                class BridgeVfi(Entity):
                    """
                    Virtual Forwarding Interfaces
                    
                    .. attribute:: access
                    
                    	VFI is an Access VFI
                    	**type**\:  bool
                    
                    .. attribute:: discovery_information
                    
                    	Auto Discovery information
                    	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of Pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_information
                    
                    	Multicast P2MP information
                    	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: vfi_name
                    
                    	Virtual forwarding instance name
                    	**type**\:  str
                    
                    .. attribute:: vfi_state
                    
                    	VFI state
                    	**type**\:   :py:class:`L2VpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiState>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__init__()

                        self.yang_name = "bridge-vfi"
                        self.yang_parent_name = "bridge-domain-info"

                        self.access = YLeaf(YType.boolean, "access")

                        self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                        self.vfi_name = YLeaf(YType.str, "vfi-name")

                        self.vfi_state = YLeaf(YType.enumeration, "vfi-state")

                        self.discovery_information = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                        self.discovery_information.parent = self
                        self._children_name_map["discovery_information"] = "discovery-information"
                        self._children_yang_names.add("discovery-information")

                        self.p2mp_information = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("access",
                                        "number_pseudowires",
                                        "shutdown",
                                        "vfi_name",
                                        "vfi_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__setattr__(name, value)


                    class DiscoveryInformation(Entity):
                        """
                        Auto Discovery information
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_signalling_method
                        
                        	Signaling protocol
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_number
                        
                        	Autonomous System Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: export_route_policy
                        
                        	Export Route Policy
                        	**type**\:  str
                        
                        .. attribute:: export_rt
                        
                        	List of export route targets
                        	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                        
                        .. attribute:: import_rt
                        
                        	List of import route targets
                        	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                        
                        .. attribute:: l2vpn_router_id
                        
                        	L2PVN Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: provisioned_ve_id
                        
                        	Provisioned VPLS edge ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rd_value
                        
                        	Route Distinguisher
                        	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                        
                        .. attribute:: service_connected
                        
                        	Is the BGP service connected?
                        	**type**\:  bool
                        
                        .. attribute:: ve_id
                        
                        	VPLS Edge ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ve_range
                        
                        	VE range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vpls_id
                        
                        	VPLS ID
                        	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                        
                        .. attribute:: vpls_id_conflict
                        
                        	VPLS\-ID Conflict
                        	**type**\:  bool
                        
                        .. attribute:: vpn_added
                        
                        	Is VPN id configured
                        	**type**\:  bool
                        
                        .. attribute:: vpn_id
                        
                        	Vpn ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__init__()

                            self.yang_name = "discovery-information"
                            self.yang_parent_name = "bridge-vfi"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                            self.as_number = YLeaf(YType.uint32, "as-number")

                            self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                            self.l2vpn_router_id = YLeaf(YType.str, "l2vpn-router-id")

                            self.provisioned_ve_id = YLeaf(YType.uint32, "provisioned-ve-id")

                            self.service_connected = YLeaf(YType.boolean, "service-connected")

                            self.ve_id = YLeaf(YType.uint32, "ve-id")

                            self.ve_range = YLeaf(YType.uint16, "ve-range")

                            self.vpls_id_conflict = YLeaf(YType.boolean, "vpls-id-conflict")

                            self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                            self.rd_value = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                            self.rd_value.parent = self
                            self._children_name_map["rd_value"] = "rd-value"
                            self._children_yang_names.add("rd-value")

                            self.vpls_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                            self.vpls_id.parent = self
                            self._children_name_map["vpls_id"] = "vpls-id"
                            self._children_yang_names.add("vpls-id")

                            self.export_rt = YList(self)
                            self.import_rt = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_signalling_method",
                                            "as_number",
                                            "export_route_policy",
                                            "l2vpn_router_id",
                                            "provisioned_ve_id",
                                            "service_connected",
                                            "ve_id",
                                            "ve_range",
                                            "vpls_id_conflict",
                                            "vpn_added",
                                            "vpn_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__setattr__(name, value)


                        class RdValue(Entity):
                            """
                            Route Distinguisher
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                            
                            .. attribute:: rd
                            
                            	RD
                            	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__init__()

                                self.yang_name = "rd-value"
                                self.yang_parent_name = "discovery-information"

                                self.rd = YLeaf(YType.enumeration, "rd")

                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                                self._children_yang_names.add("auto")

                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                self._children_yang_names.add("four-byte-as")

                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rd") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: auto_index
                                
                                	Auto\-generated Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: router_id
                                
                                	BGP Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "rd-value"

                                    self.auto_index = YLeaf(YType.uint16, "auto-index")

                                    self.router_id = YLeaf(YType.str, "router-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("auto_index",
                                                    "router_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.auto_index.is_set or
                                        self.router_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.auto_index.yfilter != YFilter.not_set or
                                        self.router_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "auto" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.auto_index.get_name_leafdata())
                                    if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto-index" or name == "router-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "auto-index"):
                                        self.auto_index = value
                                        self.auto_index.value_namespace = name_space
                                        self.auto_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router-id"):
                                        self.router_id = value
                                        self.router_id.value_namespace = name_space
                                        self.router_id.value_namespace_prefix = name_space_prefix


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "rd-value"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "rd-value"

                                    self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_as",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_as.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_as.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "four-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-as" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-as"):
                                        self.four_byte_as = value
                                        self.four_byte_as.value_namespace = name_space
                                        self.four_byte_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "rd-value"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rd.is_set or
                                    (self.auto is not None and self.auto.has_data()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rd.yfilter != YFilter.not_set or
                                    (self.auto is not None and self.auto.has_operation()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rd-value" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rd.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "auto"):
                                    if (self.auto is None):
                                        self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                    return self.auto

                                if (child_yang_name == "four-byte-as"):
                                    if (self.four_byte_as is None):
                                        self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                    return self.four_byte_as

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rd"):
                                    self.rd = value
                                    self.rd.value_namespace = name_space
                                    self.rd.value_namespace_prefix = name_space_prefix


                        class VplsId(Entity):
                            """
                            VPLS ID
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                            
                            .. attribute:: vpls_id_type
                            
                            	VPLS ID TYPE
                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__init__()

                                self.yang_name = "vpls-id"
                                self.yang_parent_name = "discovery-information"

                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                                self._children_yang_names.add("auto")

                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("vpls_id_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: asn
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpn_id
                                
                                	VPN ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "vpls-id"

                                    self.asn = YLeaf(YType.uint16, "asn")

                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("asn",
                                                    "vpn_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.asn.is_set or
                                        self.vpn_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.asn.yfilter != YFilter.not_set or
                                        self.vpn_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "auto" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "asn" or name == "vpn-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "asn"):
                                        self.asn = value
                                        self.asn.value_namespace = name_space
                                        self.asn.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpn-id"):
                                        self.vpn_id = value
                                        self.vpn_id.value_namespace = name_space
                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "vpls-id"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "vpls-id"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.vpls_id_type.is_set or
                                    (self.auto is not None and self.auto.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                    (self.auto is not None and self.auto.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vpls-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "auto"):
                                    if (self.auto is None):
                                        self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                    return self.auto

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "vpls-id-type"):
                                    self.vpls_id_type = value
                                    self.vpls_id_type.value_namespace = name_space
                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                        class ImportRt(Entity):
                            """
                            List of import route targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__init__()

                                self.yang_name = "import-rt"
                                self.yang_parent_name = "discovery-information"

                                self.rt = YLeaf(YType.enumeration, "rt")

                                self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                self.es_import.parent = self
                                self._children_name_map["es_import"] = "es-import"
                                self._children_yang_names.add("es-import")

                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                self._children_yang_names.add("four-byte-as")

                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rt") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "import-rt"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "import-rt"

                                    self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_as",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_as.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_as.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "four-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-as" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-as"):
                                        self.four_byte_as = value
                                        self.four_byte_as.value_namespace = name_space
                                        self.four_byte_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "import-rt"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class EsImport(Entity):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                    self.yang_name = "es-import"
                                    self.yang_parent_name = "import-rt"

                                    self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                    self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("high_bytes",
                                                    "low_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.high_bytes.is_set or
                                        self.low_bytes.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.high_bytes.yfilter != YFilter.not_set or
                                        self.low_bytes.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "es-import" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                    if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "high-bytes" or name == "low-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "high-bytes"):
                                        self.high_bytes = value
                                        self.high_bytes.value_namespace = name_space
                                        self.high_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low-bytes"):
                                        self.low_bytes = value
                                        self.low_bytes.value_namespace = name_space
                                        self.low_bytes.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rt.is_set or
                                    (self.es_import is not None and self.es_import.has_data()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rt.yfilter != YFilter.not_set or
                                    (self.es_import is not None and self.es_import.has_operation()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "import-rt" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rt.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "es-import"):
                                    if (self.es_import is None):
                                        self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                    return self.es_import

                                if (child_yang_name == "four-byte-as"):
                                    if (self.four_byte_as is None):
                                        self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                    return self.four_byte_as

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rt"):
                                    self.rt = value
                                    self.rt.value_namespace = name_space
                                    self.rt.value_namespace_prefix = name_space_prefix


                        class ExportRt(Entity):
                            """
                            List of export route targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__init__()

                                self.yang_name = "export-rt"
                                self.yang_parent_name = "discovery-information"

                                self.rt = YLeaf(YType.enumeration, "rt")

                                self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                self.es_import.parent = self
                                self._children_name_map["es_import"] = "es-import"
                                self._children_yang_names.add("es-import")

                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                self._children_yang_names.add("four-byte-as")

                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rt") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "export-rt"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "export-rt"

                                    self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_as",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_as.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_as.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "four-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-as" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-as"):
                                        self.four_byte_as = value
                                        self.four_byte_as.value_namespace = name_space
                                        self.four_byte_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "export-rt"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class EsImport(Entity):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                    self.yang_name = "es-import"
                                    self.yang_parent_name = "export-rt"

                                    self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                    self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("high_bytes",
                                                    "low_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.high_bytes.is_set or
                                        self.low_bytes.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.high_bytes.yfilter != YFilter.not_set or
                                        self.low_bytes.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "es-import" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                    if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "high-bytes" or name == "low-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "high-bytes"):
                                        self.high_bytes = value
                                        self.high_bytes.value_namespace = name_space
                                        self.high_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low-bytes"):
                                        self.low_bytes = value
                                        self.low_bytes.value_namespace = name_space
                                        self.low_bytes.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rt.is_set or
                                    (self.es_import is not None and self.es_import.has_data()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rt.yfilter != YFilter.not_set or
                                    (self.es_import is not None and self.es_import.has_operation()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "export-rt" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rt.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "es-import"):
                                    if (self.es_import is None):
                                        self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                    return self.es_import

                                if (child_yang_name == "four-byte-as"):
                                    if (self.four_byte_as is None):
                                        self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                    return self.four_byte_as

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rt"):
                                    self.rt = value
                                    self.rt.value_namespace = name_space
                                    self.rt.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.export_rt:
                                if (c.has_data()):
                                    return True
                            for c in self.import_rt:
                                if (c.has_data()):
                                    return True
                            return (
                                self.ad_method.is_set or
                                self.ad_signalling_method.is_set or
                                self.as_number.is_set or
                                self.export_route_policy.is_set or
                                self.l2vpn_router_id.is_set or
                                self.provisioned_ve_id.is_set or
                                self.service_connected.is_set or
                                self.ve_id.is_set or
                                self.ve_range.is_set or
                                self.vpls_id_conflict.is_set or
                                self.vpn_added.is_set or
                                self.vpn_id.is_set or
                                (self.rd_value is not None and self.rd_value.has_data()) or
                                (self.vpls_id is not None and self.vpls_id.has_data()))

                        def has_operation(self):
                            for c in self.export_rt:
                                if (c.has_operation()):
                                    return True
                            for c in self.import_rt:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_signalling_method.yfilter != YFilter.not_set or
                                self.as_number.yfilter != YFilter.not_set or
                                self.export_route_policy.yfilter != YFilter.not_set or
                                self.l2vpn_router_id.yfilter != YFilter.not_set or
                                self.provisioned_ve_id.yfilter != YFilter.not_set or
                                self.service_connected.yfilter != YFilter.not_set or
                                self.ve_id.yfilter != YFilter.not_set or
                                self.ve_range.yfilter != YFilter.not_set or
                                self.vpls_id_conflict.yfilter != YFilter.not_set or
                                self.vpn_added.yfilter != YFilter.not_set or
                                self.vpn_id.yfilter != YFilter.not_set or
                                (self.rd_value is not None and self.rd_value.has_operation()) or
                                (self.vpls_id is not None and self.vpls_id.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "discovery-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                            if (self.as_number.is_set or self.as_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_number.get_name_leafdata())
                            if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                            if (self.l2vpn_router_id.is_set or self.l2vpn_router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.l2vpn_router_id.get_name_leafdata())
                            if (self.provisioned_ve_id.is_set or self.provisioned_ve_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.provisioned_ve_id.get_name_leafdata())
                            if (self.service_connected.is_set or self.service_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.service_connected.get_name_leafdata())
                            if (self.ve_id.is_set or self.ve_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ve_id.get_name_leafdata())
                            if (self.ve_range.is_set or self.ve_range.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ve_range.get_name_leafdata())
                            if (self.vpls_id_conflict.is_set or self.vpls_id_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vpls_id_conflict.get_name_leafdata())
                            if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vpn_added.get_name_leafdata())
                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "export-rt"):
                                for c in self.export_rt:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.export_rt.append(c)
                                return c

                            if (child_yang_name == "import-rt"):
                                for c in self.import_rt:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.import_rt.append(c)
                                return c

                            if (child_yang_name == "rd-value"):
                                if (self.rd_value is None):
                                    self.rd_value = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                    self.rd_value.parent = self
                                    self._children_name_map["rd_value"] = "rd-value"
                                return self.rd_value

                            if (child_yang_name == "vpls-id"):
                                if (self.vpls_id is None):
                                    self.vpls_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                    self.vpls_id.parent = self
                                    self._children_name_map["vpls_id"] = "vpls-id"
                                return self.vpls_id

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "vpls-id" or name == "ad-method" or name == "ad-signalling-method" or name == "as-number" or name == "export-route-policy" or name == "l2vpn-router-id" or name == "provisioned-ve-id" or name == "service-connected" or name == "ve-id" or name == "ve-range" or name == "vpls-id-conflict" or name == "vpn-added" or name == "vpn-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-signalling-method"):
                                self.ad_signalling_method = value
                                self.ad_signalling_method.value_namespace = name_space
                                self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "as-number"):
                                self.as_number = value
                                self.as_number.value_namespace = name_space
                                self.as_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "export-route-policy"):
                                self.export_route_policy = value
                                self.export_route_policy.value_namespace = name_space
                                self.export_route_policy.value_namespace_prefix = name_space_prefix
                            if(value_path == "l2vpn-router-id"):
                                self.l2vpn_router_id = value
                                self.l2vpn_router_id.value_namespace = name_space
                                self.l2vpn_router_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "provisioned-ve-id"):
                                self.provisioned_ve_id = value
                                self.provisioned_ve_id.value_namespace = name_space
                                self.provisioned_ve_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "service-connected"):
                                self.service_connected = value
                                self.service_connected.value_namespace = name_space
                                self.service_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "ve-id"):
                                self.ve_id = value
                                self.ve_id.value_namespace = name_space
                                self.ve_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ve-range"):
                                self.ve_range = value
                                self.ve_range.value_namespace = name_space
                                self.ve_range.value_namespace_prefix = name_space_prefix
                            if(value_path == "vpls-id-conflict"):
                                self.vpls_id_conflict = value
                                self.vpls_id_conflict.value_namespace = name_space
                                self.vpls_id_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "vpn-added"):
                                self.vpn_added = value
                                self.vpn_added.value_namespace = name_space
                                self.vpn_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "vpn-id"):
                                self.vpn_id = value
                                self.vpn_id.value_namespace = name_space
                                self.vpn_id.value_namespace_prefix = name_space_prefix


                    class P2MpInformation(Entity):
                        """
                        Multicast P2MP information
                        
                        .. attribute:: attribute_set_name
                        
                        	TE Attribute Set Name
                        	**type**\:  str
                        
                        .. attribute:: local_label
                        
                        	P2MP Tunnel Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ptree_id
                        
                        	PTree ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: signaling
                        
                        	P2MP signaling
                        	**type**\:   :py:class:`L2VpnVfiP2MpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignaling>`
                        
                        .. attribute:: transport
                        
                        	P2MP transport
                        	**type**\:   :py:class:`L2VpnVfiP2MpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransport>`
                        
                        .. attribute:: transport_status
                        
                        	Transport Status
                        	**type**\:   :py:class:`P2MpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportState>`
                        
                        .. attribute:: tunnel_interface
                        
                        	P2MP Tunnel Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__init__()

                            self.yang_name = "p2mp-information"
                            self.yang_parent_name = "bridge-vfi"

                            self.attribute_set_name = YLeaf(YType.str, "attribute-set-name")

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.ptree_id = YLeaf(YType.uint32, "ptree-id")

                            self.signaling = YLeaf(YType.enumeration, "signaling")

                            self.transport = YLeaf(YType.enumeration, "transport")

                            self.transport_status = YLeaf(YType.enumeration, "transport-status")

                            self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("attribute_set_name",
                                            "local_label",
                                            "ptree_id",
                                            "signaling",
                                            "transport",
                                            "transport_status",
                                            "tunnel_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.attribute_set_name.is_set or
                                self.local_label.is_set or
                                self.ptree_id.is_set or
                                self.signaling.is_set or
                                self.transport.is_set or
                                self.transport_status.is_set or
                                self.tunnel_interface.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.attribute_set_name.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                self.ptree_id.yfilter != YFilter.not_set or
                                self.signaling.yfilter != YFilter.not_set or
                                self.transport.yfilter != YFilter.not_set or
                                self.transport_status.yfilter != YFilter.not_set or
                                self.tunnel_interface.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.attribute_set_name.is_set or self.attribute_set_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.attribute_set_name.get_name_leafdata())
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())
                            if (self.ptree_id.is_set or self.ptree_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ptree_id.get_name_leafdata())
                            if (self.signaling.is_set or self.signaling.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.signaling.get_name_leafdata())
                            if (self.transport.is_set or self.transport.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport.get_name_leafdata())
                            if (self.transport_status.is_set or self.transport_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_status.get_name_leafdata())
                            if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "attribute-set-name" or name == "local-label" or name == "ptree-id" or name == "signaling" or name == "transport" or name == "transport-status" or name == "tunnel-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "attribute-set-name"):
                                self.attribute_set_name = value
                                self.attribute_set_name.value_namespace = name_space
                                self.attribute_set_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "ptree-id"):
                                self.ptree_id = value
                                self.ptree_id.value_namespace = name_space
                                self.ptree_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "signaling"):
                                self.signaling = value
                                self.signaling.value_namespace = name_space
                                self.signaling.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport"):
                                self.transport = value
                                self.transport.value_namespace = name_space
                                self.transport.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-status"):
                                self.transport_status = value
                                self.transport_status.value_namespace = name_space
                                self.transport_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-interface"):
                                self.tunnel_interface = value
                                self.tunnel_interface.value_namespace = name_space
                                self.tunnel_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.p2mp_information:
                            if (c.has_data()):
                                return True
                        return (
                            self.access.is_set or
                            self.number_pseudowires.is_set or
                            self.shutdown.is_set or
                            self.vfi_name.is_set or
                            self.vfi_state.is_set or
                            (self.discovery_information is not None and self.discovery_information.has_data()))

                    def has_operation(self):
                        for c in self.p2mp_information:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.access.yfilter != YFilter.not_set or
                            self.number_pseudowires.yfilter != YFilter.not_set or
                            self.shutdown.yfilter != YFilter.not_set or
                            self.vfi_name.yfilter != YFilter.not_set or
                            self.vfi_state.yfilter != YFilter.not_set or
                            (self.discovery_information is not None and self.discovery_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-vfi" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.access.is_set or self.access.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.access.get_name_leafdata())
                        if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                        if (self.vfi_name.is_set or self.vfi_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vfi_name.get_name_leafdata())
                        if (self.vfi_state.is_set or self.vfi_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vfi_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "discovery-information"):
                            if (self.discovery_information is None):
                                self.discovery_information = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                                self.discovery_information.parent = self
                                self._children_name_map["discovery_information"] = "discovery-information"
                            return self.discovery_information

                        if (child_yang_name == "p2mp-information"):
                            for c in self.p2mp_information:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.p2mp_information.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "discovery-information" or name == "p2mp-information" or name == "access" or name == "number-pseudowires" or name == "shutdown" or name == "vfi-name" or name == "vfi-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "access"):
                            self.access = value
                            self.access.value_namespace = name_space
                            self.access.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-pseudowires"):
                            self.number_pseudowires = value
                            self.number_pseudowires.value_namespace = name_space
                            self.number_pseudowires.value_namespace_prefix = name_space_prefix
                        if(value_path == "shutdown"):
                            self.shutdown = value
                            self.shutdown.value_namespace = name_space
                            self.shutdown.value_namespace_prefix = name_space_prefix
                        if(value_path == "vfi-name"):
                            self.vfi_name = value
                            self.vfi_name.value_namespace = name_space
                            self.vfi_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vfi-state"):
                            self.vfi_state = value
                            self.vfi_state.value_namespace = name_space
                            self.vfi_state.value_namespace_prefix = name_space_prefix


                class BridgeAccessVfi(Entity):
                    """
                    Access Virtual Forwarding Interfaces
                    
                    .. attribute:: access
                    
                    	VFI is an Access VFI
                    	**type**\:  bool
                    
                    .. attribute:: discovery_information
                    
                    	Auto Discovery information
                    	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of Pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_information
                    
                    	Multicast P2MP information
                    	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: vfi_name
                    
                    	Virtual forwarding instance name
                    	**type**\:  str
                    
                    .. attribute:: vfi_state
                    
                    	VFI state
                    	**type**\:   :py:class:`L2VpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiState>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__init__()

                        self.yang_name = "bridge-access-vfi"
                        self.yang_parent_name = "bridge-domain-info"

                        self.access = YLeaf(YType.boolean, "access")

                        self.number_pseudowires = YLeaf(YType.uint32, "number-pseudowires")

                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                        self.vfi_name = YLeaf(YType.str, "vfi-name")

                        self.vfi_state = YLeaf(YType.enumeration, "vfi-state")

                        self.discovery_information = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                        self.discovery_information.parent = self
                        self._children_name_map["discovery_information"] = "discovery-information"
                        self._children_yang_names.add("discovery-information")

                        self.p2mp_information = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("access",
                                        "number_pseudowires",
                                        "shutdown",
                                        "vfi_name",
                                        "vfi_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__setattr__(name, value)


                    class DiscoveryInformation(Entity):
                        """
                        Auto Discovery information
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_signalling_method
                        
                        	Signaling protocol
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_number
                        
                        	Autonomous System Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: export_route_policy
                        
                        	Export Route Policy
                        	**type**\:  str
                        
                        .. attribute:: export_rt
                        
                        	List of export route targets
                        	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                        
                        .. attribute:: import_rt
                        
                        	List of import route targets
                        	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                        
                        .. attribute:: l2vpn_router_id
                        
                        	L2PVN Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: provisioned_ve_id
                        
                        	Provisioned VPLS edge ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rd_value
                        
                        	Route Distinguisher
                        	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                        
                        .. attribute:: service_connected
                        
                        	Is the BGP service connected?
                        	**type**\:  bool
                        
                        .. attribute:: ve_id
                        
                        	VPLS Edge ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ve_range
                        
                        	VE range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vpls_id
                        
                        	VPLS ID
                        	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                        
                        .. attribute:: vpls_id_conflict
                        
                        	VPLS\-ID Conflict
                        	**type**\:  bool
                        
                        .. attribute:: vpn_added
                        
                        	Is VPN id configured
                        	**type**\:  bool
                        
                        .. attribute:: vpn_id
                        
                        	Vpn ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__init__()

                            self.yang_name = "discovery-information"
                            self.yang_parent_name = "bridge-access-vfi"

                            self.ad_method = YLeaf(YType.uint32, "ad-method")

                            self.ad_signalling_method = YLeaf(YType.uint32, "ad-signalling-method")

                            self.as_number = YLeaf(YType.uint32, "as-number")

                            self.export_route_policy = YLeaf(YType.str, "export-route-policy")

                            self.l2vpn_router_id = YLeaf(YType.str, "l2vpn-router-id")

                            self.provisioned_ve_id = YLeaf(YType.uint32, "provisioned-ve-id")

                            self.service_connected = YLeaf(YType.boolean, "service-connected")

                            self.ve_id = YLeaf(YType.uint32, "ve-id")

                            self.ve_range = YLeaf(YType.uint16, "ve-range")

                            self.vpls_id_conflict = YLeaf(YType.boolean, "vpls-id-conflict")

                            self.vpn_added = YLeaf(YType.boolean, "vpn-added")

                            self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                            self.rd_value = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                            self.rd_value.parent = self
                            self._children_name_map["rd_value"] = "rd-value"
                            self._children_yang_names.add("rd-value")

                            self.vpls_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                            self.vpls_id.parent = self
                            self._children_name_map["vpls_id"] = "vpls-id"
                            self._children_yang_names.add("vpls-id")

                            self.export_rt = YList(self)
                            self.import_rt = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ad_method",
                                            "ad_signalling_method",
                                            "as_number",
                                            "export_route_policy",
                                            "l2vpn_router_id",
                                            "provisioned_ve_id",
                                            "service_connected",
                                            "ve_id",
                                            "ve_range",
                                            "vpls_id_conflict",
                                            "vpn_added",
                                            "vpn_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__setattr__(name, value)


                        class RdValue(Entity):
                            """
                            Route Distinguisher
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                            
                            .. attribute:: rd
                            
                            	RD
                            	**type**\:   :py:class:`L2VpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRd>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__init__()

                                self.yang_name = "rd-value"
                                self.yang_parent_name = "discovery-information"

                                self.rd = YLeaf(YType.enumeration, "rd")

                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                                self._children_yang_names.add("auto")

                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                self._children_yang_names.add("four-byte-as")

                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rd") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__setattr__(name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: auto_index
                                
                                	Auto\-generated Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: router_id
                                
                                	BGP Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "rd-value"

                                    self.auto_index = YLeaf(YType.uint16, "auto-index")

                                    self.router_id = YLeaf(YType.str, "router-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("auto_index",
                                                    "router_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.auto_index.is_set or
                                        self.router_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.auto_index.yfilter != YFilter.not_set or
                                        self.router_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "auto" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.auto_index.is_set or self.auto_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.auto_index.get_name_leafdata())
                                    if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto-index" or name == "router-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "auto-index"):
                                        self.auto_index = value
                                        self.auto_index.value_namespace = name_space
                                        self.auto_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router-id"):
                                        self.router_id = value
                                        self.router_id.value_namespace = name_space
                                        self.router_id.value_namespace_prefix = name_space_prefix


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "rd-value"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "rd-value"

                                    self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_as",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_as.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_as.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "four-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-as" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-as"):
                                        self.four_byte_as = value
                                        self.four_byte_as.value_namespace = name_space
                                        self.four_byte_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "rd-value"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rd.is_set or
                                    (self.auto is not None and self.auto.has_data()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rd.yfilter != YFilter.not_set or
                                    (self.auto is not None and self.auto.has_operation()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rd-value" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rd.is_set or self.rd.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rd.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "auto"):
                                    if (self.auto is None):
                                        self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                    return self.auto

                                if (child_yang_name == "four-byte-as"):
                                    if (self.four_byte_as is None):
                                        self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                    return self.four_byte_as

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rd"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rd"):
                                    self.rd = value
                                    self.rd.value_namespace = name_space
                                    self.rd.value_namespace_prefix = name_space_prefix


                        class VplsId(Entity):
                            """
                            VPLS ID
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                            
                            .. attribute:: vpls_id_type
                            
                            	VPLS ID TYPE
                            	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__init__()

                                self.yang_name = "vpls-id"
                                self.yang_parent_name = "discovery-information"

                                self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"
                                self._children_yang_names.add("auto")

                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("vpls_id_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__setattr__(name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: asn
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpn_id
                                
                                	VPN ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "vpls-id"

                                    self.asn = YLeaf(YType.uint16, "asn")

                                    self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("asn",
                                                    "vpn_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.asn.is_set or
                                        self.vpn_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.asn.yfilter != YFilter.not_set or
                                        self.vpn_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "auto" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.asn.get_name_leafdata())
                                    if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "asn" or name == "vpn-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "asn"):
                                        self.asn = value
                                        self.asn.value_namespace = name_space
                                        self.asn.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpn-id"):
                                        self.vpn_id = value
                                        self.vpn_id.value_namespace = name_space
                                        self.vpn_id.value_namespace_prefix = name_space_prefix


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "vpls-id"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "vpls-id"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.vpls_id_type.is_set or
                                    (self.auto is not None and self.auto.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.vpls_id_type.yfilter != YFilter.not_set or
                                    (self.auto is not None and self.auto.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vpls-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "auto"):
                                    if (self.auto is None):
                                        self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"
                                    return self.auto

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "vpls-id-type"):
                                    self.vpls_id_type = value
                                    self.vpls_id_type.value_namespace = name_space
                                    self.vpls_id_type.value_namespace_prefix = name_space_prefix


                        class ImportRt(Entity):
                            """
                            List of import route targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__init__()

                                self.yang_name = "import-rt"
                                self.yang_parent_name = "discovery-information"

                                self.rt = YLeaf(YType.enumeration, "rt")

                                self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                self.es_import.parent = self
                                self._children_name_map["es_import"] = "es-import"
                                self._children_yang_names.add("es-import")

                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                self._children_yang_names.add("four-byte-as")

                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rt") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__setattr__(name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "import-rt"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "import-rt"

                                    self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_as",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_as.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_as.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "four-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-as" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-as"):
                                        self.four_byte_as = value
                                        self.four_byte_as.value_namespace = name_space
                                        self.four_byte_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "import-rt"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class EsImport(Entity):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                    self.yang_name = "es-import"
                                    self.yang_parent_name = "import-rt"

                                    self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                    self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("high_bytes",
                                                    "low_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.high_bytes.is_set or
                                        self.low_bytes.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.high_bytes.yfilter != YFilter.not_set or
                                        self.low_bytes.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "es-import" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                    if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "high-bytes" or name == "low-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "high-bytes"):
                                        self.high_bytes = value
                                        self.high_bytes.value_namespace = name_space
                                        self.high_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low-bytes"):
                                        self.low_bytes = value
                                        self.low_bytes.value_namespace = name_space
                                        self.low_bytes.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rt.is_set or
                                    (self.es_import is not None and self.es_import.has_data()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rt.yfilter != YFilter.not_set or
                                    (self.es_import is not None and self.es_import.has_operation()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "import-rt" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rt.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "es-import"):
                                    if (self.es_import is None):
                                        self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                    return self.es_import

                                if (child_yang_name == "four-byte-as"):
                                    if (self.four_byte_as is None):
                                        self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                    return self.four_byte_as

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rt"):
                                    self.rt = value
                                    self.rt.value_namespace = name_space
                                    self.rt.value_namespace_prefix = name_space_prefix


                        class ExportRt(Entity):
                            """
                            List of export route targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRt>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__init__()

                                self.yang_name = "export-rt"
                                self.yang_parent_name = "discovery-information"

                                self.rt = YLeaf(YType.enumeration, "rt")

                                self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                self.es_import.parent = self
                                self._children_name_map["es_import"] = "es-import"
                                self._children_yang_names.add("es-import")

                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"
                                self._children_yang_names.add("four-byte-as")

                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"
                                self._children_yang_names.add("two-byte-as")

                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._children_yang_names.add("v4-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rt") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__setattr__(name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "export-rt"

                                    self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                    self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_index",
                                                    "two_byte_as") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_index.is_set or
                                        self.two_byte_as.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_index.yfilter != YFilter.not_set or
                                        self.two_byte_as.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "two-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                    if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-index" or name == "two-byte-as"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-index"):
                                        self.four_byte_index = value
                                        self.four_byte_index.value_namespace = name_space
                                        self.four_byte_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-as"):
                                        self.two_byte_as = value
                                        self.two_byte_as.value_namespace = name_space
                                        self.two_byte_as.value_namespace_prefix = name_space_prefix


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "export-rt"

                                    self.four_byte_as = YLeaf(YType.uint32, "four-byte-as")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("four_byte_as",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.four_byte_as.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.four_byte_as.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "four-byte-as" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.four_byte_as.is_set or self.four_byte_as.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.four_byte_as.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "four-byte-as" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "four-byte-as"):
                                        self.four_byte_as = value
                                        self.four_byte_as.value_namespace = name_space
                                        self.four_byte_as.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "export-rt"

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ipv4_address",
                                                    "two_byte_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ipv4_address.is_set or
                                        self.two_byte_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.two_byte_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "v4-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-address" or name == "two-byte-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "two-byte-index"):
                                        self.two_byte_index = value
                                        self.two_byte_index.value_namespace = name_space
                                        self.two_byte_index.value_namespace_prefix = name_space_prefix


                            class EsImport(Entity):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                    self.yang_name = "es-import"
                                    self.yang_parent_name = "export-rt"

                                    self.high_bytes = YLeaf(YType.uint32, "high-bytes")

                                    self.low_bytes = YLeaf(YType.uint16, "low-bytes")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("high_bytes",
                                                    "low_bytes") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.high_bytes.is_set or
                                        self.low_bytes.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.high_bytes.yfilter != YFilter.not_set or
                                        self.low_bytes.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "es-import" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.high_bytes.is_set or self.high_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high_bytes.get_name_leafdata())
                                    if (self.low_bytes.is_set or self.low_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low_bytes.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "high-bytes" or name == "low-bytes"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "high-bytes"):
                                        self.high_bytes = value
                                        self.high_bytes.value_namespace = name_space
                                        self.high_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low-bytes"):
                                        self.low_bytes = value
                                        self.low_bytes.value_namespace = name_space
                                        self.low_bytes.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rt.is_set or
                                    (self.es_import is not None and self.es_import.has_data()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_data()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                    (self.v4_addr is not None and self.v4_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rt.yfilter != YFilter.not_set or
                                    (self.es_import is not None and self.es_import.has_operation()) or
                                    (self.four_byte_as is not None and self.four_byte_as.has_operation()) or
                                    (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                    (self.v4_addr is not None and self.v4_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "export-rt" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rt.is_set or self.rt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rt.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "es-import"):
                                    if (self.es_import is None):
                                        self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                    return self.es_import

                                if (child_yang_name == "four-byte-as"):
                                    if (self.four_byte_as is None):
                                        self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"
                                    return self.four_byte_as

                                if (child_yang_name == "two-byte-as"):
                                    if (self.two_byte_as is None):
                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"
                                    return self.two_byte_as

                                if (child_yang_name == "v4-addr"):
                                    if (self.v4_addr is None):
                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                    return self.v4_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "es-import" or name == "four-byte-as" or name == "two-byte-as" or name == "v4-addr" or name == "rt"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rt"):
                                    self.rt = value
                                    self.rt.value_namespace = name_space
                                    self.rt.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.export_rt:
                                if (c.has_data()):
                                    return True
                            for c in self.import_rt:
                                if (c.has_data()):
                                    return True
                            return (
                                self.ad_method.is_set or
                                self.ad_signalling_method.is_set or
                                self.as_number.is_set or
                                self.export_route_policy.is_set or
                                self.l2vpn_router_id.is_set or
                                self.provisioned_ve_id.is_set or
                                self.service_connected.is_set or
                                self.ve_id.is_set or
                                self.ve_range.is_set or
                                self.vpls_id_conflict.is_set or
                                self.vpn_added.is_set or
                                self.vpn_id.is_set or
                                (self.rd_value is not None and self.rd_value.has_data()) or
                                (self.vpls_id is not None and self.vpls_id.has_data()))

                        def has_operation(self):
                            for c in self.export_rt:
                                if (c.has_operation()):
                                    return True
                            for c in self.import_rt:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ad_method.yfilter != YFilter.not_set or
                                self.ad_signalling_method.yfilter != YFilter.not_set or
                                self.as_number.yfilter != YFilter.not_set or
                                self.export_route_policy.yfilter != YFilter.not_set or
                                self.l2vpn_router_id.yfilter != YFilter.not_set or
                                self.provisioned_ve_id.yfilter != YFilter.not_set or
                                self.service_connected.yfilter != YFilter.not_set or
                                self.ve_id.yfilter != YFilter.not_set or
                                self.ve_range.yfilter != YFilter.not_set or
                                self.vpls_id_conflict.yfilter != YFilter.not_set or
                                self.vpn_added.yfilter != YFilter.not_set or
                                self.vpn_id.yfilter != YFilter.not_set or
                                (self.rd_value is not None and self.rd_value.has_operation()) or
                                (self.vpls_id is not None and self.vpls_id.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "discovery-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_method.get_name_leafdata())
                            if (self.ad_signalling_method.is_set or self.ad_signalling_method.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ad_signalling_method.get_name_leafdata())
                            if (self.as_number.is_set or self.as_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_number.get_name_leafdata())
                            if (self.export_route_policy.is_set or self.export_route_policy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.export_route_policy.get_name_leafdata())
                            if (self.l2vpn_router_id.is_set or self.l2vpn_router_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.l2vpn_router_id.get_name_leafdata())
                            if (self.provisioned_ve_id.is_set or self.provisioned_ve_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.provisioned_ve_id.get_name_leafdata())
                            if (self.service_connected.is_set or self.service_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.service_connected.get_name_leafdata())
                            if (self.ve_id.is_set or self.ve_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ve_id.get_name_leafdata())
                            if (self.ve_range.is_set or self.ve_range.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ve_range.get_name_leafdata())
                            if (self.vpls_id_conflict.is_set or self.vpls_id_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vpls_id_conflict.get_name_leafdata())
                            if (self.vpn_added.is_set or self.vpn_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vpn_added.get_name_leafdata())
                            if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vpn_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "export-rt"):
                                for c in self.export_rt:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.export_rt.append(c)
                                return c

                            if (child_yang_name == "import-rt"):
                                for c in self.import_rt:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.import_rt.append(c)
                                return c

                            if (child_yang_name == "rd-value"):
                                if (self.rd_value is None):
                                    self.rd_value = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                    self.rd_value.parent = self
                                    self._children_name_map["rd_value"] = "rd-value"
                                return self.rd_value

                            if (child_yang_name == "vpls-id"):
                                if (self.vpls_id is None):
                                    self.vpls_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                    self.vpls_id.parent = self
                                    self._children_name_map["vpls_id"] = "vpls-id"
                                return self.vpls_id

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "export-rt" or name == "import-rt" or name == "rd-value" or name == "vpls-id" or name == "ad-method" or name == "ad-signalling-method" or name == "as-number" or name == "export-route-policy" or name == "l2vpn-router-id" or name == "provisioned-ve-id" or name == "service-connected" or name == "ve-id" or name == "ve-range" or name == "vpls-id-conflict" or name == "vpn-added" or name == "vpn-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ad-method"):
                                self.ad_method = value
                                self.ad_method.value_namespace = name_space
                                self.ad_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "ad-signalling-method"):
                                self.ad_signalling_method = value
                                self.ad_signalling_method.value_namespace = name_space
                                self.ad_signalling_method.value_namespace_prefix = name_space_prefix
                            if(value_path == "as-number"):
                                self.as_number = value
                                self.as_number.value_namespace = name_space
                                self.as_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "export-route-policy"):
                                self.export_route_policy = value
                                self.export_route_policy.value_namespace = name_space
                                self.export_route_policy.value_namespace_prefix = name_space_prefix
                            if(value_path == "l2vpn-router-id"):
                                self.l2vpn_router_id = value
                                self.l2vpn_router_id.value_namespace = name_space
                                self.l2vpn_router_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "provisioned-ve-id"):
                                self.provisioned_ve_id = value
                                self.provisioned_ve_id.value_namespace = name_space
                                self.provisioned_ve_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "service-connected"):
                                self.service_connected = value
                                self.service_connected.value_namespace = name_space
                                self.service_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "ve-id"):
                                self.ve_id = value
                                self.ve_id.value_namespace = name_space
                                self.ve_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ve-range"):
                                self.ve_range = value
                                self.ve_range.value_namespace = name_space
                                self.ve_range.value_namespace_prefix = name_space_prefix
                            if(value_path == "vpls-id-conflict"):
                                self.vpls_id_conflict = value
                                self.vpls_id_conflict.value_namespace = name_space
                                self.vpls_id_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "vpn-added"):
                                self.vpn_added = value
                                self.vpn_added.value_namespace = name_space
                                self.vpn_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "vpn-id"):
                                self.vpn_id = value
                                self.vpn_id.value_namespace = name_space
                                self.vpn_id.value_namespace_prefix = name_space_prefix


                    class P2MpInformation(Entity):
                        """
                        Multicast P2MP information
                        
                        .. attribute:: attribute_set_name
                        
                        	TE Attribute Set Name
                        	**type**\:  str
                        
                        .. attribute:: local_label
                        
                        	P2MP Tunnel Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ptree_id
                        
                        	PTree ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: signaling
                        
                        	P2MP signaling
                        	**type**\:   :py:class:`L2VpnVfiP2MpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignaling>`
                        
                        .. attribute:: transport
                        
                        	P2MP transport
                        	**type**\:   :py:class:`L2VpnVfiP2MpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransport>`
                        
                        .. attribute:: transport_status
                        
                        	Transport Status
                        	**type**\:   :py:class:`P2MpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportState>`
                        
                        .. attribute:: tunnel_interface
                        
                        	P2MP Tunnel Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__init__()

                            self.yang_name = "p2mp-information"
                            self.yang_parent_name = "bridge-access-vfi"

                            self.attribute_set_name = YLeaf(YType.str, "attribute-set-name")

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.ptree_id = YLeaf(YType.uint32, "ptree-id")

                            self.signaling = YLeaf(YType.enumeration, "signaling")

                            self.transport = YLeaf(YType.enumeration, "transport")

                            self.transport_status = YLeaf(YType.enumeration, "transport-status")

                            self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("attribute_set_name",
                                            "local_label",
                                            "ptree_id",
                                            "signaling",
                                            "transport",
                                            "transport_status",
                                            "tunnel_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.attribute_set_name.is_set or
                                self.local_label.is_set or
                                self.ptree_id.is_set or
                                self.signaling.is_set or
                                self.transport.is_set or
                                self.transport_status.is_set or
                                self.tunnel_interface.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.attribute_set_name.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                self.ptree_id.yfilter != YFilter.not_set or
                                self.signaling.yfilter != YFilter.not_set or
                                self.transport.yfilter != YFilter.not_set or
                                self.transport_status.yfilter != YFilter.not_set or
                                self.tunnel_interface.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.attribute_set_name.is_set or self.attribute_set_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.attribute_set_name.get_name_leafdata())
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())
                            if (self.ptree_id.is_set or self.ptree_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ptree_id.get_name_leafdata())
                            if (self.signaling.is_set or self.signaling.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.signaling.get_name_leafdata())
                            if (self.transport.is_set or self.transport.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport.get_name_leafdata())
                            if (self.transport_status.is_set or self.transport_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transport_status.get_name_leafdata())
                            if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "attribute-set-name" or name == "local-label" or name == "ptree-id" or name == "signaling" or name == "transport" or name == "transport-status" or name == "tunnel-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "attribute-set-name"):
                                self.attribute_set_name = value
                                self.attribute_set_name.value_namespace = name_space
                                self.attribute_set_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "ptree-id"):
                                self.ptree_id = value
                                self.ptree_id.value_namespace = name_space
                                self.ptree_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "signaling"):
                                self.signaling = value
                                self.signaling.value_namespace = name_space
                                self.signaling.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport"):
                                self.transport = value
                                self.transport.value_namespace = name_space
                                self.transport.value_namespace_prefix = name_space_prefix
                            if(value_path == "transport-status"):
                                self.transport_status = value
                                self.transport_status.value_namespace = name_space
                                self.transport_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-interface"):
                                self.tunnel_interface = value
                                self.tunnel_interface.value_namespace = name_space
                                self.tunnel_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.p2mp_information:
                            if (c.has_data()):
                                return True
                        return (
                            self.access.is_set or
                            self.number_pseudowires.is_set or
                            self.shutdown.is_set or
                            self.vfi_name.is_set or
                            self.vfi_state.is_set or
                            (self.discovery_information is not None and self.discovery_information.has_data()))

                    def has_operation(self):
                        for c in self.p2mp_information:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.access.yfilter != YFilter.not_set or
                            self.number_pseudowires.yfilter != YFilter.not_set or
                            self.shutdown.yfilter != YFilter.not_set or
                            self.vfi_name.yfilter != YFilter.not_set or
                            self.vfi_state.yfilter != YFilter.not_set or
                            (self.discovery_information is not None and self.discovery_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bridge-access-vfi" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/bridge-domain-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.access.is_set or self.access.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.access.get_name_leafdata())
                        if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                        if (self.vfi_name.is_set or self.vfi_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vfi_name.get_name_leafdata())
                        if (self.vfi_state.is_set or self.vfi_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vfi_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "discovery-information"):
                            if (self.discovery_information is None):
                                self.discovery_information = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                                self.discovery_information.parent = self
                                self._children_name_map["discovery_information"] = "discovery-information"
                            return self.discovery_information

                        if (child_yang_name == "p2mp-information"):
                            for c in self.p2mp_information:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.p2mp_information.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "discovery-information" or name == "p2mp-information" or name == "access" or name == "number-pseudowires" or name == "shutdown" or name == "vfi-name" or name == "vfi-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "access"):
                            self.access = value
                            self.access.value_namespace = name_space
                            self.access.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-pseudowires"):
                            self.number_pseudowires = value
                            self.number_pseudowires.value_namespace = name_space
                            self.number_pseudowires.value_namespace_prefix = name_space_prefix
                        if(value_path == "shutdown"):
                            self.shutdown = value
                            self.shutdown.value_namespace = name_space
                            self.shutdown.value_namespace_prefix = name_space_prefix
                        if(value_path == "vfi-name"):
                            self.vfi_name = value
                            self.vfi_name.value_namespace = name_space
                            self.vfi_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vfi-state"):
                            self.vfi_state = value
                            self.vfi_state.value_namespace = name_space
                            self.vfi_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bridge_access_vfi:
                        if (c.has_data()):
                            return True
                    for c in self.bridge_vfi:
                        if (c.has_data()):
                            return True
                    for c in self.mac_filter:
                        if (c.has_data()):
                            return True
                    return (
                        self.acpwup.is_set or
                        self.as_.is_set or
                        self.bridge_coupled_state.is_set or
                        self.bridge_description.is_set or
                        self.bridge_domain_id.is_set or
                        self.bridge_internal_msti.is_set or
                        self.bridge_msti.is_set or
                        self.bridge_mtu.is_set or
                        self.bridge_name.is_set or
                        self.bridge_shg_id.is_set or
                        self.bridge_state.is_set or
                        self.bridge_type.is_set or
                        self.configured.is_set or
                        self.disposition_bytecount.is_set or
                        self.disposition_pkt_count.is_set or
                        self.evi.is_set or
                        self.flodd_group_id_down.is_set or
                        self.group_name.is_set or
                        self.imposition_byte_count.is_set or
                        self.imposition_pkt_count.is_set or
                        self.is_bridge_partially_programmed.is_set or
                        self.is_rd_configured.is_set or
                        self.last_time_status_changed.is_set or
                        self.load_balance.is_set or
                        self.mac_limit_down.is_set or
                        self.mac_withdraw.is_set or
                        self.mac_withdraw_access.is_set or
                        self.mac_withdraw_option.is_set or
                        self.mac_withdraw_relay.is_set or
                        self.num_vn_is.is_set or
                        self.num_vn_is_up.is_set or
                        self.number_a_cs.is_set or
                        self.number_a_cs_up.is_set or
                        self.number_access_vf_is.is_set or
                        self.number_p_ws_up.is_set or
                        self.number_pb_bs.is_set or
                        self.number_pb_bs_up.is_set or
                        self.number_pseudowires.is_set or
                        self.number_vf_is.is_set or
                        self.nv_satellite_offload_ipv4_multicast_disabled.is_set or
                        self.p2mp_enabled.is_set or
                        self.partially_programmed_a_cs.is_set or
                        self.partially_programmed_pseudowires.is_set or
                        self.shutdown.is_set or
                        self.standby_pseudowires.is_set or
                        self.time_created.is_set or
                        self.time_elapsed_creation.is_set or
                        self.time_elapsed_status_changed.is_set or
                        self.vine_fsm_state.is_set or
                        (self.evpn_parameters is not None and self.evpn_parameters.has_data()) or
                        (self.pbb_parameters is not None and self.pbb_parameters.has_data()) or
                        (self.rd is not None and self.rd.has_data()) or
                        (self.security_parameters is not None and self.security_parameters.has_data()) or
                        (self.vni_parameters is not None and self.vni_parameters.has_data()))

                def has_operation(self):
                    for c in self.bridge_access_vfi:
                        if (c.has_operation()):
                            return True
                    for c in self.bridge_vfi:
                        if (c.has_operation()):
                            return True
                    for c in self.mac_filter:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.acpwup.yfilter != YFilter.not_set or
                        self.as_.yfilter != YFilter.not_set or
                        self.bridge_coupled_state.yfilter != YFilter.not_set or
                        self.bridge_description.yfilter != YFilter.not_set or
                        self.bridge_domain_id.yfilter != YFilter.not_set or
                        self.bridge_internal_msti.yfilter != YFilter.not_set or
                        self.bridge_msti.yfilter != YFilter.not_set or
                        self.bridge_mtu.yfilter != YFilter.not_set or
                        self.bridge_name.yfilter != YFilter.not_set or
                        self.bridge_shg_id.yfilter != YFilter.not_set or
                        self.bridge_state.yfilter != YFilter.not_set or
                        self.bridge_type.yfilter != YFilter.not_set or
                        self.configured.yfilter != YFilter.not_set or
                        self.disposition_bytecount.yfilter != YFilter.not_set or
                        self.disposition_pkt_count.yfilter != YFilter.not_set or
                        self.evi.yfilter != YFilter.not_set or
                        self.flodd_group_id_down.yfilter != YFilter.not_set or
                        self.group_name.yfilter != YFilter.not_set or
                        self.imposition_byte_count.yfilter != YFilter.not_set or
                        self.imposition_pkt_count.yfilter != YFilter.not_set or
                        self.is_bridge_partially_programmed.yfilter != YFilter.not_set or
                        self.is_rd_configured.yfilter != YFilter.not_set or
                        self.last_time_status_changed.yfilter != YFilter.not_set or
                        self.load_balance.yfilter != YFilter.not_set or
                        self.mac_limit_down.yfilter != YFilter.not_set or
                        self.mac_withdraw.yfilter != YFilter.not_set or
                        self.mac_withdraw_access.yfilter != YFilter.not_set or
                        self.mac_withdraw_option.yfilter != YFilter.not_set or
                        self.mac_withdraw_relay.yfilter != YFilter.not_set or
                        self.num_vn_is.yfilter != YFilter.not_set or
                        self.num_vn_is_up.yfilter != YFilter.not_set or
                        self.number_a_cs.yfilter != YFilter.not_set or
                        self.number_a_cs_up.yfilter != YFilter.not_set or
                        self.number_access_vf_is.yfilter != YFilter.not_set or
                        self.number_p_ws_up.yfilter != YFilter.not_set or
                        self.number_pb_bs.yfilter != YFilter.not_set or
                        self.number_pb_bs_up.yfilter != YFilter.not_set or
                        self.number_pseudowires.yfilter != YFilter.not_set or
                        self.number_vf_is.yfilter != YFilter.not_set or
                        self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set or
                        self.p2mp_enabled.yfilter != YFilter.not_set or
                        self.partially_programmed_a_cs.yfilter != YFilter.not_set or
                        self.partially_programmed_pseudowires.yfilter != YFilter.not_set or
                        self.shutdown.yfilter != YFilter.not_set or
                        self.standby_pseudowires.yfilter != YFilter.not_set or
                        self.time_created.yfilter != YFilter.not_set or
                        self.time_elapsed_creation.yfilter != YFilter.not_set or
                        self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                        self.vine_fsm_state.yfilter != YFilter.not_set or
                        (self.evpn_parameters is not None and self.evpn_parameters.has_operation()) or
                        (self.pbb_parameters is not None and self.pbb_parameters.has_operation()) or
                        (self.rd is not None and self.rd.has_operation()) or
                        (self.security_parameters is not None and self.security_parameters.has_operation()) or
                        (self.vni_parameters is not None and self.vni_parameters.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bridge-domain-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/bridge-domain/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.acpwup.is_set or self.acpwup.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.acpwup.get_name_leafdata())
                    if (self.as_.is_set or self.as_.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.as_.get_name_leafdata())
                    if (self.bridge_coupled_state.is_set or self.bridge_coupled_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_coupled_state.get_name_leafdata())
                    if (self.bridge_description.is_set or self.bridge_description.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_description.get_name_leafdata())
                    if (self.bridge_domain_id.is_set or self.bridge_domain_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_domain_id.get_name_leafdata())
                    if (self.bridge_internal_msti.is_set or self.bridge_internal_msti.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_internal_msti.get_name_leafdata())
                    if (self.bridge_msti.is_set or self.bridge_msti.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_msti.get_name_leafdata())
                    if (self.bridge_mtu.is_set or self.bridge_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_mtu.get_name_leafdata())
                    if (self.bridge_name.is_set or self.bridge_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_name.get_name_leafdata())
                    if (self.bridge_shg_id.is_set or self.bridge_shg_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_shg_id.get_name_leafdata())
                    if (self.bridge_state.is_set or self.bridge_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_state.get_name_leafdata())
                    if (self.bridge_type.is_set or self.bridge_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bridge_type.get_name_leafdata())
                    if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured.get_name_leafdata())
                    if (self.disposition_bytecount.is_set or self.disposition_bytecount.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disposition_bytecount.get_name_leafdata())
                    if (self.disposition_pkt_count.is_set or self.disposition_pkt_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disposition_pkt_count.get_name_leafdata())
                    if (self.evi.is_set or self.evi.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.evi.get_name_leafdata())
                    if (self.flodd_group_id_down.is_set or self.flodd_group_id_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flodd_group_id_down.get_name_leafdata())
                    if (self.group_name.is_set or self.group_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_name.get_name_leafdata())
                    if (self.imposition_byte_count.is_set or self.imposition_byte_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.imposition_byte_count.get_name_leafdata())
                    if (self.imposition_pkt_count.is_set or self.imposition_pkt_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.imposition_pkt_count.get_name_leafdata())
                    if (self.is_bridge_partially_programmed.is_set or self.is_bridge_partially_programmed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bridge_partially_programmed.get_name_leafdata())
                    if (self.is_rd_configured.is_set or self.is_rd_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rd_configured.get_name_leafdata())
                    if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                    if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.load_balance.get_name_leafdata())
                    if (self.mac_limit_down.is_set or self.mac_limit_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mac_limit_down.get_name_leafdata())
                    if (self.mac_withdraw.is_set or self.mac_withdraw.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mac_withdraw.get_name_leafdata())
                    if (self.mac_withdraw_access.is_set or self.mac_withdraw_access.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mac_withdraw_access.get_name_leafdata())
                    if (self.mac_withdraw_option.is_set or self.mac_withdraw_option.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mac_withdraw_option.get_name_leafdata())
                    if (self.mac_withdraw_relay.is_set or self.mac_withdraw_relay.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mac_withdraw_relay.get_name_leafdata())
                    if (self.num_vn_is.is_set or self.num_vn_is.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.num_vn_is.get_name_leafdata())
                    if (self.num_vn_is_up.is_set or self.num_vn_is_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.num_vn_is_up.get_name_leafdata())
                    if (self.number_a_cs.is_set or self.number_a_cs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_a_cs.get_name_leafdata())
                    if (self.number_a_cs_up.is_set or self.number_a_cs_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_a_cs_up.get_name_leafdata())
                    if (self.number_access_vf_is.is_set or self.number_access_vf_is.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_access_vf_is.get_name_leafdata())
                    if (self.number_p_ws_up.is_set or self.number_p_ws_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_p_ws_up.get_name_leafdata())
                    if (self.number_pb_bs.is_set or self.number_pb_bs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_pb_bs.get_name_leafdata())
                    if (self.number_pb_bs_up.is_set or self.number_pb_bs_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_pb_bs_up.get_name_leafdata())
                    if (self.number_pseudowires.is_set or self.number_pseudowires.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_pseudowires.get_name_leafdata())
                    if (self.number_vf_is.is_set or self.number_vf_is.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.number_vf_is.get_name_leafdata())
                    if (self.nv_satellite_offload_ipv4_multicast_disabled.is_set or self.nv_satellite_offload_ipv4_multicast_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nv_satellite_offload_ipv4_multicast_disabled.get_name_leafdata())
                    if (self.p2mp_enabled.is_set or self.p2mp_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mp_enabled.get_name_leafdata())
                    if (self.partially_programmed_a_cs.is_set or self.partially_programmed_a_cs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partially_programmed_a_cs.get_name_leafdata())
                    if (self.partially_programmed_pseudowires.is_set or self.partially_programmed_pseudowires.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partially_programmed_pseudowires.get_name_leafdata())
                    if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.shutdown.get_name_leafdata())
                    if (self.standby_pseudowires.is_set or self.standby_pseudowires.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_pseudowires.get_name_leafdata())
                    if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.time_created.get_name_leafdata())
                    if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                    if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                    if (self.vine_fsm_state.is_set or self.vine_fsm_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vine_fsm_state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bridge-access-vfi"):
                        for c in self.bridge_access_vfi:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bridge_access_vfi.append(c)
                        return c

                    if (child_yang_name == "bridge-vfi"):
                        for c in self.bridge_vfi:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bridge_vfi.append(c)
                        return c

                    if (child_yang_name == "evpn-parameters"):
                        if (self.evpn_parameters is None):
                            self.evpn_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                            self.evpn_parameters.parent = self
                            self._children_name_map["evpn_parameters"] = "evpn-parameters"
                        return self.evpn_parameters

                    if (child_yang_name == "mac-filter"):
                        for c in self.mac_filter:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.mac_filter.append(c)
                        return c

                    if (child_yang_name == "pbb-parameters"):
                        if (self.pbb_parameters is None):
                            self.pbb_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                            self.pbb_parameters.parent = self
                            self._children_name_map["pbb_parameters"] = "pbb-parameters"
                        return self.pbb_parameters

                    if (child_yang_name == "rd"):
                        if (self.rd is None):
                            self.rd = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                            self.rd.parent = self
                            self._children_name_map["rd"] = "rd"
                        return self.rd

                    if (child_yang_name == "security-parameters"):
                        if (self.security_parameters is None):
                            self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"
                        return self.security_parameters

                    if (child_yang_name == "vni-parameters"):
                        if (self.vni_parameters is None):
                            self.vni_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                            self.vni_parameters.parent = self
                            self._children_name_map["vni_parameters"] = "vni-parameters"
                        return self.vni_parameters

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bridge-access-vfi" or name == "bridge-vfi" or name == "evpn-parameters" or name == "mac-filter" or name == "pbb-parameters" or name == "rd" or name == "security-parameters" or name == "vni-parameters" or name == "acpwup" or name == "as" or name == "bridge-coupled-state" or name == "bridge-description" or name == "bridge-domain-id" or name == "bridge-internal-msti" or name == "bridge-msti" or name == "bridge-mtu" or name == "bridge-name" or name == "bridge-shg-id" or name == "bridge-state" or name == "bridge-type" or name == "configured" or name == "disposition-bytecount" or name == "disposition-pkt-count" or name == "evi" or name == "flodd-group-id-down" or name == "group-name" or name == "imposition-byte-count" or name == "imposition-pkt-count" or name == "is-bridge-partially-programmed" or name == "is-rd-configured" or name == "last-time-status-changed" or name == "load-balance" or name == "mac-limit-down" or name == "mac-withdraw" or name == "mac-withdraw-access" or name == "mac-withdraw-option" or name == "mac-withdraw-relay" or name == "num-vn-is" or name == "num-vn-is-up" or name == "number-a-cs" or name == "number-a-cs-up" or name == "number-access-vf-is" or name == "number-p-ws-up" or name == "number-pb-bs" or name == "number-pb-bs-up" or name == "number-pseudowires" or name == "number-vf-is" or name == "nv-satellite-offload-ipv4-multicast-disabled" or name == "p2mp-enabled" or name == "partially-programmed-a-cs" or name == "partially-programmed-pseudowires" or name == "shutdown" or name == "standby-pseudowires" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "vine-fsm-state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "acpwup"):
                        self.acpwup = value
                        self.acpwup.value_namespace = name_space
                        self.acpwup.value_namespace_prefix = name_space_prefix
                    if(value_path == "as"):
                        self.as_ = value
                        self.as_.value_namespace = name_space
                        self.as_.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-coupled-state"):
                        self.bridge_coupled_state = value
                        self.bridge_coupled_state.value_namespace = name_space
                        self.bridge_coupled_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-description"):
                        self.bridge_description = value
                        self.bridge_description.value_namespace = name_space
                        self.bridge_description.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-domain-id"):
                        self.bridge_domain_id = value
                        self.bridge_domain_id.value_namespace = name_space
                        self.bridge_domain_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-internal-msti"):
                        self.bridge_internal_msti = value
                        self.bridge_internal_msti.value_namespace = name_space
                        self.bridge_internal_msti.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-msti"):
                        self.bridge_msti = value
                        self.bridge_msti.value_namespace = name_space
                        self.bridge_msti.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-mtu"):
                        self.bridge_mtu = value
                        self.bridge_mtu.value_namespace = name_space
                        self.bridge_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-name"):
                        self.bridge_name = value
                        self.bridge_name.value_namespace = name_space
                        self.bridge_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-shg-id"):
                        self.bridge_shg_id = value
                        self.bridge_shg_id.value_namespace = name_space
                        self.bridge_shg_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-state"):
                        self.bridge_state = value
                        self.bridge_state.value_namespace = name_space
                        self.bridge_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "bridge-type"):
                        self.bridge_type = value
                        self.bridge_type.value_namespace = name_space
                        self.bridge_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "configured"):
                        self.configured = value
                        self.configured.value_namespace = name_space
                        self.configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "disposition-bytecount"):
                        self.disposition_bytecount = value
                        self.disposition_bytecount.value_namespace = name_space
                        self.disposition_bytecount.value_namespace_prefix = name_space_prefix
                    if(value_path == "disposition-pkt-count"):
                        self.disposition_pkt_count = value
                        self.disposition_pkt_count.value_namespace = name_space
                        self.disposition_pkt_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "evi"):
                        self.evi = value
                        self.evi.value_namespace = name_space
                        self.evi.value_namespace_prefix = name_space_prefix
                    if(value_path == "flodd-group-id-down"):
                        self.flodd_group_id_down = value
                        self.flodd_group_id_down.value_namespace = name_space
                        self.flodd_group_id_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-name"):
                        self.group_name = value
                        self.group_name.value_namespace = name_space
                        self.group_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "imposition-byte-count"):
                        self.imposition_byte_count = value
                        self.imposition_byte_count.value_namespace = name_space
                        self.imposition_byte_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "imposition-pkt-count"):
                        self.imposition_pkt_count = value
                        self.imposition_pkt_count.value_namespace = name_space
                        self.imposition_pkt_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-bridge-partially-programmed"):
                        self.is_bridge_partially_programmed = value
                        self.is_bridge_partially_programmed.value_namespace = name_space
                        self.is_bridge_partially_programmed.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rd-configured"):
                        self.is_rd_configured = value
                        self.is_rd_configured.value_namespace = name_space
                        self.is_rd_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-time-status-changed"):
                        self.last_time_status_changed = value
                        self.last_time_status_changed.value_namespace = name_space
                        self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                    if(value_path == "load-balance"):
                        self.load_balance = value
                        self.load_balance.value_namespace = name_space
                        self.load_balance.value_namespace_prefix = name_space_prefix
                    if(value_path == "mac-limit-down"):
                        self.mac_limit_down = value
                        self.mac_limit_down.value_namespace = name_space
                        self.mac_limit_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "mac-withdraw"):
                        self.mac_withdraw = value
                        self.mac_withdraw.value_namespace = name_space
                        self.mac_withdraw.value_namespace_prefix = name_space_prefix
                    if(value_path == "mac-withdraw-access"):
                        self.mac_withdraw_access = value
                        self.mac_withdraw_access.value_namespace = name_space
                        self.mac_withdraw_access.value_namespace_prefix = name_space_prefix
                    if(value_path == "mac-withdraw-option"):
                        self.mac_withdraw_option = value
                        self.mac_withdraw_option.value_namespace = name_space
                        self.mac_withdraw_option.value_namespace_prefix = name_space_prefix
                    if(value_path == "mac-withdraw-relay"):
                        self.mac_withdraw_relay = value
                        self.mac_withdraw_relay.value_namespace = name_space
                        self.mac_withdraw_relay.value_namespace_prefix = name_space_prefix
                    if(value_path == "num-vn-is"):
                        self.num_vn_is = value
                        self.num_vn_is.value_namespace = name_space
                        self.num_vn_is.value_namespace_prefix = name_space_prefix
                    if(value_path == "num-vn-is-up"):
                        self.num_vn_is_up = value
                        self.num_vn_is_up.value_namespace = name_space
                        self.num_vn_is_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-a-cs"):
                        self.number_a_cs = value
                        self.number_a_cs.value_namespace = name_space
                        self.number_a_cs.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-a-cs-up"):
                        self.number_a_cs_up = value
                        self.number_a_cs_up.value_namespace = name_space
                        self.number_a_cs_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-access-vf-is"):
                        self.number_access_vf_is = value
                        self.number_access_vf_is.value_namespace = name_space
                        self.number_access_vf_is.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-p-ws-up"):
                        self.number_p_ws_up = value
                        self.number_p_ws_up.value_namespace = name_space
                        self.number_p_ws_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-pb-bs"):
                        self.number_pb_bs = value
                        self.number_pb_bs.value_namespace = name_space
                        self.number_pb_bs.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-pb-bs-up"):
                        self.number_pb_bs_up = value
                        self.number_pb_bs_up.value_namespace = name_space
                        self.number_pb_bs_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-pseudowires"):
                        self.number_pseudowires = value
                        self.number_pseudowires.value_namespace = name_space
                        self.number_pseudowires.value_namespace_prefix = name_space_prefix
                    if(value_path == "number-vf-is"):
                        self.number_vf_is = value
                        self.number_vf_is.value_namespace = name_space
                        self.number_vf_is.value_namespace_prefix = name_space_prefix
                    if(value_path == "nv-satellite-offload-ipv4-multicast-disabled"):
                        self.nv_satellite_offload_ipv4_multicast_disabled = value
                        self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace = name_space
                        self.nv_satellite_offload_ipv4_multicast_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mp-enabled"):
                        self.p2mp_enabled = value
                        self.p2mp_enabled.value_namespace = name_space
                        self.p2mp_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "partially-programmed-a-cs"):
                        self.partially_programmed_a_cs = value
                        self.partially_programmed_a_cs.value_namespace = name_space
                        self.partially_programmed_a_cs.value_namespace_prefix = name_space_prefix
                    if(value_path == "partially-programmed-pseudowires"):
                        self.partially_programmed_pseudowires = value
                        self.partially_programmed_pseudowires.value_namespace = name_space
                        self.partially_programmed_pseudowires.value_namespace_prefix = name_space_prefix
                    if(value_path == "shutdown"):
                        self.shutdown = value
                        self.shutdown.value_namespace = name_space
                        self.shutdown.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-pseudowires"):
                        self.standby_pseudowires = value
                        self.standby_pseudowires.value_namespace = name_space
                        self.standby_pseudowires.value_namespace_prefix = name_space_prefix
                    if(value_path == "time-created"):
                        self.time_created = value
                        self.time_created.value_namespace = name_space
                        self.time_created.value_namespace_prefix = name_space_prefix
                    if(value_path == "time-elapsed-creation"):
                        self.time_elapsed_creation = value
                        self.time_elapsed_creation.value_namespace = name_space
                        self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                    if(value_path == "time-elapsed-status-changed"):
                        self.time_elapsed_status_changed = value
                        self.time_elapsed_status_changed.value_namespace = name_space
                        self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                    if(value_path == "vine-fsm-state"):
                        self.vine_fsm_state = value
                        self.vine_fsm_state.value_namespace = name_space
                        self.vine_fsm_state.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.bridge_domain_group_name.is_set or
                    self.bridge_domain_name.is_set or
                    (self.bridge_access_pws is not None and self.bridge_access_pws.has_data()) or
                    (self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table.has_data()) or
                    (self.bridge_acs is not None and self.bridge_acs.has_data()) or
                    (self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table.has_data()) or
                    (self.bridge_domain_info is not None and self.bridge_domain_info.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.bridge_domain_group_name.yfilter != YFilter.not_set or
                    self.bridge_domain_name.yfilter != YFilter.not_set or
                    (self.bridge_access_pws is not None and self.bridge_access_pws.has_operation()) or
                    (self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table.has_operation()) or
                    (self.bridge_acs is not None and self.bridge_acs.has_operation()) or
                    (self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table.has_operation()) or
                    (self.bridge_domain_info is not None and self.bridge_domain_info.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bridge-domain" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/bridge-domains/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.bridge_domain_group_name.is_set or self.bridge_domain_group_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bridge_domain_group_name.get_name_leafdata())
                if (self.bridge_domain_name.is_set or self.bridge_domain_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bridge_domain_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bridge-access-pws"):
                    if (self.bridge_access_pws is None):
                        self.bridge_access_pws = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws()
                        self.bridge_access_pws.parent = self
                        self._children_name_map["bridge_access_pws"] = "bridge-access-pws"
                    return self.bridge_access_pws

                if (child_yang_name == "bridge-access-vfi-table"):
                    if (self.bridge_access_vfi_table is None):
                        self.bridge_access_vfi_table = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                        self.bridge_access_vfi_table.parent = self
                        self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"
                    return self.bridge_access_vfi_table

                if (child_yang_name == "bridge-acs"):
                    if (self.bridge_acs is None):
                        self.bridge_acs = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs()
                        self.bridge_acs.parent = self
                        self._children_name_map["bridge_acs"] = "bridge-acs"
                    return self.bridge_acs

                if (child_yang_name == "bridge-core-vfi-table"):
                    if (self.bridge_core_vfi_table is None):
                        self.bridge_core_vfi_table = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                        self.bridge_core_vfi_table.parent = self
                        self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"
                    return self.bridge_core_vfi_table

                if (child_yang_name == "bridge-domain-info"):
                    if (self.bridge_domain_info is None):
                        self.bridge_domain_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                        self.bridge_domain_info.parent = self
                        self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                    return self.bridge_domain_info

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bridge-access-pws" or name == "bridge-access-vfi-table" or name == "bridge-acs" or name == "bridge-core-vfi-table" or name == "bridge-domain-info" or name == "bridge-domain-group-name" or name == "bridge-domain-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "bridge-domain-group-name"):
                    self.bridge_domain_group_name = value
                    self.bridge_domain_group_name.value_namespace = name_space
                    self.bridge_domain_group_name.value_namespace_prefix = name_space_prefix
                if(value_path == "bridge-domain-name"):
                    self.bridge_domain_name = value
                    self.bridge_domain_name.value_namespace = name_space
                    self.bridge_domain_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.bridge_domain:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.bridge_domain:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "bridge-domains" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "bridge-domain"):
                for c in self.bridge_domain:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.BridgeDomains.BridgeDomain()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.bridge_domain.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bridge-domain"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class DiscoverySummary(Entity):
        """
        Discovery summary information
        
        .. attribute:: bgp_current_node_id
        
        	BGP current node id
        	**type**\:  str
        
        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
        
        .. attribute:: bgp_ipc_transport_mode
        
        	IPC Transport mode with BGP
        	**type**\:   :py:class:`L2VpnIpcTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIpcTransportMode>`
        
        .. attribute:: bgp_stateon_active_rp
        
        	BGP state on the active RP
        	**type**\:  bool
        
        .. attribute:: bgp_stateon_standby_rp
        
        	BGP state on standby RP
        	**type**\:  bool
        
        .. attribute:: number_bridge_domainvpns
        
        	Number of BDs registered
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_local_edges_bridge_domain
        
        	Number of local Edges
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_local_edges_xconnect
        
        	Number of local Edges
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2m_pxconnect_vpns
        
        	Number of XCs registered
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_nlri_bridge_domain
        
        	Number of NLRI
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_nlri_xconnect
        
        	Number of NLRI
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_remote_edges_bridge_domain
        
        	Number of Remote Edges
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_remote_edges_xconnect
        
        	Number of Remote Edges
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: vpls_registered
        
        	Is the VPLS service registered
        	**type**\:  bool
        
        .. attribute:: vpws_registered
        
        	Is the VPWS service registered
        	**type**\:  bool
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.DiscoverySummary, self).__init__()

            self.yang_name = "discovery-summary"
            self.yang_parent_name = "l2vpn"

            self.bgp_current_node_id = YLeaf(YType.str, "bgp-current-node-id")

            self.bgp_ipc_transport_mode = YLeaf(YType.enumeration, "bgp-ipc-transport-mode")

            self.bgp_stateon_active_rp = YLeaf(YType.boolean, "bgp-stateon-active-rp")

            self.bgp_stateon_standby_rp = YLeaf(YType.boolean, "bgp-stateon-standby-rp")

            self.number_bridge_domainvpns = YLeaf(YType.uint32, "number-bridge-domainvpns")

            self.number_local_edges_bridge_domain = YLeaf(YType.uint32, "number-local-edges-bridge-domain")

            self.number_local_edges_xconnect = YLeaf(YType.uint32, "number-local-edges-xconnect")

            self.number_mp2m_pxconnect_vpns = YLeaf(YType.uint32, "number-mp2m-pxconnect-vpns")

            self.number_nlri_bridge_domain = YLeaf(YType.uint32, "number-nlri-bridge-domain")

            self.number_nlri_xconnect = YLeaf(YType.uint32, "number-nlri-xconnect")

            self.number_remote_edges_bridge_domain = YLeaf(YType.uint32, "number-remote-edges-bridge-domain")

            self.number_remote_edges_xconnect = YLeaf(YType.uint32, "number-remote-edges-xconnect")

            self.vpls_registered = YLeaf(YType.boolean, "vpls-registered")

            self.vpws_registered = YLeaf(YType.boolean, "vpws-registered")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("bgp_current_node_id",
                            "bgp_ipc_transport_mode",
                            "bgp_stateon_active_rp",
                            "bgp_stateon_standby_rp",
                            "number_bridge_domainvpns",
                            "number_local_edges_bridge_domain",
                            "number_local_edges_xconnect",
                            "number_mp2m_pxconnect_vpns",
                            "number_nlri_bridge_domain",
                            "number_nlri_xconnect",
                            "number_remote_edges_bridge_domain",
                            "number_remote_edges_xconnect",
                            "vpls_registered",
                            "vpws_registered") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.DiscoverySummary, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.DiscoverySummary, self).__setattr__(name, value)

        def has_data(self):
            return (
                self.bgp_current_node_id.is_set or
                self.bgp_ipc_transport_mode.is_set or
                self.bgp_stateon_active_rp.is_set or
                self.bgp_stateon_standby_rp.is_set or
                self.number_bridge_domainvpns.is_set or
                self.number_local_edges_bridge_domain.is_set or
                self.number_local_edges_xconnect.is_set or
                self.number_mp2m_pxconnect_vpns.is_set or
                self.number_nlri_bridge_domain.is_set or
                self.number_nlri_xconnect.is_set or
                self.number_remote_edges_bridge_domain.is_set or
                self.number_remote_edges_xconnect.is_set or
                self.vpls_registered.is_set or
                self.vpws_registered.is_set)

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.bgp_current_node_id.yfilter != YFilter.not_set or
                self.bgp_ipc_transport_mode.yfilter != YFilter.not_set or
                self.bgp_stateon_active_rp.yfilter != YFilter.not_set or
                self.bgp_stateon_standby_rp.yfilter != YFilter.not_set or
                self.number_bridge_domainvpns.yfilter != YFilter.not_set or
                self.number_local_edges_bridge_domain.yfilter != YFilter.not_set or
                self.number_local_edges_xconnect.yfilter != YFilter.not_set or
                self.number_mp2m_pxconnect_vpns.yfilter != YFilter.not_set or
                self.number_nlri_bridge_domain.yfilter != YFilter.not_set or
                self.number_nlri_xconnect.yfilter != YFilter.not_set or
                self.number_remote_edges_bridge_domain.yfilter != YFilter.not_set or
                self.number_remote_edges_xconnect.yfilter != YFilter.not_set or
                self.vpls_registered.yfilter != YFilter.not_set or
                self.vpws_registered.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "discovery-summary" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.bgp_current_node_id.is_set or self.bgp_current_node_id.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bgp_current_node_id.get_name_leafdata())
            if (self.bgp_ipc_transport_mode.is_set or self.bgp_ipc_transport_mode.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bgp_ipc_transport_mode.get_name_leafdata())
            if (self.bgp_stateon_active_rp.is_set or self.bgp_stateon_active_rp.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bgp_stateon_active_rp.get_name_leafdata())
            if (self.bgp_stateon_standby_rp.is_set or self.bgp_stateon_standby_rp.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bgp_stateon_standby_rp.get_name_leafdata())
            if (self.number_bridge_domainvpns.is_set or self.number_bridge_domainvpns.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_bridge_domainvpns.get_name_leafdata())
            if (self.number_local_edges_bridge_domain.is_set or self.number_local_edges_bridge_domain.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_local_edges_bridge_domain.get_name_leafdata())
            if (self.number_local_edges_xconnect.is_set or self.number_local_edges_xconnect.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_local_edges_xconnect.get_name_leafdata())
            if (self.number_mp2m_pxconnect_vpns.is_set or self.number_mp2m_pxconnect_vpns.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_mp2m_pxconnect_vpns.get_name_leafdata())
            if (self.number_nlri_bridge_domain.is_set or self.number_nlri_bridge_domain.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_nlri_bridge_domain.get_name_leafdata())
            if (self.number_nlri_xconnect.is_set or self.number_nlri_xconnect.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_nlri_xconnect.get_name_leafdata())
            if (self.number_remote_edges_bridge_domain.is_set or self.number_remote_edges_bridge_domain.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_remote_edges_bridge_domain.get_name_leafdata())
            if (self.number_remote_edges_xconnect.is_set or self.number_remote_edges_xconnect.yfilter != YFilter.not_set):
                leaf_name_data.append(self.number_remote_edges_xconnect.get_name_leafdata())
            if (self.vpls_registered.is_set or self.vpls_registered.yfilter != YFilter.not_set):
                leaf_name_data.append(self.vpls_registered.get_name_leafdata())
            if (self.vpws_registered.is_set or self.vpws_registered.yfilter != YFilter.not_set):
                leaf_name_data.append(self.vpws_registered.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bgp-current-node-id" or name == "bgp-ipc-transport-mode" or name == "bgp-stateon-active-rp" or name == "bgp-stateon-standby-rp" or name == "number-bridge-domainvpns" or name == "number-local-edges-bridge-domain" or name == "number-local-edges-xconnect" or name == "number-mp2m-pxconnect-vpns" or name == "number-nlri-bridge-domain" or name == "number-nlri-xconnect" or name == "number-remote-edges-bridge-domain" or name == "number-remote-edges-xconnect" or name == "vpls-registered" or name == "vpws-registered"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "bgp-current-node-id"):
                self.bgp_current_node_id = value
                self.bgp_current_node_id.value_namespace = name_space
                self.bgp_current_node_id.value_namespace_prefix = name_space_prefix
            if(value_path == "bgp-ipc-transport-mode"):
                self.bgp_ipc_transport_mode = value
                self.bgp_ipc_transport_mode.value_namespace = name_space
                self.bgp_ipc_transport_mode.value_namespace_prefix = name_space_prefix
            if(value_path == "bgp-stateon-active-rp"):
                self.bgp_stateon_active_rp = value
                self.bgp_stateon_active_rp.value_namespace = name_space
                self.bgp_stateon_active_rp.value_namespace_prefix = name_space_prefix
            if(value_path == "bgp-stateon-standby-rp"):
                self.bgp_stateon_standby_rp = value
                self.bgp_stateon_standby_rp.value_namespace = name_space
                self.bgp_stateon_standby_rp.value_namespace_prefix = name_space_prefix
            if(value_path == "number-bridge-domainvpns"):
                self.number_bridge_domainvpns = value
                self.number_bridge_domainvpns.value_namespace = name_space
                self.number_bridge_domainvpns.value_namespace_prefix = name_space_prefix
            if(value_path == "number-local-edges-bridge-domain"):
                self.number_local_edges_bridge_domain = value
                self.number_local_edges_bridge_domain.value_namespace = name_space
                self.number_local_edges_bridge_domain.value_namespace_prefix = name_space_prefix
            if(value_path == "number-local-edges-xconnect"):
                self.number_local_edges_xconnect = value
                self.number_local_edges_xconnect.value_namespace = name_space
                self.number_local_edges_xconnect.value_namespace_prefix = name_space_prefix
            if(value_path == "number-mp2m-pxconnect-vpns"):
                self.number_mp2m_pxconnect_vpns = value
                self.number_mp2m_pxconnect_vpns.value_namespace = name_space
                self.number_mp2m_pxconnect_vpns.value_namespace_prefix = name_space_prefix
            if(value_path == "number-nlri-bridge-domain"):
                self.number_nlri_bridge_domain = value
                self.number_nlri_bridge_domain.value_namespace = name_space
                self.number_nlri_bridge_domain.value_namespace_prefix = name_space_prefix
            if(value_path == "number-nlri-xconnect"):
                self.number_nlri_xconnect = value
                self.number_nlri_xconnect.value_namespace = name_space
                self.number_nlri_xconnect.value_namespace_prefix = name_space_prefix
            if(value_path == "number-remote-edges-bridge-domain"):
                self.number_remote_edges_bridge_domain = value
                self.number_remote_edges_bridge_domain.value_namespace = name_space
                self.number_remote_edges_bridge_domain.value_namespace_prefix = name_space_prefix
            if(value_path == "number-remote-edges-xconnect"):
                self.number_remote_edges_xconnect = value
                self.number_remote_edges_xconnect.value_namespace = name_space
                self.number_remote_edges_xconnect.value_namespace_prefix = name_space_prefix
            if(value_path == "vpls-registered"):
                self.vpls_registered = value
                self.vpls_registered.value_namespace = name_space
                self.vpls_registered.value_namespace_prefix = name_space_prefix
            if(value_path == "vpws-registered"):
                self.vpws_registered = value
                self.vpws_registered.value_namespace = name_space
                self.vpws_registered.value_namespace_prefix = name_space_prefix


    class G8032(Entity):
        """
        G8032 information
        
        .. attribute:: g8032_rings
        
        	G8032 Ring table
        	**type**\:   :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.G8032, self).__init__()

            self.yang_name = "g8032"
            self.yang_parent_name = "l2vpn"

            self.g8032_rings = L2Vpn.G8032.G8032Rings()
            self.g8032_rings.parent = self
            self._children_name_map["g8032_rings"] = "g8032-rings"
            self._children_yang_names.add("g8032-rings")


        class G8032Rings(Entity):
            """
            G8032 Ring table
            
            .. attribute:: g8032_ring
            
            	G8032 Ring
            	**type**\: list of    :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.G8032.G8032Rings, self).__init__()

                self.yang_name = "g8032-rings"
                self.yang_parent_name = "g8032"

                self.g8032_ring = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.G8032.G8032Rings, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.G8032.G8032Rings, self).__setattr__(name, value)


            class G8032Ring(Entity):
                """
                G8032 Ring
                
                .. attribute:: ring_name  <key>
                
                	Ring Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: g8032_ring_detail
                
                	G8032 Ring detailed information
                	**type**\:   :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                
                .. attribute:: g8032_ring_instance_details
                
                	G8032 Ring Instance detail table
                	**type**\:   :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                
                .. attribute:: g8032_ring_instance_summaries
                
                	G8032 Ring Instance summary table
                	**type**\:   :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                
                .. attribute:: g8032_ring_summary
                
                	G8032 Ring summary information
                	**type**\:   :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.G8032.G8032Rings.G8032Ring, self).__init__()

                    self.yang_name = "g8032-ring"
                    self.yang_parent_name = "g8032-rings"

                    self.ring_name = YLeaf(YType.str, "ring-name")

                    self.g8032_ring_detail = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                    self.g8032_ring_detail.parent = self
                    self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"
                    self._children_yang_names.add("g8032-ring-detail")

                    self.g8032_ring_instance_details = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                    self.g8032_ring_instance_details.parent = self
                    self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                    self._children_yang_names.add("g8032-ring-instance-details")

                    self.g8032_ring_instance_summaries = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                    self.g8032_ring_instance_summaries.parent = self
                    self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"
                    self._children_yang_names.add("g8032-ring-instance-summaries")

                    self.g8032_ring_summary = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                    self.g8032_ring_summary.parent = self
                    self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"
                    self._children_yang_names.add("g8032-ring-summary")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ring_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.G8032.G8032Rings.G8032Ring, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.G8032.G8032Rings.G8032Ring, self).__setattr__(name, value)


                class G8032RingDetail(Entity):
                    """
                    G8032 Ring detailed information
                    
                    .. attribute:: excluded_vlan_id
                    
                    	Exclusion Vlan ids list 
                    	**type**\:  list of int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: is_open_ring
                    
                    	Flag open ring
                    	**type**\:  bool
                    
                    .. attribute:: is_provider_bridge
                    
                    	Operating mode Customer/Provider 
                    	**type**\:  bool
                    
                    .. attribute:: monitor0
                    
                    	Monitor port 0
                    	**type**\:  str
                    
                    .. attribute:: monitor1
                    
                    	Monitor port 1
                    	**type**\:  str
                    
                    .. attribute:: port0
                    
                    	Port 0
                    	**type**\:  str
                    
                    .. attribute:: port1
                    
                    	Port 1
                    	**type**\:  str
                    
                    .. attribute:: ring_name
                    
                    	Name of the ring
                    	**type**\:  str
                    
                    .. attribute:: tcn_propagation
                    
                    	Global TCN propagation
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__init__()

                        self.yang_name = "g8032-ring-detail"
                        self.yang_parent_name = "g8032-ring"

                        self.excluded_vlan_id = YLeafList(YType.uint16, "excluded-vlan-id")

                        self.is_open_ring = YLeaf(YType.boolean, "is-open-ring")

                        self.is_provider_bridge = YLeaf(YType.boolean, "is-provider-bridge")

                        self.monitor0 = YLeaf(YType.str, "monitor0")

                        self.monitor1 = YLeaf(YType.str, "monitor1")

                        self.port0 = YLeaf(YType.str, "port0")

                        self.port1 = YLeaf(YType.str, "port1")

                        self.ring_name = YLeaf(YType.str, "ring-name")

                        self.tcn_propagation = YLeaf(YType.boolean, "tcn-propagation")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("excluded_vlan_id",
                                        "is_open_ring",
                                        "is_provider_bridge",
                                        "monitor0",
                                        "monitor1",
                                        "port0",
                                        "port1",
                                        "ring_name",
                                        "tcn_propagation") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__setattr__(name, value)

                    def has_data(self):
                        for leaf in self.excluded_vlan_id.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.is_open_ring.is_set or
                            self.is_provider_bridge.is_set or
                            self.monitor0.is_set or
                            self.monitor1.is_set or
                            self.port0.is_set or
                            self.port1.is_set or
                            self.ring_name.is_set or
                            self.tcn_propagation.is_set)

                    def has_operation(self):
                        for leaf in self.excluded_vlan_id.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.excluded_vlan_id.yfilter != YFilter.not_set or
                            self.is_open_ring.yfilter != YFilter.not_set or
                            self.is_provider_bridge.yfilter != YFilter.not_set or
                            self.monitor0.yfilter != YFilter.not_set or
                            self.monitor1.yfilter != YFilter.not_set or
                            self.port0.yfilter != YFilter.not_set or
                            self.port1.yfilter != YFilter.not_set or
                            self.ring_name.yfilter != YFilter.not_set or
                            self.tcn_propagation.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g8032-ring-detail" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_open_ring.is_set or self.is_open_ring.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_open_ring.get_name_leafdata())
                        if (self.is_provider_bridge.is_set or self.is_provider_bridge.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_provider_bridge.get_name_leafdata())
                        if (self.monitor0.is_set or self.monitor0.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.monitor0.get_name_leafdata())
                        if (self.monitor1.is_set or self.monitor1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.monitor1.get_name_leafdata())
                        if (self.port0.is_set or self.port0.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port0.get_name_leafdata())
                        if (self.port1.is_set or self.port1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port1.get_name_leafdata())
                        if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ring_name.get_name_leafdata())
                        if (self.tcn_propagation.is_set or self.tcn_propagation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tcn_propagation.get_name_leafdata())

                        leaf_name_data.extend(self.excluded_vlan_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "excluded-vlan-id" or name == "is-open-ring" or name == "is-provider-bridge" or name == "monitor0" or name == "monitor1" or name == "port0" or name == "port1" or name == "ring-name" or name == "tcn-propagation"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "excluded-vlan-id"):
                            self.excluded_vlan_id.append(value)
                        if(value_path == "is-open-ring"):
                            self.is_open_ring = value
                            self.is_open_ring.value_namespace = name_space
                            self.is_open_ring.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-provider-bridge"):
                            self.is_provider_bridge = value
                            self.is_provider_bridge.value_namespace = name_space
                            self.is_provider_bridge.value_namespace_prefix = name_space_prefix
                        if(value_path == "monitor0"):
                            self.monitor0 = value
                            self.monitor0.value_namespace = name_space
                            self.monitor0.value_namespace_prefix = name_space_prefix
                        if(value_path == "monitor1"):
                            self.monitor1 = value
                            self.monitor1.value_namespace = name_space
                            self.monitor1.value_namespace_prefix = name_space_prefix
                        if(value_path == "port0"):
                            self.port0 = value
                            self.port0.value_namespace = name_space
                            self.port0.value_namespace_prefix = name_space_prefix
                        if(value_path == "port1"):
                            self.port1 = value
                            self.port1.value_namespace = name_space
                            self.port1.value_namespace_prefix = name_space_prefix
                        if(value_path == "ring-name"):
                            self.ring_name = value
                            self.ring_name.value_namespace = name_space
                            self.ring_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "tcn-propagation"):
                            self.tcn_propagation = value
                            self.tcn_propagation.value_namespace = name_space
                            self.tcn_propagation.value_namespace_prefix = name_space_prefix


                class G8032RingInstanceSummaries(Entity):
                    """
                    G8032 Ring Instance summary table
                    
                    .. attribute:: g8032_ring_instance_summary
                    
                    	G8032 Ring Instance summary information
                    	**type**\: list of    :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__init__()

                        self.yang_name = "g8032-ring-instance-summaries"
                        self.yang_parent_name = "g8032-ring"

                        self.g8032_ring_instance_summary = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__setattr__(name, value)


                    class G8032RingInstanceSummary(Entity):
                        """
                        G8032 Ring Instance summary information
                        
                        .. attribute:: instance  <key>
                        
                        	Instance
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: aps_port0
                        
                        	Port 0 of aps\-channel
                        	**type**\:  str
                        
                        .. attribute:: aps_port1
                        
                        	Port 1 of aps\-channel
                        	**type**\:  str
                        
                        .. attribute:: config_state
                        
                        	State of the instance
                        	**type**\:  bool
                        
                        .. attribute:: included_vlan_id
                        
                        	Inclusion list Vlan Ids
                        	**type**\:  list of int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ring_instance
                        
                        	Ring instance number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__init__()

                            self.yang_name = "g8032-ring-instance-summary"
                            self.yang_parent_name = "g8032-ring-instance-summaries"

                            self.instance = YLeaf(YType.int32, "instance")

                            self.aps_port0 = YLeaf(YType.str, "aps-port0")

                            self.aps_port1 = YLeaf(YType.str, "aps-port1")

                            self.config_state = YLeaf(YType.boolean, "config-state")

                            self.included_vlan_id = YLeafList(YType.uint16, "included-vlan-id")

                            self.ring_instance = YLeaf(YType.uint32, "ring-instance")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("instance",
                                            "aps_port0",
                                            "aps_port1",
                                            "config_state",
                                            "included_vlan_id",
                                            "ring_instance") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.included_vlan_id.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.instance.is_set or
                                self.aps_port0.is_set or
                                self.aps_port1.is_set or
                                self.config_state.is_set or
                                self.ring_instance.is_set)

                        def has_operation(self):
                            for leaf in self.included_vlan_id.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.instance.yfilter != YFilter.not_set or
                                self.aps_port0.yfilter != YFilter.not_set or
                                self.aps_port1.yfilter != YFilter.not_set or
                                self.config_state.yfilter != YFilter.not_set or
                                self.included_vlan_id.yfilter != YFilter.not_set or
                                self.ring_instance.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring-instance-summary" + "[instance='" + self.instance.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.instance.get_name_leafdata())
                            if (self.aps_port0.is_set or self.aps_port0.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.aps_port0.get_name_leafdata())
                            if (self.aps_port1.is_set or self.aps_port1.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.aps_port1.get_name_leafdata())
                            if (self.config_state.is_set or self.config_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.config_state.get_name_leafdata())
                            if (self.ring_instance.is_set or self.ring_instance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ring_instance.get_name_leafdata())

                            leaf_name_data.extend(self.included_vlan_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "instance" or name == "aps-port0" or name == "aps-port1" or name == "config-state" or name == "included-vlan-id" or name == "ring-instance"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "instance"):
                                self.instance = value
                                self.instance.value_namespace = name_space
                                self.instance.value_namespace_prefix = name_space_prefix
                            if(value_path == "aps-port0"):
                                self.aps_port0 = value
                                self.aps_port0.value_namespace = name_space
                                self.aps_port0.value_namespace_prefix = name_space_prefix
                            if(value_path == "aps-port1"):
                                self.aps_port1 = value
                                self.aps_port1.value_namespace = name_space
                                self.aps_port1.value_namespace_prefix = name_space_prefix
                            if(value_path == "config-state"):
                                self.config_state = value
                                self.config_state.value_namespace = name_space
                                self.config_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "included-vlan-id"):
                                self.included_vlan_id.append(value)
                            if(value_path == "ring-instance"):
                                self.ring_instance = value
                                self.ring_instance.value_namespace = name_space
                                self.ring_instance.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.g8032_ring_instance_summary:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.g8032_ring_instance_summary:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g8032-ring-instance-summaries" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "g8032-ring-instance-summary"):
                            for c in self.g8032_ring_instance_summary:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.g8032_ring_instance_summary.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "g8032-ring-instance-summary"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class G8032RingSummary(Entity):
                    """
                    G8032 Ring summary information
                    
                    .. attribute:: port0
                    
                    	Port 0
                    	**type**\:  str
                    
                    .. attribute:: port1
                    
                    	Port 1
                    	**type**\:  str
                    
                    .. attribute:: ring_name
                    
                    	Name of the ring
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__init__()

                        self.yang_name = "g8032-ring-summary"
                        self.yang_parent_name = "g8032-ring"

                        self.port0 = YLeaf(YType.str, "port0")

                        self.port1 = YLeaf(YType.str, "port1")

                        self.ring_name = YLeaf(YType.str, "ring-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("port0",
                                        "port1",
                                        "ring_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.port0.is_set or
                            self.port1.is_set or
                            self.ring_name.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.port0.yfilter != YFilter.not_set or
                            self.port1.yfilter != YFilter.not_set or
                            self.ring_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g8032-ring-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.port0.is_set or self.port0.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port0.get_name_leafdata())
                        if (self.port1.is_set or self.port1.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port1.get_name_leafdata())
                        if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ring_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "port0" or name == "port1" or name == "ring-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "port0"):
                            self.port0 = value
                            self.port0.value_namespace = name_space
                            self.port0.value_namespace_prefix = name_space_prefix
                        if(value_path == "port1"):
                            self.port1 = value
                            self.port1.value_namespace = name_space
                            self.port1.value_namespace_prefix = name_space_prefix
                        if(value_path == "ring-name"):
                            self.ring_name = value
                            self.ring_name.value_namespace = name_space
                            self.ring_name.value_namespace_prefix = name_space_prefix


                class G8032RingInstanceDetails(Entity):
                    """
                    G8032 Ring Instance detail table
                    
                    .. attribute:: g8032_ring_instance_detail
                    
                    	G8032 Ring Instance detailed information
                    	**type**\: list of    :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__init__()

                        self.yang_name = "g8032-ring-instance-details"
                        self.yang_parent_name = "g8032-ring"

                        self.g8032_ring_instance_detail = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__setattr__(name, value)


                    class G8032RingInstanceDetail(Entity):
                        """
                        G8032 Ring Instance detailed information
                        
                        .. attribute:: instance  <key>
                        
                        	Instance
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: aps_channel_level
                        
                        	APS channel level
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: aps_port0
                        
                        	Port 0 of aps\-channel
                        	**type**\:  str
                        
                        .. attribute:: aps_port1
                        
                        	Port 1 of aps\-channel
                        	**type**\:  str
                        
                        .. attribute:: config_state
                        
                        	State of the instance
                        	**type**\:  bool
                        
                        .. attribute:: included_vlan_id
                        
                        	Inclusion list Vlan Ids
                        	**type**\:  list of int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ring_description
                        
                        	Ring description
                        	**type**\:  str
                        
                        .. attribute:: ring_instance
                        
                        	Ring instance number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ring_profile
                        
                        	Ring Profile
                        	**type**\:  str
                        
                        .. attribute:: rpl
                        
                        	RPL
                        	**type**\:   :py:class:`L2VpnG8032Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032Rpl>`
                        
                        .. attribute:: unresolved_reason
                        
                        	Reason of unresolved state state
                        	**type**\:   :py:class:`L2VpnG8032UncfgReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032UncfgReason>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__init__()

                            self.yang_name = "g8032-ring-instance-detail"
                            self.yang_parent_name = "g8032-ring-instance-details"

                            self.instance = YLeaf(YType.int32, "instance")

                            self.aps_channel_level = YLeaf(YType.uint32, "aps-channel-level")

                            self.aps_port0 = YLeaf(YType.str, "aps-port0")

                            self.aps_port1 = YLeaf(YType.str, "aps-port1")

                            self.config_state = YLeaf(YType.boolean, "config-state")

                            self.included_vlan_id = YLeafList(YType.uint16, "included-vlan-id")

                            self.ring_description = YLeaf(YType.str, "ring-description")

                            self.ring_instance = YLeaf(YType.uint32, "ring-instance")

                            self.ring_profile = YLeaf(YType.str, "ring-profile")

                            self.rpl = YLeaf(YType.enumeration, "rpl")

                            self.unresolved_reason = YLeaf(YType.enumeration, "unresolved-reason")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("instance",
                                            "aps_channel_level",
                                            "aps_port0",
                                            "aps_port1",
                                            "config_state",
                                            "included_vlan_id",
                                            "ring_description",
                                            "ring_instance",
                                            "ring_profile",
                                            "rpl",
                                            "unresolved_reason") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.included_vlan_id.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return (
                                self.instance.is_set or
                                self.aps_channel_level.is_set or
                                self.aps_port0.is_set or
                                self.aps_port1.is_set or
                                self.config_state.is_set or
                                self.ring_description.is_set or
                                self.ring_instance.is_set or
                                self.ring_profile.is_set or
                                self.rpl.is_set or
                                self.unresolved_reason.is_set)

                        def has_operation(self):
                            for leaf in self.included_vlan_id.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.instance.yfilter != YFilter.not_set or
                                self.aps_channel_level.yfilter != YFilter.not_set or
                                self.aps_port0.yfilter != YFilter.not_set or
                                self.aps_port1.yfilter != YFilter.not_set or
                                self.config_state.yfilter != YFilter.not_set or
                                self.included_vlan_id.yfilter != YFilter.not_set or
                                self.ring_description.yfilter != YFilter.not_set or
                                self.ring_instance.yfilter != YFilter.not_set or
                                self.ring_profile.yfilter != YFilter.not_set or
                                self.rpl.yfilter != YFilter.not_set or
                                self.unresolved_reason.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "g8032-ring-instance-detail" + "[instance='" + self.instance.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.instance.is_set or self.instance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.instance.get_name_leafdata())
                            if (self.aps_channel_level.is_set or self.aps_channel_level.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.aps_channel_level.get_name_leafdata())
                            if (self.aps_port0.is_set or self.aps_port0.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.aps_port0.get_name_leafdata())
                            if (self.aps_port1.is_set or self.aps_port1.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.aps_port1.get_name_leafdata())
                            if (self.config_state.is_set or self.config_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.config_state.get_name_leafdata())
                            if (self.ring_description.is_set or self.ring_description.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ring_description.get_name_leafdata())
                            if (self.ring_instance.is_set or self.ring_instance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ring_instance.get_name_leafdata())
                            if (self.ring_profile.is_set or self.ring_profile.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ring_profile.get_name_leafdata())
                            if (self.rpl.is_set or self.rpl.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpl.get_name_leafdata())
                            if (self.unresolved_reason.is_set or self.unresolved_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unresolved_reason.get_name_leafdata())

                            leaf_name_data.extend(self.included_vlan_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "instance" or name == "aps-channel-level" or name == "aps-port0" or name == "aps-port1" or name == "config-state" or name == "included-vlan-id" or name == "ring-description" or name == "ring-instance" or name == "ring-profile" or name == "rpl" or name == "unresolved-reason"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "instance"):
                                self.instance = value
                                self.instance.value_namespace = name_space
                                self.instance.value_namespace_prefix = name_space_prefix
                            if(value_path == "aps-channel-level"):
                                self.aps_channel_level = value
                                self.aps_channel_level.value_namespace = name_space
                                self.aps_channel_level.value_namespace_prefix = name_space_prefix
                            if(value_path == "aps-port0"):
                                self.aps_port0 = value
                                self.aps_port0.value_namespace = name_space
                                self.aps_port0.value_namespace_prefix = name_space_prefix
                            if(value_path == "aps-port1"):
                                self.aps_port1 = value
                                self.aps_port1.value_namespace = name_space
                                self.aps_port1.value_namespace_prefix = name_space_prefix
                            if(value_path == "config-state"):
                                self.config_state = value
                                self.config_state.value_namespace = name_space
                                self.config_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "included-vlan-id"):
                                self.included_vlan_id.append(value)
                            if(value_path == "ring-description"):
                                self.ring_description = value
                                self.ring_description.value_namespace = name_space
                                self.ring_description.value_namespace_prefix = name_space_prefix
                            if(value_path == "ring-instance"):
                                self.ring_instance = value
                                self.ring_instance.value_namespace = name_space
                                self.ring_instance.value_namespace_prefix = name_space_prefix
                            if(value_path == "ring-profile"):
                                self.ring_profile = value
                                self.ring_profile.value_namespace = name_space
                                self.ring_profile.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpl"):
                                self.rpl = value
                                self.rpl.value_namespace = name_space
                                self.rpl.value_namespace_prefix = name_space_prefix
                            if(value_path == "unresolved-reason"):
                                self.unresolved_reason = value
                                self.unresolved_reason.value_namespace = name_space
                                self.unresolved_reason.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.g8032_ring_instance_detail:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.g8032_ring_instance_detail:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g8032-ring-instance-details" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "g8032-ring-instance-detail"):
                            for c in self.g8032_ring_instance_detail:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.g8032_ring_instance_detail.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "g8032-ring-instance-detail"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.ring_name.is_set or
                        (self.g8032_ring_detail is not None and self.g8032_ring_detail.has_data()) or
                        (self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details.has_data()) or
                        (self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries.has_data()) or
                        (self.g8032_ring_summary is not None and self.g8032_ring_summary.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ring_name.yfilter != YFilter.not_set or
                        (self.g8032_ring_detail is not None and self.g8032_ring_detail.has_operation()) or
                        (self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details.has_operation()) or
                        (self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries.has_operation()) or
                        (self.g8032_ring_summary is not None and self.g8032_ring_summary.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "g8032-ring" + "[ring-name='" + self.ring_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/g8032/g8032-rings/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ring_name.is_set or self.ring_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ring_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g8032-ring-detail"):
                        if (self.g8032_ring_detail is None):
                            self.g8032_ring_detail = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                            self.g8032_ring_detail.parent = self
                            self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"
                        return self.g8032_ring_detail

                    if (child_yang_name == "g8032-ring-instance-details"):
                        if (self.g8032_ring_instance_details is None):
                            self.g8032_ring_instance_details = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                            self.g8032_ring_instance_details.parent = self
                            self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                        return self.g8032_ring_instance_details

                    if (child_yang_name == "g8032-ring-instance-summaries"):
                        if (self.g8032_ring_instance_summaries is None):
                            self.g8032_ring_instance_summaries = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                            self.g8032_ring_instance_summaries.parent = self
                            self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"
                        return self.g8032_ring_instance_summaries

                    if (child_yang_name == "g8032-ring-summary"):
                        if (self.g8032_ring_summary is None):
                            self.g8032_ring_summary = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                            self.g8032_ring_summary.parent = self
                            self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"
                        return self.g8032_ring_summary

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g8032-ring-detail" or name == "g8032-ring-instance-details" or name == "g8032-ring-instance-summaries" or name == "g8032-ring-summary" or name == "ring-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ring-name"):
                        self.ring_name = value
                        self.ring_name.value_namespace = name_space
                        self.ring_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.g8032_ring:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.g8032_ring:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "g8032-rings" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/g8032/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "g8032-ring"):
                    for c in self.g8032_ring:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.G8032.G8032Rings.G8032Ring()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.g8032_ring.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "g8032-ring"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.g8032_rings is not None and self.g8032_rings.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.g8032_rings is not None and self.g8032_rings.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "g8032" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "g8032-rings"):
                if (self.g8032_rings is None):
                    self.g8032_rings = L2Vpn.G8032.G8032Rings()
                    self.g8032_rings.parent = self
                    self._children_name_map["g8032_rings"] = "g8032-rings"
                return self.g8032_rings

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "g8032-rings"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class PseudowireClasses(Entity):
        """
        List of pseudowire classes
        
        .. attribute:: pseudowire_class
        
        	Pseudowire class information
        	**type**\: list of    :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses.PseudowireClass>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.PseudowireClasses, self).__init__()

            self.yang_name = "pseudowire-classes"
            self.yang_parent_name = "l2vpn"

            self.pseudowire_class = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.PseudowireClasses, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.PseudowireClasses, self).__setattr__(name, value)


        class PseudowireClass(Entity):
            """
            Pseudowire class information
            
            .. attribute:: pseudowire_class_name  <key>
            
            	Pseudowire Class Name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: backup_mac_withdraw
            
            	TRUE if MAC withdraw message is sent
            	**type**\:  bool
            
            .. attribute:: control_word
            
            	Control word
            	**type**\:   :py:class:`L2VpnPwClassControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwClassControlWord>`
            
            .. attribute:: disable_delay
            
            	Disable Deley
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: disable_never
            
            	TRUE if backup is not automatically disabled
            	**type**\:  bool
            
            .. attribute:: encapsulation_info
            
            	Encapsulation specific pseudowire information
            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
            
            .. attribute:: is_flow_label_static
            
            	is flow label static
            	**type**\:  bool
            
            .. attribute:: load_balance
            
            	Load Balance Type
            	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
            
            .. attribute:: local_source_address
            
            	Local source address
            	**type**\:   :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
            
            .. attribute:: preferred_path
            
            	MPLS Preferred Path
            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses.PseudowireClass.PreferredPath>`
            
            .. attribute:: preferred_path_disable_fallback
            
            	PreferredPathDisableFallback
            	**type**\:  bool
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
            
            .. attribute:: pw_class_name
            
            	Pseudowire class name
            	**type**\:  str
            
            	**length:** 0..33
            
            .. attribute:: pw_flow_label_code17_disabled
            
            	Disable sending Code 17 TLV
            	**type**\:  bool
            
            .. attribute:: pw_flow_label_type_cfg
            
            	Configured pseudowire flow label type
            	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
            
            .. attribute:: resync_enabled
            
            	Resync if packets out of sequence
            	**type**\:  bool
            
            .. attribute:: resync_threshold
            
            	Number of Packets Out of Seqence to trigger resync
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: sequencing_type
            
            	Sequencing Type
            	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
            
            .. attribute:: tag_rewrite
            
            	Static tag rewrite
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: transport_mode
            
            	Transport mode
            	**type**\:   :py:class:`L2VpnTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTransportMode>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.PseudowireClasses.PseudowireClass, self).__init__()

                self.yang_name = "pseudowire-class"
                self.yang_parent_name = "pseudowire-classes"

                self.pseudowire_class_name = YLeaf(YType.str, "pseudowire-class-name")

                self.backup_mac_withdraw = YLeaf(YType.boolean, "backup-mac-withdraw")

                self.control_word = YLeaf(YType.enumeration, "control-word")

                self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                self.disable_never = YLeaf(YType.boolean, "disable-never")

                self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                self.load_balance = YLeaf(YType.enumeration, "load-balance")

                self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                self.protocol = YLeaf(YType.enumeration, "protocol")

                self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                self.transport_mode = YLeaf(YType.enumeration, "transport-mode")

                self.encapsulation_info = L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                self.encapsulation_info.parent = self
                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                self._children_yang_names.add("encapsulation-info")

                self.local_source_address = L2Vpn.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                self.local_source_address.parent = self
                self._children_name_map["local_source_address"] = "local-source-address"
                self._children_yang_names.add("local-source-address")

                self.preferred_path = L2Vpn.PseudowireClasses.PseudowireClass.PreferredPath()
                self.preferred_path.parent = self
                self._children_name_map["preferred_path"] = "preferred-path"
                self._children_yang_names.add("preferred-path")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("pseudowire_class_name",
                                "backup_mac_withdraw",
                                "control_word",
                                "disable_delay",
                                "disable_never",
                                "is_flow_label_static",
                                "load_balance",
                                "preferred_path_disable_fallback",
                                "protocol",
                                "pw_class_name",
                                "pw_flow_label_code17_disabled",
                                "pw_flow_label_type_cfg",
                                "resync_enabled",
                                "resync_threshold",
                                "sequencing_type",
                                "tag_rewrite",
                                "transport_mode") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.PseudowireClasses.PseudowireClass, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.PseudowireClasses.PseudowireClass, self).__setattr__(name, value)


            class EncapsulationInfo(Entity):
                """
                Encapsulation specific pseudowire information
                
                .. attribute:: encapsulation
                
                	Encapsulation
                	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                
                .. attribute:: l2tpv3
                
                	l2tpv3
                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__init__()

                    self.yang_name = "encapsulation-info"
                    self.yang_parent_name = "pseudowire-class"

                    self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                    self.l2tpv3 = L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                    self.l2tpv3.parent = self
                    self._children_name_map["l2tpv3"] = "l2tpv3"
                    self._children_yang_names.add("l2tpv3")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("encapsulation") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__setattr__(name, value)


                class L2Tpv3(Entity):
                    """
                    l2tpv3
                    
                    .. attribute:: cookie_size
                    
                    	Cookie size\: 0, 4, or 8 bytes
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: dont_fragment_bit
                    
                    	Don't Fragment Bit
                    	**type**\:  bool
                    
                    .. attribute:: ipv4_source_address
                    
                    	IPv4 source address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: l2tp_class_name
                    
                    	L2TPClassName
                    	**type**\:  str
                    
                    	**length:** 0..32
                    
                    .. attribute:: path_mtu_enabled
                    
                    	Path MTU enabled
                    	**type**\:  bool
                    
                    .. attribute:: path_mtu_max_value
                    
                    	Path MTU Maximum allowable session MTU
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tos
                    
                    	Type Of Service Value
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: tos_mode
                    
                    	Type Of Service Mode
                    	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                    
                    .. attribute:: ttl
                    
                    	Time To Live value
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__init__()

                        self.yang_name = "l2tpv3"
                        self.yang_parent_name = "encapsulation-info"

                        self.cookie_size = YLeaf(YType.uint8, "cookie-size")

                        self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                        self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                        self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                        self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                        self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                        self.tos = YLeaf(YType.uint8, "tos")

                        self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                        self.ttl = YLeaf(YType.uint8, "ttl")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("cookie_size",
                                        "dont_fragment_bit",
                                        "ipv4_source_address",
                                        "l2tp_class_name",
                                        "path_mtu_enabled",
                                        "path_mtu_max_value",
                                        "tos",
                                        "tos_mode",
                                        "ttl") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.cookie_size.is_set or
                            self.dont_fragment_bit.is_set or
                            self.ipv4_source_address.is_set or
                            self.l2tp_class_name.is_set or
                            self.path_mtu_enabled.is_set or
                            self.path_mtu_max_value.is_set or
                            self.tos.is_set or
                            self.tos_mode.is_set or
                            self.ttl.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.cookie_size.yfilter != YFilter.not_set or
                            self.dont_fragment_bit.yfilter != YFilter.not_set or
                            self.ipv4_source_address.yfilter != YFilter.not_set or
                            self.l2tp_class_name.yfilter != YFilter.not_set or
                            self.path_mtu_enabled.yfilter != YFilter.not_set or
                            self.path_mtu_max_value.yfilter != YFilter.not_set or
                            self.tos.yfilter != YFilter.not_set or
                            self.tos_mode.yfilter != YFilter.not_set or
                            self.ttl.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "l2tpv3" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.cookie_size.is_set or self.cookie_size.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cookie_size.get_name_leafdata())
                        if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                        if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                        if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                        if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                        if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                        if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tos.get_name_leafdata())
                        if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tos_mode.get_name_leafdata())
                        if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ttl.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "cookie-size" or name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "l2tp-class-name" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "tos" or name == "tos-mode" or name == "ttl"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "cookie-size"):
                            self.cookie_size = value
                            self.cookie_size.value_namespace = name_space
                            self.cookie_size.value_namespace_prefix = name_space_prefix
                        if(value_path == "dont-fragment-bit"):
                            self.dont_fragment_bit = value
                            self.dont_fragment_bit.value_namespace = name_space
                            self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4-source-address"):
                            self.ipv4_source_address = value
                            self.ipv4_source_address.value_namespace = name_space
                            self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "l2tp-class-name"):
                            self.l2tp_class_name = value
                            self.l2tp_class_name.value_namespace = name_space
                            self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-mtu-enabled"):
                            self.path_mtu_enabled = value
                            self.path_mtu_enabled.value_namespace = name_space
                            self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-mtu-max-value"):
                            self.path_mtu_max_value = value
                            self.path_mtu_max_value.value_namespace = name_space
                            self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                        if(value_path == "tos"):
                            self.tos = value
                            self.tos.value_namespace = name_space
                            self.tos.value_namespace_prefix = name_space_prefix
                        if(value_path == "tos-mode"):
                            self.tos_mode = value
                            self.tos_mode.value_namespace = name_space
                            self.tos_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "ttl"):
                            self.ttl = value
                            self.ttl.value_namespace = name_space
                            self.ttl.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.encapsulation.is_set or
                        (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.encapsulation.yfilter != YFilter.not_set or
                        (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "encapsulation-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.encapsulation.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "l2tpv3"):
                        if (self.l2tpv3 is None):
                            self.l2tpv3 = L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self
                            self._children_name_map["l2tpv3"] = "l2tpv3"
                        return self.l2tpv3

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "l2tpv3" or name == "encapsulation"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "encapsulation"):
                        self.encapsulation = value
                        self.encapsulation.value_namespace = name_space
                        self.encapsulation.value_namespace_prefix = name_space_prefix


            class PreferredPath(Entity):
                """
                MPLS Preferred Path
                
                .. attribute:: ip_tunnel_interface_number
                
                	IPTunnelInterfaceNumber
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: next_hop_ip
                
                	NextHopIP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: option
                
                	Option
                	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                
                .. attribute:: te_tunnel_interface_number
                
                	TETunnelInterfaceNumber
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tp_tunnel_interface_number
                
                	TPTunnelInterfaceNumber
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.PseudowireClasses.PseudowireClass.PreferredPath, self).__init__()

                    self.yang_name = "preferred-path"
                    self.yang_parent_name = "pseudowire-class"

                    self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                    self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                    self.option = YLeaf(YType.enumeration, "option")

                    self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                    self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ip_tunnel_interface_number",
                                    "next_hop_ip",
                                    "option",
                                    "te_tunnel_interface_number",
                                    "tp_tunnel_interface_number") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.PseudowireClasses.PseudowireClass.PreferredPath, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.PseudowireClasses.PseudowireClass.PreferredPath, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ip_tunnel_interface_number.is_set or
                        self.next_hop_ip.is_set or
                        self.option.is_set or
                        self.te_tunnel_interface_number.is_set or
                        self.tp_tunnel_interface_number.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                        self.next_hop_ip.yfilter != YFilter.not_set or
                        self.option.yfilter != YFilter.not_set or
                        self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                        self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "preferred-path" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                    if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                    if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.option.get_name_leafdata())
                    if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                    if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ip-tunnel-interface-number"):
                        self.ip_tunnel_interface_number = value
                        self.ip_tunnel_interface_number.value_namespace = name_space
                        self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                    if(value_path == "next-hop-ip"):
                        self.next_hop_ip = value
                        self.next_hop_ip.value_namespace = name_space
                        self.next_hop_ip.value_namespace_prefix = name_space_prefix
                    if(value_path == "option"):
                        self.option = value
                        self.option.value_namespace = name_space
                        self.option.value_namespace_prefix = name_space_prefix
                    if(value_path == "te-tunnel-interface-number"):
                        self.te_tunnel_interface_number = value
                        self.te_tunnel_interface_number.value_namespace = name_space
                        self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                    if(value_path == "tp-tunnel-interface-number"):
                        self.tp_tunnel_interface_number = value
                        self.tp_tunnel_interface_number.value_namespace = name_space
                        self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


            class LocalSourceAddress(Entity):
                """
                Local source address
                
                .. attribute:: address
                
                	Local source address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: configuration
                
                	Configuration
                	**type**\:   :py:class:`L2VpnSrcAddressSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSrcAddressSet>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__init__()

                    self.yang_name = "local-source-address"
                    self.yang_parent_name = "pseudowire-class"

                    self.address = YLeaf(YType.str, "address")

                    self.configuration = YLeaf(YType.enumeration, "configuration")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("address",
                                    "configuration") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.address.is_set or
                        self.configuration.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.address.yfilter != YFilter.not_set or
                        self.configuration.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "local-source-address" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.address.get_name_leafdata())
                    if (self.configuration.is_set or self.configuration.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configuration.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "address" or name == "configuration"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "address"):
                        self.address = value
                        self.address.value_namespace = name_space
                        self.address.value_namespace_prefix = name_space_prefix
                    if(value_path == "configuration"):
                        self.configuration = value
                        self.configuration.value_namespace = name_space
                        self.configuration.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.pseudowire_class_name.is_set or
                    self.backup_mac_withdraw.is_set or
                    self.control_word.is_set or
                    self.disable_delay.is_set or
                    self.disable_never.is_set or
                    self.is_flow_label_static.is_set or
                    self.load_balance.is_set or
                    self.preferred_path_disable_fallback.is_set or
                    self.protocol.is_set or
                    self.pw_class_name.is_set or
                    self.pw_flow_label_code17_disabled.is_set or
                    self.pw_flow_label_type_cfg.is_set or
                    self.resync_enabled.is_set or
                    self.resync_threshold.is_set or
                    self.sequencing_type.is_set or
                    self.tag_rewrite.is_set or
                    self.transport_mode.is_set or
                    (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                    (self.local_source_address is not None and self.local_source_address.has_data()) or
                    (self.preferred_path is not None and self.preferred_path.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.pseudowire_class_name.yfilter != YFilter.not_set or
                    self.backup_mac_withdraw.yfilter != YFilter.not_set or
                    self.control_word.yfilter != YFilter.not_set or
                    self.disable_delay.yfilter != YFilter.not_set or
                    self.disable_never.yfilter != YFilter.not_set or
                    self.is_flow_label_static.yfilter != YFilter.not_set or
                    self.load_balance.yfilter != YFilter.not_set or
                    self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.pw_class_name.yfilter != YFilter.not_set or
                    self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                    self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                    self.resync_enabled.yfilter != YFilter.not_set or
                    self.resync_threshold.yfilter != YFilter.not_set or
                    self.sequencing_type.yfilter != YFilter.not_set or
                    self.tag_rewrite.yfilter != YFilter.not_set or
                    self.transport_mode.yfilter != YFilter.not_set or
                    (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                    (self.local_source_address is not None and self.local_source_address.has_operation()) or
                    (self.preferred_path is not None and self.preferred_path.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "pseudowire-class" + "[pseudowire-class-name='" + self.pseudowire_class_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/pseudowire-classes/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.pseudowire_class_name.is_set or self.pseudowire_class_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pseudowire_class_name.get_name_leafdata())
                if (self.backup_mac_withdraw.is_set or self.backup_mac_withdraw.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.backup_mac_withdraw.get_name_leafdata())
                if (self.control_word.is_set or self.control_word.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.control_word.get_name_leafdata())
                if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.disable_delay.get_name_leafdata())
                if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.disable_never.get_name_leafdata())
                if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.load_balance.get_name_leafdata())
                if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                if (self.transport_mode.is_set or self.transport_mode.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.transport_mode.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "encapsulation-info"):
                    if (self.encapsulation_info is None):
                        self.encapsulation_info = L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                    return self.encapsulation_info

                if (child_yang_name == "local-source-address"):
                    if (self.local_source_address is None):
                        self.local_source_address = L2Vpn.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                        self.local_source_address.parent = self
                        self._children_name_map["local_source_address"] = "local-source-address"
                    return self.local_source_address

                if (child_yang_name == "preferred-path"):
                    if (self.preferred_path is None):
                        self.preferred_path = L2Vpn.PseudowireClasses.PseudowireClass.PreferredPath()
                        self.preferred_path.parent = self
                        self._children_name_map["preferred_path"] = "preferred-path"
                    return self.preferred_path

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "encapsulation-info" or name == "local-source-address" or name == "preferred-path" or name == "pseudowire-class-name" or name == "backup-mac-withdraw" or name == "control-word" or name == "disable-delay" or name == "disable-never" or name == "is-flow-label-static" or name == "load-balance" or name == "preferred-path-disable-fallback" or name == "protocol" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type-cfg" or name == "resync-enabled" or name == "resync-threshold" or name == "sequencing-type" or name == "tag-rewrite" or name == "transport-mode"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "pseudowire-class-name"):
                    self.pseudowire_class_name = value
                    self.pseudowire_class_name.value_namespace = name_space
                    self.pseudowire_class_name.value_namespace_prefix = name_space_prefix
                if(value_path == "backup-mac-withdraw"):
                    self.backup_mac_withdraw = value
                    self.backup_mac_withdraw.value_namespace = name_space
                    self.backup_mac_withdraw.value_namespace_prefix = name_space_prefix
                if(value_path == "control-word"):
                    self.control_word = value
                    self.control_word.value_namespace = name_space
                    self.control_word.value_namespace_prefix = name_space_prefix
                if(value_path == "disable-delay"):
                    self.disable_delay = value
                    self.disable_delay.value_namespace = name_space
                    self.disable_delay.value_namespace_prefix = name_space_prefix
                if(value_path == "disable-never"):
                    self.disable_never = value
                    self.disable_never.value_namespace = name_space
                    self.disable_never.value_namespace_prefix = name_space_prefix
                if(value_path == "is-flow-label-static"):
                    self.is_flow_label_static = value
                    self.is_flow_label_static.value_namespace = name_space
                    self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                if(value_path == "load-balance"):
                    self.load_balance = value
                    self.load_balance.value_namespace = name_space
                    self.load_balance.value_namespace_prefix = name_space_prefix
                if(value_path == "preferred-path-disable-fallback"):
                    self.preferred_path_disable_fallback = value
                    self.preferred_path_disable_fallback.value_namespace = name_space
                    self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "pw-class-name"):
                    self.pw_class_name = value
                    self.pw_class_name.value_namespace = name_space
                    self.pw_class_name.value_namespace_prefix = name_space_prefix
                if(value_path == "pw-flow-label-code17-disabled"):
                    self.pw_flow_label_code17_disabled = value
                    self.pw_flow_label_code17_disabled.value_namespace = name_space
                    self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                if(value_path == "pw-flow-label-type-cfg"):
                    self.pw_flow_label_type_cfg = value
                    self.pw_flow_label_type_cfg.value_namespace = name_space
                    self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                if(value_path == "resync-enabled"):
                    self.resync_enabled = value
                    self.resync_enabled.value_namespace = name_space
                    self.resync_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "resync-threshold"):
                    self.resync_threshold = value
                    self.resync_threshold.value_namespace = name_space
                    self.resync_threshold.value_namespace_prefix = name_space_prefix
                if(value_path == "sequencing-type"):
                    self.sequencing_type = value
                    self.sequencing_type.value_namespace = name_space
                    self.sequencing_type.value_namespace_prefix = name_space_prefix
                if(value_path == "tag-rewrite"):
                    self.tag_rewrite = value
                    self.tag_rewrite.value_namespace = name_space
                    self.tag_rewrite.value_namespace_prefix = name_space_prefix
                if(value_path == "transport-mode"):
                    self.transport_mode = value
                    self.transport_mode.value_namespace = name_space
                    self.transport_mode.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.pseudowire_class:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.pseudowire_class:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "pseudowire-classes" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "pseudowire-class"):
                for c in self.pseudowire_class:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.PseudowireClasses.PseudowireClass()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.pseudowire_class.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "pseudowire-class"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class L2VpnCollaborators(Entity):
        """
        L2VPN collaborator information
        
        .. attribute:: collaborator_statistics
        
        	Collaborator Statistics
        	**type**\:   :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.L2VpnCollaborators.CollaboratorStatistics>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.L2VpnCollaborators, self).__init__()

            self.yang_name = "l2vpn-collaborators"
            self.yang_parent_name = "l2vpn"

            self.collaborator_statistics = L2Vpn.L2VpnCollaborators.CollaboratorStatistics()
            self.collaborator_statistics.parent = self
            self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
            self._children_yang_names.add("collaborator-statistics")


        class CollaboratorStatistics(Entity):
            """
            Collaborator Statistics
            
            .. attribute:: count
            
            	count
            	**type**\: list of    :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.L2VpnCollaborators.CollaboratorStatistics.Count>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.L2VpnCollaborators.CollaboratorStatistics, self).__init__()

                self.yang_name = "collaborator-statistics"
                self.yang_parent_name = "l2vpn-collaborators"

                self.count = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.L2VpnCollaborators.CollaboratorStatistics, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.L2VpnCollaborators.CollaboratorStatistics, self).__setattr__(name, value)


            class Count(Entity):
                """
                count
                
                .. attribute:: collaborator_name
                
                	Collaborator Name
                	**type**\:  str
                
                .. attribute:: down
                
                	Down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_up
                
                	Is up
                	**type**\:  bool
                
                .. attribute:: up
                
                	Up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.L2VpnCollaborators.CollaboratorStatistics.Count, self).__init__()

                    self.yang_name = "count"
                    self.yang_parent_name = "collaborator-statistics"

                    self.collaborator_name = YLeaf(YType.str, "collaborator-name")

                    self.down = YLeaf(YType.uint32, "down")

                    self.is_up = YLeaf(YType.boolean, "is-up")

                    self.up = YLeaf(YType.uint32, "up")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("collaborator_name",
                                    "down",
                                    "is_up",
                                    "up") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.L2VpnCollaborators.CollaboratorStatistics.Count, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.L2VpnCollaborators.CollaboratorStatistics.Count, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.collaborator_name.is_set or
                        self.down.is_set or
                        self.is_up.is_set or
                        self.up.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.collaborator_name.yfilter != YFilter.not_set or
                        self.down.yfilter != YFilter.not_set or
                        self.is_up.yfilter != YFilter.not_set or
                        self.up.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "count" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/l2vpn-collaborators/collaborator-statistics/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.collaborator_name.is_set or self.collaborator_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collaborator_name.get_name_leafdata())
                    if (self.down.is_set or self.down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.down.get_name_leafdata())
                    if (self.is_up.is_set or self.is_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_up.get_name_leafdata())
                    if (self.up.is_set or self.up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.up.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "collaborator-name" or name == "down" or name == "is-up" or name == "up"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "collaborator-name"):
                        self.collaborator_name = value
                        self.collaborator_name.value_namespace = name_space
                        self.collaborator_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "down"):
                        self.down = value
                        self.down.value_namespace = name_space
                        self.down.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-up"):
                        self.is_up = value
                        self.is_up.value_namespace = name_space
                        self.is_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "up"):
                        self.up = value
                        self.up.value_namespace = name_space
                        self.up.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.count:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.count:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "collaborator-statistics" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/l2vpn-collaborators/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "count"):
                    for c in self.count:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.L2VpnCollaborators.CollaboratorStatistics.Count()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.count.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "count"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.collaborator_statistics is not None and self.collaborator_statistics.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.collaborator_statistics is not None and self.collaborator_statistics.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "l2vpn-collaborators" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "collaborator-statistics"):
                if (self.collaborator_statistics is None):
                    self.collaborator_statistics = L2Vpn.L2VpnCollaborators.CollaboratorStatistics()
                    self.collaborator_statistics.parent = self
                    self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
                return self.collaborator_statistics

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "collaborator-statistics"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Mvrp(Entity):
        """
        MVRP
        
        .. attribute:: mvrp_main_ports
        
        	MVRP Main Port Table
        	**type**\:   :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.Mvrp, self).__init__()

            self.yang_name = "mvrp"
            self.yang_parent_name = "l2vpn"

            self.mvrp_main_ports = L2Vpn.Mvrp.MvrpMainPorts()
            self.mvrp_main_ports.parent = self
            self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
            self._children_yang_names.add("mvrp-main-ports")


        class MvrpMainPorts(Entity):
            """
            MVRP Main Port Table
            
            .. attribute:: mvrp_main_port
            
            	MVRP Main Port
            	**type**\: list of    :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.Mvrp.MvrpMainPorts, self).__init__()

                self.yang_name = "mvrp-main-ports"
                self.yang_parent_name = "mvrp"

                self.mvrp_main_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.Mvrp.MvrpMainPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.Mvrp.MvrpMainPorts, self).__setattr__(name, value)


            class MvrpMainPort(Entity):
                """
                MVRP Main Port
                
                .. attribute:: main_port_interface_name  <key>
                
                	Main Port interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mvrp_bridge_ports
                
                	MVRP Bridge Port Table
                	**type**\:   :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                
                .. attribute:: mvrp_main_port_info
                
                	MVRP Main Port Information
                	**type**\:   :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort, self).__init__()

                    self.yang_name = "mvrp-main-port"
                    self.yang_parent_name = "mvrp-main-ports"

                    self.main_port_interface_name = YLeaf(YType.str, "main-port-interface-name")

                    self.mvrp_bridge_ports = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                    self.mvrp_bridge_ports.parent = self
                    self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                    self._children_yang_names.add("mvrp-bridge-ports")

                    self.mvrp_main_port_info = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                    self.mvrp_main_port_info.parent = self
                    self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"
                    self._children_yang_names.add("mvrp-main-port-info")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("main_port_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort, self).__setattr__(name, value)


                class MvrpMainPortInfo(Entity):
                    """
                    MVRP Main Port Information
                    
                    .. attribute:: default_bridge_port
                    
                    	Trunk or default Bridge Port
                    	**type**\:   :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                    
                    .. attribute:: is_default_encap
                    
                    	Is default encap set
                    	**type**\:  bool
                    
                    .. attribute:: is_trunk
                    
                    	Is main port a trunk
                    	**type**\:  bool
                    
                    .. attribute:: main_port_interface_name
                    
                    	Main Port Interface name
                    	**type**\:  str
                    
                    .. attribute:: number_of_bridge_ports
                    
                    	Number of Bridge Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__init__()

                        self.yang_name = "mvrp-main-port-info"
                        self.yang_parent_name = "mvrp-main-port"

                        self.is_default_encap = YLeaf(YType.boolean, "is-default-encap")

                        self.is_trunk = YLeaf(YType.boolean, "is-trunk")

                        self.main_port_interface_name = YLeaf(YType.str, "main-port-interface-name")

                        self.number_of_bridge_ports = YLeaf(YType.uint32, "number-of-bridge-ports")

                        self.default_bridge_port = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                        self.default_bridge_port.parent = self
                        self._children_name_map["default_bridge_port"] = "default-bridge-port"
                        self._children_yang_names.add("default-bridge-port")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_default_encap",
                                        "is_trunk",
                                        "main_port_interface_name",
                                        "number_of_bridge_ports") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__setattr__(name, value)


                    class DefaultBridgePort(Entity):
                        """
                        Trunk or default Bridge Port
                        
                        .. attribute:: bridge_port_interface_name
                        
                        	Bridge port Interface name
                        	**type**\:  str
                        
                        .. attribute:: bridge_port_xconnect_id
                        
                        	Bridge port XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mvrp_sequence_number
                        
                        	MVRP Sequence Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan_range
                        
                        	VLAN IDs
                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__init__()

                            self.yang_name = "default-bridge-port"
                            self.yang_parent_name = "mvrp-main-port-info"

                            self.bridge_port_interface_name = YLeaf(YType.str, "bridge-port-interface-name")

                            self.bridge_port_xconnect_id = YLeaf(YType.uint32, "bridge-port-xconnect-id")

                            self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                            self.vlan_range = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bridge_port_interface_name",
                                            "bridge_port_xconnect_id",
                                            "mvrp_sequence_number") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__setattr__(name, value)


                        class VlanRange(Entity):
                            """
                            VLAN IDs
                            
                            .. attribute:: lower
                            
                            	Lower
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: upper
                            
                            	Upper
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__init__()

                                self.yang_name = "vlan-range"
                                self.yang_parent_name = "default-bridge-port"

                                self.lower = YLeaf(YType.uint16, "lower")

                                self.upper = YLeaf(YType.uint16, "upper")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("lower",
                                                "upper") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.lower.is_set or
                                    self.upper.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.lower.yfilter != YFilter.not_set or
                                    self.upper.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vlan-range" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lower" or name == "upper"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "lower"):
                                    self.lower = value
                                    self.lower.value_namespace = name_space
                                    self.lower.value_namespace_prefix = name_space_prefix
                                if(value_path == "upper"):
                                    self.upper = value
                                    self.upper.value_namespace = name_space
                                    self.upper.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.vlan_range:
                                if (c.has_data()):
                                    return True
                            return (
                                self.bridge_port_interface_name.is_set or
                                self.bridge_port_xconnect_id.is_set or
                                self.mvrp_sequence_number.is_set)

                        def has_operation(self):
                            for c in self.vlan_range:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bridge_port_interface_name.yfilter != YFilter.not_set or
                                self.bridge_port_xconnect_id.yfilter != YFilter.not_set or
                                self.mvrp_sequence_number.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "default-bridge-port" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bridge_port_interface_name.is_set or self.bridge_port_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_port_interface_name.get_name_leafdata())
                            if (self.bridge_port_xconnect_id.is_set or self.bridge_port_xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_port_xconnect_id.get_name_leafdata())
                            if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vlan-range"):
                                for c in self.vlan_range:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.vlan_range.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vlan-range" or name == "bridge-port-interface-name" or name == "bridge-port-xconnect-id" or name == "mvrp-sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bridge-port-interface-name"):
                                self.bridge_port_interface_name = value
                                self.bridge_port_interface_name.value_namespace = name_space
                                self.bridge_port_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-port-xconnect-id"):
                                self.bridge_port_xconnect_id = value
                                self.bridge_port_xconnect_id.value_namespace = name_space
                                self.bridge_port_xconnect_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvrp-sequence-number"):
                                self.mvrp_sequence_number = value
                                self.mvrp_sequence_number.value_namespace = name_space
                                self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.is_default_encap.is_set or
                            self.is_trunk.is_set or
                            self.main_port_interface_name.is_set or
                            self.number_of_bridge_ports.is_set or
                            (self.default_bridge_port is not None and self.default_bridge_port.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_default_encap.yfilter != YFilter.not_set or
                            self.is_trunk.yfilter != YFilter.not_set or
                            self.main_port_interface_name.yfilter != YFilter.not_set or
                            self.number_of_bridge_ports.yfilter != YFilter.not_set or
                            (self.default_bridge_port is not None and self.default_bridge_port.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mvrp-main-port-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_default_encap.is_set or self.is_default_encap.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_default_encap.get_name_leafdata())
                        if (self.is_trunk.is_set or self.is_trunk.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_trunk.get_name_leafdata())
                        if (self.main_port_interface_name.is_set or self.main_port_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.main_port_interface_name.get_name_leafdata())
                        if (self.number_of_bridge_ports.is_set or self.number_of_bridge_ports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_bridge_ports.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "default-bridge-port"):
                            if (self.default_bridge_port is None):
                                self.default_bridge_port = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                                self.default_bridge_port.parent = self
                                self._children_name_map["default_bridge_port"] = "default-bridge-port"
                            return self.default_bridge_port

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-bridge-port" or name == "is-default-encap" or name == "is-trunk" or name == "main-port-interface-name" or name == "number-of-bridge-ports"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-default-encap"):
                            self.is_default_encap = value
                            self.is_default_encap.value_namespace = name_space
                            self.is_default_encap.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-trunk"):
                            self.is_trunk = value
                            self.is_trunk.value_namespace = name_space
                            self.is_trunk.value_namespace_prefix = name_space_prefix
                        if(value_path == "main-port-interface-name"):
                            self.main_port_interface_name = value
                            self.main_port_interface_name.value_namespace = name_space
                            self.main_port_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-bridge-ports"):
                            self.number_of_bridge_ports = value
                            self.number_of_bridge_ports.value_namespace = name_space
                            self.number_of_bridge_ports.value_namespace_prefix = name_space_prefix


                class MvrpBridgePorts(Entity):
                    """
                    MVRP Bridge Port Table
                    
                    .. attribute:: mvrp_bridge_port
                    
                    	MVRP Bridge Port Information
                    	**type**\: list of    :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__init__()

                        self.yang_name = "mvrp-bridge-ports"
                        self.yang_parent_name = "mvrp-main-port"

                        self.mvrp_bridge_port = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__setattr__(name, value)


                    class MvrpBridgePort(Entity):
                        """
                        MVRP Bridge Port Information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Bridge Port Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: bridge_port_interface_name
                        
                        	Bridge port Interface name
                        	**type**\:  str
                        
                        .. attribute:: bridge_port_xconnect_id
                        
                        	Bridge port XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mvrp_sequence_number
                        
                        	MVRP Sequence Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan_range
                        
                        	VLAN IDs
                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__init__()

                            self.yang_name = "mvrp-bridge-port"
                            self.yang_parent_name = "mvrp-bridge-ports"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.bridge_port_interface_name = YLeaf(YType.str, "bridge-port-interface-name")

                            self.bridge_port_xconnect_id = YLeaf(YType.uint32, "bridge-port-xconnect-id")

                            self.mvrp_sequence_number = YLeaf(YType.uint16, "mvrp-sequence-number")

                            self.vlan_range = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "bridge_port_interface_name",
                                            "bridge_port_xconnect_id",
                                            "mvrp_sequence_number") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__setattr__(name, value)


                        class VlanRange(Entity):
                            """
                            VLAN IDs
                            
                            .. attribute:: lower
                            
                            	Lower
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: upper
                            
                            	Upper
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__init__()

                                self.yang_name = "vlan-range"
                                self.yang_parent_name = "mvrp-bridge-port"

                                self.lower = YLeaf(YType.uint16, "lower")

                                self.upper = YLeaf(YType.uint16, "upper")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("lower",
                                                "upper") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.lower.is_set or
                                    self.upper.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.lower.yfilter != YFilter.not_set or
                                    self.upper.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "vlan-range" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lower.get_name_leafdata())
                                if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.upper.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lower" or name == "upper"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "lower"):
                                    self.lower = value
                                    self.lower.value_namespace = name_space
                                    self.lower.value_namespace_prefix = name_space_prefix
                                if(value_path == "upper"):
                                    self.upper = value
                                    self.upper.value_namespace = name_space
                                    self.upper.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.vlan_range:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.bridge_port_interface_name.is_set or
                                self.bridge_port_xconnect_id.is_set or
                                self.mvrp_sequence_number.is_set)

                        def has_operation(self):
                            for c in self.vlan_range:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.bridge_port_interface_name.yfilter != YFilter.not_set or
                                self.bridge_port_xconnect_id.yfilter != YFilter.not_set or
                                self.mvrp_sequence_number.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mvrp-bridge-port" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.bridge_port_interface_name.is_set or self.bridge_port_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_port_interface_name.get_name_leafdata())
                            if (self.bridge_port_xconnect_id.is_set or self.bridge_port_xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bridge_port_xconnect_id.get_name_leafdata())
                            if (self.mvrp_sequence_number.is_set or self.mvrp_sequence_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvrp_sequence_number.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "vlan-range"):
                                for c in self.vlan_range:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.vlan_range.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "vlan-range" or name == "interface-name" or name == "bridge-port-interface-name" or name == "bridge-port-xconnect-id" or name == "mvrp-sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-port-interface-name"):
                                self.bridge_port_interface_name = value
                                self.bridge_port_interface_name.value_namespace = name_space
                                self.bridge_port_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "bridge-port-xconnect-id"):
                                self.bridge_port_xconnect_id = value
                                self.bridge_port_xconnect_id.value_namespace = name_space
                                self.bridge_port_xconnect_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvrp-sequence-number"):
                                self.mvrp_sequence_number = value
                                self.mvrp_sequence_number.value_namespace = name_space
                                self.mvrp_sequence_number.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.mvrp_bridge_port:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.mvrp_bridge_port:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mvrp-bridge-ports" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mvrp-bridge-port"):
                            for c in self.mvrp_bridge_port:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mvrp_bridge_port.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mvrp-bridge-port"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.main_port_interface_name.is_set or
                        (self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports.has_data()) or
                        (self.mvrp_main_port_info is not None and self.mvrp_main_port_info.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.main_port_interface_name.yfilter != YFilter.not_set or
                        (self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports.has_operation()) or
                        (self.mvrp_main_port_info is not None and self.mvrp_main_port_info.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mvrp-main-port" + "[main-port-interface-name='" + self.main_port_interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/mvrp/mvrp-main-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.main_port_interface_name.is_set or self.main_port_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.main_port_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mvrp-bridge-ports"):
                        if (self.mvrp_bridge_ports is None):
                            self.mvrp_bridge_ports = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                            self.mvrp_bridge_ports.parent = self
                            self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                        return self.mvrp_bridge_ports

                    if (child_yang_name == "mvrp-main-port-info"):
                        if (self.mvrp_main_port_info is None):
                            self.mvrp_main_port_info = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                            self.mvrp_main_port_info.parent = self
                            self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"
                        return self.mvrp_main_port_info

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mvrp-bridge-ports" or name == "mvrp-main-port-info" or name == "main-port-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "main-port-interface-name"):
                        self.main_port_interface_name = value
                        self.main_port_interface_name.value_namespace = name_space
                        self.main_port_interface_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.mvrp_main_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.mvrp_main_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mvrp-main-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/mvrp/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mvrp-main-port"):
                    for c in self.mvrp_main_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.mvrp_main_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mvrp-main-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.mvrp_main_ports is not None and self.mvrp_main_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.mvrp_main_ports is not None and self.mvrp_main_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "mvrp" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "mvrp-main-ports"):
                if (self.mvrp_main_ports is None):
                    self.mvrp_main_ports = L2Vpn.Mvrp.MvrpMainPorts()
                    self.mvrp_main_ports.parent = self
                    self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
                return self.mvrp_main_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "mvrp-main-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class GenericInterfaces(Entity):
        """
        L2VPN generic interface list Table
        
        .. attribute:: generic_interface
        
        	Generic Interface List information
        	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaces.GenericInterface>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.GenericInterfaces, self).__init__()

            self.yang_name = "generic-interfaces"
            self.yang_parent_name = "l2vpn"

            self.generic_interface = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.GenericInterfaces, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.GenericInterfaces, self).__setattr__(name, value)


        class GenericInterface(Entity):
            """
            Generic Interface List information
            
            .. attribute:: interface_list_name  <key>
            
            	Generic Interface List Name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: interface
            
            	Interfaces
            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaces.GenericInterface.Interface>`
            
            .. attribute:: interface_list_id
            
            	Interface internal ID
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interface_list_name_xr
            
            	Interface\-list name
            	**type**\:  str
            
            	**length:** 0..33
            
            .. attribute:: items
            
            	Number of items
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_of_interfaces
            
            	Number of interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.GenericInterfaces.GenericInterface, self).__init__()

                self.yang_name = "generic-interface"
                self.yang_parent_name = "generic-interfaces"

                self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                self.interface_list_name_xr = YLeaf(YType.str, "interface-list-name-xr")

                self.items = YLeaf(YType.uint32, "items")

                self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                self.interface = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("interface_list_name",
                                "interface_list_id",
                                "interface_list_name_xr",
                                "items",
                                "number_of_interfaces") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.GenericInterfaces.GenericInterface, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.GenericInterfaces.GenericInterface, self).__setattr__(name, value)


            class Interface(Entity):
                """
                Interfaces
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\:  str
                
                .. attribute:: is_fib_downloaded
                
                	Is interface downloaded to FIB
                	**type**\:  bool
                
                .. attribute:: not_supported_replications
                
                	Number of replications failed because unsupported
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pending_replications
                
                	Number of pending replications
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.GenericInterfaces.GenericInterface.Interface, self).__init__()

                    self.yang_name = "interface"
                    self.yang_parent_name = "generic-interface"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                    self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                    self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "is_fib_downloaded",
                                    "not_supported_replications",
                                    "pending_replications") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.is_fib_downloaded.is_set or
                        self.not_supported_replications.is_set or
                        self.pending_replications.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.is_fib_downloaded.yfilter != YFilter.not_set or
                        self.not_supported_replications.yfilter != YFilter.not_set or
                        self.pending_replications.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                    if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                    if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pending_replications.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-fib-downloaded"):
                        self.is_fib_downloaded = value
                        self.is_fib_downloaded.value_namespace = name_space
                        self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-supported-replications"):
                        self.not_supported_replications = value
                        self.not_supported_replications.value_namespace = name_space
                        self.not_supported_replications.value_namespace_prefix = name_space_prefix
                    if(value_path == "pending-replications"):
                        self.pending_replications = value
                        self.pending_replications.value_namespace = name_space
                        self.pending_replications.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface:
                    if (c.has_data()):
                        return True
                return (
                    self.interface_list_name.is_set or
                    self.interface_list_id.is_set or
                    self.interface_list_name_xr.is_set or
                    self.items.is_set or
                    self.number_of_interfaces.is_set)

            def has_operation(self):
                for c in self.interface:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.interface_list_name.yfilter != YFilter.not_set or
                    self.interface_list_id.yfilter != YFilter.not_set or
                    self.interface_list_name_xr.yfilter != YFilter.not_set or
                    self.items.yfilter != YFilter.not_set or
                    self.number_of_interfaces.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "generic-interface" + "[interface-list-name='" + self.interface_list_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/generic-interfaces/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                if (self.interface_list_name_xr.is_set or self.interface_list_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_list_name_xr.get_name_leafdata())
                if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.items.get_name_leafdata())
                if (self.number_of_interfaces.is_set or self.number_of_interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.number_of_interfaces.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface"):
                    for c in self.interface:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.GenericInterfaces.GenericInterface.Interface()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface" or name == "interface-list-name" or name == "interface-list-id" or name == "interface-list-name-xr" or name == "items" or name == "number-of-interfaces"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "interface-list-name"):
                    self.interface_list_name = value
                    self.interface_list_name.value_namespace = name_space
                    self.interface_list_name.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-list-id"):
                    self.interface_list_id = value
                    self.interface_list_id.value_namespace = name_space
                    self.interface_list_id.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-list-name-xr"):
                    self.interface_list_name_xr = value
                    self.interface_list_name_xr.value_namespace = name_space
                    self.interface_list_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "items"):
                    self.items = value
                    self.items.value_namespace = name_space
                    self.items.value_namespace_prefix = name_space_prefix
                if(value_path == "number-of-interfaces"):
                    self.number_of_interfaces = value
                    self.number_of_interfaces.value_namespace = name_space
                    self.number_of_interfaces.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.generic_interface:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.generic_interface:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "generic-interfaces" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "generic-interface"):
                for c in self.generic_interface:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.GenericInterfaces.GenericInterface()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.generic_interface.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "generic-interface"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class MstpVlans(Entity):
        """
        L2VPN MSTP VLAN Table
        
        .. attribute:: mstp_vlan
        
        	L2VPN MSTP VLAN information
        	**type**\: list of    :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpVlans.MstpVlan>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.MstpVlans, self).__init__()

            self.yang_name = "mstp-vlans"
            self.yang_parent_name = "l2vpn"

            self.mstp_vlan = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.MstpVlans, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.MstpVlans, self).__setattr__(name, value)


        class MstpVlan(Entity):
            """
            L2VPN MSTP VLAN information
            
            .. attribute:: vlan_id  <key>
            
            	vlan id
            	**type**\:  int
            
            	**range:** 0..4098
            
            .. attribute:: msti_id
            
            	MSTI id
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: port_count
            
            	Port Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: sub_interface
            
            	Sub interfaces
            	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpVlans.MstpVlan.SubInterface>`
            
            .. attribute:: vlan_id_xr
            
            	Vlan id
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.MstpVlans.MstpVlan, self).__init__()

                self.yang_name = "mstp-vlan"
                self.yang_parent_name = "mstp-vlans"

                self.vlan_id = YLeaf(YType.uint32, "vlan-id")

                self.msti_id = YLeaf(YType.uint32, "msti-id")

                self.port_count = YLeaf(YType.uint32, "port-count")

                self.vlan_id_xr = YLeaf(YType.uint32, "vlan-id-xr")

                self.sub_interface = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("vlan_id",
                                "msti_id",
                                "port_count",
                                "vlan_id_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.MstpVlans.MstpVlan, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.MstpVlans.MstpVlan, self).__setattr__(name, value)


            class SubInterface(Entity):
                """
                Sub interfaces
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\:  str
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.MstpVlans.MstpVlan.SubInterface, self).__init__()

                    self.yang_name = "sub-interface"
                    self.yang_parent_name = "mstp-vlan"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.MstpVlans.MstpVlan.SubInterface, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.MstpVlans.MstpVlan.SubInterface, self).__setattr__(name, value)

                def has_data(self):
                    return self.interface_name.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "sub-interface" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.sub_interface:
                    if (c.has_data()):
                        return True
                return (
                    self.vlan_id.is_set or
                    self.msti_id.is_set or
                    self.port_count.is_set or
                    self.vlan_id_xr.is_set)

            def has_operation(self):
                for c in self.sub_interface:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.vlan_id.yfilter != YFilter.not_set or
                    self.msti_id.yfilter != YFilter.not_set or
                    self.port_count.yfilter != YFilter.not_set or
                    self.vlan_id_xr.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mstp-vlan" + "[vlan-id='" + self.vlan_id.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/mstp-vlans/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.vlan_id.is_set or self.vlan_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vlan_id.get_name_leafdata())
                if (self.msti_id.is_set or self.msti_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.msti_id.get_name_leafdata())
                if (self.port_count.is_set or self.port_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.port_count.get_name_leafdata())
                if (self.vlan_id_xr.is_set or self.vlan_id_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vlan_id_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "sub-interface"):
                    for c in self.sub_interface:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.MstpVlans.MstpVlan.SubInterface()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.sub_interface.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "sub-interface" or name == "vlan-id" or name == "msti-id" or name == "port-count" or name == "vlan-id-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "vlan-id"):
                    self.vlan_id = value
                    self.vlan_id.value_namespace = name_space
                    self.vlan_id.value_namespace_prefix = name_space_prefix
                if(value_path == "msti-id"):
                    self.msti_id = value
                    self.msti_id.value_namespace = name_space
                    self.msti_id.value_namespace_prefix = name_space_prefix
                if(value_path == "port-count"):
                    self.port_count = value
                    self.port_count.value_namespace = name_space
                    self.port_count.value_namespace_prefix = name_space_prefix
                if(value_path == "vlan-id-xr"):
                    self.vlan_id_xr = value
                    self.vlan_id_xr.value_namespace = name_space
                    self.vlan_id_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.mstp_vlan:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.mstp_vlan:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "mstp-vlans" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "mstp-vlan"):
                for c in self.mstp_vlan:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.MstpVlans.MstpVlan()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.mstp_vlan.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "mstp-vlan"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class L2VpnPbbBsa(Entity):
        """
        L2VPN PBB Backbone Source MAC information
        
        .. attribute:: bmac_sa
        
        	BMAC SA
        	**type**\:  str
        
        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
        
        .. attribute:: chassis_is_provisioned
        
        	Chassis MAC is configured
        	**type**\:  bool
        
        .. attribute:: chassis_mac
        
        	Chassis MAC
        	**type**\:  str
        
        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
        
        .. attribute:: provisioned
        
        	BMAC SA configured
        	**type**\:  bool
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.L2VpnPbbBsa, self).__init__()

            self.yang_name = "l2vpn-pbb-bsa"
            self.yang_parent_name = "l2vpn"

            self.bmac_sa = YLeaf(YType.str, "bmac-sa")

            self.chassis_is_provisioned = YLeaf(YType.boolean, "chassis-is-provisioned")

            self.chassis_mac = YLeaf(YType.str, "chassis-mac")

            self.provisioned = YLeaf(YType.boolean, "provisioned")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("bmac_sa",
                            "chassis_is_provisioned",
                            "chassis_mac",
                            "provisioned") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.L2VpnPbbBsa, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.L2VpnPbbBsa, self).__setattr__(name, value)

        def has_data(self):
            return (
                self.bmac_sa.is_set or
                self.chassis_is_provisioned.is_set or
                self.chassis_mac.is_set or
                self.provisioned.is_set)

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.bmac_sa.yfilter != YFilter.not_set or
                self.chassis_is_provisioned.yfilter != YFilter.not_set or
                self.chassis_mac.yfilter != YFilter.not_set or
                self.provisioned.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "l2vpn-pbb-bsa" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.bmac_sa.is_set or self.bmac_sa.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bmac_sa.get_name_leafdata())
            if (self.chassis_is_provisioned.is_set or self.chassis_is_provisioned.yfilter != YFilter.not_set):
                leaf_name_data.append(self.chassis_is_provisioned.get_name_leafdata())
            if (self.chassis_mac.is_set or self.chassis_mac.yfilter != YFilter.not_set):
                leaf_name_data.append(self.chassis_mac.get_name_leafdata())
            if (self.provisioned.is_set or self.provisioned.yfilter != YFilter.not_set):
                leaf_name_data.append(self.provisioned.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bmac-sa" or name == "chassis-is-provisioned" or name == "chassis-mac" or name == "provisioned"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "bmac-sa"):
                self.bmac_sa = value
                self.bmac_sa.value_namespace = name_space
                self.bmac_sa.value_namespace_prefix = name_space_prefix
            if(value_path == "chassis-is-provisioned"):
                self.chassis_is_provisioned = value
                self.chassis_is_provisioned.value_namespace = name_space
                self.chassis_is_provisioned.value_namespace_prefix = name_space_prefix
            if(value_path == "chassis-mac"):
                self.chassis_mac = value
                self.chassis_mac.value_namespace = name_space
                self.chassis_mac.value_namespace_prefix = name_space_prefix
            if(value_path == "provisioned"):
                self.provisioned = value
                self.provisioned.value_namespace = name_space
                self.provisioned.value_namespace_prefix = name_space_prefix


    class FlexibleXconnectServices(Entity):
        """
        Flexible XConnect Service Table
        
        .. attribute:: flexible_xconnect_service
        
        	Flexible XConnect Service Information
        	**type**\: list of    :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.FlexibleXconnectServices, self).__init__()

            self.yang_name = "flexible-xconnect-services"
            self.yang_parent_name = "l2vpn"

            self.flexible_xconnect_service = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.FlexibleXconnectServices, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.FlexibleXconnectServices, self).__setattr__(name, value)


        class FlexibleXconnectService(Entity):
            """
            Flexible XConnect Service Information
            
            .. attribute:: name  <key>
            
            	Flexible XConnect Service Name
            	**type**\:  str
            
            	**length:** 1..23
            
            .. attribute:: flexible_xconnect_service_acs
            
            	Flexible XConnect Service Attachment Circuit Table
            	**type**\:   :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
            
            .. attribute:: flexible_xconnect_service_info
            
            	Flexible XConnect Service Information
            	**type**\:   :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService, self).__init__()

                self.yang_name = "flexible-xconnect-service"
                self.yang_parent_name = "flexible-xconnect-services"

                self.name = YLeaf(YType.str, "name")

                self.flexible_xconnect_service_acs = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                self.flexible_xconnect_service_acs.parent = self
                self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"
                self._children_yang_names.add("flexible-xconnect-service-acs")

                self.flexible_xconnect_service_info = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                self.flexible_xconnect_service_info.parent = self
                self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                self._children_yang_names.add("flexible-xconnect-service-info")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService, self).__setattr__(name, value)


            class FlexibleXconnectServiceAcs(Entity):
                """
                Flexible XConnect Service Attachment Circuit
                Table
                
                .. attribute:: flexible_xconnect_service_ac
                
                	Flexible XConnect Service Attachment Circuit
                	**type**\: list of    :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__init__()

                    self.yang_name = "flexible-xconnect-service-acs"
                    self.yang_parent_name = "flexible-xconnect-service"

                    self.flexible_xconnect_service_ac = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__setattr__(name, value)


                class FlexibleXconnectServiceAc(Entity):
                    """
                    Flexible XConnect Service Attachment Circuit
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: attachment_circuit
                    
                    	Flexible XConnect Service Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__init__()

                        self.yang_name = "flexible-xconnect-service-ac"
                        self.yang_parent_name = "flexible-xconnect-service-acs"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.attachment_circuit = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"
                        self._children_yang_names.add("attachment-circuit")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__setattr__(name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Flexible XConnect Service Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "flexible-xconnect-service-ac"

                            self.bvi_mac_conflict = YLeaf(YType.boolean, "bvi-mac-conflict")

                            self.bvi_no_port_up = YLeaf(YType.boolean, "bvi-no-port-up")

                            self.control_word_mismatched = YLeaf(YType.boolean, "control-word-mismatched")

                            self.encapsulation_error = YLeaf(YType.str, "encapsulation-error")

                            self.encapsulation_mismatched = YLeaf(YType.boolean, "encapsulation-mismatched")

                            self.evpn_internal_label = YLeaf(YType.uint32, "evpn-internal-label")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.internal_ms_ti = YLeaf(YType.str, "internal-ms-ti")

                            self.interworking = YLeaf(YType.enumeration, "interworking")

                            self.is_ac_partially_programmed = YLeaf(YType.boolean, "is-ac-partially-programmed")

                            self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                            self.ms_ti_mismatch = YLeaf(YType.boolean, "ms-ti-mismatch")

                            self.msti = YLeaf(YType.str, "msti")

                            self.msti_mismatch_down = YLeaf(YType.boolean, "msti-mismatch-down")

                            self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                            self.node_id = YLeaf(YType.str, "node-id")

                            self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                            self.redundancy_group_id = YLeaf(YType.uint32, "redundancy-group-id")

                            self.redundancy_group_state = YLeaf(YType.enumeration, "redundancy-group-state")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.tdm_media_mismatched = YLeaf(YType.boolean, "tdm-media-mismatched")

                            self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                            self.interface = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")

                            self.l2vpn_protection = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._children_yang_names.add("l2vpn-protection")

                            self.statistics = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bvi_mac_conflict",
                                            "bvi_no_port_up",
                                            "control_word_mismatched",
                                            "encapsulation_error",
                                            "encapsulation_mismatched",
                                            "evpn_internal_label",
                                            "interface_handle",
                                            "internal_ms_ti",
                                            "interworking",
                                            "is_ac_partially_programmed",
                                            "mac_limit_oper_down",
                                            "ms_ti_mismatch",
                                            "msti",
                                            "msti_mismatch_down",
                                            "mtu_mismatched",
                                            "node_id",
                                            "out_of_memory_state",
                                            "redundancy_group_id",
                                            "redundancy_group_state",
                                            "redundancy_object_id",
                                            "state",
                                            "tdm_media_mismatched",
                                            "xconnect_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__setattr__(name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.name = YLeaf(YType.str, "name")

                                self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                self.parameters = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._children_yang_names.add("parameters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mtu",
                                                "name",
                                                "payload_bytes") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__setattr__(name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.atm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"
                                    self._children_yang_names.add("atm")

                                    self.ethernet = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"
                                    self._children_yang_names.add("ethernet")

                                    self.fr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"
                                    self._children_yang_names.add("fr")

                                    self.pseudowire_ether = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    self._children_yang_names.add("pseudowire-ether")

                                    self.pseudowire_iw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._children_yang_names.add("pseudowire-iw")

                                    self.tdm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"
                                    self._children_yang_names.add("tdm")

                                    self.vlan = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"
                                    self._children_yang_names.add("vlan")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__setattr__(name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.xconnect_tags.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"

                                        self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                        self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                        self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                        self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                        self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                        self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                        self.vlan_range = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("encapsulation_type",
                                                        "outer_tag",
                                                        "rewrite_tag",
                                                        "simple_efp",
                                                        "vlan_rewrite_tag",
                                                        "xconnect_tags") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__setattr__(name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"

                                            self.lower = YLeaf(YType.uint16, "lower")

                                            self.upper = YLeaf(YType.uint16, "upper")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("lower",
                                                            "upper") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.lower.is_set or
                                                self.upper.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.lower.yfilter != YFilter.not_set or
                                                self.upper.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "vlan-range" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.lower.get_name_leafdata())
                                            if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.upper.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "lower" or name == "upper"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "lower"):
                                                self.lower = value
                                                self.lower.value_namespace = name_space
                                                self.lower.value_namespace_prefix = name_space_prefix
                                            if(value_path == "upper"):
                                                self.upper = value
                                                self.upper.value_namespace = name_space
                                                self.upper.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.vlan_range:
                                            if (c.has_data()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.yfilter != YFilter.not_set):
                                                return True
                                        return (
                                            self.encapsulation_type.is_set or
                                            self.outer_tag.is_set or
                                            self.simple_efp.is_set or
                                            self.vlan_rewrite_tag.is_set or
                                            self.xconnect_tags.is_set)

                                    def has_operation(self):
                                        for c in self.vlan_range:
                                            if (c.has_operation()):
                                                return True
                                        for leaf in self.rewrite_tag.getYLeafs():
                                            if (leaf.is_set):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.encapsulation_type.yfilter != YFilter.not_set or
                                            self.outer_tag.yfilter != YFilter.not_set or
                                            self.rewrite_tag.yfilter != YFilter.not_set or
                                            self.simple_efp.yfilter != YFilter.not_set or
                                            self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                            self.xconnect_tags.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                        if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                        if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                        if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                        if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                        leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "vlan-range"):
                                            for c in self.vlan_range:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.vlan_range.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "encapsulation-type"):
                                            self.encapsulation_type = value
                                            self.encapsulation_type.value_namespace = name_space
                                            self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "outer-tag"):
                                            self.outer_tag = value
                                            self.outer_tag.value_namespace = name_space
                                            self.outer_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rewrite-tag"):
                                            self.rewrite_tag.append(value)
                                        if(value_path == "simple-efp"):
                                            self.simple_efp = value
                                            self.simple_efp.value_namespace = name_space
                                            self.simple_efp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vlan-rewrite-tag"):
                                            self.vlan_rewrite_tag = value
                                            self.vlan_rewrite_tag.value_namespace = name_space
                                            self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "xconnect-tags"):
                                            self.xconnect_tags = value
                                            self.xconnect_tags.value_namespace = name_space
                                            self.xconnect_tags.value_namespace_prefix = name_space_prefix


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"

                                        self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                        self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                        self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                        self.tdm_options = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._children_yang_names.add("tdm-options")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tdm_mode",
                                                        "timeslot_group",
                                                        "timeslot_rate") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__setattr__(name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"

                                            self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                            self.cas = YLeaf(YType.uint8, "cas")

                                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                            self.rtp = YLeaf(YType.enumeration, "rtp")

                                            self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                            self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                            self.ssrc = YLeaf(YType.uint32, "ssrc")

                                            self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                            self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("bit_rate",
                                                            "cas",
                                                            "payload_bytes",
                                                            "rtp",
                                                            "rtp_header_payload_type",
                                                            "signalling_packets",
                                                            "ssrc",
                                                            "timestamp_clock_freq",
                                                            "timestamp_mode") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.bit_rate.is_set or
                                                self.cas.is_set or
                                                self.payload_bytes.is_set or
                                                self.rtp.is_set or
                                                self.rtp_header_payload_type.is_set or
                                                self.signalling_packets.is_set or
                                                self.ssrc.is_set or
                                                self.timestamp_clock_freq.is_set or
                                                self.timestamp_mode.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.bit_rate.yfilter != YFilter.not_set or
                                                self.cas.yfilter != YFilter.not_set or
                                                self.payload_bytes.yfilter != YFilter.not_set or
                                                self.rtp.yfilter != YFilter.not_set or
                                                self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                                self.signalling_packets.yfilter != YFilter.not_set or
                                                self.ssrc.yfilter != YFilter.not_set or
                                                self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                                self.timestamp_mode.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tdm-options" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                            if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cas.get_name_leafdata())
                                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                            if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp.get_name_leafdata())
                                            if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                            if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                            if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ssrc.get_name_leafdata())
                                            if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                            if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "bit-rate"):
                                                self.bit_rate = value
                                                self.bit_rate.value_namespace = name_space
                                                self.bit_rate.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cas"):
                                                self.cas = value
                                                self.cas.value_namespace = name_space
                                                self.cas.value_namespace_prefix = name_space_prefix
                                            if(value_path == "payload-bytes"):
                                                self.payload_bytes = value
                                                self.payload_bytes.value_namespace = name_space
                                                self.payload_bytes.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp"):
                                                self.rtp = value
                                                self.rtp.value_namespace = name_space
                                                self.rtp.value_namespace_prefix = name_space_prefix
                                            if(value_path == "rtp-header-payload-type"):
                                                self.rtp_header_payload_type = value
                                                self.rtp_header_payload_type.value_namespace = name_space
                                                self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "signalling-packets"):
                                                self.signalling_packets = value
                                                self.signalling_packets.value_namespace = name_space
                                                self.signalling_packets.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ssrc"):
                                                self.ssrc = value
                                                self.ssrc.value_namespace = name_space
                                                self.ssrc.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-clock-freq"):
                                                self.timestamp_clock_freq = value
                                                self.timestamp_clock_freq.value_namespace = name_space
                                                self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                            if(value_path == "timestamp-mode"):
                                                self.timestamp_mode = value
                                                self.timestamp_mode.value_namespace = name_space
                                                self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.tdm_mode.is_set or
                                            self.timeslot_group.is_set or
                                            self.timeslot_rate.is_set or
                                            (self.tdm_options is not None and self.tdm_options.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tdm_mode.yfilter != YFilter.not_set or
                                            self.timeslot_group.yfilter != YFilter.not_set or
                                            self.timeslot_rate.yfilter != YFilter.not_set or
                                            (self.tdm_options is not None and self.tdm_options.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                        if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                        if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "tdm-options"):
                                            if (self.tdm_options is None):
                                                self.tdm_options = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                            return self.tdm_options

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tdm-mode"):
                                            self.tdm_mode = value
                                            self.tdm_mode.value_namespace = name_space
                                            self.tdm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-group"):
                                            self.timeslot_group = value
                                            self.timeslot_group.value_namespace = name_space
                                            self.timeslot_group.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timeslot-rate"):
                                            self.timeslot_rate = value
                                            self.timeslot_rate.value_namespace = name_space
                                            self.timeslot_rate.value_namespace_prefix = name_space_prefix


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"

                                        self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                        self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                        self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                        self.vci = YLeaf(YType.uint16, "vci")

                                        self.vpi = YLeaf(YType.uint16, "vpi")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("atm_mode",
                                                        "maximum_number_cells_packed",
                                                        "maximum_number_cells_un_packed",
                                                        "vci",
                                                        "vpi") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.atm_mode.is_set or
                                            self.maximum_number_cells_packed.is_set or
                                            self.maximum_number_cells_un_packed.is_set or
                                            self.vci.is_set or
                                            self.vpi.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.atm_mode.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                            self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                            self.vci.yfilter != YFilter.not_set or
                                            self.vpi.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "atm" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                        if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                        if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                        if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vci.get_name_leafdata())
                                        if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpi.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "atm-mode"):
                                            self.atm_mode = value
                                            self.atm_mode.value_namespace = name_space
                                            self.atm_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-packed"):
                                            self.maximum_number_cells_packed = value
                                            self.maximum_number_cells_packed.value_namespace = name_space
                                            self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-number-cells-un-packed"):
                                            self.maximum_number_cells_un_packed = value
                                            self.maximum_number_cells_un_packed.value_namespace = name_space
                                            self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vci"):
                                            self.vci = value
                                            self.vci.value_namespace = name_space
                                            self.vci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpi"):
                                            self.vpi = value
                                            self.vpi.value_namespace = name_space
                                            self.vpi.value_namespace_prefix = name_space_prefix


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"

                                        self.dlci = YLeaf(YType.uint32, "dlci")

                                        self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("dlci",
                                                        "fr_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.dlci.is_set or
                                            self.fr_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.dlci.yfilter != YFilter.not_set or
                                            self.fr_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dlci.get_name_leafdata())
                                        if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dlci" or name == "fr-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "dlci"):
                                            self.dlci = value
                                            self.dlci.value_namespace = name_space
                                            self.dlci.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fr-mode"):
                                            self.fr_mode = value
                                            self.fr_mode.value_namespace = name_space
                                            self.fr_mode.value_namespace_prefix = name_space_prefix


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-ether" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"

                                        self.internal_label = YLeaf(YType.uint32, "internal-label")

                                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                                        self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._children_yang_names.add("interface-list")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("internal_label",
                                                        "is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"

                                            self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                            self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                            self.interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_list_id",
                                                            "interface_list_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name",
                                                                "replicate_status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.interface_name.is_set or
                                                    self.replicate_status.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set or
                                                    self.replicate_status.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "interface" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                                if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name" or name == "replicate-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "replicate-status"):
                                                    self.replicate_status = value
                                                    self.replicate_status.value_namespace = name_space
                                                    self.replicate_status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.interface:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.interface_list_id.is_set or
                                                self.interface_list_name.is_set)

                                        def has_operation(self):
                                            for c in self.interface:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_list_id.yfilter != YFilter.not_set or
                                                self.interface_list_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                            if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "interface"):
                                                for c in self.interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-list-id"):
                                                self.interface_list_id = value
                                                self.interface_list_id.value_namespace = name_space
                                                self.interface_list_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interface-list-name"):
                                                self.interface_list_name = value
                                                self.interface_list_name.value_namespace = name_space
                                                self.interface_list_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.internal_label.is_set or
                                            self.is_valid.is_set or
                                            (self.interface_list is not None and self.interface_list.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.internal_label.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.interface_list is not None and self.interface_list.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudowire-iw" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.internal_label.get_name_leafdata())
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface-list"):
                                            if (self.interface_list is None):
                                                self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                            return self.interface_list

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "internal-label"):
                                            self.internal_label = value
                                            self.internal_label.value_namespace = name_space
                                            self.internal_label.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.type.is_set or
                                        (self.atm is not None and self.atm.has_data()) or
                                        (self.ethernet is not None and self.ethernet.has_data()) or
                                        (self.fr is not None and self.fr.has_data()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                        (self.tdm is not None and self.tdm.has_data()) or
                                        (self.vlan is not None and self.vlan.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        (self.atm is not None and self.atm.has_operation()) or
                                        (self.ethernet is not None and self.ethernet.has_operation()) or
                                        (self.fr is not None and self.fr.has_operation()) or
                                        (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                        (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                        (self.tdm is not None and self.tdm.has_operation()) or
                                        (self.vlan is not None and self.vlan.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "parameters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "atm"):
                                        if (self.atm is None):
                                            self.atm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"
                                        return self.atm

                                    if (child_yang_name == "ethernet"):
                                        if (self.ethernet is None):
                                            self.ethernet = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"
                                        return self.ethernet

                                    if (child_yang_name == "fr"):
                                        if (self.fr is None):
                                            self.fr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"
                                        return self.fr

                                    if (child_yang_name == "pseudowire-ether"):
                                        if (self.pseudowire_ether is None):
                                            self.pseudowire_ether = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                        return self.pseudowire_ether

                                    if (child_yang_name == "pseudowire-iw"):
                                        if (self.pseudowire_iw is None):
                                            self.pseudowire_iw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        return self.pseudowire_iw

                                    if (child_yang_name == "tdm"):
                                        if (self.tdm is None):
                                            self.tdm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"
                                        return self.tdm

                                    if (child_yang_name == "vlan"):
                                        if (self.vlan is None):
                                            self.vlan = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"
                                        return self.vlan

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mtu.is_set or
                                    self.name.is_set or
                                    self.payload_bytes.is_set or
                                    (self.parameters is not None and self.parameters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.name.yfilter != YFilter.not_set or
                                    self.payload_bytes.yfilter != YFilter.not_set or
                                    (self.parameters is not None and self.parameters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.name.get_name_leafdata())
                                if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "parameters"):
                                    if (self.parameters is None):
                                        self.parameters = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                    return self.parameters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "name"):
                                    self.name = value
                                    self.name.value_namespace = name_space
                                    self.name.value_namespace_prefix = name_space_prefix
                                if(value_path == "payload-bytes"):
                                    self.payload_bytes = value
                                    self.payload_bytes.value_namespace = name_space
                                    self.payload_bytes.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"

                                self.dispostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                self._children_yang_names.add("dispostion-stats")

                                self.impostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"
                                self._children_yang_names.add("impostion-stats")

                                self.sequence_number = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._children_yang_names.add("sequence-number")


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"
                                    self._children_yang_names.add("broadcast")

                                    self.imposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    self._children_yang_names.add("imposition-mtu-drop")

                                    self.imposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"
                                    self._children_yang_names.add("imposition-stat")

                                    self.impostion_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    self._children_yang_names.add("impostion-tail-drop")

                                    self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.l2fsbi_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    self._children_yang_names.add("l2fsbi-drop")

                                    self.multicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"
                                    self._children_yang_names.add("multicast")

                                    self.unknown_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._children_yang_names.add("unknown-unicast")


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "imposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "impostion-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class L2FsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "l2fsbi-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unknown-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast is not None and self.broadcast.has_data()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                        (self.multicast is not None and self.multicast.has_data()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast is not None and self.broadcast.has_operation()) or
                                        (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                        (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                        (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                        (self.multicast is not None and self.multicast.has_operation()) or
                                        (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast"):
                                        if (self.broadcast is None):
                                            self.broadcast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"
                                        return self.broadcast

                                    if (child_yang_name == "imposition-mtu-drop"):
                                        if (self.imposition_mtu_drop is None):
                                            self.imposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                        return self.imposition_mtu_drop

                                    if (child_yang_name == "imposition-stat"):
                                        if (self.imposition_stat is None):
                                            self.imposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"
                                        return self.imposition_stat

                                    if (child_yang_name == "impostion-tail-drop"):
                                        if (self.impostion_tail_drop is None):
                                            self.impostion_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                        return self.impostion_tail_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "l2fsbi-drop"):
                                        if (self.l2fsbi_drop is None):
                                            self.l2fsbi_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                        return self.l2fsbi_drop

                                    if (child_yang_name == "multicast"):
                                        if (self.multicast is None):
                                            self.multicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"
                                        return self.multicast

                                    if (child_yang_name == "unknown-unicast"):
                                        if (self.unknown_unicast is None):
                                            self.unknown_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        return self.unknown_unicast

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"

                                    self.broadcast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    self._children_yang_names.add("broadcast-drop")

                                    self.dai_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"
                                    self._children_yang_names.add("dai-drop")

                                    self.disposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    self._children_yang_names.add("disposition-mtu-drop")

                                    self.disposition_oo_o_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    self._children_yang_names.add("disposition-oo-o-drops")

                                    self.disposition_p2mp_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    self._children_yang_names.add("disposition-p2mp-stats")

                                    self.disposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"
                                    self._children_yang_names.add("disposition-stat")

                                    self.disposition_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    self._children_yang_names.add("disposition-tail-drop")

                                    self.ipsg_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    self._children_yang_names.add("ipsg-drop")

                                    self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"
                                    self._children_yang_names.add("known-unicast")

                                    self.mac_move = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._children_yang_names.add("mac-move")

                                    self.multicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"
                                    self._children_yang_names.add("multicast-drop")

                                    self.received_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"
                                    self._children_yang_names.add("received-drops")

                                    self.unicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"
                                    self._children_yang_names.add("unicast-drop")


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-mtu-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-tail-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "unicast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "broadcast-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dai-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipsg-drop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-oo-o-drops" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class DispositionP2MpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disposition-p2mp-stats" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "known-unicast" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"

                                        self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                        self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("byte_counts",
                                                        "packet_counts") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.byte_counts.is_set or
                                            self.packet_counts.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.byte_counts.yfilter != YFilter.not_set or
                                            self.packet_counts.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-move" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                        if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "byte-counts" or name == "packet-counts"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "byte-counts"):
                                            self.byte_counts = value
                                            self.byte_counts.value_namespace = name_space
                                            self.byte_counts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-counts"):
                                            self.packet_counts = value
                                            self.packet_counts.value_namespace = name_space
                                            self.packet_counts.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                        (self.dai_drop is not None and self.dai_drop.has_data()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                        (self.known_unicast is not None and self.known_unicast.has_data()) or
                                        (self.mac_move is not None and self.mac_move.has_data()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                        (self.received_drops is not None and self.received_drops.has_data()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                        (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                        (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                        (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                        (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                        (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                        (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                        (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                        (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                        (self.mac_move is not None and self.mac_move.has_operation()) or
                                        (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                        (self.received_drops is not None and self.received_drops.has_operation()) or
                                        (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dispostion-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "broadcast-drop"):
                                        if (self.broadcast_drop is None):
                                            self.broadcast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                        return self.broadcast_drop

                                    if (child_yang_name == "dai-drop"):
                                        if (self.dai_drop is None):
                                            self.dai_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"
                                        return self.dai_drop

                                    if (child_yang_name == "disposition-mtu-drop"):
                                        if (self.disposition_mtu_drop is None):
                                            self.disposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                        return self.disposition_mtu_drop

                                    if (child_yang_name == "disposition-oo-o-drops"):
                                        if (self.disposition_oo_o_drops is None):
                                            self.disposition_oo_o_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                        return self.disposition_oo_o_drops

                                    if (child_yang_name == "disposition-p2mp-stats"):
                                        if (self.disposition_p2mp_stats is None):
                                            self.disposition_p2mp_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                        return self.disposition_p2mp_stats

                                    if (child_yang_name == "disposition-stat"):
                                        if (self.disposition_stat is None):
                                            self.disposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"
                                        return self.disposition_stat

                                    if (child_yang_name == "disposition-tail-drop"):
                                        if (self.disposition_tail_drop is None):
                                            self.disposition_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                        return self.disposition_tail_drop

                                    if (child_yang_name == "ipsg-drop"):
                                        if (self.ipsg_drop is None):
                                            self.ipsg_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                        return self.ipsg_drop

                                    if (child_yang_name == "known-unicast"):
                                        if (self.known_unicast is None):
                                            self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"
                                        return self.known_unicast

                                    if (child_yang_name == "mac-move"):
                                        if (self.mac_move is None):
                                            self.mac_move = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                        return self.mac_move

                                    if (child_yang_name == "multicast-drop"):
                                        if (self.multicast_drop is None):
                                            self.multicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"
                                        return self.multicast_drop

                                    if (child_yang_name == "received-drops"):
                                        if (self.received_drops is None):
                                            self.received_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"
                                        return self.received_drops

                                    if (child_yang_name == "unicast-drop"):
                                        if (self.unicast_drop is None):
                                            self.unicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"
                                        return self.unicast_drop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"

                                    self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                    self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                    self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                    self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bypassed_inbound_sequence_packet",
                                                    "bypassed_out_sequence_packet",
                                                    "sequence_number_expected",
                                                    "sequence_number_sent") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bypassed_inbound_sequence_packet.is_set or
                                        self.bypassed_out_sequence_packet.is_set or
                                        self.sequence_number_expected.is_set or
                                        self.sequence_number_sent.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                        self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                        self.sequence_number_expected.yfilter != YFilter.not_set or
                                        self.sequence_number_sent.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sequence-number" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                    if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                    if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                    if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bypassed-inbound-sequence-packet"):
                                        self.bypassed_inbound_sequence_packet = value
                                        self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                        self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bypassed-out-sequence-packet"):
                                        self.bypassed_out_sequence_packet = value
                                        self.bypassed_out_sequence_packet.value_namespace = name_space
                                        self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-expected"):
                                        self.sequence_number_expected = value
                                        self.sequence_number_expected.value_namespace = name_space
                                        self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sequence-number-sent"):
                                        self.sequence_number_sent = value
                                        self.sequence_number_sent.value_namespace = name_space
                                        self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                    (self.sequence_number is not None and self.sequence_number.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                    (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                    (self.sequence_number is not None and self.sequence_number.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dispostion-stats"):
                                    if (self.dispostion_stats is None):
                                        self.dispostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                    return self.dispostion_stats

                                if (child_yang_name == "impostion-stats"):
                                    if (self.impostion_stats is None):
                                        self.impostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"
                                    return self.impostion_stats

                                if (child_yang_name == "sequence-number"):
                                    if (self.sequence_number is None):
                                        self.sequence_number = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                    return self.sequence_number

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class L2VpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtection>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"

                                self.active = YLeaf(YType.boolean, "active")

                                self.protected_name = YLeaf(YType.str, "protected-name")

                                self.protection_configured = YLeaf(YType.enumeration, "protection-configured")

                                self.protection_name = YLeaf(YType.str, "protection-name")

                                self.protection_type = YLeaf(YType.enumeration, "protection-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active",
                                                "protected_name",
                                                "protection_configured",
                                                "protection_name",
                                                "protection_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.active.is_set or
                                    self.protected_name.is_set or
                                    self.protection_configured.is_set or
                                    self.protection_name.is_set or
                                    self.protection_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active.yfilter != YFilter.not_set or
                                    self.protected_name.yfilter != YFilter.not_set or
                                    self.protection_configured.yfilter != YFilter.not_set or
                                    self.protection_name.yfilter != YFilter.not_set or
                                    self.protection_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2vpn-protection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active.get_name_leafdata())
                                if (self.protected_name.is_set or self.protected_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protected_name.get_name_leafdata())
                                if (self.protection_configured.is_set or self.protection_configured.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_configured.get_name_leafdata())
                                if (self.protection_name.is_set or self.protection_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_name.get_name_leafdata())
                                if (self.protection_type.is_set or self.protection_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protection_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "active" or name == "protected-name" or name == "protection-configured" or name == "protection-name" or name == "protection-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active"):
                                    self.active = value
                                    self.active.value_namespace = name_space
                                    self.active.value_namespace_prefix = name_space_prefix
                                if(value_path == "protected-name"):
                                    self.protected_name = value
                                    self.protected_name.value_namespace = name_space
                                    self.protected_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-configured"):
                                    self.protection_configured = value
                                    self.protection_configured.value_namespace = name_space
                                    self.protection_configured.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-name"):
                                    self.protection_name = value
                                    self.protection_name.value_namespace = name_space
                                    self.protection_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "protection-type"):
                                    self.protection_type = value
                                    self.protection_type.value_namespace = name_space
                                    self.protection_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bvi_mac_conflict.is_set or
                                self.bvi_no_port_up.is_set or
                                self.control_word_mismatched.is_set or
                                self.encapsulation_error.is_set or
                                self.encapsulation_mismatched.is_set or
                                self.evpn_internal_label.is_set or
                                self.interface_handle.is_set or
                                self.internal_ms_ti.is_set or
                                self.interworking.is_set or
                                self.is_ac_partially_programmed.is_set or
                                self.mac_limit_oper_down.is_set or
                                self.ms_ti_mismatch.is_set or
                                self.msti.is_set or
                                self.msti_mismatch_down.is_set or
                                self.mtu_mismatched.is_set or
                                self.node_id.is_set or
                                self.out_of_memory_state.is_set or
                                self.redundancy_group_id.is_set or
                                self.redundancy_group_state.is_set or
                                self.redundancy_object_id.is_set or
                                self.state.is_set or
                                self.tdm_media_mismatched.is_set or
                                self.xconnect_id.is_set or
                                (self.interface is not None and self.interface.has_data()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bvi_mac_conflict.yfilter != YFilter.not_set or
                                self.bvi_no_port_up.yfilter != YFilter.not_set or
                                self.control_word_mismatched.yfilter != YFilter.not_set or
                                self.encapsulation_error.yfilter != YFilter.not_set or
                                self.encapsulation_mismatched.yfilter != YFilter.not_set or
                                self.evpn_internal_label.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.internal_ms_ti.yfilter != YFilter.not_set or
                                self.interworking.yfilter != YFilter.not_set or
                                self.is_ac_partially_programmed.yfilter != YFilter.not_set or
                                self.mac_limit_oper_down.yfilter != YFilter.not_set or
                                self.ms_ti_mismatch.yfilter != YFilter.not_set or
                                self.msti.yfilter != YFilter.not_set or
                                self.msti_mismatch_down.yfilter != YFilter.not_set or
                                self.mtu_mismatched.yfilter != YFilter.not_set or
                                self.node_id.yfilter != YFilter.not_set or
                                self.out_of_memory_state.yfilter != YFilter.not_set or
                                self.redundancy_group_id.yfilter != YFilter.not_set or
                                self.redundancy_group_state.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.tdm_media_mismatched.yfilter != YFilter.not_set or
                                self.xconnect_id.yfilter != YFilter.not_set or
                                (self.interface is not None and self.interface.has_operation()) or
                                (self.l2vpn_protection is not None and self.l2vpn_protection.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "attachment-circuit" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bvi_mac_conflict.is_set or self.bvi_mac_conflict.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_mac_conflict.get_name_leafdata())
                            if (self.bvi_no_port_up.is_set or self.bvi_no_port_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bvi_no_port_up.get_name_leafdata())
                            if (self.control_word_mismatched.is_set or self.control_word_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.control_word_mismatched.get_name_leafdata())
                            if (self.encapsulation_error.is_set or self.encapsulation_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_error.get_name_leafdata())
                            if (self.encapsulation_mismatched.is_set or self.encapsulation_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation_mismatched.get_name_leafdata())
                            if (self.evpn_internal_label.is_set or self.evpn_internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.evpn_internal_label.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.internal_ms_ti.is_set or self.internal_ms_ti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_ms_ti.get_name_leafdata())
                            if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interworking.get_name_leafdata())
                            if (self.is_ac_partially_programmed.is_set or self.is_ac_partially_programmed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ac_partially_programmed.get_name_leafdata())
                            if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                            if (self.ms_ti_mismatch.is_set or self.ms_ti_mismatch.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ms_ti_mismatch.get_name_leafdata())
                            if (self.msti.is_set or self.msti.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti.get_name_leafdata())
                            if (self.msti_mismatch_down.is_set or self.msti_mismatch_down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.msti_mismatch_down.get_name_leafdata())
                            if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                            if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node_id.get_name_leafdata())
                            if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                            if (self.redundancy_group_id.is_set or self.redundancy_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_id.get_name_leafdata())
                            if (self.redundancy_group_state.is_set or self.redundancy_group_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_group_state.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.tdm_media_mismatched.is_set or self.tdm_media_mismatched.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tdm_media_mismatched.get_name_leafdata())
                            if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "interface"):
                                if (self.interface is None):
                                    self.interface = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"
                                return self.interface

                            if (child_yang_name == "l2vpn-protection"):
                                if (self.l2vpn_protection is None):
                                    self.l2vpn_protection = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                return self.l2vpn_protection

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface" or name == "l2vpn-protection" or name == "statistics" or name == "bvi-mac-conflict" or name == "bvi-no-port-up" or name == "control-word-mismatched" or name == "encapsulation-error" or name == "encapsulation-mismatched" or name == "evpn-internal-label" or name == "interface-handle" or name == "internal-ms-ti" or name == "interworking" or name == "is-ac-partially-programmed" or name == "mac-limit-oper-down" or name == "ms-ti-mismatch" or name == "msti" or name == "msti-mismatch-down" or name == "mtu-mismatched" or name == "node-id" or name == "out-of-memory-state" or name == "redundancy-group-id" or name == "redundancy-group-state" or name == "redundancy-object-id" or name == "state" or name == "tdm-media-mismatched" or name == "xconnect-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bvi-mac-conflict"):
                                self.bvi_mac_conflict = value
                                self.bvi_mac_conflict.value_namespace = name_space
                                self.bvi_mac_conflict.value_namespace_prefix = name_space_prefix
                            if(value_path == "bvi-no-port-up"):
                                self.bvi_no_port_up = value
                                self.bvi_no_port_up.value_namespace = name_space
                                self.bvi_no_port_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "control-word-mismatched"):
                                self.control_word_mismatched = value
                                self.control_word_mismatched.value_namespace = name_space
                                self.control_word_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-error"):
                                self.encapsulation_error = value
                                self.encapsulation_error.value_namespace = name_space
                                self.encapsulation_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "encapsulation-mismatched"):
                                self.encapsulation_mismatched = value
                                self.encapsulation_mismatched.value_namespace = name_space
                                self.encapsulation_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "evpn-internal-label"):
                                self.evpn_internal_label = value
                                self.evpn_internal_label.value_namespace = name_space
                                self.evpn_internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-ms-ti"):
                                self.internal_ms_ti = value
                                self.internal_ms_ti.value_namespace = name_space
                                self.internal_ms_ti.value_namespace_prefix = name_space_prefix
                            if(value_path == "interworking"):
                                self.interworking = value
                                self.interworking.value_namespace = name_space
                                self.interworking.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ac-partially-programmed"):
                                self.is_ac_partially_programmed = value
                                self.is_ac_partially_programmed.value_namespace = name_space
                                self.is_ac_partially_programmed.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-limit-oper-down"):
                                self.mac_limit_oper_down = value
                                self.mac_limit_oper_down.value_namespace = name_space
                                self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "ms-ti-mismatch"):
                                self.ms_ti_mismatch = value
                                self.ms_ti_mismatch.value_namespace = name_space
                                self.ms_ti_mismatch.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti"):
                                self.msti = value
                                self.msti.value_namespace = name_space
                                self.msti.value_namespace_prefix = name_space_prefix
                            if(value_path == "msti-mismatch-down"):
                                self.msti_mismatch_down = value
                                self.msti_mismatch_down.value_namespace = name_space
                                self.msti_mismatch_down.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-mismatched"):
                                self.mtu_mismatched = value
                                self.mtu_mismatched.value_namespace = name_space
                                self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "node-id"):
                                self.node_id = value
                                self.node_id.value_namespace = name_space
                                self.node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "out-of-memory-state"):
                                self.out_of_memory_state = value
                                self.out_of_memory_state.value_namespace = name_space
                                self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-id"):
                                self.redundancy_group_id = value
                                self.redundancy_group_id.value_namespace = name_space
                                self.redundancy_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-group-state"):
                                self.redundancy_group_state = value
                                self.redundancy_group_state.value_namespace = name_space
                                self.redundancy_group_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "tdm-media-mismatched"):
                                self.tdm_media_mismatched = value
                                self.tdm_media_mismatched.value_namespace = name_space
                                self.tdm_media_mismatched.value_namespace_prefix = name_space_prefix
                            if(value_path == "xconnect-id"):
                                self.xconnect_id = value
                                self.xconnect_id.value_namespace = name_space
                                self.xconnect_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            (self.attachment_circuit is not None and self.attachment_circuit.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "flexible-xconnect-service-ac" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "attachment-circuit"):
                            if (self.attachment_circuit is None):
                                self.attachment_circuit = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            return self.attachment_circuit

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "attachment-circuit" or name == "interface-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.flexible_xconnect_service_ac:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.flexible_xconnect_service_ac:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flexible-xconnect-service-acs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "flexible-xconnect-service-ac"):
                        for c in self.flexible_xconnect_service_ac:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.flexible_xconnect_service_ac.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flexible-xconnect-service-ac"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class FlexibleXconnectServiceInfo(Entity):
                """
                Flexible XConnect Service Information
                
                .. attribute:: fxc_id
                
                	Flexible XConnect ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: name
                
                	Flexible XConnect Service Name
                	**type**\:  str
                
                .. attribute:: num_p_ws
                
                	Number of Pseudowires in Pseudowire List
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: pseudowire
                
                	Flexible XConnect Service Pseudowire List
                	**type**\: list of    :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                
                .. attribute:: state
                
                	State of the Flexible XConnect Service
                	**type**\:   :py:class:`L2VpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcState>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__init__()

                    self.yang_name = "flexible-xconnect-service-info"
                    self.yang_parent_name = "flexible-xconnect-service"

                    self.fxc_id = YLeaf(YType.uint32, "fxc-id")

                    self.name = YLeaf(YType.str, "name")

                    self.num_p_ws = YLeaf(YType.uint8, "num-p-ws")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.pseudowire = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("fxc_id",
                                    "name",
                                    "num_p_ws",
                                    "state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__setattr__(name, value)


                class Pseudowire(Entity):
                    """
                    Flexible XConnect Service Pseudowire List
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_remote_down
                    
                    	Auto\-Discovered PW remote state down
                    	**type**\:  bool
                    
                    .. attribute:: admited_bw
                    
                    	Admited Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: auto_discovery
                    
                    	Is autodiscovery
                    	**type**\:  bool
                    
                    .. attribute:: backup_active
                    
                    	TRUE if backup is active
                    	**type**\:  bool
                    
                    .. attribute:: backup_force_active
                    
                    	TRUE if backup is active due to switchover
                    	**type**\:  bool
                    
                    .. attribute:: backup_pw
                    
                    	TRUE if PW is a backup PW
                    	**type**\:  bool
                    
                    .. attribute:: bitrate_mismatched
                    
                    	Bitrate mismatched
                    	**type**\:  bool
                    
                    .. attribute:: bridge_pw_type_mismatch
                    
                    	Oper down because Bridge has mismatched PW Types
                    	**type**\:  bool
                    
                    .. attribute:: cas_mismatched
                    
                    	CAS mismatched
                    	**type**\:  bool
                    
                    .. attribute:: diff_ts_mismatched
                    
                    	Differential timestamp mismatched
                    	**type**\:  bool
                    
                    .. attribute:: disable_delay
                    
                    	Backup disable delay
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                    
                    .. attribute:: evpn_src_acid
                    
                    	EVPN VPWS Source AC ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fe_ctype
                    
                    	Pseudowire FEC type
                    	**type**\:   :py:class:`L2VpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFec>`
                    
                    .. attribute:: forward_class
                    
                    	Forward Class attribute
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: freq_mismatched
                    
                    	Frequency mismatched
                    	**type**\:  bool
                    
                    .. attribute:: illegal_control_word
                    
                    	Illegal control word
                    	**type**\:  bool
                    
                    .. attribute:: imposed_vlan_id
                    
                    	Imposed vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworking>`
                    
                    .. attribute:: ipv6_local_source_address
                    
                    	Local IPv6 Source Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_evpnvpws_type
                    
                    	is EVPN VPWS
                    	**type**\:  bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: is_multi_segment_pseudowire
                    
                    	Is Multi\-Segment Pseudowire
                    	**type**\:  bool
                    
                    .. attribute:: is_partially_programmed
                    
                    	Is Pseudowire partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_pwr_type
                    
                    	is Pseudowire\-routed
                    	**type**\:  bool
                    
                    .. attribute:: is_vfi
                    
                    	Is VFI interface
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the pseudowire status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_down
                    
                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: ldp_label_advertise_failed
                    
                    	LDP label advertisment failed
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBal>`
                    
                    .. attribute:: local_control_word
                    
                    	Local control word
                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                    
                    .. attribute:: local_label_failed
                    
                    	Failed to set BGP advertised local label
                    	**type**\:  bool
                    
                    .. attribute:: local_pseudo_wire_type
                    
                    	Local pseudowire type
                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                    
                    .. attribute:: local_signalling
                    
                    	Local signalling
                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                    
                    .. attribute:: local_source_address
                    
                    	Local Source Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_qinq
                    
                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                    	**type**\:  bool
                    
                    .. attribute:: num_ma_cwithdraw_msg_received
                    
                    	Num MW messages received over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ma_cwithdraw_message_sent
                    
                    	Num MW messages sent over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_pw
                    
                    	P2MP Pseudowire Information
                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw>`
                    
                    .. attribute:: payload_bytes_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: payload_type_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: peer_id
                    
                    	Peer
                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	Prefpath fallback enable/disable
                    	**type**\:  bool
                    
                    .. attribute:: primary_peer_id
                    
                    	Primary Peer IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: primary_pseudo_wire_id
                    
                    	Primary Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: primary_pw
                    
                    	TRUE if PW is a primary PW
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProto>`
                    
                    .. attribute:: pseudo_wire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: pseudo_wire_state
                    
                    	Pseudowire state
                    	**type**\:   :py:class:`L2VpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwState>`
                    
                    .. attribute:: pseudo_wire_type_mismatched
                    
                    	Pseudowire type mismatched
                    	**type**\:  bool
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type
                    
                    	Negotiated pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label Type
                    	**type**\:   :py:class:`L2VpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabel>`
                    
                    .. attribute:: pw_redundancy_initial_delay
                    
                    	Initial delay for redundant PW in seconds
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    .. attribute:: pw_redundancy_one_way
                    
                    	Force one\-way PW redundancy behaviour in Redundancy Group
                    	**type**\:  bool
                    
                    .. attribute:: pw_status_use
                    
                    	PW status in use
                    	**type**\:  bool
                    
                    .. attribute:: pwlsd_rewrite_failed
                    
                    	LSD rewrite failed
                    	**type**\:  bool
                    
                    .. attribute:: remote_control_word
                    
                    	Remote control word
                    	**type**\:   :py:class:`L2VpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWord>`
                    
                    .. attribute:: remote_interface
                    
                    	Remote interface
                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                    
                    .. attribute:: remote_label_failed
                    
                    	Failed to set BGP advertised remote label
                    	**type**\:  bool
                    
                    .. attribute:: remote_pseudo_wire_type
                    
                    	Remote pseudowire type
                    	**type**\:   :py:class:`L2VpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPw>`
                    
                    .. attribute:: remote_signalling
                    
                    	Remote signalling
                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                    
                    .. attribute:: required_bw
                    
                    	Required Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rtp_mismatched
                    
                    	RTP mismatched
                    	**type**\:  bool
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequence>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: sig_pkts_mismatched
                    
                    	Signalling packets mismatched
                    	**type**\:  bool
                    
                    .. attribute:: ssrc_mismatched
                    
                    	SSRC mismatched
                    	**type**\:  bool
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentState>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                    
                    .. attribute:: table_policy_name
                    
                    	Table\-policy Name
                    	**type**\:  str
                    
                    .. attribute:: tag_rewrite
                    
                    	StaticTagRewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: time_created
                    
                    	Time when the pseudowire was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_down
                    
                    	Time elapsed since last status down in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: transport_lsp_down
                    
                    	Oper down due to Transport LSP down
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__init__()

                        self.yang_name = "pseudowire"
                        self.yang_parent_name = "flexible-xconnect-service-info"

                        self.ad_method = YLeaf(YType.uint32, "ad-method")

                        self.ad_remote_down = YLeaf(YType.boolean, "ad-remote-down")

                        self.admited_bw = YLeaf(YType.uint32, "admited-bw")

                        self.auto_discovery = YLeaf(YType.boolean, "auto-discovery")

                        self.backup_active = YLeaf(YType.boolean, "backup-active")

                        self.backup_force_active = YLeaf(YType.boolean, "backup-force-active")

                        self.backup_pw = YLeaf(YType.boolean, "backup-pw")

                        self.bitrate_mismatched = YLeaf(YType.boolean, "bitrate-mismatched")

                        self.bridge_pw_type_mismatch = YLeaf(YType.boolean, "bridge-pw-type-mismatch")

                        self.cas_mismatched = YLeaf(YType.boolean, "cas-mismatched")

                        self.diff_ts_mismatched = YLeaf(YType.boolean, "diff-ts-mismatched")

                        self.disable_delay = YLeaf(YType.uint8, "disable-delay")

                        self.disable_never = YLeaf(YType.boolean, "disable-never")

                        self.evpn_src_acid = YLeaf(YType.uint32, "evpn-src-acid")

                        self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                        self.forward_class = YLeaf(YType.uint8, "forward-class")

                        self.freq_mismatched = YLeaf(YType.boolean, "freq-mismatched")

                        self.illegal_control_word = YLeaf(YType.boolean, "illegal-control-word")

                        self.imposed_vlan_id = YLeaf(YType.uint32, "imposed-vlan-id")

                        self.interworking = YLeaf(YType.enumeration, "interworking")

                        self.ipv6_local_source_address = YLeaf(YType.str, "ipv6-local-source-address")

                        self.is_evpnvpws_type = YLeaf(YType.boolean, "is-evpnvpws-type")

                        self.is_flow_label_static = YLeaf(YType.boolean, "is-flow-label-static")

                        self.is_multi_segment_pseudowire = YLeaf(YType.boolean, "is-multi-segment-pseudowire")

                        self.is_partially_programmed = YLeaf(YType.boolean, "is-partially-programmed")

                        self.is_pwr_type = YLeaf(YType.boolean, "is-pwr-type")

                        self.is_vfi = YLeaf(YType.boolean, "is-vfi")

                        self.last_time_status_changed = YLeaf(YType.str, "last-time-status-changed")

                        self.last_time_status_down = YLeaf(YType.str, "last-time-status-down")

                        self.ldp_label_advertise_failed = YLeaf(YType.boolean, "ldp-label-advertise-failed")

                        self.load_balance = YLeaf(YType.enumeration, "load-balance")

                        self.local_control_word = YLeaf(YType.enumeration, "local-control-word")

                        self.local_label_failed = YLeaf(YType.boolean, "local-label-failed")

                        self.local_pseudo_wire_type = YLeaf(YType.enumeration, "local-pseudo-wire-type")

                        self.local_source_address = YLeaf(YType.str, "local-source-address")

                        self.mac_limit_oper_down = YLeaf(YType.boolean, "mac-limit-oper-down")

                        self.mtu_mismatched = YLeaf(YType.boolean, "mtu-mismatched")

                        self.not_supported_qinq = YLeaf(YType.boolean, "not-supported-qinq")

                        self.num_ma_cwithdraw_msg_received = YLeaf(YType.uint32, "num-ma-cwithdraw-msg-received")

                        self.number_ma_cwithdraw_message_sent = YLeaf(YType.uint32, "number-ma-cwithdraw-message-sent")

                        self.out_of_memory_state = YLeaf(YType.uint32, "out-of-memory-state")

                        self.payload_bytes_mismatched = YLeaf(YType.boolean, "payload-bytes-mismatched")

                        self.payload_type_mismatched = YLeaf(YType.boolean, "payload-type-mismatched")

                        self.preferred_path_disable_fallback = YLeaf(YType.boolean, "preferred-path-disable-fallback")

                        self.primary_peer_id = YLeaf(YType.str, "primary-peer-id")

                        self.primary_pseudo_wire_id = YLeaf(YType.uint64, "primary-pseudo-wire-id")

                        self.primary_pw = YLeaf(YType.boolean, "primary-pw")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.pseudo_wire_id = YLeaf(YType.uint64, "pseudo-wire-id")

                        self.pseudo_wire_state = YLeaf(YType.enumeration, "pseudo-wire-state")

                        self.pseudo_wire_type_mismatched = YLeaf(YType.boolean, "pseudo-wire-type-mismatched")

                        self.pw_class_name = YLeaf(YType.str, "pw-class-name")

                        self.pw_flow_label_code17_disabled = YLeaf(YType.boolean, "pw-flow-label-code17-disabled")

                        self.pw_flow_label_type = YLeaf(YType.enumeration, "pw-flow-label-type")

                        self.pw_flow_label_type_cfg = YLeaf(YType.enumeration, "pw-flow-label-type-cfg")

                        self.pw_redundancy_initial_delay = YLeaf(YType.uint8, "pw-redundancy-initial-delay")

                        self.pw_redundancy_one_way = YLeaf(YType.boolean, "pw-redundancy-one-way")

                        self.pw_status_use = YLeaf(YType.boolean, "pw-status-use")

                        self.pwlsd_rewrite_failed = YLeaf(YType.boolean, "pwlsd-rewrite-failed")

                        self.remote_control_word = YLeaf(YType.enumeration, "remote-control-word")

                        self.remote_label_failed = YLeaf(YType.boolean, "remote-label-failed")

                        self.remote_pseudo_wire_type = YLeaf(YType.enumeration, "remote-pseudo-wire-type")

                        self.required_bw = YLeaf(YType.uint32, "required-bw")

                        self.resync_enabled = YLeaf(YType.boolean, "resync-enabled")

                        self.resync_threshold = YLeaf(YType.uint32, "resync-threshold")

                        self.rtp_mismatched = YLeaf(YType.boolean, "rtp-mismatched")

                        self.sequencing_type = YLeaf(YType.enumeration, "sequencing-type")

                        self.shutdown = YLeaf(YType.boolean, "shutdown")

                        self.sig_pkts_mismatched = YLeaf(YType.boolean, "sig-pkts-mismatched")

                        self.ssrc_mismatched = YLeaf(YType.boolean, "ssrc-mismatched")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.table_policy_name = YLeaf(YType.str, "table-policy-name")

                        self.tag_rewrite = YLeaf(YType.uint16, "tag-rewrite")

                        self.time_created = YLeaf(YType.str, "time-created")

                        self.time_elapsed_creation = YLeaf(YType.str, "time-elapsed-creation")

                        self.time_elapsed_status_changed = YLeaf(YType.str, "time-elapsed-status-changed")

                        self.time_elapsed_status_down = YLeaf(YType.uint32, "time-elapsed-status-down")

                        self.transport_lsp_down = YLeaf(YType.boolean, "transport-lsp-down")

                        self.xconnect_id = YLeaf(YType.uint32, "xconnect-id")

                        self.encapsulation_info = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self._children_name_map["encapsulation_info"] = "encapsulation-info"
                        self._children_yang_names.add("encapsulation-info")

                        self.local_interface = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                        self.local_interface.parent = self
                        self._children_name_map["local_interface"] = "local-interface"
                        self._children_yang_names.add("local-interface")

                        self.local_signalling = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                        self.local_signalling.parent = self
                        self._children_name_map["local_signalling"] = "local-signalling"
                        self._children_yang_names.add("local-signalling")

                        self.p2mp_pw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                        self.p2mp_pw.parent = self
                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                        self._children_yang_names.add("p2mp-pw")

                        self.peer_id = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                        self.peer_id.parent = self
                        self._children_name_map["peer_id"] = "peer-id"
                        self._children_yang_names.add("peer-id")

                        self.preferred_path = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                        self.preferred_path.parent = self
                        self._children_name_map["preferred_path"] = "preferred-path"
                        self._children_yang_names.add("preferred-path")

                        self.remote_interface = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                        self.remote_interface.parent = self
                        self._children_name_map["remote_interface"] = "remote-interface"
                        self._children_yang_names.add("remote-interface")

                        self.remote_signalling = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                        self.remote_signalling.parent = self
                        self._children_name_map["remote_signalling"] = "remote-signalling"
                        self._children_yang_names.add("remote-signalling")

                        self.statistics = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ad_method",
                                        "ad_remote_down",
                                        "admited_bw",
                                        "auto_discovery",
                                        "backup_active",
                                        "backup_force_active",
                                        "backup_pw",
                                        "bitrate_mismatched",
                                        "bridge_pw_type_mismatch",
                                        "cas_mismatched",
                                        "diff_ts_mismatched",
                                        "disable_delay",
                                        "disable_never",
                                        "evpn_src_acid",
                                        "fe_ctype",
                                        "forward_class",
                                        "freq_mismatched",
                                        "illegal_control_word",
                                        "imposed_vlan_id",
                                        "interworking",
                                        "ipv6_local_source_address",
                                        "is_evpnvpws_type",
                                        "is_flow_label_static",
                                        "is_multi_segment_pseudowire",
                                        "is_partially_programmed",
                                        "is_pwr_type",
                                        "is_vfi",
                                        "last_time_status_changed",
                                        "last_time_status_down",
                                        "ldp_label_advertise_failed",
                                        "load_balance",
                                        "local_control_word",
                                        "local_label_failed",
                                        "local_pseudo_wire_type",
                                        "local_source_address",
                                        "mac_limit_oper_down",
                                        "mtu_mismatched",
                                        "not_supported_qinq",
                                        "num_ma_cwithdraw_msg_received",
                                        "number_ma_cwithdraw_message_sent",
                                        "out_of_memory_state",
                                        "payload_bytes_mismatched",
                                        "payload_type_mismatched",
                                        "preferred_path_disable_fallback",
                                        "primary_peer_id",
                                        "primary_pseudo_wire_id",
                                        "primary_pw",
                                        "protocol",
                                        "pseudo_wire_id",
                                        "pseudo_wire_state",
                                        "pseudo_wire_type_mismatched",
                                        "pw_class_name",
                                        "pw_flow_label_code17_disabled",
                                        "pw_flow_label_type",
                                        "pw_flow_label_type_cfg",
                                        "pw_redundancy_initial_delay",
                                        "pw_redundancy_one_way",
                                        "pw_status_use",
                                        "pwlsd_rewrite_failed",
                                        "remote_control_word",
                                        "remote_label_failed",
                                        "remote_pseudo_wire_type",
                                        "required_bw",
                                        "resync_enabled",
                                        "resync_threshold",
                                        "rtp_mismatched",
                                        "sequencing_type",
                                        "shutdown",
                                        "sig_pkts_mismatched",
                                        "ssrc_mismatched",
                                        "state",
                                        "table_policy_name",
                                        "tag_rewrite",
                                        "time_created",
                                        "time_elapsed_creation",
                                        "time_elapsed_status_changed",
                                        "time_elapsed_status_down",
                                        "transport_lsp_down",
                                        "xconnect_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__setattr__(name, value)


                    class PeerId(Entity):
                        """
                        Peer
                        
                        .. attribute:: internal_label
                        
                        	Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_peer_id
                        
                        	Peer IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_peer_id
                        
                        	Peer IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: type
                        
                        	type
                        	**type**\:   :py:class:`L2VpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeer>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__init__()

                            self.yang_name = "peer-id"
                            self.yang_parent_name = "pseudowire"

                            self.internal_label = YLeaf(YType.uint32, "internal-label")

                            self.ipv4_peer_id = YLeaf(YType.str, "ipv4-peer-id")

                            self.ipv6_peer_id = YLeaf(YType.str, "ipv6-peer-id")

                            self.type = YLeaf(YType.enumeration, "type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("internal_label",
                                            "ipv4_peer_id",
                                            "ipv6_peer_id",
                                            "type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.internal_label.is_set or
                                self.ipv4_peer_id.is_set or
                                self.ipv6_peer_id.is_set or
                                self.type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.internal_label.yfilter != YFilter.not_set or
                                self.ipv4_peer_id.yfilter != YFilter.not_set or
                                self.ipv6_peer_id.yfilter != YFilter.not_set or
                                self.type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "peer-id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_label.get_name_leafdata())
                            if (self.ipv4_peer_id.is_set or self.ipv4_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_peer_id.get_name_leafdata())
                            if (self.ipv6_peer_id.is_set or self.ipv6_peer_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_peer_id.get_name_leafdata())
                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "internal-label" or name == "ipv4-peer-id" or name == "ipv6-peer-id" or name == "type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "internal-label"):
                                self.internal_label = value
                                self.internal_label.value_namespace = name_space
                                self.internal_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-peer-id"):
                                self.ipv4_peer_id = value
                                self.ipv4_peer_id.value_namespace = name_space
                                self.ipv4_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-peer-id"):
                                self.ipv6_peer_id = value
                                self.ipv6_peer_id.value_namespace = name_space
                                self.ipv6_peer_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "type"):
                                self.type = value
                                self.type.value_namespace = name_space
                                self.type.value_namespace_prefix = name_space_prefix


                    class EncapsulationInfo(Entity):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: atom
                        
                        	atom
                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethod>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__init__()

                            self.yang_name = "encapsulation-info"
                            self.yang_parent_name = "pseudowire"

                            self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                            self.atom = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                            self.atom.parent = self
                            self._children_name_map["atom"] = "atom"
                            self._children_yang_names.add("atom")

                            self.l2tpv3 = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self
                            self._children_name_map["l2tpv3"] = "l2tpv3"
                            self._children_yang_names.add("l2tpv3")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("encapsulation") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__setattr__(name, value)


                        class Atom(Entity):
                            """
                            atom
                            
                            .. attribute:: is_pseudowire_headend
                            
                            	Is this connected to a PW\-HE AC
                            	**type**\:  bool
                            
                            .. attribute:: is_sai_itype2
                            
                            	Is SAII FEC129 Type 2
                            	**type**\:  bool
                            
                            .. attribute:: is_tai_itype2
                            
                            	Is TAII type 2
                            	**type**\:  bool
                            
                            .. attribute:: ldp_label_advertisment_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: local_agi
                            
                            	Local Attachment Group Identifier
                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                            
                            .. attribute:: local_c_ctype
                            
                            	Local VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_ceid
                            
                            	Local CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cv_type
                            
                            	Local VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_group_id
                            
                            	Local group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ldp_id
                            
                            	Local LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_saii_gbl_id
                            
                            	Local SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_saiiac_id
                            
                            	Local SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taii_gbl_id
                            
                            	Local TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taiiac_id
                            
                            	Local TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_veid
                            
                            	Local VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: multi_segment_pseudowire_stats
                            
                            	Multisegment pseudowire statistics
                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                            
                            .. attribute:: rem_saii
                            
                            	Remote Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_saii_gbl_id
                            
                            	Remote SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_saiiac_id
                            
                            	Remote SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taii
                            
                            	Remote Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_taii_gbl_id
                            
                            	Remote TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taiiac_id
                            
                            	Remote TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_agi
                            
                            	Remote Attachment Group Identifier
                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                            
                            .. attribute:: remote_c_ctype
                            
                            	Remote VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_ceid
                            
                            	Remote CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cv_type
                            
                            	Remote VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_group_id
                            
                            	Remote group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_label
                            
                            	Remote label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ldp_id
                            
                            	Remote LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_source_address
                            
                            	Remote BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_veid
                            
                            	Remote VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_address
                            
                            	Local BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                self.yang_name = "atom"
                                self.yang_parent_name = "encapsulation-info"

                                self.is_pseudowire_headend = YLeaf(YType.boolean, "is-pseudowire-headend")

                                self.is_sai_itype2 = YLeaf(YType.boolean, "is-sai-itype2")

                                self.is_tai_itype2 = YLeaf(YType.boolean, "is-tai-itype2")

                                self.ldp_label_advertisment_failed = YLeaf(YType.boolean, "ldp-label-advertisment-failed")

                                self.local_c_ctype = YLeaf(YType.uint8, "local-c-ctype")

                                self.local_ceid = YLeaf(YType.uint32, "local-ceid")

                                self.local_cv_type = YLeaf(YType.uint8, "local-cv-type")

                                self.local_group_id = YLeaf(YType.uint32, "local-group-id")

                                self.local_label = YLeaf(YType.uint32, "local-label")

                                self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                self.local_saii_gbl_id = YLeaf(YType.uint32, "local-saii-gbl-id")

                                self.local_saiiac_id = YLeaf(YType.uint32, "local-saiiac-id")

                                self.local_taii_gbl_id = YLeaf(YType.uint32, "local-taii-gbl-id")

                                self.local_taiiac_id = YLeaf(YType.uint32, "local-taiiac-id")

                                self.local_veid = YLeaf(YType.uint32, "local-veid")

                                self.lsd_rewrite_failed = YLeaf(YType.boolean, "lsd-rewrite-failed")

                                self.rem_saii = YLeaf(YType.str, "rem-saii")

                                self.rem_saii_gbl_id = YLeaf(YType.uint32, "rem-saii-gbl-id")

                                self.rem_saiiac_id = YLeaf(YType.uint32, "rem-saiiac-id")

                                self.rem_taii = YLeaf(YType.str, "rem-taii")

                                self.rem_taii_gbl_id = YLeaf(YType.uint32, "rem-taii-gbl-id")

                                self.rem_taiiac_id = YLeaf(YType.uint32, "rem-taiiac-id")

                                self.remote_c_ctype = YLeaf(YType.uint8, "remote-c-ctype")

                                self.remote_ceid = YLeaf(YType.uint32, "remote-ceid")

                                self.remote_cv_type = YLeaf(YType.uint8, "remote-cv-type")

                                self.remote_group_id = YLeaf(YType.uint32, "remote-group-id")

                                self.remote_label = YLeaf(YType.uint32, "remote-label")

                                self.remote_ldp_id = YLeaf(YType.str, "remote-ldp-id")

                                self.remote_source_address = YLeaf(YType.str, "remote-source-address")

                                self.remote_veid = YLeaf(YType.uint32, "remote-veid")

                                self.saii = YLeaf(YType.str, "saii")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.taii = YLeaf(YType.str, "taii")

                                self.local_agi = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                self.local_agi.parent = self
                                self._children_name_map["local_agi"] = "local-agi"
                                self._children_yang_names.add("local-agi")

                                self.multi_segment_pseudowire_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                self.multi_segment_pseudowire_stats.parent = self
                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                self._children_yang_names.add("multi-segment-pseudowire-stats")

                                self.remote_agi = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                self.remote_agi.parent = self
                                self._children_name_map["remote_agi"] = "remote-agi"
                                self._children_yang_names.add("remote-agi")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_pseudowire_headend",
                                                "is_sai_itype2",
                                                "is_tai_itype2",
                                                "ldp_label_advertisment_failed",
                                                "local_c_ctype",
                                                "local_ceid",
                                                "local_cv_type",
                                                "local_group_id",
                                                "local_label",
                                                "local_ldp_id",
                                                "local_saii_gbl_id",
                                                "local_saiiac_id",
                                                "local_taii_gbl_id",
                                                "local_taiiac_id",
                                                "local_veid",
                                                "lsd_rewrite_failed",
                                                "rem_saii",
                                                "rem_saii_gbl_id",
                                                "rem_saiiac_id",
                                                "rem_taii",
                                                "rem_taii_gbl_id",
                                                "rem_taiiac_id",
                                                "remote_c_ctype",
                                                "remote_ceid",
                                                "remote_cv_type",
                                                "remote_group_id",
                                                "remote_label",
                                                "remote_ldp_id",
                                                "remote_source_address",
                                                "remote_veid",
                                                "saii",
                                                "source_address",
                                                "taii") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__setattr__(name, value)


                            class LocalAgi(Entity):
                                """
                                Local Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                    self.yang_name = "local-agi"
                                    self.yang_parent_name = "atom"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "local-agi"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "local-agi"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "local-agi"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local-agi" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class RemoteAgi(Entity):
                                """
                                Remote Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                    self.yang_name = "remote-agi"
                                    self.yang_parent_name = "atom"

                                    self.vpls_id_type = YLeaf(YType.enumeration, "vpls-id-type")

                                    self.auto = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"
                                    self._children_yang_names.add("auto")

                                    self.two_byte_as = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"
                                    self._children_yang_names.add("two-byte-as")

                                    self.v4_addr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._children_yang_names.add("v4-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("vpls_id_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__setattr__(name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "remote-agi"

                                        self.asn = YLeaf(YType.uint16, "asn")

                                        self.vpn_id = YLeaf(YType.uint32, "vpn-id")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("asn",
                                                        "vpn_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.asn.is_set or
                                            self.vpn_id.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.asn.yfilter != YFilter.not_set or
                                            self.vpn_id.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "auto" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.asn.is_set or self.asn.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.asn.get_name_leafdata())
                                        if (self.vpn_id.is_set or self.vpn_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vpn_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "asn" or name == "vpn-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "asn"):
                                            self.asn = value
                                            self.asn.value_namespace = name_space
                                            self.asn.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vpn-id"):
                                            self.vpn_id = value
                                            self.vpn_id.value_namespace = name_space
                                            self.vpn_id.value_namespace_prefix = name_space_prefix


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "remote-agi"

                                        self.four_byte_index = YLeaf(YType.uint32, "four-byte-index")

                                        self.two_byte_as = YLeaf(YType.uint16, "two-byte-as")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("four_byte_index",
                                                        "two_byte_as") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.four_byte_index.is_set or
                                            self.two_byte_as.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.four_byte_index.yfilter != YFilter.not_set or
                                            self.two_byte_as.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "two-byte-as" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.four_byte_index.is_set or self.four_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.four_byte_index.get_name_leafdata())
                                        if (self.two_byte_as.is_set or self.two_byte_as.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_as.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "four-byte-index" or name == "two-byte-as"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "four-byte-index"):
                                            self.four_byte_index = value
                                            self.four_byte_index.value_namespace = name_space
                                            self.four_byte_index.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-as"):
                                            self.two_byte_as = value
                                            self.two_byte_as.value_namespace = name_space
                                            self.two_byte_as.value_namespace_prefix = name_space_prefix


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "remote-agi"

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.two_byte_index = YLeaf(YType.uint16, "two-byte-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("ipv4_address",
                                                        "two_byte_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.ipv4_address.is_set or
                                            self.two_byte_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.two_byte_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "v4-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.two_byte_index.is_set or self.two_byte_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.two_byte_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ipv4-address" or name == "two-byte-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "two-byte-index"):
                                            self.two_byte_index = value
                                            self.two_byte_index.value_namespace = name_space
                                            self.two_byte_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.vpls_id_type.is_set or
                                        (self.auto is not None and self.auto.has_data()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_data()) or
                                        (self.v4_addr is not None and self.v4_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.vpls_id_type.yfilter != YFilter.not_set or
                                        (self.auto is not None and self.auto.has_operation()) or
                                        (self.two_byte_as is not None and self.two_byte_as.has_operation()) or
                                        (self.v4_addr is not None and self.v4_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-agi" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.vpls_id_type.is_set or self.vpls_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpls_id_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "auto"):
                                        if (self.auto is None):
                                            self.auto = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"
                                        return self.auto

                                    if (child_yang_name == "two-byte-as"):
                                        if (self.two_byte_as is None):
                                            self.two_byte_as = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"
                                        return self.two_byte_as

                                    if (child_yang_name == "v4-addr"):
                                        if (self.v4_addr is None):
                                            self.v4_addr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                        return self.v4_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "auto" or name == "two-byte-as" or name == "v4-addr" or name == "vpls-id-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "vpls-id-type"):
                                        self.vpls_id_type = value
                                        self.vpls_id_type.value_namespace = name_space
                                        self.vpls_id_type.value_namespace_prefix = name_space_prefix


                            class MultiSegmentPseudowireStats(Entity):
                                """
                                Multisegment pseudowire statistics
                                
                                .. attribute:: received_bytes
                                
                                	Bytes received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: received_packets
                                
                                	Packets received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                    self.yang_name = "multi-segment-pseudowire-stats"
                                    self.yang_parent_name = "atom"

                                    self.received_bytes = YLeaf(YType.uint64, "received-bytes")

                                    self.received_packets = YLeaf(YType.uint64, "received-packets")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("received_bytes",
                                                    "received_packets") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.received_bytes.is_set or
                                        self.received_packets.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.received_bytes.yfilter != YFilter.not_set or
                                        self.received_packets.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multi-segment-pseudowire-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.received_bytes.is_set or self.received_bytes.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_bytes.get_name_leafdata())
                                    if (self.received_packets.is_set or self.received_packets.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_packets.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-bytes" or name == "received-packets"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "received-bytes"):
                                        self.received_bytes = value
                                        self.received_bytes.value_namespace = name_space
                                        self.received_bytes.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-packets"):
                                        self.received_packets = value
                                        self.received_packets.value_namespace = name_space
                                        self.received_packets.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.is_pseudowire_headend.is_set or
                                    self.is_sai_itype2.is_set or
                                    self.is_tai_itype2.is_set or
                                    self.ldp_label_advertisment_failed.is_set or
                                    self.local_c_ctype.is_set or
                                    self.local_ceid.is_set or
                                    self.local_cv_type.is_set or
                                    self.local_group_id.is_set or
                                    self.local_label.is_set or
                                    self.local_ldp_id.is_set or
                                    self.local_saii_gbl_id.is_set or
                                    self.local_saiiac_id.is_set or
                                    self.local_taii_gbl_id.is_set or
                                    self.local_taiiac_id.is_set or
                                    self.local_veid.is_set or
                                    self.lsd_rewrite_failed.is_set or
                                    self.rem_saii.is_set or
                                    self.rem_saii_gbl_id.is_set or
                                    self.rem_saiiac_id.is_set or
                                    self.rem_taii.is_set or
                                    self.rem_taii_gbl_id.is_set or
                                    self.rem_taiiac_id.is_set or
                                    self.remote_c_ctype.is_set or
                                    self.remote_ceid.is_set or
                                    self.remote_cv_type.is_set or
                                    self.remote_group_id.is_set or
                                    self.remote_label.is_set or
                                    self.remote_ldp_id.is_set or
                                    self.remote_source_address.is_set or
                                    self.remote_veid.is_set or
                                    self.saii.is_set or
                                    self.source_address.is_set or
                                    self.taii.is_set or
                                    (self.local_agi is not None and self.local_agi.has_data()) or
                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_data()) or
                                    (self.remote_agi is not None and self.remote_agi.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_pseudowire_headend.yfilter != YFilter.not_set or
                                    self.is_sai_itype2.yfilter != YFilter.not_set or
                                    self.is_tai_itype2.yfilter != YFilter.not_set or
                                    self.ldp_label_advertisment_failed.yfilter != YFilter.not_set or
                                    self.local_c_ctype.yfilter != YFilter.not_set or
                                    self.local_ceid.yfilter != YFilter.not_set or
                                    self.local_cv_type.yfilter != YFilter.not_set or
                                    self.local_group_id.yfilter != YFilter.not_set or
                                    self.local_label.yfilter != YFilter.not_set or
                                    self.local_ldp_id.yfilter != YFilter.not_set or
                                    self.local_saii_gbl_id.yfilter != YFilter.not_set or
                                    self.local_saiiac_id.yfilter != YFilter.not_set or
                                    self.local_taii_gbl_id.yfilter != YFilter.not_set or
                                    self.local_taiiac_id.yfilter != YFilter.not_set or
                                    self.local_veid.yfilter != YFilter.not_set or
                                    self.lsd_rewrite_failed.yfilter != YFilter.not_set or
                                    self.rem_saii.yfilter != YFilter.not_set or
                                    self.rem_saii_gbl_id.yfilter != YFilter.not_set or
                                    self.rem_saiiac_id.yfilter != YFilter.not_set or
                                    self.rem_taii.yfilter != YFilter.not_set or
                                    self.rem_taii_gbl_id.yfilter != YFilter.not_set or
                                    self.rem_taiiac_id.yfilter != YFilter.not_set or
                                    self.remote_c_ctype.yfilter != YFilter.not_set or
                                    self.remote_ceid.yfilter != YFilter.not_set or
                                    self.remote_cv_type.yfilter != YFilter.not_set or
                                    self.remote_group_id.yfilter != YFilter.not_set or
                                    self.remote_label.yfilter != YFilter.not_set or
                                    self.remote_ldp_id.yfilter != YFilter.not_set or
                                    self.remote_source_address.yfilter != YFilter.not_set or
                                    self.remote_veid.yfilter != YFilter.not_set or
                                    self.saii.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.taii.yfilter != YFilter.not_set or
                                    (self.local_agi is not None and self.local_agi.has_operation()) or
                                    (self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats.has_operation()) or
                                    (self.remote_agi is not None and self.remote_agi.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "atom" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_pseudowire_headend.is_set or self.is_pseudowire_headend.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_pseudowire_headend.get_name_leafdata())
                                if (self.is_sai_itype2.is_set or self.is_sai_itype2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_sai_itype2.get_name_leafdata())
                                if (self.is_tai_itype2.is_set or self.is_tai_itype2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_tai_itype2.get_name_leafdata())
                                if (self.ldp_label_advertisment_failed.is_set or self.ldp_label_advertisment_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_label_advertisment_failed.get_name_leafdata())
                                if (self.local_c_ctype.is_set or self.local_c_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_c_ctype.get_name_leafdata())
                                if (self.local_ceid.is_set or self.local_ceid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ceid.get_name_leafdata())
                                if (self.local_cv_type.is_set or self.local_cv_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cv_type.get_name_leafdata())
                                if (self.local_group_id.is_set or self.local_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_group_id.get_name_leafdata())
                                if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_label.get_name_leafdata())
                                if (self.local_ldp_id.is_set or self.local_ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_ldp_id.get_name_leafdata())
                                if (self.local_saii_gbl_id.is_set or self.local_saii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_saii_gbl_id.get_name_leafdata())
                                if (self.local_saiiac_id.is_set or self.local_saiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_saiiac_id.get_name_leafdata())
                                if (self.local_taii_gbl_id.is_set or self.local_taii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_taii_gbl_id.get_name_leafdata())
                                if (self.local_taiiac_id.is_set or self.local_taiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_taiiac_id.get_name_leafdata())
                                if (self.local_veid.is_set or self.local_veid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_veid.get_name_leafdata())
                                if (self.lsd_rewrite_failed.is_set or self.lsd_rewrite_failed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsd_rewrite_failed.get_name_leafdata())
                                if (self.rem_saii.is_set or self.rem_saii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saii.get_name_leafdata())
                                if (self.rem_saii_gbl_id.is_set or self.rem_saii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saii_gbl_id.get_name_leafdata())
                                if (self.rem_saiiac_id.is_set or self.rem_saiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_saiiac_id.get_name_leafdata())
                                if (self.rem_taii.is_set or self.rem_taii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taii.get_name_leafdata())
                                if (self.rem_taii_gbl_id.is_set or self.rem_taii_gbl_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taii_gbl_id.get_name_leafdata())
                                if (self.rem_taiiac_id.is_set or self.rem_taiiac_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rem_taiiac_id.get_name_leafdata())
                                if (self.remote_c_ctype.is_set or self.remote_c_ctype.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_c_ctype.get_name_leafdata())
                                if (self.remote_ceid.is_set or self.remote_ceid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ceid.get_name_leafdata())
                                if (self.remote_cv_type.is_set or self.remote_cv_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cv_type.get_name_leafdata())
                                if (self.remote_group_id.is_set or self.remote_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_group_id.get_name_leafdata())
                                if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_label.get_name_leafdata())
                                if (self.remote_ldp_id.is_set or self.remote_ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_ldp_id.get_name_leafdata())
                                if (self.remote_source_address.is_set or self.remote_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_source_address.get_name_leafdata())
                                if (self.remote_veid.is_set or self.remote_veid.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_veid.get_name_leafdata())
                                if (self.saii.is_set or self.saii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.saii.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.taii.is_set or self.taii.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.taii.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "local-agi"):
                                    if (self.local_agi is None):
                                        self.local_agi = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"
                                    return self.local_agi

                                if (child_yang_name == "multi-segment-pseudowire-stats"):
                                    if (self.multi_segment_pseudowire_stats is None):
                                        self.multi_segment_pseudowire_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    return self.multi_segment_pseudowire_stats

                                if (child_yang_name == "remote-agi"):
                                    if (self.remote_agi is None):
                                        self.remote_agi = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"
                                    return self.remote_agi

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-agi" or name == "multi-segment-pseudowire-stats" or name == "remote-agi" or name == "is-pseudowire-headend" or name == "is-sai-itype2" or name == "is-tai-itype2" or name == "ldp-label-advertisment-failed" or name == "local-c-ctype" or name == "local-ceid" or name == "local-cv-type" or name == "local-group-id" or name == "local-label" or name == "local-ldp-id" or name == "local-saii-gbl-id" or name == "local-saiiac-id" or name == "local-taii-gbl-id" or name == "local-taiiac-id" or name == "local-veid" or name == "lsd-rewrite-failed" or name == "rem-saii" or name == "rem-saii-gbl-id" or name == "rem-saiiac-id" or name == "rem-taii" or name == "rem-taii-gbl-id" or name == "rem-taiiac-id" or name == "remote-c-ctype" or name == "remote-ceid" or name == "remote-cv-type" or name == "remote-group-id" or name == "remote-label" or name == "remote-ldp-id" or name == "remote-source-address" or name == "remote-veid" or name == "saii" or name == "source-address" or name == "taii"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-pseudowire-headend"):
                                    self.is_pseudowire_headend = value
                                    self.is_pseudowire_headend.value_namespace = name_space
                                    self.is_pseudowire_headend.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-sai-itype2"):
                                    self.is_sai_itype2 = value
                                    self.is_sai_itype2.value_namespace = name_space
                                    self.is_sai_itype2.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-tai-itype2"):
                                    self.is_tai_itype2 = value
                                    self.is_tai_itype2.value_namespace = name_space
                                    self.is_tai_itype2.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-label-advertisment-failed"):
                                    self.ldp_label_advertisment_failed = value
                                    self.ldp_label_advertisment_failed.value_namespace = name_space
                                    self.ldp_label_advertisment_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-c-ctype"):
                                    self.local_c_ctype = value
                                    self.local_c_ctype.value_namespace = name_space
                                    self.local_c_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ceid"):
                                    self.local_ceid = value
                                    self.local_ceid.value_namespace = name_space
                                    self.local_ceid.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cv-type"):
                                    self.local_cv_type = value
                                    self.local_cv_type.value_namespace = name_space
                                    self.local_cv_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-group-id"):
                                    self.local_group_id = value
                                    self.local_group_id.value_namespace = name_space
                                    self.local_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-label"):
                                    self.local_label = value
                                    self.local_label.value_namespace = name_space
                                    self.local_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-ldp-id"):
                                    self.local_ldp_id = value
                                    self.local_ldp_id.value_namespace = name_space
                                    self.local_ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-saii-gbl-id"):
                                    self.local_saii_gbl_id = value
                                    self.local_saii_gbl_id.value_namespace = name_space
                                    self.local_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-saiiac-id"):
                                    self.local_saiiac_id = value
                                    self.local_saiiac_id.value_namespace = name_space
                                    self.local_saiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-taii-gbl-id"):
                                    self.local_taii_gbl_id = value
                                    self.local_taii_gbl_id.value_namespace = name_space
                                    self.local_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-taiiac-id"):
                                    self.local_taiiac_id = value
                                    self.local_taiiac_id.value_namespace = name_space
                                    self.local_taiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-veid"):
                                    self.local_veid = value
                                    self.local_veid.value_namespace = name_space
                                    self.local_veid.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsd-rewrite-failed"):
                                    self.lsd_rewrite_failed = value
                                    self.lsd_rewrite_failed.value_namespace = name_space
                                    self.lsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saii"):
                                    self.rem_saii = value
                                    self.rem_saii.value_namespace = name_space
                                    self.rem_saii.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saii-gbl-id"):
                                    self.rem_saii_gbl_id = value
                                    self.rem_saii_gbl_id.value_namespace = name_space
                                    self.rem_saii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-saiiac-id"):
                                    self.rem_saiiac_id = value
                                    self.rem_saiiac_id.value_namespace = name_space
                                    self.rem_saiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taii"):
                                    self.rem_taii = value
                                    self.rem_taii.value_namespace = name_space
                                    self.rem_taii.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taii-gbl-id"):
                                    self.rem_taii_gbl_id = value
                                    self.rem_taii_gbl_id.value_namespace = name_space
                                    self.rem_taii_gbl_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "rem-taiiac-id"):
                                    self.rem_taiiac_id = value
                                    self.rem_taiiac_id.value_namespace = name_space
                                    self.rem_taiiac_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-c-ctype"):
                                    self.remote_c_ctype = value
                                    self.remote_c_ctype.value_namespace = name_space
                                    self.remote_c_ctype.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ceid"):
                                    self.remote_ceid = value
                                    self.remote_ceid.value_namespace = name_space
                                    self.remote_ceid.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cv-type"):
                                    self.remote_cv_type = value
                                    self.remote_cv_type.value_namespace = name_space
                                    self.remote_cv_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-group-id"):
                                    self.remote_group_id = value
                                    self.remote_group_id.value_namespace = name_space
                                    self.remote_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-label"):
                                    self.remote_label = value
                                    self.remote_label.value_namespace = name_space
                                    self.remote_label.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-ldp-id"):
                                    self.remote_ldp_id = value
                                    self.remote_ldp_id.value_namespace = name_space
                                    self.remote_ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-source-address"):
                                    self.remote_source_address = value
                                    self.remote_source_address.value_namespace = name_space
                                    self.remote_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-veid"):
                                    self.remote_veid = value
                                    self.remote_veid.value_namespace = name_space
                                    self.remote_veid.value_namespace_prefix = name_space_prefix
                                if(value_path == "saii"):
                                    self.saii = value
                                    self.saii.value_namespace = name_space
                                    self.saii.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "taii"):
                                    self.taii = value
                                    self.taii.value_namespace = name_space
                                    self.taii.value_namespace_prefix = name_space_prefix


                        class L2Tpv3(Entity):
                            """
                            l2tpv3
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_source_address
                            
                            	IPv6 source address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: local_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_size
                            
                            	Local cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_secondary_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_size
                            
                            	Local secondary cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_session_id
                            
                            	Local session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: remote_circuit_status_up
                            
                            	RemoteCircuitStatusUp
                            	**type**\:  bool
                            
                            .. attribute:: remote_cookie_high_value
                            
                            	Upper 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_low_value
                            
                            	Lower 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_size
                            
                            	Remote cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_session_id
                            
                            	Remote session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosMode>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_state
                            
                            	L2TP tunnel state
                            	**type**\:   :py:class:`L2VpnL2TpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__init__()

                                self.yang_name = "l2tpv3"
                                self.yang_parent_name = "encapsulation-info"

                                self.dont_fragment_bit = YLeaf(YType.boolean, "dont-fragment-bit")

                                self.ipv4_source_address = YLeaf(YType.str, "ipv4-source-address")

                                self.ipv6_source_address = YLeaf(YType.str, "ipv6-source-address")

                                self.l2tp_class_name = YLeaf(YType.str, "l2tp-class-name")

                                self.local_cookie_high_value = YLeaf(YType.uint32, "local-cookie-high-value")

                                self.local_cookie_low_value = YLeaf(YType.uint32, "local-cookie-low-value")

                                self.local_cookie_size = YLeaf(YType.uint8, "local-cookie-size")

                                self.local_secondary_cookie_high_value = YLeaf(YType.uint32, "local-secondary-cookie-high-value")

                                self.local_secondary_cookie_low_value = YLeaf(YType.uint32, "local-secondary-cookie-low-value")

                                self.local_secondary_cookie_size = YLeaf(YType.uint8, "local-secondary-cookie-size")

                                self.local_session_id = YLeaf(YType.uint32, "local-session-id")

                                self.path_mtu_enabled = YLeaf(YType.boolean, "path-mtu-enabled")

                                self.path_mtu_max_value = YLeaf(YType.uint16, "path-mtu-max-value")

                                self.remote_circuit_status_up = YLeaf(YType.boolean, "remote-circuit-status-up")

                                self.remote_cookie_high_value = YLeaf(YType.uint32, "remote-cookie-high-value")

                                self.remote_cookie_low_value = YLeaf(YType.uint32, "remote-cookie-low-value")

                                self.remote_cookie_size = YLeaf(YType.uint8, "remote-cookie-size")

                                self.remote_session_id = YLeaf(YType.uint32, "remote-session-id")

                                self.tos = YLeaf(YType.uint8, "tos")

                                self.tos_mode = YLeaf(YType.enumeration, "tos-mode")

                                self.ttl = YLeaf(YType.uint8, "ttl")

                                self.tunnel_state = YLeaf(YType.enumeration, "tunnel-state")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dont_fragment_bit",
                                                "ipv4_source_address",
                                                "ipv6_source_address",
                                                "l2tp_class_name",
                                                "local_cookie_high_value",
                                                "local_cookie_low_value",
                                                "local_cookie_size",
                                                "local_secondary_cookie_high_value",
                                                "local_secondary_cookie_low_value",
                                                "local_secondary_cookie_size",
                                                "local_session_id",
                                                "path_mtu_enabled",
                                                "path_mtu_max_value",
                                                "remote_circuit_status_up",
                                                "remote_cookie_high_value",
                                                "remote_cookie_low_value",
                                                "remote_cookie_size",
                                                "remote_session_id",
                                                "tos",
                                                "tos_mode",
                                                "ttl",
                                                "tunnel_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dont_fragment_bit.is_set or
                                    self.ipv4_source_address.is_set or
                                    self.ipv6_source_address.is_set or
                                    self.l2tp_class_name.is_set or
                                    self.local_cookie_high_value.is_set or
                                    self.local_cookie_low_value.is_set or
                                    self.local_cookie_size.is_set or
                                    self.local_secondary_cookie_high_value.is_set or
                                    self.local_secondary_cookie_low_value.is_set or
                                    self.local_secondary_cookie_size.is_set or
                                    self.local_session_id.is_set or
                                    self.path_mtu_enabled.is_set or
                                    self.path_mtu_max_value.is_set or
                                    self.remote_circuit_status_up.is_set or
                                    self.remote_cookie_high_value.is_set or
                                    self.remote_cookie_low_value.is_set or
                                    self.remote_cookie_size.is_set or
                                    self.remote_session_id.is_set or
                                    self.tos.is_set or
                                    self.tos_mode.is_set or
                                    self.ttl.is_set or
                                    self.tunnel_state.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dont_fragment_bit.yfilter != YFilter.not_set or
                                    self.ipv4_source_address.yfilter != YFilter.not_set or
                                    self.ipv6_source_address.yfilter != YFilter.not_set or
                                    self.l2tp_class_name.yfilter != YFilter.not_set or
                                    self.local_cookie_high_value.yfilter != YFilter.not_set or
                                    self.local_cookie_low_value.yfilter != YFilter.not_set or
                                    self.local_cookie_size.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_high_value.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_low_value.yfilter != YFilter.not_set or
                                    self.local_secondary_cookie_size.yfilter != YFilter.not_set or
                                    self.local_session_id.yfilter != YFilter.not_set or
                                    self.path_mtu_enabled.yfilter != YFilter.not_set or
                                    self.path_mtu_max_value.yfilter != YFilter.not_set or
                                    self.remote_circuit_status_up.yfilter != YFilter.not_set or
                                    self.remote_cookie_high_value.yfilter != YFilter.not_set or
                                    self.remote_cookie_low_value.yfilter != YFilter.not_set or
                                    self.remote_cookie_size.yfilter != YFilter.not_set or
                                    self.remote_session_id.yfilter != YFilter.not_set or
                                    self.tos.yfilter != YFilter.not_set or
                                    self.tos_mode.yfilter != YFilter.not_set or
                                    self.ttl.yfilter != YFilter.not_set or
                                    self.tunnel_state.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "l2tpv3" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dont_fragment_bit.is_set or self.dont_fragment_bit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dont_fragment_bit.get_name_leafdata())
                                if (self.ipv4_source_address.is_set or self.ipv4_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_source_address.get_name_leafdata())
                                if (self.ipv6_source_address.is_set or self.ipv6_source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_source_address.get_name_leafdata())
                                if (self.l2tp_class_name.is_set or self.l2tp_class_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.l2tp_class_name.get_name_leafdata())
                                if (self.local_cookie_high_value.is_set or self.local_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_high_value.get_name_leafdata())
                                if (self.local_cookie_low_value.is_set or self.local_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_low_value.get_name_leafdata())
                                if (self.local_cookie_size.is_set or self.local_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_cookie_size.get_name_leafdata())
                                if (self.local_secondary_cookie_high_value.is_set or self.local_secondary_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_high_value.get_name_leafdata())
                                if (self.local_secondary_cookie_low_value.is_set or self.local_secondary_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_low_value.get_name_leafdata())
                                if (self.local_secondary_cookie_size.is_set or self.local_secondary_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_secondary_cookie_size.get_name_leafdata())
                                if (self.local_session_id.is_set or self.local_session_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_session_id.get_name_leafdata())
                                if (self.path_mtu_enabled.is_set or self.path_mtu_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_enabled.get_name_leafdata())
                                if (self.path_mtu_max_value.is_set or self.path_mtu_max_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_mtu_max_value.get_name_leafdata())
                                if (self.remote_circuit_status_up.is_set or self.remote_circuit_status_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_circuit_status_up.get_name_leafdata())
                                if (self.remote_cookie_high_value.is_set or self.remote_cookie_high_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_high_value.get_name_leafdata())
                                if (self.remote_cookie_low_value.is_set or self.remote_cookie_low_value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_low_value.get_name_leafdata())
                                if (self.remote_cookie_size.is_set or self.remote_cookie_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_cookie_size.get_name_leafdata())
                                if (self.remote_session_id.is_set or self.remote_session_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_session_id.get_name_leafdata())
                                if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos.get_name_leafdata())
                                if (self.tos_mode.is_set or self.tos_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tos_mode.get_name_leafdata())
                                if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ttl.get_name_leafdata())
                                if (self.tunnel_state.is_set or self.tunnel_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dont-fragment-bit" or name == "ipv4-source-address" or name == "ipv6-source-address" or name == "l2tp-class-name" or name == "local-cookie-high-value" or name == "local-cookie-low-value" or name == "local-cookie-size" or name == "local-secondary-cookie-high-value" or name == "local-secondary-cookie-low-value" or name == "local-secondary-cookie-size" or name == "local-session-id" or name == "path-mtu-enabled" or name == "path-mtu-max-value" or name == "remote-circuit-status-up" or name == "remote-cookie-high-value" or name == "remote-cookie-low-value" or name == "remote-cookie-size" or name == "remote-session-id" or name == "tos" or name == "tos-mode" or name == "ttl" or name == "tunnel-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dont-fragment-bit"):
                                    self.dont_fragment_bit = value
                                    self.dont_fragment_bit.value_namespace = name_space
                                    self.dont_fragment_bit.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-source-address"):
                                    self.ipv4_source_address = value
                                    self.ipv4_source_address.value_namespace = name_space
                                    self.ipv4_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-source-address"):
                                    self.ipv6_source_address = value
                                    self.ipv6_source_address.value_namespace = name_space
                                    self.ipv6_source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "l2tp-class-name"):
                                    self.l2tp_class_name = value
                                    self.l2tp_class_name.value_namespace = name_space
                                    self.l2tp_class_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-high-value"):
                                    self.local_cookie_high_value = value
                                    self.local_cookie_high_value.value_namespace = name_space
                                    self.local_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-low-value"):
                                    self.local_cookie_low_value = value
                                    self.local_cookie_low_value.value_namespace = name_space
                                    self.local_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-cookie-size"):
                                    self.local_cookie_size = value
                                    self.local_cookie_size.value_namespace = name_space
                                    self.local_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-high-value"):
                                    self.local_secondary_cookie_high_value = value
                                    self.local_secondary_cookie_high_value.value_namespace = name_space
                                    self.local_secondary_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-low-value"):
                                    self.local_secondary_cookie_low_value = value
                                    self.local_secondary_cookie_low_value.value_namespace = name_space
                                    self.local_secondary_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-secondary-cookie-size"):
                                    self.local_secondary_cookie_size = value
                                    self.local_secondary_cookie_size.value_namespace = name_space
                                    self.local_secondary_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-session-id"):
                                    self.local_session_id = value
                                    self.local_session_id.value_namespace = name_space
                                    self.local_session_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-enabled"):
                                    self.path_mtu_enabled = value
                                    self.path_mtu_enabled.value_namespace = name_space
                                    self.path_mtu_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-mtu-max-value"):
                                    self.path_mtu_max_value = value
                                    self.path_mtu_max_value.value_namespace = name_space
                                    self.path_mtu_max_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-circuit-status-up"):
                                    self.remote_circuit_status_up = value
                                    self.remote_circuit_status_up.value_namespace = name_space
                                    self.remote_circuit_status_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-high-value"):
                                    self.remote_cookie_high_value = value
                                    self.remote_cookie_high_value.value_namespace = name_space
                                    self.remote_cookie_high_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-low-value"):
                                    self.remote_cookie_low_value = value
                                    self.remote_cookie_low_value.value_namespace = name_space
                                    self.remote_cookie_low_value.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-cookie-size"):
                                    self.remote_cookie_size = value
                                    self.remote_cookie_size.value_namespace = name_space
                                    self.remote_cookie_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-session-id"):
                                    self.remote_session_id = value
                                    self.remote_session_id.value_namespace = name_space
                                    self.remote_session_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos"):
                                    self.tos = value
                                    self.tos.value_namespace = name_space
                                    self.tos.value_namespace_prefix = name_space_prefix
                                if(value_path == "tos-mode"):
                                    self.tos_mode = value
                                    self.tos_mode.value_namespace = name_space
                                    self.tos_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "ttl"):
                                    self.ttl = value
                                    self.ttl.value_namespace = name_space
                                    self.ttl.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-state"):
                                    self.tunnel_state = value
                                    self.tunnel_state.value_namespace = name_space
                                    self.tunnel_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.encapsulation.is_set or
                                (self.atom is not None and self.atom.has_data()) or
                                (self.l2tpv3 is not None and self.l2tpv3.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.encapsulation.yfilter != YFilter.not_set or
                                (self.atom is not None and self.atom.has_operation()) or
                                (self.l2tpv3 is not None and self.l2tpv3.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "encapsulation-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.encapsulation.is_set or self.encapsulation.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.encapsulation.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "atom"):
                                if (self.atom is None):
                                    self.atom = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                return self.atom

                            if (child_yang_name == "l2tpv3"):
                                if (self.l2tpv3 is None):
                                    self.l2tpv3 = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                return self.l2tpv3

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "atom" or name == "l2tpv3" or name == "encapsulation"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "encapsulation"):
                                self.encapsulation = value
                                self.encapsulation.value_namespace = name_space
                                self.encapsulation.value_namespace_prefix = name_space_prefix


                    class LocalInterface(Entity):
                        """
                        Local interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__init__()

                            self.yang_name = "local-interface"
                            self.yang_parent_name = "pseudowire"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "local-interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class RemoteInterface(Entity):
                        """
                        Remote interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__init__()

                            self.yang_name = "remote-interface"
                            self.yang_parent_name = "pseudowire"

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.name = YLeaf(YType.str, "name")

                            self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                            self.parameters = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                            self.parameters.parent = self
                            self._children_name_map["parameters"] = "parameters"
                            self._children_yang_names.add("parameters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mtu",
                                            "name",
                                            "payload_bytes") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__setattr__(name, value)


                        class Parameters(Entity):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterface>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                self.yang_name = "parameters"
                                self.yang_parent_name = "remote-interface"

                                self.type = YLeaf(YType.enumeration, "type")

                                self.atm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                self.atm.parent = self
                                self._children_name_map["atm"] = "atm"
                                self._children_yang_names.add("atm")

                                self.ethernet = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self._children_name_map["ethernet"] = "ethernet"
                                self._children_yang_names.add("ethernet")

                                self.fr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                self.fr.parent = self
                                self._children_name_map["fr"] = "fr"
                                self._children_yang_names.add("fr")

                                self.pseudowire_ether = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                self._children_yang_names.add("pseudowire-ether")

                                self.pseudowire_iw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                self._children_yang_names.add("pseudowire-iw")

                                self.tdm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self._children_name_map["tdm"] = "tdm"
                                self._children_yang_names.add("tdm")

                                self.vlan = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                self.vlan.parent = self
                                self._children_name_map["vlan"] = "vlan"
                                self._children_yang_names.add("vlan")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__setattr__(name, value)


                            class Ethernet(Entity):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                    self.yang_name = "ethernet"
                                    self.yang_parent_name = "parameters"

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.xconnect_tags.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Vlan(Entity):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                    self.yang_name = "vlan"
                                    self.yang_parent_name = "parameters"

                                    self.encapsulation_type = YLeaf(YType.uint8, "encapsulation-type")

                                    self.outer_tag = YLeaf(YType.uint16, "outer-tag")

                                    self.rewrite_tag = YLeafList(YType.uint16, "rewrite-tag")

                                    self.simple_efp = YLeaf(YType.uint8, "simple-efp")

                                    self.vlan_rewrite_tag = YLeaf(YType.uint16, "vlan-rewrite-tag")

                                    self.xconnect_tags = YLeaf(YType.uint8, "xconnect-tags")

                                    self.vlan_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("encapsulation_type",
                                                    "outer_tag",
                                                    "rewrite_tag",
                                                    "simple_efp",
                                                    "vlan_rewrite_tag",
                                                    "xconnect_tags") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__setattr__(name, value)


                                class VlanRange(Entity):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "vlan"

                                        self.lower = YLeaf(YType.uint16, "lower")

                                        self.upper = YLeaf(YType.uint16, "upper")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("lower",
                                                        "upper") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.lower.is_set or
                                            self.upper.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.lower.yfilter != YFilter.not_set or
                                            self.upper.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "vlan-range" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.lower.is_set or self.lower.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lower.get_name_leafdata())
                                        if (self.upper.is_set or self.upper.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.upper.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "lower" or name == "upper"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "lower"):
                                            self.lower = value
                                            self.lower.value_namespace = name_space
                                            self.lower.value_namespace_prefix = name_space_prefix
                                        if(value_path == "upper"):
                                            self.upper = value
                                            self.upper.value_namespace = name_space
                                            self.upper.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.vlan_range:
                                        if (c.has_data()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.yfilter != YFilter.not_set):
                                            return True
                                    return (
                                        self.encapsulation_type.is_set or
                                        self.outer_tag.is_set or
                                        self.simple_efp.is_set or
                                        self.vlan_rewrite_tag.is_set or
                                        self.xconnect_tags.is_set)

                                def has_operation(self):
                                    for c in self.vlan_range:
                                        if (c.has_operation()):
                                            return True
                                    for leaf in self.rewrite_tag.getYLeafs():
                                        if (leaf.is_set):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.encapsulation_type.yfilter != YFilter.not_set or
                                        self.outer_tag.yfilter != YFilter.not_set or
                                        self.rewrite_tag.yfilter != YFilter.not_set or
                                        self.simple_efp.yfilter != YFilter.not_set or
                                        self.vlan_rewrite_tag.yfilter != YFilter.not_set or
                                        self.xconnect_tags.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "vlan" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.encapsulation_type.is_set or self.encapsulation_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.encapsulation_type.get_name_leafdata())
                                    if (self.outer_tag.is_set or self.outer_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.outer_tag.get_name_leafdata())
                                    if (self.simple_efp.is_set or self.simple_efp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.simple_efp.get_name_leafdata())
                                    if (self.vlan_rewrite_tag.is_set or self.vlan_rewrite_tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vlan_rewrite_tag.get_name_leafdata())
                                    if (self.xconnect_tags.is_set or self.xconnect_tags.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.xconnect_tags.get_name_leafdata())

                                    leaf_name_data.extend(self.rewrite_tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "vlan-range"):
                                        for c in self.vlan_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.vlan_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "vlan-range" or name == "encapsulation-type" or name == "outer-tag" or name == "rewrite-tag" or name == "simple-efp" or name == "vlan-rewrite-tag" or name == "xconnect-tags"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "encapsulation-type"):
                                        self.encapsulation_type = value
                                        self.encapsulation_type.value_namespace = name_space
                                        self.encapsulation_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "outer-tag"):
                                        self.outer_tag = value
                                        self.outer_tag.value_namespace = name_space
                                        self.outer_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rewrite-tag"):
                                        self.rewrite_tag.append(value)
                                    if(value_path == "simple-efp"):
                                        self.simple_efp = value
                                        self.simple_efp.value_namespace = name_space
                                        self.simple_efp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vlan-rewrite-tag"):
                                        self.vlan_rewrite_tag = value
                                        self.vlan_rewrite_tag.value_namespace = name_space
                                        self.vlan_rewrite_tag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "xconnect-tags"):
                                        self.xconnect_tags = value
                                        self.xconnect_tags.value_namespace = name_space
                                        self.xconnect_tags.value_namespace_prefix = name_space_prefix


                            class Tdm(Entity):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmMode>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                    self.yang_name = "tdm"
                                    self.yang_parent_name = "parameters"

                                    self.tdm_mode = YLeaf(YType.enumeration, "tdm-mode")

                                    self.timeslot_group = YLeaf(YType.str, "timeslot-group")

                                    self.timeslot_rate = YLeaf(YType.uint8, "timeslot-rate")

                                    self.tdm_options = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self._children_name_map["tdm_options"] = "tdm-options"
                                    self._children_yang_names.add("tdm-options")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tdm_mode",
                                                    "timeslot_group",
                                                    "timeslot_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__setattr__(name, value)


                                class TdmOptions(Entity):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOption>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                        self.yang_name = "tdm-options"
                                        self.yang_parent_name = "tdm"

                                        self.bit_rate = YLeaf(YType.uint32, "bit-rate")

                                        self.cas = YLeaf(YType.uint8, "cas")

                                        self.payload_bytes = YLeaf(YType.uint16, "payload-bytes")

                                        self.rtp = YLeaf(YType.enumeration, "rtp")

                                        self.rtp_header_payload_type = YLeaf(YType.uint8, "rtp-header-payload-type")

                                        self.signalling_packets = YLeaf(YType.uint8, "signalling-packets")

                                        self.ssrc = YLeaf(YType.uint32, "ssrc")

                                        self.timestamp_clock_freq = YLeaf(YType.uint16, "timestamp-clock-freq")

                                        self.timestamp_mode = YLeaf(YType.enumeration, "timestamp-mode")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bit_rate",
                                                        "cas",
                                                        "payload_bytes",
                                                        "rtp",
                                                        "rtp_header_payload_type",
                                                        "signalling_packets",
                                                        "ssrc",
                                                        "timestamp_clock_freq",
                                                        "timestamp_mode") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bit_rate.is_set or
                                            self.cas.is_set or
                                            self.payload_bytes.is_set or
                                            self.rtp.is_set or
                                            self.rtp_header_payload_type.is_set or
                                            self.signalling_packets.is_set or
                                            self.ssrc.is_set or
                                            self.timestamp_clock_freq.is_set or
                                            self.timestamp_mode.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bit_rate.yfilter != YFilter.not_set or
                                            self.cas.yfilter != YFilter.not_set or
                                            self.payload_bytes.yfilter != YFilter.not_set or
                                            self.rtp.yfilter != YFilter.not_set or
                                            self.rtp_header_payload_type.yfilter != YFilter.not_set or
                                            self.signalling_packets.yfilter != YFilter.not_set or
                                            self.ssrc.yfilter != YFilter.not_set or
                                            self.timestamp_clock_freq.yfilter != YFilter.not_set or
                                            self.timestamp_mode.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tdm-options" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bit_rate.is_set or self.bit_rate.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bit_rate.get_name_leafdata())
                                        if (self.cas.is_set or self.cas.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cas.get_name_leafdata())
                                        if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.payload_bytes.get_name_leafdata())
                                        if (self.rtp.is_set or self.rtp.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp.get_name_leafdata())
                                        if (self.rtp_header_payload_type.is_set or self.rtp_header_payload_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rtp_header_payload_type.get_name_leafdata())
                                        if (self.signalling_packets.is_set or self.signalling_packets.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.signalling_packets.get_name_leafdata())
                                        if (self.ssrc.is_set or self.ssrc.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ssrc.get_name_leafdata())
                                        if (self.timestamp_clock_freq.is_set or self.timestamp_clock_freq.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_clock_freq.get_name_leafdata())
                                        if (self.timestamp_mode.is_set or self.timestamp_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.timestamp_mode.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bit-rate" or name == "cas" or name == "payload-bytes" or name == "rtp" or name == "rtp-header-payload-type" or name == "signalling-packets" or name == "ssrc" or name == "timestamp-clock-freq" or name == "timestamp-mode"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bit-rate"):
                                            self.bit_rate = value
                                            self.bit_rate.value_namespace = name_space
                                            self.bit_rate.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cas"):
                                            self.cas = value
                                            self.cas.value_namespace = name_space
                                            self.cas.value_namespace_prefix = name_space_prefix
                                        if(value_path == "payload-bytes"):
                                            self.payload_bytes = value
                                            self.payload_bytes.value_namespace = name_space
                                            self.payload_bytes.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp"):
                                            self.rtp = value
                                            self.rtp.value_namespace = name_space
                                            self.rtp.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rtp-header-payload-type"):
                                            self.rtp_header_payload_type = value
                                            self.rtp_header_payload_type.value_namespace = name_space
                                            self.rtp_header_payload_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "signalling-packets"):
                                            self.signalling_packets = value
                                            self.signalling_packets.value_namespace = name_space
                                            self.signalling_packets.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ssrc"):
                                            self.ssrc = value
                                            self.ssrc.value_namespace = name_space
                                            self.ssrc.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-clock-freq"):
                                            self.timestamp_clock_freq = value
                                            self.timestamp_clock_freq.value_namespace = name_space
                                            self.timestamp_clock_freq.value_namespace_prefix = name_space_prefix
                                        if(value_path == "timestamp-mode"):
                                            self.timestamp_mode = value
                                            self.timestamp_mode.value_namespace = name_space
                                            self.timestamp_mode.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.tdm_mode.is_set or
                                        self.timeslot_group.is_set or
                                        self.timeslot_rate.is_set or
                                        (self.tdm_options is not None and self.tdm_options.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tdm_mode.yfilter != YFilter.not_set or
                                        self.timeslot_group.yfilter != YFilter.not_set or
                                        self.timeslot_rate.yfilter != YFilter.not_set or
                                        (self.tdm_options is not None and self.tdm_options.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tdm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tdm_mode.is_set or self.tdm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tdm_mode.get_name_leafdata())
                                    if (self.timeslot_group.is_set or self.timeslot_group.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_group.get_name_leafdata())
                                    if (self.timeslot_rate.is_set or self.timeslot_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timeslot_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tdm-options"):
                                        if (self.tdm_options is None):
                                            self.tdm_options = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                        return self.tdm_options

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tdm-options" or name == "tdm-mode" or name == "timeslot-group" or name == "timeslot-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tdm-mode"):
                                        self.tdm_mode = value
                                        self.tdm_mode.value_namespace = name_space
                                        self.tdm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-group"):
                                        self.timeslot_group = value
                                        self.timeslot_group.value_namespace = name_space
                                        self.timeslot_group.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timeslot-rate"):
                                        self.timeslot_rate = value
                                        self.timeslot_rate.value_namespace = name_space
                                        self.timeslot_rate.value_namespace_prefix = name_space_prefix


                            class Atm(Entity):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmMode>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                    self.yang_name = "atm"
                                    self.yang_parent_name = "parameters"

                                    self.atm_mode = YLeaf(YType.enumeration, "atm-mode")

                                    self.maximum_number_cells_packed = YLeaf(YType.uint16, "maximum-number-cells-packed")

                                    self.maximum_number_cells_un_packed = YLeaf(YType.uint16, "maximum-number-cells-un-packed")

                                    self.vci = YLeaf(YType.uint16, "vci")

                                    self.vpi = YLeaf(YType.uint16, "vpi")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("atm_mode",
                                                    "maximum_number_cells_packed",
                                                    "maximum_number_cells_un_packed",
                                                    "vci",
                                                    "vpi") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.atm_mode.is_set or
                                        self.maximum_number_cells_packed.is_set or
                                        self.maximum_number_cells_un_packed.is_set or
                                        self.vci.is_set or
                                        self.vpi.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.atm_mode.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_packed.yfilter != YFilter.not_set or
                                        self.maximum_number_cells_un_packed.yfilter != YFilter.not_set or
                                        self.vci.yfilter != YFilter.not_set or
                                        self.vpi.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "atm" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.atm_mode.is_set or self.atm_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.atm_mode.get_name_leafdata())
                                    if (self.maximum_number_cells_packed.is_set or self.maximum_number_cells_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_packed.get_name_leafdata())
                                    if (self.maximum_number_cells_un_packed.is_set or self.maximum_number_cells_un_packed.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_number_cells_un_packed.get_name_leafdata())
                                    if (self.vci.is_set or self.vci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vci.get_name_leafdata())
                                    if (self.vpi.is_set or self.vpi.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.vpi.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "atm-mode" or name == "maximum-number-cells-packed" or name == "maximum-number-cells-un-packed" or name == "vci" or name == "vpi"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "atm-mode"):
                                        self.atm_mode = value
                                        self.atm_mode.value_namespace = name_space
                                        self.atm_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-packed"):
                                        self.maximum_number_cells_packed = value
                                        self.maximum_number_cells_packed.value_namespace = name_space
                                        self.maximum_number_cells_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "maximum-number-cells-un-packed"):
                                        self.maximum_number_cells_un_packed = value
                                        self.maximum_number_cells_un_packed.value_namespace = name_space
                                        self.maximum_number_cells_un_packed.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vci"):
                                        self.vci = value
                                        self.vci.value_namespace = name_space
                                        self.vci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "vpi"):
                                        self.vpi = value
                                        self.vpi.value_namespace = name_space
                                        self.vpi.value_namespace_prefix = name_space_prefix


                            class Fr(Entity):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrMode>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                    self.yang_name = "fr"
                                    self.yang_parent_name = "parameters"

                                    self.dlci = YLeaf(YType.uint32, "dlci")

                                    self.fr_mode = YLeaf(YType.enumeration, "fr-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("dlci",
                                                    "fr_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.dlci.is_set or
                                        self.fr_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.dlci.yfilter != YFilter.not_set or
                                        self.fr_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.dlci.is_set or self.dlci.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.dlci.get_name_leafdata())
                                    if (self.fr_mode.is_set or self.fr_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fr_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dlci" or name == "fr-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "dlci"):
                                        self.dlci = value
                                        self.dlci.value_namespace = name_space
                                        self.dlci.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fr-mode"):
                                        self.fr_mode = value
                                        self.fr_mode.value_namespace = name_space
                                        self.fr_mode.value_namespace_prefix = name_space_prefix


                            class PseudowireEther(Entity):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                    self.yang_name = "pseudowire-ether"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-ether"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-ether" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PseudowireIw(Entity):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                    self.yang_name = "pseudowire-iw"
                                    self.yang_parent_name = "parameters"

                                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                                    self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self._children_name_map["interface_list"] = "interface-list"
                                    self._children_yang_names.add("interface-list")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("internal_label",
                                                    "is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__setattr__(name, value)


                                class InterfaceList(Entity):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                        self.yang_name = "interface-list"
                                        self.yang_parent_name = "pseudowire-iw"

                                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_list_id",
                                                        "interface_list_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "interface-list"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.replicate_status = YLeaf(YType.enumeration, "replicate-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name",
                                                            "replicate_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interface_name.is_set or
                                                self.replicate_status.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set or
                                                self.replicate_status.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                                            if (self.replicate_status.is_set or self.replicate_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.replicate_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name" or name == "replicate-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "replicate-status"):
                                                self.replicate_status = value
                                                self.replicate_status.value_namespace = name_space
                                                self.replicate_status.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.interface_list_id.is_set or
                                            self.interface_list_name.is_set)

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_list_id.yfilter != YFilter.not_set or
                                            self.interface_list_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "interface-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface" or name == "interface-list-id" or name == "interface-list-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-list-id"):
                                            self.interface_list_id = value
                                            self.interface_list_id.value_namespace = name_space
                                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-list-name"):
                                            self.interface_list_name = value
                                            self.interface_list_name.value_namespace = name_space
                                            self.interface_list_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.internal_label.is_set or
                                        self.is_valid.is_set or
                                        (self.interface_list is not None and self.interface_list.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.internal_label.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.interface_list is not None and self.interface_list.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pseudowire-iw" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.internal_label.is_set or self.internal_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.internal_label.get_name_leafdata())
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "interface-list"):
                                        if (self.interface_list is None):
                                            self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                        return self.interface_list

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-list" or name == "internal-label" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "internal-label"):
                                        self.internal_label = value
                                        self.internal_label.value_namespace = name_space
                                        self.internal_label.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.type.is_set or
                                    (self.atm is not None and self.atm.has_data()) or
                                    (self.ethernet is not None and self.ethernet.has_data()) or
                                    (self.fr is not None and self.fr.has_data()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_data()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_data()) or
                                    (self.tdm is not None and self.tdm.has_data()) or
                                    (self.vlan is not None and self.vlan.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    (self.atm is not None and self.atm.has_operation()) or
                                    (self.ethernet is not None and self.ethernet.has_operation()) or
                                    (self.fr is not None and self.fr.has_operation()) or
                                    (self.pseudowire_ether is not None and self.pseudowire_ether.has_operation()) or
                                    (self.pseudowire_iw is not None and self.pseudowire_iw.has_operation()) or
                                    (self.tdm is not None and self.tdm.has_operation()) or
                                    (self.vlan is not None and self.vlan.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "parameters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "atm"):
                                    if (self.atm is None):
                                        self.atm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"
                                    return self.atm

                                if (child_yang_name == "ethernet"):
                                    if (self.ethernet is None):
                                        self.ethernet = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"
                                    return self.ethernet

                                if (child_yang_name == "fr"):
                                    if (self.fr is None):
                                        self.fr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"
                                    return self.fr

                                if (child_yang_name == "pseudowire-ether"):
                                    if (self.pseudowire_ether is None):
                                        self.pseudowire_ether = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
                                    return self.pseudowire_ether

                                if (child_yang_name == "pseudowire-iw"):
                                    if (self.pseudowire_iw is None):
                                        self.pseudowire_iw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    return self.pseudowire_iw

                                if (child_yang_name == "tdm"):
                                    if (self.tdm is None):
                                        self.tdm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"
                                    return self.tdm

                                if (child_yang_name == "vlan"):
                                    if (self.vlan is None):
                                        self.vlan = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"
                                    return self.vlan

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "atm" or name == "ethernet" or name == "fr" or name == "pseudowire-ether" or name == "pseudowire-iw" or name == "tdm" or name == "vlan" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mtu.is_set or
                                self.name.is_set or
                                self.payload_bytes.is_set or
                                (self.parameters is not None and self.parameters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                self.payload_bytes.yfilter != YFilter.not_set or
                                (self.parameters is not None and self.parameters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())
                            if (self.payload_bytes.is_set or self.payload_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.payload_bytes.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "parameters"):
                                if (self.parameters is None):
                                    self.parameters = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                return self.parameters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "parameters" or name == "mtu" or name == "name" or name == "payload-bytes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix
                            if(value_path == "payload-bytes"):
                                self.payload_bytes = value
                                self.payload_bytes.value_namespace = name_space
                                self.payload_bytes.value_namespace_prefix = name_space_prefix


                    class PreferredPath(Entity):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOption>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__init__()

                            self.yang_name = "preferred-path"
                            self.yang_parent_name = "pseudowire"

                            self.ip_tunnel_interface_number = YLeaf(YType.uint32, "ip-tunnel-interface-number")

                            self.next_hop_ip = YLeaf(YType.uint32, "next-hop-ip")

                            self.option = YLeaf(YType.enumeration, "option")

                            self.te_tunnel_interface_number = YLeaf(YType.uint32, "te-tunnel-interface-number")

                            self.tp_tunnel_interface_number = YLeaf(YType.uint32, "tp-tunnel-interface-number")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ip_tunnel_interface_number",
                                            "next_hop_ip",
                                            "option",
                                            "te_tunnel_interface_number",
                                            "tp_tunnel_interface_number") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.ip_tunnel_interface_number.is_set or
                                self.next_hop_ip.is_set or
                                self.option.is_set or
                                self.te_tunnel_interface_number.is_set or
                                self.tp_tunnel_interface_number.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ip_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.next_hop_ip.yfilter != YFilter.not_set or
                                self.option.yfilter != YFilter.not_set or
                                self.te_tunnel_interface_number.yfilter != YFilter.not_set or
                                self.tp_tunnel_interface_number.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "preferred-path" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ip_tunnel_interface_number.is_set or self.ip_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ip_tunnel_interface_number.get_name_leafdata())
                            if (self.next_hop_ip.is_set or self.next_hop_ip.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_ip.get_name_leafdata())
                            if (self.option.is_set or self.option.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.option.get_name_leafdata())
                            if (self.te_tunnel_interface_number.is_set or self.te_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_tunnel_interface_number.get_name_leafdata())
                            if (self.tp_tunnel_interface_number.is_set or self.tp_tunnel_interface_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tp_tunnel_interface_number.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ip-tunnel-interface-number" or name == "next-hop-ip" or name == "option" or name == "te-tunnel-interface-number" or name == "tp-tunnel-interface-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ip-tunnel-interface-number"):
                                self.ip_tunnel_interface_number = value
                                self.ip_tunnel_interface_number.value_namespace = name_space
                                self.ip_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-ip"):
                                self.next_hop_ip = value
                                self.next_hop_ip.value_namespace = name_space
                                self.next_hop_ip.value_namespace_prefix = name_space_prefix
                            if(value_path == "option"):
                                self.option = value
                                self.option.value_namespace = name_space
                                self.option.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-tunnel-interface-number"):
                                self.te_tunnel_interface_number = value
                                self.te_tunnel_interface_number.value_namespace = name_space
                                self.te_tunnel_interface_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "tp-tunnel-interface-number"):
                                self.tp_tunnel_interface_number = value
                                self.tp_tunnel_interface_number.value_namespace = name_space
                                self.tp_tunnel_interface_number.value_namespace_prefix = name_space_prefix


                    class LocalSignalling(Entity):
                        """
                        Local signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__init__()

                            self.yang_name = "local-signalling"
                            self.yang_parent_name = "pseudowire"

                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                            self.status_tlv = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self._children_name_map["status_tlv"] = "status-tlv"
                            self._children_yang_names.add("status-tlv")

                            self.tlv = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pw_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__setattr__(name, value)


                        class StatusTlv(Entity):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                self.yang_name = "status-tlv"
                                self.yang_parent_name = "local-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "status-tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix


                        class Tlv(Entity):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "local-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.tlv:
                                if (c.has_data()):
                                    return True
                            return (
                                self.pw_status.is_set or
                                (self.status_tlv is not None and self.status_tlv.has_data()))

                        def has_operation(self):
                            for c in self.tlv:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pw_status.yfilter != YFilter.not_set or
                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "local-signalling" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "status-tlv"):
                                if (self.status_tlv is None):
                                    self.status_tlv = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                return self.status_tlv

                            if (child_yang_name == "tlv"):
                                for c in self.tlv:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.tlv.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pw-status"):
                                self.pw_status = value
                                self.pw_status.value_namespace = name_space
                                self.pw_status.value_namespace_prefix = name_space_prefix


                    class RemoteSignalling(Entity):
                        """
                        Remote signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__init__()

                            self.yang_name = "remote-signalling"
                            self.yang_parent_name = "pseudowire"

                            self.pw_status = YLeaf(YType.uint32, "pw-status")

                            self.status_tlv = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self._children_name_map["status_tlv"] = "status-tlv"
                            self._children_yang_names.add("status-tlv")

                            self.tlv = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pw_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__setattr__(name, value)


                        class StatusTlv(Entity):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                self.yang_name = "status-tlv"
                                self.yang_parent_name = "remote-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "status-tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix


                        class Tlv(Entity):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                self.yang_name = "tlv"
                                self.yang_parent_name = "remote-signalling"

                                self.description = YLeaf(YType.str, "description")

                                self.local_address = YLeaf(YType.str, "local-address")

                                self.pw_id = YLeaf(YType.uint32, "pw-id")

                                self.remote_address = YLeaf(YType.str, "remote-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("description",
                                                "local_address",
                                                "pw_id",
                                                "remote_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.description.is_set or
                                    self.local_address.is_set or
                                    self.pw_id.is_set or
                                    self.remote_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.description.yfilter != YFilter.not_set or
                                    self.local_address.yfilter != YFilter.not_set or
                                    self.pw_id.yfilter != YFilter.not_set or
                                    self.remote_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tlv" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.description.is_set or self.description.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.description.get_name_leafdata())
                                if (self.local_address.is_set or self.local_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_address.get_name_leafdata())
                                if (self.pw_id.is_set or self.pw_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pw_id.get_name_leafdata())
                                if (self.remote_address.is_set or self.remote_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.remote_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "description" or name == "local-address" or name == "pw-id" or name == "remote-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "description"):
                                    self.description = value
                                    self.description.value_namespace = name_space
                                    self.description.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-address"):
                                    self.local_address = value
                                    self.local_address.value_namespace = name_space
                                    self.local_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pw-id"):
                                    self.pw_id = value
                                    self.pw_id.value_namespace = name_space
                                    self.pw_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "remote-address"):
                                    self.remote_address = value
                                    self.remote_address.value_namespace = name_space
                                    self.remote_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.tlv:
                                if (c.has_data()):
                                    return True
                            return (
                                self.pw_status.is_set or
                                (self.status_tlv is not None and self.status_tlv.has_data()))

                        def has_operation(self):
                            for c in self.tlv:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pw_status.yfilter != YFilter.not_set or
                                (self.status_tlv is not None and self.status_tlv.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-signalling" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pw_status.is_set or self.pw_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pw_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "status-tlv"):
                                if (self.status_tlv is None):
                                    self.status_tlv = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"
                                return self.status_tlv

                            if (child_yang_name == "tlv"):
                                for c in self.tlv:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.tlv.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "status-tlv" or name == "tlv" or name == "pw-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pw-status"):
                                self.pw_status = value
                                self.pw_status.value_namespace = name_space
                                self.pw_status.value_namespace_prefix = name_space_prefix


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "pseudowire"

                            self.dispostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self._children_name_map["dispostion_stats"] = "dispostion-stats"
                            self._children_yang_names.add("dispostion-stats")

                            self.impostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self._children_name_map["impostion_stats"] = "impostion-stats"
                            self._children_yang_names.add("impostion-stats")

                            self.sequence_number = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                            self.sequence_number.parent = self
                            self._children_name_map["sequence_number"] = "sequence-number"
                            self._children_yang_names.add("sequence-number")


                        class ImpostionStats(Entity):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                self.yang_name = "impostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self._children_name_map["broadcast"] = "broadcast"
                                self._children_yang_names.add("broadcast")

                                self.imposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                self._children_yang_names.add("imposition-mtu-drop")

                                self.imposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self._children_name_map["imposition_stat"] = "imposition-stat"
                                self._children_yang_names.add("imposition-stat")

                                self.impostion_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                self._children_yang_names.add("impostion-tail-drop")

                                self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.l2fsbi_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                self._children_yang_names.add("l2fsbi-drop")

                                self.multicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self._children_name_map["multicast"] = "multicast"
                                self._children_yang_names.add("multicast")

                                self.unknown_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self
                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                self._children_yang_names.add("unknown-unicast")


                            class ImpositionStat(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                    self.yang_name = "imposition-stat"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpositionMtuDrop(Entity):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                    self.yang_name = "imposition-mtu-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "imposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ImpostionTailDrop(Entity):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                    self.yang_name = "impostion-tail-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "impostion-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class L2FsbiDrop(Entity):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__init__()

                                    self.yang_name = "l2fsbi-drop"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "l2fsbi-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Multicast(Entity):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                    self.yang_name = "multicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class Broadcast(Entity):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                    self.yang_name = "broadcast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnknownUnicast(Entity):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                    self.yang_name = "unknown-unicast"
                                    self.yang_parent_name = "impostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unknown-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast is not None and self.broadcast.has_data()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_data()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_data()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_data()) or
                                    (self.multicast is not None and self.multicast.has_data()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast is not None and self.broadcast.has_operation()) or
                                    (self.imposition_mtu_drop is not None and self.imposition_mtu_drop.has_operation()) or
                                    (self.imposition_stat is not None and self.imposition_stat.has_operation()) or
                                    (self.impostion_tail_drop is not None and self.impostion_tail_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.l2fsbi_drop is not None and self.l2fsbi_drop.has_operation()) or
                                    (self.multicast is not None and self.multicast.has_operation()) or
                                    (self.unknown_unicast is not None and self.unknown_unicast.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "impostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast"):
                                    if (self.broadcast is None):
                                        self.broadcast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"
                                    return self.broadcast

                                if (child_yang_name == "imposition-mtu-drop"):
                                    if (self.imposition_mtu_drop is None):
                                        self.imposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"
                                    return self.imposition_mtu_drop

                                if (child_yang_name == "imposition-stat"):
                                    if (self.imposition_stat is None):
                                        self.imposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"
                                    return self.imposition_stat

                                if (child_yang_name == "impostion-tail-drop"):
                                    if (self.impostion_tail_drop is None):
                                        self.impostion_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"
                                    return self.impostion_tail_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "l2fsbi-drop"):
                                    if (self.l2fsbi_drop is None):
                                        self.l2fsbi_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"
                                    return self.l2fsbi_drop

                                if (child_yang_name == "multicast"):
                                    if (self.multicast is None):
                                        self.multicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"
                                    return self.multicast

                                if (child_yang_name == "unknown-unicast"):
                                    if (self.unknown_unicast is None):
                                        self.unknown_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    return self.unknown_unicast

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast" or name == "imposition-mtu-drop" or name == "imposition-stat" or name == "impostion-tail-drop" or name == "known-unicast" or name == "l2fsbi-drop" or name == "multicast" or name == "unknown-unicast"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DispostionStats(Entity):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats, self).__init__()

                                self.yang_name = "dispostion-stats"
                                self.yang_parent_name = "statistics"

                                self.broadcast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                self._children_yang_names.add("broadcast-drop")

                                self.dai_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self._children_name_map["dai_drop"] = "dai-drop"
                                self._children_yang_names.add("dai-drop")

                                self.disposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                self._children_yang_names.add("disposition-mtu-drop")

                                self.disposition_oo_o_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                self._children_yang_names.add("disposition-oo-o-drops")

                                self.disposition_p2mp_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                self._children_yang_names.add("disposition-p2mp-stats")

                                self.disposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self._children_name_map["disposition_stat"] = "disposition-stat"
                                self._children_yang_names.add("disposition-stat")

                                self.disposition_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                self._children_yang_names.add("disposition-tail-drop")

                                self.ipsg_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                self._children_yang_names.add("ipsg-drop")

                                self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self._children_name_map["known_unicast"] = "known-unicast"
                                self._children_yang_names.add("known-unicast")

                                self.mac_move = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self._children_name_map["mac_move"] = "mac-move"
                                self._children_yang_names.add("mac-move")

                                self.multicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self._children_name_map["multicast_drop"] = "multicast-drop"
                                self._children_yang_names.add("multicast-drop")

                                self.received_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self._children_name_map["received_drops"] = "received-drops"
                                self._children_yang_names.add("received-drops")

                                self.unicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self
                                self._children_name_map["unicast_drop"] = "unicast-drop"
                                self._children_yang_names.add("unicast-drop")


                            class DispositionStat(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                    self.yang_name = "disposition-stat"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-stat" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionMtuDrop(Entity):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                    self.yang_name = "disposition-mtu-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-mtu-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionTailDrop(Entity):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                    self.yang_name = "disposition-tail-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-tail-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MulticastDrop(Entity):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                    self.yang_name = "multicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class UnicastDrop(Entity):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                    self.yang_name = "unicast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unicast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class BroadcastDrop(Entity):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                    self.yang_name = "broadcast-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "broadcast-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class ReceivedDrops(Entity):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                    self.yang_name = "received-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DaiDrop(Entity):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                    self.yang_name = "dai-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dai-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class IpsgDrop(Entity):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                    self.yang_name = "ipsg-drop"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipsg-drop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionOoODrops(Entity):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                    self.yang_name = "disposition-oo-o-drops"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-oo-o-drops" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class DispositionP2MpStats(Entity):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__init__()

                                    self.yang_name = "disposition-p2mp-stats"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "disposition-p2mp-stats" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class KnownUnicast(Entity):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                    self.yang_name = "known-unicast"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "known-unicast" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix


                            class MacMove(Entity):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                    self.yang_name = "mac-move"
                                    self.yang_parent_name = "dispostion-stats"

                                    self.byte_counts = YLeaf(YType.uint64, "byte-counts")

                                    self.packet_counts = YLeaf(YType.uint64, "packet-counts")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("byte_counts",
                                                    "packet_counts") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.byte_counts.is_set or
                                        self.packet_counts.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.byte_counts.yfilter != YFilter.not_set or
                                        self.packet_counts.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-move" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.byte_counts.is_set or self.byte_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.byte_counts.get_name_leafdata())
                                    if (self.packet_counts.is_set or self.packet_counts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_counts.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "byte-counts" or name == "packet-counts"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "byte-counts"):
                                        self.byte_counts = value
                                        self.byte_counts.value_namespace = name_space
                                        self.byte_counts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-counts"):
                                        self.packet_counts = value
                                        self.packet_counts.value_namespace = name_space
                                        self.packet_counts.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_data()) or
                                    (self.dai_drop is not None and self.dai_drop.has_data()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_data()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_data()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_data()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_data()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_data()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_data()) or
                                    (self.known_unicast is not None and self.known_unicast.has_data()) or
                                    (self.mac_move is not None and self.mac_move.has_data()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_data()) or
                                    (self.received_drops is not None and self.received_drops.has_data()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.broadcast_drop is not None and self.broadcast_drop.has_operation()) or
                                    (self.dai_drop is not None and self.dai_drop.has_operation()) or
                                    (self.disposition_mtu_drop is not None and self.disposition_mtu_drop.has_operation()) or
                                    (self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops.has_operation()) or
                                    (self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats.has_operation()) or
                                    (self.disposition_stat is not None and self.disposition_stat.has_operation()) or
                                    (self.disposition_tail_drop is not None and self.disposition_tail_drop.has_operation()) or
                                    (self.ipsg_drop is not None and self.ipsg_drop.has_operation()) or
                                    (self.known_unicast is not None and self.known_unicast.has_operation()) or
                                    (self.mac_move is not None and self.mac_move.has_operation()) or
                                    (self.multicast_drop is not None and self.multicast_drop.has_operation()) or
                                    (self.received_drops is not None and self.received_drops.has_operation()) or
                                    (self.unicast_drop is not None and self.unicast_drop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dispostion-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "broadcast-drop"):
                                    if (self.broadcast_drop is None):
                                        self.broadcast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"
                                    return self.broadcast_drop

                                if (child_yang_name == "dai-drop"):
                                    if (self.dai_drop is None):
                                        self.dai_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"
                                    return self.dai_drop

                                if (child_yang_name == "disposition-mtu-drop"):
                                    if (self.disposition_mtu_drop is None):
                                        self.disposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"
                                    return self.disposition_mtu_drop

                                if (child_yang_name == "disposition-oo-o-drops"):
                                    if (self.disposition_oo_o_drops is None):
                                        self.disposition_oo_o_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"
                                    return self.disposition_oo_o_drops

                                if (child_yang_name == "disposition-p2mp-stats"):
                                    if (self.disposition_p2mp_stats is None):
                                        self.disposition_p2mp_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"
                                    return self.disposition_p2mp_stats

                                if (child_yang_name == "disposition-stat"):
                                    if (self.disposition_stat is None):
                                        self.disposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"
                                    return self.disposition_stat

                                if (child_yang_name == "disposition-tail-drop"):
                                    if (self.disposition_tail_drop is None):
                                        self.disposition_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"
                                    return self.disposition_tail_drop

                                if (child_yang_name == "ipsg-drop"):
                                    if (self.ipsg_drop is None):
                                        self.ipsg_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"
                                    return self.ipsg_drop

                                if (child_yang_name == "known-unicast"):
                                    if (self.known_unicast is None):
                                        self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"
                                    return self.known_unicast

                                if (child_yang_name == "mac-move"):
                                    if (self.mac_move is None):
                                        self.mac_move = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                    return self.mac_move

                                if (child_yang_name == "multicast-drop"):
                                    if (self.multicast_drop is None):
                                        self.multicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"
                                    return self.multicast_drop

                                if (child_yang_name == "received-drops"):
                                    if (self.received_drops is None):
                                        self.received_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"
                                    return self.received_drops

                                if (child_yang_name == "unicast-drop"):
                                    if (self.unicast_drop is None):
                                        self.unicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"
                                    return self.unicast_drop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "broadcast-drop" or name == "dai-drop" or name == "disposition-mtu-drop" or name == "disposition-oo-o-drops" or name == "disposition-p2mp-stats" or name == "disposition-stat" or name == "disposition-tail-drop" or name == "ipsg-drop" or name == "known-unicast" or name == "mac-move" or name == "multicast-drop" or name == "received-drops" or name == "unicast-drop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SequenceNumber(Entity):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                self.yang_name = "sequence-number"
                                self.yang_parent_name = "statistics"

                                self.bypassed_inbound_sequence_packet = YLeaf(YType.uint64, "bypassed-inbound-sequence-packet")

                                self.bypassed_out_sequence_packet = YLeaf(YType.uint64, "bypassed-out-sequence-packet")

                                self.sequence_number_expected = YLeaf(YType.uint32, "sequence-number-expected")

                                self.sequence_number_sent = YLeaf(YType.uint32, "sequence-number-sent")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bypassed_inbound_sequence_packet",
                                                "bypassed_out_sequence_packet",
                                                "sequence_number_expected",
                                                "sequence_number_sent") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bypassed_inbound_sequence_packet.is_set or
                                    self.bypassed_out_sequence_packet.is_set or
                                    self.sequence_number_expected.is_set or
                                    self.sequence_number_sent.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set or
                                    self.bypassed_out_sequence_packet.yfilter != YFilter.not_set or
                                    self.sequence_number_expected.yfilter != YFilter.not_set or
                                    self.sequence_number_sent.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sequence-number" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bypassed_inbound_sequence_packet.is_set or self.bypassed_inbound_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_inbound_sequence_packet.get_name_leafdata())
                                if (self.bypassed_out_sequence_packet.is_set or self.bypassed_out_sequence_packet.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bypassed_out_sequence_packet.get_name_leafdata())
                                if (self.sequence_number_expected.is_set or self.sequence_number_expected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_expected.get_name_leafdata())
                                if (self.sequence_number_sent.is_set or self.sequence_number_sent.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sequence_number_sent.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bypassed-inbound-sequence-packet" or name == "bypassed-out-sequence-packet" or name == "sequence-number-expected" or name == "sequence-number-sent"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bypassed-inbound-sequence-packet"):
                                    self.bypassed_inbound_sequence_packet = value
                                    self.bypassed_inbound_sequence_packet.value_namespace = name_space
                                    self.bypassed_inbound_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "bypassed-out-sequence-packet"):
                                    self.bypassed_out_sequence_packet = value
                                    self.bypassed_out_sequence_packet.value_namespace = name_space
                                    self.bypassed_out_sequence_packet.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-expected"):
                                    self.sequence_number_expected = value
                                    self.sequence_number_expected.value_namespace = name_space
                                    self.sequence_number_expected.value_namespace_prefix = name_space_prefix
                                if(value_path == "sequence-number-sent"):
                                    self.sequence_number_sent = value
                                    self.sequence_number_sent.value_namespace = name_space
                                    self.sequence_number_sent.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.dispostion_stats is not None and self.dispostion_stats.has_data()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_data()) or
                                (self.sequence_number is not None and self.sequence_number.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dispostion_stats is not None and self.dispostion_stats.has_operation()) or
                                (self.impostion_stats is not None and self.impostion_stats.has_operation()) or
                                (self.sequence_number is not None and self.sequence_number.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dispostion-stats"):
                                if (self.dispostion_stats is None):
                                    self.dispostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"
                                return self.dispostion_stats

                            if (child_yang_name == "impostion-stats"):
                                if (self.impostion_stats is None):
                                    self.impostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"
                                return self.impostion_stats

                            if (child_yang_name == "sequence-number"):
                                if (self.sequence_number is None):
                                    self.sequence_number = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                return self.sequence_number

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispostion-stats" or name == "impostion-stats" or name == "sequence-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class P2MpPw(Entity):
                        """
                        P2MP Pseudowire Information
                        
                        .. attribute:: local_available
                        
                        	Local LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: local_extended_tunnel_id
                        
                        	Local Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_flags
                        
                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: local_label
                        
                        	Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_p2mp_id
                        
                        	Local P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_ptree_type
                        
                        	Local P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                        
                        .. attribute:: local_tunnel_id
                        
                        	Local Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_available
                        
                        	Remote LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: remote_extended_tunnel_id
                        
                        	Remote Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_flags
                        
                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_label
                        
                        	Remote Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_p2mp_id
                        
                        	Remote P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_ptree_type
                        
                        	Remote P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtree>`
                        
                        .. attribute:: remote_tunnel_id
                        
                        	Remote Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__init__()

                            self.yang_name = "p2mp-pw"
                            self.yang_parent_name = "pseudowire"

                            self.local_available = YLeaf(YType.boolean, "local-available")

                            self.local_extended_tunnel_id = YLeaf(YType.str, "local-extended-tunnel-id")

                            self.local_flags = YLeaf(YType.uint8, "local-flags")

                            self.local_label = YLeaf(YType.uint32, "local-label")

                            self.local_p2mp_id = YLeaf(YType.uint32, "local-p2mp-id")

                            self.local_ptree_type = YLeaf(YType.enumeration, "local-ptree-type")

                            self.local_tunnel_id = YLeaf(YType.uint32, "local-tunnel-id")

                            self.remote_available = YLeaf(YType.boolean, "remote-available")

                            self.remote_extended_tunnel_id = YLeaf(YType.str, "remote-extended-tunnel-id")

                            self.remote_flags = YLeaf(YType.uint8, "remote-flags")

                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                            self.remote_p2mp_id = YLeaf(YType.uint32, "remote-p2mp-id")

                            self.remote_ptree_type = YLeaf(YType.enumeration, "remote-ptree-type")

                            self.remote_tunnel_id = YLeaf(YType.uint32, "remote-tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("local_available",
                                            "local_extended_tunnel_id",
                                            "local_flags",
                                            "local_label",
                                            "local_p2mp_id",
                                            "local_ptree_type",
                                            "local_tunnel_id",
                                            "remote_available",
                                            "remote_extended_tunnel_id",
                                            "remote_flags",
                                            "remote_label",
                                            "remote_p2mp_id",
                                            "remote_ptree_type",
                                            "remote_tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.local_available.is_set or
                                self.local_extended_tunnel_id.is_set or
                                self.local_flags.is_set or
                                self.local_label.is_set or
                                self.local_p2mp_id.is_set or
                                self.local_ptree_type.is_set or
                                self.local_tunnel_id.is_set or
                                self.remote_available.is_set or
                                self.remote_extended_tunnel_id.is_set or
                                self.remote_flags.is_set or
                                self.remote_label.is_set or
                                self.remote_p2mp_id.is_set or
                                self.remote_ptree_type.is_set or
                                self.remote_tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.local_available.yfilter != YFilter.not_set or
                                self.local_extended_tunnel_id.yfilter != YFilter.not_set or
                                self.local_flags.yfilter != YFilter.not_set or
                                self.local_label.yfilter != YFilter.not_set or
                                self.local_p2mp_id.yfilter != YFilter.not_set or
                                self.local_ptree_type.yfilter != YFilter.not_set or
                                self.local_tunnel_id.yfilter != YFilter.not_set or
                                self.remote_available.yfilter != YFilter.not_set or
                                self.remote_extended_tunnel_id.yfilter != YFilter.not_set or
                                self.remote_flags.yfilter != YFilter.not_set or
                                self.remote_label.yfilter != YFilter.not_set or
                                self.remote_p2mp_id.yfilter != YFilter.not_set or
                                self.remote_ptree_type.yfilter != YFilter.not_set or
                                self.remote_tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-pw" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.local_available.is_set or self.local_available.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_available.get_name_leafdata())
                            if (self.local_extended_tunnel_id.is_set or self.local_extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_extended_tunnel_id.get_name_leafdata())
                            if (self.local_flags.is_set or self.local_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_flags.get_name_leafdata())
                            if (self.local_label.is_set or self.local_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_label.get_name_leafdata())
                            if (self.local_p2mp_id.is_set or self.local_p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_p2mp_id.get_name_leafdata())
                            if (self.local_ptree_type.is_set or self.local_ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_ptree_type.get_name_leafdata())
                            if (self.local_tunnel_id.is_set or self.local_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_tunnel_id.get_name_leafdata())
                            if (self.remote_available.is_set or self.remote_available.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_available.get_name_leafdata())
                            if (self.remote_extended_tunnel_id.is_set or self.remote_extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_extended_tunnel_id.get_name_leafdata())
                            if (self.remote_flags.is_set or self.remote_flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_flags.get_name_leafdata())
                            if (self.remote_label.is_set or self.remote_label.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_label.get_name_leafdata())
                            if (self.remote_p2mp_id.is_set or self.remote_p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_p2mp_id.get_name_leafdata())
                            if (self.remote_ptree_type.is_set or self.remote_ptree_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_ptree_type.get_name_leafdata())
                            if (self.remote_tunnel_id.is_set or self.remote_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "local-available" or name == "local-extended-tunnel-id" or name == "local-flags" or name == "local-label" or name == "local-p2mp-id" or name == "local-ptree-type" or name == "local-tunnel-id" or name == "remote-available" or name == "remote-extended-tunnel-id" or name == "remote-flags" or name == "remote-label" or name == "remote-p2mp-id" or name == "remote-ptree-type" or name == "remote-tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "local-available"):
                                self.local_available = value
                                self.local_available.value_namespace = name_space
                                self.local_available.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-extended-tunnel-id"):
                                self.local_extended_tunnel_id = value
                                self.local_extended_tunnel_id.value_namespace = name_space
                                self.local_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-flags"):
                                self.local_flags = value
                                self.local_flags.value_namespace = name_space
                                self.local_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-label"):
                                self.local_label = value
                                self.local_label.value_namespace = name_space
                                self.local_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-p2mp-id"):
                                self.local_p2mp_id = value
                                self.local_p2mp_id.value_namespace = name_space
                                self.local_p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-ptree-type"):
                                self.local_ptree_type = value
                                self.local_ptree_type.value_namespace = name_space
                                self.local_ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-tunnel-id"):
                                self.local_tunnel_id = value
                                self.local_tunnel_id.value_namespace = name_space
                                self.local_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-available"):
                                self.remote_available = value
                                self.remote_available.value_namespace = name_space
                                self.remote_available.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-extended-tunnel-id"):
                                self.remote_extended_tunnel_id = value
                                self.remote_extended_tunnel_id.value_namespace = name_space
                                self.remote_extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-flags"):
                                self.remote_flags = value
                                self.remote_flags.value_namespace = name_space
                                self.remote_flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-label"):
                                self.remote_label = value
                                self.remote_label.value_namespace = name_space
                                self.remote_label.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-p2mp-id"):
                                self.remote_p2mp_id = value
                                self.remote_p2mp_id.value_namespace = name_space
                                self.remote_p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-ptree-type"):
                                self.remote_ptree_type = value
                                self.remote_ptree_type.value_namespace = name_space
                                self.remote_ptree_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-tunnel-id"):
                                self.remote_tunnel_id = value
                                self.remote_tunnel_id.value_namespace = name_space
                                self.remote_tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ad_method.is_set or
                            self.ad_remote_down.is_set or
                            self.admited_bw.is_set or
                            self.auto_discovery.is_set or
                            self.backup_active.is_set or
                            self.backup_force_active.is_set or
                            self.backup_pw.is_set or
                            self.bitrate_mismatched.is_set or
                            self.bridge_pw_type_mismatch.is_set or
                            self.cas_mismatched.is_set or
                            self.diff_ts_mismatched.is_set or
                            self.disable_delay.is_set or
                            self.disable_never.is_set or
                            self.evpn_src_acid.is_set or
                            self.fe_ctype.is_set or
                            self.forward_class.is_set or
                            self.freq_mismatched.is_set or
                            self.illegal_control_word.is_set or
                            self.imposed_vlan_id.is_set or
                            self.interworking.is_set or
                            self.ipv6_local_source_address.is_set or
                            self.is_evpnvpws_type.is_set or
                            self.is_flow_label_static.is_set or
                            self.is_multi_segment_pseudowire.is_set or
                            self.is_partially_programmed.is_set or
                            self.is_pwr_type.is_set or
                            self.is_vfi.is_set or
                            self.last_time_status_changed.is_set or
                            self.last_time_status_down.is_set or
                            self.ldp_label_advertise_failed.is_set or
                            self.load_balance.is_set or
                            self.local_control_word.is_set or
                            self.local_label_failed.is_set or
                            self.local_pseudo_wire_type.is_set or
                            self.local_source_address.is_set or
                            self.mac_limit_oper_down.is_set or
                            self.mtu_mismatched.is_set or
                            self.not_supported_qinq.is_set or
                            self.num_ma_cwithdraw_msg_received.is_set or
                            self.number_ma_cwithdraw_message_sent.is_set or
                            self.out_of_memory_state.is_set or
                            self.payload_bytes_mismatched.is_set or
                            self.payload_type_mismatched.is_set or
                            self.preferred_path_disable_fallback.is_set or
                            self.primary_peer_id.is_set or
                            self.primary_pseudo_wire_id.is_set or
                            self.primary_pw.is_set or
                            self.protocol.is_set or
                            self.pseudo_wire_id.is_set or
                            self.pseudo_wire_state.is_set or
                            self.pseudo_wire_type_mismatched.is_set or
                            self.pw_class_name.is_set or
                            self.pw_flow_label_code17_disabled.is_set or
                            self.pw_flow_label_type.is_set or
                            self.pw_flow_label_type_cfg.is_set or
                            self.pw_redundancy_initial_delay.is_set or
                            self.pw_redundancy_one_way.is_set or
                            self.pw_status_use.is_set or
                            self.pwlsd_rewrite_failed.is_set or
                            self.remote_control_word.is_set or
                            self.remote_label_failed.is_set or
                            self.remote_pseudo_wire_type.is_set or
                            self.required_bw.is_set or
                            self.resync_enabled.is_set or
                            self.resync_threshold.is_set or
                            self.rtp_mismatched.is_set or
                            self.sequencing_type.is_set or
                            self.shutdown.is_set or
                            self.sig_pkts_mismatched.is_set or
                            self.ssrc_mismatched.is_set or
                            self.state.is_set or
                            self.table_policy_name.is_set or
                            self.tag_rewrite.is_set or
                            self.time_created.is_set or
                            self.time_elapsed_creation.is_set or
                            self.time_elapsed_status_changed.is_set or
                            self.time_elapsed_status_down.is_set or
                            self.transport_lsp_down.is_set or
                            self.xconnect_id.is_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_data()) or
                            (self.local_interface is not None and self.local_interface.has_data()) or
                            (self.local_signalling is not None and self.local_signalling.has_data()) or
                            (self.p2mp_pw is not None and self.p2mp_pw.has_data()) or
                            (self.peer_id is not None and self.peer_id.has_data()) or
                            (self.preferred_path is not None and self.preferred_path.has_data()) or
                            (self.remote_interface is not None and self.remote_interface.has_data()) or
                            (self.remote_signalling is not None and self.remote_signalling.has_data()) or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ad_method.yfilter != YFilter.not_set or
                            self.ad_remote_down.yfilter != YFilter.not_set or
                            self.admited_bw.yfilter != YFilter.not_set or
                            self.auto_discovery.yfilter != YFilter.not_set or
                            self.backup_active.yfilter != YFilter.not_set or
                            self.backup_force_active.yfilter != YFilter.not_set or
                            self.backup_pw.yfilter != YFilter.not_set or
                            self.bitrate_mismatched.yfilter != YFilter.not_set or
                            self.bridge_pw_type_mismatch.yfilter != YFilter.not_set or
                            self.cas_mismatched.yfilter != YFilter.not_set or
                            self.diff_ts_mismatched.yfilter != YFilter.not_set or
                            self.disable_delay.yfilter != YFilter.not_set or
                            self.disable_never.yfilter != YFilter.not_set or
                            self.evpn_src_acid.yfilter != YFilter.not_set or
                            self.fe_ctype.yfilter != YFilter.not_set or
                            self.forward_class.yfilter != YFilter.not_set or
                            self.freq_mismatched.yfilter != YFilter.not_set or
                            self.illegal_control_word.yfilter != YFilter.not_set or
                            self.imposed_vlan_id.yfilter != YFilter.not_set or
                            self.interworking.yfilter != YFilter.not_set or
                            self.ipv6_local_source_address.yfilter != YFilter.not_set or
                            self.is_evpnvpws_type.yfilter != YFilter.not_set or
                            self.is_flow_label_static.yfilter != YFilter.not_set or
                            self.is_multi_segment_pseudowire.yfilter != YFilter.not_set or
                            self.is_partially_programmed.yfilter != YFilter.not_set or
                            self.is_pwr_type.yfilter != YFilter.not_set or
                            self.is_vfi.yfilter != YFilter.not_set or
                            self.last_time_status_changed.yfilter != YFilter.not_set or
                            self.last_time_status_down.yfilter != YFilter.not_set or
                            self.ldp_label_advertise_failed.yfilter != YFilter.not_set or
                            self.load_balance.yfilter != YFilter.not_set or
                            self.local_control_word.yfilter != YFilter.not_set or
                            self.local_label_failed.yfilter != YFilter.not_set or
                            self.local_pseudo_wire_type.yfilter != YFilter.not_set or
                            self.local_source_address.yfilter != YFilter.not_set or
                            self.mac_limit_oper_down.yfilter != YFilter.not_set or
                            self.mtu_mismatched.yfilter != YFilter.not_set or
                            self.not_supported_qinq.yfilter != YFilter.not_set or
                            self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set or
                            self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set or
                            self.out_of_memory_state.yfilter != YFilter.not_set or
                            self.payload_bytes_mismatched.yfilter != YFilter.not_set or
                            self.payload_type_mismatched.yfilter != YFilter.not_set or
                            self.preferred_path_disable_fallback.yfilter != YFilter.not_set or
                            self.primary_peer_id.yfilter != YFilter.not_set or
                            self.primary_pseudo_wire_id.yfilter != YFilter.not_set or
                            self.primary_pw.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.pseudo_wire_id.yfilter != YFilter.not_set or
                            self.pseudo_wire_state.yfilter != YFilter.not_set or
                            self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set or
                            self.pw_class_name.yfilter != YFilter.not_set or
                            self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set or
                            self.pw_flow_label_type.yfilter != YFilter.not_set or
                            self.pw_flow_label_type_cfg.yfilter != YFilter.not_set or
                            self.pw_redundancy_initial_delay.yfilter != YFilter.not_set or
                            self.pw_redundancy_one_way.yfilter != YFilter.not_set or
                            self.pw_status_use.yfilter != YFilter.not_set or
                            self.pwlsd_rewrite_failed.yfilter != YFilter.not_set or
                            self.remote_control_word.yfilter != YFilter.not_set or
                            self.remote_label_failed.yfilter != YFilter.not_set or
                            self.remote_pseudo_wire_type.yfilter != YFilter.not_set or
                            self.required_bw.yfilter != YFilter.not_set or
                            self.resync_enabled.yfilter != YFilter.not_set or
                            self.resync_threshold.yfilter != YFilter.not_set or
                            self.rtp_mismatched.yfilter != YFilter.not_set or
                            self.sequencing_type.yfilter != YFilter.not_set or
                            self.shutdown.yfilter != YFilter.not_set or
                            self.sig_pkts_mismatched.yfilter != YFilter.not_set or
                            self.ssrc_mismatched.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.table_policy_name.yfilter != YFilter.not_set or
                            self.tag_rewrite.yfilter != YFilter.not_set or
                            self.time_created.yfilter != YFilter.not_set or
                            self.time_elapsed_creation.yfilter != YFilter.not_set or
                            self.time_elapsed_status_changed.yfilter != YFilter.not_set or
                            self.time_elapsed_status_down.yfilter != YFilter.not_set or
                            self.transport_lsp_down.yfilter != YFilter.not_set or
                            self.xconnect_id.yfilter != YFilter.not_set or
                            (self.encapsulation_info is not None and self.encapsulation_info.has_operation()) or
                            (self.local_interface is not None and self.local_interface.has_operation()) or
                            (self.local_signalling is not None and self.local_signalling.has_operation()) or
                            (self.p2mp_pw is not None and self.p2mp_pw.has_operation()) or
                            (self.peer_id is not None and self.peer_id.has_operation()) or
                            (self.preferred_path is not None and self.preferred_path.has_operation()) or
                            (self.remote_interface is not None and self.remote_interface.has_operation()) or
                            (self.remote_signalling is not None and self.remote_signalling.has_operation()) or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pseudowire" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ad_method.is_set or self.ad_method.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_method.get_name_leafdata())
                        if (self.ad_remote_down.is_set or self.ad_remote_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ad_remote_down.get_name_leafdata())
                        if (self.admited_bw.is_set or self.admited_bw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.admited_bw.get_name_leafdata())
                        if (self.auto_discovery.is_set or self.auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auto_discovery.get_name_leafdata())
                        if (self.backup_active.is_set or self.backup_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_active.get_name_leafdata())
                        if (self.backup_force_active.is_set or self.backup_force_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_force_active.get_name_leafdata())
                        if (self.backup_pw.is_set or self.backup_pw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_pw.get_name_leafdata())
                        if (self.bitrate_mismatched.is_set or self.bitrate_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bitrate_mismatched.get_name_leafdata())
                        if (self.bridge_pw_type_mismatch.is_set or self.bridge_pw_type_mismatch.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bridge_pw_type_mismatch.get_name_leafdata())
                        if (self.cas_mismatched.is_set or self.cas_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cas_mismatched.get_name_leafdata())
                        if (self.diff_ts_mismatched.is_set or self.diff_ts_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.diff_ts_mismatched.get_name_leafdata())
                        if (self.disable_delay.is_set or self.disable_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_delay.get_name_leafdata())
                        if (self.disable_never.is_set or self.disable_never.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_never.get_name_leafdata())
                        if (self.evpn_src_acid.is_set or self.evpn_src_acid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.evpn_src_acid.get_name_leafdata())
                        if (self.fe_ctype.is_set or self.fe_ctype.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fe_ctype.get_name_leafdata())
                        if (self.forward_class.is_set or self.forward_class.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.forward_class.get_name_leafdata())
                        if (self.freq_mismatched.is_set or self.freq_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.freq_mismatched.get_name_leafdata())
                        if (self.illegal_control_word.is_set or self.illegal_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.illegal_control_word.get_name_leafdata())
                        if (self.imposed_vlan_id.is_set or self.imposed_vlan_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.imposed_vlan_id.get_name_leafdata())
                        if (self.interworking.is_set or self.interworking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interworking.get_name_leafdata())
                        if (self.ipv6_local_source_address.is_set or self.ipv6_local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_local_source_address.get_name_leafdata())
                        if (self.is_evpnvpws_type.is_set or self.is_evpnvpws_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_evpnvpws_type.get_name_leafdata())
                        if (self.is_flow_label_static.is_set or self.is_flow_label_static.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_flow_label_static.get_name_leafdata())
                        if (self.is_multi_segment_pseudowire.is_set or self.is_multi_segment_pseudowire.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multi_segment_pseudowire.get_name_leafdata())
                        if (self.is_partially_programmed.is_set or self.is_partially_programmed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_partially_programmed.get_name_leafdata())
                        if (self.is_pwr_type.is_set or self.is_pwr_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pwr_type.get_name_leafdata())
                        if (self.is_vfi.is_set or self.is_vfi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_vfi.get_name_leafdata())
                        if (self.last_time_status_changed.is_set or self.last_time_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_changed.get_name_leafdata())
                        if (self.last_time_status_down.is_set or self.last_time_status_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_status_down.get_name_leafdata())
                        if (self.ldp_label_advertise_failed.is_set or self.ldp_label_advertise_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ldp_label_advertise_failed.get_name_leafdata())
                        if (self.load_balance.is_set or self.load_balance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance.get_name_leafdata())
                        if (self.local_control_word.is_set or self.local_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_control_word.get_name_leafdata())
                        if (self.local_label_failed.is_set or self.local_label_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_label_failed.get_name_leafdata())
                        if (self.local_pseudo_wire_type.is_set or self.local_pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_pseudo_wire_type.get_name_leafdata())
                        if (self.local_source_address.is_set or self.local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_source_address.get_name_leafdata())
                        if (self.mac_limit_oper_down.is_set or self.mac_limit_oper_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_limit_oper_down.get_name_leafdata())
                        if (self.mtu_mismatched.is_set or self.mtu_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_mismatched.get_name_leafdata())
                        if (self.not_supported_qinq.is_set or self.not_supported_qinq.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_qinq.get_name_leafdata())
                        if (self.num_ma_cwithdraw_msg_received.is_set or self.num_ma_cwithdraw_msg_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.num_ma_cwithdraw_msg_received.get_name_leafdata())
                        if (self.number_ma_cwithdraw_message_sent.is_set or self.number_ma_cwithdraw_message_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_ma_cwithdraw_message_sent.get_name_leafdata())
                        if (self.out_of_memory_state.is_set or self.out_of_memory_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_of_memory_state.get_name_leafdata())
                        if (self.payload_bytes_mismatched.is_set or self.payload_bytes_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.payload_bytes_mismatched.get_name_leafdata())
                        if (self.payload_type_mismatched.is_set or self.payload_type_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.payload_type_mismatched.get_name_leafdata())
                        if (self.preferred_path_disable_fallback.is_set or self.preferred_path_disable_fallback.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.preferred_path_disable_fallback.get_name_leafdata())
                        if (self.primary_peer_id.is_set or self.primary_peer_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_peer_id.get_name_leafdata())
                        if (self.primary_pseudo_wire_id.is_set or self.primary_pseudo_wire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_pseudo_wire_id.get_name_leafdata())
                        if (self.primary_pw.is_set or self.primary_pw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_pw.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.pseudo_wire_id.is_set or self.pseudo_wire_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_id.get_name_leafdata())
                        if (self.pseudo_wire_state.is_set or self.pseudo_wire_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_state.get_name_leafdata())
                        if (self.pseudo_wire_type_mismatched.is_set or self.pseudo_wire_type_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pseudo_wire_type_mismatched.get_name_leafdata())
                        if (self.pw_class_name.is_set or self.pw_class_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_class_name.get_name_leafdata())
                        if (self.pw_flow_label_code17_disabled.is_set or self.pw_flow_label_code17_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_code17_disabled.get_name_leafdata())
                        if (self.pw_flow_label_type.is_set or self.pw_flow_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type.get_name_leafdata())
                        if (self.pw_flow_label_type_cfg.is_set or self.pw_flow_label_type_cfg.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_flow_label_type_cfg.get_name_leafdata())
                        if (self.pw_redundancy_initial_delay.is_set or self.pw_redundancy_initial_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_redundancy_initial_delay.get_name_leafdata())
                        if (self.pw_redundancy_one_way.is_set or self.pw_redundancy_one_way.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_redundancy_one_way.get_name_leafdata())
                        if (self.pw_status_use.is_set or self.pw_status_use.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pw_status_use.get_name_leafdata())
                        if (self.pwlsd_rewrite_failed.is_set or self.pwlsd_rewrite_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pwlsd_rewrite_failed.get_name_leafdata())
                        if (self.remote_control_word.is_set or self.remote_control_word.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_control_word.get_name_leafdata())
                        if (self.remote_label_failed.is_set or self.remote_label_failed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_label_failed.get_name_leafdata())
                        if (self.remote_pseudo_wire_type.is_set or self.remote_pseudo_wire_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_pseudo_wire_type.get_name_leafdata())
                        if (self.required_bw.is_set or self.required_bw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.required_bw.get_name_leafdata())
                        if (self.resync_enabled.is_set or self.resync_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_enabled.get_name_leafdata())
                        if (self.resync_threshold.is_set or self.resync_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.resync_threshold.get_name_leafdata())
                        if (self.rtp_mismatched.is_set or self.rtp_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rtp_mismatched.get_name_leafdata())
                        if (self.sequencing_type.is_set or self.sequencing_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequencing_type.get_name_leafdata())
                        if (self.shutdown.is_set or self.shutdown.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.shutdown.get_name_leafdata())
                        if (self.sig_pkts_mismatched.is_set or self.sig_pkts_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sig_pkts_mismatched.get_name_leafdata())
                        if (self.ssrc_mismatched.is_set or self.ssrc_mismatched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssrc_mismatched.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.table_policy_name.is_set or self.table_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_policy_name.get_name_leafdata())
                        if (self.tag_rewrite.is_set or self.tag_rewrite.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tag_rewrite.get_name_leafdata())
                        if (self.time_created.is_set or self.time_created.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_created.get_name_leafdata())
                        if (self.time_elapsed_creation.is_set or self.time_elapsed_creation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_creation.get_name_leafdata())
                        if (self.time_elapsed_status_changed.is_set or self.time_elapsed_status_changed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_changed.get_name_leafdata())
                        if (self.time_elapsed_status_down.is_set or self.time_elapsed_status_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_elapsed_status_down.get_name_leafdata())
                        if (self.transport_lsp_down.is_set or self.transport_lsp_down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transport_lsp_down.get_name_leafdata())
                        if (self.xconnect_id.is_set or self.xconnect_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.xconnect_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "encapsulation-info"):
                            if (self.encapsulation_info is None):
                                self.encapsulation_info = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"
                            return self.encapsulation_info

                        if (child_yang_name == "local-interface"):
                            if (self.local_interface is None):
                                self.local_interface = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"
                            return self.local_interface

                        if (child_yang_name == "local-signalling"):
                            if (self.local_signalling is None):
                                self.local_signalling = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"
                            return self.local_signalling

                        if (child_yang_name == "p2mp-pw"):
                            if (self.p2mp_pw is None):
                                self.p2mp_pw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            return self.p2mp_pw

                        if (child_yang_name == "peer-id"):
                            if (self.peer_id is None):
                                self.peer_id = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"
                            return self.peer_id

                        if (child_yang_name == "preferred-path"):
                            if (self.preferred_path is None):
                                self.preferred_path = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"
                            return self.preferred_path

                        if (child_yang_name == "remote-interface"):
                            if (self.remote_interface is None):
                                self.remote_interface = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"
                            return self.remote_interface

                        if (child_yang_name == "remote-signalling"):
                            if (self.remote_signalling is None):
                                self.remote_signalling = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"
                            return self.remote_signalling

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "encapsulation-info" or name == "local-interface" or name == "local-signalling" or name == "p2mp-pw" or name == "peer-id" or name == "preferred-path" or name == "remote-interface" or name == "remote-signalling" or name == "statistics" or name == "ad-method" or name == "ad-remote-down" or name == "admited-bw" or name == "auto-discovery" or name == "backup-active" or name == "backup-force-active" or name == "backup-pw" or name == "bitrate-mismatched" or name == "bridge-pw-type-mismatch" or name == "cas-mismatched" or name == "diff-ts-mismatched" or name == "disable-delay" or name == "disable-never" or name == "evpn-src-acid" or name == "fe-ctype" or name == "forward-class" or name == "freq-mismatched" or name == "illegal-control-word" or name == "imposed-vlan-id" or name == "interworking" or name == "ipv6-local-source-address" or name == "is-evpnvpws-type" or name == "is-flow-label-static" or name == "is-multi-segment-pseudowire" or name == "is-partially-programmed" or name == "is-pwr-type" or name == "is-vfi" or name == "last-time-status-changed" or name == "last-time-status-down" or name == "ldp-label-advertise-failed" or name == "load-balance" or name == "local-control-word" or name == "local-label-failed" or name == "local-pseudo-wire-type" or name == "local-source-address" or name == "mac-limit-oper-down" or name == "mtu-mismatched" or name == "not-supported-qinq" or name == "num-ma-cwithdraw-msg-received" or name == "number-ma-cwithdraw-message-sent" or name == "out-of-memory-state" or name == "payload-bytes-mismatched" or name == "payload-type-mismatched" or name == "preferred-path-disable-fallback" or name == "primary-peer-id" or name == "primary-pseudo-wire-id" or name == "primary-pw" or name == "protocol" or name == "pseudo-wire-id" or name == "pseudo-wire-state" or name == "pseudo-wire-type-mismatched" or name == "pw-class-name" or name == "pw-flow-label-code17-disabled" or name == "pw-flow-label-type" or name == "pw-flow-label-type-cfg" or name == "pw-redundancy-initial-delay" or name == "pw-redundancy-one-way" or name == "pw-status-use" or name == "pwlsd-rewrite-failed" or name == "remote-control-word" or name == "remote-label-failed" or name == "remote-pseudo-wire-type" or name == "required-bw" or name == "resync-enabled" or name == "resync-threshold" or name == "rtp-mismatched" or name == "sequencing-type" or name == "shutdown" or name == "sig-pkts-mismatched" or name == "ssrc-mismatched" or name == "state" or name == "table-policy-name" or name == "tag-rewrite" or name == "time-created" or name == "time-elapsed-creation" or name == "time-elapsed-status-changed" or name == "time-elapsed-status-down" or name == "transport-lsp-down" or name == "xconnect-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ad-method"):
                            self.ad_method = value
                            self.ad_method.value_namespace = name_space
                            self.ad_method.value_namespace_prefix = name_space_prefix
                        if(value_path == "ad-remote-down"):
                            self.ad_remote_down = value
                            self.ad_remote_down.value_namespace = name_space
                            self.ad_remote_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "admited-bw"):
                            self.admited_bw = value
                            self.admited_bw.value_namespace = name_space
                            self.admited_bw.value_namespace_prefix = name_space_prefix
                        if(value_path == "auto-discovery"):
                            self.auto_discovery = value
                            self.auto_discovery.value_namespace = name_space
                            self.auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-active"):
                            self.backup_active = value
                            self.backup_active.value_namespace = name_space
                            self.backup_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-force-active"):
                            self.backup_force_active = value
                            self.backup_force_active.value_namespace = name_space
                            self.backup_force_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-pw"):
                            self.backup_pw = value
                            self.backup_pw.value_namespace = name_space
                            self.backup_pw.value_namespace_prefix = name_space_prefix
                        if(value_path == "bitrate-mismatched"):
                            self.bitrate_mismatched = value
                            self.bitrate_mismatched.value_namespace = name_space
                            self.bitrate_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "bridge-pw-type-mismatch"):
                            self.bridge_pw_type_mismatch = value
                            self.bridge_pw_type_mismatch.value_namespace = name_space
                            self.bridge_pw_type_mismatch.value_namespace_prefix = name_space_prefix
                        if(value_path == "cas-mismatched"):
                            self.cas_mismatched = value
                            self.cas_mismatched.value_namespace = name_space
                            self.cas_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "diff-ts-mismatched"):
                            self.diff_ts_mismatched = value
                            self.diff_ts_mismatched.value_namespace = name_space
                            self.diff_ts_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-delay"):
                            self.disable_delay = value
                            self.disable_delay.value_namespace = name_space
                            self.disable_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-never"):
                            self.disable_never = value
                            self.disable_never.value_namespace = name_space
                            self.disable_never.value_namespace_prefix = name_space_prefix
                        if(value_path == "evpn-src-acid"):
                            self.evpn_src_acid = value
                            self.evpn_src_acid.value_namespace = name_space
                            self.evpn_src_acid.value_namespace_prefix = name_space_prefix
                        if(value_path == "fe-ctype"):
                            self.fe_ctype = value
                            self.fe_ctype.value_namespace = name_space
                            self.fe_ctype.value_namespace_prefix = name_space_prefix
                        if(value_path == "forward-class"):
                            self.forward_class = value
                            self.forward_class.value_namespace = name_space
                            self.forward_class.value_namespace_prefix = name_space_prefix
                        if(value_path == "freq-mismatched"):
                            self.freq_mismatched = value
                            self.freq_mismatched.value_namespace = name_space
                            self.freq_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "illegal-control-word"):
                            self.illegal_control_word = value
                            self.illegal_control_word.value_namespace = name_space
                            self.illegal_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "imposed-vlan-id"):
                            self.imposed_vlan_id = value
                            self.imposed_vlan_id.value_namespace = name_space
                            self.imposed_vlan_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interworking"):
                            self.interworking = value
                            self.interworking.value_namespace = name_space
                            self.interworking.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-local-source-address"):
                            self.ipv6_local_source_address = value
                            self.ipv6_local_source_address.value_namespace = name_space
                            self.ipv6_local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-evpnvpws-type"):
                            self.is_evpnvpws_type = value
                            self.is_evpnvpws_type.value_namespace = name_space
                            self.is_evpnvpws_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-flow-label-static"):
                            self.is_flow_label_static = value
                            self.is_flow_label_static.value_namespace = name_space
                            self.is_flow_label_static.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multi-segment-pseudowire"):
                            self.is_multi_segment_pseudowire = value
                            self.is_multi_segment_pseudowire.value_namespace = name_space
                            self.is_multi_segment_pseudowire.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-partially-programmed"):
                            self.is_partially_programmed = value
                            self.is_partially_programmed.value_namespace = name_space
                            self.is_partially_programmed.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pwr-type"):
                            self.is_pwr_type = value
                            self.is_pwr_type.value_namespace = name_space
                            self.is_pwr_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-vfi"):
                            self.is_vfi = value
                            self.is_vfi.value_namespace = name_space
                            self.is_vfi.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-changed"):
                            self.last_time_status_changed = value
                            self.last_time_status_changed.value_namespace = name_space
                            self.last_time_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-status-down"):
                            self.last_time_status_down = value
                            self.last_time_status_down.value_namespace = name_space
                            self.last_time_status_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "ldp-label-advertise-failed"):
                            self.ldp_label_advertise_failed = value
                            self.ldp_label_advertise_failed.value_namespace = name_space
                            self.ldp_label_advertise_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance"):
                            self.load_balance = value
                            self.load_balance.value_namespace = name_space
                            self.load_balance.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-control-word"):
                            self.local_control_word = value
                            self.local_control_word.value_namespace = name_space
                            self.local_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-label-failed"):
                            self.local_label_failed = value
                            self.local_label_failed.value_namespace = name_space
                            self.local_label_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-pseudo-wire-type"):
                            self.local_pseudo_wire_type = value
                            self.local_pseudo_wire_type.value_namespace = name_space
                            self.local_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-source-address"):
                            self.local_source_address = value
                            self.local_source_address.value_namespace = name_space
                            self.local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-limit-oper-down"):
                            self.mac_limit_oper_down = value
                            self.mac_limit_oper_down.value_namespace = name_space
                            self.mac_limit_oper_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-mismatched"):
                            self.mtu_mismatched = value
                            self.mtu_mismatched.value_namespace = name_space
                            self.mtu_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-qinq"):
                            self.not_supported_qinq = value
                            self.not_supported_qinq.value_namespace = name_space
                            self.not_supported_qinq.value_namespace_prefix = name_space_prefix
                        if(value_path == "num-ma-cwithdraw-msg-received"):
                            self.num_ma_cwithdraw_msg_received = value
                            self.num_ma_cwithdraw_msg_received.value_namespace = name_space
                            self.num_ma_cwithdraw_msg_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-ma-cwithdraw-message-sent"):
                            self.number_ma_cwithdraw_message_sent = value
                            self.number_ma_cwithdraw_message_sent.value_namespace = name_space
                            self.number_ma_cwithdraw_message_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-of-memory-state"):
                            self.out_of_memory_state = value
                            self.out_of_memory_state.value_namespace = name_space
                            self.out_of_memory_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "payload-bytes-mismatched"):
                            self.payload_bytes_mismatched = value
                            self.payload_bytes_mismatched.value_namespace = name_space
                            self.payload_bytes_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "payload-type-mismatched"):
                            self.payload_type_mismatched = value
                            self.payload_type_mismatched.value_namespace = name_space
                            self.payload_type_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "preferred-path-disable-fallback"):
                            self.preferred_path_disable_fallback = value
                            self.preferred_path_disable_fallback.value_namespace = name_space
                            self.preferred_path_disable_fallback.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-peer-id"):
                            self.primary_peer_id = value
                            self.primary_peer_id.value_namespace = name_space
                            self.primary_peer_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-pseudo-wire-id"):
                            self.primary_pseudo_wire_id = value
                            self.primary_pseudo_wire_id.value_namespace = name_space
                            self.primary_pseudo_wire_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-pw"):
                            self.primary_pw = value
                            self.primary_pw.value_namespace = name_space
                            self.primary_pw.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-id"):
                            self.pseudo_wire_id = value
                            self.pseudo_wire_id.value_namespace = name_space
                            self.pseudo_wire_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-state"):
                            self.pseudo_wire_state = value
                            self.pseudo_wire_state.value_namespace = name_space
                            self.pseudo_wire_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "pseudo-wire-type-mismatched"):
                            self.pseudo_wire_type_mismatched = value
                            self.pseudo_wire_type_mismatched.value_namespace = name_space
                            self.pseudo_wire_type_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-class-name"):
                            self.pw_class_name = value
                            self.pw_class_name.value_namespace = name_space
                            self.pw_class_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-code17-disabled"):
                            self.pw_flow_label_code17_disabled = value
                            self.pw_flow_label_code17_disabled.value_namespace = name_space
                            self.pw_flow_label_code17_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type"):
                            self.pw_flow_label_type = value
                            self.pw_flow_label_type.value_namespace = name_space
                            self.pw_flow_label_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-flow-label-type-cfg"):
                            self.pw_flow_label_type_cfg = value
                            self.pw_flow_label_type_cfg.value_namespace = name_space
                            self.pw_flow_label_type_cfg.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-redundancy-initial-delay"):
                            self.pw_redundancy_initial_delay = value
                            self.pw_redundancy_initial_delay.value_namespace = name_space
                            self.pw_redundancy_initial_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-redundancy-one-way"):
                            self.pw_redundancy_one_way = value
                            self.pw_redundancy_one_way.value_namespace = name_space
                            self.pw_redundancy_one_way.value_namespace_prefix = name_space_prefix
                        if(value_path == "pw-status-use"):
                            self.pw_status_use = value
                            self.pw_status_use.value_namespace = name_space
                            self.pw_status_use.value_namespace_prefix = name_space_prefix
                        if(value_path == "pwlsd-rewrite-failed"):
                            self.pwlsd_rewrite_failed = value
                            self.pwlsd_rewrite_failed.value_namespace = name_space
                            self.pwlsd_rewrite_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-control-word"):
                            self.remote_control_word = value
                            self.remote_control_word.value_namespace = name_space
                            self.remote_control_word.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-label-failed"):
                            self.remote_label_failed = value
                            self.remote_label_failed.value_namespace = name_space
                            self.remote_label_failed.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-pseudo-wire-type"):
                            self.remote_pseudo_wire_type = value
                            self.remote_pseudo_wire_type.value_namespace = name_space
                            self.remote_pseudo_wire_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "required-bw"):
                            self.required_bw = value
                            self.required_bw.value_namespace = name_space
                            self.required_bw.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-enabled"):
                            self.resync_enabled = value
                            self.resync_enabled.value_namespace = name_space
                            self.resync_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "resync-threshold"):
                            self.resync_threshold = value
                            self.resync_threshold.value_namespace = name_space
                            self.resync_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "rtp-mismatched"):
                            self.rtp_mismatched = value
                            self.rtp_mismatched.value_namespace = name_space
                            self.rtp_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "sequencing-type"):
                            self.sequencing_type = value
                            self.sequencing_type.value_namespace = name_space
                            self.sequencing_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "shutdown"):
                            self.shutdown = value
                            self.shutdown.value_namespace = name_space
                            self.shutdown.value_namespace_prefix = name_space_prefix
                        if(value_path == "sig-pkts-mismatched"):
                            self.sig_pkts_mismatched = value
                            self.sig_pkts_mismatched.value_namespace = name_space
                            self.sig_pkts_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssrc-mismatched"):
                            self.ssrc_mismatched = value
                            self.ssrc_mismatched.value_namespace = name_space
                            self.ssrc_mismatched.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-policy-name"):
                            self.table_policy_name = value
                            self.table_policy_name.value_namespace = name_space
                            self.table_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "tag-rewrite"):
                            self.tag_rewrite = value
                            self.tag_rewrite.value_namespace = name_space
                            self.tag_rewrite.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-created"):
                            self.time_created = value
                            self.time_created.value_namespace = name_space
                            self.time_created.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-creation"):
                            self.time_elapsed_creation = value
                            self.time_elapsed_creation.value_namespace = name_space
                            self.time_elapsed_creation.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-changed"):
                            self.time_elapsed_status_changed = value
                            self.time_elapsed_status_changed.value_namespace = name_space
                            self.time_elapsed_status_changed.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-elapsed-status-down"):
                            self.time_elapsed_status_down = value
                            self.time_elapsed_status_down.value_namespace = name_space
                            self.time_elapsed_status_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "transport-lsp-down"):
                            self.transport_lsp_down = value
                            self.transport_lsp_down.value_namespace = name_space
                            self.transport_lsp_down.value_namespace_prefix = name_space_prefix
                        if(value_path == "xconnect-id"):
                            self.xconnect_id = value
                            self.xconnect_id.value_namespace = name_space
                            self.xconnect_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.pseudowire:
                        if (c.has_data()):
                            return True
                    return (
                        self.fxc_id.is_set or
                        self.name.is_set or
                        self.num_p_ws.is_set or
                        self.state.is_set)

                def has_operation(self):
                    for c in self.pseudowire:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.fxc_id.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        self.num_p_ws.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flexible-xconnect-service-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.fxc_id.is_set or self.fxc_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.fxc_id.get_name_leafdata())
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())
                    if (self.num_p_ws.is_set or self.num_p_ws.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.num_p_ws.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pseudowire"):
                        for c in self.pseudowire:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.pseudowire.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pseudowire" or name == "fxc-id" or name == "name" or name == "num-p-ws" or name == "state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "fxc-id"):
                        self.fxc_id = value
                        self.fxc_id.value_namespace = name_space
                        self.fxc_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix
                    if(value_path == "num-p-ws"):
                        self.num_p_ws = value
                        self.num_p_ws.value_namespace = name_space
                        self.num_p_ws.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.name.is_set or
                    (self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs.has_data()) or
                    (self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.name.yfilter != YFilter.not_set or
                    (self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs.has_operation()) or
                    (self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "flexible-xconnect-service" + "[name='" + self.name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/flexible-xconnect-services/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "flexible-xconnect-service-acs"):
                    if (self.flexible_xconnect_service_acs is None):
                        self.flexible_xconnect_service_acs = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                        self.flexible_xconnect_service_acs.parent = self
                        self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"
                    return self.flexible_xconnect_service_acs

                if (child_yang_name == "flexible-xconnect-service-info"):
                    if (self.flexible_xconnect_service_info is None):
                        self.flexible_xconnect_service_info = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                        self.flexible_xconnect_service_info.parent = self
                        self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                    return self.flexible_xconnect_service_info

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "flexible-xconnect-service-acs" or name == "flexible-xconnect-service-info" or name == "name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "name"):
                    self.name = value
                    self.name.value_namespace = name_space
                    self.name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.flexible_xconnect_service:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.flexible_xconnect_service:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "flexible-xconnect-services" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "flexible-xconnect-service"):
                for c in self.flexible_xconnect_service:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.flexible_xconnect_service.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "flexible-xconnect-service"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class XconnectBrief(Entity):
        """
        XConnect brief information
        
        .. attribute:: encapsulation_report_matrix
        
        	Encapsulation report counters matrix
        	**type**\: list of    :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectBrief.EncapsulationReportMatrix>`
        
        .. attribute:: encapsulation_total
        
        	Total summary
        	**type**\: list of    :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectBrief.EncapsulationTotal>`
        
        .. attribute:: main_total_down
        
        	Total Number of non\-active Cross\-Conections with valid encaps
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: main_total_unresolved
        
        	Total Number of unresolved Cross\-Conections with valid encaps
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: main_total_up
        
        	Total Number of active Cross\-Conections with valid encaps
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: memory_state
        
        	L2VPN memory state
        	**type**\:   :py:class:`L2VpnMemoryState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMemoryState>`
        
        .. attribute:: undefined_xc
        
        	Undefined xc including PW\-PW
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(L2Vpn.XconnectBrief, self).__init__()

            self.yang_name = "xconnect-brief"
            self.yang_parent_name = "l2vpn"

            self.main_total_down = YLeaf(YType.uint32, "main-total-down")

            self.main_total_unresolved = YLeaf(YType.uint32, "main-total-unresolved")

            self.main_total_up = YLeaf(YType.uint32, "main-total-up")

            self.memory_state = YLeaf(YType.enumeration, "memory-state")

            self.undefined_xc = YLeaf(YType.uint32, "undefined-xc")

            self.encapsulation_report_matrix = YList(self)
            self.encapsulation_total = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("main_total_down",
                            "main_total_unresolved",
                            "main_total_up",
                            "memory_state",
                            "undefined_xc") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(L2Vpn.XconnectBrief, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(L2Vpn.XconnectBrief, self).__setattr__(name, value)


        class EncapsulationReportMatrix(Entity):
            """
            Encapsulation report counters matrix
            
            .. attribute:: ac1
            
            	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
            	**type**\: list of    :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.XconnectBrief.EncapsulationReportMatrix, self).__init__()

                self.yang_name = "encapsulation-report-matrix"
                self.yang_parent_name = "xconnect-brief"

                self.ac1 = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.XconnectBrief.EncapsulationReportMatrix, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.XconnectBrief.EncapsulationReportMatrix, self).__setattr__(name, value)


            class Ac1(Entity):
                """
                Array of l2vpn\_xc\_brief\_first layer indexed by
                the AC1 encapsulation type
                
                .. attribute:: ac2
                
                	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                	**type**\: list of    :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__init__()

                    self.yang_name = "ac1"
                    self.yang_parent_name = "encapsulation-report-matrix"

                    self.ac2 = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__setattr__(name, value)


                class Ac2(Entity):
                    """
                    Array of l2vpn\_xc\_brief\_line indexed by the AC2
                    encapsulation type plus one type for PW
                    
                    .. attribute:: ac1_encapsulation
                    
                    	AC1 encapsulation
                    	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                    
                    .. attribute:: ac2_encapsulation
                    
                    	AC2 encapsulation
                    	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
                    
                    .. attribute:: down_count
                    
                    	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: psn_type
                    
                    	PSN Type
                    	**type**\:   :py:class:`L2VpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBriefPsn>`
                    
                    .. attribute:: unresolved_count
                    
                    	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: up_count
                    
                    	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__init__()

                        self.yang_name = "ac2"
                        self.yang_parent_name = "ac1"

                        self.ac1_encapsulation = YLeaf(YType.enumeration, "ac1-encapsulation")

                        self.ac2_encapsulation = YLeaf(YType.enumeration, "ac2-encapsulation")

                        self.down_count = YLeafList(YType.uint32, "down-count")

                        self.psn_type = YLeaf(YType.enumeration, "psn-type")

                        self.unresolved_count = YLeafList(YType.uint32, "unresolved-count")

                        self.up_count = YLeafList(YType.uint32, "up-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ac1_encapsulation",
                                        "ac2_encapsulation",
                                        "down_count",
                                        "psn_type",
                                        "unresolved_count",
                                        "up_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__setattr__(name, value)

                    def has_data(self):
                        for leaf in self.down_count.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.unresolved_count.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.up_count.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.ac1_encapsulation.is_set or
                            self.ac2_encapsulation.is_set or
                            self.psn_type.is_set)

                    def has_operation(self):
                        for leaf in self.down_count.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.unresolved_count.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.up_count.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ac1_encapsulation.yfilter != YFilter.not_set or
                            self.ac2_encapsulation.yfilter != YFilter.not_set or
                            self.down_count.yfilter != YFilter.not_set or
                            self.psn_type.yfilter != YFilter.not_set or
                            self.unresolved_count.yfilter != YFilter.not_set or
                            self.up_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ac2" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-brief/encapsulation-report-matrix/ac1/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ac1_encapsulation.is_set or self.ac1_encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac1_encapsulation.get_name_leafdata())
                        if (self.ac2_encapsulation.is_set or self.ac2_encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ac2_encapsulation.get_name_leafdata())
                        if (self.psn_type.is_set or self.psn_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.psn_type.get_name_leafdata())

                        leaf_name_data.extend(self.down_count.get_name_leafdata())

                        leaf_name_data.extend(self.unresolved_count.get_name_leafdata())

                        leaf_name_data.extend(self.up_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ac1-encapsulation" or name == "ac2-encapsulation" or name == "down-count" or name == "psn-type" or name == "unresolved-count" or name == "up-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ac1-encapsulation"):
                            self.ac1_encapsulation = value
                            self.ac1_encapsulation.value_namespace = name_space
                            self.ac1_encapsulation.value_namespace_prefix = name_space_prefix
                        if(value_path == "ac2-encapsulation"):
                            self.ac2_encapsulation = value
                            self.ac2_encapsulation.value_namespace = name_space
                            self.ac2_encapsulation.value_namespace_prefix = name_space_prefix
                        if(value_path == "down-count"):
                            self.down_count.append(value)
                        if(value_path == "psn-type"):
                            self.psn_type = value
                            self.psn_type.value_namespace = name_space
                            self.psn_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "unresolved-count"):
                            self.unresolved_count.append(value)
                        if(value_path == "up-count"):
                            self.up_count.append(value)

                def has_data(self):
                    for c in self.ac2:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ac2:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ac1" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-brief/encapsulation-report-matrix/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ac2"):
                        for c in self.ac2:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ac2.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ac2"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                for c in self.ac1:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.ac1:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "encapsulation-report-matrix" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-brief/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "ac1"):
                    for c in self.ac1:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.ac1.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ac1"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EncapsulationTotal(Entity):
            """
            Total summary
            
            .. attribute:: ac1_encapsulation
            
            	AC1 encapsulation
            	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
            
            .. attribute:: ac2_encapsulation
            
            	AC2 encapsulation
            	**type**\:   :py:class:`L2VpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncap>`
            
            .. attribute:: down_count
            
            	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: psn_type
            
            	PSN Type
            	**type**\:   :py:class:`L2VpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBriefPsn>`
            
            .. attribute:: unresolved_count
            
            	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_count
            
            	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(L2Vpn.XconnectBrief.EncapsulationTotal, self).__init__()

                self.yang_name = "encapsulation-total"
                self.yang_parent_name = "xconnect-brief"

                self.ac1_encapsulation = YLeaf(YType.enumeration, "ac1-encapsulation")

                self.ac2_encapsulation = YLeaf(YType.enumeration, "ac2-encapsulation")

                self.down_count = YLeafList(YType.uint32, "down-count")

                self.psn_type = YLeaf(YType.enumeration, "psn-type")

                self.unresolved_count = YLeafList(YType.uint32, "unresolved-count")

                self.up_count = YLeafList(YType.uint32, "up-count")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("ac1_encapsulation",
                                "ac2_encapsulation",
                                "down_count",
                                "psn_type",
                                "unresolved_count",
                                "up_count") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(L2Vpn.XconnectBrief.EncapsulationTotal, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(L2Vpn.XconnectBrief.EncapsulationTotal, self).__setattr__(name, value)

            def has_data(self):
                for leaf in self.down_count.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.unresolved_count.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.up_count.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                return (
                    self.ac1_encapsulation.is_set or
                    self.ac2_encapsulation.is_set or
                    self.psn_type.is_set)

            def has_operation(self):
                for leaf in self.down_count.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.unresolved_count.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.up_count.getYLeafs():
                    if (leaf.is_set):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.ac1_encapsulation.yfilter != YFilter.not_set or
                    self.ac2_encapsulation.yfilter != YFilter.not_set or
                    self.down_count.yfilter != YFilter.not_set or
                    self.psn_type.yfilter != YFilter.not_set or
                    self.unresolved_count.yfilter != YFilter.not_set or
                    self.up_count.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "encapsulation-total" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/xconnect-brief/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.ac1_encapsulation.is_set or self.ac1_encapsulation.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ac1_encapsulation.get_name_leafdata())
                if (self.ac2_encapsulation.is_set or self.ac2_encapsulation.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ac2_encapsulation.get_name_leafdata())
                if (self.psn_type.is_set or self.psn_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.psn_type.get_name_leafdata())

                leaf_name_data.extend(self.down_count.get_name_leafdata())

                leaf_name_data.extend(self.unresolved_count.get_name_leafdata())

                leaf_name_data.extend(self.up_count.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ac1-encapsulation" or name == "ac2-encapsulation" or name == "down-count" or name == "psn-type" or name == "unresolved-count" or name == "up-count"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "ac1-encapsulation"):
                    self.ac1_encapsulation = value
                    self.ac1_encapsulation.value_namespace = name_space
                    self.ac1_encapsulation.value_namespace_prefix = name_space_prefix
                if(value_path == "ac2-encapsulation"):
                    self.ac2_encapsulation = value
                    self.ac2_encapsulation.value_namespace = name_space
                    self.ac2_encapsulation.value_namespace_prefix = name_space_prefix
                if(value_path == "down-count"):
                    self.down_count.append(value)
                if(value_path == "psn-type"):
                    self.psn_type = value
                    self.psn_type.value_namespace = name_space
                    self.psn_type.value_namespace_prefix = name_space_prefix
                if(value_path == "unresolved-count"):
                    self.unresolved_count.append(value)
                if(value_path == "up-count"):
                    self.up_count.append(value)

        def has_data(self):
            for c in self.encapsulation_report_matrix:
                if (c.has_data()):
                    return True
            for c in self.encapsulation_total:
                if (c.has_data()):
                    return True
            return (
                self.main_total_down.is_set or
                self.main_total_unresolved.is_set or
                self.main_total_up.is_set or
                self.memory_state.is_set or
                self.undefined_xc.is_set)

        def has_operation(self):
            for c in self.encapsulation_report_matrix:
                if (c.has_operation()):
                    return True
            for c in self.encapsulation_total:
                if (c.has_operation()):
                    return True
            return (
                self.yfilter != YFilter.not_set or
                self.main_total_down.yfilter != YFilter.not_set or
                self.main_total_unresolved.yfilter != YFilter.not_set or
                self.main_total_up.yfilter != YFilter.not_set or
                self.memory_state.yfilter != YFilter.not_set or
                self.undefined_xc.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "xconnect-brief" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.main_total_down.is_set or self.main_total_down.yfilter != YFilter.not_set):
                leaf_name_data.append(self.main_total_down.get_name_leafdata())
            if (self.main_total_unresolved.is_set or self.main_total_unresolved.yfilter != YFilter.not_set):
                leaf_name_data.append(self.main_total_unresolved.get_name_leafdata())
            if (self.main_total_up.is_set or self.main_total_up.yfilter != YFilter.not_set):
                leaf_name_data.append(self.main_total_up.get_name_leafdata())
            if (self.memory_state.is_set or self.memory_state.yfilter != YFilter.not_set):
                leaf_name_data.append(self.memory_state.get_name_leafdata())
            if (self.undefined_xc.is_set or self.undefined_xc.yfilter != YFilter.not_set):
                leaf_name_data.append(self.undefined_xc.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "encapsulation-report-matrix"):
                for c in self.encapsulation_report_matrix:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.XconnectBrief.EncapsulationReportMatrix()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.encapsulation_report_matrix.append(c)
                return c

            if (child_yang_name == "encapsulation-total"):
                for c in self.encapsulation_total:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = L2Vpn.XconnectBrief.EncapsulationTotal()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.encapsulation_total.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "encapsulation-report-matrix" or name == "encapsulation-total" or name == "main-total-down" or name == "main-total-unresolved" or name == "main-total-up" or name == "memory-state" or name == "undefined-xc"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "main-total-down"):
                self.main_total_down = value
                self.main_total_down.value_namespace = name_space
                self.main_total_down.value_namespace_prefix = name_space_prefix
            if(value_path == "main-total-unresolved"):
                self.main_total_unresolved = value
                self.main_total_unresolved.value_namespace = name_space
                self.main_total_unresolved.value_namespace_prefix = name_space_prefix
            if(value_path == "main-total-up"):
                self.main_total_up = value
                self.main_total_up.value_namespace = name_space
                self.main_total_up.value_namespace_prefix = name_space_prefix
            if(value_path == "memory-state"):
                self.memory_state = value
                self.memory_state.value_namespace = name_space
                self.memory_state.value_namespace_prefix = name_space_prefix
            if(value_path == "undefined-xc"):
                self.undefined_xc = value
                self.undefined_xc.value_namespace = name_space
                self.undefined_xc.value_namespace_prefix = name_space_prefix

    def has_data(self):
        return (
            (self.bridge_domains is not None and self.bridge_domains.has_data()) or
            (self.bridge_summary is not None and self.bridge_summary.has_data()) or
            (self.discoveries is not None and self.discoveries.has_data()) or
            (self.discovery_summary is not None and self.discovery_summary.has_data()) or
            (self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary.has_data()) or
            (self.flexible_xconnect_services is not None and self.flexible_xconnect_services.has_data()) or
            (self.g8032 is not None and self.g8032.has_data()) or
            (self.generic_interface_list_details is not None and self.generic_interface_list_details.has_data()) or
            (self.generic_interfaces is not None and self.generic_interfaces.has_data()) or
            (self.global_settings is not None and self.global_settings.has_data()) or
            (self.iccp_sm is not None and self.iccp_sm.has_data()) or
            (self.indexes is not None and self.indexes.has_data()) or
            (self.l2vpn_collaborators is not None and self.l2vpn_collaborators.has_data()) or
            (self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa.has_data()) or
            (self.l2vpn_resource_state is not None and self.l2vpn_resource_state.has_data()) or
            (self.main_interfaces is not None and self.main_interfaces.has_data()) or
            (self.mstp_ports is not None and self.mstp_ports.has_data()) or
            (self.mstp_vlans is not None and self.mstp_vlans.has_data()) or
            (self.mvrp is not None and self.mvrp.has_data()) or
            (self.nsr is not None and self.nsr.has_data()) or
            (self.proc_fsm is not None and self.proc_fsm.has_data()) or
            (self.pseudowire_classes is not None and self.pseudowire_classes.has_data()) or
            (self.pseudowire_headend is not None and self.pseudowire_headend.has_data()) or
            (self.pwr is not None and self.pwr.has_data()) or
            (self.xconnect_brief is not None and self.xconnect_brief.has_data()) or
            (self.xconnect_groups is not None and self.xconnect_groups.has_data()) or
            (self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces.has_data()) or
            (self.xconnect_mp2mps is not None and self.xconnect_mp2mps.has_data()) or
            (self.xconnect_summary is not None and self.xconnect_summary.has_data()) or
            (self.xconnects is not None and self.xconnects.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.bridge_domains is not None and self.bridge_domains.has_operation()) or
            (self.bridge_summary is not None and self.bridge_summary.has_operation()) or
            (self.discoveries is not None and self.discoveries.has_operation()) or
            (self.discovery_summary is not None and self.discovery_summary.has_operation()) or
            (self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary.has_operation()) or
            (self.flexible_xconnect_services is not None and self.flexible_xconnect_services.has_operation()) or
            (self.g8032 is not None and self.g8032.has_operation()) or
            (self.generic_interface_list_details is not None and self.generic_interface_list_details.has_operation()) or
            (self.generic_interfaces is not None and self.generic_interfaces.has_operation()) or
            (self.global_settings is not None and self.global_settings.has_operation()) or
            (self.iccp_sm is not None and self.iccp_sm.has_operation()) or
            (self.indexes is not None and self.indexes.has_operation()) or
            (self.l2vpn_collaborators is not None and self.l2vpn_collaborators.has_operation()) or
            (self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa.has_operation()) or
            (self.l2vpn_resource_state is not None and self.l2vpn_resource_state.has_operation()) or
            (self.main_interfaces is not None and self.main_interfaces.has_operation()) or
            (self.mstp_ports is not None and self.mstp_ports.has_operation()) or
            (self.mstp_vlans is not None and self.mstp_vlans.has_operation()) or
            (self.mvrp is not None and self.mvrp.has_operation()) or
            (self.nsr is not None and self.nsr.has_operation()) or
            (self.proc_fsm is not None and self.proc_fsm.has_operation()) or
            (self.pseudowire_classes is not None and self.pseudowire_classes.has_operation()) or
            (self.pseudowire_headend is not None and self.pseudowire_headend.has_operation()) or
            (self.pwr is not None and self.pwr.has_operation()) or
            (self.xconnect_brief is not None and self.xconnect_brief.has_operation()) or
            (self.xconnect_groups is not None and self.xconnect_groups.has_operation()) or
            (self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces.has_operation()) or
            (self.xconnect_mp2mps is not None and self.xconnect_mp2mps.has_operation()) or
            (self.xconnect_summary is not None and self.xconnect_summary.has_operation()) or
            (self.xconnects is not None and self.xconnects.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-l2vpn-oper:l2vpn" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "bridge-domains"):
            if (self.bridge_domains is None):
                self.bridge_domains = L2Vpn.BridgeDomains()
                self.bridge_domains.parent = self
                self._children_name_map["bridge_domains"] = "bridge-domains"
            return self.bridge_domains

        if (child_yang_name == "bridge-summary"):
            if (self.bridge_summary is None):
                self.bridge_summary = L2Vpn.BridgeSummary()
                self.bridge_summary.parent = self
                self._children_name_map["bridge_summary"] = "bridge-summary"
            return self.bridge_summary

        if (child_yang_name == "discoveries"):
            if (self.discoveries is None):
                self.discoveries = L2Vpn.Discoveries()
                self.discoveries.parent = self
                self._children_name_map["discoveries"] = "discoveries"
            return self.discoveries

        if (child_yang_name == "discovery-summary"):
            if (self.discovery_summary is None):
                self.discovery_summary = L2Vpn.DiscoverySummary()
                self.discovery_summary.parent = self
                self._children_name_map["discovery_summary"] = "discovery-summary"
            return self.discovery_summary

        if (child_yang_name == "flexible-xconnect-service-summary"):
            if (self.flexible_xconnect_service_summary is None):
                self.flexible_xconnect_service_summary = L2Vpn.FlexibleXconnectServiceSummary()
                self.flexible_xconnect_service_summary.parent = self
                self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"
            return self.flexible_xconnect_service_summary

        if (child_yang_name == "flexible-xconnect-services"):
            if (self.flexible_xconnect_services is None):
                self.flexible_xconnect_services = L2Vpn.FlexibleXconnectServices()
                self.flexible_xconnect_services.parent = self
                self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"
            return self.flexible_xconnect_services

        if (child_yang_name == "g8032"):
            if (self.g8032 is None):
                self.g8032 = L2Vpn.G8032()
                self.g8032.parent = self
                self._children_name_map["g8032"] = "g8032"
            return self.g8032

        if (child_yang_name == "generic-interface-list-details"):
            if (self.generic_interface_list_details is None):
                self.generic_interface_list_details = L2Vpn.GenericInterfaceListDetails()
                self.generic_interface_list_details.parent = self
                self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"
            return self.generic_interface_list_details

        if (child_yang_name == "generic-interfaces"):
            if (self.generic_interfaces is None):
                self.generic_interfaces = L2Vpn.GenericInterfaces()
                self.generic_interfaces.parent = self
                self._children_name_map["generic_interfaces"] = "generic-interfaces"
            return self.generic_interfaces

        if (child_yang_name == "global-settings"):
            if (self.global_settings is None):
                self.global_settings = L2Vpn.GlobalSettings()
                self.global_settings.parent = self
                self._children_name_map["global_settings"] = "global-settings"
            return self.global_settings

        if (child_yang_name == "iccp-sm"):
            if (self.iccp_sm is None):
                self.iccp_sm = L2Vpn.IccpSm()
                self.iccp_sm.parent = self
                self._children_name_map["iccp_sm"] = "iccp-sm"
            return self.iccp_sm

        if (child_yang_name == "indexes"):
            if (self.indexes is None):
                self.indexes = L2Vpn.Indexes()
                self.indexes.parent = self
                self._children_name_map["indexes"] = "indexes"
            return self.indexes

        if (child_yang_name == "l2vpn-collaborators"):
            if (self.l2vpn_collaborators is None):
                self.l2vpn_collaborators = L2Vpn.L2VpnCollaborators()
                self.l2vpn_collaborators.parent = self
                self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"
            return self.l2vpn_collaborators

        if (child_yang_name == "l2vpn-pbb-bsa"):
            if (self.l2vpn_pbb_bsa is None):
                self.l2vpn_pbb_bsa = L2Vpn.L2VpnPbbBsa()
                self.l2vpn_pbb_bsa.parent = self
                self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"
            return self.l2vpn_pbb_bsa

        if (child_yang_name == "l2vpn-resource-state"):
            if (self.l2vpn_resource_state is None):
                self.l2vpn_resource_state = L2Vpn.L2VpnResourceState()
                self.l2vpn_resource_state.parent = self
                self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"
            return self.l2vpn_resource_state

        if (child_yang_name == "main-interfaces"):
            if (self.main_interfaces is None):
                self.main_interfaces = L2Vpn.MainInterfaces()
                self.main_interfaces.parent = self
                self._children_name_map["main_interfaces"] = "main-interfaces"
            return self.main_interfaces

        if (child_yang_name == "mstp-ports"):
            if (self.mstp_ports is None):
                self.mstp_ports = L2Vpn.MstpPorts()
                self.mstp_ports.parent = self
                self._children_name_map["mstp_ports"] = "mstp-ports"
            return self.mstp_ports

        if (child_yang_name == "mstp-vlans"):
            if (self.mstp_vlans is None):
                self.mstp_vlans = L2Vpn.MstpVlans()
                self.mstp_vlans.parent = self
                self._children_name_map["mstp_vlans"] = "mstp-vlans"
            return self.mstp_vlans

        if (child_yang_name == "mvrp"):
            if (self.mvrp is None):
                self.mvrp = L2Vpn.Mvrp()
                self.mvrp.parent = self
                self._children_name_map["mvrp"] = "mvrp"
            return self.mvrp

        if (child_yang_name == "nsr"):
            if (self.nsr is None):
                self.nsr = L2Vpn.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
            return self.nsr

        if (child_yang_name == "proc-fsm"):
            if (self.proc_fsm is None):
                self.proc_fsm = L2Vpn.ProcFsm()
                self.proc_fsm.parent = self
                self._children_name_map["proc_fsm"] = "proc-fsm"
            return self.proc_fsm

        if (child_yang_name == "pseudowire-classes"):
            if (self.pseudowire_classes is None):
                self.pseudowire_classes = L2Vpn.PseudowireClasses()
                self.pseudowire_classes.parent = self
                self._children_name_map["pseudowire_classes"] = "pseudowire-classes"
            return self.pseudowire_classes

        if (child_yang_name == "pseudowire-headend"):
            if (self.pseudowire_headend is None):
                self.pseudowire_headend = L2Vpn.PseudowireHeadend()
                self.pseudowire_headend.parent = self
                self._children_name_map["pseudowire_headend"] = "pseudowire-headend"
            return self.pseudowire_headend

        if (child_yang_name == "pwr"):
            if (self.pwr is None):
                self.pwr = L2Vpn.Pwr()
                self.pwr.parent = self
                self._children_name_map["pwr"] = "pwr"
            return self.pwr

        if (child_yang_name == "xconnect-brief"):
            if (self.xconnect_brief is None):
                self.xconnect_brief = L2Vpn.XconnectBrief()
                self.xconnect_brief.parent = self
                self._children_name_map["xconnect_brief"] = "xconnect-brief"
            return self.xconnect_brief

        if (child_yang_name == "xconnect-groups"):
            if (self.xconnect_groups is None):
                self.xconnect_groups = L2Vpn.XconnectGroups()
                self.xconnect_groups.parent = self
                self._children_name_map["xconnect_groups"] = "xconnect-groups"
            return self.xconnect_groups

        if (child_yang_name == "xconnect-mp2mp-ce2ces"):
            if (self.xconnect_mp2mp_ce2ces is None):
                self.xconnect_mp2mp_ce2ces = L2Vpn.XconnectMp2MpCe2Ces()
                self.xconnect_mp2mp_ce2ces.parent = self
                self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"
            return self.xconnect_mp2mp_ce2ces

        if (child_yang_name == "xconnect-mp2mps"):
            if (self.xconnect_mp2mps is None):
                self.xconnect_mp2mps = L2Vpn.XconnectMp2Mps()
                self.xconnect_mp2mps.parent = self
                self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"
            return self.xconnect_mp2mps

        if (child_yang_name == "xconnect-summary"):
            if (self.xconnect_summary is None):
                self.xconnect_summary = L2Vpn.XconnectSummary()
                self.xconnect_summary.parent = self
                self._children_name_map["xconnect_summary"] = "xconnect-summary"
            return self.xconnect_summary

        if (child_yang_name == "xconnects"):
            if (self.xconnects is None):
                self.xconnects = L2Vpn.Xconnects()
                self.xconnects.parent = self
                self._children_name_map["xconnects"] = "xconnects"
            return self.xconnects

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "bridge-domains" or name == "bridge-summary" or name == "discoveries" or name == "discovery-summary" or name == "flexible-xconnect-service-summary" or name == "flexible-xconnect-services" or name == "g8032" or name == "generic-interface-list-details" or name == "generic-interfaces" or name == "global-settings" or name == "iccp-sm" or name == "indexes" or name == "l2vpn-collaborators" or name == "l2vpn-pbb-bsa" or name == "l2vpn-resource-state" or name == "main-interfaces" or name == "mstp-ports" or name == "mstp-vlans" or name == "mvrp" or name == "nsr" or name == "proc-fsm" or name == "pseudowire-classes" or name == "pseudowire-headend" or name == "pwr" or name == "xconnect-brief" or name == "xconnect-groups" or name == "xconnect-mp2mp-ce2ces" or name == "xconnect-mp2mps" or name == "xconnect-summary" or name == "xconnects"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = L2Vpn()
        return self._top_entity

class GenericInterfaceListV2(Entity):
    """
    generic interface list v2
    
    .. attribute:: active
    
    	Active generic interface list operational data
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active>`
    
    .. attribute:: nodes
    
    	Table of generic interface list operational data for a particular node
    	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes>`
    
    .. attribute:: standby
    
    	Standby generic interface list operational data
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(GenericInterfaceListV2, self).__init__()
        self._top_entity = None

        self.yang_name = "generic-interface-list-v2"
        self.yang_parent_name = "Cisco-IOS-XR-l2vpn-oper"

        self.active = GenericInterfaceListV2.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.nodes = GenericInterfaceListV2.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._children_yang_names.add("nodes")

        self.standby = GenericInterfaceListV2.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")


    class Nodes(Entity):
        """
        Table of generic interface list operational data
        for a particular node
        
        .. attribute:: node
        
        	Generic interface list operational data for a particular node
        	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(GenericInterfaceListV2.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "generic-interface-list-v2"

            self.node = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(GenericInterfaceListV2.Nodes, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(GenericInterfaceListV2.Nodes, self).__setattr__(name, value)


        class Node(Entity):
            """
            Generic interface list operational data for a
            particular node
            
            .. attribute:: node_id  <key>
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: generic_interfaces
            
            	Generic interface list table
            	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node.GenericInterfaces>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(GenericInterfaceListV2.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"

                self.node_id = YLeaf(YType.str, "node-id")

                self.generic_interfaces = GenericInterfaceListV2.Nodes.Node.GenericInterfaces()
                self.generic_interfaces.parent = self
                self._children_name_map["generic_interfaces"] = "generic-interfaces"
                self._children_yang_names.add("generic-interfaces")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("node_id") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(GenericInterfaceListV2.Nodes.Node, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(GenericInterfaceListV2.Nodes.Node, self).__setattr__(name, value)


            class GenericInterfaces(Entity):
                """
                Generic interface list table
                
                .. attribute:: generic_interface
                
                	Generic Interface List
                	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(GenericInterfaceListV2.Nodes.Node.GenericInterfaces, self).__init__()

                    self.yang_name = "generic-interfaces"
                    self.yang_parent_name = "node"

                    self.generic_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(GenericInterfaceListV2.Nodes.Node.GenericInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(GenericInterfaceListV2.Nodes.Node.GenericInterfaces, self).__setattr__(name, value)


                class GenericInterface(Entity):
                    """
                    Generic Interface List
                    
                    .. attribute:: generic_interface_list_name  <key>
                    
                    	Generic Interface List Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface.Interface>`
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_list_name
                    
                    	Interface\-list name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is Interface list downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: is_provisioned
                    
                    	Is Provisioned
                    	**type**\:  bool
                    
                    .. attribute:: items
                    
                    	Number of items on which interface list is replicated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface, self).__init__()

                        self.yang_name = "generic-interface"
                        self.yang_parent_name = "generic-interfaces"

                        self.generic_interface_list_name = YLeaf(YType.str, "generic-interface-list-name")

                        self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                        self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                        self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                        self.is_provisioned = YLeaf(YType.boolean, "is-provisioned")

                        self.items = YLeaf(YType.uint32, "items")

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_interface_list_name",
                                        "interface_list_id",
                                        "interface_list_name",
                                        "is_fib_downloaded",
                                        "is_provisioned",
                                        "items") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "generic-interface"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                            self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                            self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "is_fib_downloaded",
                                            "not_supported_replications",
                                            "pending_replications") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.is_fib_downloaded.is_set or
                                self.not_supported_replications.is_set or
                                self.pending_replications.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_fib_downloaded.yfilter != YFilter.not_set or
                                self.not_supported_replications.yfilter != YFilter.not_set or
                                self.pending_replications.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                            if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                            if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pending_replications.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-fib-downloaded"):
                                self.is_fib_downloaded = value
                                self.is_fib_downloaded.value_namespace = name_space
                                self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-supported-replications"):
                                self.not_supported_replications = value
                                self.not_supported_replications.value_namespace = name_space
                                self.not_supported_replications.value_namespace_prefix = name_space_prefix
                            if(value_path == "pending-replications"):
                                self.pending_replications = value
                                self.pending_replications.value_namespace = name_space
                                self.pending_replications.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.generic_interface_list_name.is_set or
                            self.interface_list_id.is_set or
                            self.interface_list_name.is_set or
                            self.is_fib_downloaded.is_set or
                            self.is_provisioned.is_set or
                            self.items.is_set)

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_interface_list_name.yfilter != YFilter.not_set or
                            self.interface_list_id.yfilter != YFilter.not_set or
                            self.interface_list_name.yfilter != YFilter.not_set or
                            self.is_fib_downloaded.yfilter != YFilter.not_set or
                            self.is_provisioned.yfilter != YFilter.not_set or
                            self.items.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-interface" + "[generic-interface-list-name='" + self.generic_interface_list_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_interface_list_name.is_set or self.generic_interface_list_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_interface_list_name.get_name_leafdata())
                        if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                        if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                        if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                        if (self.is_provisioned.is_set or self.is_provisioned.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_provisioned.get_name_leafdata())
                        if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.items.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "generic-interface-list-name" or name == "interface-list-id" or name == "interface-list-name" or name == "is-fib-downloaded" or name == "is-provisioned" or name == "items"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-interface-list-name"):
                            self.generic_interface_list_name = value
                            self.generic_interface_list_name.value_namespace = name_space
                            self.generic_interface_list_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-list-id"):
                            self.interface_list_id = value
                            self.interface_list_id.value_namespace = name_space
                            self.interface_list_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-list-name"):
                            self.interface_list_name = value
                            self.interface_list_name.value_namespace = name_space
                            self.interface_list_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-fib-downloaded"):
                            self.is_fib_downloaded = value
                            self.is_fib_downloaded.value_namespace = name_space
                            self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-provisioned"):
                            self.is_provisioned = value
                            self.is_provisioned.value_namespace = name_space
                            self.is_provisioned.value_namespace_prefix = name_space_prefix
                        if(value_path == "items"):
                            self.items = value
                            self.items.value_namespace = name_space
                            self.items.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.generic_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.generic_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "generic-interface"):
                        for c in self.generic_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.generic_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "generic-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.node_id.is_set or
                    (self.generic_interfaces is not None and self.generic_interfaces.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.node_id.yfilter != YFilter.not_set or
                    (self.generic_interfaces is not None and self.generic_interfaces.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "node" + "[node-id='" + self.node_id.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/nodes/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_id.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "generic-interfaces"):
                    if (self.generic_interfaces is None):
                        self.generic_interfaces = GenericInterfaceListV2.Nodes.Node.GenericInterfaces()
                        self.generic_interfaces.parent = self
                        self._children_name_map["generic_interfaces"] = "generic-interfaces"
                    return self.generic_interfaces

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-interfaces" or name == "node-id"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "node-id"):
                    self.node_id = value
                    self.node_id.value_namespace = name_space
                    self.node_id.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.node:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.node:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "nodes" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "node"):
                for c in self.node:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = GenericInterfaceListV2.Nodes.Node()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.node.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "node"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Standby(Entity):
        """
        Standby generic interface list operational data
        
        .. attribute:: generic_interfaces
        
        	Generic interface list table
        	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby.GenericInterfaces>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(GenericInterfaceListV2.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "generic-interface-list-v2"

            self.generic_interfaces = GenericInterfaceListV2.Standby.GenericInterfaces()
            self.generic_interfaces.parent = self
            self._children_name_map["generic_interfaces"] = "generic-interfaces"
            self._children_yang_names.add("generic-interfaces")


        class GenericInterfaces(Entity):
            """
            Generic interface list table
            
            .. attribute:: generic_interface
            
            	Generic Interface List
            	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(GenericInterfaceListV2.Standby.GenericInterfaces, self).__init__()

                self.yang_name = "generic-interfaces"
                self.yang_parent_name = "standby"

                self.generic_interface = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(GenericInterfaceListV2.Standby.GenericInterfaces, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(GenericInterfaceListV2.Standby.GenericInterfaces, self).__setattr__(name, value)


            class GenericInterface(Entity):
                """
                Generic Interface List
                
                .. attribute:: generic_interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface.Interface>`
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_list_name
                
                	Interface\-list name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: is_fib_downloaded
                
                	Is Interface list downloaded to FIB
                	**type**\:  bool
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\:  bool
                
                .. attribute:: items
                
                	Number of items on which interface list is replicated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface, self).__init__()

                    self.yang_name = "generic-interface"
                    self.yang_parent_name = "generic-interfaces"

                    self.generic_interface_list_name = YLeaf(YType.str, "generic-interface-list-name")

                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                    self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                    self.is_provisioned = YLeaf(YType.boolean, "is-provisioned")

                    self.items = YLeaf(YType.uint32, "items")

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("generic_interface_list_name",
                                    "interface_list_id",
                                    "interface_list_name",
                                    "is_fib_downloaded",
                                    "is_provisioned",
                                    "items") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                        self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                        self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_fib_downloaded",
                                        "not_supported_replications",
                                        "pending_replications") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.is_fib_downloaded.is_set or
                            self.not_supported_replications.is_set or
                            self.pending_replications.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_fib_downloaded.yfilter != YFilter.not_set or
                            self.not_supported_replications.yfilter != YFilter.not_set or
                            self.pending_replications.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                        if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                        if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pending_replications.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-fib-downloaded"):
                            self.is_fib_downloaded = value
                            self.is_fib_downloaded.value_namespace = name_space
                            self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-replications"):
                            self.not_supported_replications = value
                            self.not_supported_replications.value_namespace = name_space
                            self.not_supported_replications.value_namespace_prefix = name_space_prefix
                        if(value_path == "pending-replications"):
                            self.pending_replications = value
                            self.pending_replications.value_namespace = name_space
                            self.pending_replications.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.generic_interface_list_name.is_set or
                        self.interface_list_id.is_set or
                        self.interface_list_name.is_set or
                        self.is_fib_downloaded.is_set or
                        self.is_provisioned.is_set or
                        self.items.is_set)

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.generic_interface_list_name.yfilter != YFilter.not_set or
                        self.interface_list_id.yfilter != YFilter.not_set or
                        self.interface_list_name.yfilter != YFilter.not_set or
                        self.is_fib_downloaded.yfilter != YFilter.not_set or
                        self.is_provisioned.yfilter != YFilter.not_set or
                        self.items.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-interface" + "[generic-interface-list-name='" + self.generic_interface_list_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/standby/generic-interfaces/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.generic_interface_list_name.is_set or self.generic_interface_list_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.generic_interface_list_name.get_name_leafdata())
                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                    if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                    if (self.is_provisioned.is_set or self.is_provisioned.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_provisioned.get_name_leafdata())
                    if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.items.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "generic-interface-list-name" or name == "interface-list-id" or name == "interface-list-name" or name == "is-fib-downloaded" or name == "is-provisioned" or name == "items"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "generic-interface-list-name"):
                        self.generic_interface_list_name = value
                        self.generic_interface_list_name.value_namespace = name_space
                        self.generic_interface_list_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-list-id"):
                        self.interface_list_id = value
                        self.interface_list_id.value_namespace = name_space
                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-list-name"):
                        self.interface_list_name = value
                        self.interface_list_name.value_namespace = name_space
                        self.interface_list_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-fib-downloaded"):
                        self.is_fib_downloaded = value
                        self.is_fib_downloaded.value_namespace = name_space
                        self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-provisioned"):
                        self.is_provisioned = value
                        self.is_provisioned.value_namespace = name_space
                        self.is_provisioned.value_namespace_prefix = name_space_prefix
                    if(value_path == "items"):
                        self.items = value
                        self.items.value_namespace = name_space
                        self.items.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.generic_interface:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.generic_interface:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "generic-interfaces" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "generic-interface"):
                    for c in self.generic_interface:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.generic_interface.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.generic_interfaces is not None and self.generic_interfaces.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.generic_interfaces is not None and self.generic_interfaces.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "standby" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "generic-interfaces"):
                if (self.generic_interfaces is None):
                    self.generic_interfaces = GenericInterfaceListV2.Standby.GenericInterfaces()
                    self.generic_interfaces.parent = self
                    self._children_name_map["generic_interfaces"] = "generic-interfaces"
                return self.generic_interfaces

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "generic-interfaces"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Active(Entity):
        """
        Active generic interface list operational data
        
        .. attribute:: generic_interfaces
        
        	Generic interface list table
        	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active.GenericInterfaces>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(GenericInterfaceListV2.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "generic-interface-list-v2"

            self.generic_interfaces = GenericInterfaceListV2.Active.GenericInterfaces()
            self.generic_interfaces.parent = self
            self._children_name_map["generic_interfaces"] = "generic-interfaces"
            self._children_yang_names.add("generic-interfaces")


        class GenericInterfaces(Entity):
            """
            Generic interface list table
            
            .. attribute:: generic_interface
            
            	Generic Interface List
            	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(GenericInterfaceListV2.Active.GenericInterfaces, self).__init__()

                self.yang_name = "generic-interfaces"
                self.yang_parent_name = "active"

                self.generic_interface = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(GenericInterfaceListV2.Active.GenericInterfaces, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(GenericInterfaceListV2.Active.GenericInterfaces, self).__setattr__(name, value)


            class GenericInterface(Entity):
                """
                Generic Interface List
                
                .. attribute:: generic_interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface.Interface>`
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_list_name
                
                	Interface\-list name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: is_fib_downloaded
                
                	Is Interface list downloaded to FIB
                	**type**\:  bool
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\:  bool
                
                .. attribute:: items
                
                	Number of items on which interface list is replicated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface, self).__init__()

                    self.yang_name = "generic-interface"
                    self.yang_parent_name = "generic-interfaces"

                    self.generic_interface_list_name = YLeaf(YType.str, "generic-interface-list-name")

                    self.interface_list_id = YLeaf(YType.uint32, "interface-list-id")

                    self.interface_list_name = YLeaf(YType.str, "interface-list-name")

                    self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                    self.is_provisioned = YLeaf(YType.boolean, "is-provisioned")

                    self.items = YLeaf(YType.uint32, "items")

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("generic_interface_list_name",
                                    "interface_list_id",
                                    "interface_list_name",
                                    "is_fib_downloaded",
                                    "is_provisioned",
                                    "items") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_fib_downloaded = YLeaf(YType.boolean, "is-fib-downloaded")

                        self.not_supported_replications = YLeaf(YType.uint32, "not-supported-replications")

                        self.pending_replications = YLeaf(YType.uint32, "pending-replications")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_fib_downloaded",
                                        "not_supported_replications",
                                        "pending_replications") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.is_fib_downloaded.is_set or
                            self.not_supported_replications.is_set or
                            self.pending_replications.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_fib_downloaded.yfilter != YFilter.not_set or
                            self.not_supported_replications.yfilter != YFilter.not_set or
                            self.pending_replications.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                        if (self.not_supported_replications.is_set or self.not_supported_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.not_supported_replications.get_name_leafdata())
                        if (self.pending_replications.is_set or self.pending_replications.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pending_replications.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "is-fib-downloaded" or name == "not-supported-replications" or name == "pending-replications"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-fib-downloaded"):
                            self.is_fib_downloaded = value
                            self.is_fib_downloaded.value_namespace = name_space
                            self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                        if(value_path == "not-supported-replications"):
                            self.not_supported_replications = value
                            self.not_supported_replications.value_namespace = name_space
                            self.not_supported_replications.value_namespace_prefix = name_space_prefix
                        if(value_path == "pending-replications"):
                            self.pending_replications = value
                            self.pending_replications.value_namespace = name_space
                            self.pending_replications.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.generic_interface_list_name.is_set or
                        self.interface_list_id.is_set or
                        self.interface_list_name.is_set or
                        self.is_fib_downloaded.is_set or
                        self.is_provisioned.is_set or
                        self.items.is_set)

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.generic_interface_list_name.yfilter != YFilter.not_set or
                        self.interface_list_id.yfilter != YFilter.not_set or
                        self.interface_list_name.yfilter != YFilter.not_set or
                        self.is_fib_downloaded.yfilter != YFilter.not_set or
                        self.is_provisioned.yfilter != YFilter.not_set or
                        self.items.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-interface" + "[generic-interface-list-name='" + self.generic_interface_list_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/active/generic-interfaces/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.generic_interface_list_name.is_set or self.generic_interface_list_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.generic_interface_list_name.get_name_leafdata())
                    if (self.interface_list_id.is_set or self.interface_list_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_id.get_name_leafdata())
                    if (self.interface_list_name.is_set or self.interface_list_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_list_name.get_name_leafdata())
                    if (self.is_fib_downloaded.is_set or self.is_fib_downloaded.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_fib_downloaded.get_name_leafdata())
                    if (self.is_provisioned.is_set or self.is_provisioned.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_provisioned.get_name_leafdata())
                    if (self.items.is_set or self.items.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.items.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "generic-interface-list-name" or name == "interface-list-id" or name == "interface-list-name" or name == "is-fib-downloaded" or name == "is-provisioned" or name == "items"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "generic-interface-list-name"):
                        self.generic_interface_list_name = value
                        self.generic_interface_list_name.value_namespace = name_space
                        self.generic_interface_list_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-list-id"):
                        self.interface_list_id = value
                        self.interface_list_id.value_namespace = name_space
                        self.interface_list_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-list-name"):
                        self.interface_list_name = value
                        self.interface_list_name.value_namespace = name_space
                        self.interface_list_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-fib-downloaded"):
                        self.is_fib_downloaded = value
                        self.is_fib_downloaded.value_namespace = name_space
                        self.is_fib_downloaded.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-provisioned"):
                        self.is_provisioned = value
                        self.is_provisioned.value_namespace = name_space
                        self.is_provisioned.value_namespace_prefix = name_space_prefix
                    if(value_path == "items"):
                        self.items = value
                        self.items.value_namespace = name_space
                        self.items.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.generic_interface:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.generic_interface:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "generic-interfaces" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "generic-interface"):
                    for c in self.generic_interface:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.generic_interface.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.generic_interfaces is not None and self.generic_interfaces.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.generic_interfaces is not None and self.generic_interfaces.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "active" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "generic-interfaces"):
                if (self.generic_interfaces is None):
                    self.generic_interfaces = GenericInterfaceListV2.Active.GenericInterfaces()
                    self.generic_interfaces.parent = self
                    self._children_name_map["generic_interfaces"] = "generic-interfaces"
                return self.generic_interfaces

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "generic-interfaces"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.active is not None and self.active.has_data()) or
            (self.nodes is not None and self.nodes.has_data()) or
            (self.standby is not None and self.standby.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.active is not None and self.active.has_operation()) or
            (self.nodes is not None and self.nodes.has_operation()) or
            (self.standby is not None and self.standby.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "active"):
            if (self.active is None):
                self.active = GenericInterfaceListV2.Active()
                self.active.parent = self
                self._children_name_map["active"] = "active"
            return self.active

        if (child_yang_name == "nodes"):
            if (self.nodes is None):
                self.nodes = GenericInterfaceListV2.Nodes()
                self.nodes.parent = self
                self._children_name_map["nodes"] = "nodes"
            return self.nodes

        if (child_yang_name == "standby"):
            if (self.standby is None):
                self.standby = GenericInterfaceListV2.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"
            return self.standby

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "active" or name == "nodes" or name == "standby"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = GenericInterfaceListV2()
        return self._top_entity

